#ifndef __VMLINUX_H__
#define __VMLINUX_H__

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute push (__attribute__((preserve_access_index)), apply_to = record)
#endif

typedef signed char __s8;

typedef unsigned char __u8;

typedef short int __s16;

typedef short unsigned int __u16;

typedef int __s32;

typedef unsigned int __u32;

typedef long long int __s64;

typedef long long unsigned int __u64;

typedef __s8 s8;

typedef __u8 u8;

typedef __s16 s16;

typedef __u16 u16;

typedef __s32 s32;

typedef __u32 u32;

typedef __s64 s64;

typedef __u64 u64;

enum {
	false = 0,
	true = 1,
};

typedef long int __kernel_long_t;

typedef long unsigned int __kernel_ulong_t;

typedef int __kernel_pid_t;

typedef unsigned int __kernel_uid32_t;

typedef unsigned int __kernel_gid32_t;

typedef __kernel_ulong_t __kernel_size_t;

typedef __kernel_long_t __kernel_ssize_t;

typedef long long int __kernel_loff_t;

typedef long long int __kernel_time64_t;

typedef __kernel_long_t __kernel_clock_t;

typedef int __kernel_timer_t;

typedef int __kernel_clockid_t;

typedef __u16 __be16;

typedef __u32 __le32;

typedef __u32 __be32;

typedef __u32 __wsum;

typedef unsigned int __poll_t;

typedef u32 __kernel_dev_t;

typedef __kernel_dev_t dev_t;

typedef short unsigned int umode_t;

typedef __kernel_pid_t pid_t;

typedef __kernel_clockid_t clockid_t;

typedef _Bool bool;

typedef __kernel_uid32_t uid_t;

typedef __kernel_gid32_t gid_t;

typedef __kernel_loff_t loff_t;

typedef __kernel_size_t size_t;

typedef __kernel_ssize_t ssize_t;

typedef s32 int32_t;

typedef u32 uint32_t;

typedef u64 sector_t;

typedef u64 blkcnt_t;

typedef unsigned int gfp_t;

typedef unsigned int fmode_t;

typedef u64 phys_addr_t;

typedef long unsigned int irq_hw_number_t;

typedef struct {
	int counter;
} atomic_t;

typedef struct {
	s64 counter;
} atomic64_t;

struct list_head {
	struct list_head *next;
	struct list_head *prev;
};

struct hlist_node;

struct hlist_head {
	struct hlist_node *first;
};

struct hlist_node {
	struct hlist_node *next;
	struct hlist_node **pprev;
};

struct callback_head {
	struct callback_head *next;
	void (*func)(struct callback_head *);
};

struct kernel_symbol {
	int value_offset;
	int name_offset;
	int namespace_offset;
};

struct jump_entry {
	s32 code;
	s32 target;
	long int key;
};

struct static_key_mod;

struct static_key {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry *entries;
		struct static_key_mod *next;
	};
};

struct static_key_true {
	struct static_key key;
};

struct static_key_false {
	struct static_key key;
};

typedef int (*initcall_t)();

typedef int initcall_entry_t;

struct lock_class_key {};

struct fs_context;

struct fs_parameter_spec;

struct dentry;

struct super_block;

struct module;

struct file_system_type {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry * (*mount)(struct file_system_type *, int, const char *, void *);
	void (*kill_sb)(struct super_block *);
	struct module *owner;
	struct file_system_type *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct obs_kernel_param {
	const char *str;
	int (*setup_func)(char *);
	int early;
};

typedef atomic64_t atomic_long_t;

struct qspinlock {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
};

typedef struct qspinlock arch_spinlock_t;

struct qrwlock {
	union {
		atomic_t cnts;
		struct {
			u8 wlocked;
			u8 __lstate[3];
		};
	};
	arch_spinlock_t wait_lock;
};

typedef struct qrwlock arch_rwlock_t;

struct lockdep_map {};

struct raw_spinlock {
	arch_spinlock_t raw_lock;
};

typedef struct raw_spinlock raw_spinlock_t;

struct spinlock {
	union {
		struct raw_spinlock rlock;
	};
};

typedef struct spinlock spinlock_t;

typedef struct {
	arch_rwlock_t raw_lock;
} rwlock_t;

struct ratelimit_state {
	raw_spinlock_t lock;
	int interval;
	int burst;
	int printed;
	int missed;
	long unsigned int begin;
	long unsigned int flags;
};

struct _ddebug {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct static_key_true dd_key_true;
		struct static_key_false dd_key_false;
	} key;
};

typedef void *fl_owner_t;

struct file;

struct kiocb;

struct iov_iter;

struct dir_context;

struct poll_table_struct;

struct vm_area_struct;

struct inode;

struct file_lock;

struct page;

struct pipe_inode_info;

struct seq_file;

struct file_operations {
	struct module *owner;
	loff_t (*llseek)(struct file *, loff_t, int);
	ssize_t (*read)(struct file *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb *, struct iov_iter *);
	ssize_t (*write_iter)(struct kiocb *, struct iov_iter *);
	int (*iopoll)(struct kiocb *, bool);
	int (*iterate)(struct file *, struct dir_context *);
	int (*iterate_shared)(struct file *, struct dir_context *);
	__poll_t (*poll)(struct file *, struct poll_table_struct *);
	long int (*unlocked_ioctl)(struct file *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file *, unsigned int, long unsigned int);
	int (*mmap)(struct file *, struct vm_area_struct *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode *, struct file *);
	int (*flush)(struct file *, fl_owner_t);
	int (*release)(struct inode *, struct file *);
	int (*fsync)(struct file *, loff_t, loff_t, int);
	int (*fasync)(int, struct file *, int);
	int (*lock)(struct file *, int, struct file_lock *);
	ssize_t (*sendpage)(struct file *, struct page *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file *, long unsigned int);
	int (*flock)(struct file *, int, struct file_lock *);
	ssize_t (*splice_write)(struct pipe_inode_info *, struct file *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file *, loff_t *, struct pipe_inode_info *, size_t, unsigned int);
	int (*setlease)(struct file *, long int, struct file_lock **, void **);
	long int (*fallocate)(struct file *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file *, struct file *);
	ssize_t (*copy_file_range)(struct file *, loff_t, struct file *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file *, loff_t, struct file *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file *, loff_t, loff_t, int);
};

struct static_call_key {
	void *func;
};

enum system_states {
	SYSTEM_BOOTING = 0,
	SYSTEM_SCHEDULING = 1,
	SYSTEM_RUNNING = 2,
	SYSTEM_HALT = 3,
	SYSTEM_POWER_OFF = 4,
	SYSTEM_RESTART = 5,
	SYSTEM_SUSPEND = 6,
};

typedef __s64 time64_t;

struct __kernel_timespec {
	__kernel_time64_t tv_sec;
	long long int tv_nsec;
};

struct timespec64 {
	time64_t tv_sec;
	long int tv_nsec;
};

struct bug_entry {
	int bug_addr_disp;
	int file_disp;
	short unsigned int line;
	short unsigned int flags;
};

struct cpumask {
	long unsigned int bits[4];
};

typedef struct cpumask cpumask_t;

typedef struct cpumask cpumask_var_t[1];

struct llist_node;

struct llist_head {
	struct llist_node *first;
};

struct llist_node {
	struct llist_node *next;
};

struct __call_single_node {
	struct llist_node llist;
	union {
		unsigned int u_flags;
		atomic_t a_flags;
	};
	u16 src;
	u16 dst;
};

typedef void (*smp_call_func_t)(void *);

struct __call_single_data {
	struct __call_single_node node;
	smp_call_func_t func;
	void *info;
};

enum timespec_type {
	TT_NONE = 0,
	TT_NATIVE = 1,
	TT_COMPAT = 2,
};

typedef s32 old_time32_t;

struct old_timespec32 {
	old_time32_t tv_sec;
	s32 tv_nsec;
};

struct pollfd {
	int fd;
	short int events;
	short int revents;
};

struct restart_block {
	long unsigned int arch_data;
	long int (*fn)(struct restart_block *);
	union {
		struct {
			u32 *uaddr;
			u32 val;
			u32 flags;
			u32 bitset;
			u64 time;
			u32 *uaddr2;
		} futex;
		struct {
			clockid_t clockid;
			enum timespec_type type;
			union {
				struct __kernel_timespec *rmtp;
				struct old_timespec32 *compat_rmtp;
			};
			u64 expires;
		} nanosleep;
		struct {
			struct pollfd *ufds;
			int nfds;
			int has_timeout;
			long unsigned int tv_sec;
			long unsigned int tv_nsec;
		} poll;
	};
};

struct thread_info {
	long unsigned int flags;
	u64 ttbr0;
	union {
		u64 preempt_count;
		struct {
			u32 count;
			u32 need_resched;
		} preempt;
	};
};

struct refcount_struct {
	atomic_t refs;
};

typedef struct refcount_struct refcount_t;

struct load_weight {
	long unsigned int weight;
	u32 inv_weight;
};

struct rb_node {
	long unsigned int __rb_parent_color;
	struct rb_node *rb_right;
	struct rb_node *rb_left;
};

struct sched_statistics {
	u64 wait_start;
	u64 wait_max;
	u64 wait_count;
	u64 wait_sum;
	u64 iowait_count;
	u64 iowait_sum;
	u64 sleep_start;
	u64 sleep_max;
	s64 sum_sleep_runtime;
	u64 block_start;
	u64 block_max;
	u64 exec_max;
	u64 slice_max;
	u64 nr_migrations_cold;
	u64 nr_failed_migrations_affine;
	u64 nr_failed_migrations_running;
	u64 nr_failed_migrations_hot;
	u64 nr_forced_migrations;
	u64 nr_wakeups;
	u64 nr_wakeups_sync;
	u64 nr_wakeups_migrate;
	u64 nr_wakeups_local;
	u64 nr_wakeups_remote;
	u64 nr_wakeups_affine;
	u64 nr_wakeups_affine_attempts;
	u64 nr_wakeups_passive;
	u64 nr_wakeups_idle;
};

struct util_est {
	unsigned int enqueued;
	unsigned int ewma;
};

struct sched_avg {
	u64 last_update_time;
	u64 load_sum;
	u64 runnable_sum;
	u32 util_sum;
	u32 period_contrib;
	long unsigned int load_avg;
	long unsigned int runnable_avg;
	long unsigned int util_avg;
	struct util_est util_est;
};

struct cfs_rq;

struct sched_entity {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity *parent;
	struct cfs_rq *cfs_rq;
	struct cfs_rq *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct sched_rt_entity {
	struct list_head run_list;
	long unsigned int timeout;
	long unsigned int watchdog_stamp;
	unsigned int time_slice;
	short unsigned int on_rq;
	short unsigned int on_list;
	struct sched_rt_entity *back;
};

typedef s64 ktime_t;

struct timerqueue_node {
	struct rb_node node;
	ktime_t expires;
};

enum hrtimer_restart {
	HRTIMER_NORESTART = 0,
	HRTIMER_RESTART = 1,
};

struct hrtimer_clock_base;

struct hrtimer {
	struct timerqueue_node node;
	ktime_t _softexpires;
	enum hrtimer_restart (*function)(struct hrtimer *);
	struct hrtimer_clock_base *base;
	u8 state;
	u8 is_rel;
	u8 is_soft;
	u8 is_hard;
};

struct sched_dl_entity {
	struct rb_node rb_node;
	u64 dl_runtime;
	u64 dl_deadline;
	u64 dl_period;
	u64 dl_bw;
	u64 dl_density;
	s64 runtime;
	u64 deadline;
	unsigned int flags;
	unsigned int dl_throttled: 1;
	unsigned int dl_yielded: 1;
	unsigned int dl_non_contending: 1;
	unsigned int dl_overrun: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer dl_timer;
	struct hrtimer inactive_timer;
	struct sched_dl_entity *pi_se;
};

struct uclamp_se {
	unsigned int value: 11;
	unsigned int bucket_id: 3;
	unsigned int active: 1;
	unsigned int user_defined: 1;
};

union rcu_special {
	struct {
		u8 blocked;
		u8 need_qs;
		u8 exp_hint;
		u8 need_mb;
	} b;
	u32 s;
};

struct sched_info {
	long unsigned int pcount;
	long long unsigned int run_delay;
	long long unsigned int last_arrival;
	long long unsigned int last_queued;
};

struct plist_node {
	int prio;
	struct list_head prio_list;
	struct list_head node_list;
};

struct vmacache {
	u64 seqnum;
	struct vm_area_struct *vmas[4];
};

struct task_rss_stat {
	int events;
	int count[4];
};

struct prev_cputime {
	u64 utime;
	u64 stime;
	raw_spinlock_t lock;
};

struct rb_root {
	struct rb_node *rb_node;
};

struct rb_root_cached {
	struct rb_root rb_root;
	struct rb_node *rb_leftmost;
};

struct timerqueue_head {
	struct rb_root_cached rb_root;
};

struct posix_cputimer_base {
	u64 nextevt;
	struct timerqueue_head tqhead;
};

struct posix_cputimers {
	struct posix_cputimer_base bases[3];
	unsigned int timers_active;
	unsigned int expiry_active;
};

struct nameidata;

struct sem_undo_list;

struct sysv_sem {
	struct sem_undo_list *undo_list;
};

struct sysv_shm {
	struct list_head shm_clist;
};

typedef struct {
	long unsigned int sig[1];
} sigset_t;

struct sigpending {
	struct list_head list;
	sigset_t signal;
};

typedef struct {
	uid_t val;
} kuid_t;

struct seccomp_filter;

struct seccomp {
	int mode;
	atomic_t filter_count;
	struct seccomp_filter *filter;
};

struct syscall_user_dispatch {};

struct wake_q_node {
	struct wake_q_node *next;
};

struct task_io_accounting {
	u64 rchar;
	u64 wchar;
	u64 syscr;
	u64 syscw;
	u64 read_bytes;
	u64 write_bytes;
	u64 cancelled_write_bytes;
};

typedef struct {
	long unsigned int bits[1];
} nodemask_t;

struct seqcount {
	unsigned int sequence;
};

typedef struct seqcount seqcount_t;

struct seqcount_spinlock {
	seqcount_t seqcount;
};

typedef struct seqcount_spinlock seqcount_spinlock_t;

struct optimistic_spin_queue {
	atomic_t tail;
};

struct mutex {
	atomic_long_t owner;
	raw_spinlock_t wait_lock;
	struct optimistic_spin_queue osq;
	struct list_head wait_list;
};

struct tlbflush_unmap_batch {};

struct page_frag {
	struct page *page;
	__u32 offset;
	__u32 size;
};

struct kmap_ctrl {};

struct cpu_context {
	long unsigned int x19;
	long unsigned int x20;
	long unsigned int x21;
	long unsigned int x22;
	long unsigned int x23;
	long unsigned int x24;
	long unsigned int x25;
	long unsigned int x26;
	long unsigned int x27;
	long unsigned int x28;
	long unsigned int fp;
	long unsigned int sp;
	long unsigned int pc;
};

struct user_fpsimd_state {
	__int128 unsigned vregs[32];
	__u32 fpsr;
	__u32 fpcr;
	__u32 __reserved[2];
};

struct perf_event;

struct debug_info {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event *hbp_break[16];
	struct perf_event *hbp_watch[16];
};

struct ptrauth_key {
	long unsigned int lo;
	long unsigned int hi;
};

struct ptrauth_keys_user {
	struct ptrauth_key apia;
	struct ptrauth_key apib;
	struct ptrauth_key apda;
	struct ptrauth_key apdb;
	struct ptrauth_key apga;
};

struct ptrauth_keys_kernel {
	struct ptrauth_key apia;
};

struct thread_struct {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct sched_class;

struct task_group;

struct mm_struct;

struct pid;

struct completion;

struct cred;

struct key;

struct fs_struct;

struct files_struct;

struct io_uring_task;

struct nsproxy;

struct signal_struct;

struct sighand_struct;

struct audit_context;

struct rt_mutex_waiter;

struct bio_list;

struct blk_plug;

struct reclaim_state;

struct backing_dev_info;

struct io_context;

struct capture_control;

struct kernel_siginfo;

typedef struct kernel_siginfo kernel_siginfo_t;

struct css_set;

struct robust_list_head;

struct compat_robust_list_head;

struct futex_pi_state;

struct perf_event_context;

struct mempolicy;

struct numa_group;

struct rseq;

struct task_delay_info;

struct ftrace_ret_stack;

struct mem_cgroup;

struct request_queue;

struct uprobe_task;

struct vm_struct;

struct bpf_local_storage;

struct bpf_run_ctx;

struct task_struct {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct *mm;
	struct mm_struct *active_mm;
	struct vmacache vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct *real_parent;
	struct task_struct *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy *nsproxy;
	struct signal_struct *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info *backing_dev_info;
	struct io_context *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup *active_memcg;
	struct request_queue *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct *oom_reaper_list;
	struct vm_struct *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef s32 compat_long_t;

typedef u32 compat_uptr_t;

struct user_pt_regs {
	__u64 regs[31];
	__u64 sp;
	__u64 pc;
	__u64 pstate;
};

struct pt_regs {
	union {
		struct user_pt_regs user_regs;
		struct {
			u64 regs[31];
			u64 sp;
			u64 pc;
			u64 pstate;
		};
	};
	u64 orig_x0;
	s32 syscallno;
	u32 unused2;
	u64 sdei_ttbr1;
	u64 pmr_save;
	u64 stackframe[2];
	u64 lockdep_hardirqs;
	u64 exit_rcu;
};

struct arch_hw_breakpoint_ctrl {
	u32 __reserved: 19;
	u32 len: 8;
	u32 type: 2;
	u32 privilege: 2;
	u32 enabled: 1;
};

struct arch_hw_breakpoint {
	u64 address;
	u64 trigger;
	struct arch_hw_breakpoint_ctrl ctrl;
};

typedef u64 pteval_t;

typedef u64 pmdval_t;

typedef u64 pudval_t;

typedef u64 pgdval_t;

typedef struct {
	pteval_t pte;
} pte_t;

typedef struct {
	pmdval_t pmd;
} pmd_t;

typedef struct {
	pudval_t pud;
} pud_t;

typedef struct {
	pgdval_t pgd;
} pgd_t;

typedef struct {
	pteval_t pgprot;
} pgprot_t;

enum module_state {
	MODULE_STATE_LIVE = 0,
	MODULE_STATE_COMING = 1,
	MODULE_STATE_GOING = 2,
	MODULE_STATE_UNFORMED = 3,
};

struct kref {
	refcount_t refcount;
};

struct kset;

struct kobj_type;

struct kernfs_node;

struct kobject {
	const char *name;
	struct list_head entry;
	struct kobject *parent;
	struct kset *kset;
	struct kobj_type *ktype;
	struct kernfs_node *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_param_attrs;

struct module_kobject {
	struct kobject kobj;
	struct module *mod;
	struct kobject *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct latch_tree_node {
	struct rb_node node[2];
};

struct mod_tree_node {
	struct module *mod;
	struct latch_tree_node node;
};

struct module_layout {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node mtn;
};

struct mod_plt_sec {
	int plt_shndx;
	int plt_num_entries;
	int plt_max_entries;
};

struct plt_entry;

struct mod_arch_specific {
	struct mod_plt_sec core;
	struct mod_plt_sec init;
	struct plt_entry *ftrace_trampolines;
};

struct elf64_sym;

typedef struct elf64_sym Elf64_Sym;

struct mod_kallsyms {
	Elf64_Sym *symtab;
	unsigned int num_symtab;
	char *strtab;
	char *typetab;
};

typedef const int tracepoint_ptr_t;

struct module_attribute;

struct kernel_param;

struct exception_table_entry;

struct module_sect_attrs;

struct module_notes_attrs;

struct srcu_struct;

struct bpf_raw_event_map;

struct trace_event_call;

struct trace_eval_map;

struct error_injection_entry;

struct module {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject mkobj;
	struct module_attribute *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout core_layout;
	struct module_layout init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum perf_event_state {
	PERF_EVENT_STATE_DEAD = 4294967292,
	PERF_EVENT_STATE_EXIT = 4294967293,
	PERF_EVENT_STATE_ERROR = 4294967294,
	PERF_EVENT_STATE_OFF = 4294967295,
	PERF_EVENT_STATE_INACTIVE = 0,
	PERF_EVENT_STATE_ACTIVE = 1,
};

typedef struct {
	atomic_long_t a;
} local_t;

typedef struct {
	local_t a;
} local64_t;

struct perf_event_attr {
	__u32 type;
	__u32 size;
	__u64 config;
	union {
		__u64 sample_period;
		__u64 sample_freq;
	};
	__u64 sample_type;
	__u64 read_format;
	__u64 disabled: 1;
	__u64 inherit: 1;
	__u64 pinned: 1;
	__u64 exclusive: 1;
	__u64 exclude_user: 1;
	__u64 exclude_kernel: 1;
	__u64 exclude_hv: 1;
	__u64 exclude_idle: 1;
	__u64 mmap: 1;
	__u64 comm: 1;
	__u64 freq: 1;
	__u64 inherit_stat: 1;
	__u64 enable_on_exec: 1;
	__u64 task: 1;
	__u64 watermark: 1;
	__u64 precise_ip: 2;
	__u64 mmap_data: 1;
	__u64 sample_id_all: 1;
	__u64 exclude_host: 1;
	__u64 exclude_guest: 1;
	__u64 exclude_callchain_kernel: 1;
	__u64 exclude_callchain_user: 1;
	__u64 mmap2: 1;
	__u64 comm_exec: 1;
	__u64 use_clockid: 1;
	__u64 context_switch: 1;
	__u64 write_backward: 1;
	__u64 namespaces: 1;
	__u64 ksymbol: 1;
	__u64 bpf_event: 1;
	__u64 aux_output: 1;
	__u64 cgroup: 1;
	__u64 text_poke: 1;
	__u64 build_id: 1;
	__u64 inherit_thread: 1;
	__u64 remove_on_exec: 1;
	__u64 sigtrap: 1;
	__u64 __reserved_1: 26;
	long: 38;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		__u32 wakeup_events;
		__u32 wakeup_watermark;
	};
	__u32 bp_type;
	union {
		__u64 bp_addr;
		__u64 kprobe_func;
		__u64 uprobe_path;
		__u64 config1;
	};
	union {
		__u64 bp_len;
		__u64 kprobe_addr;
		__u64 probe_offset;
		__u64 config2;
	};
	__u64 branch_sample_type;
	__u64 sample_regs_user;
	__u32 sample_stack_user;
	__s32 clockid;
	__u64 sample_regs_intr;
	__u32 aux_watermark;
	__u16 sample_max_stack;
	__u16 __reserved_2;
	__u32 aux_sample_size;
	__u32 __reserved_3;
	__u64 sig_data;
};

struct hw_perf_event_extra {
	u64 config;
	unsigned int reg;
	int alloc;
	int idx;
};

struct hw_perf_event {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct wait_queue_head {
	spinlock_t lock;
	struct list_head head;
};

typedef struct wait_queue_head wait_queue_head_t;

struct irq_work {
	struct __call_single_node node;
	void (*func)(struct irq_work *);
};

struct perf_addr_filters_head {
	struct list_head list;
	raw_spinlock_t lock;
	unsigned int nr_file_filters;
};

struct perf_sample_data;

typedef void (*perf_overflow_handler_t)(struct perf_event *, struct perf_sample_data *, struct pt_regs *);

struct ftrace_ops;

struct ftrace_regs;

typedef void (*ftrace_func_t)(long unsigned int, long unsigned int, struct ftrace_ops *, struct ftrace_regs *);

struct ftrace_hash;

struct ftrace_ops_hash {
	struct ftrace_hash *notrace_hash;
	struct ftrace_hash *filter_hash;
	struct mutex regex_lock;
};

struct ftrace_ops {
	ftrace_func_t func;
	struct ftrace_ops *next;
	long unsigned int flags;
	void *private;
	ftrace_func_t saved_func;
	struct ftrace_ops_hash local_hash;
	struct ftrace_ops_hash *func_hash;
	struct ftrace_ops_hash old_hash;
	long unsigned int trampoline;
	long unsigned int trampoline_size;
	struct list_head list;
};

struct pmu;

struct perf_buffer;

struct fasync_struct;

struct perf_addr_filter_range;

struct pid_namespace;

struct bpf_prog;

struct event_filter;

struct perf_cgroup;

struct perf_event {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event *group_leader;
	struct pmu *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event hw;
	struct perf_event_context *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event *aux_event;
	void (*destroy)(struct perf_event *);
	struct callback_head callback_head;
	struct pid_namespace *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup *cgrp;
	void *security;
	struct list_head sb_list;
};

struct wait_queue_entry;

typedef int (*wait_queue_func_t)(struct wait_queue_entry *, unsigned int, int, void *);

struct wait_queue_entry {
	unsigned int flags;
	void *private;
	wait_queue_func_t func;
	struct list_head entry;
};

typedef struct wait_queue_entry wait_queue_entry_t;

enum refcount_saturation_type {
	REFCOUNT_ADD_NOT_ZERO_OVF = 0,
	REFCOUNT_ADD_OVF = 1,
	REFCOUNT_ADD_UAF = 2,
	REFCOUNT_SUB_UAF = 3,
	REFCOUNT_DEC_LEAK = 4,
};

enum pid_type {
	PIDTYPE_PID = 0,
	PIDTYPE_TGID = 1,
	PIDTYPE_PGID = 2,
	PIDTYPE_SID = 3,
	PIDTYPE_MAX = 4,
};

struct upid {
	int nr;
	struct pid_namespace *ns;
};

struct xarray {
	spinlock_t xa_lock;
	gfp_t xa_flags;
	void *xa_head;
};

struct idr {
	struct xarray idr_rt;
	unsigned int idr_base;
	unsigned int idr_next;
};

struct proc_ns_operations;

struct ns_common {
	atomic_long_t stashed;
	const struct proc_ns_operations *ops;
	unsigned int inum;
	refcount_t count;
};

struct kmem_cache;

struct fs_pin;

struct user_namespace;

struct ucounts;

struct pid_namespace {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid numbers[1];
};

struct uid_gid_extent {
	u32 first;
	u32 lower_first;
	u32 count;
};

struct uid_gid_map {
	u32 nr_extents;
	union {
		struct uid_gid_extent extent[5];
		struct {
			struct uid_gid_extent *forward;
			struct uid_gid_extent *reverse;
		};
	};
};

typedef struct {
	gid_t val;
} kgid_t;

struct rw_semaphore {
	atomic_long_t count;
	atomic_long_t owner;
	struct optimistic_spin_queue osq;
	raw_spinlock_t wait_lock;
	struct list_head wait_list;
};

struct work_struct;

typedef void (*work_func_t)(struct work_struct *);

struct work_struct {
	atomic_long_t data;
	struct list_head entry;
	work_func_t func;
};

struct ctl_table;

struct ctl_table_root;

struct ctl_table_set;

struct ctl_dir;

struct ctl_node;

struct ctl_table_header {
	union {
		struct {
			struct ctl_table *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion *unregistering;
	struct ctl_table *ctl_table_arg;
	struct ctl_table_root *root;
	struct ctl_table_set *set;
	struct ctl_dir *parent;
	struct ctl_node *node;
	struct hlist_head inodes;
};

struct ctl_dir {
	struct ctl_table_header header;
	struct rb_root root;
};

struct ctl_table_set {
	int (*is_seen)(struct ctl_table_set *);
	struct ctl_dir dir;
};

struct user_namespace {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts *ucounts;
	long int ucount_max[16];
};

struct timer_list {
	struct hlist_node entry;
	long unsigned int expires;
	void (*function)(struct timer_list *);
	u32 flags;
};

struct workqueue_struct;

struct delayed_work {
	struct work_struct work;
	struct timer_list timer;
	struct workqueue_struct *wq;
	int cpu;
};

struct rcu_work {
	struct work_struct work;
	struct callback_head rcu;
	struct workqueue_struct *wq;
};

struct rhash_head {
	struct rhash_head *next;
};

struct rhashtable;

struct rhashtable_compare_arg {
	struct rhashtable *ht;
	const void *key;
};

typedef u32 (*rht_hashfn_t)(const void *, u32, u32);

typedef u32 (*rht_obj_hashfn_t)(const void *, u32, u32);

typedef int (*rht_obj_cmpfn_t)(struct rhashtable_compare_arg *, const void *);

struct rhashtable_params {
	u16 nelem_hint;
	u16 key_len;
	u16 key_offset;
	u16 head_offset;
	unsigned int max_size;
	u16 min_size;
	bool automatic_shrinking;
	rht_hashfn_t hashfn;
	rht_obj_hashfn_t obj_hashfn;
	rht_obj_cmpfn_t obj_cmpfn;
};

struct bucket_table;

struct rhashtable {
	struct bucket_table *tbl;
	unsigned int key_len;
	unsigned int max_elems;
	struct rhashtable_params p;
	bool rhlist;
	struct work_struct run_work;
	struct mutex mutex;
	spinlock_t lock;
	atomic_t nelems;
};

typedef struct page *pgtable_t;

struct address_space;

struct page_pool;

struct dev_pagemap;

struct page {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct seqcount_raw_spinlock {
	seqcount_t seqcount;
};

typedef struct seqcount_raw_spinlock seqcount_raw_spinlock_t;

typedef struct {
	seqcount_spinlock_t seqcount;
	spinlock_t lock;
} seqlock_t;

struct hrtimer_cpu_base;

struct hrtimer_clock_base {
	struct hrtimer_cpu_base *cpu_base;
	unsigned int index;
	clockid_t clockid;
	seqcount_raw_spinlock_t seq;
	struct hrtimer *running;
	struct timerqueue_head active;
	ktime_t (*get_time)();
	ktime_t offset;
};

struct hrtimer_cpu_base {
	raw_spinlock_t lock;
	unsigned int cpu;
	unsigned int active_bases;
	unsigned int clock_was_set_seq;
	unsigned int hres_active: 1;
	unsigned int in_hrtirq: 1;
	unsigned int hang_detected: 1;
	unsigned int softirq_activated: 1;
	long: 31;
	long: 64;
	long: 64;
	unsigned int nr_events;
	short unsigned int nr_retries;
	short unsigned int nr_hangs;
	unsigned int max_hang_time;
	ktime_t expires_next;
	struct hrtimer *next_timer;
	ktime_t softirq_expires_next;
	struct hrtimer *softirq_next_timer;
	struct hrtimer_clock_base clock_base[8];
};

enum node_states {
	N_POSSIBLE = 0,
	N_ONLINE = 1,
	N_NORMAL_MEMORY = 2,
	N_HIGH_MEMORY = 2,
	N_MEMORY = 3,
	N_CPU = 4,
	N_GENERIC_INITIATOR = 5,
	NR_NODE_STATES = 6,
};

struct rlimit {
	__kernel_ulong_t rlim_cur;
	__kernel_ulong_t rlim_max;
};

struct task_cputime {
	u64 stime;
	u64 utime;
	long long unsigned int sum_exec_runtime;
};

typedef void __signalfn_t(int);

typedef __signalfn_t *__sighandler_t;

typedef void __restorefn_t();

typedef __restorefn_t *__sigrestore_t;

union sigval {
	int sival_int;
	void *sival_ptr;
};

typedef union sigval sigval_t;

union __sifields {
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
	} _kill;
	struct {
		__kernel_timer_t _tid;
		int _overrun;
		sigval_t _sigval;
		int _sys_private;
	} _timer;
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
		sigval_t _sigval;
	} _rt;
	struct {
		__kernel_pid_t _pid;
		__kernel_uid32_t _uid;
		int _status;
		__kernel_clock_t _utime;
		__kernel_clock_t _stime;
	} _sigchld;
	struct {
		void *_addr;
		union {
			int _trapno;
			short int _addr_lsb;
			struct {
				char _dummy_bnd[8];
				void *_lower;
				void *_upper;
			} _addr_bnd;
			struct {
				char _dummy_pkey[8];
				__u32 _pkey;
			} _addr_pkey;
			struct {
				long unsigned int _data;
				__u32 _type;
			} _perf;
		};
	} _sigfault;
	struct {
		long int _band;
		int _fd;
	} _sigpoll;
	struct {
		void *_call_addr;
		int _syscall;
		unsigned int _arch;
	} _sigsys;
};

struct kernel_siginfo {
	struct {
		int si_signo;
		int si_errno;
		int si_code;
		union __sifields _sifields;
	};
};

struct ucounts {
	struct hlist_node node;
	struct user_namespace *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct sigaction {
	__sighandler_t sa_handler;
	long unsigned int sa_flags;
	__sigrestore_t sa_restorer;
	sigset_t sa_mask;
};

struct k_sigaction {
	struct sigaction sa;
};

struct userfaultfd_ctx;

struct vm_userfaultfd_ctx {
	struct userfaultfd_ctx *ctx;
};

struct anon_vma;

struct vm_operations_struct;

struct vm_area_struct {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct *vm_next;
	struct vm_area_struct *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct *vm_ops;
	long unsigned int vm_pgoff;
	struct file *vm_file;
	struct file *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct mm_rss_stat {
	atomic_long_t count[4];
};

struct cpu_itimer {
	u64 expires;
	u64 incr;
};

struct task_cputime_atomic {
	atomic64_t utime;
	atomic64_t stime;
	atomic64_t sum_exec_runtime;
};

struct thread_group_cputimer {
	struct task_cputime_atomic cputime_atomic;
};

struct pacct_struct {
	int ac_flag;
	long int ac_exitcode;
	long unsigned int ac_mem;
	u64 ac_utime;
	u64 ac_stime;
	long unsigned int ac_minflt;
	long unsigned int ac_majflt;
};

struct tty_struct;

struct autogroup;

struct taskstats;

struct tty_audit_buf;

struct signal_struct {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid *pids[4];
	struct pid *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct rseq {
	__u32 cpu_id_start;
	__u32 cpu_id;
	__u64 rseq_cs;
	__u32 flags;
	long: 32;
	long: 64;
};

struct rq;

struct task_struct___2;

struct rq_flags;

struct sched_class {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq *, struct task_struct___2 *, int);
	void (*dequeue_task)(struct rq *, struct task_struct___2 *, int);
	void (*yield_task)(struct rq *);
	bool (*yield_to_task)(struct rq *, struct task_struct___2 *);
	void (*check_preempt_curr)(struct rq *, struct task_struct___2 *, int);
	struct task_struct___2 * (*pick_next_task)(struct rq *);
	void (*put_prev_task)(struct rq *, struct task_struct___2 *);
	void (*set_next_task)(struct rq *, struct task_struct___2 *, bool);
	int (*balance)(struct rq *, struct task_struct___2 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___2 *, int, int);
	struct task_struct___2 * (*pick_task)(struct rq *);
	void (*migrate_task_rq)(struct task_struct___2 *, int);
	void (*task_woken)(struct rq *, struct task_struct___2 *);
	void (*set_cpus_allowed)(struct task_struct___2 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq *);
	void (*rq_offline)(struct rq *);
	struct rq * (*find_lock_rq)(struct task_struct___2 *, struct rq *);
	void (*task_tick)(struct rq *, struct task_struct___2 *, int);
	void (*task_fork)(struct task_struct___2 *);
	void (*task_dead)(struct task_struct___2 *);
	void (*switched_from)(struct rq *, struct task_struct___2 *);
	void (*switched_to)(struct rq *, struct task_struct___2 *);
	void (*prio_changed)(struct rq *, struct task_struct___2 *, int);
	unsigned int (*get_rr_interval)(struct rq *, struct task_struct___2 *);
	void (*update_curr)(struct rq *);
	void (*task_change_group)(struct task_struct___2 *, int);
};

typedef struct {
	atomic64_t id;
	void *sigpage;
	refcount_t pinned;
	void *vdso;
	long unsigned int flags;
} mm_context_t;

struct xol_area;

struct uprobes_state {
	struct xol_area *xol_area;
};

struct linux_binfmt;

struct core_state;

struct kioctx_table;

struct mmu_notifier_subscriptions;

struct mm_struct {
	struct {
		struct vm_area_struct *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct *owner;
		struct user_namespace *user_ns;
		struct file *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct swait_queue_head {
	raw_spinlock_t lock;
	struct list_head task_list;
};

struct completion {
	unsigned int done;
	struct swait_queue_head wait;
};

struct kernel_cap_struct {
	__u32 cap[2];
};

typedef struct kernel_cap_struct kernel_cap_t;

struct user_struct;

struct group_info;

struct cred {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

typedef int32_t key_serial_t;

typedef uint32_t key_perm_t;

struct key_type;

struct key_tag;

struct keyring_index_key {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type *type;
	struct key_tag *domain_tag;
	const char *description;
};

union key_payload {
	void *rcu_data0;
	void *data[4];
};

struct assoc_array_ptr;

struct assoc_array {
	struct assoc_array_ptr *root;
	long unsigned int nr_leaves_on_tree;
};

struct watch_list;

struct key_user;

struct key_restriction;

struct key {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction *restrict_link;
};

struct uts_namespace;

struct ipc_namespace;

struct mnt_namespace;

struct net;

struct time_namespace;

struct cgroup_namespace;

struct nsproxy {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace *cgroup_ns;
};

struct sighand_struct {
	spinlock_t siglock;
	refcount_t count;
	wait_queue_head_t signalfd_wqh;
	struct k_sigaction action[64];
};

struct bio;

struct bio_list {
	struct bio *head;
	struct bio *tail;
};

struct blk_plug {
	struct list_head mq_list;
	struct list_head cb_list;
	short unsigned int rq_count;
	bool multiple_queues;
	bool nowait;
};

struct reclaim_state {
	long unsigned int reclaimed_slab;
};

struct percpu_counter {
	raw_spinlock_t lock;
	s64 count;
	struct list_head list;
	s32 *counters;
};

struct fprop_local_percpu {
	struct percpu_counter events;
	unsigned int period;
	raw_spinlock_t lock;
};

enum wb_reason {
	WB_REASON_BACKGROUND = 0,
	WB_REASON_VMSCAN = 1,
	WB_REASON_SYNC = 2,
	WB_REASON_PERIODIC = 3,
	WB_REASON_LAPTOP_TIMER = 4,
	WB_REASON_FS_FREE_SPACE = 5,
	WB_REASON_FORKER_THREAD = 6,
	WB_REASON_FOREIGN_FLUSH = 7,
	WB_REASON_MAX = 8,
};

struct percpu_ref_data;

struct percpu_ref {
	long unsigned int percpu_count_ptr;
	struct percpu_ref_data *data;
};

struct cgroup_subsys_state;

struct bdi_writeback {
	struct backing_dev_info *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state *memcg_css;
	struct cgroup_subsys_state *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device;

struct backing_dev_info {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device *dev;
	char dev_name[64];
	struct device *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry *debug_dir;
};

struct io_cq;

struct io_context {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup;

struct css_set {
	struct cgroup_subsys_state *subsys[14];
	refcount_t refcount;
	struct css_set *dom_cset;
	struct cgroup *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup *mg_src_cgrp;
	struct cgroup *mg_dst_cgrp;
	struct css_set *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct compat_robust_list {
	compat_uptr_t next;
};

struct compat_robust_list_head {
	struct compat_robust_list list;
	compat_long_t futex_offset;
	compat_uptr_t list_op_pending;
};

struct perf_event_groups {
	struct rb_root tree;
	u64 index;
};

struct perf_event_context {
	struct pmu *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct mempolicy {
	atomic_t refcnt;
	short unsigned int mode;
	short unsigned int flags;
	nodemask_t nodes;
	union {
		nodemask_t cpuset_mems_allowed;
		nodemask_t user_nodemask;
	} w;
};

struct pipe_buffer;

struct watch_queue;

struct pipe_inode_info {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page *tmp_page;
	struct fasync_struct *fasync_readers;
	struct fasync_struct *fasync_writers;
	struct pipe_buffer *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct task_delay_info {
	raw_spinlock_t lock;
	unsigned int flags;
	u64 blkio_start;
	u64 blkio_delay;
	u64 swapin_delay;
	u32 blkio_count;
	u32 swapin_count;
	u64 freepages_start;
	u64 freepages_delay;
	u64 thrashing_start;
	u64 thrashing_delay;
	u32 freepages_count;
	u32 thrashing_count;
};

struct ftrace_ret_stack {
	long unsigned int ret;
	long unsigned int func;
	long long unsigned int calltime;
	long long unsigned int subtime;
	long unsigned int fp;
};

struct cgroup_subsys;

struct cgroup_subsys_state {
	struct cgroup *cgroup;
	struct cgroup_subsys *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state *parent;
};

struct mem_cgroup_id {
	int id;
	refcount_t ref;
};

struct page_counter {
	atomic_long_t usage;
	long unsigned int min;
	long unsigned int low;
	long unsigned int high;
	long unsigned int max;
	long unsigned int emin;
	atomic_long_t min_usage;
	atomic_long_t children_min_usage;
	long unsigned int elow;
	atomic_long_t low_usage;
	atomic_long_t children_low_usage;
	long unsigned int watermark;
	long unsigned int failcnt;
	struct page_counter *parent;
};

struct vmpressure {
	long unsigned int scanned;
	long unsigned int reclaimed;
	long unsigned int tree_scanned;
	long unsigned int tree_reclaimed;
	spinlock_t sr_lock;
	struct list_head events;
	struct mutex events_lock;
	struct work_struct work;
};

struct cgroup_file {
	struct kernfs_node *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct mem_cgroup_threshold_ary;

struct mem_cgroup_thresholds {
	struct mem_cgroup_threshold_ary *primary;
	struct mem_cgroup_threshold_ary *spare;
};

struct memcg_padding {
	char x[0];
};

struct memcg_vmstats {
	long int state[42];
	long unsigned int events[99];
	long int state_pending[42];
	long unsigned int events_pending[99];
};

enum memcg_kmem_state {
	KMEM_NONE = 0,
	KMEM_ALLOCATED = 1,
	KMEM_ONLINE = 2,
};

struct fprop_global {
	struct percpu_counter events;
	unsigned int period;
	seqcount_t sequence;
};

struct wb_domain {
	spinlock_t lock;
	struct fprop_global completions;
	struct timer_list period_timer;
	long unsigned int period_time;
	long unsigned int dirty_limit_tstamp;
	long unsigned int dirty_limit;
};

struct wb_completion {
	atomic_t cnt;
	wait_queue_head_t *waitq;
};

struct memcg_cgwb_frn {
	u64 bdi_id;
	int memcg_id;
	u64 at;
	struct wb_completion done;
};

struct deferred_split {
	spinlock_t split_queue_lock;
	struct list_head split_queue;
	long unsigned int split_queue_len;
};

struct obj_cgroup;

struct memcg_vmstats_percpu;

struct mem_cgroup_per_node;

struct mem_cgroup {
	struct cgroup_subsys_state css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file events_file;
	struct cgroup_file events_local_file;
	struct cgroup_file swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile;

struct blk_integrity {
	const struct blk_integrity_profile *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

enum rpm_status {
	RPM_ACTIVE = 0,
	RPM_RESUMING = 1,
	RPM_SUSPENDED = 2,
	RPM_SUSPENDING = 3,
};

struct blk_rq_stat {
	u64 mean;
	u64 min;
	u64 max;
	u32 nr_samples;
	u64 batch;
};

struct sbitmap_word;

struct sbitmap {
	unsigned int depth;
	unsigned int shift;
	unsigned int map_nr;
	bool round_robin;
	struct sbitmap_word *map;
	unsigned int *alloc_hint;
};

struct sbq_wait_state;

struct sbitmap_queue {
	struct sbitmap sb;
	unsigned int wake_batch;
	atomic_t wake_index;
	struct sbq_wait_state *ws;
	atomic_t ws_active;
	unsigned int min_shallow_depth;
};

enum blk_bounce {
	BLK_BOUNCE_NONE = 0,
	BLK_BOUNCE_HIGH = 1,
};

enum blk_zoned_model {
	BLK_ZONED_NONE = 0,
	BLK_ZONED_HA = 1,
	BLK_ZONED_HM = 2,
};

struct queue_limits {
	enum blk_bounce bounce;
	long unsigned int seg_boundary_mask;
	long unsigned int virt_boundary_mask;
	unsigned int max_hw_sectors;
	unsigned int max_dev_sectors;
	unsigned int chunk_sectors;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	unsigned int physical_block_size;
	unsigned int logical_block_size;
	unsigned int alignment_offset;
	unsigned int io_min;
	unsigned int io_opt;
	unsigned int max_discard_sectors;
	unsigned int max_hw_discard_sectors;
	unsigned int max_write_same_sectors;
	unsigned int max_write_zeroes_sectors;
	unsigned int max_zone_append_sectors;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	unsigned int zone_write_granularity;
	short unsigned int max_segments;
	short unsigned int max_integrity_segments;
	short unsigned int max_discard_segments;
	unsigned char misaligned;
	unsigned char discard_misaligned;
	unsigned char raid_partial_stripes_expensive;
	enum blk_zoned_model zoned;
};

typedef void *mempool_alloc_t(gfp_t, void *);

typedef void mempool_free_t(void *, void *);

struct mempool_s {
	spinlock_t lock;
	int min_nr;
	int curr_nr;
	void **elements;
	void *pool_data;
	mempool_alloc_t *alloc;
	mempool_free_t *free;
	wait_queue_head_t wait;
};

typedef struct mempool_s mempool_t;

struct bio_alloc_cache;

struct bio_set {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request;

struct elevator_queue;

struct blk_queue_stats;

struct rq_qos;

struct blk_mq_ops;

struct blk_mq_ctx;

struct blk_mq_hw_ctx;

struct gendisk;

struct blk_keyslot_manager;

struct blk_stat_callback;

struct blkcg_gq;

struct blk_trace;

struct blk_flush_queue;

struct throtl_data;

struct blk_mq_tag_set;

struct request_queue {
	struct request *last_merge;
	struct elevator_queue *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk *disk;
	struct kobject kobj;
	struct kobject *mq_kobj;
	struct blk_integrity integrity;
	struct device *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set *tag_set;
	struct list_head tag_set_list;
	struct bio_set bio_split;
	struct dentry *debugfs_dir;
	struct dentry *sched_debugfs_dir;
	struct dentry *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

enum uprobe_task_state {
	UTASK_RUNNING = 0,
	UTASK_SSTEP = 1,
	UTASK_SSTEP_ACK = 2,
	UTASK_SSTEP_TRAPPED = 3,
};

struct arch_uprobe_task {};

struct uprobe;

struct return_instance;

struct uprobe_task {
	enum uprobe_task_state state;
	union {
		struct {
			struct arch_uprobe_task autask;
			long unsigned int vaddr;
		};
		struct {
			struct callback_head dup_xol_work;
			long unsigned int dup_xol_addr;
		};
	};
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	struct return_instance *return_instances;
	unsigned int depth;
};

struct vm_struct {
	struct vm_struct *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_run_ctx {};

struct kstat {
	u32 result_mask;
	umode_t mode;
	unsigned int nlink;
	uint32_t blksize;
	u64 attributes;
	u64 attributes_mask;
	u64 ino;
	dev_t dev;
	dev_t rdev;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct timespec64 atime;
	struct timespec64 mtime;
	struct timespec64 ctime;
	struct timespec64 btime;
	u64 blocks;
	u64 mnt_id;
};

struct return_instance {
	struct uprobe *uprobe;
	long unsigned int func;
	long unsigned int stack;
	long unsigned int orig_ret_vaddr;
	bool chained;
	struct return_instance *next;
};

typedef u32 errseq_t;

struct address_space_operations;

struct address_space {
	struct inode *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

enum dma_data_direction {
	DMA_BIDIRECTIONAL = 0,
	DMA_TO_DEVICE = 1,
	DMA_FROM_DEVICE = 2,
	DMA_NONE = 3,
};

struct page_pool_params {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache {
	u32 count;
	struct page *cache[128];
};

struct ptr_ring {
	int producer;
	spinlock_t producer_lock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int consumer_head;
	int consumer_tail;
	spinlock_t consumer_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int size;
	int batch;
	void **queue;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct page_pool {
	struct page_pool_params p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmem_altmap {
	long unsigned int base_pfn;
	const long unsigned int end_pfn;
	const long unsigned int reserve;
	long unsigned int free;
	long unsigned int align;
	long unsigned int alloc;
};

enum memory_type {
	MEMORY_DEVICE_PRIVATE = 1,
	MEMORY_DEVICE_FS_DAX = 2,
	MEMORY_DEVICE_GENERIC = 3,
	MEMORY_DEVICE_PCI_P2PDMA = 4,
};

struct range {
	u64 start;
	u64 end;
};

struct dev_pagemap_ops;

struct dev_pagemap {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount;

struct path {
	struct vfsmount *mnt;
	struct dentry *dentry;
};

enum rw_hint {
	WRITE_LIFE_NOT_SET = 0,
	WRITE_LIFE_NONE = 1,
	WRITE_LIFE_SHORT = 2,
	WRITE_LIFE_MEDIUM = 3,
	WRITE_LIFE_LONG = 4,
	WRITE_LIFE_EXTREME = 5,
};

struct fown_struct {
	rwlock_t lock;
	struct pid *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_ra_state {
	long unsigned int start;
	unsigned int size;
	unsigned int async_size;
	unsigned int ra_pages;
	unsigned int mmap_miss;
	loff_t prev_pos;
};

struct file {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path f_path;
	struct inode *f_inode;
	const struct file_operations *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct anon_vma {
	struct anon_vma *root;
	struct rw_semaphore rwsem;
	atomic_t refcount;
	unsigned int degree;
	struct anon_vma *parent;
	struct rb_root_cached rb_root;
};

typedef unsigned int vm_fault_t;

enum page_entry_size {
	PE_SIZE_PTE = 0,
	PE_SIZE_PMD = 1,
	PE_SIZE_PUD = 2,
};

struct vm_fault;

struct vm_operations_struct {
	void (*open)(struct vm_area_struct *);
	void (*close)(struct vm_area_struct *);
	int (*may_split)(struct vm_area_struct *, long unsigned int);
	int (*mremap)(struct vm_area_struct *);
	int (*mprotect)(struct vm_area_struct *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault *);
	vm_fault_t (*huge_fault)(struct vm_fault *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct *);
	vm_fault_t (*page_mkwrite)(struct vm_fault *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault *);
	int (*access)(struct vm_area_struct *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct *);
	int (*set_policy)(struct vm_area_struct *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct *, long unsigned int);
	struct page * (*find_special_page)(struct vm_area_struct *, long unsigned int);
};

struct core_thread {
	struct task_struct *task;
	struct core_thread *next;
};

struct core_state {
	atomic_t nr_threads;
	struct core_thread dumper;
	struct completion startup;
};

struct linux_binprm;

struct coredump_params;

struct linux_binfmt {
	struct list_head lh;
	struct module *module;
	int (*load_binary)(struct linux_binprm *);
	int (*load_shlib)(struct file *);
	int (*core_dump)(struct coredump_params *);
	long unsigned int min_coredump;
};

enum fault_flag {
	FAULT_FLAG_WRITE = 1,
	FAULT_FLAG_MKWRITE = 2,
	FAULT_FLAG_ALLOW_RETRY = 4,
	FAULT_FLAG_RETRY_NOWAIT = 8,
	FAULT_FLAG_KILLABLE = 16,
	FAULT_FLAG_TRIED = 32,
	FAULT_FLAG_USER = 64,
	FAULT_FLAG_REMOTE = 128,
	FAULT_FLAG_INSTRUCTION = 256,
	FAULT_FLAG_INTERRUPTIBLE = 512,
};

struct vm_fault {
	const struct {
		struct vm_area_struct *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page *cow_page;
	struct page *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t prealloc_pte;
};

struct free_area {
	struct list_head free_list[6];
	long unsigned int nr_free;
};

struct zone_padding {
	char x[0];
};

enum node_stat_item {
	NR_LRU_BASE = 0,
	NR_INACTIVE_ANON = 0,
	NR_ACTIVE_ANON = 1,
	NR_INACTIVE_FILE = 2,
	NR_ACTIVE_FILE = 3,
	NR_UNEVICTABLE = 4,
	NR_SLAB_RECLAIMABLE_B = 5,
	NR_SLAB_UNRECLAIMABLE_B = 6,
	NR_ISOLATED_ANON = 7,
	NR_ISOLATED_FILE = 8,
	WORKINGSET_NODES = 9,
	WORKINGSET_REFAULT_BASE = 10,
	WORKINGSET_REFAULT_ANON = 10,
	WORKINGSET_REFAULT_FILE = 11,
	WORKINGSET_ACTIVATE_BASE = 12,
	WORKINGSET_ACTIVATE_ANON = 12,
	WORKINGSET_ACTIVATE_FILE = 13,
	WORKINGSET_RESTORE_BASE = 14,
	WORKINGSET_RESTORE_ANON = 14,
	WORKINGSET_RESTORE_FILE = 15,
	WORKINGSET_NODERECLAIM = 16,
	NR_ANON_MAPPED = 17,
	NR_FILE_MAPPED = 18,
	NR_FILE_PAGES = 19,
	NR_FILE_DIRTY = 20,
	NR_WRITEBACK = 21,
	NR_WRITEBACK_TEMP = 22,
	NR_SHMEM = 23,
	NR_SHMEM_THPS = 24,
	NR_SHMEM_PMDMAPPED = 25,
	NR_FILE_THPS = 26,
	NR_FILE_PMDMAPPED = 27,
	NR_ANON_THPS = 28,
	NR_VMSCAN_WRITE = 29,
	NR_VMSCAN_IMMEDIATE = 30,
	NR_DIRTIED = 31,
	NR_WRITTEN = 32,
	NR_KERNEL_MISC_RECLAIMABLE = 33,
	NR_FOLL_PIN_ACQUIRED = 34,
	NR_FOLL_PIN_RELEASED = 35,
	NR_KERNEL_STACK_KB = 36,
	NR_PAGETABLE = 37,
	NR_SWAPCACHE = 38,
	NR_VM_NODE_STAT_ITEMS = 39,
};

enum lru_list {
	LRU_INACTIVE_ANON = 0,
	LRU_ACTIVE_ANON = 1,
	LRU_INACTIVE_FILE = 2,
	LRU_ACTIVE_FILE = 3,
	LRU_UNEVICTABLE = 4,
	NR_LRU_LISTS = 5,
};

struct pglist_data;

struct lruvec {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data *pgdat;
};

struct per_cpu_pages;

struct per_cpu_zonestat;

struct zone {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref {
	struct zone *zone;
	int zone_idx;
};

struct zonelist {
	struct zoneref _zonerefs[321];
};

enum zone_type {
	ZONE_DMA = 0,
	ZONE_DMA32 = 1,
	ZONE_NORMAL = 2,
	ZONE_MOVABLE = 3,
	ZONE_DEVICE = 4,
	__MAX_NR_ZONES = 5,
};

struct per_cpu_nodestat;

struct pglist_data {
	struct zone node_zones[5];
	struct zonelist node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef unsigned int isolate_mode_t;

struct per_cpu_pages {
	int count;
	int high;
	int batch;
	short int free_factor;
	short int expire;
	struct list_head lists[15];
};

struct per_cpu_zonestat {
	s8 vm_stat_diff[11];
	s8 stat_threshold;
	long unsigned int vm_numa_event[6];
};

struct per_cpu_nodestat {
	s8 stat_threshold;
	s8 vm_node_stat_diff[39];
};

typedef struct pglist_data pg_data_t;

struct rcu_segcblist {
	struct callback_head *head;
	struct callback_head **tails[4];
	long unsigned int gp_seq[4];
	long int len;
	long int seglen[4];
	u8 flags;
};

struct srcu_node;

struct srcu_data {
	long unsigned int srcu_lock_count[2];
	long unsigned int srcu_unlock_count[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	struct rcu_segcblist srcu_cblist;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	bool srcu_cblist_invoking;
	struct timer_list delay_work;
	struct work_struct work;
	struct callback_head srcu_barrier_head;
	struct srcu_node *mynode;
	long unsigned int grpmask;
	int cpu;
	struct srcu_struct *ssp;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct srcu_node {
	spinlock_t lock;
	long unsigned int srcu_have_cbs[4];
	long unsigned int srcu_data_have_cbs[4];
	long unsigned int srcu_gp_seq_needed_exp;
	struct srcu_node *srcu_parent;
	int grplo;
	int grphi;
};

struct srcu_struct {
	struct srcu_node node[17];
	struct srcu_node *level[3];
	struct mutex srcu_cb_mutex;
	spinlock_t lock;
	struct mutex srcu_gp_mutex;
	unsigned int srcu_idx;
	long unsigned int srcu_gp_seq;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	long unsigned int srcu_last_gp_end;
	struct srcu_data *sda;
	long unsigned int srcu_barrier_seq;
	struct mutex srcu_barrier_mutex;
	struct completion srcu_barrier_completion;
	atomic_t srcu_barrier_cpu_cnt;
	struct delayed_work work;
	struct lockdep_map dep_map;
};

struct notifier_block;

typedef int (*notifier_fn_t)(struct notifier_block *, long unsigned int, void *);

struct notifier_block {
	notifier_fn_t notifier_call;
	struct notifier_block *next;
	int priority;
};

struct blocking_notifier_head {
	struct rw_semaphore rwsem;
	struct notifier_block *head;
};

struct raw_notifier_head {
	struct notifier_block *head;
};

typedef int proc_handler(struct ctl_table *, int, void *, size_t *, loff_t *);

struct ctl_table_poll;

struct ctl_table {
	const char *procname;
	void *data;
	int maxlen;
	umode_t mode;
	struct ctl_table *child;
	proc_handler *proc_handler;
	struct ctl_table_poll *poll;
	void *extra1;
	void *extra2;
};

struct ctl_table_poll {
	atomic_t event;
	wait_queue_head_t wait;
};

struct ctl_node {
	struct rb_node node;
	struct ctl_table_header *header;
};

struct ctl_table_root {
	struct ctl_table_set default_set;
	struct ctl_table_set * (*lookup)(struct ctl_table_root *);
	void (*set_ownership)(struct ctl_table_header *, struct ctl_table *, kuid_t *, kgid_t *);
	int (*permissions)(struct ctl_table_header *, struct ctl_table *);
};

typedef __u64 Elf64_Addr;

typedef __u16 Elf64_Half;

typedef __u32 Elf64_Word;

typedef __u64 Elf64_Xword;

struct elf64_sym {
	Elf64_Word st_name;
	unsigned char st_info;
	unsigned char st_other;
	Elf64_Half st_shndx;
	Elf64_Addr st_value;
	Elf64_Xword st_size;
};

struct hlist_bl_node;

struct hlist_bl_head {
	struct hlist_bl_node *first;
};

struct hlist_bl_node {
	struct hlist_bl_node *next;
	struct hlist_bl_node **pprev;
};

struct lockref {
	union {
		__u64 lock_count;
		struct {
			spinlock_t lock;
			int count;
		};
	};
};

struct qstr {
	union {
		struct {
			u32 hash;
			u32 len;
		};
		u64 hash_len;
	};
	const unsigned char *name;
};

struct dentry_operations;

struct dentry {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry *d_parent;
	struct qstr d_name;
	struct inode *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations *d_op;
	struct super_block *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct posix_acl;

struct inode_operations;

struct file_lock_context;

struct cdev;

struct fsnotify_mark_connector;

struct fscrypt_info;

struct fsverity_info;

struct inode {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations *i_op;
	struct super_block *i_sb;
	struct address_space *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations *i_fop;
		void (*free_inode)(struct inode *);
	};
	struct file_lock_context *i_flctx;
	struct address_space i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info *i_pipe;
		struct cdev *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations {
	int (*d_revalidate)(struct dentry *, unsigned int);
	int (*d_weak_revalidate)(struct dentry *, unsigned int);
	int (*d_hash)(const struct dentry *, struct qstr *);
	int (*d_compare)(const struct dentry *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry *);
	int (*d_init)(struct dentry *);
	void (*d_release)(struct dentry *);
	void (*d_prune)(struct dentry *);
	void (*d_iput)(struct dentry *, struct inode *);
	char * (*d_dname)(struct dentry *, char *, int);
	struct vfsmount * (*d_automount)(struct path *);
	int (*d_manage)(const struct path *, bool);
	struct dentry * (*d_real)(struct dentry *, const struct inode *);
	long: 64;
	long: 64;
	long: 64;
};

struct mtd_info;

typedef long long int qsize_t;

struct quota_format_type;

struct mem_dqinfo {
	struct quota_format_type *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops;

struct quota_info {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode *files[3];
	struct mem_dqinfo info[3];
	const struct quota_format_ops *ops[3];
};

struct rcu_sync {
	int gp_state;
	int gp_count;
	wait_queue_head_t gp_wait;
	struct callback_head cb_head;
};

struct rcuwait {
	struct task_struct *task;
};

struct percpu_rw_semaphore {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore rw_sem[3];
};

typedef struct {
	__u8 b[16];
} uuid_t;

struct shrink_control;

struct shrinker {
	long unsigned int (*count_objects)(struct shrinker *, struct shrink_control *);
	long unsigned int (*scan_objects)(struct shrinker *, struct shrink_control *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct list_lru_node;

struct list_lru {
	struct list_lru_node *node;
	struct list_head list;
	int shrinker_id;
	bool memcg_aware;
};

struct super_operations;

struct dquot_operations;

struct quotactl_ops;

struct export_operations;

struct xattr_handler;

struct fscrypt_operations;

struct fsverity_operations;

struct unicode_map;

struct block_device;

struct super_block {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type *s_type;
	const struct super_operations *s_op;
	const struct dquot_operations *dq_op;
	const struct quotactl_ops *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device *s_bdev;
	struct backing_dev_info *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info s_dquot;
	struct sb_writers s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount {
	struct dentry *mnt_root;
	struct super_block *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup *memcg;
};

struct list_lru_one {
	struct list_head list;
	long int nr_items;
};

struct list_lru_memcg {
	struct callback_head rcu;
	struct list_lru_one *lru[0];
};

struct list_lru_node {
	spinlock_t lock;
	struct list_lru_one lru;
	struct list_lru_memcg *memcg_lrus;
	long int nr_items;
	long: 64;
	long: 64;
};

enum migrate_mode {
	MIGRATE_ASYNC = 0,
	MIGRATE_SYNC_LIGHT = 1,
	MIGRATE_SYNC = 2,
	MIGRATE_SYNC_NO_COPY = 3,
};

struct exception_table_entry {
	int insn;
	int fixup;
};

struct cgroup_base_stat {
	struct task_cputime cputime;
};

struct psi_group_cpu;

struct psi_group {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array;

struct cgroup_bpf {
	struct bpf_prog_array *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_freezer_state {
	bool freeze;
	int e_freeze;
	int nr_frozen_descendants;
	int nr_frozen_tasks;
};

struct cgroup_root;

struct cgroup_rstat_cpu;

struct cgroup {
	struct cgroup_subsys_state self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node *kn;
	struct cgroup_file procs_file;
	struct cgroup_file events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state *subsys[14];
	struct cgroup_root *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup *dom_cgrp;
	struct cgroup *old_dom_cgrp;
	struct cgroup_rstat_cpu *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct key_tag {
	struct callback_head rcu;
	refcount_t usage;
	bool removed;
};

typedef int (*request_key_actor_t)(struct key *, void *);

struct key_preparsed_payload;

struct key_match_data;

struct seq_file___2;

struct kernel_pkey_params;

struct kernel_pkey_query;

struct key_type {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key *, struct key_preparsed_payload *);
	int (*update)(struct key *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data *);
	void (*match_free)(struct key_match_data *);
	void (*revoke)(struct key *);
	void (*destroy)(struct key *);
	void (*describe)(const struct key *, struct seq_file___2 *);
	long int (*read)(const struct key *, char *, size_t);
	request_key_actor_t request_key;
	struct key_restriction * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t)(struct key *, const struct key_type *, const union key_payload *, struct key *);

struct key_restriction {
	key_restrict_link_func_t check;
	struct key *key;
	struct key_type *keytype;
};

struct user_struct {
	refcount_t __count;
	struct percpu_counter epoll_watches;
	long unsigned int unix_inflight;
	atomic_long_t pipe_bufs;
	struct hlist_node uidhash_node;
	kuid_t uid;
	atomic_long_t locked_vm;
	atomic_t nr_watches;
	struct ratelimit_state ratelimit;
};

struct group_info {
	atomic_t usage;
	int ngroups;
	kgid_t gid[0];
};

struct taskstats {
	__u16 version;
	__u32 ac_exitcode;
	__u8 ac_flag;
	__u8 ac_nice;
	__u64 cpu_count;
	__u64 cpu_delay_total;
	__u64 blkio_count;
	__u64 blkio_delay_total;
	__u64 swapin_count;
	__u64 swapin_delay_total;
	__u64 cpu_run_real_total;
	__u64 cpu_run_virtual_total;
	char ac_comm[32];
	__u8 ac_sched;
	__u8 ac_pad[3];
	int: 32;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u64 ac_etime;
	__u64 ac_utime;
	__u64 ac_stime;
	__u64 ac_minflt;
	__u64 ac_majflt;
	__u64 coremem;
	__u64 virtmem;
	__u64 hiwater_rss;
	__u64 hiwater_vm;
	__u64 read_char;
	__u64 write_char;
	__u64 read_syscalls;
	__u64 write_syscalls;
	__u64 read_bytes;
	__u64 write_bytes;
	__u64 cancelled_write_bytes;
	__u64 nvcsw;
	__u64 nivcsw;
	__u64 ac_utimescaled;
	__u64 ac_stimescaled;
	__u64 cpu_scaled_run_real_total;
	__u64 freepages_count;
	__u64 freepages_delay_total;
	__u64 thrashing_count;
	__u64 thrashing_delay_total;
	__u64 ac_btime64;
};

struct delayed_call {
	void (*fn)(void *);
	void *arg;
};

struct io_cq {
	struct request_queue *q;
	struct io_context *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue;

struct kiocb {
	struct file *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue *ki_waitq;
	};
};

struct iattr {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file *ia_file;
};

typedef __kernel_uid32_t projid_t;

typedef struct {
	projid_t val;
} kprojid_t;

enum quota_type {
	USRQUOTA = 0,
	GRPQUOTA = 1,
	PRJQUOTA = 2,
};

struct kqid {
	union {
		kuid_t uid;
		kgid_t gid;
		kprojid_t projid;
	};
	enum quota_type type;
};

struct mem_dqblk {
	qsize_t dqb_bhardlimit;
	qsize_t dqb_bsoftlimit;
	qsize_t dqb_curspace;
	qsize_t dqb_rsvspace;
	qsize_t dqb_ihardlimit;
	qsize_t dqb_isoftlimit;
	qsize_t dqb_curinodes;
	time64_t dqb_btime;
	time64_t dqb_itime;
};

struct dquot {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type {
	int qf_fmt_id;
	const struct quota_format_ops *qf_ops;
	struct module *qf_owner;
	struct quota_format_type *qf_next;
};

struct quota_format_ops {
	int (*check_quota_file)(struct super_block *, int);
	int (*read_file_info)(struct super_block *, int);
	int (*write_file_info)(struct super_block *, int);
	int (*free_file_info)(struct super_block *, int);
	int (*read_dqblk)(struct dquot *);
	int (*commit_dqblk)(struct dquot *);
	int (*release_dqblk)(struct dquot *);
	int (*get_next_id)(struct super_block *, struct kqid *);
};

struct dquot_operations {
	int (*write_dquot)(struct dquot *);
	struct dquot * (*alloc_dquot)(struct super_block *, int);
	void (*destroy_dquot)(struct dquot *);
	int (*acquire_dquot)(struct dquot *);
	int (*release_dquot)(struct dquot *);
	int (*mark_dirty)(struct dquot *);
	int (*write_info)(struct super_block *, int);
	qsize_t * (*get_reserved_space)(struct inode *);
	int (*get_projid)(struct inode *, kprojid_t *);
	int (*get_inode_usage)(struct inode *, qsize_t *);
	int (*get_next_id)(struct super_block *, struct kqid *);
};

struct qc_dqblk {
	int d_fieldmask;
	u64 d_spc_hardlimit;
	u64 d_spc_softlimit;
	u64 d_ino_hardlimit;
	u64 d_ino_softlimit;
	u64 d_space;
	u64 d_ino_count;
	s64 d_ino_timer;
	s64 d_spc_timer;
	int d_ino_warns;
	int d_spc_warns;
	u64 d_rt_spc_hardlimit;
	u64 d_rt_spc_softlimit;
	u64 d_rt_space;
	s64 d_rt_spc_timer;
	int d_rt_spc_warns;
};

struct qc_type_state {
	unsigned int flags;
	unsigned int spc_timelimit;
	unsigned int ino_timelimit;
	unsigned int rt_spc_timelimit;
	unsigned int spc_warnlimit;
	unsigned int ino_warnlimit;
	unsigned int rt_spc_warnlimit;
	long long unsigned int ino;
	blkcnt_t blocks;
	blkcnt_t nextents;
};

struct qc_state {
	unsigned int s_incoredqs;
	struct qc_type_state s_state[3];
};

struct qc_info {
	int i_fieldmask;
	unsigned int i_flags;
	unsigned int i_spc_timelimit;
	unsigned int i_ino_timelimit;
	unsigned int i_rt_spc_timelimit;
	unsigned int i_spc_warnlimit;
	unsigned int i_ino_warnlimit;
	unsigned int i_rt_spc_warnlimit;
};

struct quotactl_ops {
	int (*quota_on)(struct super_block *, int, int, const struct path *);
	int (*quota_off)(struct super_block *, int);
	int (*quota_enable)(struct super_block *, unsigned int);
	int (*quota_disable)(struct super_block *, unsigned int);
	int (*quota_sync)(struct super_block *, int);
	int (*set_info)(struct super_block *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block *, struct qc_state *);
	int (*rm_xquota)(struct super_block *, unsigned int);
};

struct wait_page_queue {
	struct page *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control;

struct readahead_control;

struct swap_info_struct;

struct address_space_operations {
	int (*writepage)(struct page *, struct writeback_control *);
	int (*readpage)(struct file *, struct page *);
	int (*writepages)(struct address_space *, struct writeback_control *);
	int (*set_page_dirty)(struct page *);
	int (*readpages)(struct file *, struct address_space *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control *);
	int (*write_begin)(struct file *, struct address_space *, loff_t, unsigned int, unsigned int, struct page **, void **);
	int (*write_end)(struct file *, struct address_space *, loff_t, unsigned int, unsigned int, struct page *, void *);
	sector_t (*bmap)(struct address_space *, sector_t);
	void (*invalidatepage)(struct page *, unsigned int, unsigned int);
	int (*releasepage)(struct page *, gfp_t);
	void (*freepage)(struct page *);
	ssize_t (*direct_IO)(struct kiocb *, struct iov_iter *);
	int (*migratepage)(struct address_space *, struct page *, struct page *, enum migrate_mode);
	bool (*isolate_page)(struct page *, isolate_mode_t);
	void (*putback_page)(struct page *);
	int (*launder_page)(struct page *);
	int (*is_partially_uptodate)(struct page *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page *, bool *, bool *);
	int (*error_remove_page)(struct address_space *, struct page *);
	int (*swap_activate)(struct swap_info_struct *, struct file *, sector_t *);
	void (*swap_deactivate)(struct file *);
};

enum writeback_sync_modes {
	WB_SYNC_NONE = 0,
	WB_SYNC_ALL = 1,
};

struct writeback_control {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback *wb;
	struct inode *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control {
	struct file *file;
	struct address_space *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct iovec;

struct kvec;

struct bio_vec;

struct iov_iter {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec *bvec;
		struct xarray *xarray;
		struct pipe_inode_info *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_cluster_info {
	spinlock_t lock;
	unsigned int data: 24;
	unsigned int flags: 8;
	long: 56;
};

struct swap_cluster_list {
	struct swap_cluster_info head;
	struct swap_cluster_info tail;
};

struct percpu_cluster;

struct swap_info_struct {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device *bdev;
	struct file *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev {
	struct kobject kobj;
	struct module *owner;
	const struct file_operations *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct fiemap_extent_info;

struct fileattr;

struct inode_operations {
	struct dentry * (*lookup)(struct inode *, struct dentry *, unsigned int);
	const char * (*get_link)(struct dentry *, struct inode *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode *, int);
	struct posix_acl * (*get_acl)(struct inode *, int, bool);
	int (*readlink)(struct dentry *, char *, int);
	int (*create)(struct user_namespace *, struct inode *, struct dentry *, umode_t, bool);
	int (*link)(struct dentry *, struct inode *, struct dentry *);
	int (*unlink)(struct inode *, struct dentry *);
	int (*symlink)(struct user_namespace *, struct inode *, struct dentry *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode *, struct dentry *, umode_t);
	int (*rmdir)(struct inode *, struct dentry *);
	int (*mknod)(struct user_namespace *, struct inode *, struct dentry *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode *, struct dentry *, struct inode *, struct dentry *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry *, struct iattr *);
	int (*getattr)(struct user_namespace *, const struct path *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry *, char *, size_t);
	int (*fiemap)(struct inode *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode *, struct timespec64 *, int);
	int (*atomic_open)(struct inode *, struct dentry *, struct file *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode *, struct dentry *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry *, struct fileattr *);
	int (*fileattr_get)(struct dentry *, struct fileattr *);
	long: 64;
};

struct file_lock_context {
	spinlock_t flc_lock;
	struct list_head flc_flock;
	struct list_head flc_posix;
	struct list_head flc_lease;
};

struct file_lock_operations {
	void (*fl_copy_lock)(struct file_lock *, struct file_lock *);
	void (*fl_release_private)(struct file_lock *);
};

struct nlm_lockowner;

struct nfs_lock_info {
	u32 state;
	struct nlm_lockowner *owner;
	struct list_head list;
};

struct nfs4_lock_state;

struct nfs4_lock_info {
	struct nfs4_lock_state *owner;
};

struct lock_manager_operations;

struct file_lock {
	struct file_lock *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations *fl_ops;
	const struct lock_manager_operations *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock *);
	int (*lm_grant)(struct file_lock *, int);
	bool (*lm_break)(struct file_lock *);
	int (*lm_change)(struct file_lock *, int, struct list_head *);
	void (*lm_setup)(struct file_lock *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock *);
};

struct fasync_struct {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct *fa_next;
	struct file *fa_file;
	struct callback_head fa_rcu;
};

struct kstatfs;

struct super_operations {
	struct inode * (*alloc_inode)(struct super_block *);
	void (*destroy_inode)(struct inode *);
	void (*free_inode)(struct inode *);
	void (*dirty_inode)(struct inode *, int);
	int (*write_inode)(struct inode *, struct writeback_control *);
	int (*drop_inode)(struct inode *);
	void (*evict_inode)(struct inode *);
	void (*put_super)(struct super_block *);
	int (*sync_fs)(struct super_block *, int);
	int (*freeze_super)(struct super_block *);
	int (*freeze_fs)(struct super_block *);
	int (*thaw_super)(struct super_block *);
	int (*unfreeze_fs)(struct super_block *);
	int (*statfs)(struct dentry *, struct kstatfs *);
	int (*remount_fs)(struct super_block *, int *, char *);
	void (*umount_begin)(struct super_block *);
	int (*show_options)(struct seq_file *, struct dentry *);
	int (*show_devname)(struct seq_file *, struct dentry *);
	int (*show_path)(struct seq_file *, struct dentry *);
	int (*show_stats)(struct seq_file *, struct dentry *);
	ssize_t (*quota_read)(struct super_block *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block *, int, const char *, size_t, loff_t);
	struct dquot ** (*get_dquots)(struct inode *);
	long int (*nr_cached_objects)(struct super_block *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block *, struct shrink_control *);
	struct file * (*real_loop)(struct file *);
};

struct iomap;

struct inode___2;

struct dentry___2;

struct super_block___2;

struct fid;

struct iattr___2;

struct export_operations {
	int (*encode_fh)(struct inode___2 *, __u32 *, int *, struct inode___2 *);
	struct dentry___2 * (*fh_to_dentry)(struct super_block___2 *, struct fid *, int, int);
	struct dentry___2 * (*fh_to_parent)(struct super_block___2 *, struct fid *, int, int);
	int (*get_name)(struct dentry___2 *, char *, struct dentry___2 *);
	struct dentry___2 * (*get_parent)(struct dentry___2 *);
	int (*commit_metadata)(struct inode___2 *);
	int (*get_uuid)(struct super_block___2 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___2 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___2 *, struct iomap *, int, struct iattr___2 *);
	u64 (*fetch_iversion)(struct inode___2 *);
	long unsigned int flags;
};

struct xattr_handler {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry *);
	int (*get)(const struct xattr_handler *, struct dentry *, struct inode *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler *, struct user_namespace *, struct dentry *, struct inode *, const char *, const void *, size_t, int);
};

union fscrypt_policy;

struct request_queue___2;

struct fscrypt_operations {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___2 *, void *, size_t);
	int (*set_context)(struct inode___2 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___2 *);
	bool (*empty_dir)(struct inode___2 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___2 *);
	void (*get_ino_and_lblk_bits)(struct super_block___2 *, int *, int *);
	int (*get_num_devices)(struct super_block___2 *);
	void (*get_devices)(struct super_block___2 *, struct request_queue___2 **);
};

struct file___2;

struct inode___3;

struct page___2;

struct fsverity_operations {
	int (*begin_enable_verity)(struct file___2 *);
	int (*end_enable_verity)(struct file___2 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___3 *, void *, size_t);
	struct page___2 * (*read_merkle_tree_page)(struct inode___3 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___3 *, const void *, u64, int);
};

enum dl_dev_state {
	DL_DEV_NO_DRIVER = 0,
	DL_DEV_PROBING = 1,
	DL_DEV_DRIVER_BOUND = 2,
	DL_DEV_UNBINDING = 3,
};

struct dev_links_info {
	struct list_head suppliers;
	struct list_head consumers;
	struct list_head defer_sync;
	enum dl_dev_state status;
};

struct pm_message {
	int event;
};

typedef struct pm_message pm_message_t;

enum rpm_request {
	RPM_REQ_NONE = 0,
	RPM_REQ_IDLE = 1,
	RPM_REQ_SUSPEND = 2,
	RPM_REQ_AUTOSUSPEND = 3,
	RPM_REQ_RESUME = 4,
};

struct wakeup_source;

struct wake_irq;

struct pm_subsys_data;

struct dev_pm_qos;

struct dev_pm_info {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device *, s32);
	struct dev_pm_qos *qos;
};

struct dev_archdata {};

enum device_removable {
	DEVICE_REMOVABLE_NOT_SUPPORTED = 0,
	DEVICE_REMOVABLE_UNKNOWN = 1,
	DEVICE_FIXED = 2,
	DEVICE_REMOVABLE = 3,
};

struct device_private;

struct device_type;

struct bus_type;

struct device_driver;

struct dev_pm_domain;

struct em_perf_domain;

struct irq_domain;

struct dev_pin_info;

struct dma_map_ops;

struct bus_dma_region;

struct device_dma_parameters;

struct dma_coherent_mem;

struct cma;

struct io_tlb_mem;

struct device_node;

struct fwnode_handle;

struct class;

struct attribute_group;

struct iommu_group;

struct dev_iommu;

struct device {
	struct kobject kobj;
	struct device *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type *type;
	struct bus_type *bus;
	struct device_driver *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info power;
	struct dev_pm_domain *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node *of_node;
	struct fwnode_handle *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class *class;
	const struct attribute_group **groups;
	void (*release)(struct device *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct disk_stats;

struct partition_meta_info;

struct block_device {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode *bd_inode;
	struct super_block *bd_super;
	void *bd_claiming;
	struct device bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef int (*filldir_t)(struct dir_context *, const char *, int, loff_t, u64, unsigned int);

struct dir_context {
	filldir_t actor;
	loff_t pos;
};

typedef void (*poll_queue_proc)(struct file *, wait_queue_head_t *, struct poll_table_struct *);

struct poll_table_struct {
	poll_queue_proc _qproc;
	__poll_t _key;
};

struct seq_operations;

struct seq_file {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations *op;
	int poll_event;
	const struct file *file;
	void *private;
};

struct fc_log;

struct p_log {
	const char *prefix;
	struct fc_log *log;
};

enum fs_context_purpose {
	FS_CONTEXT_FOR_MOUNT = 0,
	FS_CONTEXT_FOR_SUBMOUNT = 1,
	FS_CONTEXT_FOR_RECONFIGURE = 2,
};

enum fs_context_phase {
	FS_CONTEXT_CREATE_PARAMS = 0,
	FS_CONTEXT_CREATING = 1,
	FS_CONTEXT_AWAITING_MOUNT = 2,
	FS_CONTEXT_AWAITING_RECONF = 3,
	FS_CONTEXT_RECONF_PARAMS = 4,
	FS_CONTEXT_RECONFIGURING = 5,
	FS_CONTEXT_FAILED = 6,
};

struct fs_context_operations;

struct fs_context {
	const struct fs_context_operations *ops;
	struct mutex uapi_mutex;
	struct file_system_type *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry *root;
	struct user_namespace *user_ns;
	struct net *net_ns;
	const struct cred *cred;
	struct p_log log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter;

struct fs_parse_result;

typedef int fs_param_type(struct p_log *, const struct fs_parameter_spec *, struct fs_parameter *, struct fs_parse_result *);

struct fs_parameter_spec {
	const char *name;
	fs_param_type *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct audit_names;

struct filename {
	const char *name;
	const char *uptr;
	int refcnt;
	struct audit_names *aname;
	const char iname[0];
};

typedef u8 blk_status_t;

struct bvec_iter {
	sector_t bi_sector;
	unsigned int bi_size;
	unsigned int bi_idx;
	unsigned int bi_bvec_done;
};

typedef void bio_end_io_t(struct bio *);

struct bio_issue {
	u64 value;
};

struct bio_vec {
	struct page *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_crypt_ctx;

struct bio_integrity_payload;

struct bio {
	struct bio *bi_next;
	struct block_device *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t *bi_end_io;
	void *bi_private;
	struct blkcg_gq *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec *bi_io_vec;
	struct bio_set *bi_pool;
	struct bio_vec bi_inline_vecs[0];
};

struct kernfs_root;

struct kernfs_elem_dir {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops;

struct kernfs_root {
	struct kernfs_node *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink {
	struct kernfs_node *target_kn;
};

struct kernfs_ops;

struct kernfs_open_node;

struct kernfs_elem_attr {
	const struct kernfs_ops *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node *notify_next;
};

struct kernfs_iattrs;

struct kernfs_node {
	atomic_t count;
	atomic_t active;
	struct kernfs_node *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir dir;
		struct kernfs_elem_symlink symlink;
		struct kernfs_elem_attr attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file;

struct kernfs_ops {
	int (*open)(struct kernfs_open_file *);
	void (*release)(struct kernfs_open_file *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	ssize_t (*read)(struct kernfs_open_file *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file *, struct poll_table_struct *);
	int (*mmap)(struct kernfs_open_file *, struct vm_area_struct *);
};

struct kernfs_syscall_ops {
	int (*show_options)(struct seq_file *, struct kernfs_root *);
	int (*mkdir)(struct kernfs_node *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node *);
	int (*rename)(struct kernfs_node *, struct kernfs_node *, const char *);
	int (*show_path)(struct seq_file *, struct kernfs_node *, struct kernfs_root *);
};

struct kernfs_open_file {
	struct kernfs_node *kn;
	struct file *file;
	struct seq_file *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct *vm_ops;
};

enum kobj_ns_type {
	KOBJ_NS_TYPE_NONE = 0,
	KOBJ_NS_TYPE_NET = 1,
	KOBJ_NS_TYPES = 2,
};

struct sock;

struct kobj_ns_type_operations {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct attribute {
	const char *name;
	umode_t mode;
};

struct bin_attribute;

struct attribute_group {
	const char *name;
	umode_t (*is_visible)(struct kobject *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject *, struct bin_attribute *, int);
	struct attribute **attrs;
	struct bin_attribute **bin_attrs;
};

struct bin_attribute {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space * (*f_mapping)();
	ssize_t (*read)(struct file *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	ssize_t (*write)(struct file *, struct kobject *, struct bin_attribute *, char *, loff_t, size_t);
	int (*mmap)(struct file *, struct kobject *, struct bin_attribute *, struct vm_area_struct *);
};

struct sysfs_ops {
	ssize_t (*show)(struct kobject *, struct attribute *, char *);
	ssize_t (*store)(struct kobject *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops;

struct kset {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject kobj;
	const struct kset_uevent_ops *uevent_ops;
};

struct kobj_type {
	void (*release)(struct kobject *);
	const struct sysfs_ops *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject *);
	const void * (*namespace)(struct kobject *);
	void (*get_ownership)(struct kobject *, kuid_t *, kgid_t *);
};

struct kobj_uevent_env {
	char *argv[3];
	char *envp[64];
	int envp_idx;
	char buf[2048];
	int buflen;
};

struct kset_uevent_ops {
	int (* const filter)(struct kset *, struct kobject *);
	const char * (* const name)(struct kset *, struct kobject *);
	int (* const uevent)(struct kset *, struct kobject *, struct kobj_uevent_env *);
};

struct kernel_param_ops {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param *);
	int (*get)(char *, const struct kernel_param *);
	void (*free)(void *);
};

struct kparam_string;

struct kparam_array;

struct kernel_param {
	const char *name;
	struct module *mod;
	const struct kernel_param_ops *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array *arr;
	};
};

struct kparam_string {
	unsigned int maxlen;
	char *string;
};

struct kparam_array {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops *ops;
	void *elem;
};

struct error_injection_entry {
	long unsigned int addr;
	int etype;
};

struct tracepoint_func {
	void *func;
	void *data;
	int prio;
};

struct tracepoint {
	const char *name;
	struct static_key key;
	struct static_call_key *static_call_key;
	void *static_call_tramp;
	void *iterator;
	int (*regfunc)();
	void (*unregfunc)();
	struct tracepoint_func *funcs;
};

struct bpf_raw_event_map {
	struct tracepoint *tp;
	void *bpf_func;
	u32 num_args;
	u32 writable_size;
	long: 64;
};

struct plt_entry {
	__le32 adrp;
	__le32 add;
	__le32 br;
};

struct module_attribute {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute *, struct module_kobject *, char *);
	ssize_t (*store)(struct module_attribute *, struct module_kobject *, const char *, size_t);
	void (*setup)(struct module *, const char *);
	int (*test)(struct module *);
	void (*free)(struct module *);
};

struct trace_event_functions;

struct trace_event {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions *funcs;
};

struct trace_event_class;

struct trace_event_call {
	struct list_head list;
	struct trace_event_class *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call *, struct perf_event *);
};

struct trace_eval_map {
	const char *system;
	const char *eval_string;
	long unsigned int eval_value;
};

struct linux_binprm {
	struct vm_area_struct *vma;
	long unsigned int vma_pages;
	struct mm_struct *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file *executable;
	struct file *interpreter;
	struct file *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct core_vma_metadata;

struct coredump_params {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct em_perf_state {
	long unsigned int frequency;
	long unsigned int power;
	long unsigned int cost;
};

struct em_perf_domain {
	struct em_perf_state *table;
	int nr_perf_states;
	int milliwatts;
	long unsigned int cpus[0];
};

struct dev_pm_ops {
	int (*prepare)(struct device *);
	void (*complete)(struct device *);
	int (*suspend)(struct device *);
	int (*resume)(struct device *);
	int (*freeze)(struct device *);
	int (*thaw)(struct device *);
	int (*poweroff)(struct device *);
	int (*restore)(struct device *);
	int (*suspend_late)(struct device *);
	int (*resume_early)(struct device *);
	int (*freeze_late)(struct device *);
	int (*thaw_early)(struct device *);
	int (*poweroff_late)(struct device *);
	int (*restore_early)(struct device *);
	int (*suspend_noirq)(struct device *);
	int (*resume_noirq)(struct device *);
	int (*freeze_noirq)(struct device *);
	int (*thaw_noirq)(struct device *);
	int (*poweroff_noirq)(struct device *);
	int (*restore_noirq)(struct device *);
	int (*runtime_suspend)(struct device *);
	int (*runtime_resume)(struct device *);
	int (*runtime_idle)(struct device *);
};

struct pm_domain_data;

struct pm_subsys_data {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data *domain_data;
};

struct wakeup_source {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain {
	struct dev_pm_ops ops;
	int (*start)(struct device *);
	void (*detach)(struct device *, bool);
	int (*activate)(struct device *);
	void (*sync)(struct device *);
	void (*dismiss)(struct device *);
};

struct iommu_ops;

struct subsys_private;

struct bus_type {
	const char *name;
	const char *dev_name;
	struct device *dev_root;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device *, struct device_driver *);
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	int (*probe)(struct device *);
	void (*sync_state)(struct device *);
	void (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*online)(struct device *);
	int (*offline)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	int (*num_vf)(struct device *);
	int (*dma_configure)(struct device *);
	const struct dev_pm_ops *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

enum probe_type {
	PROBE_DEFAULT_STRATEGY = 0,
	PROBE_PREFER_ASYNCHRONOUS = 1,
	PROBE_FORCE_SYNCHRONOUS = 2,
};

struct of_device_id;

struct acpi_device_id;

struct driver_private;

struct device_driver {
	const char *name;
	struct bus_type *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device *);
	void (*sync_state)(struct device *);
	int (*remove)(struct device *);
	void (*shutdown)(struct device *);
	int (*suspend)(struct device *, pm_message_t);
	int (*resume)(struct device *);
	const struct attribute_group **groups;
	const struct attribute_group **dev_groups;
	const struct dev_pm_ops *pm;
	void (*coredump)(struct device *);
	struct driver_private *p;
};

enum iommu_cap {
	IOMMU_CAP_CACHE_COHERENCY = 0,
	IOMMU_CAP_INTR_REMAP = 1,
	IOMMU_CAP_NOEXEC = 2,
};

typedef u64 dma_addr_t;

enum iommu_dev_features {
	IOMMU_DEV_FEAT_AUX = 0,
	IOMMU_DEV_FEAT_SVA = 1,
	IOMMU_DEV_FEAT_IOPF = 2,
};

struct iommu_domain;

struct device___2;

struct iommu_iotlb_gather;

struct iommu_device;

struct iommu_resv_region;

struct of_phandle_args;

struct iommu_sva;

struct mm_struct___2;

struct iommu_fault_event;

struct iommu_page_response;

struct iommu_cache_invalidate_info;

struct iommu_gpasid_bind_data;

struct module___2;

struct iommu_ops {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain *);
	int (*attach_dev)(struct iommu_domain *, struct device___2 *);
	void (*detach_dev)(struct iommu_domain *, struct device___2 *);
	int (*map)(struct iommu_domain *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain *, long unsigned int, size_t, struct iommu_iotlb_gather *);
	size_t (*unmap_pages)(struct iommu_domain *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather *);
	void (*flush_iotlb_all)(struct iommu_domain *);
	void (*iotlb_sync_map)(struct iommu_domain *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain *, struct iommu_iotlb_gather *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain *, dma_addr_t);
	struct iommu_device * (*probe_device)(struct device___2 *);
	void (*release_device)(struct device___2 *);
	void (*probe_finalize)(struct device___2 *);
	struct iommu_group * (*device_group)(struct device___2 *);
	int (*enable_nesting)(struct iommu_domain *);
	int (*set_pgtable_quirks)(struct iommu_domain *, long unsigned int);
	void (*get_resv_regions)(struct device___2 *, struct list_head *);
	void (*put_resv_regions)(struct device___2 *, struct list_head *);
	void (*apply_resv_region)(struct device___2 *, struct iommu_domain *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___2 *, struct of_phandle_args *);
	bool (*is_attach_deferred)(struct iommu_domain *, struct device___2 *);
	bool (*dev_has_feat)(struct device___2 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___2 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___2 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___2 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain *, struct device___2 *);
	void (*aux_detach_dev)(struct iommu_domain *, struct device___2 *);
	int (*aux_get_pasid)(struct iommu_domain *, struct device___2 *);
	struct iommu_sva * (*sva_bind)(struct device___2 *, struct mm_struct___2 *, void *);
	void (*sva_unbind)(struct iommu_sva *);
	u32 (*sva_get_pasid)(struct iommu_sva *);
	int (*page_response)(struct device___2 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain *, struct device___2 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain *, struct device___2 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___2 *, u32);
	int (*def_domain_type)(struct device___2 *);
	long unsigned int pgsize_bitmap;
	struct module___2 *owner;
};

struct device_type {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device *);
	const struct dev_pm_ops *pm;
};

struct class {
	const char *name;
	struct module *owner;
	const struct attribute_group **class_groups;
	const struct attribute_group **dev_groups;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device *, struct kobj_uevent_env *);
	char * (*devnode)(struct device *, umode_t *);
	void (*class_release)(struct class *);
	void (*dev_release)(struct device *);
	int (*shutdown_pre)(struct device *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device *);
	void (*get_ownership)(struct device *, kuid_t *, kgid_t *);
	const struct dev_pm_ops *pm;
	struct subsys_private *p;
};

struct of_device_id {
	char name[32];
	char type[32];
	char compatible[128];
	const void *data;
};

typedef long unsigned int kernel_ulong_t;

struct acpi_device_id {
	__u8 id[9];
	kernel_ulong_t driver_data;
	__u32 cls;
	__u32 cls_msk;
};

struct device_dma_parameters {
	unsigned int max_segment_size;
	unsigned int min_align_mask;
	long unsigned int segment_boundary_mask;
};

enum irq_domain_bus_token {
	DOMAIN_BUS_ANY = 0,
	DOMAIN_BUS_WIRED = 1,
	DOMAIN_BUS_GENERIC_MSI = 2,
	DOMAIN_BUS_PCI_MSI = 3,
	DOMAIN_BUS_PLATFORM_MSI = 4,
	DOMAIN_BUS_NEXUS = 5,
	DOMAIN_BUS_IPI = 6,
	DOMAIN_BUS_FSL_MC_MSI = 7,
	DOMAIN_BUS_TI_SCI_INTA_MSI = 8,
	DOMAIN_BUS_WAKEUP = 9,
	DOMAIN_BUS_VMD_MSI = 10,
};

struct irq_domain_ops;

struct irq_domain_chip_generic;

struct irq_data;

struct irq_domain {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic *gc;
	struct irq_domain *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data *revmap[0];
};

struct page___3;

struct sg_table;

struct vm_area_struct___2;

struct scatterlist;

struct dma_map_ops {
	void * (*alloc)(struct device___2 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___2 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___3 * (*alloc_pages)(struct device___2 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___2 *, size_t, struct page___3 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___2 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___2 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___2 *, struct vm_area_struct___2 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___2 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___2 *, struct page___3 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___2 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___2 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___2 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___2 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___2 *, u64);
	u64 (*get_required_mask)(struct device___2 *);
	size_t (*max_mapping_size)(struct device___2 *);
	long unsigned int (*get_merge_boundary)(struct device___2 *);
};

struct bus_dma_region {
	phys_addr_t cpu_start;
	dma_addr_t dma_start;
	u64 size;
	u64 offset;
};

typedef u32 phandle;

struct fwnode_operations;

struct fwnode_handle {
	struct fwnode_handle *secondary;
	const struct fwnode_operations *ops;
	struct device *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property;

struct device_node {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node *parent;
	struct device_node *child;
	struct device_node *sibling;
	struct kobject kobj;
	long unsigned int _flags;
	void *data;
};

enum cpuhp_state {
	CPUHP_INVALID = 4294967295,
	CPUHP_OFFLINE = 0,
	CPUHP_CREATE_THREADS = 1,
	CPUHP_PERF_PREPARE = 2,
	CPUHP_PERF_X86_PREPARE = 3,
	CPUHP_PERF_X86_AMD_UNCORE_PREP = 4,
	CPUHP_PERF_POWER = 5,
	CPUHP_PERF_SUPERH = 6,
	CPUHP_X86_HPET_DEAD = 7,
	CPUHP_X86_APB_DEAD = 8,
	CPUHP_X86_MCE_DEAD = 9,
	CPUHP_VIRT_NET_DEAD = 10,
	CPUHP_SLUB_DEAD = 11,
	CPUHP_DEBUG_OBJ_DEAD = 12,
	CPUHP_MM_WRITEBACK_DEAD = 13,
	CPUHP_MM_DEMOTION_DEAD = 14,
	CPUHP_MM_VMSTAT_DEAD = 15,
	CPUHP_SOFTIRQ_DEAD = 16,
	CPUHP_NET_MVNETA_DEAD = 17,
	CPUHP_CPUIDLE_DEAD = 18,
	CPUHP_ARM64_FPSIMD_DEAD = 19,
	CPUHP_ARM_OMAP_WAKE_DEAD = 20,
	CPUHP_IRQ_POLL_DEAD = 21,
	CPUHP_BLOCK_SOFTIRQ_DEAD = 22,
	CPUHP_BIO_DEAD = 23,
	CPUHP_ACPI_CPUDRV_DEAD = 24,
	CPUHP_S390_PFAULT_DEAD = 25,
	CPUHP_BLK_MQ_DEAD = 26,
	CPUHP_FS_BUFF_DEAD = 27,
	CPUHP_PRINTK_DEAD = 28,
	CPUHP_MM_MEMCQ_DEAD = 29,
	CPUHP_XFS_DEAD = 30,
	CPUHP_PERCPU_CNT_DEAD = 31,
	CPUHP_RADIX_DEAD = 32,
	CPUHP_PAGE_ALLOC = 33,
	CPUHP_NET_DEV_DEAD = 34,
	CPUHP_PCI_XGENE_DEAD = 35,
	CPUHP_IOMMU_IOVA_DEAD = 36,
	CPUHP_LUSTRE_CFS_DEAD = 37,
	CPUHP_AP_ARM_CACHE_B15_RAC_DEAD = 38,
	CPUHP_PADATA_DEAD = 39,
	CPUHP_WORKQUEUE_PREP = 40,
	CPUHP_POWER_NUMA_PREPARE = 41,
	CPUHP_HRTIMERS_PREPARE = 42,
	CPUHP_PROFILE_PREPARE = 43,
	CPUHP_X2APIC_PREPARE = 44,
	CPUHP_SMPCFD_PREPARE = 45,
	CPUHP_RELAY_PREPARE = 46,
	CPUHP_SLAB_PREPARE = 47,
	CPUHP_MD_RAID5_PREPARE = 48,
	CPUHP_RCUTREE_PREP = 49,
	CPUHP_CPUIDLE_COUPLED_PREPARE = 50,
	CPUHP_POWERPC_PMAC_PREPARE = 51,
	CPUHP_POWERPC_MMU_CTX_PREPARE = 52,
	CPUHP_XEN_PREPARE = 53,
	CPUHP_XEN_EVTCHN_PREPARE = 54,
	CPUHP_ARM_SHMOBILE_SCU_PREPARE = 55,
	CPUHP_SH_SH3X_PREPARE = 56,
	CPUHP_NET_FLOW_PREPARE = 57,
	CPUHP_TOPOLOGY_PREPARE = 58,
	CPUHP_NET_IUCV_PREPARE = 59,
	CPUHP_ARM_BL_PREPARE = 60,
	CPUHP_TRACE_RB_PREPARE = 61,
	CPUHP_MM_ZS_PREPARE = 62,
	CPUHP_MM_ZSWP_MEM_PREPARE = 63,
	CPUHP_MM_ZSWP_POOL_PREPARE = 64,
	CPUHP_KVM_PPC_BOOK3S_PREPARE = 65,
	CPUHP_ZCOMP_PREPARE = 66,
	CPUHP_TIMERS_PREPARE = 67,
	CPUHP_MIPS_SOC_PREPARE = 68,
	CPUHP_BP_PREPARE_DYN = 69,
	CPUHP_BP_PREPARE_DYN_END = 89,
	CPUHP_BRINGUP_CPU = 90,
	CPUHP_AP_IDLE_DEAD = 91,
	CPUHP_AP_OFFLINE = 92,
	CPUHP_AP_SCHED_STARTING = 93,
	CPUHP_AP_RCUTREE_DYING = 94,
	CPUHP_AP_CPU_PM_STARTING = 95,
	CPUHP_AP_IRQ_GIC_STARTING = 96,
	CPUHP_AP_IRQ_HIP04_STARTING = 97,
	CPUHP_AP_IRQ_APPLE_AIC_STARTING = 98,
	CPUHP_AP_IRQ_ARMADA_XP_STARTING = 99,
	CPUHP_AP_IRQ_BCM2836_STARTING = 100,
	CPUHP_AP_IRQ_MIPS_GIC_STARTING = 101,
	CPUHP_AP_IRQ_RISCV_STARTING = 102,
	CPUHP_AP_IRQ_SIFIVE_PLIC_STARTING = 103,
	CPUHP_AP_ARM_MVEBU_COHERENCY = 104,
	CPUHP_AP_MICROCODE_LOADER = 105,
	CPUHP_AP_PERF_X86_AMD_UNCORE_STARTING = 106,
	CPUHP_AP_PERF_X86_STARTING = 107,
	CPUHP_AP_PERF_X86_AMD_IBS_STARTING = 108,
	CPUHP_AP_PERF_X86_CQM_STARTING = 109,
	CPUHP_AP_PERF_X86_CSTATE_STARTING = 110,
	CPUHP_AP_PERF_XTENSA_STARTING = 111,
	CPUHP_AP_MIPS_OP_LOONGSON3_STARTING = 112,
	CPUHP_AP_ARM_SDEI_STARTING = 113,
	CPUHP_AP_ARM_VFP_STARTING = 114,
	CPUHP_AP_ARM64_DEBUG_MONITORS_STARTING = 115,
	CPUHP_AP_PERF_ARM_HW_BREAKPOINT_STARTING = 116,
	CPUHP_AP_PERF_ARM_ACPI_STARTING = 117,
	CPUHP_AP_PERF_ARM_STARTING = 118,
	CPUHP_AP_ARM_L2X0_STARTING = 119,
	CPUHP_AP_EXYNOS4_MCT_TIMER_STARTING = 120,
	CPUHP_AP_ARM_ARCH_TIMER_STARTING = 121,
	CPUHP_AP_ARM_GLOBAL_TIMER_STARTING = 122,
	CPUHP_AP_JCORE_TIMER_STARTING = 123,
	CPUHP_AP_ARM_TWD_STARTING = 124,
	CPUHP_AP_QCOM_TIMER_STARTING = 125,
	CPUHP_AP_TEGRA_TIMER_STARTING = 126,
	CPUHP_AP_ARMADA_TIMER_STARTING = 127,
	CPUHP_AP_MARCO_TIMER_STARTING = 128,
	CPUHP_AP_MIPS_GIC_TIMER_STARTING = 129,
	CPUHP_AP_ARC_TIMER_STARTING = 130,
	CPUHP_AP_RISCV_TIMER_STARTING = 131,
	CPUHP_AP_CLINT_TIMER_STARTING = 132,
	CPUHP_AP_CSKY_TIMER_STARTING = 133,
	CPUHP_AP_TI_GP_TIMER_STARTING = 134,
	CPUHP_AP_HYPERV_TIMER_STARTING = 135,
	CPUHP_AP_KVM_STARTING = 136,
	CPUHP_AP_KVM_ARM_VGIC_INIT_STARTING = 137,
	CPUHP_AP_KVM_ARM_VGIC_STARTING = 138,
	CPUHP_AP_KVM_ARM_TIMER_STARTING = 139,
	CPUHP_AP_DUMMY_TIMER_STARTING = 140,
	CPUHP_AP_ARM_XEN_STARTING = 141,
	CPUHP_AP_ARM_CORESIGHT_STARTING = 142,
	CPUHP_AP_ARM_CORESIGHT_CTI_STARTING = 143,
	CPUHP_AP_ARM64_ISNDEP_STARTING = 144,
	CPUHP_AP_SMPCFD_DYING = 145,
	CPUHP_AP_X86_TBOOT_DYING = 146,
	CPUHP_AP_ARM_CACHE_B15_RAC_DYING = 147,
	CPUHP_AP_ONLINE = 148,
	CPUHP_TEARDOWN_CPU = 149,
	CPUHP_AP_ONLINE_IDLE = 150,
	CPUHP_AP_SCHED_WAIT_EMPTY = 151,
	CPUHP_AP_SMPBOOT_THREADS = 152,
	CPUHP_AP_X86_VDSO_VMA_ONLINE = 153,
	CPUHP_AP_IRQ_AFFINITY_ONLINE = 154,
	CPUHP_AP_BLK_MQ_ONLINE = 155,
	CPUHP_AP_ARM_MVEBU_SYNC_CLOCKS = 156,
	CPUHP_AP_X86_INTEL_EPB_ONLINE = 157,
	CPUHP_AP_PERF_ONLINE = 158,
	CPUHP_AP_PERF_X86_ONLINE = 159,
	CPUHP_AP_PERF_X86_UNCORE_ONLINE = 160,
	CPUHP_AP_PERF_X86_AMD_UNCORE_ONLINE = 161,
	CPUHP_AP_PERF_X86_AMD_POWER_ONLINE = 162,
	CPUHP_AP_PERF_X86_RAPL_ONLINE = 163,
	CPUHP_AP_PERF_X86_CQM_ONLINE = 164,
	CPUHP_AP_PERF_X86_CSTATE_ONLINE = 165,
	CPUHP_AP_PERF_X86_IDXD_ONLINE = 166,
	CPUHP_AP_PERF_S390_CF_ONLINE = 167,
	CPUHP_AP_PERF_S390_SF_ONLINE = 168,
	CPUHP_AP_PERF_ARM_CCI_ONLINE = 169,
	CPUHP_AP_PERF_ARM_CCN_ONLINE = 170,
	CPUHP_AP_PERF_ARM_HISI_DDRC_ONLINE = 171,
	CPUHP_AP_PERF_ARM_HISI_HHA_ONLINE = 172,
	CPUHP_AP_PERF_ARM_HISI_L3_ONLINE = 173,
	CPUHP_AP_PERF_ARM_HISI_PA_ONLINE = 174,
	CPUHP_AP_PERF_ARM_HISI_SLLC_ONLINE = 175,
	CPUHP_AP_PERF_ARM_L2X0_ONLINE = 176,
	CPUHP_AP_PERF_ARM_QCOM_L2_ONLINE = 177,
	CPUHP_AP_PERF_ARM_QCOM_L3_ONLINE = 178,
	CPUHP_AP_PERF_ARM_APM_XGENE_ONLINE = 179,
	CPUHP_AP_PERF_ARM_CAVIUM_TX2_UNCORE_ONLINE = 180,
	CPUHP_AP_PERF_POWERPC_NEST_IMC_ONLINE = 181,
	CPUHP_AP_PERF_POWERPC_CORE_IMC_ONLINE = 182,
	CPUHP_AP_PERF_POWERPC_THREAD_IMC_ONLINE = 183,
	CPUHP_AP_PERF_POWERPC_TRACE_IMC_ONLINE = 184,
	CPUHP_AP_PERF_POWERPC_HV_24x7_ONLINE = 185,
	CPUHP_AP_PERF_POWERPC_HV_GPCI_ONLINE = 186,
	CPUHP_AP_PERF_CSKY_ONLINE = 187,
	CPUHP_AP_WATCHDOG_ONLINE = 188,
	CPUHP_AP_WORKQUEUE_ONLINE = 189,
	CPUHP_AP_RCUTREE_ONLINE = 190,
	CPUHP_AP_BASE_CACHEINFO_ONLINE = 191,
	CPUHP_AP_ONLINE_DYN = 192,
	CPUHP_AP_ONLINE_DYN_END = 222,
	CPUHP_AP_MM_DEMOTION_ONLINE = 223,
	CPUHP_AP_X86_HPET_ONLINE = 224,
	CPUHP_AP_X86_KVM_CLK_ONLINE = 225,
	CPUHP_AP_DTPM_CPU_ONLINE = 226,
	CPUHP_AP_ACTIVE = 227,
	CPUHP_ONLINE = 228,
};

typedef void percpu_ref_func_t(struct percpu_ref *);

struct percpu_ref_data {
	atomic_long_t count;
	percpu_ref_func_t *release;
	percpu_ref_func_t *confirm_switch;
	bool force_atomic: 1;
	bool allow_reinit: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct percpu_ref *ref;
};

struct dev_pagemap_ops {
	void (*page_free)(struct page *);
	void (*kill)(struct dev_pagemap *);
	void (*cleanup)(struct dev_pagemap *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault *);
};

enum vm_event_item {
	PGPGIN = 0,
	PGPGOUT = 1,
	PSWPIN = 2,
	PSWPOUT = 3,
	PGALLOC_DMA = 4,
	PGALLOC_DMA32 = 5,
	PGALLOC_NORMAL = 6,
	PGALLOC_MOVABLE = 7,
	ALLOCSTALL_DMA = 8,
	ALLOCSTALL_DMA32 = 9,
	ALLOCSTALL_NORMAL = 10,
	ALLOCSTALL_MOVABLE = 11,
	PGSCAN_SKIP_DMA = 12,
	PGSCAN_SKIP_DMA32 = 13,
	PGSCAN_SKIP_NORMAL = 14,
	PGSCAN_SKIP_MOVABLE = 15,
	PGFREE = 16,
	PGACTIVATE = 17,
	PGDEACTIVATE = 18,
	PGLAZYFREE = 19,
	PGFAULT = 20,
	PGMAJFAULT = 21,
	PGLAZYFREED = 22,
	PGREFILL = 23,
	PGREUSE = 24,
	PGSTEAL_KSWAPD = 25,
	PGSTEAL_DIRECT = 26,
	PGDEMOTE_KSWAPD = 27,
	PGDEMOTE_DIRECT = 28,
	PGSCAN_KSWAPD = 29,
	PGSCAN_DIRECT = 30,
	PGSCAN_DIRECT_THROTTLE = 31,
	PGSCAN_ANON = 32,
	PGSCAN_FILE = 33,
	PGSTEAL_ANON = 34,
	PGSTEAL_FILE = 35,
	PGSCAN_ZONE_RECLAIM_FAILED = 36,
	PGINODESTEAL = 37,
	SLABS_SCANNED = 38,
	KSWAPD_INODESTEAL = 39,
	KSWAPD_LOW_WMARK_HIT_QUICKLY = 40,
	KSWAPD_HIGH_WMARK_HIT_QUICKLY = 41,
	PAGEOUTRUN = 42,
	PGROTATED = 43,
	DROP_PAGECACHE = 44,
	DROP_SLAB = 45,
	OOM_KILL = 46,
	NUMA_PTE_UPDATES = 47,
	NUMA_HUGE_PTE_UPDATES = 48,
	NUMA_HINT_FAULTS = 49,
	NUMA_HINT_FAULTS_LOCAL = 50,
	NUMA_PAGE_MIGRATE = 51,
	PGMIGRATE_SUCCESS = 52,
	PGMIGRATE_FAIL = 53,
	THP_MIGRATION_SUCCESS = 54,
	THP_MIGRATION_FAIL = 55,
	THP_MIGRATION_SPLIT = 56,
	COMPACTMIGRATE_SCANNED = 57,
	COMPACTFREE_SCANNED = 58,
	COMPACTISOLATED = 59,
	COMPACTSTALL = 60,
	COMPACTFAIL = 61,
	COMPACTSUCCESS = 62,
	KCOMPACTD_WAKE = 63,
	KCOMPACTD_MIGRATE_SCANNED = 64,
	KCOMPACTD_FREE_SCANNED = 65,
	HTLB_BUDDY_PGALLOC = 66,
	HTLB_BUDDY_PGALLOC_FAIL = 67,
	CMA_ALLOC_SUCCESS = 68,
	CMA_ALLOC_FAIL = 69,
	UNEVICTABLE_PGCULLED = 70,
	UNEVICTABLE_PGSCANNED = 71,
	UNEVICTABLE_PGRESCUED = 72,
	UNEVICTABLE_PGMLOCKED = 73,
	UNEVICTABLE_PGMUNLOCKED = 74,
	UNEVICTABLE_PGCLEARED = 75,
	UNEVICTABLE_PGSTRANDED = 76,
	THP_FAULT_ALLOC = 77,
	THP_FAULT_FALLBACK = 78,
	THP_FAULT_FALLBACK_CHARGE = 79,
	THP_COLLAPSE_ALLOC = 80,
	THP_COLLAPSE_ALLOC_FAILED = 81,
	THP_FILE_ALLOC = 82,
	THP_FILE_FALLBACK = 83,
	THP_FILE_FALLBACK_CHARGE = 84,
	THP_FILE_MAPPED = 85,
	THP_SPLIT_PAGE = 86,
	THP_SPLIT_PAGE_FAILED = 87,
	THP_DEFERRED_SPLIT_PAGE = 88,
	THP_SPLIT_PMD = 89,
	THP_ZERO_PAGE_ALLOC = 90,
	THP_ZERO_PAGE_ALLOC_FAILED = 91,
	THP_SWPOUT = 92,
	THP_SWPOUT_FALLBACK = 93,
	BALLOON_INFLATE = 94,
	BALLOON_DEFLATE = 95,
	BALLOON_MIGRATE = 96,
	SWAP_RA = 97,
	SWAP_RA_HIT = 98,
	NR_VM_EVENT_ITEMS = 99,
};

struct seq_operations {
	void * (*start)(struct seq_file *, loff_t *);
	void (*stop)(struct seq_file *, void *);
	void * (*next)(struct seq_file *, void *, loff_t *);
	int (*show)(struct seq_file *, void *);
};

struct ring_buffer_event {
	u32 type_len: 5;
	u32 time_delta: 27;
	u32 array[0];
};

struct seq_buf {
	char *buffer;
	size_t size;
	size_t len;
	loff_t readpos;
};

struct trace_seq {
	char buffer[4096];
	struct seq_buf seq;
	int full;
};

struct irq_desc;

typedef void (*irq_flow_handler_t)(struct irq_desc *);

struct msi_desc;

struct irq_common_data {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip;

struct irq_data {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip *chip;
	struct irq_domain *domain;
	struct irq_data *parent_data;
	void *chip_data;
};

struct irqaction;

struct irq_affinity_notify;

struct proc_dir_entry;

struct irq_desc {
	struct irq_common_data irq_common_data;
	struct irq_data irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t handle_irq;
	struct irqaction *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum irqreturn {
	IRQ_NONE = 0,
	IRQ_HANDLED = 1,
	IRQ_WAKE_THREAD = 2,
};

typedef enum irqreturn irqreturn_t;

struct fwnode_reference_args;

struct fwnode_endpoint;

struct fwnode_operations {
	struct fwnode_handle * (*get)(struct fwnode_handle *);
	void (*put)(struct fwnode_handle *);
	bool (*device_is_available)(const struct fwnode_handle *);
	const void * (*device_get_match_data)(const struct fwnode_handle *, const struct device *);
	bool (*property_present)(const struct fwnode_handle *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle *);
	const char * (*get_name_prefix)(const struct fwnode_handle *);
	struct fwnode_handle * (*get_parent)(const struct fwnode_handle *);
	struct fwnode_handle * (*get_next_child_node)(const struct fwnode_handle *, struct fwnode_handle *);
	struct fwnode_handle * (*get_named_child_node)(const struct fwnode_handle *, const char *);
	int (*get_reference_args)(const struct fwnode_handle *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args *);
	struct fwnode_handle * (*graph_get_next_endpoint)(const struct fwnode_handle *, struct fwnode_handle *);
	struct fwnode_handle * (*graph_get_remote_endpoint)(const struct fwnode_handle *);
	struct fwnode_handle * (*graph_get_port_parent)(struct fwnode_handle *);
	int (*graph_parse_endpoint)(const struct fwnode_handle *, struct fwnode_endpoint *);
	int (*add_links)(struct fwnode_handle *);
};

struct fwnode_endpoint {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle *local_fwnode;
};

struct fwnode_reference_args {
	struct fwnode_handle *fwnode;
	unsigned int nargs;
	u64 args[8];
};

enum kmalloc_cache_type {
	KMALLOC_NORMAL = 0,
	KMALLOC_CGROUP = 1,
	KMALLOC_RECLAIM = 2,
	KMALLOC_DMA = 3,
	NR_KMALLOC_TYPES = 4,
};

enum irqchip_irq_state {
	IRQCHIP_STATE_PENDING = 0,
	IRQCHIP_STATE_ACTIVE = 1,
	IRQCHIP_STATE_MASKED = 2,
	IRQCHIP_STATE_LINE_LEVEL = 3,
};

struct msi_msg;

struct irq_chip {
	struct device *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data *);
	void (*irq_shutdown)(struct irq_data *);
	void (*irq_enable)(struct irq_data *);
	void (*irq_disable)(struct irq_data *);
	void (*irq_ack)(struct irq_data *);
	void (*irq_mask)(struct irq_data *);
	void (*irq_mask_ack)(struct irq_data *);
	void (*irq_unmask)(struct irq_data *);
	void (*irq_eoi)(struct irq_data *);
	int (*irq_set_affinity)(struct irq_data *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data *);
	int (*irq_set_type)(struct irq_data *, unsigned int);
	int (*irq_set_wake)(struct irq_data *, unsigned int);
	void (*irq_bus_lock)(struct irq_data *);
	void (*irq_bus_sync_unlock)(struct irq_data *);
	void (*irq_cpu_online)(struct irq_data *);
	void (*irq_cpu_offline)(struct irq_data *);
	void (*irq_suspend)(struct irq_data *);
	void (*irq_resume)(struct irq_data *);
	void (*irq_pm_shutdown)(struct irq_data *);
	void (*irq_calc_mask)(struct irq_data *);
	void (*irq_print_chip)(struct irq_data *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data *);
	void (*irq_release_resources)(struct irq_data *);
	void (*irq_compose_msi_msg)(struct irq_data *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data *, void *);
	void (*ipi_send_single)(struct irq_data *, unsigned int);
	void (*ipi_send_mask)(struct irq_data *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data *);
	void (*irq_nmi_teardown)(struct irq_data *);
	long unsigned int flags;
};

typedef irqreturn_t (*irq_handler_t)(int, void *);

struct irqaction {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction *next;
	irq_handler_t thread_fn;
	struct task_struct *thread;
	struct irqaction *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_affinity_notify {
	unsigned int irq;
	struct kref kref;
	struct work_struct work;
	void (*notify)(struct irq_affinity_notify *, const cpumask_t *);
	void (*release)(struct kref *);
};

struct irq_chip_regs {
	long unsigned int enable;
	long unsigned int disable;
	long unsigned int mask;
	long unsigned int ack;
	long unsigned int eoi;
	long unsigned int type;
	long unsigned int polarity;
};

struct irq_chip_type {
	struct irq_chip chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic *);
	void (*resume)(struct irq_chip_generic *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain *domain;
	struct list_head list;
	struct irq_chip_type chip_types[0];
};

enum irq_gc_flags {
	IRQ_GC_INIT_MASK_CACHE = 1,
	IRQ_GC_INIT_NESTED_LOCK = 2,
	IRQ_GC_MASK_CACHE_PER_TYPE = 4,
	IRQ_GC_NO_MASK = 8,
	IRQ_GC_BE_IO = 16,
};

struct irq_domain_chip_generic {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic *gc[0];
};

enum perf_sw_ids {
	PERF_COUNT_SW_CPU_CLOCK = 0,
	PERF_COUNT_SW_TASK_CLOCK = 1,
	PERF_COUNT_SW_PAGE_FAULTS = 2,
	PERF_COUNT_SW_CONTEXT_SWITCHES = 3,
	PERF_COUNT_SW_CPU_MIGRATIONS = 4,
	PERF_COUNT_SW_PAGE_FAULTS_MIN = 5,
	PERF_COUNT_SW_PAGE_FAULTS_MAJ = 6,
	PERF_COUNT_SW_ALIGNMENT_FAULTS = 7,
	PERF_COUNT_SW_EMULATION_FAULTS = 8,
	PERF_COUNT_SW_DUMMY = 9,
	PERF_COUNT_SW_BPF_OUTPUT = 10,
	PERF_COUNT_SW_CGROUP_SWITCHES = 11,
	PERF_COUNT_SW_MAX = 12,
};

union perf_mem_data_src {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_blk: 3;
		__u64 mem_rsvd: 21;
	};
};

struct perf_branch_entry {
	__u64 from;
	__u64 to;
	__u64 mispred: 1;
	__u64 predicted: 1;
	__u64 in_tx: 1;
	__u64 abort: 1;
	__u64 cycles: 16;
	__u64 type: 4;
	__u64 reserved: 40;
	long: 24;
	long: 64;
	long: 64;
};

union perf_sample_weight {
	__u64 full;
	struct {
		__u32 var1_dw;
		__u16 var2_w;
		__u16 var3_w;
	};
};

struct new_utsname {
	char sysname[65];
	char nodename[65];
	char release[65];
	char version[65];
	char machine[65];
	char domainname[65];
};

struct uts_namespace {
	struct new_utsname name;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common ns;
};

struct prot_inuse;

struct netns_core {
	struct ctl_table_header *sysctl_hdr;
	int sysctl_somaxconn;
	int *sock_inuse;
	struct prot_inuse *prot_inuse;
};

struct ipstats_mib;

struct tcp_mib;

struct linux_mib;

struct udp_mib;

struct linux_xfrm_mib;

struct linux_tls_mib;

struct mptcp_mib;

struct icmp_mib;

struct icmpmsg_mib;

struct icmpv6_mib;

struct icmpv6msg_mib;

struct netns_mib {
	struct ipstats_mib *ip_statistics;
	struct ipstats_mib *ipv6_statistics;
	struct tcp_mib *tcp_statistics;
	struct linux_mib *net_statistics;
	struct udp_mib *udp_statistics;
	struct udp_mib *udp_stats_in6;
	struct linux_xfrm_mib *xfrm_statistics;
	struct linux_tls_mib *tls_statistics;
	struct mptcp_mib *mptcp_statistics;
	struct udp_mib *udplite_statistics;
	struct udp_mib *udplite_stats_in6;
	struct icmp_mib *icmp_statistics;
	struct icmpmsg_mib *icmpmsg_statistics;
	struct icmpv6_mib *icmpv6_statistics;
	struct icmpv6msg_mib *icmpv6msg_statistics;
	struct proc_dir_entry *proc_net_devsnmp6;
};

struct netns_packet {
	struct mutex sklist_lock;
	struct hlist_head sklist;
};

struct netns_unix {
	int sysctl_max_dgram_qlen;
	struct ctl_table_header *ctl;
};

struct netns_nexthop {
	struct rb_root rb_root;
	struct hlist_head *devhash;
	unsigned int seq;
	u32 last_id_allocated;
	struct blocking_notifier_head notifier_chain;
};

struct inet_hashinfo;

struct inet_timewait_death_row {
	atomic_t tw_count;
	char tw_pad[60];
	struct inet_hashinfo *hashinfo;
	int sysctl_max_tw_buckets;
};

struct local_ports {
	seqlock_t lock;
	int range[2];
	bool warned;
};

struct ping_group_range {
	seqlock_t lock;
	kgid_t range[2];
};

typedef struct {
	u64 key[2];
} siphash_key_t;

struct ipv4_devconf;

struct ip_ra_chain;

struct fib_rules_ops;

struct fib_table;

struct inet_peer_base;

struct fqdir;

struct tcp_congestion_ops;

struct tcp_fastopen_context;

struct fib_notifier_ops;

struct netns_ipv4 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry;

struct net_device;

struct sk_buff;

struct neighbour;

struct dst_ops {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff *);
	int (*local_out)(struct net *, struct sock *, struct sk_buff *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_sysctl_ipv6 {
	struct ctl_table_header *hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *icmp_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *xfrm6_hdr;
	int flush_delay;
	int ip6_rt_max_size;
	int ip6_rt_gc_min_interval;
	int ip6_rt_gc_timeout;
	int ip6_rt_gc_interval;
	int ip6_rt_gc_elasticity;
	int ip6_rt_mtu_expires;
	int ip6_rt_min_advmss;
	u32 multipath_hash_fields;
	u8 multipath_hash_policy;
	u8 bindv6only;
	u8 flowlabel_consistency;
	u8 auto_flowlabels;
	int icmpv6_time;
	u8 icmpv6_echo_ignore_all;
	u8 icmpv6_echo_ignore_multicast;
	u8 icmpv6_echo_ignore_anycast;
	long unsigned int icmpv6_ratemask[4];
	long unsigned int *icmpv6_ratemask_ptr;
	u8 anycast_src_echo_reply;
	u8 ip_nonlocal_bind;
	u8 fwmark_reflect;
	u8 flowlabel_state_ranges;
	int idgen_retries;
	int idgen_delay;
	int flowlabel_reflect;
	int max_dst_opts_cnt;
	int max_hbh_opts_cnt;
	int max_dst_opts_len;
	int max_hbh_opts_len;
	int seg6_flowlabel;
	u32 ioam6_id;
	u64 ioam6_id_wide;
	bool skip_notify_on_dev_down;
	u8 fib_notify_on_flag_change;
};

struct ipv6_devconf;

struct fib6_info;

struct rt6_info;

struct rt6_statistics;

struct fib6_table;

struct seg6_pernet_data;

struct ioam6_pernet_data;

struct netns_ipv6 {
	struct dst_ops ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
	long: 64;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_sysctl_lowpan {
	struct ctl_table_header *frags_hdr;
};

struct netns_ieee802154_lowpan {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir *fqdir;
};

struct sctp_mib;

struct netns_sctp {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock *ctl_sock;
	struct sock *udp4_sock;
	struct sock *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_logger;

struct nf_hook_entries;

struct netns_nf {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries *hooks_ipv4[5];
	struct nf_hook_entries *hooks_ipv6[5];
	struct nf_hook_entries *hooks_arp[3];
	struct nf_hook_entries *hooks_bridge[5];
	struct nf_hook_entries *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct nf_generic_net {
	unsigned int timeout;
};

struct nf_tcp_net {
	unsigned int timeouts[14];
	u8 tcp_loose;
	u8 tcp_be_liberal;
	u8 tcp_max_retrans;
	u8 tcp_ignore_invalid_rst;
	unsigned int offload_timeout;
};

struct nf_udp_net {
	unsigned int timeouts[2];
	unsigned int offload_timeout;
};

struct nf_icmp_net {
	unsigned int timeout;
};

struct nf_dccp_net {
	u8 dccp_loose;
	unsigned int dccp_timeout[10];
};

struct nf_sctp_net {
	unsigned int timeouts[10];
};

struct nf_gre_net {
	struct list_head keymap_list;
	unsigned int timeouts[2];
};

struct nf_ip_net {
	struct nf_generic_net generic;
	struct nf_tcp_net tcp;
	struct nf_udp_net udp;
	struct nf_icmp_net icmp;
	struct nf_icmp_net icmpv6;
	struct nf_dccp_net dccp;
	struct nf_sctp_net sctp;
	struct nf_gre_net gre;
};

struct ct_pcpu;

struct ip_conntrack_stat;

struct nf_ct_event_notifier;

struct netns_ct {
	bool ecache_dwork_pending;
	u8 sysctl_log_invalid;
	u8 sysctl_events;
	u8 sysctl_acct;
	u8 sysctl_auto_assign_helper;
	u8 sysctl_tstamp;
	u8 sysctl_checksum;
	struct ct_pcpu *pcpu_lists;
	struct ip_conntrack_stat *stat;
	struct nf_ct_event_notifier *nf_conntrack_event_cb;
	struct nf_ip_net nf_ct_proto;
	unsigned int labels_used;
};

struct netns_nftables {
	u8 gencursor;
};

struct sk_buff_head {
	struct sk_buff *next;
	struct sk_buff *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf {
	struct bpf_prog_array *run_array[2];
	struct bpf_prog *progs[2];
	struct list_head links[2];
};

struct xfrm_policy_hash {
	struct hlist_head *table;
	unsigned int hmask;
	u8 dbits4;
	u8 sbits4;
	u8 dbits6;
	u8 sbits6;
};

struct xfrm_policy_hthresh {
	struct work_struct work;
	seqlock_t lock;
	u8 lbits4;
	u8 rbits4;
	u8 lbits6;
	u8 rbits6;
};

struct netns_xfrm {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops xfrm4_dst_ops;
	struct dst_ops xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct netns_ipvs;

struct mpls_route;

struct netns_mpls {
	int ip_ttl_propagate;
	int default_ttl;
	size_t platform_labels;
	struct mpls_route **platform_label;
	struct ctl_table_header *ctl;
};

struct can_dev_rcv_lists;

struct can_pkg_stats;

struct can_rcv_lists_stats;

struct netns_can {
	struct proc_dir_entry *proc_dir;
	struct proc_dir_entry *pde_stats;
	struct proc_dir_entry *pde_reset_stats;
	struct proc_dir_entry *pde_rcvlist_all;
	struct proc_dir_entry *pde_rcvlist_fil;
	struct proc_dir_entry *pde_rcvlist_inv;
	struct proc_dir_entry *pde_rcvlist_sff;
	struct proc_dir_entry *pde_rcvlist_eff;
	struct proc_dir_entry *pde_rcvlist_err;
	struct proc_dir_entry *bcmproc_dir;
	struct can_dev_rcv_lists *rx_alldev_list;
	spinlock_t rcvlists_lock;
	struct timer_list stattimer;
	struct can_pkg_stats *pkg_stats;
	struct can_rcv_lists_stats *rcv_lists_stats;
	struct hlist_head cgw_list;
};

struct netns_xdp {
	struct mutex lock;
	struct hlist_head list;
};

struct netns_mctp {
	struct list_head routes;
	struct mutex bind_lock;
	struct hlist_head binds;
	spinlock_t keys_lock;
	struct hlist_head keys;
	unsigned int default_net;
	struct mutex neigh_lock;
	struct list_head neighbours;
};

struct smc_stats;

struct smc_stats_rsn;

struct netns_smc {
	struct smc_stats *smc_stats;
	struct mutex mutex_fback_rsn;
	struct smc_stats_rsn *fback_rsn;
};

struct uevent_sock;

struct net_generic;

struct net {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4 ipv4;
	struct netns_ipv6 ipv6;
	struct netns_ieee802154_lowpan ieee802154_lowpan;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set *root_cset;
};

struct nsset {
	unsigned int flags;
	struct nsproxy *nsproxy;
	struct fs_struct *fs;
	const struct cred *cred;
};

struct proc_ns_operations {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common * (*get)(struct task_struct *);
	void (*put)(struct ns_common *);
	int (*install)(struct nsset *, struct ns_common *);
	struct user_namespace * (*owner)(struct ns_common *);
	struct ns_common * (*get_parent)(struct ns_common *);
};

struct iovec {
	void *iov_base;
	__kernel_size_t iov_len;
};

struct kvec {
	void *iov_base;
	size_t iov_len;
};

struct ftrace_regs {
	struct pt_regs regs;
};

struct perf_regs {
	__u64 abi;
	struct pt_regs *regs;
};

struct u64_stats_sync {};

struct bpf_cgroup_storage_key {
	__u64 cgroup_inode_id;
	__u32 attach_type;
};

struct bpf_storage_buffer;

struct bpf_cgroup_storage_map;

struct bpf_cgroup_storage {
	union {
		struct bpf_storage_buffer *buf;
		void *percpu_buf;
	};
	struct bpf_cgroup_storage_map *map;
	struct bpf_cgroup_storage_key key;
	struct list_head list_map;
	struct list_head list_cg;
	struct rb_node node;
	struct callback_head rcu;
};

struct bpf_prog_array_item {
	struct bpf_prog *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array {
	struct callback_head rcu;
	struct bpf_prog_array_item items[0];
};

typedef unsigned int sk_buff_data_t;

struct skb_ext;

struct sk_buff {
	union {
		struct {
			struct sk_buff *next;
			struct sk_buff *prev;
			union {
				struct net_device *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bpf_storage_buffer {
	struct callback_head rcu;
	char data[0];
};

struct psi_group_cpu {
	seqcount_t seq;
	unsigned int tasks[5];
	u32 state_mask;
	u32 times[7];
	u64 state_start;
	u32 times_prev[14];
	long: 64;
};

struct cgroup_taskset;

struct cftype;

struct cgroup_subsys {
	struct cgroup_subsys_state * (*css_alloc)(struct cgroup_subsys_state *);
	int (*css_online)(struct cgroup_subsys_state *);
	void (*css_offline)(struct cgroup_subsys_state *);
	void (*css_released)(struct cgroup_subsys_state *);
	void (*css_free)(struct cgroup_subsys_state *);
	void (*css_reset)(struct cgroup_subsys_state *);
	void (*css_rstat_flush)(struct cgroup_subsys_state *, int);
	int (*css_extra_stat_show)(struct seq_file *, struct cgroup_subsys_state *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct *, struct css_set *);
	void (*cancel_fork)(struct task_struct *, struct css_set *);
	void (*fork)(struct task_struct *);
	void (*exit)(struct task_struct *);
	void (*release)(struct task_struct *);
	void (*bind)(struct cgroup_subsys_state *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype *dfl_cftypes;
	struct cftype *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup *updated_children;
	struct cgroup *updated_next;
};

struct cgroup_root {
	struct kernfs_root *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys *ss;
	struct list_head node;
	struct kernfs_ops *kf_ops;
	int (*open)(struct kernfs_open_file *);
	void (*release)(struct kernfs_open_file *);
	u64 (*read_u64)(struct cgroup_subsys_state *, struct cftype *);
	s64 (*read_s64)(struct cgroup_subsys_state *, struct cftype *);
	int (*seq_show)(struct seq_file *, void *);
	void * (*seq_start)(struct seq_file *, loff_t *);
	void * (*seq_next)(struct seq_file *, void *, loff_t *);
	void (*seq_stop)(struct seq_file *, void *);
	int (*write_u64)(struct cgroup_subsys_state *, struct cftype *, u64);
	int (*write_s64)(struct cgroup_subsys_state *, struct cftype *, s64);
	ssize_t (*write)(struct kernfs_open_file *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file *, struct poll_table_struct *);
};

struct perf_callchain_entry {
	__u64 nr;
	__u64 ip[0];
};

typedef long unsigned int (*perf_copy_f)(void *, const void *, long unsigned int, long unsigned int);

struct perf_raw_frag {
	union {
		struct perf_raw_frag *next;
		long unsigned int pad;
	};
	perf_copy_f copy;
	void *data;
	u32 size;
} __attribute__((packed));

struct perf_raw_record {
	struct perf_raw_frag frag;
	u32 size;
};

struct perf_branch_stack {
	__u64 nr;
	__u64 hw_idx;
	struct perf_branch_entry entries[0];
};

struct perf_cpu_context;

struct perf_output_handle;

struct pmu {
	struct list_head entry;
	struct module *module;
	struct device *dev;
	const struct attribute_group **attr_groups;
	const struct attribute_group **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu *);
	void (*pmu_disable)(struct pmu *);
	int (*event_init)(struct perf_event *);
	void (*event_mapped)(struct perf_event *, struct mm_struct *);
	void (*event_unmapped)(struct perf_event *, struct mm_struct *);
	int (*add)(struct perf_event *, int);
	void (*del)(struct perf_event *, int);
	void (*start)(struct perf_event *, int);
	void (*stop)(struct perf_event *, int);
	void (*read)(struct perf_event *);
	void (*start_txn)(struct pmu *, unsigned int);
	int (*commit_txn)(struct pmu *);
	void (*cancel_txn)(struct pmu *);
	int (*event_idx)(struct perf_event *);
	void (*sched_task)(struct perf_event_context *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context *, struct perf_event_context *);
	void * (*setup_aux)(struct perf_event *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event *, struct perf_output_handle *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event *);
	int (*aux_output_match)(struct perf_event *);
	int (*filter_match)(struct perf_event *);
	int (*check_period)(struct perf_event *, u64);
};

struct perf_cpu_context {
	struct perf_event_context ctx;
	struct perf_event_context *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event **heap;
	struct perf_event *heap_default[2];
};

struct perf_output_handle {
	struct perf_event *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_addr_filter_range {
	long unsigned int start;
	long unsigned int size;
};

struct perf_sample_data {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	union perf_sample_weight weight;
	u64 txn;
	union perf_mem_data_src data_src;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	u64 aux_size;
	struct perf_regs regs_user;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	u64 cgroup;
	u64 data_page_size;
	u64 code_page_size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup_info;

struct perf_cgroup {
	struct cgroup_subsys_state css;
	struct perf_cgroup_info *info;
};

struct perf_cgroup_info {
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	int active;
};

struct trace_entry {
	short unsigned int type;
	unsigned char flags;
	unsigned char preempt_count;
	int pid;
};

struct trace_array;

struct tracer;

struct array_buffer;

struct ring_buffer_iter;

struct trace_iterator {
	struct trace_array *tr;
	struct tracer *trace;
	struct array_buffer *array_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	void *temp;
	unsigned int temp_size;
	char *fmt;
	unsigned int fmt_size;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

enum print_line_t {
	TRACE_TYPE_PARTIAL_LINE = 0,
	TRACE_TYPE_HANDLED = 1,
	TRACE_TYPE_UNHANDLED = 2,
	TRACE_TYPE_NO_CONSUME = 3,
};

typedef enum print_line_t (*trace_print_func)(struct trace_iterator *, int, struct trace_event *);

struct trace_event_functions {
	trace_print_func trace;
	trace_print_func raw;
	trace_print_func hex;
	trace_print_func binary;
};

enum trace_reg {
	TRACE_REG_REGISTER = 0,
	TRACE_REG_UNREGISTER = 1,
	TRACE_REG_PERF_REGISTER = 2,
	TRACE_REG_PERF_UNREGISTER = 3,
	TRACE_REG_PERF_OPEN = 4,
	TRACE_REG_PERF_CLOSE = 5,
	TRACE_REG_PERF_ADD = 6,
	TRACE_REG_PERF_DEL = 7,
};

struct trace_event_fields {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call *);
	};
};

struct trace_event_class {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call *, enum trace_reg, void *);
	struct trace_event_fields *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call *);
};

struct trace_buffer;

struct trace_event_file;

struct trace_event_buffer {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_subsystem_dir;

struct trace_event_file {
	struct list_head list;
	struct trace_event_call *event_call;
	struct event_filter *filter;
	struct dentry *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

enum {
	TRACE_EVENT_FL_FILTERED_BIT = 0,
	TRACE_EVENT_FL_CAP_ANY_BIT = 1,
	TRACE_EVENT_FL_NO_SET_FILTER_BIT = 2,
	TRACE_EVENT_FL_IGNORE_ENABLE_BIT = 3,
	TRACE_EVENT_FL_TRACEPOINT_BIT = 4,
	TRACE_EVENT_FL_DYNAMIC_BIT = 5,
	TRACE_EVENT_FL_KPROBE_BIT = 6,
	TRACE_EVENT_FL_UPROBE_BIT = 7,
	TRACE_EVENT_FL_EPROBE_BIT = 8,
};

enum {
	TRACE_EVENT_FL_FILTERED = 1,
	TRACE_EVENT_FL_CAP_ANY = 2,
	TRACE_EVENT_FL_NO_SET_FILTER = 4,
	TRACE_EVENT_FL_IGNORE_ENABLE = 8,
	TRACE_EVENT_FL_TRACEPOINT = 16,
	TRACE_EVENT_FL_DYNAMIC = 32,
	TRACE_EVENT_FL_KPROBE = 64,
	TRACE_EVENT_FL_UPROBE = 128,
	TRACE_EVENT_FL_EPROBE = 256,
};

enum {
	EVENT_FILE_FL_ENABLED_BIT = 0,
	EVENT_FILE_FL_RECORDED_CMD_BIT = 1,
	EVENT_FILE_FL_RECORDED_TGID_BIT = 2,
	EVENT_FILE_FL_FILTERED_BIT = 3,
	EVENT_FILE_FL_NO_SET_FILTER_BIT = 4,
	EVENT_FILE_FL_SOFT_MODE_BIT = 5,
	EVENT_FILE_FL_SOFT_DISABLED_BIT = 6,
	EVENT_FILE_FL_TRIGGER_MODE_BIT = 7,
	EVENT_FILE_FL_TRIGGER_COND_BIT = 8,
	EVENT_FILE_FL_PID_FILTER_BIT = 9,
	EVENT_FILE_FL_WAS_ENABLED_BIT = 10,
};

enum {
	EVENT_FILE_FL_ENABLED = 1,
	EVENT_FILE_FL_RECORDED_CMD = 2,
	EVENT_FILE_FL_RECORDED_TGID = 4,
	EVENT_FILE_FL_FILTERED = 8,
	EVENT_FILE_FL_NO_SET_FILTER = 16,
	EVENT_FILE_FL_SOFT_MODE = 32,
	EVENT_FILE_FL_SOFT_DISABLED = 64,
	EVENT_FILE_FL_TRIGGER_MODE = 128,
	EVENT_FILE_FL_TRIGGER_COND = 256,
	EVENT_FILE_FL_PID_FILTER = 512,
	EVENT_FILE_FL_WAS_ENABLED = 1024,
};

enum event_trigger_type {
	ETT_NONE = 0,
	ETT_TRACE_ONOFF = 1,
	ETT_SNAPSHOT = 2,
	ETT_STACKTRACE = 4,
	ETT_EVENT_ENABLE = 8,
	ETT_EVENT_HIST = 16,
	ETT_HIST_ENABLE = 32,
	ETT_EVENT_EPROBE = 64,
};

enum {
	FILTER_OTHER = 0,
	FILTER_STATIC_STRING = 1,
	FILTER_DYN_STRING = 2,
	FILTER_PTR_STRING = 3,
	FILTER_TRACE_FN = 4,
	FILTER_COMM = 5,
	FILTER_CPU = 6,
};

struct property {
	char *name;
	int length;
	void *value;
	struct property *next;
	long unsigned int _flags;
	struct bin_attribute attr;
};

struct irq_fwspec {
	struct fwnode_handle *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops {
	int (*match)(struct irq_domain *, struct device_node *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain *, struct irq_fwspec *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain *, unsigned int);
	int (*xlate)(struct irq_domain *, struct device_node *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain *, struct irq_data *, bool);
	void (*deactivate)(struct irq_domain *, struct irq_data *);
	int (*translate)(struct irq_domain *, struct irq_fwspec *, long unsigned int *, unsigned int *);
};

struct xbc_node {
	u16 next;
	u16 child;
	u16 parent;
	u16 data;
};

enum wb_stat_item {
	WB_RECLAIMABLE = 0,
	WB_WRITEBACK = 1,
	WB_DIRTIED = 2,
	WB_WRITTEN = 3,
	NR_WB_STAT_ITEMS = 4,
};

struct block_device_operations;

struct timer_rand_state;

struct disk_events;

struct cdrom_device_info;

struct badblocks;

struct gendisk {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device *part0;
	const struct block_device_operations *fops;
	struct request_queue *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info *bdi;
	struct kobject *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct partition_meta_info {
	char uuid[37];
	u8 volname[64];
};

struct bio_integrity_payload {
	struct bio *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec *bip_vec;
	struct bio_vec bip_inline_vecs[0];
};

struct blkg_iostat {
	u64 bytes[3];
	u64 ios[3];
};

struct blkg_iostat_set {
	struct u64_stats_sync sync;
	struct blkg_iostat cur;
	struct blkg_iostat last;
};

struct blkcg;

struct blkg_policy_data;

struct blkcg_gq {
	struct request_queue *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg *blkcg;
	struct blkcg_gq *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef __u32 blk_mq_req_flags_t;

typedef unsigned int blk_qc_t;

struct blk_integrity_iter;

typedef blk_status_t integrity_processing_fn(struct blk_integrity_iter *);

typedef void integrity_prepare_fn(struct request *);

typedef void integrity_complete_fn(struct request *, unsigned int);

struct blk_integrity_profile {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn *prepare_fn;
	integrity_complete_fn *complete_fn;
	const char *name;
};

struct blk_zone;

typedef int (*report_zones_cb)(struct blk_zone *, unsigned int, void *);

struct hd_geometry;

struct pr_ops;

struct block_device_operations {
	blk_qc_t (*submit_bio)(struct bio *);
	int (*open)(struct block_device *, fmode_t);
	void (*release)(struct gendisk *, fmode_t);
	int (*rw_page)(struct block_device *, sector_t, struct page *, unsigned int);
	int (*ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk *);
	int (*getgeo)(struct block_device *, struct hd_geometry *);
	int (*set_read_only)(struct block_device *, bool);
	void (*swap_slot_free_notify)(struct block_device *, long unsigned int);
	int (*report_zones)(struct gendisk *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk *, umode_t *);
	struct module *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk *, sector_t *);
};

struct blk_zone {
	__u64 start;
	__u64 len;
	__u64 wp;
	__u8 type;
	__u8 cond;
	__u8 non_seq;
	__u8 reset;
	__u8 resv[4];
	__u64 capacity;
	__u8 reserved[24];
};

struct sbitmap_word {
	long unsigned int depth;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int word;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int cleared;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sbq_wait_state {
	atomic_t wait_cnt;
	wait_queue_head_t wait;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void rq_end_io_fn(struct request *, blk_status_t);

typedef __u32 req_flags_t;

enum mq_rq_state {
	MQ_RQ_IDLE = 0,
	MQ_RQ_IN_FLIGHT = 1,
	MQ_RQ_COMPLETE = 2,
};

struct blk_ksm_keyslot;

struct request {
	struct request_queue *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio *bio;
	struct bio *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn *saved_end_io;
		} flush;
	};
	struct gendisk *rq_disk;
	struct block_device *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn *end_io;
	void *end_io_data;
};

struct blk_mq_tags;

struct blk_mq_hw_ctx {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry *debugfs_dir;
	struct dentry *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum elv_merge {
	ELEVATOR_NO_MERGE = 0,
	ELEVATOR_FRONT_MERGE = 1,
	ELEVATOR_BACK_MERGE = 2,
	ELEVATOR_DISCARD_MERGE = 3,
};

struct elevator_type;

struct blk_mq_alloc_data;

struct elevator_mq_ops {
	int (*init_sched)(struct request_queue *, struct elevator_type *);
	void (*exit_sched)(struct elevator_queue *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx *);
	bool (*allow_merge)(struct request_queue *, struct request *, struct bio *);
	bool (*bio_merge)(struct request_queue *, struct bio *, unsigned int);
	int (*request_merge)(struct request_queue *, struct request **, struct bio *);
	void (*request_merged)(struct request_queue *, struct request *, enum elv_merge);
	void (*requests_merged)(struct request_queue *, struct request *, struct request *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request *);
	void (*finish_request)(struct request *);
	void (*insert_requests)(struct blk_mq_hw_ctx *, struct list_head *, bool);
	struct request * (*dispatch_request)(struct blk_mq_hw_ctx *);
	bool (*has_work)(struct blk_mq_hw_ctx *);
	void (*completed_request)(struct request *, u64);
	void (*requeue_request)(struct request *);
	struct request * (*former_request)(struct request_queue *, struct request *);
	struct request * (*next_request)(struct request_queue *, struct request *);
	void (*init_icq)(struct io_cq *);
	void (*exit_icq)(struct io_cq *);
};

struct elv_fs_entry;

struct blk_mq_debugfs_attr;

struct elevator_type {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue {
	struct elevator_type *type;
	void *elevator_data;
	struct kobject kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue *, char *);
	ssize_t (*store)(struct elevator_queue *, const char *, size_t);
};

struct seq_file___3;

struct seq_operations___2;

struct blk_mq_debugfs_attr {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___3 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___2 *seq_ops;
};

enum blk_eh_timer_return {
	BLK_EH_DONE = 0,
	BLK_EH_RESET_TIMER = 1,
};

struct blk_mq_queue_data;

struct blk_mq_ops {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx *, const struct blk_mq_queue_data *);
	void (*commit_rqs)(struct blk_mq_hw_ctx *);
	int (*get_budget)(struct request_queue *);
	void (*put_budget)(struct request_queue *, int);
	void (*set_rq_budget_token)(struct request *, int);
	int (*get_rq_budget_token)(struct request *);
	enum blk_eh_timer_return (*timeout)(struct request *, bool);
	int (*poll)(struct blk_mq_hw_ctx *);
	void (*complete)(struct request *);
	int (*init_hctx)(struct blk_mq_hw_ctx *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set *, struct request *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set *, struct request *, unsigned int);
	void (*initialize_rq_fn)(struct request *);
	void (*cleanup_rq)(struct request *);
	bool (*busy)(struct request_queue *);
	int (*map_queues)(struct blk_mq_tag_set *);
	void (*show_rq)(struct seq_file *, struct request *);
};

struct blk_mq_queue_map {
	unsigned int *mq_map;
	unsigned int nr_queues;
	unsigned int queue_offset;
};

struct blk_mq_tag_set {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_integrity_iter {
	void *prot_buf;
	void *data_buf;
	sector_t seed;
	unsigned int data_size;
	short unsigned int interval;
	const char *disk_name;
};

enum pr_type {
	PR_WRITE_EXCLUSIVE = 1,
	PR_EXCLUSIVE_ACCESS = 2,
	PR_WRITE_EXCLUSIVE_REG_ONLY = 3,
	PR_EXCLUSIVE_ACCESS_REG_ONLY = 4,
	PR_WRITE_EXCLUSIVE_ALL_REGS = 5,
	PR_EXCLUSIVE_ACCESS_ALL_REGS = 6,
};

struct block_device___2;

struct pr_ops {
	int (*pr_register)(struct block_device___2 *, u64, u64, u32);
	int (*pr_reserve)(struct block_device___2 *, u64, enum pr_type, u32);
	int (*pr_release)(struct block_device___2 *, u64, enum pr_type);
	int (*pr_preempt)(struct block_device___2 *, u64, u64, enum pr_type, bool);
	int (*pr_clear)(struct block_device___2 *, u64);
};

enum hctx_type {
	HCTX_TYPE_DEFAULT = 0,
	HCTX_TYPE_READ = 1,
	HCTX_TYPE_POLL = 2,
	HCTX_MAX_TYPES = 3,
};

struct blk_mq_queue_data {
	struct request *rq;
	bool last;
};

enum blkg_iostat_type {
	BLKG_IOSTAT_READ = 0,
	BLKG_IOSTAT_WRITE = 1,
	BLKG_IOSTAT_DISCARD = 2,
	BLKG_IOSTAT_NR = 3,
};

struct blkcg_policy_data;

struct blkcg {
	struct cgroup_subsys_state css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data {
	struct blkcg *blkcg;
	int plid;
};

struct blkg_policy_data {
	struct blkcg_gq *blkg;
	int plid;
};

enum memcg_stat_item {
	MEMCG_SWAP = 39,
	MEMCG_SOCK = 40,
	MEMCG_PERCPU_B = 41,
	MEMCG_NR_STAT = 42,
};

enum memcg_memory_event {
	MEMCG_LOW = 0,
	MEMCG_HIGH = 1,
	MEMCG_MAX = 2,
	MEMCG_OOM = 3,
	MEMCG_OOM_KILL = 4,
	MEMCG_SWAP_HIGH = 5,
	MEMCG_SWAP_MAX = 6,
	MEMCG_SWAP_FAIL = 7,
	MEMCG_NR_MEMORY_EVENTS = 8,
};

enum mem_cgroup_events_target {
	MEM_CGROUP_TARGET_THRESH = 0,
	MEM_CGROUP_TARGET_SOFTLIMIT = 1,
	MEM_CGROUP_NTARGETS = 2,
};

struct memcg_vmstats_percpu {
	long int state[42];
	long unsigned int events[99];
	long int state_prev[42];
	long unsigned int events_prev[99];
	long unsigned int nr_page_events;
	long unsigned int targets[2];
};

struct mem_cgroup_reclaim_iter {
	struct mem_cgroup *position;
	unsigned int generation;
};

struct shrinker_info {
	struct callback_head rcu;
	atomic_long_t *nr_deferred;
	long unsigned int *map;
};

struct lruvec_stats_percpu {
	long int state[39];
	long int state_prev[39];
};

struct lruvec_stats {
	long int state[39];
	long int state_pending[39];
};

struct mem_cgroup_per_node {
	struct lruvec lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup *memcg;
};

struct eventfd_ctx;

struct mem_cgroup_threshold {
	struct eventfd_ctx *eventfd;
	long unsigned int threshold;
};

struct mem_cgroup_threshold_ary {
	int current_threshold;
	unsigned int size;
	struct mem_cgroup_threshold entries[0];
};

struct obj_cgroup {
	struct percpu_ref refcnt;
	struct mem_cgroup *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct percpu_cluster {
	struct swap_cluster_info index;
	unsigned int next;
};

enum fs_value_type {
	fs_value_is_undefined = 0,
	fs_value_is_flag = 1,
	fs_value_is_string = 2,
	fs_value_is_blob = 3,
	fs_value_is_filename = 4,
	fs_value_is_file = 5,
};

struct fs_parameter {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module *owner;
	char *buffer[8];
};

struct fs_context_operations {
	void (*free)(struct fs_context *);
	int (*dup)(struct fs_context *, struct fs_context *);
	int (*parse_param)(struct fs_context *, struct fs_parameter *);
	int (*parse_monolithic)(struct fs_context *, void *);
	int (*get_tree)(struct fs_context *);
	int (*reconfigure)(struct fs_context *);
};

struct fs_parse_result {
	bool negated;
	union {
		bool boolean;
		int int_32;
		unsigned int uint_32;
		u64 uint_64;
	};
};

struct in6_addr {
	union {
		__u8 u6_addr8[16];
		__be16 u6_addr16[8];
		__be32 u6_addr32[4];
	} in6_u;
};

enum flow_dissector_key_id {
	FLOW_DISSECTOR_KEY_CONTROL = 0,
	FLOW_DISSECTOR_KEY_BASIC = 1,
	FLOW_DISSECTOR_KEY_IPV4_ADDRS = 2,
	FLOW_DISSECTOR_KEY_IPV6_ADDRS = 3,
	FLOW_DISSECTOR_KEY_PORTS = 4,
	FLOW_DISSECTOR_KEY_PORTS_RANGE = 5,
	FLOW_DISSECTOR_KEY_ICMP = 6,
	FLOW_DISSECTOR_KEY_ETH_ADDRS = 7,
	FLOW_DISSECTOR_KEY_TIPC = 8,
	FLOW_DISSECTOR_KEY_ARP = 9,
	FLOW_DISSECTOR_KEY_VLAN = 10,
	FLOW_DISSECTOR_KEY_FLOW_LABEL = 11,
	FLOW_DISSECTOR_KEY_GRE_KEYID = 12,
	FLOW_DISSECTOR_KEY_MPLS_ENTROPY = 13,
	FLOW_DISSECTOR_KEY_ENC_KEYID = 14,
	FLOW_DISSECTOR_KEY_ENC_IPV4_ADDRS = 15,
	FLOW_DISSECTOR_KEY_ENC_IPV6_ADDRS = 16,
	FLOW_DISSECTOR_KEY_ENC_CONTROL = 17,
	FLOW_DISSECTOR_KEY_ENC_PORTS = 18,
	FLOW_DISSECTOR_KEY_MPLS = 19,
	FLOW_DISSECTOR_KEY_TCP = 20,
	FLOW_DISSECTOR_KEY_IP = 21,
	FLOW_DISSECTOR_KEY_CVLAN = 22,
	FLOW_DISSECTOR_KEY_ENC_IP = 23,
	FLOW_DISSECTOR_KEY_ENC_OPTS = 24,
	FLOW_DISSECTOR_KEY_META = 25,
	FLOW_DISSECTOR_KEY_CT = 26,
	FLOW_DISSECTOR_KEY_HASH = 27,
	FLOW_DISSECTOR_KEY_MAX = 28,
};

enum {
	IPSTATS_MIB_NUM = 0,
	IPSTATS_MIB_INPKTS = 1,
	IPSTATS_MIB_INOCTETS = 2,
	IPSTATS_MIB_INDELIVERS = 3,
	IPSTATS_MIB_OUTFORWDATAGRAMS = 4,
	IPSTATS_MIB_OUTPKTS = 5,
	IPSTATS_MIB_OUTOCTETS = 6,
	IPSTATS_MIB_INHDRERRORS = 7,
	IPSTATS_MIB_INTOOBIGERRORS = 8,
	IPSTATS_MIB_INNOROUTES = 9,
	IPSTATS_MIB_INADDRERRORS = 10,
	IPSTATS_MIB_INUNKNOWNPROTOS = 11,
	IPSTATS_MIB_INTRUNCATEDPKTS = 12,
	IPSTATS_MIB_INDISCARDS = 13,
	IPSTATS_MIB_OUTDISCARDS = 14,
	IPSTATS_MIB_OUTNOROUTES = 15,
	IPSTATS_MIB_REASMTIMEOUT = 16,
	IPSTATS_MIB_REASMREQDS = 17,
	IPSTATS_MIB_REASMOKS = 18,
	IPSTATS_MIB_REASMFAILS = 19,
	IPSTATS_MIB_FRAGOKS = 20,
	IPSTATS_MIB_FRAGFAILS = 21,
	IPSTATS_MIB_FRAGCREATES = 22,
	IPSTATS_MIB_INMCASTPKTS = 23,
	IPSTATS_MIB_OUTMCASTPKTS = 24,
	IPSTATS_MIB_INBCASTPKTS = 25,
	IPSTATS_MIB_OUTBCASTPKTS = 26,
	IPSTATS_MIB_INMCASTOCTETS = 27,
	IPSTATS_MIB_OUTMCASTOCTETS = 28,
	IPSTATS_MIB_INBCASTOCTETS = 29,
	IPSTATS_MIB_OUTBCASTOCTETS = 30,
	IPSTATS_MIB_CSUMERRORS = 31,
	IPSTATS_MIB_NOECTPKTS = 32,
	IPSTATS_MIB_ECT1PKTS = 33,
	IPSTATS_MIB_ECT0PKTS = 34,
	IPSTATS_MIB_CEPKTS = 35,
	IPSTATS_MIB_REASM_OVERLAPS = 36,
	__IPSTATS_MIB_MAX = 37,
};

enum {
	ICMP_MIB_NUM = 0,
	ICMP_MIB_INMSGS = 1,
	ICMP_MIB_INERRORS = 2,
	ICMP_MIB_INDESTUNREACHS = 3,
	ICMP_MIB_INTIMEEXCDS = 4,
	ICMP_MIB_INPARMPROBS = 5,
	ICMP_MIB_INSRCQUENCHS = 6,
	ICMP_MIB_INREDIRECTS = 7,
	ICMP_MIB_INECHOS = 8,
	ICMP_MIB_INECHOREPS = 9,
	ICMP_MIB_INTIMESTAMPS = 10,
	ICMP_MIB_INTIMESTAMPREPS = 11,
	ICMP_MIB_INADDRMASKS = 12,
	ICMP_MIB_INADDRMASKREPS = 13,
	ICMP_MIB_OUTMSGS = 14,
	ICMP_MIB_OUTERRORS = 15,
	ICMP_MIB_OUTDESTUNREACHS = 16,
	ICMP_MIB_OUTTIMEEXCDS = 17,
	ICMP_MIB_OUTPARMPROBS = 18,
	ICMP_MIB_OUTSRCQUENCHS = 19,
	ICMP_MIB_OUTREDIRECTS = 20,
	ICMP_MIB_OUTECHOS = 21,
	ICMP_MIB_OUTECHOREPS = 22,
	ICMP_MIB_OUTTIMESTAMPS = 23,
	ICMP_MIB_OUTTIMESTAMPREPS = 24,
	ICMP_MIB_OUTADDRMASKS = 25,
	ICMP_MIB_OUTADDRMASKREPS = 26,
	ICMP_MIB_CSUMERRORS = 27,
	__ICMP_MIB_MAX = 28,
};

enum {
	ICMP6_MIB_NUM = 0,
	ICMP6_MIB_INMSGS = 1,
	ICMP6_MIB_INERRORS = 2,
	ICMP6_MIB_OUTMSGS = 3,
	ICMP6_MIB_OUTERRORS = 4,
	ICMP6_MIB_CSUMERRORS = 5,
	__ICMP6_MIB_MAX = 6,
};

enum {
	TCP_MIB_NUM = 0,
	TCP_MIB_RTOALGORITHM = 1,
	TCP_MIB_RTOMIN = 2,
	TCP_MIB_RTOMAX = 3,
	TCP_MIB_MAXCONN = 4,
	TCP_MIB_ACTIVEOPENS = 5,
	TCP_MIB_PASSIVEOPENS = 6,
	TCP_MIB_ATTEMPTFAILS = 7,
	TCP_MIB_ESTABRESETS = 8,
	TCP_MIB_CURRESTAB = 9,
	TCP_MIB_INSEGS = 10,
	TCP_MIB_OUTSEGS = 11,
	TCP_MIB_RETRANSSEGS = 12,
	TCP_MIB_INERRS = 13,
	TCP_MIB_OUTRSTS = 14,
	TCP_MIB_CSUMERRORS = 15,
	__TCP_MIB_MAX = 16,
};

enum {
	UDP_MIB_NUM = 0,
	UDP_MIB_INDATAGRAMS = 1,
	UDP_MIB_NOPORTS = 2,
	UDP_MIB_INERRORS = 3,
	UDP_MIB_OUTDATAGRAMS = 4,
	UDP_MIB_RCVBUFERRORS = 5,
	UDP_MIB_SNDBUFERRORS = 6,
	UDP_MIB_CSUMERRORS = 7,
	UDP_MIB_IGNOREDMULTI = 8,
	UDP_MIB_MEMERRORS = 9,
	__UDP_MIB_MAX = 10,
};

enum {
	LINUX_MIB_NUM = 0,
	LINUX_MIB_SYNCOOKIESSENT = 1,
	LINUX_MIB_SYNCOOKIESRECV = 2,
	LINUX_MIB_SYNCOOKIESFAILED = 3,
	LINUX_MIB_EMBRYONICRSTS = 4,
	LINUX_MIB_PRUNECALLED = 5,
	LINUX_MIB_RCVPRUNED = 6,
	LINUX_MIB_OFOPRUNED = 7,
	LINUX_MIB_OUTOFWINDOWICMPS = 8,
	LINUX_MIB_LOCKDROPPEDICMPS = 9,
	LINUX_MIB_ARPFILTER = 10,
	LINUX_MIB_TIMEWAITED = 11,
	LINUX_MIB_TIMEWAITRECYCLED = 12,
	LINUX_MIB_TIMEWAITKILLED = 13,
	LINUX_MIB_PAWSACTIVEREJECTED = 14,
	LINUX_MIB_PAWSESTABREJECTED = 15,
	LINUX_MIB_DELAYEDACKS = 16,
	LINUX_MIB_DELAYEDACKLOCKED = 17,
	LINUX_MIB_DELAYEDACKLOST = 18,
	LINUX_MIB_LISTENOVERFLOWS = 19,
	LINUX_MIB_LISTENDROPS = 20,
	LINUX_MIB_TCPHPHITS = 21,
	LINUX_MIB_TCPPUREACKS = 22,
	LINUX_MIB_TCPHPACKS = 23,
	LINUX_MIB_TCPRENORECOVERY = 24,
	LINUX_MIB_TCPSACKRECOVERY = 25,
	LINUX_MIB_TCPSACKRENEGING = 26,
	LINUX_MIB_TCPSACKREORDER = 27,
	LINUX_MIB_TCPRENOREORDER = 28,
	LINUX_MIB_TCPTSREORDER = 29,
	LINUX_MIB_TCPFULLUNDO = 30,
	LINUX_MIB_TCPPARTIALUNDO = 31,
	LINUX_MIB_TCPDSACKUNDO = 32,
	LINUX_MIB_TCPLOSSUNDO = 33,
	LINUX_MIB_TCPLOSTRETRANSMIT = 34,
	LINUX_MIB_TCPRENOFAILURES = 35,
	LINUX_MIB_TCPSACKFAILURES = 36,
	LINUX_MIB_TCPLOSSFAILURES = 37,
	LINUX_MIB_TCPFASTRETRANS = 38,
	LINUX_MIB_TCPSLOWSTARTRETRANS = 39,
	LINUX_MIB_TCPTIMEOUTS = 40,
	LINUX_MIB_TCPLOSSPROBES = 41,
	LINUX_MIB_TCPLOSSPROBERECOVERY = 42,
	LINUX_MIB_TCPRENORECOVERYFAIL = 43,
	LINUX_MIB_TCPSACKRECOVERYFAIL = 44,
	LINUX_MIB_TCPRCVCOLLAPSED = 45,
	LINUX_MIB_TCPDSACKOLDSENT = 46,
	LINUX_MIB_TCPDSACKOFOSENT = 47,
	LINUX_MIB_TCPDSACKRECV = 48,
	LINUX_MIB_TCPDSACKOFORECV = 49,
	LINUX_MIB_TCPABORTONDATA = 50,
	LINUX_MIB_TCPABORTONCLOSE = 51,
	LINUX_MIB_TCPABORTONMEMORY = 52,
	LINUX_MIB_TCPABORTONTIMEOUT = 53,
	LINUX_MIB_TCPABORTONLINGER = 54,
	LINUX_MIB_TCPABORTFAILED = 55,
	LINUX_MIB_TCPMEMORYPRESSURES = 56,
	LINUX_MIB_TCPMEMORYPRESSURESCHRONO = 57,
	LINUX_MIB_TCPSACKDISCARD = 58,
	LINUX_MIB_TCPDSACKIGNOREDOLD = 59,
	LINUX_MIB_TCPDSACKIGNOREDNOUNDO = 60,
	LINUX_MIB_TCPSPURIOUSRTOS = 61,
	LINUX_MIB_TCPMD5NOTFOUND = 62,
	LINUX_MIB_TCPMD5UNEXPECTED = 63,
	LINUX_MIB_TCPMD5FAILURE = 64,
	LINUX_MIB_SACKSHIFTED = 65,
	LINUX_MIB_SACKMERGED = 66,
	LINUX_MIB_SACKSHIFTFALLBACK = 67,
	LINUX_MIB_TCPBACKLOGDROP = 68,
	LINUX_MIB_PFMEMALLOCDROP = 69,
	LINUX_MIB_TCPMINTTLDROP = 70,
	LINUX_MIB_TCPDEFERACCEPTDROP = 71,
	LINUX_MIB_IPRPFILTER = 72,
	LINUX_MIB_TCPTIMEWAITOVERFLOW = 73,
	LINUX_MIB_TCPREQQFULLDOCOOKIES = 74,
	LINUX_MIB_TCPREQQFULLDROP = 75,
	LINUX_MIB_TCPRETRANSFAIL = 76,
	LINUX_MIB_TCPRCVCOALESCE = 77,
	LINUX_MIB_TCPBACKLOGCOALESCE = 78,
	LINUX_MIB_TCPOFOQUEUE = 79,
	LINUX_MIB_TCPOFODROP = 80,
	LINUX_MIB_TCPOFOMERGE = 81,
	LINUX_MIB_TCPCHALLENGEACK = 82,
	LINUX_MIB_TCPSYNCHALLENGE = 83,
	LINUX_MIB_TCPFASTOPENACTIVE = 84,
	LINUX_MIB_TCPFASTOPENACTIVEFAIL = 85,
	LINUX_MIB_TCPFASTOPENPASSIVE = 86,
	LINUX_MIB_TCPFASTOPENPASSIVEFAIL = 87,
	LINUX_MIB_TCPFASTOPENLISTENOVERFLOW = 88,
	LINUX_MIB_TCPFASTOPENCOOKIEREQD = 89,
	LINUX_MIB_TCPFASTOPENBLACKHOLE = 90,
	LINUX_MIB_TCPSPURIOUS_RTX_HOSTQUEUES = 91,
	LINUX_MIB_BUSYPOLLRXPACKETS = 92,
	LINUX_MIB_TCPAUTOCORKING = 93,
	LINUX_MIB_TCPFROMZEROWINDOWADV = 94,
	LINUX_MIB_TCPTOZEROWINDOWADV = 95,
	LINUX_MIB_TCPWANTZEROWINDOWADV = 96,
	LINUX_MIB_TCPSYNRETRANS = 97,
	LINUX_MIB_TCPORIGDATASENT = 98,
	LINUX_MIB_TCPHYSTARTTRAINDETECT = 99,
	LINUX_MIB_TCPHYSTARTTRAINCWND = 100,
	LINUX_MIB_TCPHYSTARTDELAYDETECT = 101,
	LINUX_MIB_TCPHYSTARTDELAYCWND = 102,
	LINUX_MIB_TCPACKSKIPPEDSYNRECV = 103,
	LINUX_MIB_TCPACKSKIPPEDPAWS = 104,
	LINUX_MIB_TCPACKSKIPPEDSEQ = 105,
	LINUX_MIB_TCPACKSKIPPEDFINWAIT2 = 106,
	LINUX_MIB_TCPACKSKIPPEDTIMEWAIT = 107,
	LINUX_MIB_TCPACKSKIPPEDCHALLENGE = 108,
	LINUX_MIB_TCPWINPROBE = 109,
	LINUX_MIB_TCPKEEPALIVE = 110,
	LINUX_MIB_TCPMTUPFAIL = 111,
	LINUX_MIB_TCPMTUPSUCCESS = 112,
	LINUX_MIB_TCPDELIVERED = 113,
	LINUX_MIB_TCPDELIVEREDCE = 114,
	LINUX_MIB_TCPACKCOMPRESSED = 115,
	LINUX_MIB_TCPZEROWINDOWDROP = 116,
	LINUX_MIB_TCPRCVQDROP = 117,
	LINUX_MIB_TCPWQUEUETOOBIG = 118,
	LINUX_MIB_TCPFASTOPENPASSIVEALTKEY = 119,
	LINUX_MIB_TCPTIMEOUTREHASH = 120,
	LINUX_MIB_TCPDUPLICATEDATAREHASH = 121,
	LINUX_MIB_TCPDSACKRECVSEGS = 122,
	LINUX_MIB_TCPDSACKIGNOREDDUBIOUS = 123,
	LINUX_MIB_TCPMIGRATEREQSUCCESS = 124,
	LINUX_MIB_TCPMIGRATEREQFAILURE = 125,
	__LINUX_MIB_MAX = 126,
};

enum {
	LINUX_MIB_XFRMNUM = 0,
	LINUX_MIB_XFRMINERROR = 1,
	LINUX_MIB_XFRMINBUFFERERROR = 2,
	LINUX_MIB_XFRMINHDRERROR = 3,
	LINUX_MIB_XFRMINNOSTATES = 4,
	LINUX_MIB_XFRMINSTATEPROTOERROR = 5,
	LINUX_MIB_XFRMINSTATEMODEERROR = 6,
	LINUX_MIB_XFRMINSTATESEQERROR = 7,
	LINUX_MIB_XFRMINSTATEEXPIRED = 8,
	LINUX_MIB_XFRMINSTATEMISMATCH = 9,
	LINUX_MIB_XFRMINSTATEINVALID = 10,
	LINUX_MIB_XFRMINTMPLMISMATCH = 11,
	LINUX_MIB_XFRMINNOPOLS = 12,
	LINUX_MIB_XFRMINPOLBLOCK = 13,
	LINUX_MIB_XFRMINPOLERROR = 14,
	LINUX_MIB_XFRMOUTERROR = 15,
	LINUX_MIB_XFRMOUTBUNDLEGENERROR = 16,
	LINUX_MIB_XFRMOUTBUNDLECHECKERROR = 17,
	LINUX_MIB_XFRMOUTNOSTATES = 18,
	LINUX_MIB_XFRMOUTSTATEPROTOERROR = 19,
	LINUX_MIB_XFRMOUTSTATEMODEERROR = 20,
	LINUX_MIB_XFRMOUTSTATESEQERROR = 21,
	LINUX_MIB_XFRMOUTSTATEEXPIRED = 22,
	LINUX_MIB_XFRMOUTPOLBLOCK = 23,
	LINUX_MIB_XFRMOUTPOLDEAD = 24,
	LINUX_MIB_XFRMOUTPOLERROR = 25,
	LINUX_MIB_XFRMFWDHDRERROR = 26,
	LINUX_MIB_XFRMOUTSTATEINVALID = 27,
	LINUX_MIB_XFRMACQUIREERROR = 28,
	__LINUX_MIB_XFRMMAX = 29,
};

enum {
	LINUX_MIB_TLSNUM = 0,
	LINUX_MIB_TLSCURRTXSW = 1,
	LINUX_MIB_TLSCURRRXSW = 2,
	LINUX_MIB_TLSCURRTXDEVICE = 3,
	LINUX_MIB_TLSCURRRXDEVICE = 4,
	LINUX_MIB_TLSTXSW = 5,
	LINUX_MIB_TLSRXSW = 6,
	LINUX_MIB_TLSTXDEVICE = 7,
	LINUX_MIB_TLSRXDEVICE = 8,
	LINUX_MIB_TLSDECRYPTERROR = 9,
	LINUX_MIB_TLSRXDEVICERESYNC = 10,
	__LINUX_MIB_TLSMAX = 11,
};

struct ipstats_mib {
	u64 mibs[37];
	struct u64_stats_sync syncp;
};

struct icmp_mib {
	long unsigned int mibs[28];
};

struct icmpmsg_mib {
	atomic_long_t mibs[512];
};

struct icmpv6_mib {
	long unsigned int mibs[6];
};

struct icmpv6msg_mib {
	atomic_long_t mibs[512];
};

struct tcp_mib {
	long unsigned int mibs[16];
};

struct udp_mib {
	long unsigned int mibs[10];
};

struct linux_mib {
	long unsigned int mibs[126];
};

struct linux_xfrm_mib {
	long unsigned int mibs[29];
};

struct linux_tls_mib {
	long unsigned int mibs[11];
};

struct inet_frags;

struct fqdir {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags *f;
	struct net *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue;

struct inet_frags {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue *, const void *);
	void (*destructor)(struct inet_frag_queue *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct frag_v4_compare_key {
	__be32 saddr;
	__be32 daddr;
	u32 user;
	u32 vif;
	__be16 id;
	u16 protocol;
};

struct frag_v6_compare_key {
	struct in6_addr saddr;
	struct in6_addr daddr;
	u32 user;
	__be32 id;
	u32 iif;
};

struct inet_frag_queue {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff *fragments_tail;
	struct sk_buff *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir *fqdir;
	struct callback_head rcu;
};

enum tcp_ca_event {
	CA_EVENT_TX_START = 0,
	CA_EVENT_CWND_RESTART = 1,
	CA_EVENT_COMPLETE_CWR = 2,
	CA_EVENT_LOSS = 3,
	CA_EVENT_ECN_NO_CE = 4,
	CA_EVENT_ECN_IS_CE = 5,
};

struct sock___2;

struct ack_sample;

struct rate_sample;

union tcp_cc_info;

struct module___3;

struct tcp_congestion_ops {
	u32 (*ssthresh)(struct sock___2 *);
	void (*cong_avoid)(struct sock___2 *, u32, u32);
	void (*set_state)(struct sock___2 *, u8);
	void (*cwnd_event)(struct sock___2 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___2 *, u32);
	void (*pkts_acked)(struct sock___2 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___2 *);
	void (*cong_control)(struct sock___2 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___2 *);
	u32 (*sndbuf_expand)(struct sock___2 *);
	size_t (*get_info)(struct sock___2 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___3 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___2 *);
	void (*release)(struct sock___2 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___2;

struct xfrm_state;

struct net___2;

struct lwtunnel_state;

struct dst_entry {
	struct net_device *dev;
	struct dst_ops___2 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff *);
	int (*output)(struct net___2 *, struct sock *, struct sk_buff *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

enum nf_inet_hooks {
	NF_INET_PRE_ROUTING = 0,
	NF_INET_LOCAL_IN = 1,
	NF_INET_FORWARD = 2,
	NF_INET_LOCAL_OUT = 3,
	NF_INET_POST_ROUTING = 4,
	NF_INET_NUMHOOKS = 5,
	NF_INET_INGRESS = 5,
};

enum {
	NFPROTO_UNSPEC = 0,
	NFPROTO_INET = 1,
	NFPROTO_IPV4 = 2,
	NFPROTO_ARP = 3,
	NFPROTO_NETDEV = 5,
	NFPROTO_BRIDGE = 7,
	NFPROTO_IPV6 = 10,
	NFPROTO_DECNET = 12,
	NFPROTO_NUMPROTO = 13,
};

enum nf_log_type {
	NF_LOG_TYPE_LOG = 0,
	NF_LOG_TYPE_ULOG = 1,
	NF_LOG_TYPE_MAX = 2,
};

typedef u8 u_int8_t;

struct net___3;

struct sk_buff___2;

struct net_device___2;

struct nf_loginfo;

typedef void nf_logfn(struct net___3 *, u_int8_t, unsigned int, const struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *, const struct nf_loginfo *, const char *);

struct module___4;

struct nf_logger {
	char *name;
	enum nf_log_type type;
	nf_logfn *logfn;
	struct module___4 *me;
};

struct hlist_nulls_node;

struct hlist_nulls_head {
	struct hlist_nulls_node *first;
};

struct hlist_nulls_node {
	struct hlist_nulls_node *next;
	struct hlist_nulls_node **pprev;
};

enum tcp_conntrack {
	TCP_CONNTRACK_NONE = 0,
	TCP_CONNTRACK_SYN_SENT = 1,
	TCP_CONNTRACK_SYN_RECV = 2,
	TCP_CONNTRACK_ESTABLISHED = 3,
	TCP_CONNTRACK_FIN_WAIT = 4,
	TCP_CONNTRACK_CLOSE_WAIT = 5,
	TCP_CONNTRACK_LAST_ACK = 6,
	TCP_CONNTRACK_TIME_WAIT = 7,
	TCP_CONNTRACK_CLOSE = 8,
	TCP_CONNTRACK_LISTEN = 9,
	TCP_CONNTRACK_MAX = 10,
	TCP_CONNTRACK_IGNORE = 11,
	TCP_CONNTRACK_RETRANS = 12,
	TCP_CONNTRACK_UNACK = 13,
	TCP_CONNTRACK_TIMEOUT_MAX = 14,
};

enum ct_dccp_states {
	CT_DCCP_NONE = 0,
	CT_DCCP_REQUEST = 1,
	CT_DCCP_RESPOND = 2,
	CT_DCCP_PARTOPEN = 3,
	CT_DCCP_OPEN = 4,
	CT_DCCP_CLOSEREQ = 5,
	CT_DCCP_CLOSING = 6,
	CT_DCCP_TIMEWAIT = 7,
	CT_DCCP_IGNORE = 8,
	CT_DCCP_INVALID = 9,
	__CT_DCCP_MAX = 10,
};

struct ip_conntrack_stat {
	unsigned int found;
	unsigned int invalid;
	unsigned int insert;
	unsigned int insert_failed;
	unsigned int clash_resolve;
	unsigned int drop;
	unsigned int early_drop;
	unsigned int error;
	unsigned int expect_new;
	unsigned int expect_create;
	unsigned int expect_delete;
	unsigned int search_restart;
	unsigned int chaintoolong;
};

enum ip_conntrack_dir {
	IP_CT_DIR_ORIGINAL = 0,
	IP_CT_DIR_REPLY = 1,
	IP_CT_DIR_MAX = 2,
};

enum sctp_conntrack {
	SCTP_CONNTRACK_NONE = 0,
	SCTP_CONNTRACK_CLOSED = 1,
	SCTP_CONNTRACK_COOKIE_WAIT = 2,
	SCTP_CONNTRACK_COOKIE_ECHOED = 3,
	SCTP_CONNTRACK_ESTABLISHED = 4,
	SCTP_CONNTRACK_SHUTDOWN_SENT = 5,
	SCTP_CONNTRACK_SHUTDOWN_RECD = 6,
	SCTP_CONNTRACK_SHUTDOWN_ACK_SENT = 7,
	SCTP_CONNTRACK_HEARTBEAT_SENT = 8,
	SCTP_CONNTRACK_HEARTBEAT_ACKED = 9,
	SCTP_CONNTRACK_MAX = 10,
};

enum udp_conntrack {
	UDP_CT_UNREPLIED = 0,
	UDP_CT_REPLIED = 1,
	UDP_CT_MAX = 2,
};

enum gre_conntrack {
	GRE_CT_UNREPLIED = 0,
	GRE_CT_REPLIED = 1,
	GRE_CT_MAX = 2,
};

struct ct_pcpu {
	spinlock_t lock;
	struct hlist_nulls_head unconfirmed;
	struct hlist_nulls_head dying;
};

enum {
	XFRM_POLICY_IN = 0,
	XFRM_POLICY_OUT = 1,
	XFRM_POLICY_FWD = 2,
	XFRM_POLICY_MASK = 3,
	XFRM_POLICY_MAX = 3,
};

enum netns_bpf_attach_type {
	NETNS_BPF_INVALID = 4294967295,
	NETNS_BPF_FLOW_DISSECTOR = 0,
	NETNS_BPF_SK_LOOKUP = 1,
	MAX_NETNS_BPF_ATTACH_TYPE = 2,
};

struct pipe_buf_operations;

struct pipe_buffer {
	struct page *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations {
	int (*confirm)(struct pipe_inode_info *, struct pipe_buffer *);
	void (*release)(struct pipe_inode_info *, struct pipe_buffer *);
	bool (*try_steal)(struct pipe_inode_info *, struct pipe_buffer *);
	bool (*get)(struct pipe_inode_info *, struct pipe_buffer *);
};

struct skb_ext {
	refcount_t refcnt;
	u8 offset[4];
	u8 chunks;
	long: 56;
	char data[0];
};

enum skb_ext_id {
	SKB_EXT_BRIDGE_NF = 0,
	SKB_EXT_SEC_PATH = 1,
	TC_SKB_EXT = 2,
	SKB_EXT_MPTCP = 3,
	SKB_EXT_NUM = 4,
};

struct trace_event_raw_initcall_level {
	struct trace_entry ent;
	u32 __data_loc_level;
	char __data[0];
};

struct trace_event_raw_initcall_start {
	struct trace_entry ent;
	initcall_t func;
	char __data[0];
};

struct trace_event_raw_initcall_finish {
	struct trace_entry ent;
	initcall_t func;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_initcall_level {
	u32 level;
};

struct trace_event_data_offsets_initcall_start {};

struct trace_event_data_offsets_initcall_finish {};

typedef void (*btf_trace_initcall_level)(void *, const char *);

typedef void (*btf_trace_initcall_start)(void *, initcall_t);

typedef void (*btf_trace_initcall_finish)(void *, initcall_t, int);

struct blacklist_entry {
	struct list_head next;
	char *buf;
};

typedef __u32 Elf32_Word;

struct elf32_note {
	Elf32_Word n_namesz;
	Elf32_Word n_descsz;
	Elf32_Word n_type;
};

struct hrtimer_clock_base___2;

struct hrtimer___2 {
	struct timerqueue_node node;
	ktime_t _softexpires;
	enum hrtimer_restart (*function)(struct hrtimer___2 *);
	struct hrtimer_clock_base___2 *base;
	u8 state;
	u8 is_rel;
	u8 is_soft;
	u8 is_hard;
};

struct sched_dl_entity___2 {
	struct rb_node rb_node;
	u64 dl_runtime;
	u64 dl_deadline;
	u64 dl_period;
	u64 dl_bw;
	u64 dl_density;
	s64 runtime;
	u64 deadline;
	unsigned int flags;
	unsigned int dl_throttled;
	unsigned int dl_yielded;
	unsigned int dl_non_contending;
	unsigned int dl_overrun;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer___2 dl_timer;
	struct hrtimer___2 inactive_timer;
	struct sched_dl_entity___2 *pi_se;
};

struct mm_struct___3;

struct uprobe_task___2;

struct nsproxy___2;

struct signal_struct___2;

struct bio_list___2;

struct backing_dev_info___2;

struct io_context___2;

struct css_set___2;

struct perf_event_context___2;

struct pipe_inode_info___2;

struct mem_cgroup___2;

struct request_queue___3;

struct vm_struct___2;

struct task_struct___3 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___3 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___2 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___3 *mm;
	struct mm_struct___3 *active_mm;
	struct vmacache vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___3 *real_parent;
	struct task_struct___3 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___3 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___2 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___3 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task___2 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___3 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum pcpu_fc {
	PCPU_FC_AUTO = 0,
	PCPU_FC_EMBED = 1,
	PCPU_FC_PAGE = 2,
	PCPU_FC_NR = 3,
};

enum {
	UNAME26 = 131072,
	ADDR_NO_RANDOMIZE = 262144,
	FDPIC_FUNCPTRS = 524288,
	MMAP_PAGE_ZERO = 1048576,
	ADDR_COMPAT_LAYOUT = 2097152,
	READ_IMPLIES_EXEC = 4194304,
	ADDR_LIMIT_32BIT = 8388608,
	SHORT_INODE = 16777216,
	WHOLE_SECONDS = 33554432,
	STICKY_TIMEOUTS = 67108864,
	ADDR_LIMIT_3GB = 134217728,
};

struct hrtimer_cpu_base___2;

struct hrtimer_clock_base___2 {
	struct hrtimer_cpu_base___2 *cpu_base;
	unsigned int index;
	clockid_t clockid;
	seqcount_raw_spinlock_t seq;
	struct hrtimer___2 *running;
	struct timerqueue_head active;
	ktime_t (*get_time)();
	ktime_t offset;
};

struct hrtimer_cpu_base___2 {
	raw_spinlock_t lock;
	unsigned int cpu;
	unsigned int active_bases;
	unsigned int clock_was_set_seq;
	unsigned int hres_active;
	unsigned int in_hrtirq;
	unsigned int hang_detected;
	unsigned int softirq_activated;
	long: 64;
	long: 64;
	unsigned int nr_events;
	short unsigned int nr_retries;
	short unsigned int nr_hangs;
	unsigned int max_hang_time;
	ktime_t expires_next;
	struct hrtimer___2 *next_timer;
	ktime_t softirq_expires_next;
	struct hrtimer___2 *softirq_next_timer;
	struct hrtimer_clock_base___2 clock_base[8];
};

enum hrtimer_base_type {
	HRTIMER_BASE_MONOTONIC = 0,
	HRTIMER_BASE_REALTIME = 1,
	HRTIMER_BASE_BOOTTIME = 2,
	HRTIMER_BASE_TAI = 3,
	HRTIMER_BASE_MONOTONIC_SOFT = 4,
	HRTIMER_BASE_REALTIME_SOFT = 5,
	HRTIMER_BASE_BOOTTIME_SOFT = 6,
	HRTIMER_BASE_TAI_SOFT = 7,
	HRTIMER_MAX_CLOCK_BASES = 8,
};

enum {
	MM_FILEPAGES = 0,
	MM_ANONPAGES = 1,
	MM_SWAPENTS = 2,
	MM_SHMEMPAGES = 3,
	NR_MM_COUNTERS = 4,
};

enum rseq_cs_flags_bit {
	RSEQ_CS_FLAG_NO_RESTART_ON_PREEMPT_BIT = 0,
	RSEQ_CS_FLAG_NO_RESTART_ON_SIGNAL_BIT = 1,
	RSEQ_CS_FLAG_NO_RESTART_ON_MIGRATE_BIT = 2,
};

enum uclamp_id {
	UCLAMP_MIN = 0,
	UCLAMP_MAX = 1,
	UCLAMP_CNT = 2,
};

enum perf_event_task_context {
	perf_invalid_context = 4294967295,
	perf_hw_context = 0,
	perf_sw_context = 1,
	perf_nr_task_contexts = 2,
};

struct uts_namespace___2;

struct cgroup_namespace___2;

struct nsproxy___2 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

enum rseq_event_mask_bits {
	RSEQ_EVENT_PREEMPT_BIT = 0,
	RSEQ_EVENT_SIGNAL_BIT = 1,
	RSEQ_EVENT_MIGRATE_BIT = 2,
};

struct proc_ns_operations___2;

struct ns_common___2 {
	atomic_long_t stashed;
	const struct proc_ns_operations___2 *ops;
	unsigned int inum;
	refcount_t count;
};

struct uts_namespace___2 {
	struct new_utsname name;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common___2 ns;
};

struct nsset___2 {
	unsigned int flags;
	struct nsproxy___2 *nsproxy;
	struct fs_struct *fs;
	const struct cred *cred;
};

struct proc_ns_operations___2 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___2 * (*get)(struct task_struct___3 *);
	void (*put)(struct ns_common___2 *);
	int (*install)(struct nsset___2 *, struct ns_common___2 *);
	struct user_namespace * (*owner)(struct ns_common___2 *);
	struct ns_common___2 * (*get_parent)(struct ns_common___2 *);
};

enum {
	PROC_ROOT_INO = 1,
	PROC_IPC_INIT_INO = 4026531839,
	PROC_UTS_INIT_INO = 4026531838,
	PROC_USER_INIT_INO = 4026531837,
	PROC_PID_INIT_INO = 4026531836,
	PROC_CGROUP_INIT_INO = 4026531835,
	PROC_TIME_INIT_INO = 4026531834,
};

typedef __u16 __le16;

typedef __u64 __be64;

typedef unsigned int slab_flags_t;

struct fs_context___2;

struct fs_parameter_spec___2;

struct dentry___3;

struct super_block___3;

struct module___5;

struct file_system_type___2 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___2 *);
	const struct fs_parameter_spec___2 *parameters;
	struct dentry___3 * (*mount)(struct file_system_type___2 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___3 *);
	struct module___5 *owner;
	struct file_system_type___2 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___3;

struct kiocb___2;

struct iov_iter___2;

struct poll_table_struct___2;

struct vm_area_struct___3;

struct inode___4;

struct file_lock___2;

struct page___4;

struct seq_file___4;

struct file_operations___2 {
	struct module___5 *owner;
	loff_t (*llseek)(struct file___3 *, loff_t, int);
	ssize_t (*read)(struct file___3 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___3 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___2 *, struct iov_iter___2 *);
	ssize_t (*write_iter)(struct kiocb___2 *, struct iov_iter___2 *);
	int (*iopoll)(struct kiocb___2 *, bool);
	int (*iterate)(struct file___3 *, struct dir_context *);
	int (*iterate_shared)(struct file___3 *, struct dir_context *);
	__poll_t (*poll)(struct file___3 *, struct poll_table_struct___2 *);
	long int (*unlocked_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___3 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___3 *, struct vm_area_struct___3 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___4 *, struct file___3 *);
	int (*flush)(struct file___3 *, fl_owner_t);
	int (*release)(struct inode___4 *, struct file___3 *);
	int (*fsync)(struct file___3 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___3 *, int);
	int (*lock)(struct file___3 *, int, struct file_lock___2 *);
	ssize_t (*sendpage)(struct file___3 *, struct page___4 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___3 *, long unsigned int);
	int (*flock)(struct file___3 *, int, struct file_lock___2 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___3 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___3 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___3 *, long int, struct file_lock___2 **, void **);
	long int (*fallocate)(struct file___3 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___4 *, struct file___3 *);
	ssize_t (*copy_file_range)(struct file___3 *, loff_t, struct file___3 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___3 *, loff_t, struct file___3 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___3 *, loff_t, loff_t, int);
};

struct vmacache___2 {
	u64 seqnum;
	struct vm_area_struct___3 *vmas[4];
};

struct page_frag___2 {
	struct page___4 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___2;

struct debug_info___2 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___2 *hbp_break[16];
	struct perf_event___2 *hbp_watch[16];
};

struct thread_struct___2 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___2 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___4;

struct pid___2;

struct fs_struct___2;

struct nsproxy___3;

struct signal_struct___3;

struct bio_list___3;

struct backing_dev_info___3;

struct io_context___3;

struct css_set___3;

struct perf_event_context___3;

struct request_queue___4;

struct vm_struct___3;

struct task_struct___4 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___4 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___4 *mm;
	struct mm_struct___4 *active_mm;
	struct vmacache___2 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___4 *real_parent;
	struct task_struct___4 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___4 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___2 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___2 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___3 *nsproxy;
	struct signal_struct___3 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___4 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___3 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___3 *backing_dev_info;
	struct io_context___3 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___3 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___3 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___2 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___4 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___4 *oom_reaper_list;
	struct vm_struct___3 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___2 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___2;

struct kobj_type___2;

struct kernfs_node___2;

struct kobject___2 {
	const char *name;
	struct list_head entry;
	struct kobject___2 *parent;
	struct kset___2 *kset;
	struct kobj_type___2 *ktype;
	struct kernfs_node___2 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___2 {
	struct kobject___2 kobj;
	struct module___5 *mod;
	struct kobject___2 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___2 {
	struct module___5 *mod;
	struct latch_tree_node node;
};

struct module_layout___2 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___2 mtn;
};

struct module_attribute___2;

struct kernel_param___2;

struct trace_event_call___2;

struct module___5 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___2 mkobj;
	struct module_attribute___2 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___2 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___2 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___2 core_layout;
	struct module_layout___2 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___2 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___2 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___4 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct perf_sample_data___2;

typedef void (*perf_overflow_handler_t___2)(struct perf_event___2 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___2;

struct fasync_struct___2;

struct pid_namespace___2;

struct perf_cgroup___2;

struct perf_event___2 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___2 *group_leader;
	struct pmu___2 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___2 hw;
	struct perf_event_context___3 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___2 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___4 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___2 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___2 *aux_event;
	void (*destroy)(struct perf_event___2 *);
	struct callback_head callback_head;
	struct pid_namespace___2 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___2 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___2 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___2 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___2 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___2 {
	int nr;
	struct pid_namespace___2 *ns;
};

struct pid_namespace___2 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___4 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___2 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___2 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___2 numbers[1];
};

typedef struct page___4 *pgtable_t___2;

struct address_space___2;

struct page_pool___2;

struct dev_pagemap___2;

struct page___4 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___2 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___4 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___2 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___4 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___2 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___2;

struct vm_area_struct___3 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___3 *vm_next;
	struct vm_area_struct___3 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___4 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___2 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___3 *vm_file;
	struct file___3 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___2;

struct signal_struct___3 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___4 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___4 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___2 *pids[4];
	struct pid___2 *tty_old_pgrp;
	int leader;
	struct tty_struct___2 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___4 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___2;

struct mm_struct___4 {
	struct {
		struct vm_area_struct___3 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___3 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___2 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___4 *owner;
		struct user_namespace *user_ns;
		struct file___3 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vfsmount___2;

struct path___2 {
	struct vfsmount___2 *mnt;
	struct dentry___3 *dentry;
};

struct fs_struct___2 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___2 root;
	struct path___2 pwd;
};

struct cgroup_namespace___3;

struct nsproxy___3 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___2 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___3 *cgroup_ns;
};

struct bio___2;

struct bio_list___3 {
	struct bio___2 *head;
	struct bio___2 *tail;
};

struct cgroup_subsys_state___2;

struct bdi_writeback___2 {
	struct backing_dev_info___3 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___2 *memcg_css;
	struct cgroup_subsys_state___2 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___3;

struct backing_dev_info___3 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___2 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___3 *dev;
	char dev_name[64];
	struct device___3 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___3 *debug_dir;
};

struct io_cq___2;

struct io_context___3 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___2 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___2;

struct css_set___3 {
	struct cgroup_subsys_state___2 *subsys[14];
	refcount_t refcount;
	struct css_set___3 *dom_cset;
	struct cgroup___2 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___2 *mg_src_cgrp;
	struct cgroup___2 *mg_dst_cgrp;
	struct css_set___3 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___3 {
	struct pmu___2 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___4 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___3 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___2;

struct pipe_inode_info___2 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___4 *tmp_page;
	struct fasync_struct___2 *fasync_readers;
	struct fasync_struct___2 *fasync_writers;
	struct pipe_buffer___2 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___2;

struct cgroup_subsys_state___2 {
	struct cgroup___2 *cgroup;
	struct cgroup_subsys___2 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___2 *parent;
};

struct cgroup_file___2 {
	struct kernfs_node___2 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___2;

struct mem_cgroup_per_node___2;

struct mem_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___2 events_file;
	struct cgroup_file___2 events_local_file;
	struct cgroup_file___2 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___2 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___4 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___2 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___2;

struct blk_integrity___2 {
	const struct blk_integrity_profile___2 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___2 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___3 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___2;

struct elevator_queue___2;

struct blk_mq_ops___2;

struct blk_mq_hw_ctx___2;

struct gendisk___2;

struct blkcg_gq___2;

struct blk_mq_tag_set___2;

struct request_queue___4 {
	struct request___2 *last_merge;
	struct elevator_queue___2 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___2 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___2 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___2 *disk;
	struct kobject___2 kobj;
	struct kobject___2 *mq_kobj;
	struct blk_integrity___2 integrity;
	struct device___3 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___2 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___2 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___2 bio_split;
	struct dentry___3 *debugfs_dir;
	struct dentry___3 *sched_debugfs_dir;
	struct dentry___3 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___3 {
	struct vm_struct___3 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___4 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___2;

struct address_space___2 {
	struct inode___4 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___2 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___2 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___3 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___2 {
	u32 count;
	struct page___4 *cache[128];
};

struct page_pool___2 {
	struct page_pool_params___2 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___4 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___2 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___2;

struct dev_pagemap___2 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___2 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___2 {
	rwlock_t lock;
	struct pid___2 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___3 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___2 f_path;
	struct inode___4 *f_inode;
	const struct file_operations___2 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___2 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___2 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___2;

struct vm_operations_struct___2 {
	void (*open)(struct vm_area_struct___3 *);
	void (*close)(struct vm_area_struct___3 *);
	int (*may_split)(struct vm_area_struct___3 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___3 *);
	int (*mprotect)(struct vm_area_struct___3 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___2 *);
	vm_fault_t (*huge_fault)(struct vm_fault___2 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___2 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___3 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___2 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___2 *);
	int (*access)(struct vm_area_struct___3 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___3 *);
	int (*set_policy)(struct vm_area_struct___3 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___3 *, long unsigned int);
	struct page___4 * (*find_special_page)(struct vm_area_struct___3 *, long unsigned int);
};

struct core_thread___2 {
	struct task_struct___4 *task;
	struct core_thread___2 *next;
};

struct core_state___2 {
	atomic_t nr_threads;
	struct core_thread___2 dumper;
	struct completion startup;
};

struct vm_fault___2 {
	const struct {
		struct vm_area_struct___3 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___4 *cow_page;
	struct page___4 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___2 prealloc_pte;
};

struct pglist_data___2;

struct lruvec___2 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___2 *pgdat;
};

struct zone___2 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___2 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___2 {
	struct zone___2 *zone;
	int zone_idx;
};

struct zonelist___2 {
	struct zoneref___2 _zonerefs[321];
};

struct pglist_data___2 {
	struct zone___2 node_zones[5];
	struct zonelist___2 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___4 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___4 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___2 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___2;

struct dentry___3 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___3 *d_parent;
	struct qstr d_name;
	struct inode___4 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___2 *d_op;
	struct super_block___3 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___2;

struct cdev___2;

struct inode___4 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___2 *i_op;
	struct super_block___3 *i_sb;
	struct address_space___2 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___2 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___2 *i_fop;
		void (*free_inode)(struct inode___4 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___2 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___2 {
	int (*d_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___3 *, unsigned int);
	int (*d_hash)(const struct dentry___3 *, struct qstr *);
	int (*d_compare)(const struct dentry___3 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___3 *);
	int (*d_init)(struct dentry___3 *);
	void (*d_release)(struct dentry___3 *);
	void (*d_prune)(struct dentry___3 *);
	void (*d_iput)(struct dentry___3 *, struct inode___4 *);
	char * (*d_dname)(struct dentry___3 *, char *, int);
	struct vfsmount___2 * (*d_automount)(struct path___2 *);
	int (*d_manage)(const struct path___2 *, bool);
	struct dentry___3 * (*d_real)(struct dentry___3 *, const struct inode___4 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___2;

struct mem_dqinfo___2 {
	struct quota_format_type___2 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___2;

struct quota_info___2 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___4 *files[3];
	struct mem_dqinfo___2 info[3];
	const struct quota_format_ops___2 *ops[3];
};

struct rcuwait___2 {
	struct task_struct___4 *task;
};

struct percpu_rw_semaphore___2 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___2 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___2 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___2 rw_sem[3];
};

struct shrink_control___2;

struct shrinker___2 {
	long unsigned int (*count_objects)(struct shrinker___2 *, struct shrink_control___2 *);
	long unsigned int (*scan_objects)(struct shrinker___2 *, struct shrink_control___2 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___2;

struct dquot_operations___2;

struct quotactl_ops___2;

struct xattr_handler___2;

struct block_device___3;

struct super_block___3 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___2 *s_type;
	const struct super_operations___2 *s_op;
	const struct dquot_operations___2 *dq_op;
	const struct quotactl_ops___2 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___3 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___2 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___3 *s_bdev;
	struct backing_dev_info___3 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___2 s_dquot;
	struct sb_writers___2 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___2 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___2 {
	struct dentry___3 *mnt_root;
	struct super_block___3 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___2 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___2 *memcg;
};

struct psi_group___2 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___4 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___2;

struct cgroup_rstat_cpu___2;

struct cgroup___2 {
	struct cgroup_subsys_state___2 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___2 *kn;
	struct cgroup_file___2 procs_file;
	struct cgroup_file___2 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___2 *subsys[14];
	struct cgroup_root___2 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___2 *dom_cgrp;
	struct cgroup___2 *old_dom_cgrp;
	struct cgroup_rstat_cpu___2 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___2 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct ld_semaphore {
	atomic_long_t count;
	raw_spinlock_t wait_lock;
	unsigned int wait_readers;
	struct list_head read_wait;
	struct list_head write_wait;
};

typedef unsigned int tcflag_t;

typedef unsigned char cc_t;

typedef unsigned int speed_t;

struct ktermios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct winsize {
	short unsigned int ws_row;
	short unsigned int ws_col;
	short unsigned int ws_xpixel;
	short unsigned int ws_ypixel;
};

struct tty_driver;

struct tty_operations;

struct tty_ldisc;

struct tty_port;

struct tty_struct___2 {
	int magic;
	struct kref kref;
	struct device___3 *dev;
	struct tty_driver *driver;
	const struct tty_operations *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___2 *pgrp;
		struct pid___2 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___2 *link;
	struct fasync_struct___2 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port *port;
};

struct io_cq___2 {
	struct request_queue___4 *q;
	struct io_context___3 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___2;

struct kiocb___2 {
	struct file___3 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___2 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___3 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___3 *ia_file;
};

struct dquot___2 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___3 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___2 {
	int qf_fmt_id;
	const struct quota_format_ops___2 *qf_ops;
	struct module___5 *qf_owner;
	struct quota_format_type___2 *qf_next;
};

struct quota_format_ops___2 {
	int (*check_quota_file)(struct super_block___3 *, int);
	int (*read_file_info)(struct super_block___3 *, int);
	int (*write_file_info)(struct super_block___3 *, int);
	int (*free_file_info)(struct super_block___3 *, int);
	int (*read_dqblk)(struct dquot___2 *);
	int (*commit_dqblk)(struct dquot___2 *);
	int (*release_dqblk)(struct dquot___2 *);
	int (*get_next_id)(struct super_block___3 *, struct kqid *);
};

struct dquot_operations___2 {
	int (*write_dquot)(struct dquot___2 *);
	struct dquot___2 * (*alloc_dquot)(struct super_block___3 *, int);
	void (*destroy_dquot)(struct dquot___2 *);
	int (*acquire_dquot)(struct dquot___2 *);
	int (*release_dquot)(struct dquot___2 *);
	int (*mark_dirty)(struct dquot___2 *);
	int (*write_info)(struct super_block___3 *, int);
	qsize_t * (*get_reserved_space)(struct inode___4 *);
	int (*get_projid)(struct inode___4 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___4 *, qsize_t *);
	int (*get_next_id)(struct super_block___3 *, struct kqid *);
};

struct quotactl_ops___2 {
	int (*quota_on)(struct super_block___3 *, int, int, const struct path___2 *);
	int (*quota_off)(struct super_block___3 *, int);
	int (*quota_enable)(struct super_block___3 *, unsigned int);
	int (*quota_disable)(struct super_block___3 *, unsigned int);
	int (*quota_sync)(struct super_block___3 *, int);
	int (*set_info)(struct super_block___3 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___3 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___3 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___3 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___3 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___3 *, unsigned int);
};

struct wait_page_queue___2 {
	struct page___4 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

typedef struct {
	size_t written;
	size_t count;
	union {
		char *buf;
		void *data;
	} arg;
	int error;
} read_descriptor_t;

struct writeback_control___2;

struct readahead_control___2;

struct swap_info_struct___2;

struct address_space_operations___2 {
	int (*writepage)(struct page___4 *, struct writeback_control___2 *);
	int (*readpage)(struct file___3 *, struct page___4 *);
	int (*writepages)(struct address_space___2 *, struct writeback_control___2 *);
	int (*set_page_dirty)(struct page___4 *);
	int (*readpages)(struct file___3 *, struct address_space___2 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___2 *);
	int (*write_begin)(struct file___3 *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___4 **, void **);
	int (*write_end)(struct file___3 *, struct address_space___2 *, loff_t, unsigned int, unsigned int, struct page___4 *, void *);
	sector_t (*bmap)(struct address_space___2 *, sector_t);
	void (*invalidatepage)(struct page___4 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___4 *, gfp_t);
	void (*freepage)(struct page___4 *);
	ssize_t (*direct_IO)(struct kiocb___2 *, struct iov_iter___2 *);
	int (*migratepage)(struct address_space___2 *, struct page___4 *, struct page___4 *, enum migrate_mode);
	bool (*isolate_page)(struct page___4 *, isolate_mode_t);
	void (*putback_page)(struct page___4 *);
	int (*launder_page)(struct page___4 *);
	int (*is_partially_uptodate)(struct page___4 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___4 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___2 *, struct page___4 *);
	int (*swap_activate)(struct swap_info_struct___2 *, struct file___3 *, sector_t *);
	void (*swap_deactivate)(struct file___3 *);
};

struct writeback_control___2 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___2 *wb;
	struct inode___4 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___2 {
	struct file___3 *file;
	struct address_space___2 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___2;

struct iov_iter___2 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___2 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___2 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___3 *bdev;
	struct file___3 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___2 {
	struct kobject___2 kobj;
	struct module___5 *owner;
	const struct file_operations___2 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct posix_acl_entry {
	short int e_tag;
	short unsigned int e_perm;
	union {
		kuid_t e_uid;
		kgid_t e_gid;
	};
};

struct posix_acl {
	refcount_t a_refcount;
	struct callback_head a_rcu;
	unsigned int a_count;
	struct posix_acl_entry a_entries[0];
};

struct inode_operations___2 {
	struct dentry___3 * (*lookup)(struct inode___4 *, struct dentry___3 *, unsigned int);
	const char * (*get_link)(struct dentry___3 *, struct inode___4 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___4 *, int);
	struct posix_acl * (*get_acl)(struct inode___4 *, int, bool);
	int (*readlink)(struct dentry___3 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___4 *, struct dentry___3 *, umode_t, bool);
	int (*link)(struct dentry___3 *, struct inode___4 *, struct dentry___3 *);
	int (*unlink)(struct inode___4 *, struct dentry___3 *);
	int (*symlink)(struct user_namespace *, struct inode___4 *, struct dentry___3 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___4 *, struct dentry___3 *, umode_t);
	int (*rmdir)(struct inode___4 *, struct dentry___3 *);
	int (*mknod)(struct user_namespace *, struct inode___4 *, struct dentry___3 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___4 *, struct dentry___3 *, struct inode___4 *, struct dentry___3 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___3 *, struct iattr___3 *);
	int (*getattr)(struct user_namespace *, const struct path___2 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___3 *, char *, size_t);
	int (*fiemap)(struct inode___4 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___4 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___4 *, struct dentry___3 *, struct file___3 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___4 *, struct dentry___3 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___4 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___3 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___3 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___2 {
	void (*fl_copy_lock)(struct file_lock___2 *, struct file_lock___2 *);
	void (*fl_release_private)(struct file_lock___2 *);
};

struct lock_manager_operations___2;

struct file_lock___2 {
	struct file_lock___2 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___3 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___2 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___2 *fl_ops;
	const struct lock_manager_operations___2 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___2 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___2 *);
	int (*lm_grant)(struct file_lock___2 *, int);
	bool (*lm_break)(struct file_lock___2 *);
	int (*lm_change)(struct file_lock___2 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___2 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___2 *);
};

struct fasync_struct___2 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___2 *fa_next;
	struct file___3 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___2 {
	struct inode___4 * (*alloc_inode)(struct super_block___3 *);
	void (*destroy_inode)(struct inode___4 *);
	void (*free_inode)(struct inode___4 *);
	void (*dirty_inode)(struct inode___4 *, int);
	int (*write_inode)(struct inode___4 *, struct writeback_control___2 *);
	int (*drop_inode)(struct inode___4 *);
	void (*evict_inode)(struct inode___4 *);
	void (*put_super)(struct super_block___3 *);
	int (*sync_fs)(struct super_block___3 *, int);
	int (*freeze_super)(struct super_block___3 *);
	int (*freeze_fs)(struct super_block___3 *);
	int (*thaw_super)(struct super_block___3 *);
	int (*unfreeze_fs)(struct super_block___3 *);
	int (*statfs)(struct dentry___3 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___3 *, int *, char *);
	void (*umount_begin)(struct super_block___3 *);
	int (*show_options)(struct seq_file___4 *, struct dentry___3 *);
	int (*show_devname)(struct seq_file___4 *, struct dentry___3 *);
	int (*show_path)(struct seq_file___4 *, struct dentry___3 *);
	int (*show_stats)(struct seq_file___4 *, struct dentry___3 *);
	ssize_t (*quota_read)(struct super_block___3 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___3 *, int, const char *, size_t, loff_t);
	struct dquot___2 ** (*get_dquots)(struct inode___4 *);
	long int (*nr_cached_objects)(struct super_block___3 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___3 *, struct shrink_control___2 *);
	struct file___3 * (*real_loop)(struct file___3 *);
};

struct xattr_handler___2 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___3 *);
	int (*get)(const struct xattr_handler___2 *, struct dentry___3 *, struct inode___4 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___2 *, struct user_namespace *, struct dentry___3 *, struct inode___4 *, const char *, const void *, size_t, int);
};

struct wakeup_source___2;

struct dev_pm_info___2 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___2 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___3 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___2;

struct bus_type___2;

struct device_driver___2;

struct dev_pm_domain___2;

struct irq_domain___2;

struct device_node___2;

struct fwnode_handle___2;

struct class___2;

struct attribute_group___2;

struct device___3 {
	struct kobject___2 kobj;
	struct device___3 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___2 *type;
	struct bus_type___2 *bus;
	struct device_driver___2 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___2 power;
	struct dev_pm_domain___2 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___2 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___2 *class;
	const struct attribute_group___2 **groups;
	void (*release)(struct device___3 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___3 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___4 *bd_inode;
	struct super_block___3 *bd_super;
	void *bd_claiming;
	struct device___3 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___2 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___2 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___3 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___2)(struct file___3 *, wait_queue_head_t *, struct poll_table_struct___2 *);

struct poll_table_struct___2 {
	poll_queue_proc___2 _qproc;
	__poll_t _key;
};

struct seq_operations___3;

struct seq_file___4 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___3 *op;
	int poll_event;
	const struct file___3 *file;
	void *private;
};

struct fc_log___2;

struct p_log___2 {
	const char *prefix;
	struct fc_log___2 *log;
};

struct fs_context_operations___2;

struct fs_context___2 {
	const struct fs_context_operations___2 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___2 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___3 *root;
	struct user_namespace *user_ns;
	struct net___2 *net_ns;
	const struct cred *cred;
	struct p_log___2 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___2;

typedef int fs_param_type___2(struct p_log___2 *, const struct fs_parameter_spec___2 *, struct fs_parameter___2 *, struct fs_parse_result *);

struct fs_parameter_spec___2 {
	const char *name;
	fs_param_type___2 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___2(struct bio___2 *);

struct bio_vec___2 {
	struct page___4 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___2;

struct bio___2 {
	struct bio___2 *bi_next;
	struct block_device___3 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___2 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___2 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___2 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___2 *bi_io_vec;
	struct bio_set___2 *bi_pool;
	struct bio_vec___2 bi_inline_vecs[0];
};

struct kernfs_root___2;

struct kernfs_elem_dir___2 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___2 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___2;

struct kernfs_root___2 {
	struct kernfs_node___2 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___2 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___2 {
	struct kernfs_node___2 *target_kn;
};

struct kernfs_ops___2;

struct kernfs_elem_attr___2 {
	const struct kernfs_ops___2 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___2 *notify_next;
};

struct kernfs_node___2 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___2 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___2 dir;
		struct kernfs_elem_symlink___2 symlink;
		struct kernfs_elem_attr___2 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___2;

struct kernfs_ops___2 {
	int (*open)(struct kernfs_open_file___2 *);
	void (*release)(struct kernfs_open_file___2 *);
	int (*seq_show)(struct seq_file___4 *, void *);
	void * (*seq_start)(struct seq_file___4 *, loff_t *);
	void * (*seq_next)(struct seq_file___4 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___4 *, void *);
	ssize_t (*read)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___2 *, struct poll_table_struct___2 *);
	int (*mmap)(struct kernfs_open_file___2 *, struct vm_area_struct___3 *);
};

struct kernfs_syscall_ops___2 {
	int (*show_options)(struct seq_file___4 *, struct kernfs_root___2 *);
	int (*mkdir)(struct kernfs_node___2 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___2 *);
	int (*rename)(struct kernfs_node___2 *, struct kernfs_node___2 *, const char *);
	int (*show_path)(struct seq_file___4 *, struct kernfs_node___2 *, struct kernfs_root___2 *);
};

struct kernfs_open_file___2 {
	struct kernfs_node___2 *kn;
	struct file___3 *file;
	struct seq_file___4 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___2 *vm_ops;
};

typedef __u64 __addrpair;

typedef __u32 __portpair;

typedef struct {
	struct net___2 *net;
} possible_net_t;

struct proto;

struct sock_common {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto *skc_prot;
	possible_net_t skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

typedef struct {
	spinlock_t slock;
	int owned;
	wait_queue_head_t wq;
} socket_lock_t;

typedef u64 netdev_features_t;

struct sock_cgroup_data {
	struct cgroup___2 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter;

struct socket_wq;

struct xfrm_policy;

struct socket;

struct sock_reuseport;

struct sock {
	struct sock_common __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head sk_error_queue;
	struct sk_buff *sk_rx_skb_cache;
	struct sk_buff_head sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff *head;
		struct sk_buff *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter *sk_filter;
	union {
		struct socket_wq *sk_wq;
		struct socket_wq *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff *sk_tx_skb_cache;
	struct sk_buff_head sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___2 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___2 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data sk_cgrp_data;
	struct mem_cgroup___2 *sk_memcg;
	void (*sk_state_change)(struct sock *);
	void (*sk_data_ready)(struct sock *);
	void (*sk_write_space)(struct sock *);
	void (*sk_error_report)(struct sock *);
	int (*sk_backlog_rcv)(struct sock *, struct sk_buff *);
	struct sk_buff * (*sk_validate_xmit_skb)(struct sock *, struct net_device *, struct sk_buff *);
	void (*sk_destruct)(struct sock *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___2;

struct attribute_group___2 {
	const char *name;
	umode_t (*is_visible)(struct kobject___2 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___2 *, struct bin_attribute___2 *, int);
	struct attribute **attrs;
	struct bin_attribute___2 **bin_attrs;
};

struct bin_attribute___2 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___2 * (*f_mapping)();
	ssize_t (*read)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, char *, loff_t, size_t);
	int (*mmap)(struct file___3 *, struct kobject___2 *, struct bin_attribute___2 *, struct vm_area_struct___3 *);
};

struct sysfs_ops___2 {
	ssize_t (*show)(struct kobject___2 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___2 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___2;

struct kset___2 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___2 kobj;
	const struct kset_uevent_ops___2 *uevent_ops;
};

struct kobj_type___2 {
	void (*release)(struct kobject___2 *);
	const struct sysfs_ops___2 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___2 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___2 *);
	const void * (*namespace)(struct kobject___2 *);
	void (*get_ownership)(struct kobject___2 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___2 {
	int (* const filter)(struct kset___2 *, struct kobject___2 *);
	const char * (* const name)(struct kset___2 *, struct kobject___2 *);
	int (* const uevent)(struct kset___2 *, struct kobject___2 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___2 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___2 *);
	int (*get)(char *, const struct kernel_param___2 *);
	void (*free)(void *);
};

struct kparam_array___2;

struct kernel_param___2 {
	const char *name;
	struct module___5 *mod;
	const struct kernel_param_ops___2 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___2 *arr;
	};
};

struct kparam_array___2 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___2 *ops;
	void *elem;
};

struct module_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___2 *, struct module_kobject___2 *, char *);
	ssize_t (*store)(struct module_attribute___2 *, struct module_kobject___2 *, const char *, size_t);
	void (*setup)(struct module___5 *, const char *);
	int (*test)(struct module___5 *);
	void (*free)(struct module___5 *);
};

struct trace_event_class___2;

struct trace_event_call___2 {
	struct list_head list;
	struct trace_event_class___2 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___2 *, struct perf_event___2 *);
};

typedef short unsigned int __kernel_sa_family_t;

typedef __kernel_sa_family_t sa_family_t;

struct sockaddr {
	sa_family_t sa_family;
	char sa_data[14];
};

struct msghdr {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___2 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___2 *msg_iocb;
};

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
} sync_serial_settings;

typedef struct {
	unsigned int clock_rate;
	unsigned int clock_type;
	short unsigned int loopback;
	unsigned int slot_map;
} te1_settings;

typedef struct {
	short unsigned int encoding;
	short unsigned int parity;
} raw_hdlc_proto;

typedef struct {
	unsigned int t391;
	unsigned int t392;
	unsigned int n391;
	unsigned int n392;
	unsigned int n393;
	short unsigned int lmi;
	short unsigned int dce;
} fr_proto;

typedef struct {
	unsigned int dlci;
} fr_proto_pvc;

typedef struct {
	unsigned int dlci;
	char master[16];
} fr_proto_pvc_info;

typedef struct {
	unsigned int interval;
	unsigned int timeout;
} cisco_proto;

typedef struct {
	short unsigned int dce;
	unsigned int modulo;
	unsigned int window;
	unsigned int t1;
	unsigned int t2;
	unsigned int n2;
} x25_hdlc_proto;

struct ifmap {
	long unsigned int mem_start;
	long unsigned int mem_end;
	short unsigned int base_addr;
	unsigned char irq;
	unsigned char dma;
	unsigned char port;
};

struct if_settings {
	unsigned int type;
	unsigned int size;
	union {
		raw_hdlc_proto *raw_hdlc;
		cisco_proto *cisco;
		fr_proto *fr;
		fr_proto_pvc *fr_pvc;
		fr_proto_pvc_info *fr_pvc_info;
		x25_hdlc_proto *x25;
		sync_serial_settings *sync;
		te1_settings *te1;
	} ifs_ifsu;
};

struct ifreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union {
		struct sockaddr ifru_addr;
		struct sockaddr ifru_dstaddr;
		struct sockaddr ifru_broadaddr;
		struct sockaddr ifru_netmask;
		struct sockaddr ifru_hwaddr;
		short int ifru_flags;
		int ifru_ivalue;
		int ifru_mtu;
		struct ifmap ifru_map;
		char ifru_slave[16];
		char ifru_newname[16];
		void *ifru_data;
		struct if_settings ifru_settings;
	} ifr_ifru;
};

struct tty_buffer {
	union {
		struct tty_buffer *next;
		struct llist_node free;
	};
	int used;
	int size;
	int commit;
	int read;
	int flags;
	long unsigned int data[0];
};

struct tty_bufhead {
	struct tty_buffer *head;
	struct work_struct work;
	struct mutex lock;
	atomic_t priority;
	struct tty_buffer sentinel;
	struct llist_head free;
	atomic_t mem_used;
	int mem_limit;
	struct tty_buffer *tail;
};

struct dev_pm_ops___2 {
	int (*prepare)(struct device___3 *);
	void (*complete)(struct device___3 *);
	int (*suspend)(struct device___3 *);
	int (*resume)(struct device___3 *);
	int (*freeze)(struct device___3 *);
	int (*thaw)(struct device___3 *);
	int (*poweroff)(struct device___3 *);
	int (*restore)(struct device___3 *);
	int (*suspend_late)(struct device___3 *);
	int (*resume_early)(struct device___3 *);
	int (*freeze_late)(struct device___3 *);
	int (*thaw_early)(struct device___3 *);
	int (*poweroff_late)(struct device___3 *);
	int (*restore_early)(struct device___3 *);
	int (*suspend_noirq)(struct device___3 *);
	int (*resume_noirq)(struct device___3 *);
	int (*freeze_noirq)(struct device___3 *);
	int (*thaw_noirq)(struct device___3 *);
	int (*poweroff_noirq)(struct device___3 *);
	int (*restore_noirq)(struct device___3 *);
	int (*runtime_suspend)(struct device___3 *);
	int (*runtime_resume)(struct device___3 *);
	int (*runtime_idle)(struct device___3 *);
};

struct wakeup_source___2 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___3 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___2 {
	struct dev_pm_ops___2 ops;
	int (*start)(struct device___3 *);
	void (*detach)(struct device___3 *, bool);
	int (*activate)(struct device___3 *);
	void (*sync)(struct device___3 *);
	void (*dismiss)(struct device___3 *);
};

struct bus_type___2 {
	const char *name;
	const char *dev_name;
	struct device___3 *dev_root;
	const struct attribute_group___2 **bus_groups;
	const struct attribute_group___2 **dev_groups;
	const struct attribute_group___2 **drv_groups;
	int (*match)(struct device___3 *, struct device_driver___2 *);
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	int (*probe)(struct device___3 *);
	void (*sync_state)(struct device___3 *);
	void (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*online)(struct device___3 *);
	int (*offline)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	int (*num_vf)(struct device___3 *);
	int (*dma_configure)(struct device___3 *);
	const struct dev_pm_ops___2 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___2 {
	const char *name;
	struct bus_type___2 *bus;
	struct module___5 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___3 *);
	void (*sync_state)(struct device___3 *);
	int (*remove)(struct device___3 *);
	void (*shutdown)(struct device___3 *);
	int (*suspend)(struct device___3 *, pm_message_t);
	int (*resume)(struct device___3 *);
	const struct attribute_group___2 **groups;
	const struct attribute_group___2 **dev_groups;
	const struct dev_pm_ops___2 *pm;
	void (*coredump)(struct device___3 *);
	struct driver_private *p;
};

struct device_type___2 {
	const char *name;
	const struct attribute_group___2 **groups;
	int (*uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___3 *);
	const struct dev_pm_ops___2 *pm;
};

struct class___2 {
	const char *name;
	struct module___5 *owner;
	const struct attribute_group___2 **class_groups;
	const struct attribute_group___2 **dev_groups;
	struct kobject___2 *dev_kobj;
	int (*dev_uevent)(struct device___3 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___3 *, umode_t *);
	void (*class_release)(struct class___2 *);
	void (*dev_release)(struct device___3 *);
	int (*shutdown_pre)(struct device___3 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___3 *);
	void (*get_ownership)(struct device___3 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___2 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___2;

struct fwnode_handle___2 {
	struct fwnode_handle___2 *secondary;
	const struct fwnode_operations___2 *ops;
	struct device___3 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___3 {
	void * (*start)(struct seq_file___4 *, loff_t *);
	void (*stop)(struct seq_file___4 *, void *);
	void * (*next)(struct seq_file___4 *, void *, loff_t *);
	int (*show)(struct seq_file___4 *, void *);
};

struct serial_icounter_struct;

struct serial_struct;

struct tty_operations {
	struct tty_struct___2 * (*lookup)(struct tty_driver *, struct file___3 *, int);
	int (*install)(struct tty_driver *, struct tty_struct___2 *);
	void (*remove)(struct tty_driver *, struct tty_struct___2 *);
	int (*open)(struct tty_struct___2 *, struct file___3 *);
	void (*close)(struct tty_struct___2 *, struct file___3 *);
	void (*shutdown)(struct tty_struct___2 *);
	void (*cleanup)(struct tty_struct___2 *);
	int (*write)(struct tty_struct___2 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___2 *, unsigned char);
	void (*flush_chars)(struct tty_struct___2 *);
	unsigned int (*write_room)(struct tty_struct___2 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___2 *);
	int (*ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___2 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	void (*throttle)(struct tty_struct___2 *);
	void (*unthrottle)(struct tty_struct___2 *);
	void (*stop)(struct tty_struct___2 *);
	void (*start)(struct tty_struct___2 *);
	void (*hangup)(struct tty_struct___2 *);
	int (*break_ctl)(struct tty_struct___2 *, int);
	void (*flush_buffer)(struct tty_struct___2 *);
	void (*set_ldisc)(struct tty_struct___2 *);
	void (*wait_until_sent)(struct tty_struct___2 *, int);
	void (*send_xchar)(struct tty_struct___2 *, char);
	int (*tiocmget)(struct tty_struct___2 *);
	int (*tiocmset)(struct tty_struct___2 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___2 *, struct winsize *);
	int (*get_icount)(struct tty_struct___2 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___2 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___2 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___2 *, struct seq_file___4 *);
	int (*poll_init)(struct tty_driver *, int, char *);
	int (*poll_get_char)(struct tty_driver *, int);
	void (*poll_put_char)(struct tty_driver *, int, char);
	int (*proc_show)(struct seq_file___4 *, void *);
};

struct tty_driver {
	int magic;
	struct kref kref;
	struct cdev___2 **cdevs;
	struct module___5 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver *other;
	struct tty_struct___2 **ttys;
	struct tty_port **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations;

struct tty_port_client_operations;

struct tty_port {
	struct tty_bufhead buf;
	struct tty_struct___2 *tty;
	struct tty_struct___2 *itty;
	const struct tty_port_operations *ops;
	const struct tty_port_client_operations *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___2 *);
	void (*close)(struct tty_struct___2 *);
	void (*flush_buffer)(struct tty_struct___2 *);
	ssize_t (*read)(struct tty_struct___2 *, struct file___3 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___2 *, struct file___3 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___2 *, struct file___3 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___2 *, struct file___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___2 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___2 *, struct file___3 *, struct poll_table_struct___2 *);
	int (*hangup)(struct tty_struct___2 *);
	void (*receive_buf)(struct tty_struct___2 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___2 *);
	void (*dcd_change)(struct tty_struct___2 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___2 *, const unsigned char *, const char *, int);
	struct module___5 *owner;
};

struct tty_ldisc {
	struct tty_ldisc_ops *ops;
	struct tty_struct___2 *tty;
};

struct tty_port_operations {
	int (*carrier_raised)(struct tty_port *);
	void (*dtr_rts)(struct tty_port *, int);
	void (*shutdown)(struct tty_port *);
	int (*activate)(struct tty_port *, struct tty_struct___2 *);
	void (*destruct)(struct tty_port *);
};

struct tty_port_client_operations {
	int (*receive_buf)(struct tty_port *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port *);
};

typedef struct {
	u64 key[2];
} siphash_key_t___2;

struct fqdir___2;

struct netns_ipv4___2 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___2 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___2 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___2 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff *);
	int (*local_out)(struct net___2 *, struct sock *, struct sk_buff *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___2 {
	struct dst_ops___2 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___2 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___2 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___2 *fqdir;
};

struct netns_xfrm___2 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___2 xfrm4_dst_ops;
	struct dst_ops___2 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___2 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___2 ipv4;
	struct netns_ipv6___2 ipv6;
	struct netns_ieee802154_lowpan___2 ieee802154_lowpan;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___2 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___3 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___3 *root_cset;
};

struct fwnode_reference_args___2;

struct fwnode_endpoint___2;

struct fwnode_operations___2 {
	struct fwnode_handle___2 * (*get)(struct fwnode_handle___2 *);
	void (*put)(struct fwnode_handle___2 *);
	bool (*device_is_available)(const struct fwnode_handle___2 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___2 *, const struct device___3 *);
	bool (*property_present)(const struct fwnode_handle___2 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___2 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___2 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___2 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_parent)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_next_child_node)(const struct fwnode_handle___2 *, struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*get_named_child_node)(const struct fwnode_handle___2 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___2 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___2 *);
	struct fwnode_handle___2 * (*graph_get_next_endpoint)(const struct fwnode_handle___2 *, struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*graph_get_remote_endpoint)(const struct fwnode_handle___2 *);
	struct fwnode_handle___2 * (*graph_get_port_parent)(struct fwnode_handle___2 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___2 *, struct fwnode_endpoint___2 *);
	int (*add_links)(struct fwnode_handle___2 *);
};

struct fwnode_endpoint___2 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___2 *local_fwnode;
};

struct fwnode_reference_args___2 {
	struct fwnode_handle___2 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef struct {
	local64_t v;
} u64_stats_t;

struct bpf_insn {
	__u8 code;
	__u8 dst_reg: 4;
	__u8 src_reg: 4;
	__s16 off;
	__s32 imm;
};

enum bpf_map_type {
	BPF_MAP_TYPE_UNSPEC = 0,
	BPF_MAP_TYPE_HASH = 1,
	BPF_MAP_TYPE_ARRAY = 2,
	BPF_MAP_TYPE_PROG_ARRAY = 3,
	BPF_MAP_TYPE_PERF_EVENT_ARRAY = 4,
	BPF_MAP_TYPE_PERCPU_HASH = 5,
	BPF_MAP_TYPE_PERCPU_ARRAY = 6,
	BPF_MAP_TYPE_STACK_TRACE = 7,
	BPF_MAP_TYPE_CGROUP_ARRAY = 8,
	BPF_MAP_TYPE_LRU_HASH = 9,
	BPF_MAP_TYPE_LRU_PERCPU_HASH = 10,
	BPF_MAP_TYPE_LPM_TRIE = 11,
	BPF_MAP_TYPE_ARRAY_OF_MAPS = 12,
	BPF_MAP_TYPE_HASH_OF_MAPS = 13,
	BPF_MAP_TYPE_DEVMAP = 14,
	BPF_MAP_TYPE_SOCKMAP = 15,
	BPF_MAP_TYPE_CPUMAP = 16,
	BPF_MAP_TYPE_XSKMAP = 17,
	BPF_MAP_TYPE_SOCKHASH = 18,
	BPF_MAP_TYPE_CGROUP_STORAGE = 19,
	BPF_MAP_TYPE_REUSEPORT_SOCKARRAY = 20,
	BPF_MAP_TYPE_PERCPU_CGROUP_STORAGE = 21,
	BPF_MAP_TYPE_QUEUE = 22,
	BPF_MAP_TYPE_STACK = 23,
	BPF_MAP_TYPE_SK_STORAGE = 24,
	BPF_MAP_TYPE_DEVMAP_HASH = 25,
	BPF_MAP_TYPE_STRUCT_OPS = 26,
	BPF_MAP_TYPE_RINGBUF = 27,
	BPF_MAP_TYPE_INODE_STORAGE = 28,
	BPF_MAP_TYPE_TASK_STORAGE = 29,
};

enum bpf_prog_type {
	BPF_PROG_TYPE_UNSPEC = 0,
	BPF_PROG_TYPE_SOCKET_FILTER = 1,
	BPF_PROG_TYPE_KPROBE = 2,
	BPF_PROG_TYPE_SCHED_CLS = 3,
	BPF_PROG_TYPE_SCHED_ACT = 4,
	BPF_PROG_TYPE_TRACEPOINT = 5,
	BPF_PROG_TYPE_XDP = 6,
	BPF_PROG_TYPE_PERF_EVENT = 7,
	BPF_PROG_TYPE_CGROUP_SKB = 8,
	BPF_PROG_TYPE_CGROUP_SOCK = 9,
	BPF_PROG_TYPE_LWT_IN = 10,
	BPF_PROG_TYPE_LWT_OUT = 11,
	BPF_PROG_TYPE_LWT_XMIT = 12,
	BPF_PROG_TYPE_SOCK_OPS = 13,
	BPF_PROG_TYPE_SK_SKB = 14,
	BPF_PROG_TYPE_CGROUP_DEVICE = 15,
	BPF_PROG_TYPE_SK_MSG = 16,
	BPF_PROG_TYPE_RAW_TRACEPOINT = 17,
	BPF_PROG_TYPE_CGROUP_SOCK_ADDR = 18,
	BPF_PROG_TYPE_LWT_SEG6LOCAL = 19,
	BPF_PROG_TYPE_LIRC_MODE2 = 20,
	BPF_PROG_TYPE_SK_REUSEPORT = 21,
	BPF_PROG_TYPE_FLOW_DISSECTOR = 22,
	BPF_PROG_TYPE_CGROUP_SYSCTL = 23,
	BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE = 24,
	BPF_PROG_TYPE_CGROUP_SOCKOPT = 25,
	BPF_PROG_TYPE_TRACING = 26,
	BPF_PROG_TYPE_STRUCT_OPS = 27,
	BPF_PROG_TYPE_EXT = 28,
	BPF_PROG_TYPE_LSM = 29,
	BPF_PROG_TYPE_SK_LOOKUP = 30,
	BPF_PROG_TYPE_SYSCALL = 31,
};

enum bpf_attach_type {
	BPF_CGROUP_INET_INGRESS = 0,
	BPF_CGROUP_INET_EGRESS = 1,
	BPF_CGROUP_INET_SOCK_CREATE = 2,
	BPF_CGROUP_SOCK_OPS = 3,
	BPF_SK_SKB_STREAM_PARSER = 4,
	BPF_SK_SKB_STREAM_VERDICT = 5,
	BPF_CGROUP_DEVICE = 6,
	BPF_SK_MSG_VERDICT = 7,
	BPF_CGROUP_INET4_BIND = 8,
	BPF_CGROUP_INET6_BIND = 9,
	BPF_CGROUP_INET4_CONNECT = 10,
	BPF_CGROUP_INET6_CONNECT = 11,
	BPF_CGROUP_INET4_POST_BIND = 12,
	BPF_CGROUP_INET6_POST_BIND = 13,
	BPF_CGROUP_UDP4_SENDMSG = 14,
	BPF_CGROUP_UDP6_SENDMSG = 15,
	BPF_LIRC_MODE2 = 16,
	BPF_FLOW_DISSECTOR = 17,
	BPF_CGROUP_SYSCTL = 18,
	BPF_CGROUP_UDP4_RECVMSG = 19,
	BPF_CGROUP_UDP6_RECVMSG = 20,
	BPF_CGROUP_GETSOCKOPT = 21,
	BPF_CGROUP_SETSOCKOPT = 22,
	BPF_TRACE_RAW_TP = 23,
	BPF_TRACE_FENTRY = 24,
	BPF_TRACE_FEXIT = 25,
	BPF_MODIFY_RETURN = 26,
	BPF_LSM_MAC = 27,
	BPF_TRACE_ITER = 28,
	BPF_CGROUP_INET4_GETPEERNAME = 29,
	BPF_CGROUP_INET6_GETPEERNAME = 30,
	BPF_CGROUP_INET4_GETSOCKNAME = 31,
	BPF_CGROUP_INET6_GETSOCKNAME = 32,
	BPF_XDP_DEVMAP = 33,
	BPF_CGROUP_INET_SOCK_RELEASE = 34,
	BPF_XDP_CPUMAP = 35,
	BPF_SK_LOOKUP = 36,
	BPF_XDP = 37,
	BPF_SK_SKB_VERDICT = 38,
	BPF_SK_REUSEPORT_SELECT = 39,
	BPF_SK_REUSEPORT_SELECT_OR_MIGRATE = 40,
	BPF_PERF_EVENT = 41,
	__MAX_BPF_ATTACH_TYPE = 42,
};

union bpf_attr {
	struct {
		__u32 map_type;
		__u32 key_size;
		__u32 value_size;
		__u32 max_entries;
		__u32 map_flags;
		__u32 inner_map_fd;
		__u32 numa_node;
		char map_name[16];
		__u32 map_ifindex;
		__u32 btf_fd;
		__u32 btf_key_type_id;
		__u32 btf_value_type_id;
		__u32 btf_vmlinux_value_type_id;
	};
	struct {
		__u32 map_fd;
		__u64 key;
		union {
			__u64 value;
			__u64 next_key;
		};
		__u64 flags;
	};
	struct {
		__u64 in_batch;
		__u64 out_batch;
		__u64 keys;
		__u64 values;
		__u32 count;
		__u32 map_fd;
		__u64 elem_flags;
		__u64 flags;
	} batch;
	struct {
		__u32 prog_type;
		__u32 insn_cnt;
		__u64 insns;
		__u64 license;
		__u32 log_level;
		__u32 log_size;
		__u64 log_buf;
		__u32 kern_version;
		__u32 prog_flags;
		char prog_name[16];
		__u32 prog_ifindex;
		__u32 expected_attach_type;
		__u32 prog_btf_fd;
		__u32 func_info_rec_size;
		__u64 func_info;
		__u32 func_info_cnt;
		__u32 line_info_rec_size;
		__u64 line_info;
		__u32 line_info_cnt;
		__u32 attach_btf_id;
		union {
			__u32 attach_prog_fd;
			__u32 attach_btf_obj_fd;
		};
		__u64 fd_array;
	};
	struct {
		__u64 pathname;
		__u32 bpf_fd;
		__u32 file_flags;
	};
	struct {
		__u32 target_fd;
		__u32 attach_bpf_fd;
		__u32 attach_type;
		__u32 attach_flags;
		__u32 replace_bpf_fd;
	};
	struct {
		__u32 prog_fd;
		__u32 retval;
		__u32 data_size_in;
		__u32 data_size_out;
		__u64 data_in;
		__u64 data_out;
		__u32 repeat;
		__u32 duration;
		__u32 ctx_size_in;
		__u32 ctx_size_out;
		__u64 ctx_in;
		__u64 ctx_out;
		__u32 flags;
		__u32 cpu;
	} test;
	struct {
		union {
			__u32 start_id;
			__u32 prog_id;
			__u32 map_id;
			__u32 btf_id;
			__u32 link_id;
		};
		__u32 next_id;
		__u32 open_flags;
	};
	struct {
		__u32 bpf_fd;
		__u32 info_len;
		__u64 info;
	} info;
	struct {
		__u32 target_fd;
		__u32 attach_type;
		__u32 query_flags;
		__u32 attach_flags;
		__u64 prog_ids;
		__u32 prog_cnt;
	} query;
	struct {
		__u64 name;
		__u32 prog_fd;
	} raw_tracepoint;
	struct {
		__u64 btf;
		__u64 btf_log_buf;
		__u32 btf_size;
		__u32 btf_log_size;
		__u32 btf_log_level;
	};
	struct {
		__u32 pid;
		__u32 fd;
		__u32 flags;
		__u32 buf_len;
		__u64 buf;
		__u32 prog_id;
		__u32 fd_type;
		__u64 probe_offset;
		__u64 probe_addr;
	} task_fd_query;
	struct {
		__u32 prog_fd;
		union {
			__u32 target_fd;
			__u32 target_ifindex;
		};
		__u32 attach_type;
		__u32 flags;
		union {
			__u32 target_btf_id;
			struct {
				__u64 iter_info;
				__u32 iter_info_len;
			};
			struct {
				__u64 bpf_cookie;
			} perf_event;
		};
	} link_create;
	struct {
		__u32 link_fd;
		__u32 new_prog_fd;
		__u32 flags;
		__u32 old_prog_fd;
	} link_update;
	struct {
		__u32 link_fd;
	} link_detach;
	struct {
		__u32 type;
	} enable_stats;
	struct {
		__u32 link_fd;
		__u32 flags;
	} iter_create;
	struct {
		__u32 prog_fd;
		__u32 map_fd;
		__u32 flags;
	} prog_bind_map;
};

struct bpf_func_info {
	__u32 insn_off;
	__u32 type_id;
};

struct bpf_line_info {
	__u32 insn_off;
	__u32 file_name_off;
	__u32 line_off;
	__u32 line_col;
};

struct dev_pagemap_ops___2 {
	void (*page_free)(struct page___4 *);
	void (*kill)(struct dev_pagemap___2 *);
	void (*cleanup)(struct dev_pagemap___2 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___2 *);
};

typedef struct {
	union {
		void *kernel;
		void *user;
	};
	bool is_kernel: 1;
	long: 63;
	long: 64;
} sockptr_t;

struct bpf_iter_aux_info;

typedef int (*bpf_iter_init_seq_priv_t)(void *, struct bpf_iter_aux_info *);

struct bpf_map;

struct bpf_iter_aux_info {
	struct bpf_map *map;
};

typedef void (*bpf_iter_fini_seq_priv_t)(void *);

struct bpf_iter_seq_info {
	const struct seq_operations___3 *seq_ops;
	bpf_iter_init_seq_priv_t init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct btf;

struct btf_type;

struct bpf_prog_aux;

struct bpf_local_storage_map;

struct bpf_verifier_env;

struct bpf_func_state;

struct bpf_map_ops {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map *, struct file___3 *);
	void (*map_free)(struct bpf_map *);
	int (*map_get_next_key)(struct bpf_map *, void *, void *);
	void (*map_release_uref)(struct bpf_map *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map *, void *);
	int (*map_lookup_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map *, void *);
	int (*map_update_elem)(struct bpf_map *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map *, void *);
	int (*map_push_elem)(struct bpf_map *, void *, u64);
	int (*map_pop_elem)(struct bpf_map *, void *);
	int (*map_peek_elem)(struct bpf_map *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map *, struct file___3 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map *, void *, struct seq_file___4 *);
	int (*map_check_btf)(const struct bpf_map *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map *, struct bpf_prog_aux *);
	void (*map_poke_untrack)(struct bpf_map *, struct bpf_prog_aux *);
	void (*map_poke_run)(struct bpf_map *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map *, u64, u32 *);
	int (*map_mmap)(struct bpf_map *, struct vm_area_struct___3 *);
	__poll_t (*map_poll)(struct bpf_map *, struct file___3 *, struct poll_table_struct___2 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map *, const struct bpf_map *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info *iter_seq_info;
};

struct bpf_map {
	const struct bpf_map_ops *ops;
	struct bpf_map *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct btf_header {
	__u16 magic;
	__u8 version;
	__u8 flags;
	__u32 hdr_len;
	__u32 type_off;
	__u32 type_len;
	__u32 str_off;
	__u32 str_len;
};

struct btf {
	void *data;
	struct btf_type **types;
	u32 *resolved_ids;
	u32 *resolved_sizes;
	const char *strings;
	void *nohdr_data;
	struct btf_header hdr;
	u32 nr_types;
	u32 types_size;
	u32 data_size;
	refcount_t refcnt;
	u32 id;
	struct callback_head rcu;
	struct btf *base_btf;
	u32 start_id;
	u32 start_str_off;
	char name[56];
	bool kernel_btf;
};

struct btf_type {
	__u32 name_off;
	__u32 info;
	union {
		__u32 size;
		__u32 type;
	};
};

struct bpf_ksym {
	long unsigned int start;
	long unsigned int end;
	char name[128];
	struct list_head lnode;
	struct latch_tree_node tnode;
	bool prog;
};

struct bpf_ctx_arg_aux;

struct bpf_trampoline;

struct bpf_jit_poke_descriptor;

struct bpf_kfunc_desc_tab;

struct bpf_prog_ops;

struct btf_mod_pair;

struct bpf_prog_offload;

struct bpf_func_info_aux;

struct bpf_prog_aux {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops *ops;
	struct bpf_map **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct sock_filter {
	__u16 code;
	__u8 jt;
	__u8 jf;
	__u32 k;
};

struct bpf_prog_stats;

struct sock_fprog_kern;

struct bpf_prog {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map;

struct bpf_map_dev_ops {
	int (*map_get_next_key)(struct bpf_offloaded_map *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map *, void *);
};

struct bpf_offloaded_map {
	struct bpf_map map;
	struct net_device *netdev;
	const struct bpf_map_dev_ops *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_stats {
	long unsigned int rx_packets;
	long unsigned int tx_packets;
	long unsigned int rx_bytes;
	long unsigned int tx_bytes;
	long unsigned int rx_errors;
	long unsigned int tx_errors;
	long unsigned int rx_dropped;
	long unsigned int tx_dropped;
	long unsigned int multicast;
	long unsigned int collisions;
	long unsigned int rx_length_errors;
	long unsigned int rx_over_errors;
	long unsigned int rx_crc_errors;
	long unsigned int rx_frame_errors;
	long unsigned int rx_fifo_errors;
	long unsigned int rx_missed_errors;
	long unsigned int tx_aborted_errors;
	long unsigned int tx_carrier_errors;
	long unsigned int tx_fifo_errors;
	long unsigned int tx_heartbeat_errors;
	long unsigned int tx_window_errors;
	long unsigned int rx_compressed;
	long unsigned int tx_compressed;
};

struct netdev_hw_addr_list {
	struct list_head list;
	int count;
	struct rb_root tree;
};

struct vlan_info;

struct tipc_bearer;

struct dn_dev;

struct wpan_dev;

struct mpls_dev;

struct mctp_dev;

enum rx_handler_result {
	RX_HANDLER_CONSUMED = 0,
	RX_HANDLER_ANOTHER = 1,
	RX_HANDLER_EXACT = 2,
	RX_HANDLER_PASS = 3,
};

typedef enum rx_handler_result rx_handler_result_t;

typedef rx_handler_result_t rx_handler_func_t(struct sk_buff **);

struct xdp_dev_bulk_queue;

enum netdev_ml_priv_type {
	ML_PRIV_NONE = 0,
	ML_PRIV_CAN = 1,
};

struct pcpu_dstats;

struct garp_port;

struct mrp_port;

struct netdev_tc_txq {
	u16 count;
	u16 offset;
};

struct macsec_ops;

struct udp_tunnel_nic;

struct bpf_xdp_link;

struct bpf_xdp_entity {
	struct bpf_prog *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node;

struct dev_ifalias;

struct net_device_ops;

struct iw_handler_def;

struct iw_public_data;

struct ethtool_ops;

struct l3mdev_ops;

struct ndisc_ops;

struct xfrmdev_ops;

struct tlsdev_ops;

struct header_ops;

struct dsa_port;

struct in_device;

struct inet6_dev;

struct wireless_dev;

struct netdev_rx_queue;

struct mini_Qdisc;

struct netdev_queue;

struct cpu_rmap;

struct Qdisc;

struct xps_dev_maps;

struct netpoll_info;

struct pcpu_lstats;

struct pcpu_sw_netstats;

struct rtnl_link_ops;

struct dcbnl_rtnl_ops;

struct netprio_map;

struct phy_device;

struct sfp_bus;

struct udp_tunnel_nic_info;

struct net_device {
	char name[16];
	struct netdev_name_node *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___2 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc *miniq_ingress;
	struct netdev_queue *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED = 0,
		NETREG_REGISTERED = 1,
		NETREG_UNREGISTERING = 2,
		NETREG_UNREGISTERED = 3,
		NETREG_RELEASED = 4,
		NETREG_DUMMY = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED = 0,
		RTNL_LINK_INITIALIZING = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device *);
	struct netpoll_info *npinfo;
	possible_net_t nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___3 dev;
	const struct attribute_group___2 *sysfs_groups[4];
	const struct attribute_group___2 *sysfs_rx_queue_group;
	const struct rtnl_link_ops *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity xdp_state[3];
	long: 64;
};

enum bpf_reg_type {
	NOT_INIT = 0,
	SCALAR_VALUE = 1,
	PTR_TO_CTX = 2,
	CONST_PTR_TO_MAP = 3,
	PTR_TO_MAP_VALUE = 4,
	PTR_TO_MAP_VALUE_OR_NULL = 5,
	PTR_TO_STACK = 6,
	PTR_TO_PACKET_META = 7,
	PTR_TO_PACKET = 8,
	PTR_TO_PACKET_END = 9,
	PTR_TO_FLOW_KEYS = 10,
	PTR_TO_SOCKET = 11,
	PTR_TO_SOCKET_OR_NULL = 12,
	PTR_TO_SOCK_COMMON = 13,
	PTR_TO_SOCK_COMMON_OR_NULL = 14,
	PTR_TO_TCP_SOCK = 15,
	PTR_TO_TCP_SOCK_OR_NULL = 16,
	PTR_TO_TP_BUFFER = 17,
	PTR_TO_XDP_SOCK = 18,
	PTR_TO_BTF_ID = 19,
	PTR_TO_BTF_ID_OR_NULL = 20,
	PTR_TO_MEM = 21,
	PTR_TO_MEM_OR_NULL = 22,
	PTR_TO_RDONLY_BUF = 23,
	PTR_TO_RDONLY_BUF_OR_NULL = 24,
	PTR_TO_RDWR_BUF = 25,
	PTR_TO_RDWR_BUF_OR_NULL = 26,
	PTR_TO_PERCPU_BTF_ID = 27,
	PTR_TO_FUNC = 28,
	PTR_TO_MAP_KEY = 29,
	__BPF_REG_TYPE_MAX = 30,
};

struct bpf_prog_ops {
	int (*test_run)(struct bpf_prog *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_offload_dev;

struct bpf_prog_offload {
	struct bpf_prog *prog;
	struct net_device *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct btf_func_model {
	u8 ret_size;
	u8 nr_args;
	u8 arg_size[12];
};

struct bpf_tramp_image {
	void *image;
	struct bpf_ksym ksym;
	struct percpu_ref pcref;
	void *ip_after_call;
	void *ip_epilogue;
	union {
		struct callback_head rcu;
		struct work_struct work;
	};
};

struct bpf_trampoline {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___5 *mod;
};

struct bpf_func_info_aux {
	u16 linkage;
	bool unreliable;
};

struct bpf_jit_poke_descriptor {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct bpf_ctx_arg_aux {
	u32 offset;
	enum bpf_reg_type reg_type;
	u32 btf_id;
};

struct btf_mod_pair {
	struct btf *btf;
	struct module___5 *module;
};

struct cftype___2;

struct cgroup_subsys___2 {
	struct cgroup_subsys_state___2 * (*css_alloc)(struct cgroup_subsys_state___2 *);
	int (*css_online)(struct cgroup_subsys_state___2 *);
	void (*css_offline)(struct cgroup_subsys_state___2 *);
	void (*css_released)(struct cgroup_subsys_state___2 *);
	void (*css_free)(struct cgroup_subsys_state___2 *);
	void (*css_reset)(struct cgroup_subsys_state___2 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___2 *, int);
	int (*css_extra_stat_show)(struct seq_file___4 *, struct cgroup_subsys_state___2 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___4 *, struct css_set___3 *);
	void (*cancel_fork)(struct task_struct___4 *, struct css_set___3 *);
	void (*fork)(struct task_struct___4 *);
	void (*exit)(struct task_struct___4 *);
	void (*release)(struct task_struct___4 *);
	void (*bind)(struct cgroup_subsys_state___2 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___2 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___2 *dfl_cftypes;
	struct cftype___2 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___2 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___2 *updated_children;
	struct cgroup___2 *updated_next;
};

struct cgroup_root___2 {
	struct kernfs_root___2 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___2 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___2 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___2 *ss;
	struct list_head node;
	struct kernfs_ops___2 *kf_ops;
	int (*open)(struct kernfs_open_file___2 *);
	void (*release)(struct kernfs_open_file___2 *);
	u64 (*read_u64)(struct cgroup_subsys_state___2 *, struct cftype___2 *);
	s64 (*read_s64)(struct cgroup_subsys_state___2 *, struct cftype___2 *);
	int (*seq_show)(struct seq_file___4 *, void *);
	void * (*seq_start)(struct seq_file___4 *, loff_t *);
	void * (*seq_next)(struct seq_file___4 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___4 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___2 *, struct cftype___2 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___2 *, struct cftype___2 *, s64);
	ssize_t (*write)(struct kernfs_open_file___2 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___2 *, struct poll_table_struct___2 *);
};

struct block_device_operations___2;

struct gendisk___2 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___3 *part0;
	const struct block_device_operations___2 *fops;
	struct request_queue___4 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___3 *bdi;
	struct kobject___2 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___2 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___2 {
	struct bio___2 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___2 *bip_vec;
	struct bio_vec___2 bip_inline_vecs[0];
};

struct blkcg___2;

struct blkg_policy_data___2;

struct blkcg_gq___2 {
	struct request_queue___4 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___2 *blkcg;
	struct blkcg_gq___2 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___2 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___3 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___2(struct request___2 *);

typedef void integrity_complete_fn___2(struct request___2 *, unsigned int);

struct blk_integrity_profile___2 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___2 *prepare_fn;
	integrity_complete_fn___2 *complete_fn;
	const char *name;
};

struct block_device_operations___2 {
	blk_qc_t (*submit_bio)(struct bio___2 *);
	int (*open)(struct block_device___3 *, fmode_t);
	void (*release)(struct gendisk___2 *, fmode_t);
	int (*rw_page)(struct block_device___3 *, sector_t, struct page___4 *, unsigned int);
	int (*ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___3 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___2 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___2 *);
	int (*getgeo)(struct block_device___3 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___3 *, bool);
	void (*swap_slot_free_notify)(struct block_device___3 *, long unsigned int);
	int (*report_zones)(struct gendisk___2 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___2 *, umode_t *);
	struct module___5 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___2 *, sector_t *);
};

struct scatterlist {
	long unsigned int page_link;
	unsigned int offset;
	unsigned int length;
	dma_addr_t dma_address;
	unsigned int dma_length;
};

typedef void rq_end_io_fn___2(struct request___2 *, blk_status_t);

struct request___2 {
	struct request_queue___4 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___2 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___2 *bio;
	struct bio___2 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___2 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___2 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___2 *saved_end_io;
		} flush;
	};
	struct gendisk___2 *rq_disk;
	struct block_device___3 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___2 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___2 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___4 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___2 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___3 *debugfs_dir;
	struct dentry___3 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___2;

struct elevator_mq_ops___2 {
	int (*init_sched)(struct request_queue___4 *, struct elevator_type___2 *);
	void (*exit_sched)(struct elevator_queue___2 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___2 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___2 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___2 *);
	bool (*allow_merge)(struct request_queue___4 *, struct request___2 *, struct bio___2 *);
	bool (*bio_merge)(struct request_queue___4 *, struct bio___2 *, unsigned int);
	int (*request_merge)(struct request_queue___4 *, struct request___2 **, struct bio___2 *);
	void (*request_merged)(struct request_queue___4 *, struct request___2 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___4 *, struct request___2 *, struct request___2 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___2 *);
	void (*finish_request)(struct request___2 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___2 *, struct list_head *, bool);
	struct request___2 * (*dispatch_request)(struct blk_mq_hw_ctx___2 *);
	bool (*has_work)(struct blk_mq_hw_ctx___2 *);
	void (*completed_request)(struct request___2 *, u64);
	void (*requeue_request)(struct request___2 *);
	struct request___2 * (*former_request)(struct request_queue___4 *, struct request___2 *);
	struct request___2 * (*next_request)(struct request_queue___4 *, struct request___2 *);
	void (*init_icq)(struct io_cq___2 *);
	void (*exit_icq)(struct io_cq___2 *);
};

struct elv_fs_entry___2;

struct elevator_type___2 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___2 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___2 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___5 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___2 {
	struct elevator_type___2 *type;
	void *elevator_data;
	struct kobject___2 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___2 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___2 *, char *);
	ssize_t (*store)(struct elevator_queue___2 *, const char *, size_t);
};

struct blk_mq_queue_data___2;

struct blk_mq_ops___2 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___2 *, const struct blk_mq_queue_data___2 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___2 *);
	int (*get_budget)(struct request_queue___4 *);
	void (*put_budget)(struct request_queue___4 *, int);
	void (*set_rq_budget_token)(struct request___2 *, int);
	int (*get_rq_budget_token)(struct request___2 *);
	enum blk_eh_timer_return (*timeout)(struct request___2 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___2 *);
	void (*complete)(struct request___2 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___2 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___2 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___2 *, struct request___2 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___2 *, struct request___2 *, unsigned int);
	void (*initialize_rq_fn)(struct request___2 *);
	void (*cleanup_rq)(struct request___2 *);
	bool (*busy)(struct request_queue___4 *);
	int (*map_queues)(struct blk_mq_tag_set___2 *);
	void (*show_rq)(struct seq_file___4 *, struct request___2 *);
};

struct blk_mq_tag_set___2 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___2 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___2 {
	struct request___2 *rq;
	bool last;
};

struct blkcg_policy_data___2;

struct blkcg___2 {
	struct cgroup_subsys_state___2 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___2 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___2 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___2 {
	struct blkcg___2 *blkcg;
	int plid;
};

struct blkg_policy_data___2 {
	struct blkcg_gq___2 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___2 {
	struct mem_cgroup___2 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___2 {
	struct lruvec___2 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___2 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___2 *memcg;
};

struct obj_cgroup___2 {
	struct percpu_ref refcnt;
	struct mem_cgroup___2 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum {
	Root_NFS = 255,
	Root_CIFS = 254,
	Root_RAM0 = 1048576,
	Root_RAM1 = 1048577,
	Root_FD0 = 2097152,
	Root_HDA1 = 3145729,
	Root_HDA2 = 3145730,
	Root_SDA1 = 8388609,
	Root_SDA2 = 8388610,
	Root_HDC1 = 23068673,
	Root_SR0 = 11534336,
};

struct fs_parameter___2 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___3 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___2 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___5 *owner;
	char *buffer[8];
};

struct fs_context_operations___2 {
	void (*free)(struct fs_context___2 *);
	int (*dup)(struct fs_context___2 *, struct fs_context___2 *);
	int (*parse_param)(struct fs_context___2 *, struct fs_parameter___2 *);
	int (*parse_monolithic)(struct fs_context___2 *, void *);
	int (*get_tree)(struct fs_context___2 *);
	int (*reconfigure)(struct fs_context___2 *);
};

struct flowi_tunnel {
	__be64 tun_id;
};

struct flowi_common {
	int flowic_oif;
	int flowic_iif;
	__u32 flowic_mark;
	__u8 flowic_tos;
	__u8 flowic_scope;
	__u8 flowic_proto;
	__u8 flowic_flags;
	__u32 flowic_secid;
	kuid_t flowic_uid;
	struct flowi_tunnel flowic_tun_key;
	__u32 flowic_multipath_hash;
};

union flowi_uli {
	struct {
		__be16 dport;
		__be16 sport;
	} ports;
	struct {
		__u8 type;
		__u8 code;
	} icmpt;
	struct {
		__le16 dport;
		__le16 sport;
	} dnports;
	__be32 gre_key;
	struct {
		__u8 type;
	} mht;
};

struct flowi4 {
	struct flowi_common __fl_common;
	__be32 saddr;
	__be32 daddr;
	union flowi_uli uli;
};

struct flowi6 {
	struct flowi_common __fl_common;
	struct in6_addr daddr;
	struct in6_addr saddr;
	__be32 flowlabel;
	union flowi_uli uli;
	__u32 mp_hash;
};

struct flowidn {
	struct flowi_common __fl_common;
	__le16 daddr;
	__le16 saddr;
	union flowi_uli uli;
};

struct flowi {
	union {
		struct flowi_common __fl_common;
		struct flowi4 ip4;
		struct flowi6 ip6;
		struct flowidn dn;
	} u;
};

struct icmpv6_mib_device {
	atomic_long_t mibs[6];
};

struct icmpv6msg_mib_device {
	atomic_long_t mibs[512];
};

struct inet_frags___2;

struct fqdir___2 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___2 *f;
	struct net___2 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___2;

struct inet_frags___2 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___2 *, const void *);
	void (*destructor)(struct inet_frag_queue___2 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___2 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff *fragments_tail;
	struct sk_buff *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___2 *fqdir;
	struct callback_head rcu;
};

struct fib_rule;

struct fib_lookup_arg;

struct fib_rule_hdr;

struct nlattr;

struct netlink_ext_ack;

struct nla_policy;

struct fib_rules_ops {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule *, struct flowi *, int, struct fib_lookup_arg *);
	bool (*suppress)(struct fib_rule *, int, struct fib_lookup_arg *);
	int (*match)(struct fib_rule *, struct flowi *, int);
	int (*configure)(struct fib_rule *, struct sk_buff *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule *);
	int (*compare)(struct fib_rule *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule *, struct sk_buff *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule *);
	void (*flush_cache)(struct fib_rules_ops *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___5 *owner;
	struct net___2 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___2 *);
	int (*fib_dump)(struct net___2 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___5 *owner;
	struct callback_head rcu;
};

struct hh_cache {
	unsigned int hh_len;
	seqlock_t hh_lock;
	long unsigned int hh_data[16];
};

struct neigh_table;

struct neigh_parms;

struct neigh_ops;

struct neighbour {
	struct neighbour *next;
	struct neigh_table *tbl;
	struct neigh_parms *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour *, struct sk_buff *);
	const struct neigh_ops *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device *dev;
	u8 primary_key[0];
};

struct ipv6_stable_secret {
	bool initialized;
	struct in6_addr secret;
};

struct ipv6_devconf {
	__s32 forwarding;
	__s32 hop_limit;
	__s32 mtu6;
	__s32 accept_ra;
	__s32 accept_redirects;
	__s32 autoconf;
	__s32 dad_transmits;
	__s32 rtr_solicits;
	__s32 rtr_solicit_interval;
	__s32 rtr_solicit_max_interval;
	__s32 rtr_solicit_delay;
	__s32 force_mld_version;
	__s32 mldv1_unsolicited_report_interval;
	__s32 mldv2_unsolicited_report_interval;
	__s32 use_tempaddr;
	__s32 temp_valid_lft;
	__s32 temp_prefered_lft;
	__s32 regen_max_retry;
	__s32 max_desync_factor;
	__s32 max_addresses;
	__s32 accept_ra_defrtr;
	__u32 ra_defrtr_metric;
	__s32 accept_ra_min_hop_limit;
	__s32 accept_ra_pinfo;
	__s32 ignore_routes_with_linkdown;
	__s32 accept_ra_rtr_pref;
	__s32 rtr_probe_interval;
	__s32 accept_ra_rt_info_min_plen;
	__s32 accept_ra_rt_info_max_plen;
	__s32 proxy_ndp;
	__s32 accept_source_route;
	__s32 accept_ra_from_local;
	atomic_t mc_forwarding;
	__s32 disable_ipv6;
	__s32 drop_unicast_in_l2_multicast;
	__s32 accept_dad;
	__s32 force_tllao;
	__s32 ndisc_notify;
	__s32 suppress_frag_ndisc;
	__s32 accept_ra_mtu;
	__s32 drop_unsolicited_na;
	struct ipv6_stable_secret stable_secret;
	__s32 use_oif_addrs_only;
	__s32 keep_addr_on_down;
	__s32 seg6_enabled;
	__s32 seg6_require_hmac;
	__u32 enhanced_dad;
	__u32 addr_gen_mode;
	__s32 disable_policy;
	__s32 ndisc_tclass;
	__s32 rpl_seg_enabled;
	__u32 ioam6_id;
	__u32 ioam6_id_wide;
	__u8 ioam6_enabled;
	struct ctl_table_header *sysctl_header;
};

typedef enum {
	SS_FREE = 0,
	SS_UNCONNECTED = 1,
	SS_CONNECTING = 2,
	SS_CONNECTED = 3,
	SS_DISCONNECTING = 4,
} socket_state;

struct socket_wq {
	wait_queue_head_t wait;
	struct fasync_struct___2 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops;

struct socket {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___3 *file;
	struct sock *sk;
	const struct proto_ops *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq wq;
};

typedef int (*sk_read_actor_t)(read_descriptor_t *, struct sk_buff *, unsigned int, size_t);

struct proto_ops {
	int family;
	struct module___5 *owner;
	int (*release)(struct socket *);
	int (*bind)(struct socket *, struct sockaddr *, int);
	int (*connect)(struct socket *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket *, struct socket *);
	int (*accept)(struct socket *, struct socket *, int, bool);
	int (*getname)(struct socket *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___3 *, struct socket *, struct poll_table_struct___2 *);
	int (*ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket *, void *, bool, bool);
	int (*listen)(struct socket *, int);
	int (*shutdown)(struct socket *, int);
	int (*setsockopt)(struct socket *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___4 *, struct socket *);
	int (*sendmsg)(struct socket *, struct msghdr *, size_t);
	int (*recvmsg)(struct socket *, struct msghdr *, size_t, int);
	int (*mmap)(struct file___3 *, struct socket *, struct vm_area_struct___3 *);
	ssize_t (*sendpage)(struct socket *, struct page___4 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock *, int);
	int (*peek_len)(struct socket *);
	int (*read_sock)(struct sock *, read_descriptor_t *, sk_read_actor_t);
	int (*sendpage_locked)(struct sock *, struct page___4 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock *, struct msghdr *, size_t);
	int (*set_rcvlowat)(struct sock *, int);
};

struct pipe_buf_operations___2;

struct pipe_buffer___2 {
	struct page___4 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___2 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___2 {
	int (*confirm)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
	void (*release)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
	bool (*try_steal)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
	bool (*get)(struct pipe_inode_info___2 *, struct pipe_buffer___2 *);
};

struct dql {
	unsigned int num_queued;
	unsigned int adj_limit;
	unsigned int last_obj_cnt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int limit;
	unsigned int num_completed;
	unsigned int prev_ovlimit;
	unsigned int prev_num_queued;
	unsigned int prev_last_obj_cnt;
	unsigned int lowest_slack;
	long unsigned int slack_start_time;
	unsigned int max_limit;
	unsigned int min_limit;
	unsigned int slack_hold_time;
	long: 32;
	long: 64;
	long: 64;
};

struct ieee_ets {
	__u8 willing;
	__u8 ets_cap;
	__u8 cbs;
	__u8 tc_tx_bw[8];
	__u8 tc_rx_bw[8];
	__u8 tc_tsa[8];
	__u8 prio_tc[8];
	__u8 tc_reco_bw[8];
	__u8 tc_reco_tsa[8];
	__u8 reco_prio_tc[8];
};

struct ieee_maxrate {
	__u64 tc_maxrate[8];
};

struct ieee_qcn {
	__u8 rpg_enable[8];
	__u32 rppp_max_rps[8];
	__u32 rpg_time_reset[8];
	__u32 rpg_byte_reset[8];
	__u32 rpg_threshold[8];
	__u32 rpg_max_rate[8];
	__u32 rpg_ai_rate[8];
	__u32 rpg_hai_rate[8];
	__u32 rpg_gd[8];
	__u32 rpg_min_dec_fac[8];
	__u32 rpg_min_rate[8];
	__u32 cndd_state_machine[8];
};

struct ieee_qcn_stats {
	__u64 rppp_rp_centiseconds[8];
	__u32 rppp_created_rps[8];
};

struct ieee_pfc {
	__u8 pfc_cap;
	__u8 pfc_en;
	__u8 mbc;
	__u16 delay;
	__u64 requests[8];
	__u64 indications[8];
};

struct dcbnl_buffer {
	__u8 prio2buffer[8];
	__u32 buffer_size[8];
	__u32 total_size;
};

struct cee_pg {
	__u8 willing;
	__u8 error;
	__u8 pg_en;
	__u8 tcs_supported;
	__u8 pg_bw[8];
	__u8 prio_pg[8];
};

struct cee_pfc {
	__u8 willing;
	__u8 error;
	__u8 pfc_en;
	__u8 tcs_supported;
};

struct dcb_app {
	__u8 selector;
	__u8 priority;
	__u16 protocol;
};

struct dcb_peer_app_info {
	__u8 willing;
	__u8 error;
};

struct dcbnl_rtnl_ops {
	int (*ieee_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device *);
	u8 (*setstate)(struct net_device *, u8);
	void (*getpermhwaddr)(struct net_device *, u8 *);
	void (*setpgtccfgtx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device *, int, u8);
	void (*setpgtccfgrx)(struct net_device *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device *, int, u8);
	void (*getpgtccfgtx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device *, int, u8 *);
	void (*setpfccfg)(struct net_device *, int, u8);
	void (*getpfccfg)(struct net_device *, int, u8 *);
	u8 (*setall)(struct net_device *);
	u8 (*getcap)(struct net_device *, int, u8 *);
	int (*getnumtcs)(struct net_device *, int, u8 *);
	int (*setnumtcs)(struct net_device *, int, u8);
	u8 (*getpfcstate)(struct net_device *);
	void (*setpfcstate)(struct net_device *, u8);
	void (*getbcncfg)(struct net_device *, int, u32 *);
	void (*setbcncfg)(struct net_device *, int, u32);
	void (*getbcnrp)(struct net_device *, int, u8 *);
	void (*setbcnrp)(struct net_device *, int, u8);
	int (*setapp)(struct net_device *, u8, u16, u8);
	int (*getapp)(struct net_device *, u8, u16);
	u8 (*getfeatcfg)(struct net_device *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device *, int, u8);
	u8 (*getdcbx)(struct net_device *);
	u8 (*setdcbx)(struct net_device *, u8);
	int (*peer_getappinfo)(struct net_device *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device *, struct dcbnl_buffer *);
};

struct netprio_map {
	struct callback_head rcu;
	u32 priomap_len;
	u32 priomap[0];
};

struct xdp_mem_info {
	u32 type;
	u32 id;
};

struct xdp_rxq_info {
	struct net_device *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info {
	struct net_device *dev;
};

struct xdp_buff {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info *rxq;
	struct xdp_txq_info *txq;
	u32 frame_sz;
};

struct xdp_frame {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device *dev_rx;
};

struct nlmsghdr {
	__u32 nlmsg_len;
	__u16 nlmsg_type;
	__u16 nlmsg_flags;
	__u32 nlmsg_seq;
	__u32 nlmsg_pid;
};

struct nlattr {
	__u16 nla_len;
	__u16 nla_type;
};

struct netlink_ext_ack {
	const char *_msg;
	const struct nlattr *bad_attr;
	const struct nla_policy *policy;
	u8 cookie[20];
	u8 cookie_len;
};

struct netlink_range_validation;

struct netlink_range_validation_signed;

struct nla_policy {
	u8 type;
	u8 validation_type;
	u16 len;
	union {
		const u32 bitfield32_valid;
		const u32 mask;
		const char *reject_message;
		const struct nla_policy *nested_policy;
		struct netlink_range_validation *range;
		struct netlink_range_validation_signed *range_signed;
		struct {
			s16 min;
			s16 max;
		};
		int (*validate)(const struct nlattr *, struct netlink_ext_ack *);
		u16 strict_start_type;
	};
};

struct netlink_callback {
	struct sk_buff *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff *, struct netlink_callback *);
	int (*done)(struct netlink_callback *);
	void *data;
	struct module___5 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ndmsg {
	__u8 ndm_family;
	__u8 ndm_pad1;
	__u16 ndm_pad2;
	__s32 ndm_ifindex;
	__u16 ndm_state;
	__u8 ndm_flags;
	__u8 ndm_type;
};

struct rtnl_link_stats64 {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 rx_errors;
	__u64 tx_errors;
	__u64 rx_dropped;
	__u64 tx_dropped;
	__u64 multicast;
	__u64 collisions;
	__u64 rx_length_errors;
	__u64 rx_over_errors;
	__u64 rx_crc_errors;
	__u64 rx_frame_errors;
	__u64 rx_fifo_errors;
	__u64 rx_missed_errors;
	__u64 tx_aborted_errors;
	__u64 tx_carrier_errors;
	__u64 tx_fifo_errors;
	__u64 tx_heartbeat_errors;
	__u64 tx_window_errors;
	__u64 rx_compressed;
	__u64 tx_compressed;
	__u64 rx_nohandler;
};

struct ifla_vf_guid {
	__u32 vf;
	__u64 guid;
};

struct ifla_vf_stats {
	__u64 rx_packets;
	__u64 tx_packets;
	__u64 rx_bytes;
	__u64 tx_bytes;
	__u64 broadcast;
	__u64 multicast;
	__u64 rx_dropped;
	__u64 tx_dropped;
};

struct ifla_vf_info {
	__u32 vf;
	__u8 mac[32];
	__u32 vlan;
	__u32 qos;
	__u32 spoofchk;
	__u32 linkstate;
	__u32 min_tx_rate;
	__u32 max_tx_rate;
	__u32 rss_query_en;
	__u32 trusted;
	__be16 vlan_proto;
};

struct tc_stats {
	__u64 bytes;
	__u32 packets;
	__u32 drops;
	__u32 overlimits;
	__u32 bps;
	__u32 pps;
	__u32 qlen;
	__u32 backlog;
};

struct tc_sizespec {
	unsigned char cell_log;
	unsigned char size_log;
	short int cell_align;
	int overhead;
	unsigned int linklayer;
	unsigned int mpu;
	unsigned int mtu;
	unsigned int tsize;
};

enum netdev_tx {
	__NETDEV_TX_MIN = 2147483648,
	NETDEV_TX_OK = 0,
	NETDEV_TX_BUSY = 16,
};

typedef enum netdev_tx netdev_tx_t;

struct header_ops {
	int (*create)(struct sk_buff *, struct net_device *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff *);
};

struct xsk_buff_pool;

struct netdev_queue {
	struct net_device *dev;
	struct Qdisc *qdisc;
	struct Qdisc *qdisc_sleeping;
	struct kobject___2 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head {
	struct sk_buff *head;
	struct sk_buff *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct gnet_stats_basic_packed {
	__u64 bytes;
	__u64 packets;
};

struct gnet_stats_queue {
	__u32 qlen;
	__u32 backlog;
	__u32 drops;
	__u32 requeues;
	__u32 overlimits;
};

struct Qdisc_ops;

struct qdisc_size_table;

struct net_rate_estimator;

struct gnet_stats_basic_cpu;

struct Qdisc {
	int (*enqueue)(struct sk_buff *, struct Qdisc *, struct sk_buff **);
	struct sk_buff * (*dequeue)(struct Qdisc *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head gso_skb;
	struct qdisc_skb_head q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc *next_sched;
	struct sk_buff_head skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct rps_map {
	unsigned int len;
	struct callback_head rcu;
	u16 cpus[0];
};

struct rps_dev_flow {
	u16 cpu;
	u16 filter;
	unsigned int last_qtail;
};

struct rps_dev_flow_table {
	unsigned int mask;
	struct callback_head rcu;
	struct rps_dev_flow flows[0];
};

struct netdev_rx_queue {
	struct xdp_rxq_info xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___2 kobj;
	struct net_device *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xps_map {
	unsigned int len;
	unsigned int alloc_len;
	struct callback_head rcu;
	u16 queues[0];
};

struct xps_dev_maps {
	struct callback_head rcu;
	unsigned int nr_ids;
	s16 num_tc;
	struct xps_map *attr_map[0];
};

struct netdev_fcoe_hbainfo {
	char manufacturer[64];
	char serial_number[64];
	char hardware_version[64];
	char driver_version[64];
	char optionrom_version[64];
	char firmware_version[64];
	char model[256];
	char model_description[256];
};

struct netdev_phys_item_id {
	unsigned char id[32];
	unsigned char id_len;
};

enum net_device_path_type {
	DEV_PATH_ETHERNET = 0,
	DEV_PATH_VLAN = 1,
	DEV_PATH_BRIDGE = 2,
	DEV_PATH_PPPOE = 3,
	DEV_PATH_DSA = 4,
};

struct net_device_path {
	enum net_device_path_type type;
	const struct net_device *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP = 0,
				DEV_PATH_BR_VLAN_TAG = 1,
				DEV_PATH_BR_VLAN_UNTAG = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx {
	const struct net_device *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

enum tc_setup_type {
	TC_SETUP_QDISC_MQPRIO = 0,
	TC_SETUP_CLSU32 = 1,
	TC_SETUP_CLSFLOWER = 2,
	TC_SETUP_CLSMATCHALL = 3,
	TC_SETUP_CLSBPF = 4,
	TC_SETUP_BLOCK = 5,
	TC_SETUP_QDISC_CBS = 6,
	TC_SETUP_QDISC_RED = 7,
	TC_SETUP_QDISC_PRIO = 8,
	TC_SETUP_QDISC_MQ = 9,
	TC_SETUP_QDISC_ETF = 10,
	TC_SETUP_ROOT_QDISC = 11,
	TC_SETUP_QDISC_GRED = 12,
	TC_SETUP_QDISC_TAPRIO = 13,
	TC_SETUP_FT = 14,
	TC_SETUP_QDISC_ETS = 15,
	TC_SETUP_QDISC_TBF = 16,
	TC_SETUP_QDISC_FIFO = 17,
	TC_SETUP_QDISC_HTB = 18,
};

enum bpf_netdev_command {
	XDP_SETUP_PROG = 0,
	XDP_SETUP_PROG_HW = 1,
	BPF_OFFLOAD_MAP_ALLOC = 2,
	BPF_OFFLOAD_MAP_FREE = 3,
	XDP_SETUP_XSK_POOL = 4,
};

struct netdev_bpf {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct dev_ifalias {
	struct callback_head rcuhead;
	char ifalias[0];
};

struct netdev_name_node {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device *dev;
	const char *name;
};

struct devlink_port;

struct ip_tunnel_parm;

struct net_device_ops {
	int (*ndo_init)(struct net_device *);
	void (*ndo_uninit)(struct net_device *);
	int (*ndo_open)(struct net_device *);
	int (*ndo_stop)(struct net_device *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff *, struct net_device *);
	netdev_features_t (*ndo_features_check)(struct sk_buff *, struct net_device *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device *, struct sk_buff *, struct net_device *);
	void (*ndo_change_rx_flags)(struct net_device *, int);
	void (*ndo_set_rx_mode)(struct net_device *);
	int (*ndo_set_mac_address)(struct net_device *, void *);
	int (*ndo_validate_addr)(struct net_device *);
	int (*ndo_do_ioctl)(struct net_device *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device *, int);
	int (*ndo_neigh_setup)(struct net_device *, struct neigh_parms *);
	void (*ndo_tx_timeout)(struct net_device *, unsigned int);
	void (*ndo_get_stats64)(struct net_device *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device *);
	int (*ndo_vlan_rx_add_vid)(struct net_device *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device *);
	int (*ndo_netpoll_setup)(struct net_device *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device *);
	int (*ndo_set_vf_mac)(struct net_device *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device *, int, bool);
	int (*ndo_get_vf_config)(struct net_device *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device *, int, int);
	int (*ndo_get_vf_stats)(struct net_device *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device *, int, struct sk_buff *);
	int (*ndo_get_vf_guid)(struct net_device *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device *, int, bool);
	int (*ndo_setup_tc)(struct net_device *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device *);
	int (*ndo_fcoe_disable)(struct net_device *);
	int (*ndo_fcoe_ddp_setup)(struct net_device *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device *, const struct sk_buff *, u16, u32);
	int (*ndo_add_slave)(struct net_device *, struct net_device *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device *, struct net_device *);
	struct net_device * (*ndo_get_xmit_slave)(struct net_device *, struct sk_buff *, bool);
	struct net_device * (*ndo_sk_get_lower_dev)(struct net_device *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device *, netdev_features_t);
	int (*ndo_set_features)(struct net_device *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff *, struct netlink_callback *, struct net_device *, struct net_device *, int *);
	int (*ndo_fdb_get)(struct sk_buff *, struct nlattr **, struct net_device *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff *, u32, u32, struct net_device *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device *, bool);
	int (*ndo_get_phys_port_id)(struct net_device *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device *, struct net_device *);
	void (*ndo_dfwd_del_station)(struct net_device *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device *, int, u32);
	int (*ndo_get_iflink)(const struct net_device *);
	int (*ndo_change_proto_down)(struct net_device *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device *, struct sk_buff *);
	void (*ndo_set_rx_headroom)(struct net_device *, int);
	int (*ndo_bpf)(struct net_device *, struct netdev_bpf *);
	int (*ndo_xdp_xmit)(struct net_device *, int, struct xdp_frame **, u32);
	struct net_device * (*ndo_xdp_get_xmit_slave)(struct net_device *, struct xdp_buff *);
	int (*ndo_xsk_wakeup)(struct net_device *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device *);
	int (*ndo_tunnel_ctl)(struct net_device *, struct ip_tunnel_parm *, int);
	struct net_device * (*ndo_get_peer_dev)(struct net_device *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx *, struct net_device_path *);
};

struct neigh_parms {
	possible_net_t net;
	struct net_device *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour *);
	struct neigh_table *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct pcpu_lstats {
	u64_stats_t packets;
	u64_stats_t bytes;
	struct u64_stats_sync syncp;
};

struct pcpu_sw_netstats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
};

struct net_device___3;

struct iw_request_info;

union iwreq_data;

typedef int (*iw_handler)(struct net_device___3 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_priv_args;

struct iw_statistics;

struct iw_handler_def {
	const iw_handler *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___3 *);
};

enum ethtool_phys_id_state {
	ETHTOOL_ID_INACTIVE = 0,
	ETHTOOL_ID_ACTIVE = 1,
	ETHTOOL_ID_ON = 2,
	ETHTOOL_ID_OFF = 3,
};

struct net_device___4;

struct ethtool_drvinfo;

struct ethtool_regs;

struct ethtool_wolinfo;

struct ethtool_link_ext_state_info;

struct ethtool_eeprom;

struct ethtool_coalesce;

struct kernel_ethtool_coalesce;

struct ethtool_ringparam;

struct ethtool_pause_stats;

struct ethtool_pauseparam;

struct ethtool_test;

struct ethtool_stats;

struct ethtool_rxnfc;

struct ethtool_flash;

struct ethtool_channels;

struct ethtool_dump;

struct ethtool_ts_info;

struct ethtool_modinfo;

struct ethtool_eee;

struct ethtool_tunable;

struct ethtool_link_ksettings;

struct ethtool_fec_stats;

struct ethtool_fecparam;

struct ethtool_module_eeprom;

struct ethtool_eth_phy_stats;

struct ethtool_eth_mac_stats;

struct ethtool_eth_ctrl_stats;

struct ethtool_rmon_stats;

struct ethtool_rmon_hist_range;

struct ethtool_ops {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___4 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___4 *);
	void (*get_regs)(struct net_device___4 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___4 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___4 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___4 *);
	void (*set_msglevel)(struct net_device___4 *, u32);
	int (*nway_reset)(struct net_device___4 *);
	u32 (*get_link)(struct net_device___4 *);
	int (*get_link_ext_state)(struct net_device___4 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___4 *);
	int (*get_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___4 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___4 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___4 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___4 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___4 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___4 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___4 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___4 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___4 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___4 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___4 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___4 *);
	void (*complete)(struct net_device___4 *);
	u32 (*get_priv_flags)(struct net_device___4 *);
	int (*set_priv_flags)(struct net_device___4 *, u32);
	int (*get_sset_count)(struct net_device___4 *, int);
	int (*get_rxnfc)(struct net_device___4 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___4 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___4 *, struct ethtool_flash *);
	int (*reset)(struct net_device___4 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___4 *);
	u32 (*get_rxfh_indir_size)(struct net_device___4 *);
	int (*get_rxfh)(struct net_device___4 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___4 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___4 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___4 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___4 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___4 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___4 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___4 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___4 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___4 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___4 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___4 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___4 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___4 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___4 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___4 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___4 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___4 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___4 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___4 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___4 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___4 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___4 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___4 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___4 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___4 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___4 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___4 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___4 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___4 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops {
	u32 (*l3mdev_fib_table)(const struct net_device *);
	struct sk_buff * (*l3mdev_l3_rcv)(struct net_device *, struct sk_buff *, u16);
	struct sk_buff * (*l3mdev_l3_out)(struct net_device *, struct sock *, struct sk_buff *, u16);
	struct dst_entry * (*l3mdev_link_scope_lookup)(const struct net_device *, struct flowi6 *);
};

struct nd_opt_hdr;

struct ndisc_options;

struct prefix_info;

struct ndisc_ops {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device *, struct neighbour *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device *, u8, struct neighbour *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device *, struct sk_buff *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___2 *, struct net_device *, const struct prefix_info *, struct inet6_dev *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

enum tls_offload_ctx_dir {
	TLS_OFFLOAD_CTX_DIR_RX = 0,
	TLS_OFFLOAD_CTX_DIR_TX = 1,
};

struct net_device___5;

struct sock___3;

struct tls_crypto_info;

struct tls_context;

struct tlsdev_ops {
	int (*tls_dev_add)(struct net_device___5 *, struct sock___3 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___5 *, struct tls_context *, enum tls_offload_ctx_dir);
	int (*tls_dev_resync)(struct net_device___5 *, struct sock___3 *, u32, u8 *, enum tls_offload_ctx_dir);
};

struct ipv6_devstat {
	struct proc_dir_entry *proc_dir_entry;
	struct ipstats_mib *ipv6;
	struct icmpv6_mib_device *icmpv6dev;
	struct icmpv6msg_mib_device *icmpv6msgdev;
};

struct ifmcaddr6;

struct ifacaddr6;

struct inet6_dev {
	struct net_device *dev;
	struct list_head addr_list;
	struct ifmcaddr6 *mc_list;
	struct ifmcaddr6 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head mc_query_queue;
	struct sk_buff_head mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto;

struct tcf_block;

struct mini_Qdisc {
	struct tcf_proto *filter_list;
	struct tcf_block *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___2 *, struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device *, struct list_head *);
	size_t (*get_size)(const struct net_device *);
	int (*fill_info)(struct sk_buff *, const struct net_device *);
	size_t (*get_xstats_size)(const struct net_device *);
	int (*fill_xstats)(struct sk_buff *, const struct net_device *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device *, struct net_device *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device *, const struct net_device *);
	int (*fill_slave_info)(struct sk_buff *, const struct net_device *, const struct net_device *);
	struct net___2 * (*get_link_net)(const struct net_device *);
	size_t (*get_linkxstats_size)(const struct net_device *, int);
	int (*fill_linkxstats)(struct sk_buff *, const struct net_device *, int *, int);
};

struct udp_tunnel_nic_table_info {
	unsigned int n_entries;
	unsigned int tunnel_types;
};

struct net_device___6;

struct udp_tunnel_info;

struct udp_tunnel_nic_shared;

struct udp_tunnel_nic_info {
	int (*set_port)(struct net_device___6 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	int (*unset_port)(struct net_device___6 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	int (*sync_table)(struct net_device___6 *, unsigned int);
	struct udp_tunnel_nic_shared *shared;
	unsigned int flags;
	struct udp_tunnel_nic_table_info tables[4];
};

enum {
	RTAX_UNSPEC = 0,
	RTAX_LOCK = 1,
	RTAX_MTU = 2,
	RTAX_WINDOW = 3,
	RTAX_RTT = 4,
	RTAX_RTTVAR = 5,
	RTAX_SSTHRESH = 6,
	RTAX_CWND = 7,
	RTAX_ADVMSS = 8,
	RTAX_REORDERING = 9,
	RTAX_HOPLIMIT = 10,
	RTAX_INITCWND = 11,
	RTAX_FEATURES = 12,
	RTAX_RTO_MIN = 13,
	RTAX_INITRWND = 14,
	RTAX_QUICKACK = 15,
	RTAX_CC_ALGO = 16,
	RTAX_FASTOPEN_NO_COOKIE = 17,
	__RTAX_MAX = 18,
};

struct tcmsg {
	unsigned char tcm_family;
	unsigned char tcm__pad1;
	short unsigned int tcm__pad2;
	int tcm_ifindex;
	__u32 tcm_handle;
	__u32 tcm_parent;
	__u32 tcm_info;
};

struct gnet_stats_basic_cpu {
	struct gnet_stats_basic_packed bstats;
	struct u64_stats_sync syncp;
};

struct gnet_dump {
	spinlock_t *lock;
	struct sk_buff *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct netlink_range_validation {
	u64 min;
	u64 max;
};

struct netlink_range_validation_signed {
	s64 min;
	s64 max;
};

enum flow_action_hw_stats_bit {
	FLOW_ACTION_HW_STATS_IMMEDIATE_BIT = 0,
	FLOW_ACTION_HW_STATS_DELAYED_BIT = 1,
	FLOW_ACTION_HW_STATS_DISABLED_BIT = 2,
	FLOW_ACTION_HW_STATS_NUM_BITS = 3,
};

struct flow_block {
	struct list_head cb_list;
};

typedef int flow_setup_cb_t(enum tc_setup_type, void *, void *);

struct qdisc_size_table {
	struct callback_head rcu;
	struct list_head list;
	struct tc_sizespec szopts;
	int refcnt;
	u16 data[0];
};

struct Qdisc_class_ops;

struct Qdisc_ops {
	struct Qdisc_ops *next;
	const struct Qdisc_class_ops *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff *, struct Qdisc *, struct sk_buff **);
	struct sk_buff * (*dequeue)(struct Qdisc *);
	struct sk_buff * (*peek)(struct Qdisc *);
	int (*init)(struct Qdisc *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc *);
	void (*destroy)(struct Qdisc *);
	int (*change)(struct Qdisc *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc *);
	int (*change_tx_queue_len)(struct Qdisc *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc *, unsigned int);
	int (*dump)(struct Qdisc *, struct sk_buff *);
	int (*dump_stats)(struct Qdisc *, struct gnet_dump *);
	void (*ingress_block_set)(struct Qdisc *, u32);
	void (*egress_block_set)(struct Qdisc *, u32);
	u32 (*ingress_block_get)(struct Qdisc *);
	u32 (*egress_block_get)(struct Qdisc *);
	struct module___5 *owner;
};

struct qdisc_walker;

struct Qdisc_class_ops {
	unsigned int flags;
	struct netdev_queue * (*select_queue)(struct Qdisc *, struct tcmsg *);
	int (*graft)(struct Qdisc *, long unsigned int, struct Qdisc *, struct Qdisc **, struct netlink_ext_ack *);
	struct Qdisc * (*leaf)(struct Qdisc *, long unsigned int);
	void (*qlen_notify)(struct Qdisc *, long unsigned int);
	long unsigned int (*find)(struct Qdisc *, u32);
	int (*change)(struct Qdisc *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc *, struct qdisc_walker *);
	struct tcf_block * (*tcf_block)(struct Qdisc *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc *, long unsigned int);
	int (*dump)(struct Qdisc *, long unsigned int, struct sk_buff *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc *, long unsigned int, struct gnet_dump *);
};

struct tcf_chain;

struct tcf_block {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___2 *net;
	struct Qdisc *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result;

struct tcf_proto_ops;

struct tcf_proto {
	struct tcf_proto *next;
	void *root;
	int (*classify)(struct sk_buff *, const struct tcf_proto *, struct tcf_result *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops *ops;
	struct tcf_chain *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker;

struct tcf_proto_ops {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff *, const struct tcf_proto *, struct tcf_result *);
	int (*init)(struct tcf_proto *);
	void (*destroy)(struct tcf_proto *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto *, u32);
	void (*put)(struct tcf_proto *, void *);
	int (*change)(struct net___2 *, struct sk_buff *, struct tcf_proto *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto *);
	void (*walk)(struct tcf_proto *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto *, void *);
	void (*hw_del)(struct tcf_proto *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___2 *, struct tcf_chain *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___2 *, struct tcf_proto *, void *, struct sk_buff *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___2 *, struct tcf_proto *, void *, struct sk_buff *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff *, struct net___2 *, void *);
	struct module___5 *owner;
	int flags;
};

struct tcf_chain {
	struct mutex filter_chain_lock;
	struct tcf_proto *filter_chain;
	struct list_head list;
	struct tcf_block *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sock_fprog_kern {
	u16 len;
	struct sock_filter *filter;
};

struct bpf_prog_stats {
	u64_stats_t cnt;
	u64_stats_t nsecs;
	u64_stats_t misses;
	struct u64_stats_sync syncp;
	long: 64;
};

struct sk_filter {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog *prog;
};

enum {
	NEIGH_VAR_MCAST_PROBES = 0,
	NEIGH_VAR_UCAST_PROBES = 1,
	NEIGH_VAR_APP_PROBES = 2,
	NEIGH_VAR_MCAST_REPROBES = 3,
	NEIGH_VAR_RETRANS_TIME = 4,
	NEIGH_VAR_BASE_REACHABLE_TIME = 5,
	NEIGH_VAR_DELAY_PROBE_TIME = 6,
	NEIGH_VAR_GC_STALETIME = 7,
	NEIGH_VAR_QUEUE_LEN_BYTES = 8,
	NEIGH_VAR_PROXY_QLEN = 9,
	NEIGH_VAR_ANYCAST_DELAY = 10,
	NEIGH_VAR_PROXY_DELAY = 11,
	NEIGH_VAR_LOCKTIME = 12,
	NEIGH_VAR_QUEUE_LEN = 13,
	NEIGH_VAR_RETRANS_TIME_MS = 14,
	NEIGH_VAR_BASE_REACHABLE_TIME_MS = 15,
	NEIGH_VAR_GC_INTERVAL = 16,
	NEIGH_VAR_GC_THRESH1 = 17,
	NEIGH_VAR_GC_THRESH2 = 18,
	NEIGH_VAR_GC_THRESH3 = 19,
	NEIGH_VAR_MAX = 20,
};

struct pneigh_entry;

struct neigh_statistics;

struct neigh_hash_table;

struct neigh_table {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device *, __u32 *);
	bool (*key_eq)(const struct neighbour *, const void *);
	int (*constructor)(struct neighbour *);
	int (*pconstructor)(struct pneigh_entry *);
	void (*pdestructor)(struct pneigh_entry *);
	void (*proxy_redo)(struct sk_buff *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table *nht;
	struct pneigh_entry **phash_buckets;
};

struct neigh_statistics {
	long unsigned int allocs;
	long unsigned int destroys;
	long unsigned int hash_grows;
	long unsigned int res_failed;
	long unsigned int lookups;
	long unsigned int hits;
	long unsigned int rcv_probes_mcast;
	long unsigned int rcv_probes_ucast;
	long unsigned int periodic_gc_runs;
	long unsigned int forced_gc_runs;
	long unsigned int unres_discards;
	long unsigned int table_fulls;
};

struct neigh_ops {
	int family;
	void (*solicit)(struct neighbour *, struct sk_buff *);
	void (*error_report)(struct neighbour *, struct sk_buff *);
	int (*output)(struct neighbour *, struct sk_buff *);
	int (*connected_output)(struct neighbour *, struct sk_buff *);
};

struct pneigh_entry {
	struct pneigh_entry *next;
	possible_net_t net;
	struct net_device *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table {
	struct neighbour **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

enum {
	TCP_ESTABLISHED = 1,
	TCP_SYN_SENT = 2,
	TCP_SYN_RECV = 3,
	TCP_FIN_WAIT1 = 4,
	TCP_FIN_WAIT2 = 5,
	TCP_TIME_WAIT = 6,
	TCP_CLOSE = 7,
	TCP_CLOSE_WAIT = 8,
	TCP_LAST_ACK = 9,
	TCP_LISTEN = 10,
	TCP_CLOSING = 11,
	TCP_NEW_SYN_RECV = 12,
	TCP_MAX_STATES = 13,
};

struct fib_rule_hdr {
	__u8 family;
	__u8 dst_len;
	__u8 src_len;
	__u8 tos;
	__u8 table;
	__u8 res1;
	__u8 res2;
	__u8 action;
	__u32 flags;
};

struct fib_rule_port_range {
	__u16 start;
	__u16 end;
};

struct fib_kuid_range {
	kuid_t start;
	kuid_t end;
};

struct fib_rule {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule *ctarget;
	struct net___2 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule *rule;
	u32 table;
	int flags;
};

struct smc_hashinfo;

struct sk_psock;

struct request_sock_ops;

struct timewait_sock_ops;

struct udp_table;

struct raw_hashinfo;

struct proto {
	void (*close)(struct sock *, long int);
	int (*pre_connect)(struct sock *, struct sockaddr *, int);
	int (*connect)(struct sock *, struct sockaddr *, int);
	int (*disconnect)(struct sock *, int);
	struct sock * (*accept)(struct sock *, int, int *, bool);
	int (*ioctl)(struct sock *, int, long unsigned int);
	int (*init)(struct sock *);
	void (*destroy)(struct sock *);
	void (*shutdown)(struct sock *, int);
	int (*setsockopt)(struct sock *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock *, int, int, char *, int *);
	void (*keepalive)(struct sock *, int);
	int (*compat_ioctl)(struct sock *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock *, struct msghdr *, size_t);
	int (*recvmsg)(struct sock *, struct msghdr *, size_t, int, int, int *);
	int (*sendpage)(struct sock *, struct page___4 *, int, size_t, int);
	int (*bind)(struct sock *, struct sockaddr *, int);
	int (*bind_add)(struct sock *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock *, struct sk_buff *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock *);
	int (*hash)(struct sock *);
	void (*unhash)(struct sock *);
	void (*rehash)(struct sock *);
	int (*get_port)(struct sock *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock *, int);
	bool (*sock_is_readable)(struct sock *);
	void (*enter_memory_pressure)(struct sock *);
	void (*leave_memory_pressure)(struct sock *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops *rsk_prot;
	struct timewait_sock_ops *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___5 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock *, int);
};

struct request_sock;

struct request_sock_ops {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock *, struct request_sock *);
	void (*send_ack)(const struct sock *, struct sk_buff *, struct request_sock *);
	void (*send_reset)(const struct sock *, struct sk_buff *);
	void (*destructor)(struct request_sock *);
	void (*syn_ack_timeout)(const struct request_sock *);
};

struct timewait_sock_ops {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock *, struct sock *, void *);
	void (*twsk_destructor)(struct sock *);
};

struct saved_syn;

struct request_sock {
	struct sock_common __req_common;
	struct request_sock *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops *rsk_ops;
	struct sock *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct saved_syn {
	u32 mac_hdrlen;
	u32 network_hdrlen;
	u32 tcp_hdrlen;
	u8 data[0];
};

enum tsq_enum {
	TSQ_THROTTLED = 0,
	TSQ_QUEUED = 1,
	TCP_TSQ_DEFERRED = 2,
	TCP_WRITE_TIMER_DEFERRED = 3,
	TCP_DELACK_TIMER_DEFERRED = 4,
	TCP_MTU_REDUCED_DEFERRED = 5,
};

struct ip6_sf_list {
	struct ip6_sf_list *sf_next;
	struct in6_addr sf_addr;
	long unsigned int sf_count[2];
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
	struct callback_head rcu;
};

struct ifmcaddr6 {
	struct in6_addr mca_addr;
	struct inet6_dev *idev;
	struct ifmcaddr6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6 {
	struct in6_addr aca_addr;
	struct fib6_info *aca_rt;
	struct ifacaddr6 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

enum {
	__ND_OPT_PREFIX_INFO_END = 0,
	ND_OPT_SOURCE_LL_ADDR = 1,
	ND_OPT_TARGET_LL_ADDR = 2,
	ND_OPT_PREFIX_INFO = 3,
	ND_OPT_REDIRECT_HDR = 4,
	ND_OPT_MTU = 5,
	ND_OPT_NONCE = 14,
	__ND_OPT_ARRAY_MAX = 15,
	ND_OPT_ROUTE_INFO = 24,
	ND_OPT_RDNSS = 25,
	ND_OPT_DNSSL = 31,
	ND_OPT_6CO = 34,
	ND_OPT_CAPTIVE_PORTAL = 37,
	ND_OPT_PREF64 = 38,
	__ND_OPT_MAX = 39,
};

struct nd_opt_hdr {
	__u8 nd_opt_type;
	__u8 nd_opt_len;
};

struct ndisc_options {
	struct nd_opt_hdr *nd_opt_array[15];
	struct nd_opt_hdr *nd_opts_ri;
	struct nd_opt_hdr *nd_opts_ri_end;
	struct nd_opt_hdr *nd_useropts;
	struct nd_opt_hdr *nd_useropts_end;
	struct nd_opt_hdr *nd_802154_opt_array[3];
};

struct prefix_info {
	__u8 type;
	__u8 length;
	__u8 prefix_len;
	__u8 reserved: 6;
	__u8 autoconf: 1;
	__u8 onlink: 1;
	__be32 valid;
	__be32 prefered;
	__be32 reserved2;
	struct in6_addr prefix;
};

enum nfs_opnum4 {
	OP_ACCESS = 3,
	OP_CLOSE = 4,
	OP_COMMIT = 5,
	OP_CREATE = 6,
	OP_DELEGPURGE = 7,
	OP_DELEGRETURN = 8,
	OP_GETATTR = 9,
	OP_GETFH = 10,
	OP_LINK = 11,
	OP_LOCK = 12,
	OP_LOCKT = 13,
	OP_LOCKU = 14,
	OP_LOOKUP = 15,
	OP_LOOKUPP = 16,
	OP_NVERIFY = 17,
	OP_OPEN = 18,
	OP_OPENATTR = 19,
	OP_OPEN_CONFIRM = 20,
	OP_OPEN_DOWNGRADE = 21,
	OP_PUTFH = 22,
	OP_PUTPUBFH = 23,
	OP_PUTROOTFH = 24,
	OP_READ = 25,
	OP_READDIR = 26,
	OP_READLINK = 27,
	OP_REMOVE = 28,
	OP_RENAME = 29,
	OP_RENEW = 30,
	OP_RESTOREFH = 31,
	OP_SAVEFH = 32,
	OP_SECINFO = 33,
	OP_SETATTR = 34,
	OP_SETCLIENTID = 35,
	OP_SETCLIENTID_CONFIRM = 36,
	OP_VERIFY = 37,
	OP_WRITE = 38,
	OP_RELEASE_LOCKOWNER = 39,
	OP_BACKCHANNEL_CTL = 40,
	OP_BIND_CONN_TO_SESSION = 41,
	OP_EXCHANGE_ID = 42,
	OP_CREATE_SESSION = 43,
	OP_DESTROY_SESSION = 44,
	OP_FREE_STATEID = 45,
	OP_GET_DIR_DELEGATION = 46,
	OP_GETDEVICEINFO = 47,
	OP_GETDEVICELIST = 48,
	OP_LAYOUTCOMMIT = 49,
	OP_LAYOUTGET = 50,
	OP_LAYOUTRETURN = 51,
	OP_SECINFO_NO_NAME = 52,
	OP_SEQUENCE = 53,
	OP_SET_SSV = 54,
	OP_TEST_STATEID = 55,
	OP_WANT_DELEGATION = 56,
	OP_DESTROY_CLIENTID = 57,
	OP_RECLAIM_COMPLETE = 58,
	OP_ALLOCATE = 59,
	OP_COPY = 60,
	OP_COPY_NOTIFY = 61,
	OP_DEALLOCATE = 62,
	OP_IO_ADVISE = 63,
	OP_LAYOUTERROR = 64,
	OP_LAYOUTSTATS = 65,
	OP_OFFLOAD_CANCEL = 66,
	OP_OFFLOAD_STATUS = 67,
	OP_READ_PLUS = 68,
	OP_SEEK = 69,
	OP_WRITE_SAME = 70,
	OP_CLONE = 71,
	OP_GETXATTR = 72,
	OP_SETXATTR = 73,
	OP_LISTXATTRS = 74,
	OP_REMOVEXATTR = 75,
	OP_ILLEGAL = 10044,
};

enum perf_branch_sample_type_shift {
	PERF_SAMPLE_BRANCH_USER_SHIFT = 0,
	PERF_SAMPLE_BRANCH_KERNEL_SHIFT = 1,
	PERF_SAMPLE_BRANCH_HV_SHIFT = 2,
	PERF_SAMPLE_BRANCH_ANY_SHIFT = 3,
	PERF_SAMPLE_BRANCH_ANY_CALL_SHIFT = 4,
	PERF_SAMPLE_BRANCH_ANY_RETURN_SHIFT = 5,
	PERF_SAMPLE_BRANCH_IND_CALL_SHIFT = 6,
	PERF_SAMPLE_BRANCH_ABORT_TX_SHIFT = 7,
	PERF_SAMPLE_BRANCH_IN_TX_SHIFT = 8,
	PERF_SAMPLE_BRANCH_NO_TX_SHIFT = 9,
	PERF_SAMPLE_BRANCH_COND_SHIFT = 10,
	PERF_SAMPLE_BRANCH_CALL_STACK_SHIFT = 11,
	PERF_SAMPLE_BRANCH_IND_JUMP_SHIFT = 12,
	PERF_SAMPLE_BRANCH_CALL_SHIFT = 13,
	PERF_SAMPLE_BRANCH_NO_FLAGS_SHIFT = 14,
	PERF_SAMPLE_BRANCH_NO_CYCLES_SHIFT = 15,
	PERF_SAMPLE_BRANCH_TYPE_SAVE_SHIFT = 16,
	PERF_SAMPLE_BRANCH_HW_INDEX_SHIFT = 17,
	PERF_SAMPLE_BRANCH_MAX_SHIFT = 18,
};

union perf_mem_data_src___2 {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_blk: 3;
		__u64 mem_rsvd: 21;
	};
};

union perf_sample_weight___2 {
	__u64 full;
	struct {
		__u32 var1_dw;
		__u16 var2_w;
		__u16 var3_w;
	};
};

struct perf_cpu_context___2;

struct perf_output_handle___2;

struct pmu___2 {
	struct list_head entry;
	struct module___5 *module;
	struct device___3 *dev;
	const struct attribute_group___2 **attr_groups;
	const struct attribute_group___2 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___2 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___2 *);
	void (*pmu_disable)(struct pmu___2 *);
	int (*event_init)(struct perf_event___2 *);
	void (*event_mapped)(struct perf_event___2 *, struct mm_struct___4 *);
	void (*event_unmapped)(struct perf_event___2 *, struct mm_struct___4 *);
	int (*add)(struct perf_event___2 *, int);
	void (*del)(struct perf_event___2 *, int);
	void (*start)(struct perf_event___2 *, int);
	void (*stop)(struct perf_event___2 *, int);
	void (*read)(struct perf_event___2 *);
	void (*start_txn)(struct pmu___2 *, unsigned int);
	int (*commit_txn)(struct pmu___2 *);
	void (*cancel_txn)(struct pmu___2 *);
	int (*event_idx)(struct perf_event___2 *);
	void (*sched_task)(struct perf_event_context___3 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___3 *, struct perf_event_context___3 *);
	void * (*setup_aux)(struct perf_event___2 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___2 *, struct perf_output_handle___2 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___2 *);
	int (*aux_output_match)(struct perf_event___2 *);
	int (*filter_match)(struct perf_event___2 *);
	int (*check_period)(struct perf_event___2 *, u64);
};

struct perf_cpu_context___2 {
	struct perf_event_context___3 ctx;
	struct perf_event_context___3 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___2 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___2 **heap;
	struct perf_event___2 *heap_default[2];
};

struct perf_output_handle___2 {
	struct perf_event___2 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_sample_data___2 {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	union perf_sample_weight___2 weight;
	long: 64;
	u64 txn;
	union perf_mem_data_src___2 data_src;
	long: 64;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	u64 aux_size;
	struct perf_regs regs_user;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	u64 cgroup;
	u64 data_page_size;
	u64 code_page_size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___2 {
	struct cgroup_subsys_state___2 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___2 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___2 *);
	};
};

struct trace_event_class___2 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___2 *, enum trace_reg, void *);
	struct trace_event_fields___2 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___2 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___2 *);
};

struct uuidcmp {
	const char *uuid;
	int len;
};

struct dentry___4;

struct super_block___4;

struct file_system_type___3 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___4 * (*mount)(struct file_system_type___3 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___4 *);
	struct module___2 *owner;
	struct file_system_type___3 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___4;

struct kiocb___3;

struct iov_iter___3;

struct poll_table_struct___3;

struct inode___5;

struct file_lock___3;

struct seq_file___5;

struct file_operations___3 {
	struct module___2 *owner;
	loff_t (*llseek)(struct file___4 *, loff_t, int);
	ssize_t (*read)(struct file___4 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___4 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___3 *, struct iov_iter___3 *);
	ssize_t (*write_iter)(struct kiocb___3 *, struct iov_iter___3 *);
	int (*iopoll)(struct kiocb___3 *, bool);
	int (*iterate)(struct file___4 *, struct dir_context *);
	int (*iterate_shared)(struct file___4 *, struct dir_context *);
	__poll_t (*poll)(struct file___4 *, struct poll_table_struct___3 *);
	long int (*unlocked_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___4 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___4 *, struct vm_area_struct___2 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___5 *, struct file___4 *);
	int (*flush)(struct file___4 *, fl_owner_t);
	int (*release)(struct inode___5 *, struct file___4 *);
	int (*fsync)(struct file___4 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___4 *, int);
	int (*lock)(struct file___4 *, int, struct file_lock___3 *);
	ssize_t (*sendpage)(struct file___4 *, struct page___3 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___4 *, long unsigned int);
	int (*flock)(struct file___4 *, int, struct file_lock___3 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___4 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___4 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___4 *, long int, struct file_lock___3 **, void **);
	long int (*fallocate)(struct file___4 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___5 *, struct file___4 *);
	ssize_t (*copy_file_range)(struct file___4 *, loff_t, struct file___4 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___4 *, loff_t, struct file___4 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___4 *, loff_t, loff_t, int);
};

struct vmacache___3 {
	u64 seqnum;
	struct vm_area_struct___2 *vmas[4];
};

struct page_frag___3 {
	struct page___3 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___3;

struct debug_info___3 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___3 *hbp_break[16];
	struct perf_event___3 *hbp_watch[16];
};

struct thread_struct___3 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___3 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct pid___3;

struct nsproxy___4;

struct signal_struct___4;

struct bio_list___4;

struct io_context___4;

struct css_set___4;

struct perf_event_context___4;

struct vm_struct___4;

struct task_struct___5 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___5 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___2 *mm;
	struct mm_struct___2 *active_mm;
	struct vmacache___3 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___5 *real_parent;
	struct task_struct___5 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___5 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___3 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___4 *nsproxy;
	struct signal_struct___4 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___5 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___4 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___4 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___4 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___3 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___5 *oom_reaper_list;
	struct vm_struct___4 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___3 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___3;

struct kobj_type___3;

struct kernfs_node___3;

struct kobject___3 {
	const char *name;
	struct list_head entry;
	struct kobject___3 *parent;
	struct kset___3 *kset;
	struct kobj_type___3 *ktype;
	struct kernfs_node___3 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___3 {
	struct kobject___3 kobj;
	struct module___2 *mod;
	struct kobject___3 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___3 {
	struct module___2 *mod;
	struct latch_tree_node node;
};

struct module_layout___3 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___3 mtn;
};

struct module_attribute___3;

struct kernel_param___3;

struct trace_event_call___3;

struct module___2 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___3 mkobj;
	struct module_attribute___3 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___3 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___3 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___3 core_layout;
	struct module_layout___3 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___3 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___3 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___5 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___3)(struct perf_event___3 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___3;

struct fasync_struct___3;

struct pid_namespace___3;

struct perf_cgroup___3;

struct perf_event___3 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___3 *group_leader;
	struct pmu___3 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___3 hw;
	struct perf_event_context___4 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___3 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___5 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___3 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___3 *aux_event;
	void (*destroy)(struct perf_event___3 *);
	struct callback_head callback_head;
	struct pid_namespace___3 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___3 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___3 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___3 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___3 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___3;

struct dentry___4 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___4 *d_parent;
	struct qstr d_name;
	struct inode___5 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___3 *d_op;
	struct super_block___4 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___3;

struct address_space___3 {
	struct inode___5 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___3 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___3;

struct bdi_writeback___3;

struct inode___5 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___3 *i_op;
	struct super_block___4 *i_sb;
	struct address_space___3 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___3 *i_fop;
		void (*free_inode)(struct inode___5 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___3 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___3;

struct path___3;

struct dentry_operations___3 {
	int (*d_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___4 *, unsigned int);
	int (*d_hash)(const struct dentry___4 *, struct qstr *);
	int (*d_compare)(const struct dentry___4 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___4 *);
	int (*d_init)(struct dentry___4 *);
	void (*d_release)(struct dentry___4 *);
	void (*d_prune)(struct dentry___4 *);
	void (*d_iput)(struct dentry___4 *, struct inode___5 *);
	char * (*d_dname)(struct dentry___4 *, char *, int);
	struct vfsmount___3 * (*d_automount)(struct path___3 *);
	int (*d_manage)(const struct path___3 *, bool);
	struct dentry___4 * (*d_real)(struct dentry___4 *, const struct inode___5 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___3;

struct mem_dqinfo___3 {
	struct quota_format_type___3 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___3;

struct quota_info___3 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___5 *files[3];
	struct mem_dqinfo___3 info[3];
	const struct quota_format_ops___3 *ops[3];
};

struct rcuwait___3 {
	struct task_struct___5 *task;
};

struct percpu_rw_semaphore___3 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___3 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___3 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___3 rw_sem[3];
};

struct super_operations___3;

struct dquot_operations___3;

struct quotactl_ops___3;

struct block_device___4;

struct super_block___4 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___3 *s_type;
	const struct super_operations___3 *s_op;
	const struct dquot_operations___3 *dq_op;
	const struct quotactl_ops___3 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___4 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___4 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___3 s_dquot;
	struct sb_writers___3 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___3 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___3 {
	struct dentry___4 *mnt_root;
	struct super_block___4 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___3 {
	struct vfsmount___3 *mnt;
	struct dentry___4 *dentry;
};

struct upid___3 {
	int nr;
	struct pid_namespace___3 *ns;
};

struct pid_namespace___3 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___5 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___3 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___3 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___3 numbers[1];
};

typedef struct page___3 *pgtable_t___3;

struct dev_pagemap___3;

struct page___3 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___3 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___3 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___3 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___2 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___3 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___3;

struct vm_area_struct___2 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___2 *vm_next;
	struct vm_area_struct___2 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___2 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___3 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___4 *vm_file;
	struct file___4 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___4 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___5 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___5 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___3 *pids[4];
	struct pid___3 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___2 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___3;

struct mm_struct___2 {
	struct {
		struct vm_area_struct___2 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___4 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___3 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___5 *owner;
		struct user_namespace *user_ns;
		struct file___4 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___4;

struct nsproxy___4 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___3 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___4 *cgroup_ns;
};

struct bio___3;

struct bio_list___4 {
	struct bio___3 *head;
	struct bio___3 *tail;
};

struct io_cq___3;

struct io_context___4 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___3 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___3;

struct cgroup___3;

struct css_set___4 {
	struct cgroup_subsys_state___3 *subsys[14];
	refcount_t refcount;
	struct css_set___4 *dom_cset;
	struct cgroup___3 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___3 *mg_src_cgrp;
	struct cgroup___3 *mg_dst_cgrp;
	struct css_set___4 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___4 {
	struct pmu___3 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___5 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___4 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___3;

struct blk_integrity___3 {
	const struct blk_integrity_profile___3 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___3 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___4 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___3;

struct elevator_queue___3;

struct blk_mq_ops___3;

struct blk_mq_hw_ctx___3;

struct gendisk___3;

struct blkcg_gq___3;

struct blk_mq_tag_set___3;

struct request_queue___3 {
	struct request___3 *last_merge;
	struct elevator_queue___3 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___3 *disk;
	struct kobject___3 kobj;
	struct kobject___3 *mq_kobj;
	struct blk_integrity___3 integrity;
	struct device___2 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___3 bio_split;
	struct dentry___4 *debugfs_dir;
	struct dentry___4 *sched_debugfs_dir;
	struct dentry___4 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___4 {
	struct vm_struct___4 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___3 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___3;

struct dev_pagemap___3 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___3 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___3 {
	rwlock_t lock;
	struct pid___3 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___4 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___3 f_path;
	struct inode___5 *f_inode;
	const struct file_operations___3 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___3 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___3 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___3;

struct vm_operations_struct___3 {
	void (*open)(struct vm_area_struct___2 *);
	void (*close)(struct vm_area_struct___2 *);
	int (*may_split)(struct vm_area_struct___2 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___2 *);
	int (*mprotect)(struct vm_area_struct___2 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___3 *);
	vm_fault_t (*huge_fault)(struct vm_fault___3 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___3 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___2 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___3 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___3 *);
	int (*access)(struct vm_area_struct___2 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___2 *);
	int (*set_policy)(struct vm_area_struct___2 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___2 *, long unsigned int);
	struct page___3 * (*find_special_page)(struct vm_area_struct___2 *, long unsigned int);
};

struct core_thread___3 {
	struct task_struct___5 *task;
	struct core_thread___3 *next;
};

struct core_state___3 {
	atomic_t nr_threads;
	struct core_thread___3 dumper;
	struct completion startup;
};

struct vm_fault___3 {
	const struct {
		struct vm_area_struct___2 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___3 *cow_page;
	struct page___3 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___3 prealloc_pte;
};

struct cgroup_subsys___3;

struct cgroup_subsys_state___3 {
	struct cgroup___3 *cgroup;
	struct cgroup_subsys___3 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___3 *parent;
};

struct cgroup_file___3 {
	struct kernfs_node___3 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___3 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___5 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___3;

struct cgroup_rstat_cpu___3;

struct cgroup___3 {
	struct cgroup_subsys_state___3 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___3 *kn;
	struct cgroup_file___3 procs_file;
	struct cgroup_file___3 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___3 *subsys[14];
	struct cgroup_root___3 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___3 *dom_cgrp;
	struct cgroup___3 *old_dom_cgrp;
	struct cgroup_rstat_cpu___3 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___3 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___3 {
	struct request_queue___3 *q;
	struct io_context___4 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___3 {
	struct file___4 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___3 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___4 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___4 *ia_file;
};

struct dquot___3 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___4 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___3 {
	int qf_fmt_id;
	const struct quota_format_ops___3 *qf_ops;
	struct module___2 *qf_owner;
	struct quota_format_type___3 *qf_next;
};

struct quota_format_ops___3 {
	int (*check_quota_file)(struct super_block___4 *, int);
	int (*read_file_info)(struct super_block___4 *, int);
	int (*write_file_info)(struct super_block___4 *, int);
	int (*free_file_info)(struct super_block___4 *, int);
	int (*read_dqblk)(struct dquot___3 *);
	int (*commit_dqblk)(struct dquot___3 *);
	int (*release_dqblk)(struct dquot___3 *);
	int (*get_next_id)(struct super_block___4 *, struct kqid *);
};

struct dquot_operations___3 {
	int (*write_dquot)(struct dquot___3 *);
	struct dquot___3 * (*alloc_dquot)(struct super_block___4 *, int);
	void (*destroy_dquot)(struct dquot___3 *);
	int (*acquire_dquot)(struct dquot___3 *);
	int (*release_dquot)(struct dquot___3 *);
	int (*mark_dirty)(struct dquot___3 *);
	int (*write_info)(struct super_block___4 *, int);
	qsize_t * (*get_reserved_space)(struct inode___5 *);
	int (*get_projid)(struct inode___5 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___5 *, qsize_t *);
	int (*get_next_id)(struct super_block___4 *, struct kqid *);
};

struct quotactl_ops___3 {
	int (*quota_on)(struct super_block___4 *, int, int, const struct path___3 *);
	int (*quota_off)(struct super_block___4 *, int);
	int (*quota_enable)(struct super_block___4 *, unsigned int);
	int (*quota_disable)(struct super_block___4 *, unsigned int);
	int (*quota_sync)(struct super_block___4 *, int);
	int (*set_info)(struct super_block___4 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___4 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___4 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___4 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___4 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___4 *, unsigned int);
};

struct writeback_control___3;

struct readahead_control___3;

struct swap_info_struct___3;

struct address_space_operations___3 {
	int (*writepage)(struct page___3 *, struct writeback_control___3 *);
	int (*readpage)(struct file___4 *, struct page___3 *);
	int (*writepages)(struct address_space___3 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___3 *);
	int (*readpages)(struct file___4 *, struct address_space___3 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___4 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___3 **, void **);
	int (*write_end)(struct file___4 *, struct address_space___3 *, loff_t, unsigned int, unsigned int, struct page___3 *, void *);
	sector_t (*bmap)(struct address_space___3 *, sector_t);
	void (*invalidatepage)(struct page___3 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___3 *, gfp_t);
	void (*freepage)(struct page___3 *);
	ssize_t (*direct_IO)(struct kiocb___3 *, struct iov_iter___3 *);
	int (*migratepage)(struct address_space___3 *, struct page___3 *, struct page___3 *, enum migrate_mode);
	bool (*isolate_page)(struct page___3 *, isolate_mode_t);
	void (*putback_page)(struct page___3 *);
	int (*launder_page)(struct page___3 *);
	int (*is_partially_uptodate)(struct page___3 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___3 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___3 *, struct page___3 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___4 *, sector_t *);
	void (*swap_deactivate)(struct file___4 *);
};

struct bio_vec___3;

struct iov_iter___3 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___3 {
	struct dentry___4 * (*lookup)(struct inode___5 *, struct dentry___4 *, unsigned int);
	const char * (*get_link)(struct dentry___4 *, struct inode___5 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___5 *, int);
	struct posix_acl * (*get_acl)(struct inode___5 *, int, bool);
	int (*readlink)(struct dentry___4 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___5 *, struct dentry___4 *, umode_t, bool);
	int (*link)(struct dentry___4 *, struct inode___5 *, struct dentry___4 *);
	int (*unlink)(struct inode___5 *, struct dentry___4 *);
	int (*symlink)(struct user_namespace *, struct inode___5 *, struct dentry___4 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___5 *, struct dentry___4 *, umode_t);
	int (*rmdir)(struct inode___5 *, struct dentry___4 *);
	int (*mknod)(struct user_namespace *, struct inode___5 *, struct dentry___4 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___5 *, struct dentry___4 *, struct inode___5 *, struct dentry___4 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___4 *, struct iattr___4 *);
	int (*getattr)(struct user_namespace *, const struct path___3 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___4 *, char *, size_t);
	int (*fiemap)(struct inode___5 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___5 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___5 *, struct dentry___4 *, struct file___4 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___5 *, struct dentry___4 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___5 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___4 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___4 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___3 {
	void (*fl_copy_lock)(struct file_lock___3 *, struct file_lock___3 *);
	void (*fl_release_private)(struct file_lock___3 *);
};

struct lock_manager_operations___3;

struct file_lock___3 {
	struct file_lock___3 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___4 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___3 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___3 *fl_ops;
	const struct lock_manager_operations___3 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___3 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___3 *);
	int (*lm_grant)(struct file_lock___3 *, int);
	bool (*lm_break)(struct file_lock___3 *);
	int (*lm_change)(struct file_lock___3 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___3 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___3 *);
};

struct fasync_struct___3 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___3 *fa_next;
	struct file___4 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___3 {
	struct inode___5 * (*alloc_inode)(struct super_block___4 *);
	void (*destroy_inode)(struct inode___5 *);
	void (*free_inode)(struct inode___5 *);
	void (*dirty_inode)(struct inode___5 *, int);
	int (*write_inode)(struct inode___5 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___5 *);
	void (*evict_inode)(struct inode___5 *);
	void (*put_super)(struct super_block___4 *);
	int (*sync_fs)(struct super_block___4 *, int);
	int (*freeze_super)(struct super_block___4 *);
	int (*freeze_fs)(struct super_block___4 *);
	int (*thaw_super)(struct super_block___4 *);
	int (*unfreeze_fs)(struct super_block___4 *);
	int (*statfs)(struct dentry___4 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___4 *, int *, char *);
	void (*umount_begin)(struct super_block___4 *);
	int (*show_options)(struct seq_file___5 *, struct dentry___4 *);
	int (*show_devname)(struct seq_file___5 *, struct dentry___4 *);
	int (*show_path)(struct seq_file___5 *, struct dentry___4 *);
	int (*show_stats)(struct seq_file___5 *, struct dentry___4 *);
	ssize_t (*quota_read)(struct super_block___4 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___4 *, int, const char *, size_t, loff_t);
	struct dquot___3 ** (*get_dquots)(struct inode___5 *);
	long int (*nr_cached_objects)(struct super_block___4 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___4 *, struct shrink_control___2 *);
	struct file___4 * (*real_loop)(struct file___4 *);
};

struct wakeup_source___3;

struct dev_pm_info___3 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___3 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___2 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___3;

struct bus_type___3;

struct device_driver___3;

struct dev_pm_domain___3;

struct fwnode_handle___3;

struct class___3;

struct attribute_group___3;

struct device___2 {
	struct kobject___3 kobj;
	struct device___2 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___3 *type;
	struct bus_type___3 *bus;
	struct device_driver___3 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___3 power;
	struct dev_pm_domain___3 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___3 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___3 *class;
	const struct attribute_group___3 **groups;
	void (*release)(struct device___2 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___4 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___5 *bd_inode;
	struct super_block___4 *bd_super;
	void *bd_claiming;
	struct device___2 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___3 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___3 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___4 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___3)(struct file___4 *, wait_queue_head_t *, struct poll_table_struct___3 *);

struct poll_table_struct___3 {
	poll_queue_proc___3 _qproc;
	__poll_t _key;
};

struct seq_operations___4;

struct seq_file___5 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___4 *op;
	int poll_event;
	const struct file___4 *file;
	void *private;
};

typedef void bio_end_io_t___3(struct bio___3 *);

struct bio_vec___3 {
	struct page___3 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___3;

struct bio___3 {
	struct bio___3 *bi_next;
	struct block_device___4 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___3 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___3 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___3 *bi_io_vec;
	struct bio_set___3 *bi_pool;
	struct bio_vec___3 bi_inline_vecs[0];
};

struct subprocess_info {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	int wait;
	int retval;
	int (*init)(struct subprocess_info *, struct cred *);
	void (*cleanup)(struct subprocess_info *);
	void *data;
};

struct dev_pagemap_ops___3 {
	void (*page_free)(struct page___3 *);
	void (*kill)(struct dev_pagemap___3 *);
	void (*cleanup)(struct dev_pagemap___3 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___3 *);
};

struct fwnode_operations___3;

struct fwnode_handle___3 {
	struct fwnode_handle___3 *secondary;
	const struct fwnode_operations___3 *ops;
	struct device___2 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___3;

struct fwnode_endpoint___3;

struct fwnode_operations___3 {
	struct fwnode_handle___3 * (*get)(struct fwnode_handle___3 *);
	void (*put)(struct fwnode_handle___3 *);
	bool (*device_is_available)(const struct fwnode_handle___3 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___3 *, const struct device___2 *);
	bool (*property_present)(const struct fwnode_handle___3 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___3 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___3 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___3 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_parent)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_next_child_node)(const struct fwnode_handle___3 *, struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*get_named_child_node)(const struct fwnode_handle___3 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___3 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___3 *);
	struct fwnode_handle___3 * (*graph_get_next_endpoint)(const struct fwnode_handle___3 *, struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*graph_get_remote_endpoint)(const struct fwnode_handle___3 *);
	struct fwnode_handle___3 * (*graph_get_port_parent)(struct fwnode_handle___3 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___3 *, struct fwnode_endpoint___3 *);
	int (*add_links)(struct fwnode_handle___3 *);
};

struct fwnode_endpoint___3 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___3 *local_fwnode;
};

struct fwnode_reference_args___3 {
	struct fwnode_handle___3 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___3;

struct kernfs_elem_dir___3 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___3 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___3;

struct kernfs_root___3 {
	struct kernfs_node___3 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___3 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___3 {
	struct kernfs_node___3 *target_kn;
};

struct kernfs_ops___3;

struct kernfs_elem_attr___3 {
	const struct kernfs_ops___3 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___3 *notify_next;
};

struct kernfs_node___3 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___3 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___3 dir;
		struct kernfs_elem_symlink___3 symlink;
		struct kernfs_elem_attr___3 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___3;

struct kernfs_ops___3 {
	int (*open)(struct kernfs_open_file___3 *);
	void (*release)(struct kernfs_open_file___3 *);
	int (*seq_show)(struct seq_file___5 *, void *);
	void * (*seq_start)(struct seq_file___5 *, loff_t *);
	void * (*seq_next)(struct seq_file___5 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___5 *, void *);
	ssize_t (*read)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___3 *, struct poll_table_struct___3 *);
	int (*mmap)(struct kernfs_open_file___3 *, struct vm_area_struct___2 *);
};

struct kernfs_syscall_ops___3 {
	int (*show_options)(struct seq_file___5 *, struct kernfs_root___3 *);
	int (*mkdir)(struct kernfs_node___3 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___3 *);
	int (*rename)(struct kernfs_node___3 *, struct kernfs_node___3 *, const char *);
	int (*show_path)(struct seq_file___5 *, struct kernfs_node___3 *, struct kernfs_root___3 *);
};

struct kernfs_open_file___3 {
	struct kernfs_node___3 *kn;
	struct file___4 *file;
	struct seq_file___5 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___3 *vm_ops;
};

struct bin_attribute___3;

struct attribute_group___3 {
	const char *name;
	umode_t (*is_visible)(struct kobject___3 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___3 *, struct bin_attribute___3 *, int);
	struct attribute **attrs;
	struct bin_attribute___3 **bin_attrs;
};

struct bin_attribute___3 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___3 * (*f_mapping)();
	ssize_t (*read)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, char *, loff_t, size_t);
	int (*mmap)(struct file___4 *, struct kobject___3 *, struct bin_attribute___3 *, struct vm_area_struct___2 *);
};

struct sysfs_ops___3 {
	ssize_t (*show)(struct kobject___3 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___3 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___3;

struct kset___3 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___3 kobj;
	const struct kset_uevent_ops___3 *uevent_ops;
};

struct kobj_type___3 {
	void (*release)(struct kobject___3 *);
	const struct sysfs_ops___3 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___3 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___3 *);
	const void * (*namespace)(struct kobject___3 *);
	void (*get_ownership)(struct kobject___3 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___3 {
	int (* const filter)(struct kset___3 *, struct kobject___3 *);
	const char * (* const name)(struct kset___3 *, struct kobject___3 *);
	int (* const uevent)(struct kset___3 *, struct kobject___3 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___3 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___3 *);
	int (*get)(char *, const struct kernel_param___3 *);
	void (*free)(void *);
};

struct kparam_array___3;

struct kernel_param___3 {
	const char *name;
	struct module___2 *mod;
	const struct kernel_param_ops___3 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___3 *arr;
	};
};

struct kparam_array___3 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___3 *ops;
	void *elem;
};

struct module_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___3 *, struct module_kobject___3 *, char *);
	ssize_t (*store)(struct module_attribute___3 *, struct module_kobject___3 *, const char *, size_t);
	void (*setup)(struct module___2 *, const char *);
	int (*test)(struct module___2 *);
	void (*free)(struct module___2 *);
};

struct trace_event_class___3;

struct trace_event_call___3 {
	struct list_head list;
	struct trace_event_class___3 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___3 *, struct perf_event___3 *);
};

struct cgroup_namespace___4 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___4 *root_cset;
};

struct dev_pm_ops___3 {
	int (*prepare)(struct device___2 *);
	void (*complete)(struct device___2 *);
	int (*suspend)(struct device___2 *);
	int (*resume)(struct device___2 *);
	int (*freeze)(struct device___2 *);
	int (*thaw)(struct device___2 *);
	int (*poweroff)(struct device___2 *);
	int (*restore)(struct device___2 *);
	int (*suspend_late)(struct device___2 *);
	int (*resume_early)(struct device___2 *);
	int (*freeze_late)(struct device___2 *);
	int (*thaw_early)(struct device___2 *);
	int (*poweroff_late)(struct device___2 *);
	int (*restore_early)(struct device___2 *);
	int (*suspend_noirq)(struct device___2 *);
	int (*resume_noirq)(struct device___2 *);
	int (*freeze_noirq)(struct device___2 *);
	int (*thaw_noirq)(struct device___2 *);
	int (*poweroff_noirq)(struct device___2 *);
	int (*restore_noirq)(struct device___2 *);
	int (*runtime_suspend)(struct device___2 *);
	int (*runtime_resume)(struct device___2 *);
	int (*runtime_idle)(struct device___2 *);
};

struct wakeup_source___3 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___2 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___3 {
	struct dev_pm_ops___3 ops;
	int (*start)(struct device___2 *);
	void (*detach)(struct device___2 *, bool);
	int (*activate)(struct device___2 *);
	void (*sync)(struct device___2 *);
	void (*dismiss)(struct device___2 *);
};

struct bus_type___3 {
	const char *name;
	const char *dev_name;
	struct device___2 *dev_root;
	const struct attribute_group___3 **bus_groups;
	const struct attribute_group___3 **dev_groups;
	const struct attribute_group___3 **drv_groups;
	int (*match)(struct device___2 *, struct device_driver___3 *);
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	int (*probe)(struct device___2 *);
	void (*sync_state)(struct device___2 *);
	void (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*online)(struct device___2 *);
	int (*offline)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	int (*num_vf)(struct device___2 *);
	int (*dma_configure)(struct device___2 *);
	const struct dev_pm_ops___3 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___3 {
	const char *name;
	struct bus_type___3 *bus;
	struct module___2 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___2 *);
	void (*sync_state)(struct device___2 *);
	int (*remove)(struct device___2 *);
	void (*shutdown)(struct device___2 *);
	int (*suspend)(struct device___2 *, pm_message_t);
	int (*resume)(struct device___2 *);
	const struct attribute_group___3 **groups;
	const struct attribute_group___3 **dev_groups;
	const struct dev_pm_ops___3 *pm;
	void (*coredump)(struct device___2 *);
	struct driver_private *p;
};

struct device_type___3 {
	const char *name;
	const struct attribute_group___3 **groups;
	int (*uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___2 *);
	const struct dev_pm_ops___3 *pm;
};

struct class___3 {
	const char *name;
	struct module___2 *owner;
	const struct attribute_group___3 **class_groups;
	const struct attribute_group___3 **dev_groups;
	struct kobject___3 *dev_kobj;
	int (*dev_uevent)(struct device___2 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___2 *, umode_t *);
	void (*class_release)(struct class___3 *);
	void (*dev_release)(struct device___2 *);
	int (*shutdown_pre)(struct device___2 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___2 *);
	void (*get_ownership)(struct device___2 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___3 *pm;
	struct subsys_private *p;
};

struct block_device_operations___3;

struct gendisk___3 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___4 *part0;
	const struct block_device_operations___3 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___3 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___3 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___3 {
	struct bio___3 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___3 *bip_vec;
	struct bio_vec___3 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___3(struct request___3 *);

typedef void integrity_complete_fn___3(struct request___3 *, unsigned int);

struct blk_integrity_profile___3 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___3 *prepare_fn;
	integrity_complete_fn___3 *complete_fn;
	const char *name;
};

struct block_device_operations___3 {
	blk_qc_t (*submit_bio)(struct bio___3 *);
	int (*open)(struct block_device___4 *, fmode_t);
	void (*release)(struct gendisk___3 *, fmode_t);
	int (*rw_page)(struct block_device___4 *, sector_t, struct page___3 *, unsigned int);
	int (*ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___4 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___3 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___3 *);
	int (*getgeo)(struct block_device___4 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___4 *, bool);
	void (*swap_slot_free_notify)(struct block_device___4 *, long unsigned int);
	int (*report_zones)(struct gendisk___3 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___3 *, umode_t *);
	struct module___2 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___3 *, sector_t *);
};

typedef void rq_end_io_fn___3(struct request___3 *, blk_status_t);

struct request___3 {
	struct request_queue___3 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___3 *bio;
	struct bio___3 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___3 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___3 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___3 *saved_end_io;
		} flush;
	};
	struct gendisk___3 *rq_disk;
	struct block_device___4 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___3 *end_io;
	void *end_io_data;
};

struct elevator_type___3;

struct elevator_mq_ops___3 {
	int (*init_sched)(struct request_queue___3 *, struct elevator_type___3 *);
	void (*exit_sched)(struct elevator_queue___3 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
	bool (*allow_merge)(struct request_queue___3 *, struct request___3 *, struct bio___3 *);
	bool (*bio_merge)(struct request_queue___3 *, struct bio___3 *, unsigned int);
	int (*request_merge)(struct request_queue___3 *, struct request___3 **, struct bio___3 *);
	void (*request_merged)(struct request_queue___3 *, struct request___3 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___3 *, struct request___3 *, struct request___3 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___3 *);
	void (*finish_request)(struct request___3 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___3 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___3 *, u64);
	void (*requeue_request)(struct request___3 *);
	struct request___3 * (*former_request)(struct request_queue___3 *, struct request___3 *);
	struct request___3 * (*next_request)(struct request_queue___3 *, struct request___3 *);
	void (*init_icq)(struct io_cq___3 *);
	void (*exit_icq)(struct io_cq___3 *);
};

struct elv_fs_entry___3;

struct elevator_type___3 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___3 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___3 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___2 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___3 {
	struct elevator_type___3 *type;
	void *elevator_data;
	struct kobject___3 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___3 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___3 *, char *);
	ssize_t (*store)(struct elevator_queue___3 *, const char *, size_t);
};

struct blk_mq_queue_data___3;

struct request_queue___5;

struct request___4;

struct seq_file___6;

struct blk_mq_ops___3 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___3 *, const struct blk_mq_queue_data___3 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___3 *);
	int (*get_budget)(struct request_queue___5 *);
	void (*put_budget)(struct request_queue___5 *, int);
	void (*set_rq_budget_token)(struct request___4 *, int);
	int (*get_rq_budget_token)(struct request___4 *);
	enum blk_eh_timer_return (*timeout)(struct request___4 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___3 *);
	void (*complete)(struct request___4 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___3 *, struct request___4 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___3 *, struct request___4 *, unsigned int);
	void (*initialize_rq_fn)(struct request___4 *);
	void (*cleanup_rq)(struct request___4 *);
	bool (*busy)(struct request_queue___5 *);
	int (*map_queues)(struct blk_mq_tag_set___3 *);
	void (*show_rq)(struct seq_file___6 *, struct request___4 *);
};

struct seq_operations___4 {
	void * (*start)(struct seq_file___5 *, loff_t *);
	void (*stop)(struct seq_file___5 *, void *);
	void * (*next)(struct seq_file___5 *, void *, loff_t *);
	int (*show)(struct seq_file___5 *, void *);
};

struct cftype___3;

struct cgroup_subsys___3 {
	struct cgroup_subsys_state___3 * (*css_alloc)(struct cgroup_subsys_state___3 *);
	int (*css_online)(struct cgroup_subsys_state___3 *);
	void (*css_offline)(struct cgroup_subsys_state___3 *);
	void (*css_released)(struct cgroup_subsys_state___3 *);
	void (*css_free)(struct cgroup_subsys_state___3 *);
	void (*css_reset)(struct cgroup_subsys_state___3 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___3 *, int);
	int (*css_extra_stat_show)(struct seq_file___5 *, struct cgroup_subsys_state___3 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___5 *, struct css_set___4 *);
	void (*cancel_fork)(struct task_struct___5 *, struct css_set___4 *);
	void (*fork)(struct task_struct___5 *);
	void (*exit)(struct task_struct___5 *);
	void (*release)(struct task_struct___5 *);
	void (*bind)(struct cgroup_subsys_state___3 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___3 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___3 *dfl_cftypes;
	struct cftype___3 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___3 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___3 *updated_children;
	struct cgroup___3 *updated_next;
};

struct cgroup_root___3 {
	struct kernfs_root___3 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___3 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___3 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___3 *ss;
	struct list_head node;
	struct kernfs_ops___3 *kf_ops;
	int (*open)(struct kernfs_open_file___3 *);
	void (*release)(struct kernfs_open_file___3 *);
	u64 (*read_u64)(struct cgroup_subsys_state___3 *, struct cftype___3 *);
	s64 (*read_s64)(struct cgroup_subsys_state___3 *, struct cftype___3 *);
	int (*seq_show)(struct seq_file___5 *, void *);
	void * (*seq_start)(struct seq_file___5 *, loff_t *);
	void * (*seq_next)(struct seq_file___5 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___5 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___3 *, struct cftype___3 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___3 *, struct cftype___3 *, s64);
	ssize_t (*write)(struct kernfs_open_file___3 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___3 *, struct poll_table_struct___3 *);
};

struct perf_cpu_context___3;

struct perf_output_handle___3;

struct pmu___3 {
	struct list_head entry;
	struct module___2 *module;
	struct device___2 *dev;
	const struct attribute_group___3 **attr_groups;
	const struct attribute_group___3 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___3 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___3 *);
	void (*pmu_disable)(struct pmu___3 *);
	int (*event_init)(struct perf_event___3 *);
	void (*event_mapped)(struct perf_event___3 *, struct mm_struct___2 *);
	void (*event_unmapped)(struct perf_event___3 *, struct mm_struct___2 *);
	int (*add)(struct perf_event___3 *, int);
	void (*del)(struct perf_event___3 *, int);
	void (*start)(struct perf_event___3 *, int);
	void (*stop)(struct perf_event___3 *, int);
	void (*read)(struct perf_event___3 *);
	void (*start_txn)(struct pmu___3 *, unsigned int);
	int (*commit_txn)(struct pmu___3 *);
	void (*cancel_txn)(struct pmu___3 *);
	int (*event_idx)(struct perf_event___3 *);
	void (*sched_task)(struct perf_event_context___4 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___4 *, struct perf_event_context___4 *);
	void * (*setup_aux)(struct perf_event___3 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___3 *, struct perf_output_handle___3 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___3 *);
	int (*aux_output_match)(struct perf_event___3 *);
	int (*filter_match)(struct perf_event___3 *);
	int (*check_period)(struct perf_event___3 *, u64);
};

struct perf_cpu_context___3 {
	struct perf_event_context___4 ctx;
	struct perf_event_context___4 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___3 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___3 **heap;
	struct perf_event___3 *heap_default[2];
};

struct perf_output_handle___3 {
	struct perf_event___3 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___3 {
	struct cgroup_subsys_state___3 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___3 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___3 *);
	};
};

struct trace_event_class___3 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___3 *, enum trace_reg, void *);
	struct trace_event_fields___3 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___3 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___3 *);
};

typedef phys_addr_t resource_size_t;

struct dentry___5;

struct super_block___5;

struct module___6;

struct file_system_type___4 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___5 * (*mount)(struct file_system_type___4 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___5 *);
	struct module___6 *owner;
	struct file_system_type___4 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct __va_list {
	void *__stack;
	void *__gr_top;
	void *__vr_top;
	int __gr_offs;
	int __vr_offs;
};

typedef struct __va_list va_list;

struct file___5;

struct kiocb___4;

struct poll_table_struct___4;

struct vm_area_struct___4;

struct inode___6;

struct file_lock___4;

struct page___5;

struct seq_file___7;

struct file_operations___4 {
	struct module___6 *owner;
	loff_t (*llseek)(struct file___5 *, loff_t, int);
	ssize_t (*read)(struct file___5 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___5 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___4 *, struct iov_iter___3 *);
	ssize_t (*write_iter)(struct kiocb___4 *, struct iov_iter___3 *);
	int (*iopoll)(struct kiocb___4 *, bool);
	int (*iterate)(struct file___5 *, struct dir_context *);
	int (*iterate_shared)(struct file___5 *, struct dir_context *);
	__poll_t (*poll)(struct file___5 *, struct poll_table_struct___4 *);
	long int (*unlocked_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___5 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___5 *, struct vm_area_struct___4 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___6 *, struct file___5 *);
	int (*flush)(struct file___5 *, fl_owner_t);
	int (*release)(struct inode___6 *, struct file___5 *);
	int (*fsync)(struct file___5 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___5 *, int);
	int (*lock)(struct file___5 *, int, struct file_lock___4 *);
	ssize_t (*sendpage)(struct file___5 *, struct page___5 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___5 *, long unsigned int);
	int (*flock)(struct file___5 *, int, struct file_lock___4 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___5 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___5 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___5 *, long int, struct file_lock___4 **, void **);
	long int (*fallocate)(struct file___5 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___7 *, struct file___5 *);
	ssize_t (*copy_file_range)(struct file___5 *, loff_t, struct file___5 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___5 *, loff_t, struct file___5 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___5 *, loff_t, loff_t, int);
};

struct vmacache___4 {
	u64 seqnum;
	struct vm_area_struct___4 *vmas[4];
};

struct page_frag___4 {
	struct page___5 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___4;

struct debug_info___4 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___4 *hbp_break[16];
	struct perf_event___4 *hbp_watch[16];
};

struct thread_struct___4 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___4 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___5;

struct pid___4;

struct nsproxy___5;

struct signal_struct___5;

struct css_set___5;

struct perf_event_context___5;

struct vm_struct___5;

struct task_struct___6 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___6 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___5 *mm;
	struct mm_struct___5 *active_mm;
	struct vmacache___4 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___6 *real_parent;
	struct task_struct___6 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___6 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___4 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___5 *nsproxy;
	struct signal_struct___5 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___6 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___5 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___5 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___4 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___6 *oom_reaper_list;
	struct vm_struct___5 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___4;

struct kobj_type___4;

struct kernfs_node___4;

struct kobject___4 {
	const char *name;
	struct list_head entry;
	struct kobject___4 *parent;
	struct kset___4 *kset;
	struct kobj_type___4 *ktype;
	struct kernfs_node___4 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___4 {
	struct kobject___4 kobj;
	struct module___6 *mod;
	struct kobject___4 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___4 {
	struct module___6 *mod;
	struct latch_tree_node node;
};

struct module_layout___4 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___4 mtn;
};

struct module_attribute___4;

struct kernel_param___4;

struct trace_event_call___4;

struct module___6 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___4 mkobj;
	struct module_attribute___4 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___4 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___4 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___4 core_layout;
	struct module_layout___4 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___4 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___4 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___6 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___4)(struct perf_event___4 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___4;

struct fasync_struct___4;

struct pid_namespace___4;

struct perf_cgroup___4;

struct perf_event___4 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___4 *group_leader;
	struct pmu___4 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___4 hw;
	struct perf_event_context___5 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___4 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___6 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___4 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___4 *aux_event;
	void (*destroy)(struct perf_event___4 *);
	struct callback_head callback_head;
	struct pid_namespace___4 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___4 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___4 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___4 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___4 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___4 {
	int nr;
	struct pid_namespace___4 *ns;
};

struct pid_namespace___4 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___6 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___4 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___4 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___4 numbers[1];
};

typedef struct page___5 *pgtable_t___4;

struct address_space___4;

struct dev_pagemap___4;

struct page___5 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___4 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___2 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___5 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___4 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___5 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___4 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___4;

struct vm_area_struct___4 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___4 *vm_next;
	struct vm_area_struct___4 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___5 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___4 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___5 *vm_file;
	struct file___5 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___5 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___6 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___6 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___4 *pids[4];
	struct pid___4 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___5 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___4;

struct mm_struct___5 {
	struct {
		struct vm_area_struct___4 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___5 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___4 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___6 *owner;
		struct user_namespace *user_ns;
		struct file___5 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___5;

struct nsproxy___5 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___4 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___5 *cgroup_ns;
};

struct cgroup_subsys_state___4;

struct cgroup___4;

struct css_set___5 {
	struct cgroup_subsys_state___4 *subsys[14];
	refcount_t refcount;
	struct css_set___5 *dom_cset;
	struct cgroup___4 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___4 *mg_src_cgrp;
	struct cgroup___4 *mg_dst_cgrp;
	struct css_set___5 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___5 {
	struct pmu___4 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___6 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___5 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___5 {
	struct vm_struct___5 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___5 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___4;

struct address_space___4 {
	struct inode___6 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___4 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___4;

struct dev_pagemap___4 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___4 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___4;

struct path___4 {
	struct vfsmount___4 *mnt;
	struct dentry___5 *dentry;
};

struct fown_struct___4 {
	rwlock_t lock;
	struct pid___4 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___5 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___4 f_path;
	struct inode___6 *f_inode;
	const struct file_operations___4 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___4 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___4 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___4;

struct vm_operations_struct___4 {
	void (*open)(struct vm_area_struct___4 *);
	void (*close)(struct vm_area_struct___4 *);
	int (*may_split)(struct vm_area_struct___4 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___4 *);
	int (*mprotect)(struct vm_area_struct___4 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___4 *);
	vm_fault_t (*huge_fault)(struct vm_fault___4 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___4 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___4 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___4 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___4 *);
	int (*access)(struct vm_area_struct___4 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___4 *);
	int (*set_policy)(struct vm_area_struct___4 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___4 *, long unsigned int);
	struct page___5 * (*find_special_page)(struct vm_area_struct___4 *, long unsigned int);
};

struct core_thread___4 {
	struct task_struct___6 *task;
	struct core_thread___4 *next;
};

struct core_state___4 {
	atomic_t nr_threads;
	struct core_thread___4 dumper;
	struct completion startup;
};

struct vm_fault___4 {
	const struct {
		struct vm_area_struct___4 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___5 *cow_page;
	struct page___5 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___4 prealloc_pte;
};

struct kernfs_root___4;

struct kernfs_elem_dir___4 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___4 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___4;

struct kernfs_root___4 {
	struct kernfs_node___4 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___4 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___4 {
	struct kernfs_node___4 *target_kn;
};

struct kernfs_ops___4;

struct kernfs_elem_attr___4 {
	const struct kernfs_ops___4 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___4 *notify_next;
};

struct kernfs_node___4 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___4 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___4 dir;
		struct kernfs_elem_symlink___4 symlink;
		struct kernfs_elem_attr___4 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___4;

struct kernfs_ops___4 {
	int (*open)(struct kernfs_open_file___4 *);
	void (*release)(struct kernfs_open_file___4 *);
	int (*seq_show)(struct seq_file___7 *, void *);
	void * (*seq_start)(struct seq_file___7 *, loff_t *);
	void * (*seq_next)(struct seq_file___7 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___7 *, void *);
	ssize_t (*read)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___4 *, struct poll_table_struct___4 *);
	int (*mmap)(struct kernfs_open_file___4 *, struct vm_area_struct___4 *);
};

struct kernfs_syscall_ops___4 {
	int (*show_options)(struct seq_file___7 *, struct kernfs_root___4 *);
	int (*mkdir)(struct kernfs_node___4 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___4 *);
	int (*rename)(struct kernfs_node___4 *, struct kernfs_node___4 *, const char *);
	int (*show_path)(struct seq_file___7 *, struct kernfs_node___4 *, struct kernfs_root___4 *);
};

struct seq_operations___5;

struct seq_file___7 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___5 *op;
	int poll_event;
	const struct file___5 *file;
	void *private;
};

struct kernfs_open_file___4 {
	struct kernfs_node___4 *kn;
	struct file___5 *file;
	struct seq_file___7 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___4 *vm_ops;
};

typedef void (*poll_queue_proc___4)(struct file___5 *, wait_queue_head_t *, struct poll_table_struct___4 *);

struct poll_table_struct___4 {
	poll_queue_proc___4 _qproc;
	__poll_t _key;
};

struct bin_attribute___4;

struct attribute_group___4 {
	const char *name;
	umode_t (*is_visible)(struct kobject___4 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___4 *, struct bin_attribute___4 *, int);
	struct attribute **attrs;
	struct bin_attribute___4 **bin_attrs;
};

struct bin_attribute___4 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___4 * (*f_mapping)();
	ssize_t (*read)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, char *, loff_t, size_t);
	int (*mmap)(struct file___5 *, struct kobject___4 *, struct bin_attribute___4 *, struct vm_area_struct___4 *);
};

struct sysfs_ops___4 {
	ssize_t (*show)(struct kobject___4 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___4 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___4;

struct kset___4 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___4 kobj;
	const struct kset_uevent_ops___4 *uevent_ops;
};

struct kobj_type___4 {
	void (*release)(struct kobject___4 *);
	const struct sysfs_ops___4 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___4 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___4 *);
	const void * (*namespace)(struct kobject___4 *);
	void (*get_ownership)(struct kobject___4 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___4 {
	int (* const filter)(struct kset___4 *, struct kobject___4 *);
	const char * (* const name)(struct kset___4 *, struct kobject___4 *);
	int (* const uevent)(struct kset___4 *, struct kobject___4 *, struct kobj_uevent_env *);
};

struct wakeup_source___4;

struct device___4;

struct dev_pm_info___4 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___4 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___4 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___4;

struct bus_type___4;

struct device_driver___4;

struct dev_pm_domain___4;

struct fwnode_handle___4;

struct class___4;

struct device___4 {
	struct kobject___4 kobj;
	struct device___4 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___4 *type;
	struct bus_type___4 *bus;
	struct device_driver___4 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___4 power;
	struct dev_pm_domain___4 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___4 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___4 *class;
	const struct attribute_group___4 **groups;
	void (*release)(struct device___4 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct resource {
	resource_size_t start;
	resource_size_t end;
	const char *name;
	long unsigned int flags;
	long unsigned int desc;
	struct resource *parent;
	struct resource *sibling;
	struct resource *child;
};

struct dev_pm_ops___4 {
	int (*prepare)(struct device___4 *);
	void (*complete)(struct device___4 *);
	int (*suspend)(struct device___4 *);
	int (*resume)(struct device___4 *);
	int (*freeze)(struct device___4 *);
	int (*thaw)(struct device___4 *);
	int (*poweroff)(struct device___4 *);
	int (*restore)(struct device___4 *);
	int (*suspend_late)(struct device___4 *);
	int (*resume_early)(struct device___4 *);
	int (*freeze_late)(struct device___4 *);
	int (*thaw_early)(struct device___4 *);
	int (*poweroff_late)(struct device___4 *);
	int (*restore_early)(struct device___4 *);
	int (*suspend_noirq)(struct device___4 *);
	int (*resume_noirq)(struct device___4 *);
	int (*freeze_noirq)(struct device___4 *);
	int (*thaw_noirq)(struct device___4 *);
	int (*poweroff_noirq)(struct device___4 *);
	int (*restore_noirq)(struct device___4 *);
	int (*runtime_suspend)(struct device___4 *);
	int (*runtime_resume)(struct device___4 *);
	int (*runtime_idle)(struct device___4 *);
};

struct wakeup_source___4 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___4 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___4 {
	struct dev_pm_ops___4 ops;
	int (*start)(struct device___4 *);
	void (*detach)(struct device___4 *, bool);
	int (*activate)(struct device___4 *);
	void (*sync)(struct device___4 *);
	void (*dismiss)(struct device___4 *);
};

struct bus_type___4 {
	const char *name;
	const char *dev_name;
	struct device___4 *dev_root;
	const struct attribute_group___4 **bus_groups;
	const struct attribute_group___4 **dev_groups;
	const struct attribute_group___4 **drv_groups;
	int (*match)(struct device___4 *, struct device_driver___4 *);
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	int (*probe)(struct device___4 *);
	void (*sync_state)(struct device___4 *);
	void (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*online)(struct device___4 *);
	int (*offline)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	int (*num_vf)(struct device___4 *);
	int (*dma_configure)(struct device___4 *);
	const struct dev_pm_ops___4 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___4 {
	const char *name;
	struct bus_type___4 *bus;
	struct module___6 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___4 *);
	void (*sync_state)(struct device___4 *);
	int (*remove)(struct device___4 *);
	void (*shutdown)(struct device___4 *);
	int (*suspend)(struct device___4 *, pm_message_t);
	int (*resume)(struct device___4 *);
	const struct attribute_group___4 **groups;
	const struct attribute_group___4 **dev_groups;
	const struct dev_pm_ops___4 *pm;
	void (*coredump)(struct device___4 *);
	struct driver_private *p;
};

struct device_type___4 {
	const char *name;
	const struct attribute_group___4 **groups;
	int (*uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___4 *);
	const struct dev_pm_ops___4 *pm;
};

struct class___4 {
	const char *name;
	struct module___6 *owner;
	const struct attribute_group___4 **class_groups;
	const struct attribute_group___4 **dev_groups;
	struct kobject___4 *dev_kobj;
	int (*dev_uevent)(struct device___4 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___4 *, umode_t *);
	void (*class_release)(struct class___4 *);
	void (*dev_release)(struct device___4 *);
	int (*shutdown_pre)(struct device___4 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___4 *);
	void (*get_ownership)(struct device___4 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___4 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___4;

struct fwnode_handle___4 {
	struct fwnode_handle___4 *secondary;
	const struct fwnode_operations___4 *ops;
	struct device___4 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

typedef u64 async_cookie_t;

typedef void (*async_func_t)(void *, async_cookie_t);

struct async_domain {
	struct list_head pending;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct dentry_operations___4;

struct dentry___5 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___5 *d_parent;
	struct qstr d_name;
	struct inode___6 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___4 *d_op;
	struct super_block___5 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___4;

struct inode___6 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___4 *i_op;
	struct super_block___5 *i_sb;
	struct address_space___4 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___4 *i_fop;
		void (*free_inode)(struct inode___6 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___4 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___4 {
	int (*d_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___5 *, unsigned int);
	int (*d_hash)(const struct dentry___5 *, struct qstr *);
	int (*d_compare)(const struct dentry___5 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___5 *);
	int (*d_init)(struct dentry___5 *);
	void (*d_release)(struct dentry___5 *);
	void (*d_prune)(struct dentry___5 *);
	void (*d_iput)(struct dentry___5 *, struct inode___6 *);
	char * (*d_dname)(struct dentry___5 *, char *, int);
	struct vfsmount___4 * (*d_automount)(struct path___4 *);
	int (*d_manage)(const struct path___4 *, bool);
	struct dentry___5 * (*d_real)(struct dentry___5 *, const struct inode___6 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___4;

struct mem_dqinfo___4 {
	struct quota_format_type___4 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___4;

struct quota_info___4 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___6 *files[3];
	struct mem_dqinfo___4 info[3];
	const struct quota_format_ops___4 *ops[3];
};

struct rcuwait___4 {
	struct task_struct___6 *task;
};

struct percpu_rw_semaphore___4 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___4 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___4 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___4 rw_sem[3];
};

struct super_operations___4;

struct dquot_operations___4;

struct quotactl_ops___4;

struct block_device___5;

struct super_block___5 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___4 *s_type;
	const struct super_operations___4 *s_op;
	const struct dquot_operations___4 *dq_op;
	const struct quotactl_ops___4 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___5 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___4 s_dquot;
	struct sb_writers___4 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___4 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___4 {
	struct dentry___5 *mnt_root;
	struct super_block___5 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___4;

struct cgroup_subsys_state___4 {
	struct cgroup___4 *cgroup;
	struct cgroup_subsys___4 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___4 *parent;
};

struct cgroup_file___4 {
	struct kernfs_node___4 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___4 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___6 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___4;

struct cgroup_rstat_cpu___4;

struct cgroup___4 {
	struct cgroup_subsys_state___4 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___4 *kn;
	struct cgroup_file___4 procs_file;
	struct cgroup_file___4 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___4 *subsys[14];
	struct cgroup_root___4 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___4 *dom_cgrp;
	struct cgroup___4 *old_dom_cgrp;
	struct cgroup_rstat_cpu___4 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___4 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___4 {
	struct file___5 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___4 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___5 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___5 *ia_file;
};

struct dquot___4 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___5 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___4 {
	int qf_fmt_id;
	const struct quota_format_ops___4 *qf_ops;
	struct module___6 *qf_owner;
	struct quota_format_type___4 *qf_next;
};

struct quota_format_ops___4 {
	int (*check_quota_file)(struct super_block___5 *, int);
	int (*read_file_info)(struct super_block___5 *, int);
	int (*write_file_info)(struct super_block___5 *, int);
	int (*free_file_info)(struct super_block___5 *, int);
	int (*read_dqblk)(struct dquot___4 *);
	int (*commit_dqblk)(struct dquot___4 *);
	int (*release_dqblk)(struct dquot___4 *);
	int (*get_next_id)(struct super_block___5 *, struct kqid *);
};

struct dquot_operations___4 {
	int (*write_dquot)(struct dquot___4 *);
	struct dquot___4 * (*alloc_dquot)(struct super_block___5 *, int);
	void (*destroy_dquot)(struct dquot___4 *);
	int (*acquire_dquot)(struct dquot___4 *);
	int (*release_dquot)(struct dquot___4 *);
	int (*mark_dirty)(struct dquot___4 *);
	int (*write_info)(struct super_block___5 *, int);
	qsize_t * (*get_reserved_space)(struct inode___6 *);
	int (*get_projid)(struct inode___6 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___6 *, qsize_t *);
	int (*get_next_id)(struct super_block___5 *, struct kqid *);
};

struct quotactl_ops___4 {
	int (*quota_on)(struct super_block___5 *, int, int, const struct path___4 *);
	int (*quota_off)(struct super_block___5 *, int);
	int (*quota_enable)(struct super_block___5 *, unsigned int);
	int (*quota_disable)(struct super_block___5 *, unsigned int);
	int (*quota_sync)(struct super_block___5 *, int);
	int (*set_info)(struct super_block___5 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___5 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___5 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___5 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___5 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___5 *, unsigned int);
};

struct address_space_operations___4 {
	int (*writepage)(struct page___5 *, struct writeback_control___3 *);
	int (*readpage)(struct file___5 *, struct page___5 *);
	int (*writepages)(struct address_space___4 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___5 *);
	int (*readpages)(struct file___5 *, struct address_space___4 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___5 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___5 **, void **);
	int (*write_end)(struct file___5 *, struct address_space___4 *, loff_t, unsigned int, unsigned int, struct page___5 *, void *);
	sector_t (*bmap)(struct address_space___4 *, sector_t);
	void (*invalidatepage)(struct page___5 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___5 *, gfp_t);
	void (*freepage)(struct page___5 *);
	ssize_t (*direct_IO)(struct kiocb___4 *, struct iov_iter___3 *);
	int (*migratepage)(struct address_space___4 *, struct page___5 *, struct page___5 *, enum migrate_mode);
	bool (*isolate_page)(struct page___5 *, isolate_mode_t);
	void (*putback_page)(struct page___5 *);
	int (*launder_page)(struct page___5 *);
	int (*is_partially_uptodate)(struct page___5 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___5 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___4 *, struct page___5 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___5 *, sector_t *);
	void (*swap_deactivate)(struct file___5 *);
};

struct inode_operations___4 {
	struct dentry___5 * (*lookup)(struct inode___6 *, struct dentry___5 *, unsigned int);
	const char * (*get_link)(struct dentry___5 *, struct inode___6 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___6 *, int);
	struct posix_acl * (*get_acl)(struct inode___6 *, int, bool);
	int (*readlink)(struct dentry___5 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___6 *, struct dentry___5 *, umode_t, bool);
	int (*link)(struct dentry___5 *, struct inode___6 *, struct dentry___5 *);
	int (*unlink)(struct inode___6 *, struct dentry___5 *);
	int (*symlink)(struct user_namespace *, struct inode___6 *, struct dentry___5 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___6 *, struct dentry___5 *, umode_t);
	int (*rmdir)(struct inode___6 *, struct dentry___5 *);
	int (*mknod)(struct user_namespace *, struct inode___6 *, struct dentry___5 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___6 *, struct dentry___5 *, struct inode___6 *, struct dentry___5 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___5 *, struct iattr___5 *);
	int (*getattr)(struct user_namespace *, const struct path___4 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___5 *, char *, size_t);
	int (*fiemap)(struct inode___6 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___6 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___6 *, struct dentry___5 *, struct file___5 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___6 *, struct dentry___5 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___6 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___5 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___5 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___4 {
	void (*fl_copy_lock)(struct file_lock___4 *, struct file_lock___4 *);
	void (*fl_release_private)(struct file_lock___4 *);
};

struct lock_manager_operations___4;

struct file_lock___4 {
	struct file_lock___4 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___5 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___4 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___4 *fl_ops;
	const struct lock_manager_operations___4 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___4 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___4 *);
	int (*lm_grant)(struct file_lock___4 *, int);
	bool (*lm_break)(struct file_lock___4 *);
	int (*lm_change)(struct file_lock___4 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___4 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___4 *);
};

struct fasync_struct___4 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___4 *fa_next;
	struct file___5 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___4 {
	struct inode___6 * (*alloc_inode)(struct super_block___5 *);
	void (*destroy_inode)(struct inode___6 *);
	void (*free_inode)(struct inode___6 *);
	void (*dirty_inode)(struct inode___6 *, int);
	int (*write_inode)(struct inode___6 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___6 *);
	void (*evict_inode)(struct inode___6 *);
	void (*put_super)(struct super_block___5 *);
	int (*sync_fs)(struct super_block___5 *, int);
	int (*freeze_super)(struct super_block___5 *);
	int (*freeze_fs)(struct super_block___5 *);
	int (*thaw_super)(struct super_block___5 *);
	int (*unfreeze_fs)(struct super_block___5 *);
	int (*statfs)(struct dentry___5 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___5 *, int *, char *);
	void (*umount_begin)(struct super_block___5 *);
	int (*show_options)(struct seq_file___7 *, struct dentry___5 *);
	int (*show_devname)(struct seq_file___7 *, struct dentry___5 *);
	int (*show_path)(struct seq_file___7 *, struct dentry___5 *);
	int (*show_stats)(struct seq_file___7 *, struct dentry___5 *);
	ssize_t (*quota_read)(struct super_block___5 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___5 *, int, const char *, size_t, loff_t);
	struct dquot___4 ** (*get_dquots)(struct inode___6 *);
	long int (*nr_cached_objects)(struct super_block___5 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___5 *, struct shrink_control___2 *);
	struct file___5 * (*real_loop)(struct file___5 *);
};

struct dev_pagemap_ops___4 {
	void (*page_free)(struct page___5 *);
	void (*kill)(struct dev_pagemap___4 *);
	void (*cleanup)(struct dev_pagemap___4 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___4 *);
};

struct seq_operations___5 {
	void * (*start)(struct seq_file___7 *, loff_t *);
	void (*stop)(struct seq_file___7 *, void *);
	void * (*next)(struct seq_file___7 *, void *, loff_t *);
	int (*show)(struct seq_file___7 *, void *);
};

struct fwnode_reference_args___4;

struct fwnode_endpoint___4;

struct fwnode_operations___4 {
	struct fwnode_handle___4 * (*get)(struct fwnode_handle___4 *);
	void (*put)(struct fwnode_handle___4 *);
	bool (*device_is_available)(const struct fwnode_handle___4 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___4 *, const struct device___4 *);
	bool (*property_present)(const struct fwnode_handle___4 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___4 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___4 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___4 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_parent)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_next_child_node)(const struct fwnode_handle___4 *, struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*get_named_child_node)(const struct fwnode_handle___4 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___4 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___4 *);
	struct fwnode_handle___4 * (*graph_get_next_endpoint)(const struct fwnode_handle___4 *, struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*graph_get_remote_endpoint)(const struct fwnode_handle___4 *);
	struct fwnode_handle___4 * (*graph_get_port_parent)(struct fwnode_handle___4 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___4 *, struct fwnode_endpoint___4 *);
	int (*add_links)(struct fwnode_handle___4 *);
};

struct fwnode_endpoint___4 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___4 *local_fwnode;
};

struct fwnode_reference_args___4 {
	struct fwnode_handle___4 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___5 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___5 *root_cset;
};

enum umh_disable_depth {
	UMH_ENABLED = 0,
	UMH_FREEZING = 1,
	UMH_DISABLED = 2,
};

struct kernel_param_ops___4 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___4 *);
	int (*get)(char *, const struct kernel_param___4 *);
	void (*free)(void *);
};

struct kparam_array___4;

struct kernel_param___4 {
	const char *name;
	struct module___6 *mod;
	const struct kernel_param_ops___4 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___4 *arr;
	};
};

struct kparam_array___4 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___4 *ops;
	void *elem;
};

struct module_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___4 *, struct module_kobject___4 *, char *);
	ssize_t (*store)(struct module_attribute___4 *, struct module_kobject___4 *, const char *, size_t);
	void (*setup)(struct module___6 *, const char *);
	int (*test)(struct module___6 *);
	void (*free)(struct module___6 *);
};

struct trace_event_class___4;

struct trace_event_call___4 {
	struct list_head list;
	struct trace_event_class___4 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___4 *, struct perf_event___4 *);
};

struct cftype___4;

struct cgroup_subsys___4 {
	struct cgroup_subsys_state___4 * (*css_alloc)(struct cgroup_subsys_state___4 *);
	int (*css_online)(struct cgroup_subsys_state___4 *);
	void (*css_offline)(struct cgroup_subsys_state___4 *);
	void (*css_released)(struct cgroup_subsys_state___4 *);
	void (*css_free)(struct cgroup_subsys_state___4 *);
	void (*css_reset)(struct cgroup_subsys_state___4 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___4 *, int);
	int (*css_extra_stat_show)(struct seq_file___7 *, struct cgroup_subsys_state___4 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___6 *, struct css_set___5 *);
	void (*cancel_fork)(struct task_struct___6 *, struct css_set___5 *);
	void (*fork)(struct task_struct___6 *);
	void (*exit)(struct task_struct___6 *);
	void (*release)(struct task_struct___6 *);
	void (*bind)(struct cgroup_subsys_state___4 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___4 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___4 *dfl_cftypes;
	struct cftype___4 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___4 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___4 *updated_children;
	struct cgroup___4 *updated_next;
};

struct cgroup_root___4 {
	struct kernfs_root___4 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___4 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___4 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___4 *ss;
	struct list_head node;
	struct kernfs_ops___4 *kf_ops;
	int (*open)(struct kernfs_open_file___4 *);
	void (*release)(struct kernfs_open_file___4 *);
	u64 (*read_u64)(struct cgroup_subsys_state___4 *, struct cftype___4 *);
	s64 (*read_s64)(struct cgroup_subsys_state___4 *, struct cftype___4 *);
	int (*seq_show)(struct seq_file___7 *, void *);
	void * (*seq_start)(struct seq_file___7 *, loff_t *);
	void * (*seq_next)(struct seq_file___7 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___7 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___4 *, struct cftype___4 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___4 *, struct cftype___4 *, s64);
	ssize_t (*write)(struct kernfs_open_file___4 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___4 *, struct poll_table_struct___4 *);
};

struct perf_cpu_context___4;

struct perf_output_handle___4;

struct pmu___4 {
	struct list_head entry;
	struct module___6 *module;
	struct device___4 *dev;
	const struct attribute_group___4 **attr_groups;
	const struct attribute_group___4 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___4 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___4 *);
	void (*pmu_disable)(struct pmu___4 *);
	int (*event_init)(struct perf_event___4 *);
	void (*event_mapped)(struct perf_event___4 *, struct mm_struct___5 *);
	void (*event_unmapped)(struct perf_event___4 *, struct mm_struct___5 *);
	int (*add)(struct perf_event___4 *, int);
	void (*del)(struct perf_event___4 *, int);
	void (*start)(struct perf_event___4 *, int);
	void (*stop)(struct perf_event___4 *, int);
	void (*read)(struct perf_event___4 *);
	void (*start_txn)(struct pmu___4 *, unsigned int);
	int (*commit_txn)(struct pmu___4 *);
	void (*cancel_txn)(struct pmu___4 *);
	int (*event_idx)(struct perf_event___4 *);
	void (*sched_task)(struct perf_event_context___5 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___5 *, struct perf_event_context___5 *);
	void * (*setup_aux)(struct perf_event___4 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___4 *, struct perf_output_handle___4 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___4 *);
	int (*aux_output_match)(struct perf_event___4 *);
	int (*filter_match)(struct perf_event___4 *);
	int (*check_period)(struct perf_event___4 *, u64);
};

struct perf_cpu_context___4 {
	struct perf_event_context___5 ctx;
	struct perf_event_context___5 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___4 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___4 **heap;
	struct perf_event___4 *heap_default[2];
};

struct perf_output_handle___4 {
	struct perf_event___4 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___4 {
	struct cgroup_subsys_state___4 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___4 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___4 *);
	};
};

struct trace_event_class___4 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___4 *, enum trace_reg, void *);
	struct trace_event_fields___4 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___4 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___4 *);
};

struct hash {
	int ino;
	int minor;
	int major;
	umode_t mode;
	struct hash *next;
	char name[4098];
};

struct dir_entry {
	struct list_head list;
	char *name;
	time64_t mtime;
};

enum state {
	Start = 0,
	Collect = 1,
	GotHeader = 2,
	SkipIt = 3,
	GotName = 4,
	CopyFile = 5,
	GotSymlink = 6,
	Reset = 7,
};

typedef int (*decompress_fn)(unsigned char *, long int, long int (*)(void *, long unsigned int), long int (*)(void *, long unsigned int), unsigned char *, long int *, void (*)(char *));

struct dentry___6;

struct super_block___6;

struct module___7;

struct file_system_type___5 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___6 * (*mount)(struct file_system_type___5 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___6 *);
	struct module___7 *owner;
	struct file_system_type___5 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___6;

struct kiocb___5;

struct iov_iter___4;

struct poll_table_struct___5;

struct vm_area_struct___5;

struct inode___7;

struct file_lock___5;

struct page___6;

struct pipe_inode_info___3;

struct seq_file___8;

struct file_operations___5 {
	struct module___7 *owner;
	loff_t (*llseek)(struct file___6 *, loff_t, int);
	ssize_t (*read)(struct file___6 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___6 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___5 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___5 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___5 *, bool);
	int (*iterate)(struct file___6 *, struct dir_context *);
	int (*iterate_shared)(struct file___6 *, struct dir_context *);
	__poll_t (*poll)(struct file___6 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___6 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___6 *, struct vm_area_struct___5 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___7 *, struct file___6 *);
	int (*flush)(struct file___6 *, fl_owner_t);
	int (*release)(struct inode___7 *, struct file___6 *);
	int (*fsync)(struct file___6 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___6 *, int);
	int (*lock)(struct file___6 *, int, struct file_lock___5 *);
	ssize_t (*sendpage)(struct file___6 *, struct page___6 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___6 *, long unsigned int);
	int (*flock)(struct file___6 *, int, struct file_lock___5 *);
	ssize_t (*splice_write)(struct pipe_inode_info___3 *, struct file___6 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___6 *, loff_t *, struct pipe_inode_info___3 *, size_t, unsigned int);
	int (*setlease)(struct file___6 *, long int, struct file_lock___5 **, void **);
	long int (*fallocate)(struct file___6 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___8 *, struct file___6 *);
	ssize_t (*copy_file_range)(struct file___6 *, loff_t, struct file___6 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___6 *, loff_t, struct file___6 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___6 *, loff_t, loff_t, int);
};

struct vmacache___5 {
	u64 seqnum;
	struct vm_area_struct___5 *vmas[4];
};

struct page_frag___5 {
	struct page___6 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___6;

struct pid___5;

struct nsproxy___6;

struct signal_struct___6;

struct vm_struct___6;

struct task_struct___7 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___7 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___6 *mm;
	struct mm_struct___6 *active_mm;
	struct vmacache___5 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___7 *real_parent;
	struct task_struct___7 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___7 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___5 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___6 *nsproxy;
	struct signal_struct___6 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___7 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___3 *splice_pipe;
	struct page_frag___5 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___7 *oom_reaper_list;
	struct vm_struct___6 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___5;

struct kobj_type___5;

struct kernfs_node___5;

struct kobject___5 {
	const char *name;
	struct list_head entry;
	struct kobject___5 *parent;
	struct kset___5 *kset;
	struct kobj_type___5 *ktype;
	struct kernfs_node___5 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___5 {
	struct kobject___5 kobj;
	struct module___7 *mod;
	struct kobject___5 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___5 {
	struct module___7 *mod;
	struct latch_tree_node node;
};

struct module_layout___5 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___5 mtn;
};

struct module_attribute___5;

struct kernel_param___5;

struct trace_event_call___5;

struct module___7 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___5 mkobj;
	struct module_attribute___5 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___5 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___5 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___5 core_layout;
	struct module_layout___5 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___5;

struct upid___5 {
	int nr;
	struct pid_namespace___5 *ns;
};

struct pid_namespace___5 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___7 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___5 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___5 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___5 numbers[1];
};

typedef struct page___6 *pgtable_t___5;

struct address_space___5;

struct page_pool___3;

struct dev_pagemap___5;

struct page___6 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___5 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___6 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___5 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___6 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___5 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___5;

struct vm_area_struct___5 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___5 *vm_next;
	struct vm_area_struct___5 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___6 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___5 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___6 *vm_file;
	struct file___6 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___6 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___7 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___7 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___5 *pids[4];
	struct pid___5 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___6 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___5;

struct mm_struct___6 {
	struct {
		struct vm_area_struct___5 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___6 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___5 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___7 *owner;
		struct user_namespace *user_ns;
		struct file___6 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___6 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___5 *pid_ns_for_children;
	struct net___2 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___5;

struct pipe_buffer___3;

struct pipe_inode_info___3 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___6 *tmp_page;
	struct fasync_struct___5 *fasync_readers;
	struct fasync_struct___5 *fasync_writers;
	struct pipe_buffer___3 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___6 {
	struct vm_struct___6 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___6 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___5;

struct address_space___5 {
	struct inode___7 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___5 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___5;

struct page_pool_params___3 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___5 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___3 {
	u32 count;
	struct page___6 *cache[128];
};

struct page_pool___3 {
	struct page_pool_params___3 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___6 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___3 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___5;

struct dev_pagemap___5 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___5 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___5;

struct path___5 {
	struct vfsmount___5 *mnt;
	struct dentry___6 *dentry;
};

struct fown_struct___5 {
	rwlock_t lock;
	struct pid___5 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___6 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___5 f_path;
	struct inode___7 *f_inode;
	const struct file_operations___5 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___5 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___5 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___5;

struct vm_operations_struct___5 {
	void (*open)(struct vm_area_struct___5 *);
	void (*close)(struct vm_area_struct___5 *);
	int (*may_split)(struct vm_area_struct___5 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___5 *);
	int (*mprotect)(struct vm_area_struct___5 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___5 *);
	vm_fault_t (*huge_fault)(struct vm_fault___5 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___5 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___5 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___5 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___5 *);
	int (*access)(struct vm_area_struct___5 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___5 *);
	int (*set_policy)(struct vm_area_struct___5 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___5 *, long unsigned int);
	struct page___6 * (*find_special_page)(struct vm_area_struct___5 *, long unsigned int);
};

struct core_thread___5 {
	struct task_struct___7 *task;
	struct core_thread___5 *next;
};

struct core_state___5 {
	atomic_t nr_threads;
	struct core_thread___5 dumper;
	struct completion startup;
};

struct vm_fault___5 {
	const struct {
		struct vm_area_struct___5 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___6 *cow_page;
	struct page___6 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___5 prealloc_pte;
};

struct fwnode_operations___5;

struct fwnode_handle___5 {
	struct fwnode_handle___5 *secondary;
	const struct fwnode_operations___5 *ops;
	struct device___5 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___5;

struct fwnode_endpoint___5;

struct fwnode_operations___5 {
	struct fwnode_handle___5 * (*get)(struct fwnode_handle___5 *);
	void (*put)(struct fwnode_handle___5 *);
	bool (*device_is_available)(const struct fwnode_handle___5 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___5 *, const struct device___5 *);
	bool (*property_present)(const struct fwnode_handle___5 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___5 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___5 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___5 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_parent)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_next_child_node)(const struct fwnode_handle___5 *, struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*get_named_child_node)(const struct fwnode_handle___5 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___5 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___5 *);
	struct fwnode_handle___5 * (*graph_get_next_endpoint)(const struct fwnode_handle___5 *, struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*graph_get_remote_endpoint)(const struct fwnode_handle___5 *);
	struct fwnode_handle___5 * (*graph_get_port_parent)(struct fwnode_handle___5 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___5 *, struct fwnode_endpoint___5 *);
	int (*add_links)(struct fwnode_handle___5 *);
};

struct wakeup_source___5;

struct dev_pm_info___5 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___5 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___5 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___5;

struct bus_type___5;

struct device_driver___5;

struct dev_pm_domain___5;

struct class___5;

struct attribute_group___5;

struct device___5 {
	struct kobject___5 kobj;
	struct device___5 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___5 *type;
	struct bus_type___5 *bus;
	struct device_driver___5 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___5 power;
	struct dev_pm_domain___5 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___5 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___5 *class;
	const struct attribute_group___5 **groups;
	void (*release)(struct device___5 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___5 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___5 *local_fwnode;
};

struct fwnode_reference_args___5 {
	struct fwnode_handle___5 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___6;

struct seq_file___8 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___6 *op;
	int poll_event;
	const struct file___6 *file;
	void *private;
};

struct kernfs_root___5;

struct kernfs_elem_dir___5 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___5 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___5;

struct kernfs_root___5 {
	struct kernfs_node___5 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___5 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___5 {
	struct kernfs_node___5 *target_kn;
};

struct kernfs_ops___5;

struct kernfs_elem_attr___5 {
	const struct kernfs_ops___5 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___5 *notify_next;
};

struct kernfs_node___5 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___5 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___5 dir;
		struct kernfs_elem_symlink___5 symlink;
		struct kernfs_elem_attr___5 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___5;

struct kernfs_ops___5 {
	int (*open)(struct kernfs_open_file___5 *);
	void (*release)(struct kernfs_open_file___5 *);
	int (*seq_show)(struct seq_file___8 *, void *);
	void * (*seq_start)(struct seq_file___8 *, loff_t *);
	void * (*seq_next)(struct seq_file___8 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___8 *, void *);
	ssize_t (*read)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___5 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___5 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___5 *, struct vm_area_struct___5 *);
};

struct kernfs_syscall_ops___5 {
	int (*show_options)(struct seq_file___8 *, struct kernfs_root___5 *);
	int (*mkdir)(struct kernfs_node___5 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___5 *);
	int (*rename)(struct kernfs_node___5 *, struct kernfs_node___5 *, const char *);
	int (*show_path)(struct seq_file___8 *, struct kernfs_node___5 *, struct kernfs_root___5 *);
};

struct kernfs_open_file___5 {
	struct kernfs_node___5 *kn;
	struct file___6 *file;
	struct seq_file___8 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___5 *vm_ops;
};

struct bin_attribute___5;

struct attribute_group___5 {
	const char *name;
	umode_t (*is_visible)(struct kobject___5 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___5 *, struct bin_attribute___5 *, int);
	struct attribute **attrs;
	struct bin_attribute___5 **bin_attrs;
};

struct bin_attribute___5 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___5 * (*f_mapping)();
	ssize_t (*read)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, char *, loff_t, size_t);
	int (*mmap)(struct file___6 *, struct kobject___5 *, struct bin_attribute___5 *, struct vm_area_struct___5 *);
};

struct sysfs_ops___5 {
	ssize_t (*show)(struct kobject___5 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___5 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___5;

struct kset___5 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___5 kobj;
	const struct kset_uevent_ops___5 *uevent_ops;
};

struct kobj_type___5 {
	void (*release)(struct kobject___5 *);
	const struct sysfs_ops___5 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___5 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___5 *);
	const void * (*namespace)(struct kobject___5 *);
	void (*get_ownership)(struct kobject___5 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___5 {
	int (* const filter)(struct kset___5 *, struct kobject___5 *);
	const char * (* const name)(struct kset___5 *, struct kobject___5 *);
	int (* const uevent)(struct kset___5 *, struct kobject___5 *, struct kobj_uevent_env *);
};

struct dev_pagemap_ops___5 {
	void (*page_free)(struct page___6 *);
	void (*kill)(struct dev_pagemap___5 *);
	void (*cleanup)(struct dev_pagemap___5 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___5 *);
};

struct dentry_operations___5;

struct dentry___6 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___6 *d_parent;
	struct qstr d_name;
	struct inode___7 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___5 *d_op;
	struct super_block___6 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___5;

struct inode___7 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___5 *i_op;
	struct super_block___6 *i_sb;
	struct address_space___5 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___5 *i_fop;
		void (*free_inode)(struct inode___7 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___5 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___3 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___5 {
	int (*d_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___6 *, unsigned int);
	int (*d_hash)(const struct dentry___6 *, struct qstr *);
	int (*d_compare)(const struct dentry___6 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___6 *);
	int (*d_init)(struct dentry___6 *);
	void (*d_release)(struct dentry___6 *);
	void (*d_prune)(struct dentry___6 *);
	void (*d_iput)(struct dentry___6 *, struct inode___7 *);
	char * (*d_dname)(struct dentry___6 *, char *, int);
	struct vfsmount___5 * (*d_automount)(struct path___5 *);
	int (*d_manage)(const struct path___5 *, bool);
	struct dentry___6 * (*d_real)(struct dentry___6 *, const struct inode___7 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___5;

struct mem_dqinfo___5 {
	struct quota_format_type___5 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___5;

struct quota_info___5 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___7 *files[3];
	struct mem_dqinfo___5 info[3];
	const struct quota_format_ops___5 *ops[3];
};

struct rcuwait___5 {
	struct task_struct___7 *task;
};

struct percpu_rw_semaphore___5 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___5 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___5 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___5 rw_sem[3];
};

struct super_operations___5;

struct dquot_operations___5;

struct quotactl_ops___5;

struct super_block___6 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___5 *s_type;
	const struct super_operations___5 *s_op;
	const struct dquot_operations___5 *dq_op;
	const struct quotactl_ops___5 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___6 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___5 s_dquot;
	struct sb_writers___5 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___5 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___5 {
	struct dentry___6 *mnt_root;
	struct super_block___6 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___5 {
	struct file___6 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___5 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___6 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___6 *ia_file;
};

struct dquot___5 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___6 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___5 {
	int qf_fmt_id;
	const struct quota_format_ops___5 *qf_ops;
	struct module___7 *qf_owner;
	struct quota_format_type___5 *qf_next;
};

struct quota_format_ops___5 {
	int (*check_quota_file)(struct super_block___6 *, int);
	int (*read_file_info)(struct super_block___6 *, int);
	int (*write_file_info)(struct super_block___6 *, int);
	int (*free_file_info)(struct super_block___6 *, int);
	int (*read_dqblk)(struct dquot___5 *);
	int (*commit_dqblk)(struct dquot___5 *);
	int (*release_dqblk)(struct dquot___5 *);
	int (*get_next_id)(struct super_block___6 *, struct kqid *);
};

struct dquot_operations___5 {
	int (*write_dquot)(struct dquot___5 *);
	struct dquot___5 * (*alloc_dquot)(struct super_block___6 *, int);
	void (*destroy_dquot)(struct dquot___5 *);
	int (*acquire_dquot)(struct dquot___5 *);
	int (*release_dquot)(struct dquot___5 *);
	int (*mark_dirty)(struct dquot___5 *);
	int (*write_info)(struct super_block___6 *, int);
	qsize_t * (*get_reserved_space)(struct inode___7 *);
	int (*get_projid)(struct inode___7 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___7 *, qsize_t *);
	int (*get_next_id)(struct super_block___6 *, struct kqid *);
};

struct quotactl_ops___5 {
	int (*quota_on)(struct super_block___6 *, int, int, const struct path___5 *);
	int (*quota_off)(struct super_block___6 *, int);
	int (*quota_enable)(struct super_block___6 *, unsigned int);
	int (*quota_disable)(struct super_block___6 *, unsigned int);
	int (*quota_sync)(struct super_block___6 *, int);
	int (*set_info)(struct super_block___6 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___6 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___6 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___6 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___6 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___6 *, unsigned int);
};

struct address_space_operations___5 {
	int (*writepage)(struct page___6 *, struct writeback_control___3 *);
	int (*readpage)(struct file___6 *, struct page___6 *);
	int (*writepages)(struct address_space___5 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___6 *);
	int (*readpages)(struct file___6 *, struct address_space___5 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___6 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___6 **, void **);
	int (*write_end)(struct file___6 *, struct address_space___5 *, loff_t, unsigned int, unsigned int, struct page___6 *, void *);
	sector_t (*bmap)(struct address_space___5 *, sector_t);
	void (*invalidatepage)(struct page___6 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___6 *, gfp_t);
	void (*freepage)(struct page___6 *);
	ssize_t (*direct_IO)(struct kiocb___5 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___5 *, struct page___6 *, struct page___6 *, enum migrate_mode);
	bool (*isolate_page)(struct page___6 *, isolate_mode_t);
	void (*putback_page)(struct page___6 *);
	int (*launder_page)(struct page___6 *);
	int (*is_partially_uptodate)(struct page___6 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___6 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___5 *, struct page___6 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___6 *, sector_t *);
	void (*swap_deactivate)(struct file___6 *);
};

struct bio_vec___4;

struct iov_iter___4 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___4 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___3 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___5 {
	struct dentry___6 * (*lookup)(struct inode___7 *, struct dentry___6 *, unsigned int);
	const char * (*get_link)(struct dentry___6 *, struct inode___7 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___7 *, int);
	struct posix_acl * (*get_acl)(struct inode___7 *, int, bool);
	int (*readlink)(struct dentry___6 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___7 *, struct dentry___6 *, umode_t, bool);
	int (*link)(struct dentry___6 *, struct inode___7 *, struct dentry___6 *);
	int (*unlink)(struct inode___7 *, struct dentry___6 *);
	int (*symlink)(struct user_namespace *, struct inode___7 *, struct dentry___6 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___7 *, struct dentry___6 *, umode_t);
	int (*rmdir)(struct inode___7 *, struct dentry___6 *);
	int (*mknod)(struct user_namespace *, struct inode___7 *, struct dentry___6 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___7 *, struct dentry___6 *, struct inode___7 *, struct dentry___6 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___6 *, struct iattr___6 *);
	int (*getattr)(struct user_namespace *, const struct path___5 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___6 *, char *, size_t);
	int (*fiemap)(struct inode___7 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___7 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___7 *, struct dentry___6 *, struct file___6 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___7 *, struct dentry___6 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___7 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___6 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___6 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___5 {
	void (*fl_copy_lock)(struct file_lock___5 *, struct file_lock___5 *);
	void (*fl_release_private)(struct file_lock___5 *);
};

struct lock_manager_operations___5;

struct file_lock___5 {
	struct file_lock___5 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___6 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___5 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___5 *fl_ops;
	const struct lock_manager_operations___5 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___5 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___5 *);
	int (*lm_grant)(struct file_lock___5 *, int);
	bool (*lm_break)(struct file_lock___5 *);
	int (*lm_change)(struct file_lock___5 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___5 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___5 *);
};

struct fasync_struct___5 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___5 *fa_next;
	struct file___6 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___5 {
	struct inode___7 * (*alloc_inode)(struct super_block___6 *);
	void (*destroy_inode)(struct inode___7 *);
	void (*free_inode)(struct inode___7 *);
	void (*dirty_inode)(struct inode___7 *, int);
	int (*write_inode)(struct inode___7 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___7 *);
	void (*evict_inode)(struct inode___7 *);
	void (*put_super)(struct super_block___6 *);
	int (*sync_fs)(struct super_block___6 *, int);
	int (*freeze_super)(struct super_block___6 *);
	int (*freeze_fs)(struct super_block___6 *);
	int (*thaw_super)(struct super_block___6 *);
	int (*unfreeze_fs)(struct super_block___6 *);
	int (*statfs)(struct dentry___6 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___6 *, int *, char *);
	void (*umount_begin)(struct super_block___6 *);
	int (*show_options)(struct seq_file___8 *, struct dentry___6 *);
	int (*show_devname)(struct seq_file___8 *, struct dentry___6 *);
	int (*show_path)(struct seq_file___8 *, struct dentry___6 *);
	int (*show_stats)(struct seq_file___8 *, struct dentry___6 *);
	ssize_t (*quota_read)(struct super_block___6 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___6 *, int, const char *, size_t, loff_t);
	struct dquot___5 ** (*get_dquots)(struct inode___7 *);
	long int (*nr_cached_objects)(struct super_block___6 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___6 *, struct shrink_control___2 *);
	struct file___6 * (*real_loop)(struct file___6 *);
};

struct kernel_param_ops___5 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___5 *);
	int (*get)(char *, const struct kernel_param___5 *);
	void (*free)(void *);
};

struct kparam_array___5;

struct kernel_param___5 {
	const char *name;
	struct module___7 *mod;
	const struct kernel_param_ops___5 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___5 *arr;
	};
};

struct kparam_array___5 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___5 *ops;
	void *elem;
};

struct module_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___5 *, struct module_kobject___5 *, char *);
	ssize_t (*store)(struct module_attribute___5 *, struct module_kobject___5 *, const char *, size_t);
	void (*setup)(struct module___7 *, const char *);
	int (*test)(struct module___7 *);
	void (*free)(struct module___7 *);
};

struct bio_vec___4 {
	struct page___6 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct seq_operations___6 {
	void * (*start)(struct seq_file___8 *, loff_t *);
	void (*stop)(struct seq_file___8 *, void *);
	void * (*next)(struct seq_file___8 *, void *, loff_t *);
	int (*show)(struct seq_file___8 *, void *);
};

struct dev_pm_ops___5 {
	int (*prepare)(struct device___5 *);
	void (*complete)(struct device___5 *);
	int (*suspend)(struct device___5 *);
	int (*resume)(struct device___5 *);
	int (*freeze)(struct device___5 *);
	int (*thaw)(struct device___5 *);
	int (*poweroff)(struct device___5 *);
	int (*restore)(struct device___5 *);
	int (*suspend_late)(struct device___5 *);
	int (*resume_early)(struct device___5 *);
	int (*freeze_late)(struct device___5 *);
	int (*thaw_early)(struct device___5 *);
	int (*poweroff_late)(struct device___5 *);
	int (*restore_early)(struct device___5 *);
	int (*suspend_noirq)(struct device___5 *);
	int (*resume_noirq)(struct device___5 *);
	int (*freeze_noirq)(struct device___5 *);
	int (*thaw_noirq)(struct device___5 *);
	int (*poweroff_noirq)(struct device___5 *);
	int (*restore_noirq)(struct device___5 *);
	int (*runtime_suspend)(struct device___5 *);
	int (*runtime_resume)(struct device___5 *);
	int (*runtime_idle)(struct device___5 *);
};

struct wakeup_source___5 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___5 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___5 {
	struct dev_pm_ops___5 ops;
	int (*start)(struct device___5 *);
	void (*detach)(struct device___5 *, bool);
	int (*activate)(struct device___5 *);
	void (*sync)(struct device___5 *);
	void (*dismiss)(struct device___5 *);
};

struct bus_type___5 {
	const char *name;
	const char *dev_name;
	struct device___5 *dev_root;
	const struct attribute_group___5 **bus_groups;
	const struct attribute_group___5 **dev_groups;
	const struct attribute_group___5 **drv_groups;
	int (*match)(struct device___5 *, struct device_driver___5 *);
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	int (*probe)(struct device___5 *);
	void (*sync_state)(struct device___5 *);
	void (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*online)(struct device___5 *);
	int (*offline)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	int (*num_vf)(struct device___5 *);
	int (*dma_configure)(struct device___5 *);
	const struct dev_pm_ops___5 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___5 {
	const char *name;
	struct bus_type___5 *bus;
	struct module___7 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___5 *);
	void (*sync_state)(struct device___5 *);
	int (*remove)(struct device___5 *);
	void (*shutdown)(struct device___5 *);
	int (*suspend)(struct device___5 *, pm_message_t);
	int (*resume)(struct device___5 *);
	const struct attribute_group___5 **groups;
	const struct attribute_group___5 **dev_groups;
	const struct dev_pm_ops___5 *pm;
	void (*coredump)(struct device___5 *);
	struct driver_private *p;
};

struct device_type___5 {
	const char *name;
	const struct attribute_group___5 **groups;
	int (*uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___5 *);
	const struct dev_pm_ops___5 *pm;
};

struct class___5 {
	const char *name;
	struct module___7 *owner;
	const struct attribute_group___5 **class_groups;
	const struct attribute_group___5 **dev_groups;
	struct kobject___5 *dev_kobj;
	int (*dev_uevent)(struct device___5 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___5 *, umode_t *);
	void (*class_release)(struct class___5 *);
	void (*dev_release)(struct device___5 *);
	int (*shutdown_pre)(struct device___5 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___5 *);
	void (*get_ownership)(struct device___5 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___5 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___3;

struct pipe_buffer___3 {
	struct page___6 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___3 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___3 {
	int (*confirm)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	void (*release)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	bool (*try_steal)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
	bool (*get)(struct pipe_inode_info___3 *, struct pipe_buffer___3 *);
};

enum audit_ntp_type {
	AUDIT_NTP_OFFSET = 0,
	AUDIT_NTP_FREQ = 1,
	AUDIT_NTP_STATUS = 2,
	AUDIT_NTP_TAI = 3,
	AUDIT_NTP_TICK = 4,
	AUDIT_NTP_ADJUST = 5,
	AUDIT_NTP_NVALS = 6,
};

typedef long unsigned int uintptr_t;

struct dentry___7;

struct super_block___7;

struct module___8;

struct file_system_type___6 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___7 * (*mount)(struct file_system_type___6 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___7 *);
	struct module___8 *owner;
	struct file_system_type___6 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___7;

struct kiocb___6;

struct vm_area_struct___6;

struct inode___8;

struct file_lock___6;

struct page___7;

struct seq_file___9;

struct file_operations___6 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___7 *, loff_t, int);
	ssize_t (*read)(struct file___7 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___7 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___6 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___6 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___6 *, bool);
	int (*iterate)(struct file___7 *, struct dir_context *);
	int (*iterate_shared)(struct file___7 *, struct dir_context *);
	__poll_t (*poll)(struct file___7 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___7 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___7 *, struct vm_area_struct___6 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___8 *, struct file___7 *);
	int (*flush)(struct file___7 *, fl_owner_t);
	int (*release)(struct inode___8 *, struct file___7 *);
	int (*fsync)(struct file___7 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___7 *, int);
	int (*lock)(struct file___7 *, int, struct file_lock___6 *);
	ssize_t (*sendpage)(struct file___7 *, struct page___7 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___7 *, long unsigned int);
	int (*flock)(struct file___7 *, int, struct file_lock___6 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___7 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___7 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___7 *, long int, struct file_lock___6 **, void **);
	long int (*fallocate)(struct file___7 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___7 *);
	ssize_t (*copy_file_range)(struct file___7 *, loff_t, struct file___7 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___7 *, loff_t, struct file___7 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___7 *, loff_t, loff_t, int);
};

struct sched_dl_entity___3 {
	struct rb_node rb_node;
	u64 dl_runtime;
	u64 dl_deadline;
	u64 dl_period;
	u64 dl_bw;
	u64 dl_density;
	s64 runtime;
	u64 deadline;
	unsigned int flags;
	unsigned int dl_throttled;
	unsigned int dl_yielded;
	unsigned int dl_non_contending;
	unsigned int dl_overrun;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer dl_timer;
	struct hrtimer inactive_timer;
	struct sched_dl_entity___3 *pi_se;
};

struct vmacache___6 {
	u64 seqnum;
	struct vm_area_struct___6 *vmas[4];
};

struct page_frag___6 {
	struct page___7 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___7;

struct pid___6;

struct nsproxy___7;

struct signal_struct___7;

struct vm_struct___7;

struct task_struct___8 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___8 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___7 *mm;
	struct mm_struct___7 *active_mm;
	struct vmacache___6 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___8 *real_parent;
	struct task_struct___8 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___8 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___6 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___7 *nsproxy;
	struct signal_struct___7 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___8 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___6 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___8 *oom_reaper_list;
	struct vm_struct___7 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___4 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___6;

struct kobj_type___6;

struct kernfs_node___6;

struct kobject___6 {
	const char *name;
	struct list_head entry;
	struct kobject___6 *parent;
	struct kset___6 *kset;
	struct kobj_type___6 *ktype;
	struct kernfs_node___6 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___6 {
	struct kobject___6 kobj;
	struct module___8 *mod;
	struct kobject___6 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___6 {
	struct module___8 *mod;
	struct latch_tree_node node;
};

struct module_layout___6 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___6 mtn;
};

struct module_attribute___6;

struct kernel_param___6;

struct module___8 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___6 mkobj;
	struct module_attribute___6 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___6 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___6 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___6 core_layout;
	struct module_layout___6 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___6;

struct upid___6 {
	int nr;
	struct pid_namespace___6 *ns;
};

struct pid_namespace___6 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___8 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___6 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___6 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___6 numbers[1];
};

typedef struct page___7 *pgtable_t___6;

struct address_space___6;

struct dev_pagemap___6;

struct page___7 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___6 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___7 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___6 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___7 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___6 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___6;

struct vm_area_struct___6 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___6 *vm_next;
	struct vm_area_struct___6 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___7 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___6 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___7 *vm_file;
	struct file___7 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___7 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___8 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___8 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___6 *pids[4];
	struct pid___6 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___7 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

enum perf_event_task_context___2 {
	perf_invalid_context___2 = 0,
	perf_hw_context___2 = 0,
	perf_sw_context___2 = 1,
	perf_nr_task_contexts___2 = 2,
};

struct core_state___6;

struct mm_struct___7 {
	struct {
		struct vm_area_struct___6 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___7 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___6 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___8 *owner;
		struct user_namespace *user_ns;
		struct file___7 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___7 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___6 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___7 {
	struct vm_struct___7 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___7 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct step_hook {
	struct list_head node;
	int (*fn)(struct pt_regs *, unsigned int);
};

struct break_hook {
	struct list_head node;
	int (*fn)(struct pt_regs *, unsigned int);
	u16 imm;
	u16 mask;
};

enum dbg_active_el {
	DBG_ACTIVE_EL0 = 0,
	DBG_ACTIVE_EL1 = 1,
};

struct address_space_operations___6;

struct address_space___6 {
	struct inode___8 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___6 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___6;

struct dev_pagemap___6 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___6 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___6;

struct path___6 {
	struct vfsmount___6 *mnt;
	struct dentry___7 *dentry;
};

struct fown_struct___6 {
	rwlock_t lock;
	struct pid___6 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___7 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___6 f_path;
	struct inode___8 *f_inode;
	const struct file_operations___6 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___6 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___6 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___6;

struct vm_operations_struct___6 {
	void (*open)(struct vm_area_struct___6 *);
	void (*close)(struct vm_area_struct___6 *);
	int (*may_split)(struct vm_area_struct___6 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___6 *);
	int (*mprotect)(struct vm_area_struct___6 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___6 *);
	vm_fault_t (*huge_fault)(struct vm_fault___6 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___6 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___6 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___6 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___6 *);
	int (*access)(struct vm_area_struct___6 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___6 *);
	int (*set_policy)(struct vm_area_struct___6 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___6 *, long unsigned int);
	struct page___7 * (*find_special_page)(struct vm_area_struct___6 *, long unsigned int);
};

struct core_thread___6 {
	struct task_struct___8 *task;
	struct core_thread___6 *next;
};

struct core_state___6 {
	atomic_t nr_threads;
	struct core_thread___6 dumper;
	struct completion startup;
};

struct vm_fault___6 {
	const struct {
		struct vm_area_struct___6 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___7 *cow_page;
	struct page___7 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___6 prealloc_pte;
};

enum migratetype {
	MIGRATE_UNMOVABLE = 0,
	MIGRATE_MOVABLE = 1,
	MIGRATE_RECLAIMABLE = 2,
	MIGRATE_PCPTYPES = 3,
	MIGRATE_HIGHATOMIC = 3,
	MIGRATE_CMA = 4,
	MIGRATE_ISOLATE = 5,
	MIGRATE_TYPES = 6,
};

enum numa_stat_item {
	NUMA_HIT = 0,
	NUMA_MISS = 1,
	NUMA_FOREIGN = 2,
	NUMA_INTERLEAVE_HIT = 3,
	NUMA_LOCAL = 4,
	NUMA_OTHER = 5,
	NR_VM_NUMA_EVENT_ITEMS = 6,
};

enum zone_stat_item {
	NR_FREE_PAGES = 0,
	NR_ZONE_LRU_BASE = 1,
	NR_ZONE_INACTIVE_ANON = 1,
	NR_ZONE_ACTIVE_ANON = 2,
	NR_ZONE_INACTIVE_FILE = 3,
	NR_ZONE_ACTIVE_FILE = 4,
	NR_ZONE_UNEVICTABLE = 5,
	NR_ZONE_WRITE_PENDING = 6,
	NR_MLOCK = 7,
	NR_BOUNCE = 8,
	NR_ZSPAGES = 9,
	NR_FREE_CMA_PAGES = 10,
	NR_VM_ZONE_STAT_ITEMS = 11,
};

enum zone_watermarks {
	WMARK_MIN = 0,
	WMARK_LOW = 1,
	WMARK_HIGH = 2,
	NR_WMARK = 3,
};

enum {
	ZONELIST_FALLBACK = 0,
	ZONELIST_NOFALLBACK = 1,
	MAX_ZONELISTS = 2,
};

struct kernfs_root___6;

struct kernfs_elem_dir___6 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___6 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___6;

struct kernfs_root___6 {
	struct kernfs_node___6 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___6 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___6 {
	struct kernfs_node___6 *target_kn;
};

struct kernfs_ops___6;

struct kernfs_elem_attr___6 {
	const struct kernfs_ops___6 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___6 *notify_next;
};

struct kernfs_node___6 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___6 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___6 dir;
		struct kernfs_elem_symlink___6 symlink;
		struct kernfs_elem_attr___6 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___6;

struct kernfs_ops___6 {
	int (*open)(struct kernfs_open_file___6 *);
	void (*release)(struct kernfs_open_file___6 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___6 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___6 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___6 *, struct vm_area_struct___6 *);
};

struct kernfs_syscall_ops___6 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___6 *);
	int (*mkdir)(struct kernfs_node___6 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___6 *);
	int (*rename)(struct kernfs_node___6 *, struct kernfs_node___6 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___6 *, struct kernfs_root___6 *);
};

struct seq_operations___7;

struct seq_file___9 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___7 *op;
	int poll_event;
	const struct file___7 *file;
	void *private;
};

struct kernfs_open_file___6 {
	struct kernfs_node___6 *kn;
	struct file___7 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___6 *vm_ops;
};

struct bin_attribute___6;

struct attribute_group___6 {
	const char *name;
	umode_t (*is_visible)(struct kobject___6 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___6 *, struct bin_attribute___6 *, int);
	struct attribute **attrs;
	struct bin_attribute___6 **bin_attrs;
};

struct bin_attribute___6 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___6 * (*f_mapping)();
	ssize_t (*read)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, char *, loff_t, size_t);
	int (*mmap)(struct file___7 *, struct kobject___6 *, struct bin_attribute___6 *, struct vm_area_struct___6 *);
};

struct sysfs_ops___6 {
	ssize_t (*show)(struct kobject___6 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___6 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___6;

struct kset___6 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___6 kobj;
	const struct kset_uevent_ops___6 *uevent_ops;
};

struct kobj_type___6 {
	void (*release)(struct kobject___6 *);
	const struct sysfs_ops___6 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___6 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___6 *);
	const void * (*namespace)(struct kobject___6 *);
	void (*get_ownership)(struct kobject___6 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___6 {
	int (* const filter)(struct kset___6 *, struct kobject___6 *);
	const char * (* const name)(struct kset___6 *, struct kobject___6 *);
	int (* const uevent)(struct kset___6 *, struct kobject___6 *, struct kobj_uevent_env *);
};

enum cpu_idle_type {
	CPU_IDLE = 0,
	CPU_NOT_IDLE = 1,
	CPU_NEWLY_IDLE = 2,
	CPU_MAX_IDLE_TYPES = 3,
};

enum {
	__SD_BALANCE_NEWIDLE = 0,
	__SD_BALANCE_EXEC = 1,
	__SD_BALANCE_FORK = 2,
	__SD_BALANCE_WAKE = 3,
	__SD_WAKE_AFFINE = 4,
	__SD_ASYM_CPUCAPACITY = 5,
	__SD_ASYM_CPUCAPACITY_FULL = 6,
	__SD_SHARE_CPUCAPACITY = 7,
	__SD_SHARE_PKG_RESOURCES = 8,
	__SD_SERIALIZE = 9,
	__SD_ASYM_PACKING = 10,
	__SD_PREFER_SIBLING = 11,
	__SD_OVERLAP = 12,
	__SD_NUMA = 13,
	__SD_FLAG_CNT = 14,
};

enum cpuhp_state___2 {
	CPUHP_INVALID___2 = 0,
	CPUHP_OFFLINE___2 = 0,
	CPUHP_CREATE_THREADS___2 = 1,
	CPUHP_PERF_PREPARE___2 = 2,
	CPUHP_PERF_X86_PREPARE___2 = 3,
	CPUHP_PERF_X86_AMD_UNCORE_PREP___2 = 4,
	CPUHP_PERF_POWER___2 = 5,
	CPUHP_PERF_SUPERH___2 = 6,
	CPUHP_X86_HPET_DEAD___2 = 7,
	CPUHP_X86_APB_DEAD___2 = 8,
	CPUHP_X86_MCE_DEAD___2 = 9,
	CPUHP_VIRT_NET_DEAD___2 = 10,
	CPUHP_SLUB_DEAD___2 = 11,
	CPUHP_DEBUG_OBJ_DEAD___2 = 12,
	CPUHP_MM_WRITEBACK_DEAD___2 = 13,
	CPUHP_MM_DEMOTION_DEAD___2 = 14,
	CPUHP_MM_VMSTAT_DEAD___2 = 15,
	CPUHP_SOFTIRQ_DEAD___2 = 16,
	CPUHP_NET_MVNETA_DEAD___2 = 17,
	CPUHP_CPUIDLE_DEAD___2 = 18,
	CPUHP_ARM64_FPSIMD_DEAD___2 = 19,
	CPUHP_ARM_OMAP_WAKE_DEAD___2 = 20,
	CPUHP_IRQ_POLL_DEAD___2 = 21,
	CPUHP_BLOCK_SOFTIRQ_DEAD___2 = 22,
	CPUHP_BIO_DEAD___2 = 23,
	CPUHP_ACPI_CPUDRV_DEAD___2 = 24,
	CPUHP_S390_PFAULT_DEAD___2 = 25,
	CPUHP_BLK_MQ_DEAD___2 = 26,
	CPUHP_FS_BUFF_DEAD___2 = 27,
	CPUHP_PRINTK_DEAD___2 = 28,
	CPUHP_MM_MEMCQ_DEAD___2 = 29,
	CPUHP_XFS_DEAD___2 = 30,
	CPUHP_PERCPU_CNT_DEAD___2 = 31,
	CPUHP_RADIX_DEAD___2 = 32,
	CPUHP_PAGE_ALLOC___2 = 33,
	CPUHP_NET_DEV_DEAD___2 = 34,
	CPUHP_PCI_XGENE_DEAD___2 = 35,
	CPUHP_IOMMU_IOVA_DEAD___2 = 36,
	CPUHP_LUSTRE_CFS_DEAD___2 = 37,
	CPUHP_AP_ARM_CACHE_B15_RAC_DEAD___2 = 38,
	CPUHP_PADATA_DEAD___2 = 39,
	CPUHP_WORKQUEUE_PREP___2 = 40,
	CPUHP_POWER_NUMA_PREPARE___2 = 41,
	CPUHP_HRTIMERS_PREPARE___2 = 42,
	CPUHP_PROFILE_PREPARE___2 = 43,
	CPUHP_X2APIC_PREPARE___2 = 44,
	CPUHP_SMPCFD_PREPARE___2 = 45,
	CPUHP_RELAY_PREPARE___2 = 46,
	CPUHP_SLAB_PREPARE___2 = 47,
	CPUHP_MD_RAID5_PREPARE___2 = 48,
	CPUHP_RCUTREE_PREP___2 = 49,
	CPUHP_CPUIDLE_COUPLED_PREPARE___2 = 50,
	CPUHP_POWERPC_PMAC_PREPARE___2 = 51,
	CPUHP_POWERPC_MMU_CTX_PREPARE___2 = 52,
	CPUHP_XEN_PREPARE___2 = 53,
	CPUHP_XEN_EVTCHN_PREPARE___2 = 54,
	CPUHP_ARM_SHMOBILE_SCU_PREPARE___2 = 55,
	CPUHP_SH_SH3X_PREPARE___2 = 56,
	CPUHP_NET_FLOW_PREPARE___2 = 57,
	CPUHP_TOPOLOGY_PREPARE___2 = 58,
	CPUHP_NET_IUCV_PREPARE___2 = 59,
	CPUHP_ARM_BL_PREPARE___2 = 60,
	CPUHP_TRACE_RB_PREPARE___2 = 61,
	CPUHP_MM_ZS_PREPARE___2 = 62,
	CPUHP_MM_ZSWP_MEM_PREPARE___2 = 63,
	CPUHP_MM_ZSWP_POOL_PREPARE___2 = 64,
	CPUHP_KVM_PPC_BOOK3S_PREPARE___2 = 65,
	CPUHP_ZCOMP_PREPARE___2 = 66,
	CPUHP_TIMERS_PREPARE___2 = 67,
	CPUHP_MIPS_SOC_PREPARE___2 = 68,
	CPUHP_BP_PREPARE_DYN___2 = 69,
	CPUHP_BP_PREPARE_DYN_END___2 = 89,
	CPUHP_BRINGUP_CPU___2 = 90,
	CPUHP_AP_IDLE_DEAD___2 = 91,
	CPUHP_AP_OFFLINE___2 = 92,
	CPUHP_AP_SCHED_STARTING___2 = 93,
	CPUHP_AP_RCUTREE_DYING___2 = 94,
	CPUHP_AP_CPU_PM_STARTING___2 = 95,
	CPUHP_AP_IRQ_GIC_STARTING___2 = 96,
	CPUHP_AP_IRQ_HIP04_STARTING___2 = 97,
	CPUHP_AP_IRQ_APPLE_AIC_STARTING___2 = 98,
	CPUHP_AP_IRQ_ARMADA_XP_STARTING___2 = 99,
	CPUHP_AP_IRQ_BCM2836_STARTING___2 = 100,
	CPUHP_AP_IRQ_MIPS_GIC_STARTING___2 = 101,
	CPUHP_AP_IRQ_RISCV_STARTING___2 = 102,
	CPUHP_AP_IRQ_SIFIVE_PLIC_STARTING___2 = 103,
	CPUHP_AP_ARM_MVEBU_COHERENCY___2 = 104,
	CPUHP_AP_MICROCODE_LOADER___2 = 105,
	CPUHP_AP_PERF_X86_AMD_UNCORE_STARTING___2 = 106,
	CPUHP_AP_PERF_X86_STARTING___2 = 107,
	CPUHP_AP_PERF_X86_AMD_IBS_STARTING___2 = 108,
	CPUHP_AP_PERF_X86_CQM_STARTING___2 = 109,
	CPUHP_AP_PERF_X86_CSTATE_STARTING___2 = 110,
	CPUHP_AP_PERF_XTENSA_STARTING___2 = 111,
	CPUHP_AP_MIPS_OP_LOONGSON3_STARTING___2 = 112,
	CPUHP_AP_ARM_SDEI_STARTING___2 = 113,
	CPUHP_AP_ARM_VFP_STARTING___2 = 114,
	CPUHP_AP_ARM64_DEBUG_MONITORS_STARTING___2 = 115,
	CPUHP_AP_PERF_ARM_HW_BREAKPOINT_STARTING___2 = 116,
	CPUHP_AP_PERF_ARM_ACPI_STARTING___2 = 117,
	CPUHP_AP_PERF_ARM_STARTING___2 = 118,
	CPUHP_AP_ARM_L2X0_STARTING___2 = 119,
	CPUHP_AP_EXYNOS4_MCT_TIMER_STARTING___2 = 120,
	CPUHP_AP_ARM_ARCH_TIMER_STARTING___2 = 121,
	CPUHP_AP_ARM_GLOBAL_TIMER_STARTING___2 = 122,
	CPUHP_AP_JCORE_TIMER_STARTING___2 = 123,
	CPUHP_AP_ARM_TWD_STARTING___2 = 124,
	CPUHP_AP_QCOM_TIMER_STARTING___2 = 125,
	CPUHP_AP_TEGRA_TIMER_STARTING___2 = 126,
	CPUHP_AP_ARMADA_TIMER_STARTING___2 = 127,
	CPUHP_AP_MARCO_TIMER_STARTING___2 = 128,
	CPUHP_AP_MIPS_GIC_TIMER_STARTING___2 = 129,
	CPUHP_AP_ARC_TIMER_STARTING___2 = 130,
	CPUHP_AP_RISCV_TIMER_STARTING___2 = 131,
	CPUHP_AP_CLINT_TIMER_STARTING___2 = 132,
	CPUHP_AP_CSKY_TIMER_STARTING___2 = 133,
	CPUHP_AP_TI_GP_TIMER_STARTING___2 = 134,
	CPUHP_AP_HYPERV_TIMER_STARTING___2 = 135,
	CPUHP_AP_KVM_STARTING___2 = 136,
	CPUHP_AP_KVM_ARM_VGIC_INIT_STARTING___2 = 137,
	CPUHP_AP_KVM_ARM_VGIC_STARTING___2 = 138,
	CPUHP_AP_KVM_ARM_TIMER_STARTING___2 = 139,
	CPUHP_AP_DUMMY_TIMER_STARTING___2 = 140,
	CPUHP_AP_ARM_XEN_STARTING___2 = 141,
	CPUHP_AP_ARM_CORESIGHT_STARTING___2 = 142,
	CPUHP_AP_ARM_CORESIGHT_CTI_STARTING___2 = 143,
	CPUHP_AP_ARM64_ISNDEP_STARTING___2 = 144,
	CPUHP_AP_SMPCFD_DYING___2 = 145,
	CPUHP_AP_X86_TBOOT_DYING___2 = 146,
	CPUHP_AP_ARM_CACHE_B15_RAC_DYING___2 = 147,
	CPUHP_AP_ONLINE___2 = 148,
	CPUHP_TEARDOWN_CPU___2 = 149,
	CPUHP_AP_ONLINE_IDLE___2 = 150,
	CPUHP_AP_SCHED_WAIT_EMPTY___2 = 151,
	CPUHP_AP_SMPBOOT_THREADS___2 = 152,
	CPUHP_AP_X86_VDSO_VMA_ONLINE___2 = 153,
	CPUHP_AP_IRQ_AFFINITY_ONLINE___2 = 154,
	CPUHP_AP_BLK_MQ_ONLINE___2 = 155,
	CPUHP_AP_ARM_MVEBU_SYNC_CLOCKS___2 = 156,
	CPUHP_AP_X86_INTEL_EPB_ONLINE___2 = 157,
	CPUHP_AP_PERF_ONLINE___2 = 158,
	CPUHP_AP_PERF_X86_ONLINE___2 = 159,
	CPUHP_AP_PERF_X86_UNCORE_ONLINE___2 = 160,
	CPUHP_AP_PERF_X86_AMD_UNCORE_ONLINE___2 = 161,
	CPUHP_AP_PERF_X86_AMD_POWER_ONLINE___2 = 162,
	CPUHP_AP_PERF_X86_RAPL_ONLINE___2 = 163,
	CPUHP_AP_PERF_X86_CQM_ONLINE___2 = 164,
	CPUHP_AP_PERF_X86_CSTATE_ONLINE___2 = 165,
	CPUHP_AP_PERF_X86_IDXD_ONLINE___2 = 166,
	CPUHP_AP_PERF_S390_CF_ONLINE___2 = 167,
	CPUHP_AP_PERF_S390_SF_ONLINE___2 = 168,
	CPUHP_AP_PERF_ARM_CCI_ONLINE___2 = 169,
	CPUHP_AP_PERF_ARM_CCN_ONLINE___2 = 170,
	CPUHP_AP_PERF_ARM_HISI_DDRC_ONLINE___2 = 171,
	CPUHP_AP_PERF_ARM_HISI_HHA_ONLINE___2 = 172,
	CPUHP_AP_PERF_ARM_HISI_L3_ONLINE___2 = 173,
	CPUHP_AP_PERF_ARM_HISI_PA_ONLINE___2 = 174,
	CPUHP_AP_PERF_ARM_HISI_SLLC_ONLINE___2 = 175,
	CPUHP_AP_PERF_ARM_L2X0_ONLINE___2 = 176,
	CPUHP_AP_PERF_ARM_QCOM_L2_ONLINE___2 = 177,
	CPUHP_AP_PERF_ARM_QCOM_L3_ONLINE___2 = 178,
	CPUHP_AP_PERF_ARM_APM_XGENE_ONLINE___2 = 179,
	CPUHP_AP_PERF_ARM_CAVIUM_TX2_UNCORE_ONLINE___2 = 180,
	CPUHP_AP_PERF_POWERPC_NEST_IMC_ONLINE___2 = 181,
	CPUHP_AP_PERF_POWERPC_CORE_IMC_ONLINE___2 = 182,
	CPUHP_AP_PERF_POWERPC_THREAD_IMC_ONLINE___2 = 183,
	CPUHP_AP_PERF_POWERPC_TRACE_IMC_ONLINE___2 = 184,
	CPUHP_AP_PERF_POWERPC_HV_24x7_ONLINE___2 = 185,
	CPUHP_AP_PERF_POWERPC_HV_GPCI_ONLINE___2 = 186,
	CPUHP_AP_PERF_CSKY_ONLINE___2 = 187,
	CPUHP_AP_WATCHDOG_ONLINE___2 = 188,
	CPUHP_AP_WORKQUEUE_ONLINE___2 = 189,
	CPUHP_AP_RCUTREE_ONLINE___2 = 190,
	CPUHP_AP_BASE_CACHEINFO_ONLINE___2 = 191,
	CPUHP_AP_ONLINE_DYN___2 = 192,
	CPUHP_AP_ONLINE_DYN_END___2 = 222,
	CPUHP_AP_MM_DEMOTION_ONLINE___2 = 223,
	CPUHP_AP_X86_HPET_ONLINE___2 = 224,
	CPUHP_AP_X86_KVM_CLK_ONLINE___2 = 225,
	CPUHP_AP_DTPM_CPU_ONLINE___2 = 226,
	CPUHP_AP_ACTIVE___2 = 227,
	CPUHP_ONLINE___2 = 228,
};

struct dentry_operations___6;

struct dentry___7 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___7 *d_parent;
	struct qstr d_name;
	struct inode___8 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___6 *d_op;
	struct super_block___7 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___6;

struct inode___8 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___6 *i_op;
	struct super_block___7 *i_sb;
	struct address_space___6 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___6 *i_fop;
		void (*free_inode)(struct inode___8 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___6 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___3 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___6 {
	int (*d_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___7 *, unsigned int);
	int (*d_hash)(const struct dentry___7 *, struct qstr *);
	int (*d_compare)(const struct dentry___7 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___7 *);
	int (*d_init)(struct dentry___7 *);
	void (*d_release)(struct dentry___7 *);
	void (*d_prune)(struct dentry___7 *);
	void (*d_iput)(struct dentry___7 *, struct inode___8 *);
	char * (*d_dname)(struct dentry___7 *, char *, int);
	struct vfsmount___6 * (*d_automount)(struct path___6 *);
	int (*d_manage)(const struct path___6 *, bool);
	struct dentry___7 * (*d_real)(struct dentry___7 *, const struct inode___8 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___6;

struct mem_dqinfo___6 {
	struct quota_format_type___6 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___6;

struct quota_info___6 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___8 *files[3];
	struct mem_dqinfo___6 info[3];
	const struct quota_format_ops___6 *ops[3];
};

struct rcuwait___6 {
	struct task_struct___8 *task;
};

struct percpu_rw_semaphore___6 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___6 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___6 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___6 rw_sem[3];
};

struct super_operations___6;

struct dquot_operations___6;

struct quotactl_ops___6;

struct super_block___7 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___6 *s_type;
	const struct super_operations___6 *s_op;
	const struct dquot_operations___6 *dq_op;
	const struct quotactl_ops___6 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___7 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___6 s_dquot;
	struct sb_writers___6 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___6 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___6 {
	struct dentry___7 *mnt_root;
	struct super_block___7 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___6 {
	struct file___7 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___6 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___7 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___7 *ia_file;
};

struct dquot___6 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___7 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

enum {
	DQF_ROOT_SQUASH_B = 0,
	DQF_SYS_FILE_B = 16,
	DQF_PRIVATE = 17,
};

struct quota_format_type___6 {
	int qf_fmt_id;
	const struct quota_format_ops___6 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___6 *qf_next;
};

enum {
	DQST_LOOKUPS = 0,
	DQST_DROPS = 1,
	DQST_READS = 2,
	DQST_WRITES = 3,
	DQST_CACHE_HITS = 4,
	DQST_ALLOC_DQUOTS = 5,
	DQST_FREE_DQUOTS = 6,
	DQST_SYNCS = 7,
	_DQST_DQSTAT_LAST = 8,
};

struct quota_format_ops___6 {
	int (*check_quota_file)(struct super_block___7 *, int);
	int (*read_file_info)(struct super_block___7 *, int);
	int (*write_file_info)(struct super_block___7 *, int);
	int (*free_file_info)(struct super_block___7 *, int);
	int (*read_dqblk)(struct dquot___6 *);
	int (*commit_dqblk)(struct dquot___6 *);
	int (*release_dqblk)(struct dquot___6 *);
	int (*get_next_id)(struct super_block___7 *, struct kqid *);
};

struct dquot_operations___6 {
	int (*write_dquot)(struct dquot___6 *);
	struct dquot___6 * (*alloc_dquot)(struct super_block___7 *, int);
	void (*destroy_dquot)(struct dquot___6 *);
	int (*acquire_dquot)(struct dquot___6 *);
	int (*release_dquot)(struct dquot___6 *);
	int (*mark_dirty)(struct dquot___6 *);
	int (*write_info)(struct super_block___7 *, int);
	qsize_t * (*get_reserved_space)(struct inode___8 *);
	int (*get_projid)(struct inode___8 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___8 *, qsize_t *);
	int (*get_next_id)(struct super_block___7 *, struct kqid *);
};

struct quotactl_ops___6 {
	int (*quota_on)(struct super_block___7 *, int, int, const struct path___6 *);
	int (*quota_off)(struct super_block___7 *, int);
	int (*quota_enable)(struct super_block___7 *, unsigned int);
	int (*quota_disable)(struct super_block___7 *, unsigned int);
	int (*quota_sync)(struct super_block___7 *, int);
	int (*set_info)(struct super_block___7 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___7 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___7 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___7 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___7 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___7 *, unsigned int);
};

struct address_space_operations___6 {
	int (*writepage)(struct page___7 *, struct writeback_control___3 *);
	int (*readpage)(struct file___7 *, struct page___7 *);
	int (*writepages)(struct address_space___6 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___7 *);
	int (*readpages)(struct file___7 *, struct address_space___6 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___7 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___7 **, void **);
	int (*write_end)(struct file___7 *, struct address_space___6 *, loff_t, unsigned int, unsigned int, struct page___7 *, void *);
	sector_t (*bmap)(struct address_space___6 *, sector_t);
	void (*invalidatepage)(struct page___7 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___7 *, gfp_t);
	void (*freepage)(struct page___7 *);
	ssize_t (*direct_IO)(struct kiocb___6 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___6 *, struct page___7 *, struct page___7 *, enum migrate_mode);
	bool (*isolate_page)(struct page___7 *, isolate_mode_t);
	void (*putback_page)(struct page___7 *);
	int (*launder_page)(struct page___7 *);
	int (*is_partially_uptodate)(struct page___7 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___7 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___6 *, struct page___7 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___7 *, sector_t *);
	void (*swap_deactivate)(struct file___7 *);
};

struct inode_operations___6 {
	struct dentry___7 * (*lookup)(struct inode___8 *, struct dentry___7 *, unsigned int);
	const char * (*get_link)(struct dentry___7 *, struct inode___8 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___8 *, int);
	struct posix_acl * (*get_acl)(struct inode___8 *, int, bool);
	int (*readlink)(struct dentry___7 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___8 *, struct dentry___7 *, umode_t, bool);
	int (*link)(struct dentry___7 *, struct inode___8 *, struct dentry___7 *);
	int (*unlink)(struct inode___8 *, struct dentry___7 *);
	int (*symlink)(struct user_namespace *, struct inode___8 *, struct dentry___7 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___8 *, struct dentry___7 *, umode_t);
	int (*rmdir)(struct inode___8 *, struct dentry___7 *);
	int (*mknod)(struct user_namespace *, struct inode___8 *, struct dentry___7 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___8 *, struct dentry___7 *, struct inode___8 *, struct dentry___7 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___7 *, struct iattr___7 *);
	int (*getattr)(struct user_namespace *, const struct path___6 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___7 *, char *, size_t);
	int (*fiemap)(struct inode___8 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___8 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___8 *, struct dentry___7 *, struct file___7 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___8 *, struct dentry___7 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___8 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___7 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___7 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___6 {
	void (*fl_copy_lock)(struct file_lock___6 *, struct file_lock___6 *);
	void (*fl_release_private)(struct file_lock___6 *);
};

struct fasync_struct___6;

struct lock_manager_operations___6;

struct file_lock___6 {
	struct file_lock___6 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___7 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___6 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___6 *fl_ops;
	const struct lock_manager_operations___6 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___6 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___6 *);
	int (*lm_grant)(struct file_lock___6 *, int);
	bool (*lm_break)(struct file_lock___6 *);
	int (*lm_change)(struct file_lock___6 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___6 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___6 *);
};

struct fasync_struct___6 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___6 *fa_next;
	struct file___7 *fa_file;
	struct callback_head fa_rcu;
};

enum {
	SB_UNFROZEN = 0,
	SB_FREEZE_WRITE = 1,
	SB_FREEZE_PAGEFAULT = 2,
	SB_FREEZE_FS = 3,
	SB_FREEZE_COMPLETE = 4,
};

struct super_operations___6 {
	struct inode___8 * (*alloc_inode)(struct super_block___7 *);
	void (*destroy_inode)(struct inode___8 *);
	void (*free_inode)(struct inode___8 *);
	void (*dirty_inode)(struct inode___8 *, int);
	int (*write_inode)(struct inode___8 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___8 *);
	void (*evict_inode)(struct inode___8 *);
	void (*put_super)(struct super_block___7 *);
	int (*sync_fs)(struct super_block___7 *, int);
	int (*freeze_super)(struct super_block___7 *);
	int (*freeze_fs)(struct super_block___7 *);
	int (*thaw_super)(struct super_block___7 *);
	int (*unfreeze_fs)(struct super_block___7 *);
	int (*statfs)(struct dentry___7 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___7 *, int *, char *);
	void (*umount_begin)(struct super_block___7 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___7 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___7 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___7 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___7 *);
	ssize_t (*quota_read)(struct super_block___7 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___7 *, int, const char *, size_t, loff_t);
	struct dquot___6 ** (*get_dquots)(struct inode___8 *);
	long int (*nr_cached_objects)(struct super_block___7 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___7 *, struct shrink_control___2 *);
	struct file___7 * (*real_loop)(struct file___7 *);
};

struct seq_operations___7 {
	void * (*start)(struct seq_file___9 *, loff_t *);
	void (*stop)(struct seq_file___9 *, void *);
	void * (*next)(struct seq_file___9 *, void *, loff_t *);
	int (*show)(struct seq_file___9 *, void *);
};

struct dev_pagemap_ops___6 {
	void (*page_free)(struct page___7 *);
	void (*kill)(struct dev_pagemap___6 *);
	void (*cleanup)(struct dev_pagemap___6 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___6 *);
};

enum compound_dtor_id {
	NULL_COMPOUND_DTOR = 0,
	COMPOUND_PAGE_DTOR = 1,
	HUGETLB_PAGE_DTOR = 2,
	TRANSHUGE_PAGE_DTOR = 3,
	NR_COMPOUND_DTORS = 4,
};

enum {
	HI_SOFTIRQ = 0,
	TIMER_SOFTIRQ = 1,
	NET_TX_SOFTIRQ = 2,
	NET_RX_SOFTIRQ = 3,
	BLOCK_SOFTIRQ = 4,
	IRQ_POLL_SOFTIRQ = 5,
	TASKLET_SOFTIRQ = 6,
	SCHED_SOFTIRQ = 7,
	HRTIMER_SOFTIRQ = 8,
	RCU_SOFTIRQ = 9,
	NR_SOFTIRQS = 10,
};

struct kernel_param_ops___6 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___6 *);
	int (*get)(char *, const struct kernel_param___6 *);
	void (*free)(void *);
};

struct kparam_array___6;

struct kernel_param___6 {
	const char *name;
	struct module___8 *mod;
	const struct kernel_param_ops___6 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___6 *arr;
	};
};

struct kparam_array___6 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___6 *ops;
	void *elem;
};

struct module_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___6 *, struct module_kobject___6 *, char *);
	ssize_t (*store)(struct module_attribute___6 *, struct module_kobject___6 *, const char *, size_t);
	void (*setup)(struct module___8 *, const char *);
	int (*test)(struct module___8 *);
	void (*free)(struct module___8 *);
};

enum {
	TSK_TRACE_FL_TRACE_BIT = 0,
	TSK_TRACE_FL_GRAPH_BIT = 1,
};

struct user_pt_regs___2 {
	__u64 regs[31];
	__u64 sp;
	__u64 pc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u64 pstate;
};

struct pt_regs___2 {
	union {
		struct user_pt_regs___2 user_regs;
		struct {
			u64 regs[31];
			u64 sp;
			u64 pc;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			long: 64;
			u64 pstate;
		};
	};
	u64 orig_x0;
	s32 syscallno;
	u32 unused2;
	u64 sdei_ttbr1;
	u64 pmr_save;
	u64 stackframe[2];
	u64 lockdep_hardirqs;
	u64 exit_rcu;
};

struct nmi_ctx {
	u64 hcr;
	unsigned int cnt;
};

struct midr_range {
	u32 model;
	u32 rv_min;
	u32 rv_max;
};

struct arm64_midr_revidr {
	u32 midr_rv;
	u32 revidr_mask;
};

struct arm64_cpu_capabilities {
	const char *desc;
	u16 capability;
	u16 type;
	bool (*matches)(const struct arm64_cpu_capabilities *, int);
	void (*cpu_enable)(const struct arm64_cpu_capabilities *);
	union {
		struct {
			struct midr_range midr_range;
			const struct arm64_midr_revidr * const fixed_revs;
		};
		const struct midr_range *midr_range_list;
		struct {
			u32 sys_reg;
			u8 field_pos;
			u8 min_field_value;
			u8 hwcap_type;
			bool sign;
			long unsigned int hwcap;
		};
	};
	const struct arm64_cpu_capabilities *match_list;
};

enum cpu_pm_event {
	CPU_PM_ENTER = 0,
	CPU_PM_ENTER_FAILED = 1,
	CPU_PM_EXIT = 2,
	CPU_CLUSTER_PM_ENTER = 3,
	CPU_CLUSTER_PM_ENTER_FAILED = 4,
	CPU_CLUSTER_PM_EXIT = 5,
};

struct fpsimd_last_state_struct {
	struct user_fpsimd_state *st;
	void *sve_state;
	unsigned int sve_vl;
};

enum arm64_hyp_spectre_vector {
	HYP_VECTOR_DIRECT = 0,
	HYP_VECTOR_SPECTRE_DIRECT = 1,
	HYP_VECTOR_INDIRECT = 2,
	HYP_VECTOR_SPECTRE_INDIRECT = 3,
};

typedef void (*bp_hardening_cb_t)();

struct bp_hardening_data {
	enum arm64_hyp_spectre_vector slot;
	bp_hardening_cb_t fn;
};

enum ctx_state {
	CONTEXT_DISABLED = 0,
	CONTEXT_KERNEL = 0,
	CONTEXT_USER = 1,
	CONTEXT_GUEST = 2,
};

enum stack_type {
	STACK_TYPE_UNKNOWN = 0,
	STACK_TYPE_TASK = 1,
	STACK_TYPE_IRQ = 2,
	STACK_TYPE_OVERFLOW = 3,
	STACK_TYPE_SDEI_NORMAL = 4,
	STACK_TYPE_SDEI_CRITICAL = 5,
	__NR_STACK_TYPES = 6,
};

struct stack_info {
	long unsigned int low;
	long unsigned int high;
	enum stack_type type;
};

struct sdei_registered_event;

struct dentry___8;

struct super_block___8;

struct module___9;

struct file_system_type___7 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___8 * (*mount)(struct file_system_type___7 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___8 *);
	struct module___9 *owner;
	struct file_system_type___7 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___8;

struct kiocb___7;

struct poll_table_struct___6;

struct vm_area_struct___7;

struct inode___9;

struct file_lock___7;

struct page___8;

struct seq_file___10;

struct file_operations___7 {
	struct module___9 *owner;
	loff_t (*llseek)(struct file___8 *, loff_t, int);
	ssize_t (*read)(struct file___8 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___8 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___7 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___7 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___7 *, bool);
	int (*iterate)(struct file___8 *, struct dir_context *);
	int (*iterate_shared)(struct file___8 *, struct dir_context *);
	__poll_t (*poll)(struct file___8 *, struct poll_table_struct___6 *);
	long int (*unlocked_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___8 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___8 *, struct vm_area_struct___7 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___9 *, struct file___8 *);
	int (*flush)(struct file___8 *, fl_owner_t);
	int (*release)(struct inode___9 *, struct file___8 *);
	int (*fsync)(struct file___8 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___8 *, int);
	int (*lock)(struct file___8 *, int, struct file_lock___7 *);
	ssize_t (*sendpage)(struct file___8 *, struct page___8 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___8 *, long unsigned int);
	int (*flock)(struct file___8 *, int, struct file_lock___7 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___8 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___8 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___8 *, long int, struct file_lock___7 **, void **);
	long int (*fallocate)(struct file___8 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___10 *, struct file___8 *);
	ssize_t (*copy_file_range)(struct file___8 *, loff_t, struct file___8 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___8 *, loff_t, struct file___8 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___8 *, loff_t, loff_t, int);
};

struct vmacache___7 {
	u64 seqnum;
	struct vm_area_struct___7 *vmas[4];
};

struct page_frag___7 {
	struct page___8 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___5;

struct debug_info___5 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___5 *hbp_break[16];
	struct perf_event___5 *hbp_watch[16];
};

struct thread_struct___5 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___5 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___8;

struct pid___7;

struct nsproxy___8;

struct signal_struct___8;

struct vm_struct___8;

struct task_struct___9 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___9 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___8 *mm;
	struct mm_struct___8 *active_mm;
	struct vmacache___7 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___9 *real_parent;
	struct task_struct___9 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___9 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___7 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___8 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___9 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___4 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___7 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___9 *oom_reaper_list;
	struct vm_struct___8 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___5 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___7;

struct kobj_type___7;

struct kernfs_node___7;

struct kobject___7 {
	const char *name;
	struct list_head entry;
	struct kobject___7 *parent;
	struct kset___7 *kset;
	struct kobj_type___7 *ktype;
	struct kernfs_node___7 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___7 {
	struct kobject___7 kobj;
	struct module___9 *mod;
	struct kobject___7 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___7 {
	struct module___9 *mod;
	struct latch_tree_node node;
};

struct module_layout___7 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___7 mtn;
};

struct module_attribute___7;

struct kernel_param___7;

struct module___9 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___7 mkobj;
	struct module_attribute___7 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___7 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___7 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___7 core_layout;
	struct module_layout___7 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___5 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___9 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___5)(struct perf_event___5 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___5;

struct fasync_struct___7;

struct pid_namespace___7;

struct perf_cgroup___5;

struct perf_event___5 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___5 *group_leader;
	struct pmu___5 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___5 hw;
	struct perf_event_context___2 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___5 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___9 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___7 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___5 *aux_event;
	void (*destroy)(struct perf_event___5 *);
	struct callback_head callback_head;
	struct pid_namespace___7 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___5 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___5 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___5 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___7 {
	int nr;
	struct pid_namespace___7 *ns;
};

struct pid_namespace___7 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___9 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___7 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___7 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___7 numbers[1];
};

typedef struct page___8 *pgtable_t___7;

struct address_space___7;

struct dev_pagemap___7;

struct page___8 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___7 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___8 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___7 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___8 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___7 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct plist_head {
	struct list_head node_list;
};

struct vm_operations_struct___7;

struct vm_area_struct___7 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___7 *vm_next;
	struct vm_area_struct___7 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___8 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___7 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___8 *vm_file;
	struct file___8 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___8 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___9 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___9 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___7 *pids[4];
	struct pid___7 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___8 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___7;

struct mm_struct___8 {
	struct {
		struct vm_area_struct___7 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___8 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___7 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___9 *owner;
		struct user_namespace *user_ns;
		struct file___8 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___6;

struct nsproxy___8 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___7 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___6 *cgroup_ns;
};

struct cgroup_subsys_state___5;

struct cgroup___5;

struct css_set___2 {
	struct cgroup_subsys_state___5 *subsys[14];
	refcount_t refcount;
	struct css_set___2 *dom_cset;
	struct cgroup___5 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___5 *mg_src_cgrp;
	struct cgroup___5 *mg_dst_cgrp;
	struct css_set___2 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___2 {
	struct pmu___5 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___9 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___2 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___8 {
	struct vm_struct___8 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___8 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___7 {
	struct file___8 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___7 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct dentry_operations___7;

struct dentry___8 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___8 *d_parent;
	struct qstr d_name;
	struct inode___9 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___7 *d_op;
	struct super_block___8 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___7;

struct address_space___7 {
	struct inode___9 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___7 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___7;

struct cdev___3;

struct inode___9 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___7 *i_op;
	struct super_block___8 *i_sb;
	struct address_space___7 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___7 *i_fop;
		void (*free_inode)(struct inode___9 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___7 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___7;

struct path___7;

struct dentry_operations___7 {
	int (*d_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___8 *, unsigned int);
	int (*d_hash)(const struct dentry___8 *, struct qstr *);
	int (*d_compare)(const struct dentry___8 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___8 *);
	int (*d_init)(struct dentry___8 *);
	void (*d_release)(struct dentry___8 *);
	void (*d_prune)(struct dentry___8 *);
	void (*d_iput)(struct dentry___8 *, struct inode___9 *);
	char * (*d_dname)(struct dentry___8 *, char *, int);
	struct vfsmount___7 * (*d_automount)(struct path___7 *);
	int (*d_manage)(const struct path___7 *, bool);
	struct dentry___8 * (*d_real)(struct dentry___8 *, const struct inode___9 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___7;

struct mem_dqinfo___7 {
	struct quota_format_type___7 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___7;

struct quota_info___7 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___9 *files[3];
	struct mem_dqinfo___7 info[3];
	const struct quota_format_ops___7 *ops[3];
};

struct rcuwait___7 {
	struct task_struct___9 *task;
};

struct percpu_rw_semaphore___7 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___7 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___7 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___7 rw_sem[3];
};

struct super_operations___7;

struct dquot_operations___7;

struct quotactl_ops___7;

struct super_block___8 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___7 *s_type;
	const struct super_operations___7 *s_op;
	const struct dquot_operations___7 *dq_op;
	const struct quotactl_ops___7 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___8 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___7 s_dquot;
	struct sb_writers___7 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___7 *s_d_op;
	int cleancache_poolid;
	struct shrinker___2 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___7 {
	struct dentry___8 *mnt_root;
	struct super_block___8 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___7 {
	struct vfsmount___7 *mnt;
	struct dentry___8 *dentry;
};

struct dev_pagemap_ops___7;

struct dev_pagemap___7 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___7 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___7 {
	rwlock_t lock;
	struct pid___7 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___8 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___7 f_path;
	struct inode___9 *f_inode;
	const struct file_operations___7 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___7 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___7 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___7;

struct vm_operations_struct___7 {
	void (*open)(struct vm_area_struct___7 *);
	void (*close)(struct vm_area_struct___7 *);
	int (*may_split)(struct vm_area_struct___7 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___7 *);
	int (*mprotect)(struct vm_area_struct___7 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___7 *);
	vm_fault_t (*huge_fault)(struct vm_fault___7 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___7 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___7 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___7 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___7 *);
	int (*access)(struct vm_area_struct___7 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___7 *);
	int (*set_policy)(struct vm_area_struct___7 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___7 *, long unsigned int);
	struct page___8 * (*find_special_page)(struct vm_area_struct___7 *, long unsigned int);
};

struct core_thread___7 {
	struct task_struct___9 *task;
	struct core_thread___7 *next;
};

struct core_state___7 {
	atomic_t nr_threads;
	struct core_thread___7 dumper;
	struct completion startup;
};

struct vm_fault___7 {
	const struct {
		struct vm_area_struct___7 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___8 *cow_page;
	struct page___8 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___7 prealloc_pte;
};

struct cgroup_subsys___5;

struct cgroup_subsys_state___5 {
	struct cgroup___5 *cgroup;
	struct cgroup_subsys___5 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___5 *parent;
};

struct cgroup_file___5 {
	struct kernfs_node___7 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___5 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___9 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___5;

struct cgroup_rstat_cpu___5;

struct cgroup___5 {
	struct cgroup_subsys_state___5 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___7 *kn;
	struct cgroup_file___5 procs_file;
	struct cgroup_file___5 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___5 *subsys[14];
	struct cgroup_root___5 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___5 *dom_cgrp;
	struct cgroup___5 *old_dom_cgrp;
	struct cgroup_rstat_cpu___5 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___5 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

typedef struct {
	__u8 b[16];
} guid_t;

struct iattr___8 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___8 *ia_file;
};

struct dquot___7 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___8 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___7 {
	int qf_fmt_id;
	const struct quota_format_ops___7 *qf_ops;
	struct module___9 *qf_owner;
	struct quota_format_type___7 *qf_next;
};

struct quota_format_ops___7 {
	int (*check_quota_file)(struct super_block___8 *, int);
	int (*read_file_info)(struct super_block___8 *, int);
	int (*write_file_info)(struct super_block___8 *, int);
	int (*free_file_info)(struct super_block___8 *, int);
	int (*read_dqblk)(struct dquot___7 *);
	int (*commit_dqblk)(struct dquot___7 *);
	int (*release_dqblk)(struct dquot___7 *);
	int (*get_next_id)(struct super_block___8 *, struct kqid *);
};

struct dquot_operations___7 {
	int (*write_dquot)(struct dquot___7 *);
	struct dquot___7 * (*alloc_dquot)(struct super_block___8 *, int);
	void (*destroy_dquot)(struct dquot___7 *);
	int (*acquire_dquot)(struct dquot___7 *);
	int (*release_dquot)(struct dquot___7 *);
	int (*mark_dirty)(struct dquot___7 *);
	int (*write_info)(struct super_block___8 *, int);
	qsize_t * (*get_reserved_space)(struct inode___9 *);
	int (*get_projid)(struct inode___9 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___9 *, qsize_t *);
	int (*get_next_id)(struct super_block___8 *, struct kqid *);
};

struct quotactl_ops___7 {
	int (*quota_on)(struct super_block___8 *, int, int, const struct path___7 *);
	int (*quota_off)(struct super_block___8 *, int);
	int (*quota_enable)(struct super_block___8 *, unsigned int);
	int (*quota_disable)(struct super_block___8 *, unsigned int);
	int (*quota_sync)(struct super_block___8 *, int);
	int (*set_info)(struct super_block___8 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___8 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___8 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___8 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___8 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___8 *, unsigned int);
};

struct address_space_operations___7 {
	int (*writepage)(struct page___8 *, struct writeback_control___3 *);
	int (*readpage)(struct file___8 *, struct page___8 *);
	int (*writepages)(struct address_space___7 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___8 *);
	int (*readpages)(struct file___8 *, struct address_space___7 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___8 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___8 **, void **);
	int (*write_end)(struct file___8 *, struct address_space___7 *, loff_t, unsigned int, unsigned int, struct page___8 *, void *);
	sector_t (*bmap)(struct address_space___7 *, sector_t);
	void (*invalidatepage)(struct page___8 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___8 *, gfp_t);
	void (*freepage)(struct page___8 *);
	ssize_t (*direct_IO)(struct kiocb___7 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___7 *, struct page___8 *, struct page___8 *, enum migrate_mode);
	bool (*isolate_page)(struct page___8 *, isolate_mode_t);
	void (*putback_page)(struct page___8 *);
	int (*launder_page)(struct page___8 *);
	int (*is_partially_uptodate)(struct page___8 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___8 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___7 *, struct page___8 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___8 *, sector_t *);
	void (*swap_deactivate)(struct file___8 *);
};

struct cdev___3 {
	struct kobject___7 kobj;
	struct module___9 *owner;
	const struct file_operations___7 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___7 {
	struct dentry___8 * (*lookup)(struct inode___9 *, struct dentry___8 *, unsigned int);
	const char * (*get_link)(struct dentry___8 *, struct inode___9 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___9 *, int);
	struct posix_acl * (*get_acl)(struct inode___9 *, int, bool);
	int (*readlink)(struct dentry___8 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___9 *, struct dentry___8 *, umode_t, bool);
	int (*link)(struct dentry___8 *, struct inode___9 *, struct dentry___8 *);
	int (*unlink)(struct inode___9 *, struct dentry___8 *);
	int (*symlink)(struct user_namespace *, struct inode___9 *, struct dentry___8 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___9 *, struct dentry___8 *, umode_t);
	int (*rmdir)(struct inode___9 *, struct dentry___8 *);
	int (*mknod)(struct user_namespace *, struct inode___9 *, struct dentry___8 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___9 *, struct dentry___8 *, struct inode___9 *, struct dentry___8 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___8 *, struct iattr___8 *);
	int (*getattr)(struct user_namespace *, const struct path___7 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___8 *, char *, size_t);
	int (*fiemap)(struct inode___9 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___9 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___9 *, struct dentry___8 *, struct file___8 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___9 *, struct dentry___8 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___9 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___8 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___8 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___7 {
	void (*fl_copy_lock)(struct file_lock___7 *, struct file_lock___7 *);
	void (*fl_release_private)(struct file_lock___7 *);
};

struct lock_manager_operations___7;

struct file_lock___7 {
	struct file_lock___7 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___8 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___7 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___7 *fl_ops;
	const struct lock_manager_operations___7 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___7 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___7 *);
	int (*lm_grant)(struct file_lock___7 *, int);
	bool (*lm_break)(struct file_lock___7 *);
	int (*lm_change)(struct file_lock___7 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___7 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___7 *);
};

struct fasync_struct___7 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___7 *fa_next;
	struct file___8 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___7 {
	struct inode___9 * (*alloc_inode)(struct super_block___8 *);
	void (*destroy_inode)(struct inode___9 *);
	void (*free_inode)(struct inode___9 *);
	void (*dirty_inode)(struct inode___9 *, int);
	int (*write_inode)(struct inode___9 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___9 *);
	void (*evict_inode)(struct inode___9 *);
	void (*put_super)(struct super_block___8 *);
	int (*sync_fs)(struct super_block___8 *, int);
	int (*freeze_super)(struct super_block___8 *);
	int (*freeze_fs)(struct super_block___8 *);
	int (*thaw_super)(struct super_block___8 *);
	int (*unfreeze_fs)(struct super_block___8 *);
	int (*statfs)(struct dentry___8 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___8 *, int *, char *);
	void (*umount_begin)(struct super_block___8 *);
	int (*show_options)(struct seq_file___10 *, struct dentry___8 *);
	int (*show_devname)(struct seq_file___10 *, struct dentry___8 *);
	int (*show_path)(struct seq_file___10 *, struct dentry___8 *);
	int (*show_stats)(struct seq_file___10 *, struct dentry___8 *);
	ssize_t (*quota_read)(struct super_block___8 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___8 *, int, const char *, size_t, loff_t);
	struct dquot___7 ** (*get_dquots)(struct inode___9 *);
	long int (*nr_cached_objects)(struct super_block___8 *, struct shrink_control___2 *);
	long int (*free_cached_objects)(struct super_block___8 *, struct shrink_control___2 *);
	struct file___8 * (*real_loop)(struct file___8 *);
};

typedef void (*poll_queue_proc___5)(struct file___8 *, wait_queue_head_t *, struct poll_table_struct___6 *);

struct poll_table_struct___6 {
	poll_queue_proc___5 _qproc;
	__poll_t _key;
};

struct seq_operations___8;

struct seq_file___10 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___8 *op;
	int poll_event;
	const struct file___8 *file;
	void *private;
};

struct fwnode_operations___6;

struct device___6;

struct fwnode_handle___6 {
	struct fwnode_handle___6 *secondary;
	const struct fwnode_operations___6 *ops;
	struct device___6 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___6;

struct fwnode_endpoint___6;

struct fwnode_operations___6 {
	struct fwnode_handle___6 * (*get)(struct fwnode_handle___6 *);
	void (*put)(struct fwnode_handle___6 *);
	bool (*device_is_available)(const struct fwnode_handle___6 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___6 *, const struct device___6 *);
	bool (*property_present)(const struct fwnode_handle___6 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___6 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___6 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___6 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_parent)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_next_child_node)(const struct fwnode_handle___6 *, struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*get_named_child_node)(const struct fwnode_handle___6 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___6 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___6 *);
	struct fwnode_handle___6 * (*graph_get_next_endpoint)(const struct fwnode_handle___6 *, struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*graph_get_remote_endpoint)(const struct fwnode_handle___6 *);
	struct fwnode_handle___6 * (*graph_get_port_parent)(struct fwnode_handle___6 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___6 *, struct fwnode_endpoint___6 *);
	int (*add_links)(struct fwnode_handle___6 *);
};

struct wakeup_source___6;

struct dev_pm_info___6 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___6 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___6 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___6;

struct bus_type___6;

struct device_driver___6;

struct dev_pm_domain___6;

struct class___6;

struct attribute_group___7;

struct device___6 {
	struct kobject___7 kobj;
	struct device___6 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___6 *type;
	struct bus_type___6 *bus;
	struct device_driver___6 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___6 power;
	struct dev_pm_domain___6 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___6 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___6 *class;
	const struct attribute_group___7 **groups;
	void (*release)(struct device___6 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___6 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___6 *local_fwnode;
};

struct fwnode_reference_args___6 {
	struct fwnode_handle___6 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___7;

struct kernfs_elem_dir___7 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___7 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___7;

struct kernfs_root___7 {
	struct kernfs_node___7 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___7 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___7 {
	struct kernfs_node___7 *target_kn;
};

struct kernfs_ops___7;

struct kernfs_elem_attr___7 {
	const struct kernfs_ops___7 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___7 *notify_next;
};

struct kernfs_node___7 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___7 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___7 dir;
		struct kernfs_elem_symlink___7 symlink;
		struct kernfs_elem_attr___7 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___7;

struct kernfs_ops___7 {
	int (*open)(struct kernfs_open_file___7 *);
	void (*release)(struct kernfs_open_file___7 *);
	int (*seq_show)(struct seq_file___10 *, void *);
	void * (*seq_start)(struct seq_file___10 *, loff_t *);
	void * (*seq_next)(struct seq_file___10 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___10 *, void *);
	ssize_t (*read)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___7 *, struct poll_table_struct___6 *);
	int (*mmap)(struct kernfs_open_file___7 *, struct vm_area_struct___7 *);
};

struct kernfs_syscall_ops___7 {
	int (*show_options)(struct seq_file___10 *, struct kernfs_root___7 *);
	int (*mkdir)(struct kernfs_node___7 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___7 *);
	int (*rename)(struct kernfs_node___7 *, struct kernfs_node___7 *, const char *);
	int (*show_path)(struct seq_file___10 *, struct kernfs_node___7 *, struct kernfs_root___7 *);
};

struct kernfs_open_file___7 {
	struct kernfs_node___7 *kn;
	struct file___8 *file;
	struct seq_file___10 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___7 *vm_ops;
};

struct bin_attribute___7;

struct attribute_group___7 {
	const char *name;
	umode_t (*is_visible)(struct kobject___7 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___7 *, struct bin_attribute___7 *, int);
	struct attribute **attrs;
	struct bin_attribute___7 **bin_attrs;
};

struct bin_attribute___7 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___7 * (*f_mapping)();
	ssize_t (*read)(struct file___8 *, struct kobject___7 *, struct bin_attribute___7 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___8 *, struct kobject___7 *, struct bin_attribute___7 *, char *, loff_t, size_t);
	int (*mmap)(struct file___8 *, struct kobject___7 *, struct bin_attribute___7 *, struct vm_area_struct___7 *);
};

struct sysfs_ops___7 {
	ssize_t (*show)(struct kobject___7 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___7 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___7;

struct kset___7 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___7 kobj;
	const struct kset_uevent_ops___7 *uevent_ops;
};

struct kobj_type___7 {
	void (*release)(struct kobject___7 *);
	const struct sysfs_ops___7 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___7 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___7 *);
	const void * (*namespace)(struct kobject___7 *);
	void (*get_ownership)(struct kobject___7 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___7 {
	int (* const filter)(struct kset___7 *, struct kobject___7 *);
	const char * (* const name)(struct kset___7 *, struct kobject___7 *);
	int (* const uevent)(struct kset___7 *, struct kobject___7 *, struct kobj_uevent_env *);
};

struct property___2;

struct device_node___2 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___6 fwnode;
	struct property___2 *properties;
	struct property___2 *deadprops;
	struct device_node___2 *parent;
	struct device_node___2 *child;
	struct device_node___2 *sibling;
	struct kobject___7 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___6 {
	int (*prepare)(struct device___6 *);
	void (*complete)(struct device___6 *);
	int (*suspend)(struct device___6 *);
	int (*resume)(struct device___6 *);
	int (*freeze)(struct device___6 *);
	int (*thaw)(struct device___6 *);
	int (*poweroff)(struct device___6 *);
	int (*restore)(struct device___6 *);
	int (*suspend_late)(struct device___6 *);
	int (*resume_early)(struct device___6 *);
	int (*freeze_late)(struct device___6 *);
	int (*thaw_early)(struct device___6 *);
	int (*poweroff_late)(struct device___6 *);
	int (*restore_early)(struct device___6 *);
	int (*suspend_noirq)(struct device___6 *);
	int (*resume_noirq)(struct device___6 *);
	int (*freeze_noirq)(struct device___6 *);
	int (*thaw_noirq)(struct device___6 *);
	int (*poweroff_noirq)(struct device___6 *);
	int (*restore_noirq)(struct device___6 *);
	int (*runtime_suspend)(struct device___6 *);
	int (*runtime_resume)(struct device___6 *);
	int (*runtime_idle)(struct device___6 *);
};

struct wakeup_source___6 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___6 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum pm_qos_type {
	PM_QOS_UNITIALIZED = 0,
	PM_QOS_MAX = 1,
	PM_QOS_MIN = 2,
};

struct pm_qos_constraints {
	struct plist_head list;
	s32 target_value;
	s32 default_value;
	s32 no_constraint_value;
	enum pm_qos_type type;
	struct blocking_notifier_head *notifiers;
};

struct freq_constraints {
	struct pm_qos_constraints min_freq;
	struct blocking_notifier_head min_freq_notifiers;
	struct pm_qos_constraints max_freq;
	struct blocking_notifier_head max_freq_notifiers;
};

struct pm_qos_flags {
	struct list_head list;
	s32 effective_flags;
};

struct dev_pm_qos_request;

struct dev_pm_qos {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request *resume_latency_req;
	struct dev_pm_qos_request *latency_tolerance_req;
	struct dev_pm_qos_request *flags_req;
};

struct dev_pm_domain___6 {
	struct dev_pm_ops___6 ops;
	int (*start)(struct device___6 *);
	void (*detach)(struct device___6 *, bool);
	int (*activate)(struct device___6 *);
	void (*sync)(struct device___6 *);
	void (*dismiss)(struct device___6 *);
};

struct bus_type___6 {
	const char *name;
	const char *dev_name;
	struct device___6 *dev_root;
	const struct attribute_group___7 **bus_groups;
	const struct attribute_group___7 **dev_groups;
	const struct attribute_group___7 **drv_groups;
	int (*match)(struct device___6 *, struct device_driver___6 *);
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	int (*probe)(struct device___6 *);
	void (*sync_state)(struct device___6 *);
	void (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*online)(struct device___6 *);
	int (*offline)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	int (*num_vf)(struct device___6 *);
	int (*dma_configure)(struct device___6 *);
	const struct dev_pm_ops___6 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___6 {
	const char *name;
	struct bus_type___6 *bus;
	struct module___9 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___6 *);
	void (*sync_state)(struct device___6 *);
	int (*remove)(struct device___6 *);
	void (*shutdown)(struct device___6 *);
	int (*suspend)(struct device___6 *, pm_message_t);
	int (*resume)(struct device___6 *);
	const struct attribute_group___7 **groups;
	const struct attribute_group___7 **dev_groups;
	const struct dev_pm_ops___6 *pm;
	void (*coredump)(struct device___6 *);
	struct driver_private *p;
};

struct device_type___6 {
	const char *name;
	const struct attribute_group___7 **groups;
	int (*uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___6 *);
	const struct dev_pm_ops___6 *pm;
};

struct class___6 {
	const char *name;
	struct module___9 *owner;
	const struct attribute_group___7 **class_groups;
	const struct attribute_group___7 **dev_groups;
	struct kobject___7 *dev_kobj;
	int (*dev_uevent)(struct device___6 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___6 *, umode_t *);
	void (*class_release)(struct class___6 *);
	void (*dev_release)(struct device___6 *);
	int (*shutdown_pre)(struct device___6 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___6 *);
	void (*get_ownership)(struct device___6 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___6 *pm;
	struct subsys_private *p;
};

struct seq_operations___8 {
	void * (*start)(struct seq_file___10 *, loff_t *);
	void (*stop)(struct seq_file___10 *, void *);
	void * (*next)(struct seq_file___10 *, void *, loff_t *);
	int (*show)(struct seq_file___10 *, void *);
};

enum reboot_mode {
	REBOOT_UNDEFINED = 4294967295,
	REBOOT_COLD = 0,
	REBOOT_WARM = 1,
	REBOOT_HARD = 2,
	REBOOT_SOFT = 3,
	REBOOT_GPIO = 4,
};

typedef long unsigned int efi_status_t;

typedef u8 efi_bool_t;

typedef u16 efi_char16_t;

typedef guid_t efi_guid_t;

typedef struct {
	u64 signature;
	u32 revision;
	u32 headersize;
	u32 crc32;
	u32 reserved;
} efi_table_hdr_t;

typedef struct {
	u32 type;
	u32 pad;
	u64 phys_addr;
	u64 virt_addr;
	u64 num_pages;
	u64 attribute;
} efi_memory_desc_t;

typedef struct {
	efi_guid_t guid;
	u32 headersize;
	u32 flags;
	u32 imagesize;
} efi_capsule_header_t;

typedef struct {
	u16 year;
	u8 month;
	u8 day;
	u8 hour;
	u8 minute;
	u8 second;
	u8 pad1;
	u32 nanosecond;
	s16 timezone;
	u8 daylight;
	u8 pad2;
} efi_time_t;

typedef struct {
	u32 resolution;
	u32 accuracy;
	u8 sets_to_zero;
} efi_time_cap_t;

typedef struct {
	efi_table_hdr_t hdr;
	u32 get_time;
	u32 set_time;
	u32 get_wakeup_time;
	u32 set_wakeup_time;
	u32 set_virtual_address_map;
	u32 convert_pointer;
	u32 get_variable;
	u32 get_next_variable;
	u32 set_variable;
	u32 get_next_high_mono_count;
	u32 reset_system;
	u32 update_capsule;
	u32 query_capsule_caps;
	u32 query_variable_info;
} efi_runtime_services_32_t;

typedef efi_status_t efi_get_time_t(efi_time_t *, efi_time_cap_t *);

typedef efi_status_t efi_set_time_t(efi_time_t *);

typedef efi_status_t efi_get_wakeup_time_t(efi_bool_t *, efi_bool_t *, efi_time_t *);

typedef efi_status_t efi_set_wakeup_time_t(efi_bool_t, efi_time_t *);

typedef efi_status_t efi_get_variable_t(efi_char16_t *, efi_guid_t *, u32 *, long unsigned int *, void *);

typedef efi_status_t efi_get_next_variable_t(long unsigned int *, efi_char16_t *, efi_guid_t *);

typedef efi_status_t efi_set_variable_t(efi_char16_t *, efi_guid_t *, u32, long unsigned int, void *);

typedef efi_status_t efi_get_next_high_mono_count_t(u32 *);

typedef void efi_reset_system_t(int, efi_status_t, long unsigned int, efi_char16_t *);

typedef efi_status_t efi_set_virtual_address_map_t(long unsigned int, long unsigned int, u32, efi_memory_desc_t *);

typedef efi_status_t efi_query_variable_info_t(u32, u64 *, u64 *, u64 *);

typedef efi_status_t efi_update_capsule_t(efi_capsule_header_t **, long unsigned int, long unsigned int);

typedef efi_status_t efi_query_capsule_caps_t(efi_capsule_header_t **, long unsigned int, u64 *, int *);

typedef union {
	struct {
		efi_table_hdr_t hdr;
		efi_get_time_t *get_time;
		efi_set_time_t *set_time;
		efi_get_wakeup_time_t *get_wakeup_time;
		efi_set_wakeup_time_t *set_wakeup_time;
		efi_set_virtual_address_map_t *set_virtual_address_map;
		void *convert_pointer;
		efi_get_variable_t *get_variable;
		efi_get_next_variable_t *get_next_variable;
		efi_set_variable_t *set_variable;
		efi_get_next_high_mono_count_t *get_next_high_mono_count;
		efi_reset_system_t *reset_system;
		efi_update_capsule_t *update_capsule;
		efi_query_capsule_caps_t *query_capsule_caps;
		efi_query_variable_info_t *query_variable_info;
	};
	efi_runtime_services_32_t mixed_mode;
} efi_runtime_services_t;

struct efi_memory_map {
	phys_addr_t phys_map;
	void *map;
	void *map_end;
	int nr_map;
	long unsigned int desc_version;
	long unsigned int desc_size;
	long unsigned int flags;
};

struct efi {
	const efi_runtime_services_t *runtime;
	unsigned int runtime_version;
	unsigned int runtime_supported_mask;
	long unsigned int acpi;
	long unsigned int acpi20;
	long unsigned int smbios;
	long unsigned int smbios3;
	long unsigned int esrt;
	long unsigned int tpm_log;
	long unsigned int tpm_final_log;
	long unsigned int mokvar_table;
	efi_get_time_t *get_time;
	efi_set_time_t *set_time;
	efi_get_wakeup_time_t *get_wakeup_time;
	efi_set_wakeup_time_t *set_wakeup_time;
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_set_variable_t *set_variable_nonblocking;
	efi_query_variable_info_t *query_variable_info;
	efi_query_variable_info_t *query_variable_info_nonblocking;
	efi_update_capsule_t *update_capsule;
	efi_query_capsule_caps_t *query_capsule_caps;
	efi_get_next_high_mono_count_t *get_next_high_mono_count;
	efi_reset_system_t *reset_system;
	struct efi_memory_map memmap;
	long unsigned int flags;
};

typedef __u32 Elf32_Addr;

typedef __u16 Elf32_Half;

typedef __u32 Elf32_Off;

struct elf32_hdr {
	unsigned char e_ident[16];
	Elf32_Half e_type;
	Elf32_Half e_machine;
	Elf32_Word e_version;
	Elf32_Addr e_entry;
	Elf32_Off e_phoff;
	Elf32_Off e_shoff;
	Elf32_Word e_flags;
	Elf32_Half e_ehsize;
	Elf32_Half e_phentsize;
	Elf32_Half e_phnum;
	Elf32_Half e_shentsize;
	Elf32_Half e_shnum;
	Elf32_Half e_shstrndx;
};

struct arch_elf_state {
	int flags;
};

struct dev_pagemap_ops___7 {
	void (*page_free)(struct page___8 *);
	void (*kill)(struct dev_pagemap___7 *);
	void (*cleanup)(struct dev_pagemap___7 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___7 *);
};

struct cgroup_namespace___6 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___2 *root_cset;
};

struct property___2 {
	char *name;
	int length;
	void *value;
	struct property___2 *next;
	long unsigned int _flags;
	struct bin_attribute___7 attr;
};

struct kernel_param_ops___7 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___7 *);
	int (*get)(char *, const struct kernel_param___7 *);
	void (*free)(void *);
};

struct kparam_array___7;

struct kernel_param___7 {
	const char *name;
	struct module___9 *mod;
	const struct kernel_param_ops___7 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___7 *arr;
	};
};

struct kparam_array___7 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___7 *ops;
	void *elem;
};

struct module_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___7 *, struct module_kobject___7 *, char *);
	ssize_t (*store)(struct module_attribute___7 *, struct module_kobject___7 *, const char *, size_t);
	void (*setup)(struct module___9 *, const char *);
	int (*test)(struct module___9 *);
	void (*free)(struct module___9 *);
};

struct trace_event_class___5;

struct trace_event_call___5 {
	struct list_head list;
	struct trace_event_class___5 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___5 *, struct perf_event___5 *);
};

struct cftype___5;

struct cgroup_subsys___5 {
	struct cgroup_subsys_state___5 * (*css_alloc)(struct cgroup_subsys_state___5 *);
	int (*css_online)(struct cgroup_subsys_state___5 *);
	void (*css_offline)(struct cgroup_subsys_state___5 *);
	void (*css_released)(struct cgroup_subsys_state___5 *);
	void (*css_free)(struct cgroup_subsys_state___5 *);
	void (*css_reset)(struct cgroup_subsys_state___5 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___5 *, int);
	int (*css_extra_stat_show)(struct seq_file___10 *, struct cgroup_subsys_state___5 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___9 *, struct css_set___2 *);
	void (*cancel_fork)(struct task_struct___9 *, struct css_set___2 *);
	void (*fork)(struct task_struct___9 *);
	void (*exit)(struct task_struct___9 *);
	void (*release)(struct task_struct___9 *);
	void (*bind)(struct cgroup_subsys_state___5 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___5 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___5 *dfl_cftypes;
	struct cftype___5 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___5 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___5 *updated_children;
	struct cgroup___5 *updated_next;
};

struct cgroup_root___5 {
	struct kernfs_root___7 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___5 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___5 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___5 *ss;
	struct list_head node;
	struct kernfs_ops___7 *kf_ops;
	int (*open)(struct kernfs_open_file___7 *);
	void (*release)(struct kernfs_open_file___7 *);
	u64 (*read_u64)(struct cgroup_subsys_state___5 *, struct cftype___5 *);
	s64 (*read_s64)(struct cgroup_subsys_state___5 *, struct cftype___5 *);
	int (*seq_show)(struct seq_file___10 *, void *);
	void * (*seq_start)(struct seq_file___10 *, loff_t *);
	void * (*seq_next)(struct seq_file___10 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___10 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___5 *, struct cftype___5 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___5 *, struct cftype___5 *, s64);
	ssize_t (*write)(struct kernfs_open_file___7 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___7 *, struct poll_table_struct___6 *);
};

struct perf_cpu_context___5;

struct perf_output_handle___5;

struct pmu___5 {
	struct list_head entry;
	struct module___9 *module;
	struct device___6 *dev;
	const struct attribute_group___7 **attr_groups;
	const struct attribute_group___7 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___5 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___5 *);
	void (*pmu_disable)(struct pmu___5 *);
	int (*event_init)(struct perf_event___5 *);
	void (*event_mapped)(struct perf_event___5 *, struct mm_struct___8 *);
	void (*event_unmapped)(struct perf_event___5 *, struct mm_struct___8 *);
	int (*add)(struct perf_event___5 *, int);
	void (*del)(struct perf_event___5 *, int);
	void (*start)(struct perf_event___5 *, int);
	void (*stop)(struct perf_event___5 *, int);
	void (*read)(struct perf_event___5 *);
	void (*start_txn)(struct pmu___5 *, unsigned int);
	int (*commit_txn)(struct pmu___5 *);
	void (*cancel_txn)(struct pmu___5 *);
	int (*event_idx)(struct perf_event___5 *);
	void (*sched_task)(struct perf_event_context___2 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___2 *, struct perf_event_context___2 *);
	void * (*setup_aux)(struct perf_event___5 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___5 *, struct perf_output_handle___5 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___5 *);
	int (*aux_output_match)(struct perf_event___5 *);
	int (*filter_match)(struct perf_event___5 *);
	int (*check_period)(struct perf_event___5 *, u64);
};

struct perf_cpu_context___5 {
	struct perf_event_context___2 ctx;
	struct perf_event_context___2 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___5 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___5 **heap;
	struct perf_event___5 *heap_default[2];
};

struct perf_output_handle___5 {
	struct perf_event___5 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___5 {
	struct cgroup_subsys_state___5 css;
	struct perf_cgroup_info *info;
};

struct pm_qos_flags_request {
	struct list_head node;
	s32 flags;
};

enum freq_qos_req_type {
	FREQ_QOS_MIN = 1,
	FREQ_QOS_MAX = 2,
};

struct freq_qos_request {
	enum freq_qos_req_type type;
	struct plist_node pnode;
	struct freq_constraints *qos;
};

enum dev_pm_qos_req_type {
	DEV_PM_QOS_RESUME_LATENCY = 1,
	DEV_PM_QOS_LATENCY_TOLERANCE = 2,
	DEV_PM_QOS_MIN_FREQUENCY = 3,
	DEV_PM_QOS_MAX_FREQUENCY = 4,
	DEV_PM_QOS_FLAGS = 5,
};

struct dev_pm_qos_request {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___6 *dev;
};

struct trace_event_fields___5 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___5 *);
	};
};

struct trace_event_class___5 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___5 *, enum trace_reg, void *);
	struct trace_event_fields___5 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___5 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___5 *);
};

struct stackframe {
	long unsigned int fp;
	long unsigned int pc;
	long unsigned int stacks_done[1];
	long unsigned int prev_fp;
	enum stack_type prev_type;
	int graph;
};

struct dentry___9;

struct super_block___9;

struct module___10;

struct file_system_type___8 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___9 * (*mount)(struct file_system_type___8 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___9 *);
	struct module___10 *owner;
	struct file_system_type___8 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___9;

struct kiocb___8;

struct iov_iter___5;

struct vm_area_struct___8;

struct inode___10;

struct file_lock___8;

struct page___9;

struct seq_file___11;

struct file_operations___8 {
	struct module___10 *owner;
	loff_t (*llseek)(struct file___9 *, loff_t, int);
	ssize_t (*read)(struct file___9 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___9 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___8 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___8 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___8 *, bool);
	int (*iterate)(struct file___9 *, struct dir_context *);
	int (*iterate_shared)(struct file___9 *, struct dir_context *);
	__poll_t (*poll)(struct file___9 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___9 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___9 *, struct vm_area_struct___8 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___10 *, struct file___9 *);
	int (*flush)(struct file___9 *, fl_owner_t);
	int (*release)(struct inode___10 *, struct file___9 *);
	int (*fsync)(struct file___9 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___9 *, int);
	int (*lock)(struct file___9 *, int, struct file_lock___8 *);
	ssize_t (*sendpage)(struct file___9 *, struct page___9 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___9 *, long unsigned int);
	int (*flock)(struct file___9 *, int, struct file_lock___8 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___9 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___9 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___9 *, long int, struct file_lock___8 **, void **);
	long int (*fallocate)(struct file___9 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___11 *, struct file___9 *);
	ssize_t (*copy_file_range)(struct file___9 *, loff_t, struct file___9 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___9 *, loff_t, struct file___9 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___9 *, loff_t, loff_t, int);
};

struct user_sve_header {
	__u32 size;
	__u32 max_size;
	__u16 vl;
	__u16 max_vl;
	__u16 flags;
	__u16 __reserved;
};

struct user_pac_mask {
	__u64 data_mask;
	__u64 insn_mask;
};

struct user_pac_address_keys {
	__int128 unsigned apiakey;
	__int128 unsigned apibkey;
	__int128 unsigned apdakey;
	__int128 unsigned apdbkey;
};

struct user_pac_generic_keys {
	__int128 unsigned apgakey;
};

struct vmacache___8 {
	u64 seqnum;
	struct vm_area_struct___8 *vmas[4];
};

struct page_frag___8 {
	struct page___9 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___6;

struct debug_info___6 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___6 *hbp_break[16];
	struct perf_event___6 *hbp_watch[16];
};

struct thread_struct___6 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___6 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___9;

struct pid___8;

struct nsproxy___9;

struct signal_struct___9;

struct io_context___5;

struct css_set___6;

struct perf_event_context___6;

struct mem_cgroup___3;

struct request_queue___6;

struct task_struct___10 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___10 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___9 *mm;
	struct mm_struct___9 *active_mm;
	struct vmacache___8 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___10 *real_parent;
	struct task_struct___10 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___10 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___8 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___9 *nsproxy;
	struct signal_struct___9 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___10 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___6 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___6 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___8 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___3 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___3 *active_memcg;
	struct request_queue___6 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___10 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___6 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___8;

struct kobj_type___8;

struct kernfs_node___8;

struct kobject___8 {
	const char *name;
	struct list_head entry;
	struct kobject___8 *parent;
	struct kset___8 *kset;
	struct kobj_type___8 *ktype;
	struct kernfs_node___8 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___8 {
	struct kobject___8 kobj;
	struct module___10 *mod;
	struct kobject___8 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___8 {
	struct module___10 *mod;
	struct latch_tree_node node;
};

struct module_layout___8 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___8 mtn;
};

struct module_attribute___8;

struct kernel_param___8;

struct trace_event_call___6;

struct module___10 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___8 mkobj;
	struct module_attribute___8 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___8 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___8 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___8 core_layout;
	struct module_layout___8 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___6 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___6 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___10 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___6)(struct perf_event___6 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___6;

struct fasync_struct___8;

struct pid_namespace___8;

struct perf_cgroup___6;

struct perf_event___6 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___6 *group_leader;
	struct pmu___6 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___6 hw;
	struct perf_event_context___6 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___6 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___10 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___8 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___6 *aux_event;
	void (*destroy)(struct perf_event___6 *);
	struct callback_head callback_head;
	struct pid_namespace___8 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___6 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___6 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___6 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___6 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___8 {
	int nr;
	struct pid_namespace___8 *ns;
};

struct pid_namespace___8 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___10 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___8 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___8 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___8 numbers[1];
};

typedef struct page___9 *pgtable_t___8;

struct address_space___8;

struct dev_pagemap___8;

struct page___9 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___8 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___9 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___8 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___9 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___8 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct seccomp_data {
	int nr;
	__u32 arch;
	__u64 instruction_pointer;
	__u64 args[6];
};

struct vm_operations_struct___8;

struct vm_area_struct___8 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___8 *vm_next;
	struct vm_area_struct___8 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___9 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___9 *vm_file;
	struct file___9 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___9 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___10 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___10 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___8 *pids[4];
	struct pid___8 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___9 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___8;

struct mm_struct___9 {
	struct {
		struct vm_area_struct___8 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___9 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___8 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___10 *owner;
		struct user_namespace *user_ns;
		struct file___9 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___7;

struct nsproxy___9 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___8 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___7 *cgroup_ns;
};

struct bio___4;

struct bio_list___2 {
	struct bio___4 *head;
	struct bio___4 *tail;
};

struct cgroup_subsys_state___6;

struct bdi_writeback___3 {
	struct backing_dev_info___2 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___6 *memcg_css;
	struct cgroup_subsys_state___6 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___7;

struct backing_dev_info___2 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___3 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___7 *dev;
	char dev_name[64];
	struct device___7 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___9 *debug_dir;
};

struct io_cq___4;

struct io_context___5 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___4 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___6;

struct css_set___6 {
	struct cgroup_subsys_state___6 *subsys[14];
	refcount_t refcount;
	struct css_set___6 *dom_cset;
	struct cgroup___6 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___6 *mg_src_cgrp;
	struct cgroup___6 *mg_dst_cgrp;
	struct css_set___6 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___6 {
	struct pmu___6 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___10 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___6 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___6;

struct cgroup_subsys_state___6 {
	struct cgroup___6 *cgroup;
	struct cgroup_subsys___6 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___6 *parent;
};

struct cgroup_file___6 {
	struct kernfs_node___8 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___3;

struct mem_cgroup_per_node___3;

struct mem_cgroup___3 {
	struct cgroup_subsys_state___6 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___6 events_file;
	struct cgroup_file___6 events_local_file;
	struct cgroup_file___6 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___3 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___10 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___3 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___4;

struct blk_integrity___4 {
	const struct blk_integrity_profile___4 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___4 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___2 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___5;

struct elevator_queue___4;

struct blk_mq_ops___4;

struct blk_mq_hw_ctx___4;

struct gendisk___4;

struct blkcg_gq___4;

struct blk_mq_tag_set___4;

struct request_queue___6 {
	struct request___5 *last_merge;
	struct elevator_queue___4 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___4 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___4 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___4 *disk;
	struct kobject___8 kobj;
	struct kobject___8 *mq_kobj;
	struct blk_integrity___4 integrity;
	struct device___7 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___4 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___4 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___4 bio_split;
	struct dentry___9 *debugfs_dir;
	struct dentry___9 *sched_debugfs_dir;
	struct dentry___9 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___2 {
	struct vm_struct___2 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___9 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___8;

struct address_space___8 {
	struct inode___10 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___8 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___8;

struct dev_pagemap___8 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___8 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___8;

struct path___8 {
	struct vfsmount___8 *mnt;
	struct dentry___9 *dentry;
};

struct fown_struct___8 {
	rwlock_t lock;
	struct pid___8 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___9 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___8 f_path;
	struct inode___10 *f_inode;
	const struct file_operations___8 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___8 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___8 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___8;

struct vm_operations_struct___8 {
	void (*open)(struct vm_area_struct___8 *);
	void (*close)(struct vm_area_struct___8 *);
	int (*may_split)(struct vm_area_struct___8 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___8 *);
	int (*mprotect)(struct vm_area_struct___8 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___8 *);
	vm_fault_t (*huge_fault)(struct vm_fault___8 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___8 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___8 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___8 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___8 *);
	int (*access)(struct vm_area_struct___8 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___8 *);
	int (*set_policy)(struct vm_area_struct___8 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___8 *, long unsigned int);
	struct page___9 * (*find_special_page)(struct vm_area_struct___8 *, long unsigned int);
};

struct core_thread___8 {
	struct task_struct___10 *task;
	struct core_thread___8 *next;
};

struct core_state___8 {
	atomic_t nr_threads;
	struct core_thread___8 dumper;
	struct completion startup;
};

struct vm_fault___8 {
	const struct {
		struct vm_area_struct___8 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___9 *cow_page;
	struct page___9 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___8 prealloc_pte;
};

struct psi_group___6 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___10 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___6;

struct cgroup_rstat_cpu___6;

struct cgroup___6 {
	struct cgroup_subsys_state___6 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___8 *kn;
	struct cgroup_file___6 procs_file;
	struct cgroup_file___6 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___6 *subsys[14];
	struct cgroup_root___6 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___6 *dom_cgrp;
	struct cgroup___6 *old_dom_cgrp;
	struct cgroup_rstat_cpu___6 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___6 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___3;

struct lruvec___3 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___3 *pgdat;
};

struct zone___3 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___3 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___3 {
	struct zone___3 *zone;
	int zone_idx;
};

struct zonelist___3 {
	struct zoneref___3 _zonerefs[321];
};

struct pglist_data___3 {
	struct zone___3 node_zones[5];
	struct zonelist___3 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___10 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___10 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___3 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___3 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___3 *memcg;
};

struct shrinker___3 {
	long unsigned int (*count_objects)(struct shrinker___3 *, struct shrink_control___3 *);
	long unsigned int (*scan_objects)(struct shrinker___3 *, struct shrink_control___3 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___8 {
	void (*page_free)(struct page___9 *);
	void (*kill)(struct dev_pagemap___8 *);
	void (*cleanup)(struct dev_pagemap___8 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___8 *);
};

struct dentry_operations___8;

struct dentry___9 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___9 *d_parent;
	struct qstr d_name;
	struct inode___10 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___8 *d_op;
	struct super_block___9 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___8;

struct inode___10 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___8 *i_op;
	struct super_block___9 *i_sb;
	struct address_space___8 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___8 *i_fop;
		void (*free_inode)(struct inode___10 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___8 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___3 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___8 {
	int (*d_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___9 *, unsigned int);
	int (*d_hash)(const struct dentry___9 *, struct qstr *);
	int (*d_compare)(const struct dentry___9 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___9 *);
	int (*d_init)(struct dentry___9 *);
	void (*d_release)(struct dentry___9 *);
	void (*d_prune)(struct dentry___9 *);
	void (*d_iput)(struct dentry___9 *, struct inode___10 *);
	char * (*d_dname)(struct dentry___9 *, char *, int);
	struct vfsmount___8 * (*d_automount)(struct path___8 *);
	int (*d_manage)(const struct path___8 *, bool);
	struct dentry___9 * (*d_real)(struct dentry___9 *, const struct inode___10 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___8;

struct mem_dqinfo___8 {
	struct quota_format_type___8 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___8;

struct quota_info___8 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___10 *files[3];
	struct mem_dqinfo___8 info[3];
	const struct quota_format_ops___8 *ops[3];
};

struct rcuwait___8 {
	struct task_struct___10 *task;
};

struct percpu_rw_semaphore___8 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___8 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___8 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___8 rw_sem[3];
};

struct super_operations___8;

struct dquot_operations___8;

struct quotactl_ops___8;

struct super_block___9 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___8 *s_type;
	const struct super_operations___8 *s_op;
	const struct dquot_operations___8 *dq_op;
	const struct quotactl_ops___8 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___9 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___8 s_dquot;
	struct sb_writers___8 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___8 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___8 {
	struct dentry___9 *mnt_root;
	struct super_block___9 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

typedef u32 compat_ulong_t;

struct io_cq___4 {
	struct request_queue___6 *q;
	struct io_context___5 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___8 {
	struct file___9 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___8 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___9 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___9 *ia_file;
};

struct dquot___8 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___9 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___8 {
	int qf_fmt_id;
	const struct quota_format_ops___8 *qf_ops;
	struct module___10 *qf_owner;
	struct quota_format_type___8 *qf_next;
};

struct quota_format_ops___8 {
	int (*check_quota_file)(struct super_block___9 *, int);
	int (*read_file_info)(struct super_block___9 *, int);
	int (*write_file_info)(struct super_block___9 *, int);
	int (*free_file_info)(struct super_block___9 *, int);
	int (*read_dqblk)(struct dquot___8 *);
	int (*commit_dqblk)(struct dquot___8 *);
	int (*release_dqblk)(struct dquot___8 *);
	int (*get_next_id)(struct super_block___9 *, struct kqid *);
};

struct dquot_operations___8 {
	int (*write_dquot)(struct dquot___8 *);
	struct dquot___8 * (*alloc_dquot)(struct super_block___9 *, int);
	void (*destroy_dquot)(struct dquot___8 *);
	int (*acquire_dquot)(struct dquot___8 *);
	int (*release_dquot)(struct dquot___8 *);
	int (*mark_dirty)(struct dquot___8 *);
	int (*write_info)(struct super_block___9 *, int);
	qsize_t * (*get_reserved_space)(struct inode___10 *);
	int (*get_projid)(struct inode___10 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___10 *, qsize_t *);
	int (*get_next_id)(struct super_block___9 *, struct kqid *);
};

struct quotactl_ops___8 {
	int (*quota_on)(struct super_block___9 *, int, int, const struct path___8 *);
	int (*quota_off)(struct super_block___9 *, int);
	int (*quota_enable)(struct super_block___9 *, unsigned int);
	int (*quota_disable)(struct super_block___9 *, unsigned int);
	int (*quota_sync)(struct super_block___9 *, int);
	int (*set_info)(struct super_block___9 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___9 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___9 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___9 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___9 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___9 *, unsigned int);
};

struct address_space_operations___8 {
	int (*writepage)(struct page___9 *, struct writeback_control___3 *);
	int (*readpage)(struct file___9 *, struct page___9 *);
	int (*writepages)(struct address_space___8 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___9 *);
	int (*readpages)(struct file___9 *, struct address_space___8 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___9 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___9 **, void **);
	int (*write_end)(struct file___9 *, struct address_space___8 *, loff_t, unsigned int, unsigned int, struct page___9 *, void *);
	sector_t (*bmap)(struct address_space___8 *, sector_t);
	void (*invalidatepage)(struct page___9 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___9 *, gfp_t);
	void (*freepage)(struct page___9 *);
	ssize_t (*direct_IO)(struct kiocb___8 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___8 *, struct page___9 *, struct page___9 *, enum migrate_mode);
	bool (*isolate_page)(struct page___9 *, isolate_mode_t);
	void (*putback_page)(struct page___9 *);
	int (*launder_page)(struct page___9 *);
	int (*is_partially_uptodate)(struct page___9 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___9 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___8 *, struct page___9 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___9 *, sector_t *);
	void (*swap_deactivate)(struct file___9 *);
};

struct writeback_control___3 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___3 *wb;
	struct inode___10 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___5;

struct iov_iter___5 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___5 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___8 {
	struct dentry___9 * (*lookup)(struct inode___10 *, struct dentry___9 *, unsigned int);
	const char * (*get_link)(struct dentry___9 *, struct inode___10 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___10 *, int);
	struct posix_acl * (*get_acl)(struct inode___10 *, int, bool);
	int (*readlink)(struct dentry___9 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___10 *, struct dentry___9 *, umode_t, bool);
	int (*link)(struct dentry___9 *, struct inode___10 *, struct dentry___9 *);
	int (*unlink)(struct inode___10 *, struct dentry___9 *);
	int (*symlink)(struct user_namespace *, struct inode___10 *, struct dentry___9 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___10 *, struct dentry___9 *, umode_t);
	int (*rmdir)(struct inode___10 *, struct dentry___9 *);
	int (*mknod)(struct user_namespace *, struct inode___10 *, struct dentry___9 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___10 *, struct dentry___9 *, struct inode___10 *, struct dentry___9 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___9 *, struct iattr___9 *);
	int (*getattr)(struct user_namespace *, const struct path___8 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___9 *, char *, size_t);
	int (*fiemap)(struct inode___10 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___10 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___10 *, struct dentry___9 *, struct file___9 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___10 *, struct dentry___9 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___10 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___9 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___9 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___8 {
	void (*fl_copy_lock)(struct file_lock___8 *, struct file_lock___8 *);
	void (*fl_release_private)(struct file_lock___8 *);
};

struct lock_manager_operations___8;

struct file_lock___8 {
	struct file_lock___8 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___9 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___8 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___8 *fl_ops;
	const struct lock_manager_operations___8 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___8 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___8 *);
	int (*lm_grant)(struct file_lock___8 *, int);
	bool (*lm_break)(struct file_lock___8 *);
	int (*lm_change)(struct file_lock___8 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___8 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___8 *);
};

struct fasync_struct___8 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___8 *fa_next;
	struct file___9 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___8 {
	struct inode___10 * (*alloc_inode)(struct super_block___9 *);
	void (*destroy_inode)(struct inode___10 *);
	void (*free_inode)(struct inode___10 *);
	void (*dirty_inode)(struct inode___10 *, int);
	int (*write_inode)(struct inode___10 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___10 *);
	void (*evict_inode)(struct inode___10 *);
	void (*put_super)(struct super_block___9 *);
	int (*sync_fs)(struct super_block___9 *, int);
	int (*freeze_super)(struct super_block___9 *);
	int (*freeze_fs)(struct super_block___9 *);
	int (*thaw_super)(struct super_block___9 *);
	int (*unfreeze_fs)(struct super_block___9 *);
	int (*statfs)(struct dentry___9 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___9 *, int *, char *);
	void (*umount_begin)(struct super_block___9 *);
	int (*show_options)(struct seq_file___11 *, struct dentry___9 *);
	int (*show_devname)(struct seq_file___11 *, struct dentry___9 *);
	int (*show_path)(struct seq_file___11 *, struct dentry___9 *);
	int (*show_stats)(struct seq_file___11 *, struct dentry___9 *);
	ssize_t (*quota_read)(struct super_block___9 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___9 *, int, const char *, size_t, loff_t);
	struct dquot___8 ** (*get_dquots)(struct inode___10 *);
	long int (*nr_cached_objects)(struct super_block___9 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___9 *, struct shrink_control___3 *);
	struct file___9 * (*real_loop)(struct file___9 *);
};

struct wakeup_source___7;

struct dev_pm_info___7 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___7 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___7 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___7;

struct bus_type___7;

struct device_driver___7;

struct dev_pm_domain___7;

struct fwnode_handle___7;

struct class___7;

struct attribute_group___8;

struct device___7 {
	struct kobject___8 kobj;
	struct device___7 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___7 *type;
	struct bus_type___7 *bus;
	struct device_driver___7 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___7 power;
	struct dev_pm_domain___7 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___7 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___7 *class;
	const struct attribute_group___8 **groups;
	void (*release)(struct device___7 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___5 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___10 *bd_inode;
	struct super_block___9 *bd_super;
	void *bd_claiming;
	struct device___7 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___8 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___4 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___9 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___6)(struct file___9 *, wait_queue_head_t *, struct poll_table_struct___5 *);

struct poll_table_struct___5 {
	poll_queue_proc___6 _qproc;
	__poll_t _key;
};

struct seq_operations___9;

struct seq_file___11 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___9 *op;
	int poll_event;
	const struct file___9 *file;
	void *private;
};

typedef void bio_end_io_t___4(struct bio___4 *);

struct bio_vec___5 {
	struct page___9 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___4;

struct bio___4 {
	struct bio___4 *bi_next;
	struct block_device___5 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___4 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___4 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___4 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___5 *bi_io_vec;
	struct bio_set___4 *bi_pool;
	struct bio_vec___5 bi_inline_vecs[0];
};

struct cgroup_namespace___7 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___6 *root_cset;
};

enum perf_type_id {
	PERF_TYPE_HARDWARE = 0,
	PERF_TYPE_SOFTWARE = 1,
	PERF_TYPE_TRACEPOINT = 2,
	PERF_TYPE_HW_CACHE = 3,
	PERF_TYPE_RAW = 4,
	PERF_TYPE_BREAKPOINT = 5,
	PERF_TYPE_MAX = 6,
};

struct fwnode_operations___7;

struct fwnode_handle___7 {
	struct fwnode_handle___7 *secondary;
	const struct fwnode_operations___7 *ops;
	struct device___7 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___7;

struct fwnode_endpoint___7;

struct fwnode_operations___7 {
	struct fwnode_handle___7 * (*get)(struct fwnode_handle___7 *);
	void (*put)(struct fwnode_handle___7 *);
	bool (*device_is_available)(const struct fwnode_handle___7 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___7 *, const struct device___7 *);
	bool (*property_present)(const struct fwnode_handle___7 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___7 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___7 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___7 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_parent)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_next_child_node)(const struct fwnode_handle___7 *, struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*get_named_child_node)(const struct fwnode_handle___7 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___7 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___7 *);
	struct fwnode_handle___7 * (*graph_get_next_endpoint)(const struct fwnode_handle___7 *, struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*graph_get_remote_endpoint)(const struct fwnode_handle___7 *);
	struct fwnode_handle___7 * (*graph_get_port_parent)(struct fwnode_handle___7 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___7 *, struct fwnode_endpoint___7 *);
	int (*add_links)(struct fwnode_handle___7 *);
};

struct fwnode_endpoint___7 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___7 *local_fwnode;
};

struct fwnode_reference_args___7 {
	struct fwnode_handle___7 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___8;

struct kernfs_elem_dir___8 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___8 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___8;

struct kernfs_root___8 {
	struct kernfs_node___8 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___8 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___8 {
	struct kernfs_node___8 *target_kn;
};

struct kernfs_ops___8;

struct kernfs_elem_attr___8 {
	const struct kernfs_ops___8 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___8 *notify_next;
};

struct kernfs_node___8 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___8 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___8 dir;
		struct kernfs_elem_symlink___8 symlink;
		struct kernfs_elem_attr___8 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___8;

struct kernfs_ops___8 {
	int (*open)(struct kernfs_open_file___8 *);
	void (*release)(struct kernfs_open_file___8 *);
	int (*seq_show)(struct seq_file___11 *, void *);
	void * (*seq_start)(struct seq_file___11 *, loff_t *);
	void * (*seq_next)(struct seq_file___11 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___11 *, void *);
	ssize_t (*read)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___8 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___8 *, struct vm_area_struct___8 *);
};

struct kernfs_syscall_ops___8 {
	int (*show_options)(struct seq_file___11 *, struct kernfs_root___8 *);
	int (*mkdir)(struct kernfs_node___8 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___8 *);
	int (*rename)(struct kernfs_node___8 *, struct kernfs_node___8 *, const char *);
	int (*show_path)(struct seq_file___11 *, struct kernfs_node___8 *, struct kernfs_root___8 *);
};

struct kernfs_open_file___8 {
	struct kernfs_node___8 *kn;
	struct file___9 *file;
	struct seq_file___11 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___8;

struct attribute_group___8 {
	const char *name;
	umode_t (*is_visible)(struct kobject___8 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___8 *, struct bin_attribute___8 *, int);
	struct attribute **attrs;
	struct bin_attribute___8 **bin_attrs;
};

struct bin_attribute___8 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___8 * (*f_mapping)();
	ssize_t (*read)(struct file___9 *, struct kobject___8 *, struct bin_attribute___8 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___9 *, struct kobject___8 *, struct bin_attribute___8 *, char *, loff_t, size_t);
	int (*mmap)(struct file___9 *, struct kobject___8 *, struct bin_attribute___8 *, struct vm_area_struct___8 *);
};

struct sysfs_ops___8 {
	ssize_t (*show)(struct kobject___8 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___8 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___8;

struct kset___8 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___8 kobj;
	const struct kset_uevent_ops___8 *uevent_ops;
};

struct kobj_type___8 {
	void (*release)(struct kobject___8 *);
	const struct sysfs_ops___8 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___8 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___8 *);
	const void * (*namespace)(struct kobject___8 *);
	void (*get_ownership)(struct kobject___8 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___8 {
	int (* const filter)(struct kset___8 *, struct kobject___8 *);
	const char * (* const name)(struct kset___8 *, struct kobject___8 *);
	int (* const uevent)(struct kset___8 *, struct kobject___8 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___8 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___8 *);
	int (*get)(char *, const struct kernel_param___8 *);
	void (*free)(void *);
};

struct kparam_array___8;

struct kernel_param___8 {
	const char *name;
	struct module___10 *mod;
	const struct kernel_param_ops___8 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___8 *arr;
	};
};

struct kparam_array___8 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___8 *ops;
	void *elem;
};

struct module_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___8 *, struct module_kobject___8 *, char *);
	ssize_t (*store)(struct module_attribute___8 *, struct module_kobject___8 *, const char *, size_t);
	void (*setup)(struct module___10 *, const char *);
	int (*test)(struct module___10 *);
	void (*free)(struct module___10 *);
};

struct trace_event_class___6;

struct trace_event_call___6 {
	struct list_head list;
	struct trace_event_class___6 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___6 *, struct perf_event___6 *);
};

struct dev_pm_ops___7 {
	int (*prepare)(struct device___7 *);
	void (*complete)(struct device___7 *);
	int (*suspend)(struct device___7 *);
	int (*resume)(struct device___7 *);
	int (*freeze)(struct device___7 *);
	int (*thaw)(struct device___7 *);
	int (*poweroff)(struct device___7 *);
	int (*restore)(struct device___7 *);
	int (*suspend_late)(struct device___7 *);
	int (*resume_early)(struct device___7 *);
	int (*freeze_late)(struct device___7 *);
	int (*thaw_early)(struct device___7 *);
	int (*poweroff_late)(struct device___7 *);
	int (*restore_early)(struct device___7 *);
	int (*suspend_noirq)(struct device___7 *);
	int (*resume_noirq)(struct device___7 *);
	int (*freeze_noirq)(struct device___7 *);
	int (*thaw_noirq)(struct device___7 *);
	int (*poweroff_noirq)(struct device___7 *);
	int (*restore_noirq)(struct device___7 *);
	int (*runtime_suspend)(struct device___7 *);
	int (*runtime_resume)(struct device___7 *);
	int (*runtime_idle)(struct device___7 *);
};

struct wakeup_source___7 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___7 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___7 {
	struct dev_pm_ops___7 ops;
	int (*start)(struct device___7 *);
	void (*detach)(struct device___7 *, bool);
	int (*activate)(struct device___7 *);
	void (*sync)(struct device___7 *);
	void (*dismiss)(struct device___7 *);
};

struct bus_type___7 {
	const char *name;
	const char *dev_name;
	struct device___7 *dev_root;
	const struct attribute_group___8 **bus_groups;
	const struct attribute_group___8 **dev_groups;
	const struct attribute_group___8 **drv_groups;
	int (*match)(struct device___7 *, struct device_driver___7 *);
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	int (*probe)(struct device___7 *);
	void (*sync_state)(struct device___7 *);
	void (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*online)(struct device___7 *);
	int (*offline)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	int (*num_vf)(struct device___7 *);
	int (*dma_configure)(struct device___7 *);
	const struct dev_pm_ops___7 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___7 {
	const char *name;
	struct bus_type___7 *bus;
	struct module___10 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___7 *);
	void (*sync_state)(struct device___7 *);
	int (*remove)(struct device___7 *);
	void (*shutdown)(struct device___7 *);
	int (*suspend)(struct device___7 *, pm_message_t);
	int (*resume)(struct device___7 *);
	const struct attribute_group___8 **groups;
	const struct attribute_group___8 **dev_groups;
	const struct dev_pm_ops___7 *pm;
	void (*coredump)(struct device___7 *);
	struct driver_private *p;
};

struct device_type___7 {
	const char *name;
	const struct attribute_group___8 **groups;
	int (*uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___7 *);
	const struct dev_pm_ops___7 *pm;
};

struct class___7 {
	const char *name;
	struct module___10 *owner;
	const struct attribute_group___8 **class_groups;
	const struct attribute_group___8 **dev_groups;
	struct kobject___8 *dev_kobj;
	int (*dev_uevent)(struct device___7 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___7 *, umode_t *);
	void (*class_release)(struct class___7 *);
	void (*dev_release)(struct device___7 *);
	int (*shutdown_pre)(struct device___7 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___7 *);
	void (*get_ownership)(struct device___7 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___7 *pm;
	struct subsys_private *p;
};

enum {
	TASKSTATS_CMD_UNSPEC = 0,
	TASKSTATS_CMD_GET = 1,
	TASKSTATS_CMD_NEW = 2,
	__TASKSTATS_CMD_MAX = 3,
};

struct seq_operations___9 {
	void * (*start)(struct seq_file___11 *, loff_t *);
	void (*stop)(struct seq_file___11 *, void *);
	void * (*next)(struct seq_file___11 *, void *, loff_t *);
	int (*show)(struct seq_file___11 *, void *);
};

enum ucount_type {
	UCOUNT_USER_NAMESPACES = 0,
	UCOUNT_PID_NAMESPACES = 1,
	UCOUNT_UTS_NAMESPACES = 2,
	UCOUNT_IPC_NAMESPACES = 3,
	UCOUNT_NET_NAMESPACES = 4,
	UCOUNT_MNT_NAMESPACES = 5,
	UCOUNT_CGROUP_NAMESPACES = 6,
	UCOUNT_TIME_NAMESPACES = 7,
	UCOUNT_INOTIFY_INSTANCES = 8,
	UCOUNT_INOTIFY_WATCHES = 9,
	UCOUNT_FANOTIFY_GROUPS = 10,
	UCOUNT_FANOTIFY_MARKS = 11,
	UCOUNT_RLIMIT_NPROC = 12,
	UCOUNT_RLIMIT_MSGQUEUE = 13,
	UCOUNT_RLIMIT_SIGPENDING = 14,
	UCOUNT_RLIMIT_MEMLOCK = 15,
	UCOUNT_COUNTS = 16,
};

enum cpu_usage_stat {
	CPUTIME_USER = 0,
	CPUTIME_NICE = 1,
	CPUTIME_SYSTEM = 2,
	CPUTIME_SOFTIRQ = 3,
	CPUTIME_IRQ = 4,
	CPUTIME_IDLE = 5,
	CPUTIME_IOWAIT = 6,
	CPUTIME_STEAL = 7,
	CPUTIME_GUEST = 8,
	CPUTIME_GUEST_NICE = 9,
	NR_STATS = 10,
};

enum bpf_cgroup_storage_type {
	BPF_CGROUP_STORAGE_SHARED = 0,
	BPF_CGROUP_STORAGE_PERCPU = 1,
	__BPF_CGROUP_STORAGE_MAX = 2,
};

enum bpf_tramp_prog_type {
	BPF_TRAMP_FENTRY = 0,
	BPF_TRAMP_FEXIT = 1,
	BPF_TRAMP_MODIFY_RETURN = 2,
	BPF_TRAMP_MAX = 3,
	BPF_TRAMP_REPLACE = 4,
};

enum cgroup_bpf_attach_type {
	CGROUP_BPF_ATTACH_TYPE_INVALID = 4294967295,
	CGROUP_INET_INGRESS = 0,
	CGROUP_INET_EGRESS = 1,
	CGROUP_INET_SOCK_CREATE = 2,
	CGROUP_SOCK_OPS = 3,
	CGROUP_DEVICE = 4,
	CGROUP_INET4_BIND = 5,
	CGROUP_INET6_BIND = 6,
	CGROUP_INET4_CONNECT = 7,
	CGROUP_INET6_CONNECT = 8,
	CGROUP_INET4_POST_BIND = 9,
	CGROUP_INET6_POST_BIND = 10,
	CGROUP_UDP4_SENDMSG = 11,
	CGROUP_UDP6_SENDMSG = 12,
	CGROUP_SYSCTL = 13,
	CGROUP_UDP4_RECVMSG = 14,
	CGROUP_UDP6_RECVMSG = 15,
	CGROUP_GETSOCKOPT = 16,
	CGROUP_SETSOCKOPT = 17,
	CGROUP_INET4_GETPEERNAME = 18,
	CGROUP_INET6_GETPEERNAME = 19,
	CGROUP_INET4_GETSOCKNAME = 20,
	CGROUP_INET6_GETSOCKNAME = 21,
	CGROUP_INET_SOCK_RELEASE = 22,
	MAX_CGROUP_BPF_ATTACH_TYPE = 23,
};

enum psi_task_count {
	NR_IOWAIT = 0,
	NR_MEMSTALL = 1,
	NR_RUNNING = 2,
	NR_ONCPU = 3,
	NR_MEMSTALL_RUNNING = 4,
	NR_PSI_TASK_COUNTS = 5,
};

enum psi_states {
	PSI_IO_SOME = 0,
	PSI_IO_FULL = 1,
	PSI_MEM_SOME = 2,
	PSI_MEM_FULL = 3,
	PSI_CPU_SOME = 4,
	PSI_CPU_FULL = 5,
	PSI_NONIDLE = 6,
	NR_PSI_STATES = 7,
};

enum psi_aggregators {
	PSI_AVGS = 0,
	PSI_POLL = 1,
	NR_PSI_AGGREGATORS = 2,
};

enum cgroup_subsys_id {
	cpuset_cgrp_id = 0,
	cpu_cgrp_id = 1,
	cpuacct_cgrp_id = 2,
	io_cgrp_id = 3,
	memory_cgrp_id = 4,
	devices_cgrp_id = 5,
	freezer_cgrp_id = 6,
	net_cls_cgrp_id = 7,
	perf_event_cgrp_id = 8,
	net_prio_cgrp_id = 9,
	hugetlb_cgrp_id = 10,
	pids_cgrp_id = 11,
	rdma_cgrp_id = 12,
	misc_cgrp_id = 13,
	CGROUP_SUBSYS_COUNT = 14,
};

struct cftype___6;

struct cgroup_subsys___6 {
	struct cgroup_subsys_state___6 * (*css_alloc)(struct cgroup_subsys_state___6 *);
	int (*css_online)(struct cgroup_subsys_state___6 *);
	void (*css_offline)(struct cgroup_subsys_state___6 *);
	void (*css_released)(struct cgroup_subsys_state___6 *);
	void (*css_free)(struct cgroup_subsys_state___6 *);
	void (*css_reset)(struct cgroup_subsys_state___6 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___6 *, int);
	int (*css_extra_stat_show)(struct seq_file___11 *, struct cgroup_subsys_state___6 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___10 *, struct css_set___6 *);
	void (*cancel_fork)(struct task_struct___10 *, struct css_set___6 *);
	void (*fork)(struct task_struct___10 *);
	void (*exit)(struct task_struct___10 *);
	void (*release)(struct task_struct___10 *);
	void (*bind)(struct cgroup_subsys_state___6 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___6 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___6 *dfl_cftypes;
	struct cftype___6 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___6 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___6 *updated_children;
	struct cgroup___6 *updated_next;
};

struct cgroup_root___6 {
	struct kernfs_root___8 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___6 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___6 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___6 *ss;
	struct list_head node;
	struct kernfs_ops___8 *kf_ops;
	int (*open)(struct kernfs_open_file___8 *);
	void (*release)(struct kernfs_open_file___8 *);
	u64 (*read_u64)(struct cgroup_subsys_state___6 *, struct cftype___6 *);
	s64 (*read_s64)(struct cgroup_subsys_state___6 *, struct cftype___6 *);
	int (*seq_show)(struct seq_file___11 *, void *);
	void * (*seq_start)(struct seq_file___11 *, loff_t *);
	void * (*seq_next)(struct seq_file___11 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___11 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___6 *, struct cftype___6 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___6 *, struct cftype___6 *, s64);
	ssize_t (*write)(struct kernfs_open_file___8 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___8 *, struct poll_table_struct___5 *);
};

struct perf_cpu_context___6;

struct perf_output_handle___6;

struct pmu___6 {
	struct list_head entry;
	struct module___10 *module;
	struct device___7 *dev;
	const struct attribute_group___8 **attr_groups;
	const struct attribute_group___8 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___6 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___6 *);
	void (*pmu_disable)(struct pmu___6 *);
	int (*event_init)(struct perf_event___6 *);
	void (*event_mapped)(struct perf_event___6 *, struct mm_struct___9 *);
	void (*event_unmapped)(struct perf_event___6 *, struct mm_struct___9 *);
	int (*add)(struct perf_event___6 *, int);
	void (*del)(struct perf_event___6 *, int);
	void (*start)(struct perf_event___6 *, int);
	void (*stop)(struct perf_event___6 *, int);
	void (*read)(struct perf_event___6 *);
	void (*start_txn)(struct pmu___6 *, unsigned int);
	int (*commit_txn)(struct pmu___6 *);
	void (*cancel_txn)(struct pmu___6 *);
	int (*event_idx)(struct perf_event___6 *);
	void (*sched_task)(struct perf_event_context___6 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___6 *, struct perf_event_context___6 *);
	void * (*setup_aux)(struct perf_event___6 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___6 *, struct perf_output_handle___6 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___6 *);
	int (*aux_output_match)(struct perf_event___6 *);
	int (*filter_match)(struct perf_event___6 *);
	int (*check_period)(struct perf_event___6 *, u64);
};

struct perf_cpu_context___6 {
	struct perf_event_context___6 ctx;
	struct perf_event_context___6 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___6 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___6 **heap;
	struct perf_event___6 *heap_default[2];
};

struct perf_output_handle___6 {
	struct perf_event___6 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___6 {
	struct cgroup_subsys_state___6 css;
	struct perf_cgroup_info *info;
};

enum {
	HW_BREAKPOINT_LEN_1 = 1,
	HW_BREAKPOINT_LEN_2 = 2,
	HW_BREAKPOINT_LEN_3 = 3,
	HW_BREAKPOINT_LEN_4 = 4,
	HW_BREAKPOINT_LEN_5 = 5,
	HW_BREAKPOINT_LEN_6 = 6,
	HW_BREAKPOINT_LEN_7 = 7,
	HW_BREAKPOINT_LEN_8 = 8,
};

enum {
	HW_BREAKPOINT_EMPTY = 0,
	HW_BREAKPOINT_R = 1,
	HW_BREAKPOINT_W = 2,
	HW_BREAKPOINT_RW = 3,
	HW_BREAKPOINT_X = 4,
	HW_BREAKPOINT_INVALID = 7,
};

enum bp_type_idx {
	TYPE_INST = 0,
	TYPE_DATA = 1,
	TYPE_MAX = 2,
};

struct membuf {
	void *p;
	size_t left;
};

struct user_regset;

typedef int user_regset_active_fn(struct task_struct___10 *, const struct user_regset *);

typedef int user_regset_get2_fn(struct task_struct___10 *, const struct user_regset *, struct membuf);

typedef int user_regset_set_fn(struct task_struct___10 *, const struct user_regset *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn(struct task_struct___10 *, const struct user_regset *, int);

struct user_regset {
	user_regset_get2_fn *regset_get;
	user_regset_set_fn *set;
	user_regset_active_fn *active;
	user_regset_writeback_fn *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view {
	const char *name;
	const struct user_regset *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct block_device_operations___4;

struct gendisk___4 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___5 *part0;
	const struct block_device_operations___4 *fops;
	struct request_queue___6 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___8 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___8 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___4 {
	struct bio___4 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___5 *bip_vec;
	struct bio_vec___5 bip_inline_vecs[0];
};

struct blkcg___3;

struct blkg_policy_data___3;

struct blkcg_gq___4 {
	struct request_queue___6 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___3 *blkcg;
	struct blkcg_gq___4 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___3 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___2 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___4(struct request___5 *);

typedef void integrity_complete_fn___4(struct request___5 *, unsigned int);

struct blk_integrity_profile___4 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___4 *prepare_fn;
	integrity_complete_fn___4 *complete_fn;
	const char *name;
};

struct block_device_operations___4 {
	blk_qc_t (*submit_bio)(struct bio___4 *);
	int (*open)(struct block_device___5 *, fmode_t);
	void (*release)(struct gendisk___4 *, fmode_t);
	int (*rw_page)(struct block_device___5 *, sector_t, struct page___9 *, unsigned int);
	int (*ioctl)(struct block_device___5 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___5 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___4 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___4 *);
	int (*getgeo)(struct block_device___5 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___5 *, bool);
	void (*swap_slot_free_notify)(struct block_device___5 *, long unsigned int);
	int (*report_zones)(struct gendisk___4 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___4 *, umode_t *);
	struct module___10 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___4 *, sector_t *);
};

typedef void rq_end_io_fn___4(struct request___5 *, blk_status_t);

struct request___5 {
	struct request_queue___6 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___4 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___4 *bio;
	struct bio___4 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___5 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___4 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___4 *saved_end_io;
		} flush;
	};
	struct gendisk___4 *rq_disk;
	struct block_device___5 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___4 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___4 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___6 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___8 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___9 *debugfs_dir;
	struct dentry___9 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___4;

struct elevator_mq_ops___4 {
	int (*init_sched)(struct request_queue___6 *, struct elevator_type___4 *);
	void (*exit_sched)(struct elevator_queue___4 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___4 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___4 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___4 *);
	bool (*allow_merge)(struct request_queue___6 *, struct request___5 *, struct bio___4 *);
	bool (*bio_merge)(struct request_queue___6 *, struct bio___4 *, unsigned int);
	int (*request_merge)(struct request_queue___6 *, struct request___5 **, struct bio___4 *);
	void (*request_merged)(struct request_queue___6 *, struct request___5 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___6 *, struct request___5 *, struct request___5 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___5 *);
	void (*finish_request)(struct request___5 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___4 *, struct list_head *, bool);
	struct request___5 * (*dispatch_request)(struct blk_mq_hw_ctx___4 *);
	bool (*has_work)(struct blk_mq_hw_ctx___4 *);
	void (*completed_request)(struct request___5 *, u64);
	void (*requeue_request)(struct request___5 *);
	struct request___5 * (*former_request)(struct request_queue___6 *, struct request___5 *);
	struct request___5 * (*next_request)(struct request_queue___6 *, struct request___5 *);
	void (*init_icq)(struct io_cq___4 *);
	void (*exit_icq)(struct io_cq___4 *);
};

struct elv_fs_entry___4;

struct elevator_type___4 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___4 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___4 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___10 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___4 {
	struct elevator_type___4 *type;
	void *elevator_data;
	struct kobject___8 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___4 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___4 *, char *);
	ssize_t (*store)(struct elevator_queue___4 *, const char *, size_t);
};

struct blk_mq_queue_data___4;

struct blk_mq_ops___4 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___4 *, const struct blk_mq_queue_data___4 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___4 *);
	int (*get_budget)(struct request_queue___6 *);
	void (*put_budget)(struct request_queue___6 *, int);
	void (*set_rq_budget_token)(struct request___5 *, int);
	int (*get_rq_budget_token)(struct request___5 *);
	enum blk_eh_timer_return (*timeout)(struct request___5 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___4 *);
	void (*complete)(struct request___5 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___4 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___4 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___4 *, struct request___5 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___4 *, struct request___5 *, unsigned int);
	void (*initialize_rq_fn)(struct request___5 *);
	void (*cleanup_rq)(struct request___5 *);
	bool (*busy)(struct request_queue___6 *);
	int (*map_queues)(struct blk_mq_tag_set___4 *);
	void (*show_rq)(struct seq_file___11 *, struct request___5 *);
};

struct blk_mq_tag_set___4 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___4 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___4 {
	struct request___5 *rq;
	bool last;
};

struct blkcg_policy_data___3;

struct blkcg___3 {
	struct cgroup_subsys_state___6 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___4 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___3 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___3 {
	struct blkcg___3 *blkcg;
	int plid;
};

struct blkg_policy_data___3 {
	struct blkcg_gq___4 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___3 {
	struct mem_cgroup___3 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___3 {
	struct lruvec___3 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___3 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___3 *memcg;
};

struct obj_cgroup___3 {
	struct percpu_ref refcnt;
	struct mem_cgroup___3 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct trace_event_fields___6 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___6 *);
	};
};

struct trace_event_class___6 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___6 *, enum trace_reg, void *);
	struct trace_event_fields___6 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___6 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___6 *);
};

struct trace_event_file___2;

struct trace_event_buffer___2 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___2 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___2 {
	struct list_head list;
	struct trace_event_call___6 *event_call;
	struct event_filter *filter;
	struct dentry___9 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_sys_enter {
	struct trace_entry ent;
	long int id;
	long unsigned int args[6];
	char __data[0];
};

struct trace_event_raw_sys_exit {
	struct trace_entry ent;
	long int id;
	long int ret;
	char __data[0];
};

struct trace_event_data_offsets_sys_enter {};

struct trace_event_data_offsets_sys_exit {};

typedef void (*btf_trace_sys_enter)(void *, struct pt_regs *, long int);

typedef void (*btf_trace_sys_exit)(void *, struct pt_regs *, long int);

struct pt_regs_offset {
	const char *name;
	int offset;
};

enum aarch64_regset {
	REGSET_GPR = 0,
	REGSET_FPR = 1,
	REGSET_TLS = 2,
	REGSET_HW_BREAK = 3,
	REGSET_HW_WATCH = 4,
	REGSET_SYSTEM_CALL = 5,
	REGSET_SVE = 6,
	REGSET_PAC_MASK = 7,
	REGSET_PAC_ENABLED_KEYS = 8,
	REGSET_PACA_KEYS = 9,
	REGSET_PACG_KEYS = 10,
	REGSET_TAGGED_ADDR_CTRL = 11,
};

enum compat_regset {
	REGSET_COMPAT_GPR = 0,
	REGSET_COMPAT_VFP = 1,
};

enum ptrace_syscall_dir {
	PTRACE_SYSCALL_ENTER = 0,
	PTRACE_SYSCALL_EXIT = 1,
};

struct irq_desc___2;

typedef void (*irq_flow_handler_t___2)(struct irq_desc___2 *);

struct irq_chip___2;

struct irq_domain___3;

struct irq_data___2 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___2 *chip;
	struct irq_domain___3 *domain;
	struct irq_data___2 *parent_data;
	void *chip_data;
};

struct kset___9;

struct kobj_type___9;

struct kernfs_node___9;

struct kobject___9 {
	const char *name;
	struct list_head entry;
	struct kobject___9 *parent;
	struct kset___9 *kset;
	struct kobj_type___9 *ktype;
	struct kernfs_node___9 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___2;

struct module___11;

struct irq_desc___2 {
	struct irq_common_data irq_common_data;
	struct irq_data___2 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___2 handle_irq;
	struct irqaction___2 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___9 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___11 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___10;

struct super_block___10;

struct file_system_type___9 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___10 * (*mount)(struct file_system_type___9 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___10 *);
	struct module___11 *owner;
	struct file_system_type___9 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___10;

struct kiocb___9;

struct poll_table_struct___7;

struct vm_area_struct___9;

struct inode___11;

struct file_lock___9;

struct page___10;

struct seq_file___12;

struct file_operations___9 {
	struct module___11 *owner;
	loff_t (*llseek)(struct file___10 *, loff_t, int);
	ssize_t (*read)(struct file___10 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___10 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___9 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___9 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___9 *, bool);
	int (*iterate)(struct file___10 *, struct dir_context *);
	int (*iterate_shared)(struct file___10 *, struct dir_context *);
	__poll_t (*poll)(struct file___10 *, struct poll_table_struct___7 *);
	long int (*unlocked_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___10 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___10 *, struct vm_area_struct___9 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___11 *, struct file___10 *);
	int (*flush)(struct file___10 *, fl_owner_t);
	int (*release)(struct inode___11 *, struct file___10 *);
	int (*fsync)(struct file___10 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___10 *, int);
	int (*lock)(struct file___10 *, int, struct file_lock___9 *);
	ssize_t (*sendpage)(struct file___10 *, struct page___10 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___10 *, long unsigned int);
	int (*flock)(struct file___10 *, int, struct file_lock___9 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___10 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___10 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___10 *, long int, struct file_lock___9 **, void **);
	long int (*fallocate)(struct file___10 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___12 *, struct file___10 *);
	ssize_t (*copy_file_range)(struct file___10 *, loff_t, struct file___10 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___10 *, loff_t, struct file___10 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___10 *, loff_t, loff_t, int);
};

struct vmacache___9 {
	u64 seqnum;
	struct vm_area_struct___9 *vmas[4];
};

struct page_frag___9 {
	struct page___10 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___10;

struct pid___9;

struct nsproxy___10;

struct signal_struct___10;

struct vm_struct___9;

struct task_struct___11 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___11 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___10 *mm;
	struct mm_struct___10 *active_mm;
	struct vmacache___9 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___11 *real_parent;
	struct task_struct___11 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___11 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___9 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___10 *nsproxy;
	struct signal_struct___10 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___11 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___9 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___11 *oom_reaper_list;
	struct vm_struct___9 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___6 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___9 {
	struct kobject___9 kobj;
	struct module___11 *mod;
	struct kobject___9 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___9 {
	struct module___11 *mod;
	struct latch_tree_node node;
};

struct module_layout___9 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___9 mtn;
};

struct module_attribute___9;

struct kernel_param___9;

struct module___11 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___9 mkobj;
	struct module_attribute___9 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___9 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___9 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___9 core_layout;
	struct module_layout___9 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___10 *pgtable_t___9;

struct address_space___9;

struct dev_pagemap___9;

struct page___10 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___9 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___10 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___9 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___10 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___9 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___9;

struct vm_area_struct___9 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___9 *vm_next;
	struct vm_area_struct___9 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___10 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___9 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___10 *vm_file;
	struct file___10 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___9;

struct mm_struct___10 {
	struct {
		struct vm_area_struct___9 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___10 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___9 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___11 *owner;
		struct user_namespace *user_ns;
		struct file___10 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___9;

struct address_space___9 {
	struct inode___11 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___9 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___9;

struct dev_pagemap___9 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___9 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___9;

struct path___9 {
	struct vfsmount___9 *mnt;
	struct dentry___10 *dentry;
};

struct fown_struct___9 {
	rwlock_t lock;
	struct pid___9 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___10 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___9 f_path;
	struct inode___11 *f_inode;
	const struct file_operations___9 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___9 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___9 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___9;

struct vm_operations_struct___9 {
	void (*open)(struct vm_area_struct___9 *);
	void (*close)(struct vm_area_struct___9 *);
	int (*may_split)(struct vm_area_struct___9 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___9 *);
	int (*mprotect)(struct vm_area_struct___9 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___9 *);
	vm_fault_t (*huge_fault)(struct vm_fault___9 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___9 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___9 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___9 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___9 *);
	int (*access)(struct vm_area_struct___9 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___9 *);
	int (*set_policy)(struct vm_area_struct___9 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___9 *, long unsigned int);
	struct page___10 * (*find_special_page)(struct vm_area_struct___9 *, long unsigned int);
};

struct core_thread___9 {
	struct task_struct___11 *task;
	struct core_thread___9 *next;
};

struct core_state___9 {
	atomic_t nr_threads;
	struct core_thread___9 dumper;
	struct completion startup;
};

struct vm_fault___9 {
	const struct {
		struct vm_area_struct___9 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___10 *cow_page;
	struct page___10 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___9 prealloc_pte;
};

struct pglist_data___4;

struct lruvec___4 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___4 *pgdat;
};

struct zone___4 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___4 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___4 {
	struct zone___4 *zone;
	int zone_idx;
};

struct zonelist___4 {
	struct zoneref___4 _zonerefs[321];
};

struct pglist_data___4 {
	struct zone___4 node_zones[5];
	struct zonelist___4 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___11 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___11 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___4 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___4 pg_data_t___2;

struct atomic_notifier_head {
	spinlock_t lock;
	struct notifier_block *head;
};

enum meminit_context {
	MEMINIT_EARLY = 0,
	MEMINIT_HOTPLUG = 1,
};

struct kernfs_root___9;

struct kernfs_elem_dir___9 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___9 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___9;

struct kernfs_root___9 {
	struct kernfs_node___9 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___9 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___9 {
	struct kernfs_node___9 *target_kn;
};

struct kernfs_ops___9;

struct kernfs_elem_attr___9 {
	const struct kernfs_ops___9 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___9 *notify_next;
};

struct kernfs_node___9 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___9 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___9 dir;
		struct kernfs_elem_symlink___9 symlink;
		struct kernfs_elem_attr___9 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___9;

struct kernfs_ops___9 {
	int (*open)(struct kernfs_open_file___9 *);
	void (*release)(struct kernfs_open_file___9 *);
	int (*seq_show)(struct seq_file___12 *, void *);
	void * (*seq_start)(struct seq_file___12 *, loff_t *);
	void * (*seq_next)(struct seq_file___12 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___12 *, void *);
	ssize_t (*read)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___9 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___9 *, struct poll_table_struct___7 *);
	int (*mmap)(struct kernfs_open_file___9 *, struct vm_area_struct___9 *);
};

struct kernfs_syscall_ops___9 {
	int (*show_options)(struct seq_file___12 *, struct kernfs_root___9 *);
	int (*mkdir)(struct kernfs_node___9 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___9 *);
	int (*rename)(struct kernfs_node___9 *, struct kernfs_node___9 *, const char *);
	int (*show_path)(struct seq_file___12 *, struct kernfs_node___9 *, struct kernfs_root___9 *);
};

struct seq_operations___10;

struct seq_file___12 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___10 *op;
	int poll_event;
	const struct file___10 *file;
	void *private;
};

struct kernfs_open_file___9 {
	struct kernfs_node___9 *kn;
	struct file___10 *file;
	struct seq_file___12 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___9 *vm_ops;
};

typedef void (*poll_queue_proc___7)(struct file___10 *, wait_queue_head_t *, struct poll_table_struct___7 *);

struct poll_table_struct___7 {
	poll_queue_proc___7 _qproc;
	__poll_t _key;
};

struct pid_namespace___9;

struct upid___9 {
	int nr;
	struct pid_namespace___9 *ns;
};

struct pid_namespace___9 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___11 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___9 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___9 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___9 numbers[1];
};

struct signal_struct___10 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___11 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___11 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___9 *pids[4];
	struct pid___9 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___10 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___10 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___9 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___9 {
	struct vm_struct___9 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___10 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___9;

struct attribute_group___9 {
	const char *name;
	umode_t (*is_visible)(struct kobject___9 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___9 *, struct bin_attribute___9 *, int);
	struct attribute **attrs;
	struct bin_attribute___9 **bin_attrs;
};

struct bin_attribute___9 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___9 * (*f_mapping)();
	ssize_t (*read)(struct file___10 *, struct kobject___9 *, struct bin_attribute___9 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___10 *, struct kobject___9 *, struct bin_attribute___9 *, char *, loff_t, size_t);
	int (*mmap)(struct file___10 *, struct kobject___9 *, struct bin_attribute___9 *, struct vm_area_struct___9 *);
};

struct sysfs_ops___9 {
	ssize_t (*show)(struct kobject___9 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___9 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___9;

struct kset___9 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___9 kobj;
	const struct kset_uevent_ops___9 *uevent_ops;
};

struct kobj_type___9 {
	void (*release)(struct kobject___9 *);
	const struct sysfs_ops___9 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___9 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___9 *);
	const void * (*namespace)(struct kobject___9 *);
	void (*get_ownership)(struct kobject___9 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___9 {
	int (* const filter)(struct kset___9 *, struct kobject___9 *);
	const char * (* const name)(struct kset___9 *, struct kobject___9 *);
	int (* const uevent)(struct kset___9 *, struct kobject___9 *, struct kobj_uevent_env *);
};

struct fwnode_operations___8;

struct device___8;

struct fwnode_handle___8 {
	struct fwnode_handle___8 *secondary;
	const struct fwnode_operations___8 *ops;
	struct device___8 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___8;

struct fwnode_endpoint___8;

struct fwnode_operations___8 {
	struct fwnode_handle___8 * (*get)(struct fwnode_handle___8 *);
	void (*put)(struct fwnode_handle___8 *);
	bool (*device_is_available)(const struct fwnode_handle___8 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___8 *, const struct device___8 *);
	bool (*property_present)(const struct fwnode_handle___8 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___8 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___8 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___8 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_parent)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_next_child_node)(const struct fwnode_handle___8 *, struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*get_named_child_node)(const struct fwnode_handle___8 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___8 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___8 *);
	struct fwnode_handle___8 * (*graph_get_next_endpoint)(const struct fwnode_handle___8 *, struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*graph_get_remote_endpoint)(const struct fwnode_handle___8 *);
	struct fwnode_handle___8 * (*graph_get_port_parent)(struct fwnode_handle___8 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___8 *, struct fwnode_endpoint___8 *);
	int (*add_links)(struct fwnode_handle___8 *);
};

struct wakeup_source___8;

struct dev_pm_info___8 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___8 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___8 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___8;

struct bus_type___8;

struct device_driver___8;

struct dev_pm_domain___8;

struct device_node___3;

struct class___8;

struct device___8 {
	struct kobject___9 kobj;
	struct device___8 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___8 *type;
	struct bus_type___8 *bus;
	struct device_driver___8 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___8 power;
	struct dev_pm_domain___8 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___3 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___3 *of_node;
	struct fwnode_handle___8 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___8 *class;
	const struct attribute_group___9 **groups;
	void (*release)(struct device___8 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___8 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___8 *local_fwnode;
};

struct fwnode_reference_args___8 {
	struct fwnode_handle___8 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___3 {
	char *name;
	int length;
	void *value;
	struct property___3 *next;
	long unsigned int _flags;
	struct bin_attribute___9 attr;
};

struct device_node___3 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___8 fwnode;
	struct property___3 *properties;
	struct property___3 *deadprops;
	struct device_node___3 *parent;
	struct device_node___3 *child;
	struct device_node___3 *sibling;
	struct kobject___9 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___2 {
	struct fwnode_handle___8 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___2 {
	int (*match)(struct irq_domain___3 *, struct device_node___3 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___3 *, struct irq_fwspec___2 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___3 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___3 *, unsigned int);
	int (*xlate)(struct irq_domain___3 *, struct device_node___3 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___3 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___3 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___3 *, struct irq_data___2 *, bool);
	void (*deactivate)(struct irq_domain___3 *, struct irq_data___2 *);
	int (*translate)(struct irq_domain___3 *, struct irq_fwspec___2 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___2;

struct irq_domain___3 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___2 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___8 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___2 *gc;
	struct irq_domain___3 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___2 *revmap[0];
};

struct irq_chip_generic___2;

struct irq_domain_chip_generic___2 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___2 *gc[0];
};

struct dev_pm_ops___8 {
	int (*prepare)(struct device___8 *);
	void (*complete)(struct device___8 *);
	int (*suspend)(struct device___8 *);
	int (*resume)(struct device___8 *);
	int (*freeze)(struct device___8 *);
	int (*thaw)(struct device___8 *);
	int (*poweroff)(struct device___8 *);
	int (*restore)(struct device___8 *);
	int (*suspend_late)(struct device___8 *);
	int (*resume_early)(struct device___8 *);
	int (*freeze_late)(struct device___8 *);
	int (*thaw_early)(struct device___8 *);
	int (*poweroff_late)(struct device___8 *);
	int (*restore_early)(struct device___8 *);
	int (*suspend_noirq)(struct device___8 *);
	int (*resume_noirq)(struct device___8 *);
	int (*freeze_noirq)(struct device___8 *);
	int (*thaw_noirq)(struct device___8 *);
	int (*poweroff_noirq)(struct device___8 *);
	int (*restore_noirq)(struct device___8 *);
	int (*runtime_suspend)(struct device___8 *);
	int (*runtime_resume)(struct device___8 *);
	int (*runtime_idle)(struct device___8 *);
};

struct wakeup_source___8 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___8 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___8 {
	struct dev_pm_ops___8 ops;
	int (*start)(struct device___8 *);
	void (*detach)(struct device___8 *, bool);
	int (*activate)(struct device___8 *);
	void (*sync)(struct device___8 *);
	void (*dismiss)(struct device___8 *);
};

struct bus_type___8 {
	const char *name;
	const char *dev_name;
	struct device___8 *dev_root;
	const struct attribute_group___9 **bus_groups;
	const struct attribute_group___9 **dev_groups;
	const struct attribute_group___9 **drv_groups;
	int (*match)(struct device___8 *, struct device_driver___8 *);
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	int (*probe)(struct device___8 *);
	void (*sync_state)(struct device___8 *);
	void (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*online)(struct device___8 *);
	int (*offline)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	int (*num_vf)(struct device___8 *);
	int (*dma_configure)(struct device___8 *);
	const struct dev_pm_ops___8 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___8 {
	const char *name;
	struct bus_type___8 *bus;
	struct module___11 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___8 *);
	void (*sync_state)(struct device___8 *);
	int (*remove)(struct device___8 *);
	void (*shutdown)(struct device___8 *);
	int (*suspend)(struct device___8 *, pm_message_t);
	int (*resume)(struct device___8 *);
	const struct attribute_group___9 **groups;
	const struct attribute_group___9 **dev_groups;
	const struct dev_pm_ops___8 *pm;
	void (*coredump)(struct device___8 *);
	struct driver_private *p;
};

struct device_type___8 {
	const char *name;
	const struct attribute_group___9 **groups;
	int (*uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___8 *);
	const struct dev_pm_ops___8 *pm;
};

struct class___8 {
	const char *name;
	struct module___11 *owner;
	const struct attribute_group___9 **class_groups;
	const struct attribute_group___9 **dev_groups;
	struct kobject___9 *dev_kobj;
	int (*dev_uevent)(struct device___8 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___8 *, umode_t *);
	void (*class_release)(struct class___8 *);
	void (*dev_release)(struct device___8 *);
	int (*shutdown_pre)(struct device___8 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___8 *);
	void (*get_ownership)(struct device___8 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___8 *pm;
	struct subsys_private *p;
};

struct dentry_operations___9;

struct dentry___10 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___10 *d_parent;
	struct qstr d_name;
	struct inode___11 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___9 *d_op;
	struct super_block___10 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___9;

struct cdev___4;

struct inode___11 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___9 *i_op;
	struct super_block___10 *i_sb;
	struct address_space___9 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___9 *i_fop;
		void (*free_inode)(struct inode___11 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___9 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___4 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___9 {
	int (*d_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___10 *, unsigned int);
	int (*d_hash)(const struct dentry___10 *, struct qstr *);
	int (*d_compare)(const struct dentry___10 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___10 *);
	int (*d_init)(struct dentry___10 *);
	void (*d_release)(struct dentry___10 *);
	void (*d_prune)(struct dentry___10 *);
	void (*d_iput)(struct dentry___10 *, struct inode___11 *);
	char * (*d_dname)(struct dentry___10 *, char *, int);
	struct vfsmount___9 * (*d_automount)(struct path___9 *);
	int (*d_manage)(const struct path___9 *, bool);
	struct dentry___10 * (*d_real)(struct dentry___10 *, const struct inode___11 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___9;

struct mem_dqinfo___9 {
	struct quota_format_type___9 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___9;

struct quota_info___9 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___11 *files[3];
	struct mem_dqinfo___9 info[3];
	const struct quota_format_ops___9 *ops[3];
};

struct rcuwait___9 {
	struct task_struct___11 *task;
};

struct percpu_rw_semaphore___9 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___9 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___9 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___9 rw_sem[3];
};

struct super_operations___9;

struct dquot_operations___9;

struct quotactl_ops___9;

struct super_block___10 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___9 *s_type;
	const struct super_operations___9 *s_op;
	const struct dquot_operations___9 *dq_op;
	const struct quotactl_ops___9 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___10 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___9 s_dquot;
	struct sb_writers___9 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___9 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___9 {
	struct dentry___10 *mnt_root;
	struct super_block___10 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___9 {
	struct file___10 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___9 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___10 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___10 *ia_file;
};

struct dquot___9 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___10 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___9 {
	int qf_fmt_id;
	const struct quota_format_ops___9 *qf_ops;
	struct module___11 *qf_owner;
	struct quota_format_type___9 *qf_next;
};

struct quota_format_ops___9 {
	int (*check_quota_file)(struct super_block___10 *, int);
	int (*read_file_info)(struct super_block___10 *, int);
	int (*write_file_info)(struct super_block___10 *, int);
	int (*free_file_info)(struct super_block___10 *, int);
	int (*read_dqblk)(struct dquot___9 *);
	int (*commit_dqblk)(struct dquot___9 *);
	int (*release_dqblk)(struct dquot___9 *);
	int (*get_next_id)(struct super_block___10 *, struct kqid *);
};

struct dquot_operations___9 {
	int (*write_dquot)(struct dquot___9 *);
	struct dquot___9 * (*alloc_dquot)(struct super_block___10 *, int);
	void (*destroy_dquot)(struct dquot___9 *);
	int (*acquire_dquot)(struct dquot___9 *);
	int (*release_dquot)(struct dquot___9 *);
	int (*mark_dirty)(struct dquot___9 *);
	int (*write_info)(struct super_block___10 *, int);
	qsize_t * (*get_reserved_space)(struct inode___11 *);
	int (*get_projid)(struct inode___11 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___11 *, qsize_t *);
	int (*get_next_id)(struct super_block___10 *, struct kqid *);
};

struct quotactl_ops___9 {
	int (*quota_on)(struct super_block___10 *, int, int, const struct path___9 *);
	int (*quota_off)(struct super_block___10 *, int);
	int (*quota_enable)(struct super_block___10 *, unsigned int);
	int (*quota_disable)(struct super_block___10 *, unsigned int);
	int (*quota_sync)(struct super_block___10 *, int);
	int (*set_info)(struct super_block___10 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___10 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___10 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___10 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___10 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___10 *, unsigned int);
};

struct address_space_operations___9 {
	int (*writepage)(struct page___10 *, struct writeback_control___3 *);
	int (*readpage)(struct file___10 *, struct page___10 *);
	int (*writepages)(struct address_space___9 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___10 *);
	int (*readpages)(struct file___10 *, struct address_space___9 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___10 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___10 **, void **);
	int (*write_end)(struct file___10 *, struct address_space___9 *, loff_t, unsigned int, unsigned int, struct page___10 *, void *);
	sector_t (*bmap)(struct address_space___9 *, sector_t);
	void (*invalidatepage)(struct page___10 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___10 *, gfp_t);
	void (*freepage)(struct page___10 *);
	ssize_t (*direct_IO)(struct kiocb___9 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___9 *, struct page___10 *, struct page___10 *, enum migrate_mode);
	bool (*isolate_page)(struct page___10 *, isolate_mode_t);
	void (*putback_page)(struct page___10 *);
	int (*launder_page)(struct page___10 *);
	int (*is_partially_uptodate)(struct page___10 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___10 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___9 *, struct page___10 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___10 *, sector_t *);
	void (*swap_deactivate)(struct file___10 *);
};

struct cdev___4 {
	struct kobject___9 kobj;
	struct module___11 *owner;
	const struct file_operations___9 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___9 {
	struct dentry___10 * (*lookup)(struct inode___11 *, struct dentry___10 *, unsigned int);
	const char * (*get_link)(struct dentry___10 *, struct inode___11 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___11 *, int);
	struct posix_acl * (*get_acl)(struct inode___11 *, int, bool);
	int (*readlink)(struct dentry___10 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___11 *, struct dentry___10 *, umode_t, bool);
	int (*link)(struct dentry___10 *, struct inode___11 *, struct dentry___10 *);
	int (*unlink)(struct inode___11 *, struct dentry___10 *);
	int (*symlink)(struct user_namespace *, struct inode___11 *, struct dentry___10 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___11 *, struct dentry___10 *, umode_t);
	int (*rmdir)(struct inode___11 *, struct dentry___10 *);
	int (*mknod)(struct user_namespace *, struct inode___11 *, struct dentry___10 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___11 *, struct dentry___10 *, struct inode___11 *, struct dentry___10 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___10 *, struct iattr___10 *);
	int (*getattr)(struct user_namespace *, const struct path___9 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___10 *, char *, size_t);
	int (*fiemap)(struct inode___11 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___11 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___11 *, struct dentry___10 *, struct file___10 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___11 *, struct dentry___10 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___11 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___10 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___10 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___9 {
	void (*fl_copy_lock)(struct file_lock___9 *, struct file_lock___9 *);
	void (*fl_release_private)(struct file_lock___9 *);
};

struct fasync_struct___9;

struct lock_manager_operations___9;

struct file_lock___9 {
	struct file_lock___9 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___10 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___9 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___9 *fl_ops;
	const struct lock_manager_operations___9 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___9 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___9 *);
	int (*lm_grant)(struct file_lock___9 *, int);
	bool (*lm_break)(struct file_lock___9 *);
	int (*lm_change)(struct file_lock___9 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___9 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___9 *);
};

struct fasync_struct___9 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___9 *fa_next;
	struct file___10 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___9 {
	struct inode___11 * (*alloc_inode)(struct super_block___10 *);
	void (*destroy_inode)(struct inode___11 *);
	void (*free_inode)(struct inode___11 *);
	void (*dirty_inode)(struct inode___11 *, int);
	int (*write_inode)(struct inode___11 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___11 *);
	void (*evict_inode)(struct inode___11 *);
	void (*put_super)(struct super_block___10 *);
	int (*sync_fs)(struct super_block___10 *, int);
	int (*freeze_super)(struct super_block___10 *);
	int (*freeze_fs)(struct super_block___10 *);
	int (*thaw_super)(struct super_block___10 *);
	int (*unfreeze_fs)(struct super_block___10 *);
	int (*statfs)(struct dentry___10 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___10 *, int *, char *);
	void (*umount_begin)(struct super_block___10 *);
	int (*show_options)(struct seq_file___12 *, struct dentry___10 *);
	int (*show_devname)(struct seq_file___12 *, struct dentry___10 *);
	int (*show_path)(struct seq_file___12 *, struct dentry___10 *);
	int (*show_stats)(struct seq_file___12 *, struct dentry___10 *);
	ssize_t (*quota_read)(struct super_block___10 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___10 *, int, const char *, size_t, loff_t);
	struct dquot___9 ** (*get_dquots)(struct inode___11 *);
	long int (*nr_cached_objects)(struct super_block___10 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___10 *, struct shrink_control___3 *);
	struct file___10 * (*real_loop)(struct file___10 *);
};

struct kernel_param_ops___9 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___9 *);
	int (*get)(char *, const struct kernel_param___9 *);
	void (*free)(void *);
};

struct kparam_array___9;

struct kernel_param___9 {
	const char *name;
	struct module___11 *mod;
	const struct kernel_param_ops___9 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___9 *arr;
	};
};

struct kparam_array___9 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___9 *ops;
	void *elem;
};

struct module_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___9 *, struct module_kobject___9 *, char *);
	ssize_t (*store)(struct module_attribute___9 *, struct module_kobject___9 *, const char *, size_t);
	void (*setup)(struct module___11 *, const char *);
	int (*test)(struct module___11 *);
	void (*free)(struct module___11 *);
};

struct irq_chip___2 {
	struct device___8 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___2 *);
	void (*irq_shutdown)(struct irq_data___2 *);
	void (*irq_enable)(struct irq_data___2 *);
	void (*irq_disable)(struct irq_data___2 *);
	void (*irq_ack)(struct irq_data___2 *);
	void (*irq_mask)(struct irq_data___2 *);
	void (*irq_mask_ack)(struct irq_data___2 *);
	void (*irq_unmask)(struct irq_data___2 *);
	void (*irq_eoi)(struct irq_data___2 *);
	int (*irq_set_affinity)(struct irq_data___2 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___2 *);
	int (*irq_set_type)(struct irq_data___2 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___2 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___2 *);
	void (*irq_bus_sync_unlock)(struct irq_data___2 *);
	void (*irq_cpu_online)(struct irq_data___2 *);
	void (*irq_cpu_offline)(struct irq_data___2 *);
	void (*irq_suspend)(struct irq_data___2 *);
	void (*irq_resume)(struct irq_data___2 *);
	void (*irq_pm_shutdown)(struct irq_data___2 *);
	void (*irq_calc_mask)(struct irq_data___2 *);
	void (*irq_print_chip)(struct irq_data___2 *, struct seq_file___12 *);
	int (*irq_request_resources)(struct irq_data___2 *);
	void (*irq_release_resources)(struct irq_data___2 *);
	void (*irq_compose_msi_msg)(struct irq_data___2 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___2 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___2 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___2 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___2 *, void *);
	void (*ipi_send_single)(struct irq_data___2 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___2 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___2 *);
	void (*irq_nmi_teardown)(struct irq_data___2 *);
	long unsigned int flags;
};

struct irqaction___2 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___2 *next;
	irq_handler_t thread_fn;
	struct task_struct___11 *thread;
	struct irqaction___2 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___2 {
	struct irq_chip___2 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___2 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___2 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___2 *);
	void (*resume)(struct irq_chip_generic___2 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___3 *domain;
	struct list_head list;
	struct irq_chip_type___2 chip_types[0];
};

struct seq_operations___10 {
	void * (*start)(struct seq_file___12 *, loff_t *);
	void (*stop)(struct seq_file___12 *, void *);
	void * (*next)(struct seq_file___12 *, void *, loff_t *);
	int (*show)(struct seq_file___12 *, void *);
};

struct dev_pagemap_ops___9 {
	void (*page_free)(struct page___10 *);
	void (*kill)(struct dev_pagemap___9 *);
	void (*cleanup)(struct dev_pagemap___9 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___9 *);
};

enum memblock_flags {
	MEMBLOCK_NONE = 0,
	MEMBLOCK_HOTPLUG = 1,
	MEMBLOCK_MIRROR = 2,
	MEMBLOCK_NOMAP = 4,
};

struct memblock_region {
	phys_addr_t base;
	phys_addr_t size;
	enum memblock_flags flags;
	int nid;
};

struct memblock_type {
	long unsigned int cnt;
	long unsigned int max;
	phys_addr_t total_size;
	struct memblock_region *regions;
	char *name;
};

struct memblock {
	bool bottom_up;
	phys_addr_t current_limit;
	struct memblock_type memory;
	struct memblock_type reserved;
};

struct mpidr_hash {
	u64 mask;
	u32 shift_aff[4];
	u32 bits;
};

struct cpu {
	int node_id;
	int hotpluggable;
	struct device___8 dev;
};

struct cpuinfo_32bit {
	u32 reg_id_dfr0;
	u32 reg_id_dfr1;
	u32 reg_id_isar0;
	u32 reg_id_isar1;
	u32 reg_id_isar2;
	u32 reg_id_isar3;
	u32 reg_id_isar4;
	u32 reg_id_isar5;
	u32 reg_id_isar6;
	u32 reg_id_mmfr0;
	u32 reg_id_mmfr1;
	u32 reg_id_mmfr2;
	u32 reg_id_mmfr3;
	u32 reg_id_mmfr4;
	u32 reg_id_mmfr5;
	u32 reg_id_pfr0;
	u32 reg_id_pfr1;
	u32 reg_id_pfr2;
	u32 reg_mvfr0;
	u32 reg_mvfr1;
	u32 reg_mvfr2;
};

struct cpuinfo_arm64 {
	struct cpu cpu;
	struct kobject___9 kobj;
	u64 reg_ctr;
	u64 reg_cntfrq;
	u64 reg_dczid;
	u64 reg_midr;
	u64 reg_revidr;
	u64 reg_gmid;
	u64 reg_id_aa64dfr0;
	u64 reg_id_aa64dfr1;
	u64 reg_id_aa64isar0;
	u64 reg_id_aa64isar1;
	u64 reg_id_aa64isar2;
	u64 reg_id_aa64mmfr0;
	u64 reg_id_aa64mmfr1;
	u64 reg_id_aa64mmfr2;
	u64 reg_id_aa64pfr0;
	u64 reg_id_aa64pfr1;
	u64 reg_id_aa64zfr0;
	struct cpuinfo_32bit aarch32;
	u64 reg_zcr;
};

struct cpu_operations {
	const char *name;
	int (*cpu_init)(unsigned int);
	int (*cpu_prepare)(unsigned int);
	int (*cpu_boot)(unsigned int);
	void (*cpu_postboot)();
	bool (*cpu_can_disable)(unsigned int);
	int (*cpu_disable)(unsigned int);
	void (*cpu_die)(unsigned int);
	int (*cpu_kill)(unsigned int);
	int (*cpu_init_idle)(unsigned int);
	int (*cpu_suspend)(long unsigned int);
};

struct sigcontext {
	__u64 fault_address;
	__u64 regs[31];
	__u64 sp;
	__u64 pc;
	__u64 pstate;
	long: 64;
	__u8 __reserved[4096];
};

struct _aarch64_ctx {
	__u32 magic;
	__u32 size;
};

struct fpsimd_context {
	struct _aarch64_ctx head;
	__u32 fpsr;
	__u32 fpcr;
	__int128 unsigned vregs[32];
};

struct esr_context {
	struct _aarch64_ctx head;
	__u64 esr;
};

struct extra_context {
	struct _aarch64_ctx head;
	__u64 datap;
	__u32 size;
	__u32 __reserved[3];
};

struct sve_context {
	struct _aarch64_ctx head;
	__u16 vl;
	__u16 __reserved[3];
};

struct sigaltstack {
	void *ss_sp;
	int ss_flags;
	size_t ss_size;
};

typedef struct sigaltstack stack_t;

struct siginfo {
	union {
		struct {
			int si_signo;
			int si_errno;
			int si_code;
			union __sifields _sifields;
		};
		int _si_pad[32];
	};
};

typedef struct siginfo siginfo_t;

struct ksignal {
	struct k_sigaction ka;
	kernel_siginfo_t info;
	int sig;
};

enum {
	EI_ETYPE_NONE = 0,
	EI_ETYPE_NULL = 1,
	EI_ETYPE_ERRNO = 2,
	EI_ETYPE_ERRNO_NULL = 3,
	EI_ETYPE_TRUE = 4,
};

struct syscall_metadata {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___6 *enter_event;
	struct trace_event_call___6 *exit_event;
};

struct ucontext {
	long unsigned int uc_flags;
	struct ucontext *uc_link;
	stack_t uc_stack;
	sigset_t uc_sigmask;
	__u8 __unused[120];
	long: 64;
	struct sigcontext uc_mcontext;
};

struct rt_sigframe {
	struct siginfo info;
	struct ucontext uc;
};

struct frame_record {
	u64 fp;
	u64 lr;
};

struct rt_sigframe_user_layout {
	struct rt_sigframe *sigframe;
	struct frame_record *next_frame;
	long unsigned int size;
	long unsigned int limit;
	long unsigned int fpsimd_offset;
	long unsigned int esr_offset;
	long unsigned int sve_offset;
	long unsigned int extra_offset;
	long unsigned int end_offset;
};

struct user_ctxs {
	struct fpsimd_context *fpsimd;
	struct sve_context *sve;
};

enum {
	PER_LINUX = 0,
	PER_LINUX_32BIT = 8388608,
	PER_LINUX_FDPIC = 524288,
	PER_SVR4 = 68157441,
	PER_SVR3 = 83886082,
	PER_SCOSVR3 = 117440515,
	PER_OSR5 = 100663299,
	PER_WYSEV386 = 83886084,
	PER_ISCR4 = 67108869,
	PER_BSD = 6,
	PER_SUNOS = 67108870,
	PER_XENIX = 83886087,
	PER_LINUX32 = 8,
	PER_LINUX32_3GB = 134217736,
	PER_IRIX32 = 67108873,
	PER_IRIXN32 = 67108874,
	PER_IRIX64 = 67108875,
	PER_RISCOS = 12,
	PER_SOLARIS = 67108877,
	PER_UW7 = 68157454,
	PER_OSF4 = 15,
	PER_HPUX = 16,
	PER_MASK = 255,
};

typedef long int (*syscall_fn_t)(const struct pt_regs *);

struct dentry___11;

struct super_block___11;

struct module___12;

struct file_system_type___10 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___11 * (*mount)(struct file_system_type___10 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___11 *);
	struct module___12 *owner;
	struct file_system_type___10 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___11;

struct kiocb___10;

struct vm_area_struct___10;

struct inode___12;

struct file_lock___10;

struct page___11;

struct file_operations___10 {
	struct module___12 *owner;
	loff_t (*llseek)(struct file___11 *, loff_t, int);
	ssize_t (*read)(struct file___11 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___11 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___10 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___10 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___10 *, bool);
	int (*iterate)(struct file___11 *, struct dir_context *);
	int (*iterate_shared)(struct file___11 *, struct dir_context *);
	__poll_t (*poll)(struct file___11 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___11 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___11 *, struct vm_area_struct___10 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___12 *, struct file___11 *);
	int (*flush)(struct file___11 *, fl_owner_t);
	int (*release)(struct inode___12 *, struct file___11 *);
	int (*fsync)(struct file___11 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___11 *, int);
	int (*lock)(struct file___11 *, int, struct file_lock___10 *);
	ssize_t (*sendpage)(struct file___11 *, struct page___11 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___11 *, long unsigned int);
	int (*flock)(struct file___11 *, int, struct file_lock___10 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___11 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___11 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___11 *, long int, struct file_lock___10 **, void **);
	long int (*fallocate)(struct file___11 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___11 *);
	ssize_t (*copy_file_range)(struct file___11 *, loff_t, struct file___11 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___11 *, loff_t, struct file___11 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___11 *, loff_t, loff_t, int);
};

struct vmacache___10 {
	u64 seqnum;
	struct vm_area_struct___10 *vmas[4];
};

struct page_frag___10 {
	struct page___11 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___11;

struct pid___10;

struct nsproxy___11;

struct signal_struct___11;

struct vm_struct___10;

struct task_struct___12 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___12 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___11 *mm;
	struct mm_struct___11 *active_mm;
	struct vmacache___10 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___12 *real_parent;
	struct task_struct___12 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___12 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___10 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___11 *nsproxy;
	struct signal_struct___11 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___12 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___10 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___12 *oom_reaper_list;
	struct vm_struct___10 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___6 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___10;

struct kobj_type___10;

struct kernfs_node___10;

struct kobject___10 {
	const char *name;
	struct list_head entry;
	struct kobject___10 *parent;
	struct kset___10 *kset;
	struct kobj_type___10 *ktype;
	struct kernfs_node___10 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___10 {
	struct kobject___10 kobj;
	struct module___12 *mod;
	struct kobject___10 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___10 {
	struct module___12 *mod;
	struct latch_tree_node node;
};

struct module_layout___10 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___10 mtn;
};

struct module_attribute___10;

struct kernel_param___10;

struct module___12 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___10 mkobj;
	struct module_attribute___10 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___10 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___10 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___10 core_layout;
	struct module_layout___10 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___10;

struct upid___10 {
	int nr;
	struct pid_namespace___10 *ns;
};

struct pid_namespace___10 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___12 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___10 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___10 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___10 numbers[1];
};

typedef struct page___11 *pgtable_t___10;

struct address_space___10;

struct dev_pagemap___10;

struct page___11 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___10 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___11 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___10 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___11 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___10 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___10;

struct vm_area_struct___10 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___10 *vm_next;
	struct vm_area_struct___10 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___11 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___10 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___11 *vm_file;
	struct file___11 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___11 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___12 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___12 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___10 *pids[4];
	struct pid___10 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___11 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___10;

struct mm_struct___11 {
	struct {
		struct vm_area_struct___10 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___11 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___10 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___12 *owner;
		struct user_namespace *user_ns;
		struct file___11 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___11 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___10 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___10 {
	struct vm_struct___10 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___11 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___10;

struct address_space___10 {
	struct inode___12 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___10 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___10;

struct dev_pagemap___10 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___10 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___10;

struct path___10 {
	struct vfsmount___10 *mnt;
	struct dentry___11 *dentry;
};

struct fown_struct___10 {
	rwlock_t lock;
	struct pid___10 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___11 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___10 f_path;
	struct inode___12 *f_inode;
	const struct file_operations___10 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___10 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___10 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___10;

struct vm_operations_struct___10 {
	void (*open)(struct vm_area_struct___10 *);
	void (*close)(struct vm_area_struct___10 *);
	int (*may_split)(struct vm_area_struct___10 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___10 *);
	int (*mprotect)(struct vm_area_struct___10 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___10 *);
	vm_fault_t (*huge_fault)(struct vm_fault___10 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___10 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___10 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___10 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___10 *);
	int (*access)(struct vm_area_struct___10 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___10 *);
	int (*set_policy)(struct vm_area_struct___10 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___10 *, long unsigned int);
	struct page___11 * (*find_special_page)(struct vm_area_struct___10 *, long unsigned int);
};

struct core_thread___10 {
	struct task_struct___12 *task;
	struct core_thread___10 *next;
};

struct core_state___10 {
	atomic_t nr_threads;
	struct core_thread___10 dumper;
	struct completion startup;
};

struct vm_fault___10 {
	const struct {
		struct vm_area_struct___10 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___11 *cow_page;
	struct page___11 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___10 prealloc_pte;
};

struct kernfs_root___10;

struct kernfs_elem_dir___10 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___10 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___10;

struct kernfs_root___10 {
	struct kernfs_node___10 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___10 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___10 {
	struct kernfs_node___10 *target_kn;
};

struct kernfs_ops___10;

struct kernfs_elem_attr___10 {
	const struct kernfs_ops___10 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___10 *notify_next;
};

struct kernfs_node___10 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___10 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___10 dir;
		struct kernfs_elem_symlink___10 symlink;
		struct kernfs_elem_attr___10 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___10;

struct kernfs_ops___10 {
	int (*open)(struct kernfs_open_file___10 *);
	void (*release)(struct kernfs_open_file___10 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___10 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___10 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___10 *, struct vm_area_struct___10 *);
};

struct kernfs_syscall_ops___10 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___10 *);
	int (*mkdir)(struct kernfs_node___10 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___10 *);
	int (*rename)(struct kernfs_node___10 *, struct kernfs_node___10 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___10 *, struct kernfs_root___10 *);
};

struct kernfs_open_file___10 {
	struct kernfs_node___10 *kn;
	struct file___11 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___10 *vm_ops;
};

struct bin_attribute___10;

struct attribute_group___10 {
	const char *name;
	umode_t (*is_visible)(struct kobject___10 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___10 *, struct bin_attribute___10 *, int);
	struct attribute **attrs;
	struct bin_attribute___10 **bin_attrs;
};

struct bin_attribute___10 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___10 * (*f_mapping)();
	ssize_t (*read)(struct file___11 *, struct kobject___10 *, struct bin_attribute___10 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___11 *, struct kobject___10 *, struct bin_attribute___10 *, char *, loff_t, size_t);
	int (*mmap)(struct file___11 *, struct kobject___10 *, struct bin_attribute___10 *, struct vm_area_struct___10 *);
};

struct sysfs_ops___10 {
	ssize_t (*show)(struct kobject___10 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___10 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___10;

struct kset___10 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___10 kobj;
	const struct kset_uevent_ops___10 *uevent_ops;
};

struct kobj_type___10 {
	void (*release)(struct kobject___10 *);
	const struct sysfs_ops___10 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___10 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___10 *);
	const void * (*namespace)(struct kobject___10 *);
	void (*get_ownership)(struct kobject___10 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___10 {
	int (* const filter)(struct kset___10 *, struct kobject___10 *);
	const char * (* const name)(struct kset___10 *, struct kobject___10 *);
	int (* const uevent)(struct kset___10 *, struct kobject___10 *, struct kobj_uevent_env *);
};

typedef bool (*stack_trace_consume_fn)(void *, long unsigned int);

struct dev_pagemap_ops___10 {
	void (*page_free)(struct page___11 *);
	void (*kill)(struct dev_pagemap___10 *);
	void (*cleanup)(struct dev_pagemap___10 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___10 *);
};

struct dentry_operations___10;

struct dentry___11 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___11 *d_parent;
	struct qstr d_name;
	struct inode___12 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___10 *d_op;
	struct super_block___11 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___10;

struct inode___12 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___10 *i_op;
	struct super_block___11 *i_sb;
	struct address_space___10 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___10 *i_fop;
		void (*free_inode)(struct inode___12 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___10 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___4 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___10 {
	int (*d_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___11 *, unsigned int);
	int (*d_hash)(const struct dentry___11 *, struct qstr *);
	int (*d_compare)(const struct dentry___11 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___11 *);
	int (*d_init)(struct dentry___11 *);
	void (*d_release)(struct dentry___11 *);
	void (*d_prune)(struct dentry___11 *);
	void (*d_iput)(struct dentry___11 *, struct inode___12 *);
	char * (*d_dname)(struct dentry___11 *, char *, int);
	struct vfsmount___10 * (*d_automount)(struct path___10 *);
	int (*d_manage)(const struct path___10 *, bool);
	struct dentry___11 * (*d_real)(struct dentry___11 *, const struct inode___12 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___10;

struct mem_dqinfo___10 {
	struct quota_format_type___10 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___10;

struct quota_info___10 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___12 *files[3];
	struct mem_dqinfo___10 info[3];
	const struct quota_format_ops___10 *ops[3];
};

struct rcuwait___10 {
	struct task_struct___12 *task;
};

struct percpu_rw_semaphore___10 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___10 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___10 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___10 rw_sem[3];
};

struct super_operations___10;

struct dquot_operations___10;

struct quotactl_ops___10;

struct super_block___11 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___10 *s_type;
	const struct super_operations___10 *s_op;
	const struct dquot_operations___10 *dq_op;
	const struct quotactl_ops___10 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___11 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___10 s_dquot;
	struct sb_writers___10 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___10 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___10 {
	struct dentry___11 *mnt_root;
	struct super_block___11 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___10 {
	struct file___11 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___10 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___11 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___11 *ia_file;
};

struct dquot___10 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___11 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___10 {
	int qf_fmt_id;
	const struct quota_format_ops___10 *qf_ops;
	struct module___12 *qf_owner;
	struct quota_format_type___10 *qf_next;
};

struct quota_format_ops___10 {
	int (*check_quota_file)(struct super_block___11 *, int);
	int (*read_file_info)(struct super_block___11 *, int);
	int (*write_file_info)(struct super_block___11 *, int);
	int (*free_file_info)(struct super_block___11 *, int);
	int (*read_dqblk)(struct dquot___10 *);
	int (*commit_dqblk)(struct dquot___10 *);
	int (*release_dqblk)(struct dquot___10 *);
	int (*get_next_id)(struct super_block___11 *, struct kqid *);
};

struct dquot_operations___10 {
	int (*write_dquot)(struct dquot___10 *);
	struct dquot___10 * (*alloc_dquot)(struct super_block___11 *, int);
	void (*destroy_dquot)(struct dquot___10 *);
	int (*acquire_dquot)(struct dquot___10 *);
	int (*release_dquot)(struct dquot___10 *);
	int (*mark_dirty)(struct dquot___10 *);
	int (*write_info)(struct super_block___11 *, int);
	qsize_t * (*get_reserved_space)(struct inode___12 *);
	int (*get_projid)(struct inode___12 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___12 *, qsize_t *);
	int (*get_next_id)(struct super_block___11 *, struct kqid *);
};

struct quotactl_ops___10 {
	int (*quota_on)(struct super_block___11 *, int, int, const struct path___10 *);
	int (*quota_off)(struct super_block___11 *, int);
	int (*quota_enable)(struct super_block___11 *, unsigned int);
	int (*quota_disable)(struct super_block___11 *, unsigned int);
	int (*quota_sync)(struct super_block___11 *, int);
	int (*set_info)(struct super_block___11 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___11 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___11 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___11 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___11 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___11 *, unsigned int);
};

struct address_space_operations___10 {
	int (*writepage)(struct page___11 *, struct writeback_control___3 *);
	int (*readpage)(struct file___11 *, struct page___11 *);
	int (*writepages)(struct address_space___10 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___11 *);
	int (*readpages)(struct file___11 *, struct address_space___10 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___11 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___11 **, void **);
	int (*write_end)(struct file___11 *, struct address_space___10 *, loff_t, unsigned int, unsigned int, struct page___11 *, void *);
	sector_t (*bmap)(struct address_space___10 *, sector_t);
	void (*invalidatepage)(struct page___11 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___11 *, gfp_t);
	void (*freepage)(struct page___11 *);
	ssize_t (*direct_IO)(struct kiocb___10 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___10 *, struct page___11 *, struct page___11 *, enum migrate_mode);
	bool (*isolate_page)(struct page___11 *, isolate_mode_t);
	void (*putback_page)(struct page___11 *);
	int (*launder_page)(struct page___11 *);
	int (*is_partially_uptodate)(struct page___11 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___11 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___10 *, struct page___11 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___11 *, sector_t *);
	void (*swap_deactivate)(struct file___11 *);
};

struct inode_operations___10 {
	struct dentry___11 * (*lookup)(struct inode___12 *, struct dentry___11 *, unsigned int);
	const char * (*get_link)(struct dentry___11 *, struct inode___12 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___12 *, int);
	struct posix_acl * (*get_acl)(struct inode___12 *, int, bool);
	int (*readlink)(struct dentry___11 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___12 *, struct dentry___11 *, umode_t, bool);
	int (*link)(struct dentry___11 *, struct inode___12 *, struct dentry___11 *);
	int (*unlink)(struct inode___12 *, struct dentry___11 *);
	int (*symlink)(struct user_namespace *, struct inode___12 *, struct dentry___11 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___12 *, struct dentry___11 *, umode_t);
	int (*rmdir)(struct inode___12 *, struct dentry___11 *);
	int (*mknod)(struct user_namespace *, struct inode___12 *, struct dentry___11 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___12 *, struct dentry___11 *, struct inode___12 *, struct dentry___11 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___11 *, struct iattr___11 *);
	int (*getattr)(struct user_namespace *, const struct path___10 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___11 *, char *, size_t);
	int (*fiemap)(struct inode___12 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___12 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___12 *, struct dentry___11 *, struct file___11 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___12 *, struct dentry___11 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___12 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___11 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___11 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___10 {
	void (*fl_copy_lock)(struct file_lock___10 *, struct file_lock___10 *);
	void (*fl_release_private)(struct file_lock___10 *);
};

struct fasync_struct___10;

struct lock_manager_operations___10;

struct file_lock___10 {
	struct file_lock___10 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___11 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___10 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___10 *fl_ops;
	const struct lock_manager_operations___10 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___10 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___10 *);
	int (*lm_grant)(struct file_lock___10 *, int);
	bool (*lm_break)(struct file_lock___10 *);
	int (*lm_change)(struct file_lock___10 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___10 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___10 *);
};

struct fasync_struct___10 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___10 *fa_next;
	struct file___11 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___10 {
	struct inode___12 * (*alloc_inode)(struct super_block___11 *);
	void (*destroy_inode)(struct inode___12 *);
	void (*free_inode)(struct inode___12 *);
	void (*dirty_inode)(struct inode___12 *, int);
	int (*write_inode)(struct inode___12 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___12 *);
	void (*evict_inode)(struct inode___12 *);
	void (*put_super)(struct super_block___11 *);
	int (*sync_fs)(struct super_block___11 *, int);
	int (*freeze_super)(struct super_block___11 *);
	int (*freeze_fs)(struct super_block___11 *);
	int (*thaw_super)(struct super_block___11 *);
	int (*unfreeze_fs)(struct super_block___11 *);
	int (*statfs)(struct dentry___11 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___11 *, int *, char *);
	void (*umount_begin)(struct super_block___11 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___11 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___11 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___11 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___11 *);
	ssize_t (*quota_read)(struct super_block___11 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___11 *, int, const char *, size_t, loff_t);
	struct dquot___10 ** (*get_dquots)(struct inode___12 *);
	long int (*nr_cached_objects)(struct super_block___11 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___11 *, struct shrink_control___3 *);
	struct file___11 * (*real_loop)(struct file___11 *);
};

struct kernel_param_ops___10 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___10 *);
	int (*get)(char *, const struct kernel_param___10 *);
	void (*free)(void *);
};

struct kparam_array___10;

struct kernel_param___10 {
	const char *name;
	struct module___12 *mod;
	const struct kernel_param_ops___10 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___10 *arr;
	};
};

struct kparam_array___10 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___10 *ops;
	void *elem;
};

struct module_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___10 *, struct module_kobject___10 *, char *);
	ssize_t (*store)(struct module_attribute___10 *, struct module_kobject___10 *, const char *, size_t);
	void (*setup)(struct module___12 *, const char *);
	int (*test)(struct module___12 *);
	void (*free)(struct module___12 *);
};

struct dentry___12;

struct super_block___12;

struct module___13;

struct file_system_type___11 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___12 * (*mount)(struct file_system_type___11 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___12 *);
	struct module___13 *owner;
	struct file_system_type___11 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___12;

struct kiocb___11;

struct poll_table_struct___8;

struct vm_area_struct___11;

struct inode___13;

struct file_lock___11;

struct page___12;

struct seq_file___13;

struct file_operations___11 {
	struct module___13 *owner;
	loff_t (*llseek)(struct file___12 *, loff_t, int);
	ssize_t (*read)(struct file___12 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___12 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___11 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___11 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___11 *, bool);
	int (*iterate)(struct file___12 *, struct dir_context *);
	int (*iterate_shared)(struct file___12 *, struct dir_context *);
	__poll_t (*poll)(struct file___12 *, struct poll_table_struct___8 *);
	long int (*unlocked_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___12 *, struct vm_area_struct___11 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___13 *, struct file___12 *);
	int (*flush)(struct file___12 *, fl_owner_t);
	int (*release)(struct inode___13 *, struct file___12 *);
	int (*fsync)(struct file___12 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___12 *, int);
	int (*lock)(struct file___12 *, int, struct file_lock___11 *);
	ssize_t (*sendpage)(struct file___12 *, struct page___12 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___12 *, long unsigned int);
	int (*flock)(struct file___12 *, int, struct file_lock___11 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___12 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___12 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___12 *, long int, struct file_lock___11 **, void **);
	long int (*fallocate)(struct file___12 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___13 *, struct file___12 *);
	ssize_t (*copy_file_range)(struct file___12 *, loff_t, struct file___12 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___12 *, loff_t, struct file___12 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___12 *, loff_t, loff_t, int);
};

struct vmacache___11 {
	u64 seqnum;
	struct vm_area_struct___11 *vmas[4];
};

struct page_frag___11 {
	struct page___12 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___12;

struct signal_struct___12;

struct vm_struct___11;

struct task_struct___13 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___13 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___12 *mm;
	struct mm_struct___12 *active_mm;
	struct vmacache___11 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___13 *real_parent;
	struct task_struct___13 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___13 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___10 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___12 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___13 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___11 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___13 *oom_reaper_list;
	struct vm_struct___11 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___6 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___11;

struct kobj_type___11;

struct kernfs_node___11;

struct kobject___11 {
	const char *name;
	struct list_head entry;
	struct kobject___11 *parent;
	struct kset___11 *kset;
	struct kobj_type___11 *ktype;
	struct kernfs_node___11 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___11 {
	struct kobject___11 kobj;
	struct module___13 *mod;
	struct kobject___11 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___11 {
	struct module___13 *mod;
	struct latch_tree_node node;
};

struct module_layout___11 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___11 mtn;
};

struct module_attribute___11;

struct kernel_param___11;

struct module___13 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___11 mkobj;
	struct module_attribute___11 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___11 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___11 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___11 core_layout;
	struct module_layout___11 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___12 *pgtable_t___11;

struct address_space___11;

struct dev_pagemap___11;

struct page___12 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___11 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___12 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___11 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___12 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___11 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___11;

struct vm_area_struct___11 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___11 *vm_next;
	struct vm_area_struct___11 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___12 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___11 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___12 *vm_file;
	struct file___12 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___11;

struct mm_struct___12 {
	struct {
		struct vm_area_struct___11 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___11 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___13 *owner;
		struct user_namespace *user_ns;
		struct file___12 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___11;

struct address_space___11 {
	struct inode___13 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___11 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___11;

struct dev_pagemap___11 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___11 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___11;

struct path___11 {
	struct vfsmount___11 *mnt;
	struct dentry___12 *dentry;
};

struct file___12 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___11 f_path;
	struct inode___13 *f_inode;
	const struct file_operations___11 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___10 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___11 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___11;

struct vm_operations_struct___11 {
	void (*open)(struct vm_area_struct___11 *);
	void (*close)(struct vm_area_struct___11 *);
	int (*may_split)(struct vm_area_struct___11 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___11 *);
	int (*mprotect)(struct vm_area_struct___11 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___11 *);
	vm_fault_t (*huge_fault)(struct vm_fault___11 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___11 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___11 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___11 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___11 *);
	int (*access)(struct vm_area_struct___11 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___11 *);
	int (*set_policy)(struct vm_area_struct___11 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___11 *, long unsigned int);
	struct page___12 * (*find_special_page)(struct vm_area_struct___11 *, long unsigned int);
};

struct core_thread___11 {
	struct task_struct___13 *task;
	struct core_thread___11 *next;
};

struct core_state___11 {
	atomic_t nr_threads;
	struct core_thread___11 dumper;
	struct completion startup;
};

struct vm_fault___11 {
	const struct {
		struct vm_area_struct___11 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___12 *cow_page;
	struct page___12 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___11 prealloc_pte;
};

struct kernfs_root___11;

struct kernfs_elem_dir___11 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___11 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___11;

struct kernfs_root___11 {
	struct kernfs_node___11 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___11 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___11 {
	struct kernfs_node___11 *target_kn;
};

struct kernfs_ops___11;

struct kernfs_elem_attr___11 {
	const struct kernfs_ops___11 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___11 *notify_next;
};

struct kernfs_node___11 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___11 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___11 dir;
		struct kernfs_elem_symlink___11 symlink;
		struct kernfs_elem_attr___11 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___11;

struct kernfs_ops___11 {
	int (*open)(struct kernfs_open_file___11 *);
	void (*release)(struct kernfs_open_file___11 *);
	int (*seq_show)(struct seq_file___13 *, void *);
	void * (*seq_start)(struct seq_file___13 *, loff_t *);
	void * (*seq_next)(struct seq_file___13 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___13 *, void *);
	ssize_t (*read)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___11 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___11 *, struct poll_table_struct___8 *);
	int (*mmap)(struct kernfs_open_file___11 *, struct vm_area_struct___11 *);
};

struct kernfs_syscall_ops___11 {
	int (*show_options)(struct seq_file___13 *, struct kernfs_root___11 *);
	int (*mkdir)(struct kernfs_node___11 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___11 *);
	int (*rename)(struct kernfs_node___11 *, struct kernfs_node___11 *, const char *);
	int (*show_path)(struct seq_file___13 *, struct kernfs_node___11 *, struct kernfs_root___11 *);
};

struct seq_operations___11;

struct seq_file___13 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___11 *op;
	int poll_event;
	const struct file___12 *file;
	void *private;
};

struct kernfs_open_file___11 {
	struct kernfs_node___11 *kn;
	struct file___12 *file;
	struct seq_file___13 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___11 *vm_ops;
};

typedef void (*poll_queue_proc___8)(struct file___12 *, wait_queue_head_t *, struct poll_table_struct___8 *);

struct poll_table_struct___8 {
	poll_queue_proc___8 _qproc;
	__poll_t _key;
};

struct signal_struct___12 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___13 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___13 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___10 *pids[4];
	struct pid___10 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___12 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct vm_struct___11 {
	struct vm_struct___11 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___12 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___11;

struct attribute_group___11 {
	const char *name;
	umode_t (*is_visible)(struct kobject___11 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___11 *, struct bin_attribute___11 *, int);
	struct attribute **attrs;
	struct bin_attribute___11 **bin_attrs;
};

struct bin_attribute___11 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___11 * (*f_mapping)();
	ssize_t (*read)(struct file___12 *, struct kobject___11 *, struct bin_attribute___11 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___12 *, struct kobject___11 *, struct bin_attribute___11 *, char *, loff_t, size_t);
	int (*mmap)(struct file___12 *, struct kobject___11 *, struct bin_attribute___11 *, struct vm_area_struct___11 *);
};

struct sysfs_ops___11 {
	ssize_t (*show)(struct kobject___11 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___11 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___11;

struct kset___11 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___11 kobj;
	const struct kset_uevent_ops___11 *uevent_ops;
};

struct kobj_type___11 {
	void (*release)(struct kobject___11 *);
	const struct sysfs_ops___11 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___11 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___11 *);
	const void * (*namespace)(struct kobject___11 *);
	void (*get_ownership)(struct kobject___11 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___11 {
	int (* const filter)(struct kset___11 *, struct kobject___11 *);
	const char * (* const name)(struct kset___11 *, struct kobject___11 *);
	int (* const uevent)(struct kset___11 *, struct kobject___11 *, struct kobj_uevent_env *);
};

struct dentry_operations___11;

struct dentry___12 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___12 *d_parent;
	struct qstr d_name;
	struct inode___13 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___11 *d_op;
	struct super_block___12 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___11;

struct cdev___5;

struct inode___13 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___11 *i_op;
	struct super_block___12 *i_sb;
	struct address_space___11 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___11 *i_fop;
		void (*free_inode)(struct inode___13 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___11 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___5 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___11 {
	int (*d_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___12 *, unsigned int);
	int (*d_hash)(const struct dentry___12 *, struct qstr *);
	int (*d_compare)(const struct dentry___12 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___12 *);
	int (*d_init)(struct dentry___12 *);
	void (*d_release)(struct dentry___12 *);
	void (*d_prune)(struct dentry___12 *);
	void (*d_iput)(struct dentry___12 *, struct inode___13 *);
	char * (*d_dname)(struct dentry___12 *, char *, int);
	struct vfsmount___11 * (*d_automount)(struct path___11 *);
	int (*d_manage)(const struct path___11 *, bool);
	struct dentry___12 * (*d_real)(struct dentry___12 *, const struct inode___13 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___11;

struct mem_dqinfo___11 {
	struct quota_format_type___11 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___11;

struct quota_info___11 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___13 *files[3];
	struct mem_dqinfo___11 info[3];
	const struct quota_format_ops___11 *ops[3];
};

struct rcuwait___11 {
	struct task_struct___13 *task;
};

struct percpu_rw_semaphore___11 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___11 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___11 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___11 rw_sem[3];
};

struct super_operations___11;

struct dquot_operations___11;

struct quotactl_ops___11;

struct super_block___12 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___11 *s_type;
	const struct super_operations___11 *s_op;
	const struct dquot_operations___11 *dq_op;
	const struct quotactl_ops___11 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___12 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___11 s_dquot;
	struct sb_writers___11 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___11 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___11 {
	struct dentry___12 *mnt_root;
	struct super_block___12 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___11 {
	struct file___12 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___11 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___12 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___12 *ia_file;
};

struct dquot___11 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___12 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___11 {
	int qf_fmt_id;
	const struct quota_format_ops___11 *qf_ops;
	struct module___13 *qf_owner;
	struct quota_format_type___11 *qf_next;
};

struct quota_format_ops___11 {
	int (*check_quota_file)(struct super_block___12 *, int);
	int (*read_file_info)(struct super_block___12 *, int);
	int (*write_file_info)(struct super_block___12 *, int);
	int (*free_file_info)(struct super_block___12 *, int);
	int (*read_dqblk)(struct dquot___11 *);
	int (*commit_dqblk)(struct dquot___11 *);
	int (*release_dqblk)(struct dquot___11 *);
	int (*get_next_id)(struct super_block___12 *, struct kqid *);
};

struct dquot_operations___11 {
	int (*write_dquot)(struct dquot___11 *);
	struct dquot___11 * (*alloc_dquot)(struct super_block___12 *, int);
	void (*destroy_dquot)(struct dquot___11 *);
	int (*acquire_dquot)(struct dquot___11 *);
	int (*release_dquot)(struct dquot___11 *);
	int (*mark_dirty)(struct dquot___11 *);
	int (*write_info)(struct super_block___12 *, int);
	qsize_t * (*get_reserved_space)(struct inode___13 *);
	int (*get_projid)(struct inode___13 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___13 *, qsize_t *);
	int (*get_next_id)(struct super_block___12 *, struct kqid *);
};

struct quotactl_ops___11 {
	int (*quota_on)(struct super_block___12 *, int, int, const struct path___11 *);
	int (*quota_off)(struct super_block___12 *, int);
	int (*quota_enable)(struct super_block___12 *, unsigned int);
	int (*quota_disable)(struct super_block___12 *, unsigned int);
	int (*quota_sync)(struct super_block___12 *, int);
	int (*set_info)(struct super_block___12 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___12 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___12 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___12 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___12 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___12 *, unsigned int);
};

struct address_space_operations___11 {
	int (*writepage)(struct page___12 *, struct writeback_control___3 *);
	int (*readpage)(struct file___12 *, struct page___12 *);
	int (*writepages)(struct address_space___11 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___12 *);
	int (*readpages)(struct file___12 *, struct address_space___11 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___12 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___12 **, void **);
	int (*write_end)(struct file___12 *, struct address_space___11 *, loff_t, unsigned int, unsigned int, struct page___12 *, void *);
	sector_t (*bmap)(struct address_space___11 *, sector_t);
	void (*invalidatepage)(struct page___12 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___12 *, gfp_t);
	void (*freepage)(struct page___12 *);
	ssize_t (*direct_IO)(struct kiocb___11 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___11 *, struct page___12 *, struct page___12 *, enum migrate_mode);
	bool (*isolate_page)(struct page___12 *, isolate_mode_t);
	void (*putback_page)(struct page___12 *);
	int (*launder_page)(struct page___12 *);
	int (*is_partially_uptodate)(struct page___12 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___12 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___11 *, struct page___12 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___12 *, sector_t *);
	void (*swap_deactivate)(struct file___12 *);
};

struct cdev___5 {
	struct kobject___11 kobj;
	struct module___13 *owner;
	const struct file_operations___11 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___11 {
	struct dentry___12 * (*lookup)(struct inode___13 *, struct dentry___12 *, unsigned int);
	const char * (*get_link)(struct dentry___12 *, struct inode___13 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___13 *, int);
	struct posix_acl * (*get_acl)(struct inode___13 *, int, bool);
	int (*readlink)(struct dentry___12 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___13 *, struct dentry___12 *, umode_t, bool);
	int (*link)(struct dentry___12 *, struct inode___13 *, struct dentry___12 *);
	int (*unlink)(struct inode___13 *, struct dentry___12 *);
	int (*symlink)(struct user_namespace *, struct inode___13 *, struct dentry___12 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___13 *, struct dentry___12 *, umode_t);
	int (*rmdir)(struct inode___13 *, struct dentry___12 *);
	int (*mknod)(struct user_namespace *, struct inode___13 *, struct dentry___12 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___13 *, struct dentry___12 *, struct inode___13 *, struct dentry___12 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___12 *, struct iattr___12 *);
	int (*getattr)(struct user_namespace *, const struct path___11 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___12 *, char *, size_t);
	int (*fiemap)(struct inode___13 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___13 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___13 *, struct dentry___12 *, struct file___12 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___13 *, struct dentry___12 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___13 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___12 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___12 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___11 {
	void (*fl_copy_lock)(struct file_lock___11 *, struct file_lock___11 *);
	void (*fl_release_private)(struct file_lock___11 *);
};

struct fasync_struct___11;

struct lock_manager_operations___11;

struct file_lock___11 {
	struct file_lock___11 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___12 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___11 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___11 *fl_ops;
	const struct lock_manager_operations___11 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___11 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___11 *);
	int (*lm_grant)(struct file_lock___11 *, int);
	bool (*lm_break)(struct file_lock___11 *);
	int (*lm_change)(struct file_lock___11 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___11 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___11 *);
};

struct fasync_struct___11 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___11 *fa_next;
	struct file___12 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___11 {
	struct inode___13 * (*alloc_inode)(struct super_block___12 *);
	void (*destroy_inode)(struct inode___13 *);
	void (*free_inode)(struct inode___13 *);
	void (*dirty_inode)(struct inode___13 *, int);
	int (*write_inode)(struct inode___13 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___13 *);
	void (*evict_inode)(struct inode___13 *);
	void (*put_super)(struct super_block___12 *);
	int (*sync_fs)(struct super_block___12 *, int);
	int (*freeze_super)(struct super_block___12 *);
	int (*freeze_fs)(struct super_block___12 *);
	int (*thaw_super)(struct super_block___12 *);
	int (*unfreeze_fs)(struct super_block___12 *);
	int (*statfs)(struct dentry___12 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___12 *, int *, char *);
	void (*umount_begin)(struct super_block___12 *);
	int (*show_options)(struct seq_file___13 *, struct dentry___12 *);
	int (*show_devname)(struct seq_file___13 *, struct dentry___12 *);
	int (*show_path)(struct seq_file___13 *, struct dentry___12 *);
	int (*show_stats)(struct seq_file___13 *, struct dentry___12 *);
	ssize_t (*quota_read)(struct super_block___12 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___12 *, int, const char *, size_t, loff_t);
	struct dquot___11 ** (*get_dquots)(struct inode___13 *);
	long int (*nr_cached_objects)(struct super_block___12 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___12 *, struct shrink_control___3 *);
	struct file___12 * (*real_loop)(struct file___12 *);
};

struct kernel_param_ops___11 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___11 *);
	int (*get)(char *, const struct kernel_param___11 *);
	void (*free)(void *);
};

struct kparam_array___11;

struct kernel_param___11 {
	const char *name;
	struct module___13 *mod;
	const struct kernel_param_ops___11 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___11 *arr;
	};
};

struct kparam_array___11 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___11 *ops;
	void *elem;
};

struct module_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___11 *, struct module_kobject___11 *, char *);
	ssize_t (*store)(struct module_attribute___11 *, struct module_kobject___11 *, const char *, size_t);
	void (*setup)(struct module___13 *, const char *);
	int (*test)(struct module___13 *);
	void (*free)(struct module___13 *);
};

struct seq_operations___11 {
	void * (*start)(struct seq_file___13 *, loff_t *);
	void (*stop)(struct seq_file___13 *, void *);
	void * (*next)(struct seq_file___13 *, void *, loff_t *);
	int (*show)(struct seq_file___13 *, void *);
};

struct dev_pagemap_ops___11 {
	void (*page_free)(struct page___12 *);
	void (*kill)(struct dev_pagemap___11 *);
	void (*cleanup)(struct dev_pagemap___11 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___11 *);
};

enum lockdep_ok {
	LOCKDEP_STILL_OK = 0,
	LOCKDEP_NOW_UNRELIABLE = 1,
};

typedef bool pstate_check_t(long unsigned int);

enum bug_trap_type {
	BUG_TRAP_TYPE_NONE = 0,
	BUG_TRAP_TYPE_WARN = 1,
	BUG_TRAP_TYPE_BUG = 2,
};

enum ftr_type {
	FTR_EXACT = 0,
	FTR_LOWER_SAFE = 1,
	FTR_HIGHER_SAFE = 2,
	FTR_HIGHER_OR_ZERO_SAFE = 3,
};

struct arm64_ftr_bits {
	bool sign;
	bool visible;
	bool strict;
	enum ftr_type type;
	u8 shift;
	u8 width;
	s64 safe_val;
};

struct arm64_ftr_override {
	u64 val;
	u64 mask;
};

struct arm64_ftr_reg {
	const char *name;
	u64 strict_mask;
	u64 user_mask;
	u64 sys_val;
	u64 user_val;
	struct arm64_ftr_override *override;
	const struct arm64_ftr_bits *ftr_bits;
};

enum siginfo_layout {
	SIL_KILL = 0,
	SIL_TIMER = 1,
	SIL_POLL = 2,
	SIL_FAULT = 3,
	SIL_FAULT_TRAPNO = 4,
	SIL_FAULT_MCEERR = 5,
	SIL_FAULT_BNDERR = 6,
	SIL_FAULT_PKUERR = 7,
	SIL_FAULT_PERF_EVENT = 8,
	SIL_CHLD = 9,
	SIL_RT = 10,
	SIL_SYS = 11,
};

enum die_val {
	DIE_UNUSED = 0,
	DIE_OOPS = 1,
};

struct undef_hook {
	struct list_head node;
	u32 instr_mask;
	u32 instr_val;
	u64 pstate_mask;
	u64 pstate_val;
	int (*fn)(struct pt_regs *, u32);
};

struct sys64_hook {
	unsigned int esr_mask;
	unsigned int esr_val;
	void (*handler)(unsigned int, struct pt_regs *);
};

struct timens_offset {
	s64 sec;
	u64 nsec;
};

enum vm_fault_reason {
	VM_FAULT_OOM = 1,
	VM_FAULT_SIGBUS = 2,
	VM_FAULT_MAJOR = 4,
	VM_FAULT_WRITE = 8,
	VM_FAULT_HWPOISON = 16,
	VM_FAULT_HWPOISON_LARGE = 32,
	VM_FAULT_SIGSEGV = 64,
	VM_FAULT_NOPAGE = 256,
	VM_FAULT_LOCKED = 512,
	VM_FAULT_RETRY = 1024,
	VM_FAULT_FALLBACK = 2048,
	VM_FAULT_DONE_COW = 4096,
	VM_FAULT_NEEDDSYNC = 8192,
	VM_FAULT_HINDEX_MASK = 983040,
};

struct vm_special_mapping {
	const char *name;
	struct page___7 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping *, struct vm_area_struct___6 *, struct vm_fault___6 *);
	int (*mremap)(const struct vm_special_mapping *, struct vm_area_struct___6 *);
};

struct timens_offsets {
	struct timespec64 monotonic;
	struct timespec64 boottime;
};

struct time_namespace {
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common___2 ns;
	struct timens_offsets offsets;
	struct page___7 *vvar_page;
	bool frozen_offsets;
};

struct arch_vdso_data {};

struct vdso_timestamp {
	u64 sec;
	u64 nsec;
};

struct vdso_data {
	u32 seq;
	s32 clock_mode;
	u64 cycle_last;
	u64 mask;
	u32 mult;
	u32 shift;
	union {
		struct vdso_timestamp basetime[12];
		struct timens_offset offset[12];
	};
	s32 tz_minuteswest;
	s32 tz_dsttime;
	u32 hrtimer_res;
	u32 __unused;
	struct arch_vdso_data arch_data;
};

enum vdso_abi {
	VDSO_ABI_AA64 = 0,
	VDSO_ABI_AA32 = 1,
};

enum vvar_pages {
	VVAR_DATA_PAGE_OFFSET = 0,
	VVAR_TIMENS_PAGE_OFFSET = 1,
	VVAR_NR_PAGES = 2,
};

struct vdso_abi_info {
	const char *name;
	const char *vdso_code_start;
	const char *vdso_code_end;
	long unsigned int vdso_pages;
	struct vm_special_mapping *dm;
	struct vm_special_mapping *cm;
};

enum aarch32_map {
	AA32_MAP_VECTORS = 0,
	AA32_MAP_SIGPAGE = 1,
	AA32_MAP_VVAR = 2,
	AA32_MAP_VDSO = 3,
};

enum aarch64_map {
	AA64_MAP_VVAR = 0,
	AA64_MAP_VDSO = 1,
};

struct linux_binprm___2;

struct psci_operations {
	u32 (*get_version)();
	int (*cpu_suspend)(u32, long unsigned int);
	int (*cpu_off)(u32);
	int (*cpu_on)(long unsigned int, long unsigned int);
	int (*migrate)(long unsigned int);
	int (*affinity_info)(long unsigned int, long unsigned int);
	int (*migrate_info_type)();
};

struct irq_desc___3;

typedef void (*irq_flow_handler_t___3)(struct irq_desc___3 *);

struct irq_chip___3;

struct irq_data___3 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___3 *chip;
	struct irq_domain___2 *domain;
	struct irq_data___3 *parent_data;
	void *chip_data;
};

struct irqaction___3;

struct irq_desc___3 {
	struct irq_common_data irq_common_data;
	struct irq_data___3 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___3 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___7 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___9 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_fwspec___3 {
	struct fwnode_handle___7 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___3 {
	int (*match)(struct irq_domain___2 *, struct device_node___2 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___2 *, struct irq_fwspec___3 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___2 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___2 *, unsigned int);
	int (*xlate)(struct irq_domain___2 *, struct device_node___2 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___2 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___2 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___2 *, struct irq_data___3 *, bool);
	void (*deactivate)(struct irq_domain___2 *, struct irq_data___3 *);
	int (*translate)(struct irq_domain___2 *, struct irq_fwspec___3 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___3;

struct irq_domain___2 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___3 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___7 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___3 *gc;
	struct irq_domain___2 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___3 *revmap[0];
};

struct irq_chip_generic___3;

struct irq_domain_chip_generic___3 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___3 *gc[0];
};

struct irq_chip___3 {
	struct device___7 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___3 *);
	void (*irq_shutdown)(struct irq_data___3 *);
	void (*irq_enable)(struct irq_data___3 *);
	void (*irq_disable)(struct irq_data___3 *);
	void (*irq_ack)(struct irq_data___3 *);
	void (*irq_mask)(struct irq_data___3 *);
	void (*irq_mask_ack)(struct irq_data___3 *);
	void (*irq_unmask)(struct irq_data___3 *);
	void (*irq_eoi)(struct irq_data___3 *);
	int (*irq_set_affinity)(struct irq_data___3 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___3 *);
	int (*irq_set_type)(struct irq_data___3 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___3 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___3 *);
	void (*irq_bus_sync_unlock)(struct irq_data___3 *);
	void (*irq_cpu_online)(struct irq_data___3 *);
	void (*irq_cpu_offline)(struct irq_data___3 *);
	void (*irq_suspend)(struct irq_data___3 *);
	void (*irq_resume)(struct irq_data___3 *);
	void (*irq_pm_shutdown)(struct irq_data___3 *);
	void (*irq_calc_mask)(struct irq_data___3 *);
	void (*irq_print_chip)(struct irq_data___3 *, struct seq_file___10 *);
	int (*irq_request_resources)(struct irq_data___3 *);
	void (*irq_release_resources)(struct irq_data___3 *);
	void (*irq_compose_msi_msg)(struct irq_data___3 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___3 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___3 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___3 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___3 *, void *);
	void (*ipi_send_single)(struct irq_data___3 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___3 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___3 *);
	void (*irq_nmi_teardown)(struct irq_data___3 *);
	long unsigned int flags;
};

struct irqaction___3 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___3 *next;
	irq_handler_t thread_fn;
	struct task_struct___9 *thread;
	struct irqaction___3 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___3 {
	struct irq_chip___3 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___3 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___3 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___3 *);
	void (*resume)(struct irq_chip_generic___3 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___2 *domain;
	struct list_head list;
	struct irq_chip_type___3 chip_types[0];
};

struct return_address_data {
	unsigned int level;
	void *addr;
};

struct kobj_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kobject___8 *, struct kobj_attribute *, char *);
	ssize_t (*store)(struct kobject___8 *, struct kobj_attribute *, const char *, size_t);
};

struct cpu___2 {
	int node_id;
	int hotpluggable;
	struct device___7 dev;
};

struct cpuinfo_arm64___2 {
	struct cpu___2 cpu;
	struct kobject___8 kobj;
	u64 reg_ctr;
	u64 reg_cntfrq;
	u64 reg_dczid;
	u64 reg_midr;
	u64 reg_revidr;
	u64 reg_gmid;
	u64 reg_id_aa64dfr0;
	u64 reg_id_aa64dfr1;
	u64 reg_id_aa64isar0;
	u64 reg_id_aa64isar1;
	u64 reg_id_aa64isar2;
	u64 reg_id_aa64mmfr0;
	u64 reg_id_aa64mmfr1;
	u64 reg_id_aa64mmfr2;
	u64 reg_id_aa64pfr0;
	u64 reg_id_aa64pfr1;
	u64 reg_id_aa64zfr0;
	struct cpuinfo_32bit aarch32;
	u64 reg_zcr;
};

typedef int (*cmp_func_t)(const void *, const void *);

enum aarch64_insn_imm_type {
	AARCH64_INSN_IMM_ADR = 0,
	AARCH64_INSN_IMM_26 = 1,
	AARCH64_INSN_IMM_19 = 2,
	AARCH64_INSN_IMM_16 = 3,
	AARCH64_INSN_IMM_14 = 4,
	AARCH64_INSN_IMM_12 = 5,
	AARCH64_INSN_IMM_9 = 6,
	AARCH64_INSN_IMM_7 = 7,
	AARCH64_INSN_IMM_6 = 8,
	AARCH64_INSN_IMM_S = 9,
	AARCH64_INSN_IMM_R = 10,
	AARCH64_INSN_IMM_N = 11,
	AARCH64_INSN_IMM_MAX = 12,
};

enum aarch64_insn_register_type {
	AARCH64_INSN_REGTYPE_RT = 0,
	AARCH64_INSN_REGTYPE_RN = 1,
	AARCH64_INSN_REGTYPE_RT2 = 2,
	AARCH64_INSN_REGTYPE_RM = 3,
	AARCH64_INSN_REGTYPE_RD = 4,
	AARCH64_INSN_REGTYPE_RA = 5,
	AARCH64_INSN_REGTYPE_RS = 6,
};

enum {
	CAP_HWCAP = 1,
	CAP_COMPAT_HWCAP = 2,
	CAP_COMPAT_HWCAP2 = 3,
};

struct secondary_data {
	struct task_struct___10 *task;
	long int status;
};

enum mitigation_state {
	SPECTRE_UNAFFECTED = 0,
	SPECTRE_MITIGATED = 1,
	SPECTRE_VULNERABLE = 2,
};

enum pageflags {
	PG_locked = 0,
	PG_referenced = 1,
	PG_uptodate = 2,
	PG_dirty = 3,
	PG_lru = 4,
	PG_active = 5,
	PG_workingset = 6,
	PG_waiters = 7,
	PG_error = 8,
	PG_slab = 9,
	PG_owner_priv_1 = 10,
	PG_arch_1 = 11,
	PG_reserved = 12,
	PG_private = 13,
	PG_private_2 = 14,
	PG_writeback = 15,
	PG_head = 16,
	PG_mappedtodisk = 17,
	PG_reclaim = 18,
	PG_swapbacked = 19,
	PG_unevictable = 20,
	PG_mlocked = 21,
	PG_hwpoison = 22,
	PG_young = 23,
	PG_idle = 24,
	PG_arch_2 = 25,
	__NR_PAGEFLAGS = 26,
	PG_checked = 10,
	PG_swapcache = 10,
	PG_fscache = 14,
	PG_pinned = 10,
	PG_savepinned = 3,
	PG_foreign = 10,
	PG_xen_remapped = 10,
	PG_slob_free = 13,
	PG_double_map = 6,
	PG_has_hwpoisoned = 17,
	PG_isolated = 18,
	PG_reported = 2,
};

enum fixed_addresses {
	FIX_HOLE = 0,
	FIX_FDT_END = 1,
	FIX_FDT = 1024,
	FIX_EARLYCON_MEM_BASE = 1025,
	FIX_TEXT_POKE0 = 1026,
	FIX_APEI_GHES_IRQ = 1027,
	FIX_APEI_GHES_SEA = 1028,
	FIX_APEI_GHES_SDEI_NORMAL = 1029,
	FIX_APEI_GHES_SDEI_CRITICAL = 1030,
	FIX_ENTRY_TRAMP_TEXT3 = 1031,
	FIX_ENTRY_TRAMP_TEXT2 = 1032,
	FIX_ENTRY_TRAMP_TEXT1 = 1033,
	FIX_ENTRY_TRAMP_DATA = 1034,
	__end_of_permanent_fixed_addresses = 1035,
	FIX_BTMAP_END = 1035,
	FIX_BTMAP_BEGIN = 1482,
	FIX_PTE = 1483,
	FIX_PMD = 1484,
	FIX_PUD = 1485,
	FIX_PGD = 1486,
	__end_of_fixed_addresses = 1487,
};

struct device_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device___7 *, struct device_attribute *, char *);
	ssize_t (*store)(struct device___7 *, struct device_attribute *, const char *, size_t);
};

typedef int (*cpu_stop_fn_t)(void *);

enum kvm_mode {
	KVM_MODE_DEFAULT = 0,
	KVM_MODE_PROTECTED = 1,
};

enum vcpu_sysreg {
	__INVALID_SYSREG__ = 0,
	MPIDR_EL1 = 1,
	CSSELR_EL1 = 2,
	SCTLR_EL1 = 3,
	ACTLR_EL1 = 4,
	CPACR_EL1 = 5,
	ZCR_EL1 = 6,
	TTBR0_EL1 = 7,
	TTBR1_EL1 = 8,
	TCR_EL1 = 9,
	ESR_EL1 = 10,
	AFSR0_EL1 = 11,
	AFSR1_EL1 = 12,
	FAR_EL1 = 13,
	MAIR_EL1 = 14,
	VBAR_EL1 = 15,
	CONTEXTIDR_EL1 = 16,
	TPIDR_EL0 = 17,
	TPIDRRO_EL0 = 18,
	TPIDR_EL1 = 19,
	AMAIR_EL1 = 20,
	CNTKCTL_EL1 = 21,
	PAR_EL1 = 22,
	MDSCR_EL1 = 23,
	MDCCINT_EL1 = 24,
	DISR_EL1 = 25,
	PMCR_EL0 = 26,
	PMSELR_EL0 = 27,
	PMEVCNTR0_EL0 = 28,
	PMEVCNTR30_EL0 = 58,
	PMCCNTR_EL0 = 59,
	PMEVTYPER0_EL0 = 60,
	PMEVTYPER30_EL0 = 90,
	PMCCFILTR_EL0 = 91,
	PMCNTENSET_EL0 = 92,
	PMINTENSET_EL1 = 93,
	PMOVSSET_EL0 = 94,
	PMUSERENR_EL0 = 95,
	APIAKEYLO_EL1 = 96,
	APIAKEYHI_EL1 = 97,
	APIBKEYLO_EL1 = 98,
	APIBKEYHI_EL1 = 99,
	APDAKEYLO_EL1 = 100,
	APDAKEYHI_EL1 = 101,
	APDBKEYLO_EL1 = 102,
	APDBKEYHI_EL1 = 103,
	APGAKEYLO_EL1 = 104,
	APGAKEYHI_EL1 = 105,
	ELR_EL1 = 106,
	SP_EL1 = 107,
	SPSR_EL1 = 108,
	CNTVOFF_EL2 = 109,
	CNTV_CVAL_EL0 = 110,
	CNTV_CTL_EL0 = 111,
	CNTP_CVAL_EL0 = 112,
	CNTP_CTL_EL0 = 113,
	RGSR_EL1 = 114,
	GCR_EL1 = 115,
	TFSR_EL1 = 116,
	TFSRE0_EL1 = 117,
	DACR32_EL2 = 118,
	IFSR32_EL2 = 119,
	FPEXC32_EL2 = 120,
	DBGVCR32_EL2 = 121,
	NR_SYS_REGS = 122,
};

enum arm64_bp_harden_el1_vectors {
	EL1_VECTOR_BHB_LOOP = 0,
	EL1_VECTOR_BHB_FW = 1,
	EL1_VECTOR_BHB_CLEAR_INSN = 2,
	EL1_VECTOR_KPTI = 3,
};

struct __ftr_reg_entry {
	u32 sys_id;
	struct arm64_ftr_reg *reg;
};

typedef void kpti_remap_fn(int, int, phys_addr_t);

typedef void ttbr_replace_func(phys_addr_t);

struct jump_entry___2 {
	s32 code;
	s32 target;
	long int key;
	long: 64;
};

struct static_key___2 {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry___2 *entries;
		struct static_key_mod *next;
	};
};

struct static_key_false___2 {
	struct static_key___2 key;
};

struct alt_instr {
	s32 orig_offset;
	s32 alt_offset;
	u16 cpufeature;
	u8 orig_len;
	u8 alt_len;
};

typedef void (*alternative_cb_t)(struct alt_instr *, __le32 *, __le32 *, int);

struct alt_region {
	struct alt_instr *begin;
	struct alt_instr *end;
	long: 64;
};

enum cache_type {
	CACHE_TYPE_NOCACHE = 0,
	CACHE_TYPE_INST = 1,
	CACHE_TYPE_DATA = 2,
	CACHE_TYPE_SEPARATE = 3,
	CACHE_TYPE_UNIFIED = 4,
};

struct cacheinfo {
	unsigned int id;
	enum cache_type type;
	unsigned int level;
	unsigned int coherency_line_size;
	unsigned int number_of_sets;
	unsigned int ways_of_associativity;
	unsigned int physical_line_partition;
	unsigned int size;
	cpumask_t shared_cpu_map;
	unsigned int attributes;
	void *fw_token;
	bool disable_sysfs;
	void *priv;
};

struct cpu_cacheinfo {
	struct cacheinfo *info_list;
	unsigned int num_levels;
	unsigned int num_leaves;
	bool cpu_map_populated;
};

struct irq_desc___4;

typedef void (*irq_flow_handler_t___4)(struct irq_desc___4 *);

struct irq_chip___4;

struct irq_domain___4;

struct irq_data___4 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___4 *chip;
	struct irq_domain___4 *domain;
	struct irq_data___4 *parent_data;
	void *chip_data;
};

struct kset___12;

struct kobj_type___12;

struct kernfs_node___12;

struct kobject___12 {
	const char *name;
	struct list_head entry;
	struct kobject___12 *parent;
	struct kset___12 *kset;
	struct kobj_type___12 *ktype;
	struct kernfs_node___12 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___4;

struct module___14;

struct irq_desc___4 {
	struct irq_common_data irq_common_data;
	struct irq_data___4 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___4 handle_irq;
	struct irqaction___4 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___12 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___14 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___13;

struct super_block___13;

struct file_system_type___12 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___13 * (*mount)(struct file_system_type___12 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___13 *);
	struct module___14 *owner;
	struct file_system_type___12 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___13;

struct kiocb___12;

struct poll_table_struct___9;

struct vm_area_struct___12;

struct inode___14;

struct file_lock___12;

struct page___13;

struct seq_file___14;

struct file_operations___12 {
	struct module___14 *owner;
	loff_t (*llseek)(struct file___13 *, loff_t, int);
	ssize_t (*read)(struct file___13 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___13 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___12 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___12 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___12 *, bool);
	int (*iterate)(struct file___13 *, struct dir_context *);
	int (*iterate_shared)(struct file___13 *, struct dir_context *);
	__poll_t (*poll)(struct file___13 *, struct poll_table_struct___9 *);
	long int (*unlocked_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___13 *, struct vm_area_struct___12 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___14 *, struct file___13 *);
	int (*flush)(struct file___13 *, fl_owner_t);
	int (*release)(struct inode___14 *, struct file___13 *);
	int (*fsync)(struct file___13 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___13 *, int);
	int (*lock)(struct file___13 *, int, struct file_lock___12 *);
	ssize_t (*sendpage)(struct file___13 *, struct page___13 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___13 *, long unsigned int);
	int (*flock)(struct file___13 *, int, struct file_lock___12 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___13 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___13 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___13 *, long int, struct file_lock___12 **, void **);
	long int (*fallocate)(struct file___13 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___14 *, struct file___13 *);
	ssize_t (*copy_file_range)(struct file___13 *, loff_t, struct file___13 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___13 *, loff_t, struct file___13 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___13 *, loff_t, loff_t, int);
};

struct vmacache___12 {
	u64 seqnum;
	struct vm_area_struct___12 *vmas[4];
};

struct page_frag___12 {
	struct page___13 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___7;

struct debug_info___7 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___7 *hbp_break[16];
	struct perf_event___7 *hbp_watch[16];
};

struct thread_struct___7 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___7 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___13;

struct pid___11;

struct nsproxy___12;

struct signal_struct___13;

struct css_set___7;

struct perf_event_context___7;

struct vm_struct___12;

struct task_struct___14 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___14 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___13 *mm;
	struct mm_struct___13 *active_mm;
	struct vmacache___12 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___14 *real_parent;
	struct task_struct___14 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___14 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___11 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___12 *nsproxy;
	struct signal_struct___13 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___14 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___7 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___7 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___12 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___14 *oom_reaper_list;
	struct vm_struct___12 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___7 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct secondary_data___2 {
	struct task_struct___14 *task;
	long int status;
};

struct module_kobject___12 {
	struct kobject___12 kobj;
	struct module___14 *mod;
	struct kobject___12 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___12 {
	struct module___14 *mod;
	struct latch_tree_node node;
};

struct module_layout___12 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___12 mtn;
};

struct module_attribute___12;

struct kernel_param___12;

struct trace_event_call___7;

struct module___14 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___12 mkobj;
	struct module_attribute___12 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___12 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___12 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___12 core_layout;
	struct module_layout___12 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___7 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___7 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___14 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___7)(struct perf_event___7 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___7;

struct fasync_struct___12;

struct pid_namespace___11;

struct perf_cgroup___7;

struct perf_event___7 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___7 *group_leader;
	struct pmu___7 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___7 hw;
	struct perf_event_context___7 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___7 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___14 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___12 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___7 *aux_event;
	void (*destroy)(struct perf_event___7 *);
	struct callback_head callback_head;
	struct pid_namespace___11 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___7 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___7 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___7 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___7 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___13 *pgtable_t___12;

struct address_space___12;

struct dev_pagemap___12;

struct page___13 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___12 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___13 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___12 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___13 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___12 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___12;

struct vm_area_struct___12 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___12 *vm_next;
	struct vm_area_struct___12 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___13 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___12 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___13 *vm_file;
	struct file___13 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___12;

struct mm_struct___13 {
	struct {
		struct vm_area_struct___12 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___12 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___14 *owner;
		struct user_namespace *user_ns;
		struct file___13 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___12;

struct address_space___12 {
	struct inode___14 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___12 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___12;

struct dev_pagemap___12 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___12 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___12;

struct path___12 {
	struct vfsmount___12 *mnt;
	struct dentry___13 *dentry;
};

struct fown_struct___11 {
	rwlock_t lock;
	struct pid___11 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___13 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___12 f_path;
	struct inode___14 *f_inode;
	const struct file_operations___12 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___11 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___12 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___12;

struct vm_operations_struct___12 {
	void (*open)(struct vm_area_struct___12 *);
	void (*close)(struct vm_area_struct___12 *);
	int (*may_split)(struct vm_area_struct___12 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___12 *);
	int (*mprotect)(struct vm_area_struct___12 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___12 *);
	vm_fault_t (*huge_fault)(struct vm_fault___12 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___12 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___12 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___12 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___12 *);
	int (*access)(struct vm_area_struct___12 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___12 *);
	int (*set_policy)(struct vm_area_struct___12 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___12 *, long unsigned int);
	struct page___13 * (*find_special_page)(struct vm_area_struct___12 *, long unsigned int);
};

struct core_thread___12 {
	struct task_struct___14 *task;
	struct core_thread___12 *next;
};

struct core_state___12 {
	atomic_t nr_threads;
	struct core_thread___12 dumper;
	struct completion startup;
};

struct vm_fault___12 {
	const struct {
		struct vm_area_struct___12 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___13 *cow_page;
	struct page___13 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___12 prealloc_pte;
};

struct kernfs_root___12;

struct kernfs_elem_dir___12 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___12 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___12;

struct kernfs_root___12 {
	struct kernfs_node___12 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___12 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___12 {
	struct kernfs_node___12 *target_kn;
};

struct kernfs_ops___12;

struct kernfs_elem_attr___12 {
	const struct kernfs_ops___12 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___12 *notify_next;
};

struct kernfs_node___12 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___12 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___12 dir;
		struct kernfs_elem_symlink___12 symlink;
		struct kernfs_elem_attr___12 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___12;

struct kernfs_ops___12 {
	int (*open)(struct kernfs_open_file___12 *);
	void (*release)(struct kernfs_open_file___12 *);
	int (*seq_show)(struct seq_file___14 *, void *);
	void * (*seq_start)(struct seq_file___14 *, loff_t *);
	void * (*seq_next)(struct seq_file___14 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___14 *, void *);
	ssize_t (*read)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___12 *, struct poll_table_struct___9 *);
	int (*mmap)(struct kernfs_open_file___12 *, struct vm_area_struct___12 *);
};

struct kernfs_syscall_ops___12 {
	int (*show_options)(struct seq_file___14 *, struct kernfs_root___12 *);
	int (*mkdir)(struct kernfs_node___12 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___12 *);
	int (*rename)(struct kernfs_node___12 *, struct kernfs_node___12 *, const char *);
	int (*show_path)(struct seq_file___14 *, struct kernfs_node___12 *, struct kernfs_root___12 *);
};

struct seq_operations___12;

struct seq_file___14 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___12 *op;
	int poll_event;
	const struct file___13 *file;
	void *private;
};

struct kernfs_open_file___12 {
	struct kernfs_node___12 *kn;
	struct file___13 *file;
	struct seq_file___14 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___12 *vm_ops;
};

typedef void (*poll_queue_proc___9)(struct file___13 *, wait_queue_head_t *, struct poll_table_struct___9 *);

struct poll_table_struct___9 {
	poll_queue_proc___9 _qproc;
	__poll_t _key;
};

struct upid___11 {
	int nr;
	struct pid_namespace___11 *ns;
};

struct pid_namespace___11 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___14 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___11 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___11 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___11 numbers[1];
};

struct signal_struct___13 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___14 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___14 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___11 *pids[4];
	struct pid___11 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___13 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___8;

struct nsproxy___12 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___11 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___8 *cgroup_ns;
};

struct cgroup_subsys_state___7;

struct cgroup___7;

struct css_set___7 {
	struct cgroup_subsys_state___7 *subsys[14];
	refcount_t refcount;
	struct css_set___7 *dom_cset;
	struct cgroup___7 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___7 *mg_src_cgrp;
	struct cgroup___7 *mg_dst_cgrp;
	struct css_set___7 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___7 {
	struct pmu___7 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___14 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___7 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___12 {
	struct vm_struct___12 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___13 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___12;

struct attribute_group___12 {
	const char *name;
	umode_t (*is_visible)(struct kobject___12 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___12 *, struct bin_attribute___12 *, int);
	struct attribute **attrs;
	struct bin_attribute___12 **bin_attrs;
};

struct bin_attribute___12 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___12 * (*f_mapping)();
	ssize_t (*read)(struct file___13 *, struct kobject___12 *, struct bin_attribute___12 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___13 *, struct kobject___12 *, struct bin_attribute___12 *, char *, loff_t, size_t);
	int (*mmap)(struct file___13 *, struct kobject___12 *, struct bin_attribute___12 *, struct vm_area_struct___12 *);
};

struct sysfs_ops___12 {
	ssize_t (*show)(struct kobject___12 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___12 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___12;

struct kset___12 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___12 kobj;
	const struct kset_uevent_ops___12 *uevent_ops;
};

struct kobj_type___12 {
	void (*release)(struct kobject___12 *);
	const struct sysfs_ops___12 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___12 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___12 *);
	const void * (*namespace)(struct kobject___12 *);
	void (*get_ownership)(struct kobject___12 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___12 {
	int (* const filter)(struct kset___12 *, struct kobject___12 *);
	const char * (* const name)(struct kset___12 *, struct kobject___12 *);
	int (* const uevent)(struct kset___12 *, struct kobject___12 *, struct kobj_uevent_env *);
};

struct fwnode_operations___9;

struct device___9;

struct fwnode_handle___9 {
	struct fwnode_handle___9 *secondary;
	const struct fwnode_operations___9 *ops;
	struct device___9 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___9;

struct fwnode_endpoint___9;

struct fwnode_operations___9 {
	struct fwnode_handle___9 * (*get)(struct fwnode_handle___9 *);
	void (*put)(struct fwnode_handle___9 *);
	bool (*device_is_available)(const struct fwnode_handle___9 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___9 *, const struct device___9 *);
	bool (*property_present)(const struct fwnode_handle___9 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___9 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___9 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___9 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_parent)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_next_child_node)(const struct fwnode_handle___9 *, struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*get_named_child_node)(const struct fwnode_handle___9 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___9 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___9 *);
	struct fwnode_handle___9 * (*graph_get_next_endpoint)(const struct fwnode_handle___9 *, struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*graph_get_remote_endpoint)(const struct fwnode_handle___9 *);
	struct fwnode_handle___9 * (*graph_get_port_parent)(struct fwnode_handle___9 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___9 *, struct fwnode_endpoint___9 *);
	int (*add_links)(struct fwnode_handle___9 *);
};

struct wakeup_source___9;

struct dev_pm_info___9 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___9 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___9 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___9;

struct bus_type___9;

struct device_driver___9;

struct dev_pm_domain___9;

struct device_node___4;

struct class___9;

struct device___9 {
	struct kobject___12 kobj;
	struct device___9 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___9 *type;
	struct bus_type___9 *bus;
	struct device_driver___9 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___9 power;
	struct dev_pm_domain___9 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___4 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___4 *of_node;
	struct fwnode_handle___9 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___9 *class;
	const struct attribute_group___12 **groups;
	void (*release)(struct device___9 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___9 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___9 *local_fwnode;
};

struct fwnode_reference_args___9 {
	struct fwnode_handle___9 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___4 {
	char *name;
	int length;
	void *value;
	struct property___4 *next;
	long unsigned int _flags;
	struct bin_attribute___12 attr;
};

struct device_node___4 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___9 fwnode;
	struct property___4 *properties;
	struct property___4 *deadprops;
	struct device_node___4 *parent;
	struct device_node___4 *child;
	struct device_node___4 *sibling;
	struct kobject___12 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___4 {
	struct fwnode_handle___9 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___4 {
	int (*match)(struct irq_domain___4 *, struct device_node___4 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___4 *, struct irq_fwspec___4 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___4 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___4 *, unsigned int);
	int (*xlate)(struct irq_domain___4 *, struct device_node___4 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___4 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___4 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___4 *, struct irq_data___4 *, bool);
	void (*deactivate)(struct irq_domain___4 *, struct irq_data___4 *);
	int (*translate)(struct irq_domain___4 *, struct irq_fwspec___4 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___4;

struct irq_domain___4 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___4 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___9 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___4 *gc;
	struct irq_domain___4 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___4 *revmap[0];
};

struct irq_chip_generic___4;

struct irq_domain_chip_generic___4 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___4 *gc[0];
};

struct dev_pm_ops___9 {
	int (*prepare)(struct device___9 *);
	void (*complete)(struct device___9 *);
	int (*suspend)(struct device___9 *);
	int (*resume)(struct device___9 *);
	int (*freeze)(struct device___9 *);
	int (*thaw)(struct device___9 *);
	int (*poweroff)(struct device___9 *);
	int (*restore)(struct device___9 *);
	int (*suspend_late)(struct device___9 *);
	int (*resume_early)(struct device___9 *);
	int (*freeze_late)(struct device___9 *);
	int (*thaw_early)(struct device___9 *);
	int (*poweroff_late)(struct device___9 *);
	int (*restore_early)(struct device___9 *);
	int (*suspend_noirq)(struct device___9 *);
	int (*resume_noirq)(struct device___9 *);
	int (*freeze_noirq)(struct device___9 *);
	int (*thaw_noirq)(struct device___9 *);
	int (*poweroff_noirq)(struct device___9 *);
	int (*restore_noirq)(struct device___9 *);
	int (*runtime_suspend)(struct device___9 *);
	int (*runtime_resume)(struct device___9 *);
	int (*runtime_idle)(struct device___9 *);
};

struct wakeup_source___9 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___9 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___9 {
	struct dev_pm_ops___9 ops;
	int (*start)(struct device___9 *);
	void (*detach)(struct device___9 *, bool);
	int (*activate)(struct device___9 *);
	void (*sync)(struct device___9 *);
	void (*dismiss)(struct device___9 *);
};

struct bus_type___9 {
	const char *name;
	const char *dev_name;
	struct device___9 *dev_root;
	const struct attribute_group___12 **bus_groups;
	const struct attribute_group___12 **dev_groups;
	const struct attribute_group___12 **drv_groups;
	int (*match)(struct device___9 *, struct device_driver___9 *);
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	int (*probe)(struct device___9 *);
	void (*sync_state)(struct device___9 *);
	void (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*online)(struct device___9 *);
	int (*offline)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	int (*num_vf)(struct device___9 *);
	int (*dma_configure)(struct device___9 *);
	const struct dev_pm_ops___9 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___9 {
	const char *name;
	struct bus_type___9 *bus;
	struct module___14 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___9 *);
	void (*sync_state)(struct device___9 *);
	int (*remove)(struct device___9 *);
	void (*shutdown)(struct device___9 *);
	int (*suspend)(struct device___9 *, pm_message_t);
	int (*resume)(struct device___9 *);
	const struct attribute_group___12 **groups;
	const struct attribute_group___12 **dev_groups;
	const struct dev_pm_ops___9 *pm;
	void (*coredump)(struct device___9 *);
	struct driver_private *p;
};

struct device_type___9 {
	const char *name;
	const struct attribute_group___12 **groups;
	int (*uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___9 *);
	const struct dev_pm_ops___9 *pm;
};

struct class___9 {
	const char *name;
	struct module___14 *owner;
	const struct attribute_group___12 **class_groups;
	const struct attribute_group___12 **dev_groups;
	struct kobject___12 *dev_kobj;
	int (*dev_uevent)(struct device___9 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___9 *, umode_t *);
	void (*class_release)(struct class___9 *);
	void (*dev_release)(struct device___9 *);
	int (*shutdown_pre)(struct device___9 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___9 *);
	void (*get_ownership)(struct device___9 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___9 *pm;
	struct subsys_private *p;
};

struct acpi_subtable_header {
	u8 type;
	u8 length;
};

struct acpi_hmat_structure {
	u16 type;
	u16 reserved;
	u32 length;
};

enum acpi_madt_type {
	ACPI_MADT_TYPE_LOCAL_APIC = 0,
	ACPI_MADT_TYPE_IO_APIC = 1,
	ACPI_MADT_TYPE_INTERRUPT_OVERRIDE = 2,
	ACPI_MADT_TYPE_NMI_SOURCE = 3,
	ACPI_MADT_TYPE_LOCAL_APIC_NMI = 4,
	ACPI_MADT_TYPE_LOCAL_APIC_OVERRIDE = 5,
	ACPI_MADT_TYPE_IO_SAPIC = 6,
	ACPI_MADT_TYPE_LOCAL_SAPIC = 7,
	ACPI_MADT_TYPE_INTERRUPT_SOURCE = 8,
	ACPI_MADT_TYPE_LOCAL_X2APIC = 9,
	ACPI_MADT_TYPE_LOCAL_X2APIC_NMI = 10,
	ACPI_MADT_TYPE_GENERIC_INTERRUPT = 11,
	ACPI_MADT_TYPE_GENERIC_DISTRIBUTOR = 12,
	ACPI_MADT_TYPE_GENERIC_MSI_FRAME = 13,
	ACPI_MADT_TYPE_GENERIC_REDISTRIBUTOR = 14,
	ACPI_MADT_TYPE_GENERIC_TRANSLATOR = 15,
	ACPI_MADT_TYPE_MULTIPROC_WAKEUP = 16,
	ACPI_MADT_TYPE_RESERVED = 17,
};

struct acpi_madt_generic_interrupt {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 cpu_interface_number;
	u32 uid;
	u32 flags;
	u32 parking_version;
	u32 performance_interrupt;
	u64 parked_address;
	u64 base_address;
	u64 gicv_base_address;
	u64 gich_base_address;
	u32 vgic_interrupt;
	u64 gicr_base_address;
	u64 arm_mpidr;
	u8 efficiency_class;
	u8 reserved2[1];
	u16 spe_interrupt;
} __attribute__((packed));

struct acpi_prmt_module_header {
	u16 revision;
	u16 length;
};

struct dentry_operations___12;

struct dentry___13 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___13 *d_parent;
	struct qstr d_name;
	struct inode___14 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___12 *d_op;
	struct super_block___13 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___12;

struct cdev___6;

struct inode___14 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___12 *i_op;
	struct super_block___13 *i_sb;
	struct address_space___12 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___12 *i_fop;
		void (*free_inode)(struct inode___14 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___12 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___6 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___12 {
	int (*d_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___13 *, unsigned int);
	int (*d_hash)(const struct dentry___13 *, struct qstr *);
	int (*d_compare)(const struct dentry___13 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___13 *);
	int (*d_init)(struct dentry___13 *);
	void (*d_release)(struct dentry___13 *);
	void (*d_prune)(struct dentry___13 *);
	void (*d_iput)(struct dentry___13 *, struct inode___14 *);
	char * (*d_dname)(struct dentry___13 *, char *, int);
	struct vfsmount___12 * (*d_automount)(struct path___12 *);
	int (*d_manage)(const struct path___12 *, bool);
	struct dentry___13 * (*d_real)(struct dentry___13 *, const struct inode___14 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___12;

struct mem_dqinfo___12 {
	struct quota_format_type___12 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___12;

struct quota_info___12 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___14 *files[3];
	struct mem_dqinfo___12 info[3];
	const struct quota_format_ops___12 *ops[3];
};

struct rcuwait___12 {
	struct task_struct___14 *task;
};

struct percpu_rw_semaphore___12 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___12 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___12 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___12 rw_sem[3];
};

struct super_operations___12;

struct dquot_operations___12;

struct quotactl_ops___12;

struct super_block___13 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___12 *s_type;
	const struct super_operations___12 *s_op;
	const struct dquot_operations___12 *dq_op;
	const struct quotactl_ops___12 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___13 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___12 s_dquot;
	struct sb_writers___12 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___12 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___12 {
	struct dentry___13 *mnt_root;
	struct super_block___13 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___7;

struct cgroup_subsys_state___7 {
	struct cgroup___7 *cgroup;
	struct cgroup_subsys___7 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___7 *parent;
};

struct cgroup_file___7 {
	struct kernfs_node___12 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___7 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___14 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___7;

struct cgroup_rstat_cpu___7;

struct cgroup___7 {
	struct cgroup_subsys_state___7 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___12 *kn;
	struct cgroup_file___7 procs_file;
	struct cgroup_file___7 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___7 *subsys[14];
	struct cgroup_root___7 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___7 *dom_cgrp;
	struct cgroup___7 *old_dom_cgrp;
	struct cgroup_rstat_cpu___7 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___7 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___12 {
	struct file___13 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___12 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___13 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___13 *ia_file;
};

struct dquot___12 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___13 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___12 {
	int qf_fmt_id;
	const struct quota_format_ops___12 *qf_ops;
	struct module___14 *qf_owner;
	struct quota_format_type___12 *qf_next;
};

struct quota_format_ops___12 {
	int (*check_quota_file)(struct super_block___13 *, int);
	int (*read_file_info)(struct super_block___13 *, int);
	int (*write_file_info)(struct super_block___13 *, int);
	int (*free_file_info)(struct super_block___13 *, int);
	int (*read_dqblk)(struct dquot___12 *);
	int (*commit_dqblk)(struct dquot___12 *);
	int (*release_dqblk)(struct dquot___12 *);
	int (*get_next_id)(struct super_block___13 *, struct kqid *);
};

struct dquot_operations___12 {
	int (*write_dquot)(struct dquot___12 *);
	struct dquot___12 * (*alloc_dquot)(struct super_block___13 *, int);
	void (*destroy_dquot)(struct dquot___12 *);
	int (*acquire_dquot)(struct dquot___12 *);
	int (*release_dquot)(struct dquot___12 *);
	int (*mark_dirty)(struct dquot___12 *);
	int (*write_info)(struct super_block___13 *, int);
	qsize_t * (*get_reserved_space)(struct inode___14 *);
	int (*get_projid)(struct inode___14 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___14 *, qsize_t *);
	int (*get_next_id)(struct super_block___13 *, struct kqid *);
};

struct quotactl_ops___12 {
	int (*quota_on)(struct super_block___13 *, int, int, const struct path___12 *);
	int (*quota_off)(struct super_block___13 *, int);
	int (*quota_enable)(struct super_block___13 *, unsigned int);
	int (*quota_disable)(struct super_block___13 *, unsigned int);
	int (*quota_sync)(struct super_block___13 *, int);
	int (*set_info)(struct super_block___13 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___13 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___13 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___13 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___13 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___13 *, unsigned int);
};

struct address_space_operations___12 {
	int (*writepage)(struct page___13 *, struct writeback_control___3 *);
	int (*readpage)(struct file___13 *, struct page___13 *);
	int (*writepages)(struct address_space___12 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___13 *);
	int (*readpages)(struct file___13 *, struct address_space___12 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___13 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___13 **, void **);
	int (*write_end)(struct file___13 *, struct address_space___12 *, loff_t, unsigned int, unsigned int, struct page___13 *, void *);
	sector_t (*bmap)(struct address_space___12 *, sector_t);
	void (*invalidatepage)(struct page___13 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___13 *, gfp_t);
	void (*freepage)(struct page___13 *);
	ssize_t (*direct_IO)(struct kiocb___12 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___12 *, struct page___13 *, struct page___13 *, enum migrate_mode);
	bool (*isolate_page)(struct page___13 *, isolate_mode_t);
	void (*putback_page)(struct page___13 *);
	int (*launder_page)(struct page___13 *);
	int (*is_partially_uptodate)(struct page___13 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___13 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___12 *, struct page___13 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___13 *, sector_t *);
	void (*swap_deactivate)(struct file___13 *);
};

struct cdev___6 {
	struct kobject___12 kobj;
	struct module___14 *owner;
	const struct file_operations___12 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___12 {
	struct dentry___13 * (*lookup)(struct inode___14 *, struct dentry___13 *, unsigned int);
	const char * (*get_link)(struct dentry___13 *, struct inode___14 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___14 *, int);
	struct posix_acl * (*get_acl)(struct inode___14 *, int, bool);
	int (*readlink)(struct dentry___13 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___14 *, struct dentry___13 *, umode_t, bool);
	int (*link)(struct dentry___13 *, struct inode___14 *, struct dentry___13 *);
	int (*unlink)(struct inode___14 *, struct dentry___13 *);
	int (*symlink)(struct user_namespace *, struct inode___14 *, struct dentry___13 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___14 *, struct dentry___13 *, umode_t);
	int (*rmdir)(struct inode___14 *, struct dentry___13 *);
	int (*mknod)(struct user_namespace *, struct inode___14 *, struct dentry___13 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___14 *, struct dentry___13 *, struct inode___14 *, struct dentry___13 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___13 *, struct iattr___13 *);
	int (*getattr)(struct user_namespace *, const struct path___12 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___13 *, char *, size_t);
	int (*fiemap)(struct inode___14 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___14 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___14 *, struct dentry___13 *, struct file___13 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___14 *, struct dentry___13 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___14 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___13 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___13 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___12 {
	void (*fl_copy_lock)(struct file_lock___12 *, struct file_lock___12 *);
	void (*fl_release_private)(struct file_lock___12 *);
};

struct lock_manager_operations___12;

struct file_lock___12 {
	struct file_lock___12 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___13 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___12 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___12 *fl_ops;
	const struct lock_manager_operations___12 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___12 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___12 *);
	int (*lm_grant)(struct file_lock___12 *, int);
	bool (*lm_break)(struct file_lock___12 *);
	int (*lm_change)(struct file_lock___12 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___12 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___12 *);
};

struct fasync_struct___12 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___12 *fa_next;
	struct file___13 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___12 {
	struct inode___14 * (*alloc_inode)(struct super_block___13 *);
	void (*destroy_inode)(struct inode___14 *);
	void (*free_inode)(struct inode___14 *);
	void (*dirty_inode)(struct inode___14 *, int);
	int (*write_inode)(struct inode___14 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___14 *);
	void (*evict_inode)(struct inode___14 *);
	void (*put_super)(struct super_block___13 *);
	int (*sync_fs)(struct super_block___13 *, int);
	int (*freeze_super)(struct super_block___13 *);
	int (*freeze_fs)(struct super_block___13 *);
	int (*thaw_super)(struct super_block___13 *);
	int (*unfreeze_fs)(struct super_block___13 *);
	int (*statfs)(struct dentry___13 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___13 *, int *, char *);
	void (*umount_begin)(struct super_block___13 *);
	int (*show_options)(struct seq_file___14 *, struct dentry___13 *);
	int (*show_devname)(struct seq_file___14 *, struct dentry___13 *);
	int (*show_path)(struct seq_file___14 *, struct dentry___13 *);
	int (*show_stats)(struct seq_file___14 *, struct dentry___13 *);
	ssize_t (*quota_read)(struct super_block___13 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___13 *, int, const char *, size_t, loff_t);
	struct dquot___12 ** (*get_dquots)(struct inode___14 *);
	long int (*nr_cached_objects)(struct super_block___13 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___13 *, struct shrink_control___3 *);
	struct file___13 * (*real_loop)(struct file___13 *);
};

struct kernel_param_ops___12 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___12 *);
	int (*get)(char *, const struct kernel_param___12 *);
	void (*free)(void *);
};

struct kparam_array___12;

struct kernel_param___12 {
	const char *name;
	struct module___14 *mod;
	const struct kernel_param_ops___12 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___12 *arr;
	};
};

struct kparam_array___12 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___12 *ops;
	void *elem;
};

struct module_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___12 *, struct module_kobject___12 *, char *);
	ssize_t (*store)(struct module_attribute___12 *, struct module_kobject___12 *, const char *, size_t);
	void (*setup)(struct module___14 *, const char *);
	int (*test)(struct module___14 *);
	void (*free)(struct module___14 *);
};

struct trace_event_class___7;

struct trace_event_call___7 {
	struct list_head list;
	struct trace_event_class___7 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___7 *, struct perf_event___7 *);
};

enum {
	IRQ_TYPE_NONE = 0,
	IRQ_TYPE_EDGE_RISING = 1,
	IRQ_TYPE_EDGE_FALLING = 2,
	IRQ_TYPE_EDGE_BOTH = 3,
	IRQ_TYPE_LEVEL_HIGH = 4,
	IRQ_TYPE_LEVEL_LOW = 8,
	IRQ_TYPE_LEVEL_MASK = 12,
	IRQ_TYPE_SENSE_MASK = 15,
	IRQ_TYPE_DEFAULT = 15,
	IRQ_TYPE_PROBE = 16,
	IRQ_LEVEL = 256,
	IRQ_PER_CPU = 512,
	IRQ_NOPROBE = 1024,
	IRQ_NOREQUEST = 2048,
	IRQ_NOAUTOEN = 4096,
	IRQ_NO_BALANCING = 8192,
	IRQ_MOVE_PCNTXT = 16384,
	IRQ_NESTED_THREAD = 32768,
	IRQ_NOTHREAD = 65536,
	IRQ_PER_CPU_DEVID = 131072,
	IRQ_IS_POLLED = 262144,
	IRQ_DISABLE_UNLAZY = 524288,
	IRQ_HIDDEN = 1048576,
	IRQ_NO_DEBUG = 2097152,
};

struct arch_msi_msg_addr_lo {
	u32 address_lo;
};

typedef struct arch_msi_msg_addr_lo arch_msi_msg_addr_lo_t;

struct arch_msi_msg_addr_hi {
	u32 address_hi;
};

typedef struct arch_msi_msg_addr_hi arch_msi_msg_addr_hi_t;

struct arch_msi_msg_data {
	u32 data;
};

typedef struct arch_msi_msg_data arch_msi_msg_data_t;

struct msi_msg {
	union {
		u32 address_lo;
		arch_msi_msg_addr_lo_t arch_addr_lo;
	};
	union {
		u32 address_hi;
		arch_msi_msg_addr_hi_t arch_addr_hi;
	};
	union {
		u32 data;
		arch_msi_msg_data_t arch_data;
	};
};

struct platform_msi_priv_data;

struct platform_msi_desc {
	struct platform_msi_priv_data *msi_priv_data;
	u16 msi_index;
};

struct fsl_mc_msi_desc {
	u16 msi_index;
};

struct ti_sci_inta_msi_desc {
	u16 dev_index;
};

struct irq_affinity_desc;

struct msi_desc {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___9 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___4 {
	struct device___9 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___4 *);
	void (*irq_shutdown)(struct irq_data___4 *);
	void (*irq_enable)(struct irq_data___4 *);
	void (*irq_disable)(struct irq_data___4 *);
	void (*irq_ack)(struct irq_data___4 *);
	void (*irq_mask)(struct irq_data___4 *);
	void (*irq_mask_ack)(struct irq_data___4 *);
	void (*irq_unmask)(struct irq_data___4 *);
	void (*irq_eoi)(struct irq_data___4 *);
	int (*irq_set_affinity)(struct irq_data___4 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___4 *);
	int (*irq_set_type)(struct irq_data___4 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___4 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___4 *);
	void (*irq_bus_sync_unlock)(struct irq_data___4 *);
	void (*irq_cpu_online)(struct irq_data___4 *);
	void (*irq_cpu_offline)(struct irq_data___4 *);
	void (*irq_suspend)(struct irq_data___4 *);
	void (*irq_resume)(struct irq_data___4 *);
	void (*irq_pm_shutdown)(struct irq_data___4 *);
	void (*irq_calc_mask)(struct irq_data___4 *);
	void (*irq_print_chip)(struct irq_data___4 *, struct seq_file___14 *);
	int (*irq_request_resources)(struct irq_data___4 *);
	void (*irq_release_resources)(struct irq_data___4 *);
	void (*irq_compose_msi_msg)(struct irq_data___4 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___4 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___4 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___4 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___4 *, void *);
	void (*ipi_send_single)(struct irq_data___4 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___4 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___4 *);
	void (*irq_nmi_teardown)(struct irq_data___4 *);
	long unsigned int flags;
};

struct irqaction___4 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___4 *next;
	irq_handler_t thread_fn;
	struct task_struct___14 *thread;
	struct irqaction___4 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___4 {
	struct irq_chip___4 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___4 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___4 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___4 *);
	void (*resume)(struct irq_chip_generic___4 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___4 *domain;
	struct list_head list;
	struct irq_chip_type___4 chip_types[0];
};

struct irq_affinity_desc {
	struct cpumask mask;
	unsigned int is_managed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___12 {
	void * (*start)(struct seq_file___14 *, loff_t *);
	void (*stop)(struct seq_file___14 *, void *);
	void * (*next)(struct seq_file___14 *, void *, loff_t *);
	int (*show)(struct seq_file___14 *, void *);
};

struct dev_pagemap_ops___12 {
	void (*page_free)(struct page___13 *);
	void (*kill)(struct dev_pagemap___12 *);
	void (*cleanup)(struct dev_pagemap___12 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___12 *);
};

union acpi_subtable_headers {
	struct acpi_subtable_header common;
	struct acpi_hmat_structure hmat;
	struct acpi_prmt_module_header prmt;
};

typedef int (*acpi_tbl_entry_handler)(union acpi_subtable_headers *, const long unsigned int);

struct cgroup_namespace___8 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___7 *root_cset;
};

struct cftype___7;

struct cgroup_subsys___7 {
	struct cgroup_subsys_state___7 * (*css_alloc)(struct cgroup_subsys_state___7 *);
	int (*css_online)(struct cgroup_subsys_state___7 *);
	void (*css_offline)(struct cgroup_subsys_state___7 *);
	void (*css_released)(struct cgroup_subsys_state___7 *);
	void (*css_free)(struct cgroup_subsys_state___7 *);
	void (*css_reset)(struct cgroup_subsys_state___7 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___7 *, int);
	int (*css_extra_stat_show)(struct seq_file___14 *, struct cgroup_subsys_state___7 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___14 *, struct css_set___7 *);
	void (*cancel_fork)(struct task_struct___14 *, struct css_set___7 *);
	void (*fork)(struct task_struct___14 *);
	void (*exit)(struct task_struct___14 *);
	void (*release)(struct task_struct___14 *);
	void (*bind)(struct cgroup_subsys_state___7 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___7 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___7 *dfl_cftypes;
	struct cftype___7 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___7 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___7 *updated_children;
	struct cgroup___7 *updated_next;
};

struct cgroup_root___7 {
	struct kernfs_root___12 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___7 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___7 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___7 *ss;
	struct list_head node;
	struct kernfs_ops___12 *kf_ops;
	int (*open)(struct kernfs_open_file___12 *);
	void (*release)(struct kernfs_open_file___12 *);
	u64 (*read_u64)(struct cgroup_subsys_state___7 *, struct cftype___7 *);
	s64 (*read_s64)(struct cgroup_subsys_state___7 *, struct cftype___7 *);
	int (*seq_show)(struct seq_file___14 *, void *);
	void * (*seq_start)(struct seq_file___14 *, loff_t *);
	void * (*seq_next)(struct seq_file___14 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___14 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___7 *, struct cftype___7 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___7 *, struct cftype___7 *, s64);
	ssize_t (*write)(struct kernfs_open_file___12 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___12 *, struct poll_table_struct___9 *);
};

struct perf_cpu_context___7;

struct perf_output_handle___7;

struct pmu___7 {
	struct list_head entry;
	struct module___14 *module;
	struct device___9 *dev;
	const struct attribute_group___12 **attr_groups;
	const struct attribute_group___12 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___7 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___7 *);
	void (*pmu_disable)(struct pmu___7 *);
	int (*event_init)(struct perf_event___7 *);
	void (*event_mapped)(struct perf_event___7 *, struct mm_struct___13 *);
	void (*event_unmapped)(struct perf_event___7 *, struct mm_struct___13 *);
	int (*add)(struct perf_event___7 *, int);
	void (*del)(struct perf_event___7 *, int);
	void (*start)(struct perf_event___7 *, int);
	void (*stop)(struct perf_event___7 *, int);
	void (*read)(struct perf_event___7 *);
	void (*start_txn)(struct pmu___7 *, unsigned int);
	int (*commit_txn)(struct pmu___7 *);
	void (*cancel_txn)(struct pmu___7 *);
	int (*event_idx)(struct perf_event___7 *);
	void (*sched_task)(struct perf_event_context___7 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___7 *, struct perf_event_context___7 *);
	void * (*setup_aux)(struct perf_event___7 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___7 *, struct perf_output_handle___7 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___7 *);
	int (*aux_output_match)(struct perf_event___7 *);
	int (*filter_match)(struct perf_event___7 *);
	int (*check_period)(struct perf_event___7 *, u64);
};

struct perf_cpu_context___7 {
	struct perf_event_context___7 ctx;
	struct perf_event_context___7 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___7 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___7 **heap;
	struct perf_event___7 *heap_default[2];
};

struct perf_output_handle___7 {
	struct perf_event___7 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___7 {
	struct cgroup_subsys_state___7 css;
	struct perf_cgroup_info *info;
};

enum kvm_bus {
	KVM_MMIO_BUS = 0,
	KVM_PIO_BUS = 1,
	KVM_VIRTIO_CCW_NOTIFY_BUS = 2,
	KVM_FAST_MMIO_BUS = 3,
	KVM_NR_BUSES = 4,
};

struct trace_event_fields___7 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___7 *);
	};
};

struct trace_event_class___7 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___7 *, enum trace_reg, void *);
	struct trace_event_fields___7 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___7 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___7 *);
};

struct trace_event_file___3;

struct trace_event_buffer___3 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___3 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___3 {
	struct list_head list;
	struct trace_event_call___7 *event_call;
	struct event_filter *filter;
	struct dentry___13 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_ipi_raise {
	struct trace_entry ent;
	u32 __data_loc_target_cpus;
	const char *reason;
	char __data[0];
};

struct trace_event_raw_ipi_handler {
	struct trace_entry ent;
	const char *reason;
	char __data[0];
};

struct trace_event_data_offsets_ipi_raise {
	u32 target_cpus;
};

struct trace_event_data_offsets_ipi_handler {};

typedef void (*btf_trace_ipi_raise)(void *, const struct cpumask *, const char *);

typedef void (*btf_trace_ipi_entry)(void *, const char *);

typedef void (*btf_trace_ipi_exit)(void *, const char *);

enum ipi_msg_type {
	IPI_RESCHEDULE = 0,
	IPI_CALL_FUNC = 1,
	IPI_CPU_STOP = 2,
	IPI_CPU_CRASH_STOP = 3,
	IPI_TIMER = 4,
	IPI_IRQ_WORK = 5,
	IPI_WAKEUP = 6,
	NR_IPI = 7,
};

typedef __u64 __le64;

struct property___5 {
	char *name;
	int length;
	void *value;
	struct property___5 *next;
	long unsigned int _flags;
	struct bin_attribute___6 attr;
};

struct device_node___5 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___9 fwnode;
	struct property___5 *properties;
	struct property___5 *deadprops;
	struct device_node___5 *parent;
	struct device_node___5 *child;
	struct device_node___5 *sibling;
	struct kobject___6 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___5;

typedef void (*irq_flow_handler_t___5)(struct irq_desc___5 *);

struct irq_chip___5;

struct irq_domain___5;

struct irq_data___5 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___5 *chip;
	struct irq_domain___5 *domain;
	struct irq_data___5 *parent_data;
	void *chip_data;
};

struct irq_desc___5 {
	struct irq_common_data irq_common_data;
	struct irq_data___5 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___5 handle_irq;
	struct irqaction___4 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___12 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___14 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum scale_freq_source {
	SCALE_FREQ_SOURCE_CPUFREQ = 0,
	SCALE_FREQ_SOURCE_ARCH = 1,
	SCALE_FREQ_SOURCE_CPPC = 2,
};

struct scale_freq_data {
	enum scale_freq_source source;
	void (*set_freq_scale)();
};

struct cpu_topology {
	int thread_id;
	int core_id;
	int package_id;
	int llc_id;
	cpumask_t thread_sibling;
	cpumask_t core_sibling;
	cpumask_t llc_sibling;
};

struct fwnode_operations___10;

struct device___10;

struct fwnode_handle___10 {
	struct fwnode_handle___10 *secondary;
	const struct fwnode_operations___10 *ops;
	struct device___10 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___10;

struct fwnode_endpoint___10;

struct fwnode_operations___10 {
	struct fwnode_handle___10 * (*get)(struct fwnode_handle___10 *);
	void (*put)(struct fwnode_handle___10 *);
	bool (*device_is_available)(const struct fwnode_handle___10 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___10 *, const struct device___10 *);
	bool (*property_present)(const struct fwnode_handle___10 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___10 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___10 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___10 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_parent)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_next_child_node)(const struct fwnode_handle___10 *, struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*get_named_child_node)(const struct fwnode_handle___10 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___10 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___10 *);
	struct fwnode_handle___10 * (*graph_get_next_endpoint)(const struct fwnode_handle___10 *, struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*graph_get_remote_endpoint)(const struct fwnode_handle___10 *);
	struct fwnode_handle___10 * (*graph_get_port_parent)(struct fwnode_handle___10 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___10 *, struct fwnode_endpoint___10 *);
	int (*add_links)(struct fwnode_handle___10 *);
};

struct wakeup_source___10;

struct dev_pm_qos___2;

struct dev_pm_info___10 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___10 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___10 *, s32);
	struct dev_pm_qos___2 *qos;
};

struct device_type___10;

struct bus_type___10;

struct device_driver___10;

struct dev_pm_domain___10;

struct device_node___6;

struct class___10;

struct device___10 {
	struct kobject___12 kobj;
	struct device___10 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___10 *type;
	struct bus_type___10 *bus;
	struct device_driver___10 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___10 power;
	struct dev_pm_domain___10 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___5 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___6 *of_node;
	struct fwnode_handle___10 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___10 *class;
	const struct attribute_group___12 **groups;
	void (*release)(struct device___10 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___10 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___10 *local_fwnode;
};

struct fwnode_reference_args___10 {
	struct fwnode_handle___10 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___6 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___10 fwnode;
	struct property___4 *properties;
	struct property___4 *deadprops;
	struct device_node___6 *parent;
	struct device_node___6 *child;
	struct device_node___6 *sibling;
	struct kobject___12 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___5 {
	struct fwnode_handle___10 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___5 {
	int (*match)(struct irq_domain___5 *, struct device_node___6 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___5 *, struct irq_fwspec___5 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___5 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___5 *, unsigned int);
	int (*xlate)(struct irq_domain___5 *, struct device_node___6 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___5 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___5 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___5 *, struct irq_data___5 *, bool);
	void (*deactivate)(struct irq_domain___5 *, struct irq_data___5 *);
	int (*translate)(struct irq_domain___5 *, struct irq_fwspec___5 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___5;

struct irq_domain___5 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___5 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___10 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___5 *gc;
	struct irq_domain___5 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___5 *revmap[0];
};

struct irq_chip_generic___5;

struct irq_domain_chip_generic___5 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___5 *gc[0];
};

struct dev_pm_ops___10 {
	int (*prepare)(struct device___10 *);
	void (*complete)(struct device___10 *);
	int (*suspend)(struct device___10 *);
	int (*resume)(struct device___10 *);
	int (*freeze)(struct device___10 *);
	int (*thaw)(struct device___10 *);
	int (*poweroff)(struct device___10 *);
	int (*restore)(struct device___10 *);
	int (*suspend_late)(struct device___10 *);
	int (*resume_early)(struct device___10 *);
	int (*freeze_late)(struct device___10 *);
	int (*thaw_early)(struct device___10 *);
	int (*poweroff_late)(struct device___10 *);
	int (*restore_early)(struct device___10 *);
	int (*suspend_noirq)(struct device___10 *);
	int (*resume_noirq)(struct device___10 *);
	int (*freeze_noirq)(struct device___10 *);
	int (*thaw_noirq)(struct device___10 *);
	int (*poweroff_noirq)(struct device___10 *);
	int (*restore_noirq)(struct device___10 *);
	int (*runtime_suspend)(struct device___10 *);
	int (*runtime_resume)(struct device___10 *);
	int (*runtime_idle)(struct device___10 *);
};

struct wakeup_source___10 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___10 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___2;

struct dev_pm_qos___2 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___2 *resume_latency_req;
	struct dev_pm_qos_request___2 *latency_tolerance_req;
	struct dev_pm_qos_request___2 *flags_req;
};

struct dev_pm_domain___10 {
	struct dev_pm_ops___10 ops;
	int (*start)(struct device___10 *);
	void (*detach)(struct device___10 *, bool);
	int (*activate)(struct device___10 *);
	void (*sync)(struct device___10 *);
	void (*dismiss)(struct device___10 *);
};

struct bus_type___10 {
	const char *name;
	const char *dev_name;
	struct device___10 *dev_root;
	const struct attribute_group___12 **bus_groups;
	const struct attribute_group___12 **dev_groups;
	const struct attribute_group___12 **drv_groups;
	int (*match)(struct device___10 *, struct device_driver___10 *);
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	int (*probe)(struct device___10 *);
	void (*sync_state)(struct device___10 *);
	void (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*online)(struct device___10 *);
	int (*offline)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	int (*num_vf)(struct device___10 *);
	int (*dma_configure)(struct device___10 *);
	const struct dev_pm_ops___10 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___10 {
	const char *name;
	struct bus_type___10 *bus;
	struct module___14 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___10 *);
	void (*sync_state)(struct device___10 *);
	int (*remove)(struct device___10 *);
	void (*shutdown)(struct device___10 *);
	int (*suspend)(struct device___10 *, pm_message_t);
	int (*resume)(struct device___10 *);
	const struct attribute_group___12 **groups;
	const struct attribute_group___12 **dev_groups;
	const struct dev_pm_ops___10 *pm;
	void (*coredump)(struct device___10 *);
	struct driver_private *p;
};

struct device_type___10 {
	const char *name;
	const struct attribute_group___12 **groups;
	int (*uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___10 *);
	const struct dev_pm_ops___10 *pm;
};

struct class___10 {
	const char *name;
	struct module___14 *owner;
	const struct attribute_group___12 **class_groups;
	const struct attribute_group___12 **dev_groups;
	struct kobject___12 *dev_kobj;
	int (*dev_uevent)(struct device___10 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___10 *, umode_t *);
	void (*class_release)(struct class___10 *);
	void (*dev_release)(struct device___10 *);
	int (*shutdown_pre)(struct device___10 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___10 *);
	void (*get_ownership)(struct device___10 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___10 *pm;
	struct subsys_private *p;
};

struct irq_chip___5 {
	struct device___10 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___5 *);
	void (*irq_shutdown)(struct irq_data___5 *);
	void (*irq_enable)(struct irq_data___5 *);
	void (*irq_disable)(struct irq_data___5 *);
	void (*irq_ack)(struct irq_data___5 *);
	void (*irq_mask)(struct irq_data___5 *);
	void (*irq_mask_ack)(struct irq_data___5 *);
	void (*irq_unmask)(struct irq_data___5 *);
	void (*irq_eoi)(struct irq_data___5 *);
	int (*irq_set_affinity)(struct irq_data___5 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___5 *);
	int (*irq_set_type)(struct irq_data___5 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___5 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___5 *);
	void (*irq_bus_sync_unlock)(struct irq_data___5 *);
	void (*irq_cpu_online)(struct irq_data___5 *);
	void (*irq_cpu_offline)(struct irq_data___5 *);
	void (*irq_suspend)(struct irq_data___5 *);
	void (*irq_resume)(struct irq_data___5 *);
	void (*irq_pm_shutdown)(struct irq_data___5 *);
	void (*irq_calc_mask)(struct irq_data___5 *);
	void (*irq_print_chip)(struct irq_data___5 *, struct seq_file___14 *);
	int (*irq_request_resources)(struct irq_data___5 *);
	void (*irq_release_resources)(struct irq_data___5 *);
	void (*irq_compose_msi_msg)(struct irq_data___5 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___5 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___5 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___5 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___5 *, void *);
	void (*ipi_send_single)(struct irq_data___5 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___5 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___5 *);
	void (*irq_nmi_teardown)(struct irq_data___5 *);
	long unsigned int flags;
};

struct irq_chip_type___5 {
	struct irq_chip___5 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___5 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___5 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___5 *);
	void (*resume)(struct irq_chip_generic___5 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___5 *domain;
	struct list_head list;
	struct irq_chip_type___5 chip_types[0];
};

struct dev_pm_qos_request___2 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___10 *dev;
};

enum cpufreq_table_sorting {
	CPUFREQ_TABLE_UNSORTED = 0,
	CPUFREQ_TABLE_SORTED_ASCENDING = 1,
	CPUFREQ_TABLE_SORTED_DESCENDING = 2,
};

struct cpufreq_cpuinfo {
	unsigned int max_freq;
	unsigned int min_freq;
	unsigned int transition_latency;
};

struct clk;

struct cpufreq_governor;

struct cpufreq_frequency_table;

struct cpufreq_stats;

struct thermal_cooling_device;

struct cpufreq_policy {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___12 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___14 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor {
	char name[16];
	int (*init)(struct cpufreq_policy *);
	void (*exit)(struct cpufreq_policy *);
	int (*start)(struct cpufreq_policy *);
	void (*stop)(struct cpufreq_policy *);
	void (*limits)(struct cpufreq_policy *);
	ssize_t (*show_setspeed)(struct cpufreq_policy *, char *);
	int (*store_setspeed)(struct cpufreq_policy *, unsigned int);
	struct list_head governor_list;
	struct module___14 *owner;
	u8 flags;
};

struct cpufreq_frequency_table {
	unsigned int flags;
	unsigned int driver_data;
	unsigned int frequency;
};

struct thermal_cooling_device_ops;

struct thermal_cooling_device {
	int id;
	char *type;
	struct device___10 device;
	struct device_node___6 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops {
	int (*get_max_state)(struct thermal_cooling_device *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device *, u32 *);
	int (*state2power)(struct thermal_cooling_device *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device *, u32, long unsigned int *);
};

struct cpc_reg {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

enum arm_smccc_conduit {
	SMCCC_CONDUIT_NONE = 0,
	SMCCC_CONDUIT_SMC = 1,
	SMCCC_CONDUIT_HVC = 2,
};

struct arm_smccc_res {
	long unsigned int a0;
	long unsigned int a1;
	long unsigned int a2;
	long unsigned int a3;
};

enum aarch64_insn_register {
	AARCH64_INSN_REG_0 = 0,
	AARCH64_INSN_REG_1 = 1,
	AARCH64_INSN_REG_2 = 2,
	AARCH64_INSN_REG_3 = 3,
	AARCH64_INSN_REG_4 = 4,
	AARCH64_INSN_REG_5 = 5,
	AARCH64_INSN_REG_6 = 6,
	AARCH64_INSN_REG_7 = 7,
	AARCH64_INSN_REG_8 = 8,
	AARCH64_INSN_REG_9 = 9,
	AARCH64_INSN_REG_10 = 10,
	AARCH64_INSN_REG_11 = 11,
	AARCH64_INSN_REG_12 = 12,
	AARCH64_INSN_REG_13 = 13,
	AARCH64_INSN_REG_14 = 14,
	AARCH64_INSN_REG_15 = 15,
	AARCH64_INSN_REG_16 = 16,
	AARCH64_INSN_REG_17 = 17,
	AARCH64_INSN_REG_18 = 18,
	AARCH64_INSN_REG_19 = 19,
	AARCH64_INSN_REG_20 = 20,
	AARCH64_INSN_REG_21 = 21,
	AARCH64_INSN_REG_22 = 22,
	AARCH64_INSN_REG_23 = 23,
	AARCH64_INSN_REG_24 = 24,
	AARCH64_INSN_REG_25 = 25,
	AARCH64_INSN_REG_26 = 26,
	AARCH64_INSN_REG_27 = 27,
	AARCH64_INSN_REG_28 = 28,
	AARCH64_INSN_REG_29 = 29,
	AARCH64_INSN_REG_FP = 29,
	AARCH64_INSN_REG_30 = 30,
	AARCH64_INSN_REG_LR = 30,
	AARCH64_INSN_REG_ZR = 31,
	AARCH64_INSN_REG_SP = 31,
};

enum aarch64_insn_variant {
	AARCH64_INSN_VARIANT_32BIT = 0,
	AARCH64_INSN_VARIANT_64BIT = 1,
};

enum aarch64_insn_movewide_type {
	AARCH64_INSN_MOVEWIDE_ZERO = 0,
	AARCH64_INSN_MOVEWIDE_KEEP = 1,
	AARCH64_INSN_MOVEWIDE_INVERSE = 2,
};

enum aarch64_insn_logic_type {
	AARCH64_INSN_LOGIC_AND = 0,
	AARCH64_INSN_LOGIC_BIC = 1,
	AARCH64_INSN_LOGIC_ORR = 2,
	AARCH64_INSN_LOGIC_ORN = 3,
	AARCH64_INSN_LOGIC_EOR = 4,
	AARCH64_INSN_LOGIC_EON = 5,
	AARCH64_INSN_LOGIC_AND_SETFLAGS = 6,
	AARCH64_INSN_LOGIC_BIC_SETFLAGS = 7,
};

enum spectre_v4_policy {
	SPECTRE_V4_POLICY_MITIGATION_DYNAMIC = 0,
	SPECTRE_V4_POLICY_MITIGATION_ENABLED = 1,
	SPECTRE_V4_POLICY_MITIGATION_DISABLED = 2,
};

struct spectre_v4_param {
	const char *str;
	enum spectre_v4_policy policy;
};

enum bhb_mitigation_bits {
	BHB_LOOP = 0,
	BHB_FW = 1,
	BHB_HW = 2,
	BHB_INSN = 3,
};

struct ftr_set_desc {
	char name[20];
	struct arm64_ftr_override *override;
	struct {
		char name[10];
		u8 shift;
		bool (*filter)(u64);
	} fields[0];
};

struct jump_entry___3 {
	s32 code;
	s32 target;
	long int key;
};

struct static_key___3 {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry___3 *entries;
		struct static_key_mod *next;
	};
};

struct static_key_false___3 {
	struct static_key___3 key;
	long: 64;
	long: 64;
};

struct arm_cpuidle_irq_context {
	long unsigned int pmr;
	long unsigned int daif_bits;
};

struct aarch64_insn_patch {
	void **text_addrs;
	u32 *new_insns;
	int insn_cnt;
	atomic_t cpu_count;
};

typedef u32 compat_size_t;

typedef long int (*syscall_fn_t___2)(const struct pt_regs___2 *);

struct compat_statfs64;

typedef s32 compat_clock_t;

typedef s32 compat_pid_t;

typedef s32 compat_timer_t;

typedef s32 compat_int_t;

typedef u32 __compat_uid32_t;

typedef u64 compat_u64;

typedef u32 compat_sigset_word;

struct compat_sigaltstack {
	compat_uptr_t ss_sp;
	int ss_flags;
	compat_size_t ss_size;
};

typedef struct compat_sigaltstack compat_stack_t;

typedef struct {
	compat_sigset_word sig[2];
} compat_sigset_t;

union compat_sigval {
	compat_int_t sival_int;
	compat_uptr_t sival_ptr;
};

typedef union compat_sigval compat_sigval_t;

struct compat_siginfo {
	int si_signo;
	int si_errno;
	int si_code;
	union {
		int _pad[29];
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
		} _kill;
		struct {
			compat_timer_t _tid;
			int _overrun;
			compat_sigval_t _sigval;
		} _timer;
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
			compat_sigval_t _sigval;
		} _rt;
		struct {
			compat_pid_t _pid;
			__compat_uid32_t _uid;
			int _status;
			compat_clock_t _utime;
			compat_clock_t _stime;
		} _sigchld;
		struct {
			compat_uptr_t _addr;
			union {
				int _trapno;
				short int _addr_lsb;
				struct {
					char _dummy_bnd[4];
					compat_uptr_t _lower;
					compat_uptr_t _upper;
				} _addr_bnd;
				struct {
					char _dummy_pkey[4];
					u32 _pkey;
				} _addr_pkey;
				struct {
					compat_ulong_t _data;
					u32 _type;
				} _perf;
			};
		} _sigfault;
		struct {
			compat_long_t _band;
			int _fd;
		} _sigpoll;
		struct {
			compat_uptr_t _call_addr;
			int _syscall;
			unsigned int _arch;
		} _sigsys;
	} _sifields;
};

struct compat_sigcontext {
	compat_ulong_t trap_no;
	compat_ulong_t error_code;
	compat_ulong_t oldmask;
	compat_ulong_t arm_r0;
	compat_ulong_t arm_r1;
	compat_ulong_t arm_r2;
	compat_ulong_t arm_r3;
	compat_ulong_t arm_r4;
	compat_ulong_t arm_r5;
	compat_ulong_t arm_r6;
	compat_ulong_t arm_r7;
	compat_ulong_t arm_r8;
	compat_ulong_t arm_r9;
	compat_ulong_t arm_r10;
	compat_ulong_t arm_fp;
	compat_ulong_t arm_ip;
	compat_ulong_t arm_sp;
	compat_ulong_t arm_lr;
	compat_ulong_t arm_pc;
	compat_ulong_t arm_cpsr;
	compat_ulong_t fault_address;
};

struct compat_ucontext {
	compat_ulong_t uc_flags;
	compat_uptr_t uc_link;
	compat_stack_t uc_stack;
	struct compat_sigcontext uc_mcontext;
	compat_sigset_t uc_sigmask;
	int __unused[30];
	compat_ulong_t uc_regspace[128];
};

struct compat_sigframe {
	struct compat_ucontext uc;
	compat_ulong_t retcode[2];
};

struct compat_rt_sigframe {
	struct compat_siginfo info;
	struct compat_sigframe sig;
};

struct compat_user_vfp {
	compat_u64 fpregs[32];
	compat_ulong_t fpscr;
};

struct compat_user_vfp_exc {
	compat_ulong_t fpexc;
	compat_ulong_t fpinst;
	compat_ulong_t fpinst2;
};

struct compat_vfp_sigframe {
	compat_ulong_t magic;
	compat_ulong_t size;
	struct compat_user_vfp ufp;
	struct compat_user_vfp_exc ufp_exc;
};

struct compat_aux_sigframe {
	struct compat_vfp_sigframe vfp;
	long unsigned int end_magic;
};

union __fpsimd_vreg {
	__int128 unsigned raw;
	struct {
		u64 lo;
		u64 hi;
	};
};

enum aarch64_insn_branch_type {
	AARCH64_INSN_BRANCH_NOLINK = 0,
	AARCH64_INSN_BRANCH_LINK = 1,
	AARCH64_INSN_BRANCH_RETURN = 2,
	AARCH64_INSN_BRANCH_COMP_ZERO = 3,
	AARCH64_INSN_BRANCH_COMP_NONZERO = 4,
};

struct dyn_arch_ftrace {};

struct dyn_ftrace {
	long unsigned int ip;
	long unsigned int flags;
	struct dyn_arch_ftrace arch;
};

enum {
	FTRACE_UPDATE_CALLS = 1,
	FTRACE_DISABLE_CALLS = 2,
	FTRACE_UPDATE_TRACE_FUNC = 4,
	FTRACE_START_FUNC_RET = 8,
	FTRACE_STOP_FUNC_RET = 16,
	FTRACE_MAY_SLEEP = 32,
};

typedef __u64 Elf64_Off;

typedef __s64 Elf64_Sxword;

struct elf64_rela {
	Elf64_Addr r_offset;
	Elf64_Xword r_info;
	Elf64_Sxword r_addend;
};

typedef struct elf64_rela Elf64_Rela;

struct elf64_hdr {
	unsigned char e_ident[16];
	Elf64_Half e_type;
	Elf64_Half e_machine;
	Elf64_Word e_version;
	Elf64_Addr e_entry;
	Elf64_Off e_phoff;
	Elf64_Off e_shoff;
	Elf64_Word e_flags;
	Elf64_Half e_ehsize;
	Elf64_Half e_phentsize;
	Elf64_Half e_phnum;
	Elf64_Half e_shentsize;
	Elf64_Half e_shnum;
	Elf64_Half e_shstrndx;
};

typedef struct elf64_hdr Elf64_Ehdr;

struct elf64_shdr {
	Elf64_Word sh_name;
	Elf64_Word sh_type;
	Elf64_Xword sh_flags;
	Elf64_Addr sh_addr;
	Elf64_Off sh_offset;
	Elf64_Xword sh_size;
	Elf64_Word sh_link;
	Elf64_Word sh_info;
	Elf64_Xword sh_addralign;
	Elf64_Xword sh_entsize;
};

typedef struct elf64_shdr Elf64_Shdr;

enum aarch64_reloc_op {
	RELOC_OP_NONE = 0,
	RELOC_OP_ABS = 1,
	RELOC_OP_PREL = 2,
	RELOC_OP_PAGE = 3,
};

enum aarch64_insn_movw_imm_type {
	AARCH64_INSN_IMM_MOVNZ = 0,
	AARCH64_INSN_IMM_MOVKZ = 1,
};

typedef void (*swap_func_t)(void *, void *, int);

enum aarch64_insn_adsb_type {
	AARCH64_INSN_ADSB_ADD = 0,
	AARCH64_INSN_ADSB_SUB = 1,
	AARCH64_INSN_ADSB_ADD_SETFLAGS = 2,
	AARCH64_INSN_ADSB_SUB_SETFLAGS = 3,
};

enum aarch64_insn_adr_type {
	AARCH64_INSN_ADR_TYPE_ADRP = 0,
	AARCH64_INSN_ADR_TYPE_ADR = 1,
};

enum perf_sample_regs_abi {
	PERF_SAMPLE_REGS_ABI_NONE = 0,
	PERF_SAMPLE_REGS_ABI_32 = 1,
	PERF_SAMPLE_REGS_ABI_64 = 2,
};

enum perf_event_arm_regs {
	PERF_REG_ARM64_X0 = 0,
	PERF_REG_ARM64_X1 = 1,
	PERF_REG_ARM64_X2 = 2,
	PERF_REG_ARM64_X3 = 3,
	PERF_REG_ARM64_X4 = 4,
	PERF_REG_ARM64_X5 = 5,
	PERF_REG_ARM64_X6 = 6,
	PERF_REG_ARM64_X7 = 7,
	PERF_REG_ARM64_X8 = 8,
	PERF_REG_ARM64_X9 = 9,
	PERF_REG_ARM64_X10 = 10,
	PERF_REG_ARM64_X11 = 11,
	PERF_REG_ARM64_X12 = 12,
	PERF_REG_ARM64_X13 = 13,
	PERF_REG_ARM64_X14 = 14,
	PERF_REG_ARM64_X15 = 15,
	PERF_REG_ARM64_X16 = 16,
	PERF_REG_ARM64_X17 = 17,
	PERF_REG_ARM64_X18 = 18,
	PERF_REG_ARM64_X19 = 19,
	PERF_REG_ARM64_X20 = 20,
	PERF_REG_ARM64_X21 = 21,
	PERF_REG_ARM64_X22 = 22,
	PERF_REG_ARM64_X23 = 23,
	PERF_REG_ARM64_X24 = 24,
	PERF_REG_ARM64_X25 = 25,
	PERF_REG_ARM64_X26 = 26,
	PERF_REG_ARM64_X27 = 27,
	PERF_REG_ARM64_X28 = 28,
	PERF_REG_ARM64_X29 = 29,
	PERF_REG_ARM64_LR = 30,
	PERF_REG_ARM64_SP = 31,
	PERF_REG_ARM64_PC = 32,
	PERF_REG_ARM64_MAX = 33,
};

struct perf_guest_info_callbacks {
	int (*is_in_guest)();
	int (*is_user_mode)();
	long unsigned int (*get_guest_ip)();
	void (*handle_intel_pt_intr)();
};

struct perf_callchain_entry_ctx {
	struct perf_callchain_entry *entry;
	u32 max_stack;
	u32 nr;
	short int contexts;
	bool contexts_maxed;
};

struct frame_tail {
	struct frame_tail *fp;
	long unsigned int lr;
};

struct compat_frame_tail {
	compat_uptr_t fp;
	u32 sp;
	u32 lr;
};

struct dentry___14;

struct super_block___14;

struct module___15;

struct file_system_type___13 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___14 * (*mount)(struct file_system_type___13 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___14 *);
	struct module___15 *owner;
	struct file_system_type___13 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___14;

struct kiocb___13;

struct poll_table_struct___10;

struct vm_area_struct___13;

struct inode___15;

struct file_lock___13;

struct page___14;

struct seq_file___15;

struct file_operations___13 {
	struct module___15 *owner;
	loff_t (*llseek)(struct file___14 *, loff_t, int);
	ssize_t (*read)(struct file___14 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___14 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___13 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___13 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___13 *, bool);
	int (*iterate)(struct file___14 *, struct dir_context *);
	int (*iterate_shared)(struct file___14 *, struct dir_context *);
	__poll_t (*poll)(struct file___14 *, struct poll_table_struct___10 *);
	long int (*unlocked_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___14 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___14 *, struct vm_area_struct___13 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___15 *, struct file___14 *);
	int (*flush)(struct file___14 *, fl_owner_t);
	int (*release)(struct inode___15 *, struct file___14 *);
	int (*fsync)(struct file___14 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___14 *, int);
	int (*lock)(struct file___14 *, int, struct file_lock___13 *);
	ssize_t (*sendpage)(struct file___14 *, struct page___14 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___14 *, long unsigned int);
	int (*flock)(struct file___14 *, int, struct file_lock___13 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___14 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___14 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___14 *, long int, struct file_lock___13 **, void **);
	long int (*fallocate)(struct file___14 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___15 *, struct file___14 *);
	ssize_t (*copy_file_range)(struct file___14 *, loff_t, struct file___14 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___14 *, loff_t, struct file___14 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___14 *, loff_t, loff_t, int);
};

struct vmacache___13 {
	u64 seqnum;
	struct vm_area_struct___13 *vmas[4];
};

struct page_frag___13 {
	struct page___14 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___8;

struct debug_info___8 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___8 *hbp_break[16];
	struct perf_event___8 *hbp_watch[16];
};

struct thread_struct___8 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___8 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___14;

struct pid___12;

struct nsproxy___13;

struct signal_struct___14;

struct css_set___8;

struct perf_event_context___8;

struct vm_struct___13;

struct task_struct___15 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___15 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___14 *mm;
	struct mm_struct___14 *active_mm;
	struct vmacache___13 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___15 *real_parent;
	struct task_struct___15 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___15 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___12 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___13 *nsproxy;
	struct signal_struct___14 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___15 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___8 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___8 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___13 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___15 *oom_reaper_list;
	struct vm_struct___13 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___8 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___6;

typedef void (*irq_flow_handler_t___6)(struct irq_desc___6 *);

struct msi_desc___2;

struct irq_common_data___2 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___2 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___6;

struct irq_domain___6;

struct irq_data___6 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___6 *chip;
	struct irq_domain___6 *domain;
	struct irq_data___6 *parent_data;
	void *chip_data;
};

struct kset___13;

struct kobj_type___13;

struct kernfs_node___13;

struct kobject___13 {
	const char *name;
	struct list_head entry;
	struct kobject___13 *parent;
	struct kset___13 *kset;
	struct kobj_type___13 *ktype;
	struct kernfs_node___13 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___5;

struct irq_desc___6 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___6 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___6 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___13 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___15 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___13 {
	struct kobject___13 kobj;
	struct module___15 *mod;
	struct kobject___13 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___13 {
	struct module___15 *mod;
	struct latch_tree_node node;
};

struct module_layout___13 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___13 mtn;
};

struct module_attribute___13;

struct kernel_param___13;

struct module___15 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___13 mkobj;
	struct module_attribute___13 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___13 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___13 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___13 core_layout;
	struct module_layout___13 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___8 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___15 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___8)(struct perf_event___8 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___8;

struct fasync_struct___13;

struct pid_namespace___12;

struct perf_cgroup___8;

struct perf_event___8 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___8 *group_leader;
	struct pmu___8 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___8 hw;
	struct perf_event_context___8 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___8 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___15 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___13 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___8 *aux_event;
	void (*destroy)(struct perf_event___8 *);
	struct callback_head callback_head;
	struct pid_namespace___12 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___8 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___8 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___8 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___14 *pgtable_t___13;

struct address_space___13;

struct dev_pagemap___13;

struct page___14 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___13 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___14 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___13 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___14 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___13 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___13;

struct vm_area_struct___13 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___13 *vm_next;
	struct vm_area_struct___13 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___14 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___13 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___14 *vm_file;
	struct file___14 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___13;

struct mm_struct___14 {
	struct {
		struct vm_area_struct___13 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___14 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___13 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___15 *owner;
		struct user_namespace *user_ns;
		struct file___14 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___13;

struct address_space___13 {
	struct inode___15 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___13 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___13;

struct dev_pagemap___13 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___13 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___13;

struct path___13 {
	struct vfsmount___13 *mnt;
	struct dentry___14 *dentry;
};

struct fown_struct___12 {
	rwlock_t lock;
	struct pid___12 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___14 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___13 f_path;
	struct inode___15 *f_inode;
	const struct file_operations___13 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___12 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___13 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___13;

struct vm_operations_struct___13 {
	void (*open)(struct vm_area_struct___13 *);
	void (*close)(struct vm_area_struct___13 *);
	int (*may_split)(struct vm_area_struct___13 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___13 *);
	int (*mprotect)(struct vm_area_struct___13 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___13 *);
	vm_fault_t (*huge_fault)(struct vm_fault___13 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___13 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___13 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___13 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___13 *);
	int (*access)(struct vm_area_struct___13 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___13 *);
	int (*set_policy)(struct vm_area_struct___13 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___13 *, long unsigned int);
	struct page___14 * (*find_special_page)(struct vm_area_struct___13 *, long unsigned int);
};

struct core_thread___13 {
	struct task_struct___15 *task;
	struct core_thread___13 *next;
};

struct core_state___13 {
	atomic_t nr_threads;
	struct core_thread___13 dumper;
	struct completion startup;
};

struct vm_fault___13 {
	const struct {
		struct vm_area_struct___13 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___14 *cow_page;
	struct page___14 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___13 prealloc_pte;
};

struct kernfs_root___13;

struct kernfs_elem_dir___13 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___13 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___13;

struct kernfs_root___13 {
	struct kernfs_node___13 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___13 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___13 {
	struct kernfs_node___13 *target_kn;
};

struct kernfs_ops___13;

struct kernfs_elem_attr___13 {
	const struct kernfs_ops___13 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___13 *notify_next;
};

struct kernfs_node___13 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___13 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___13 dir;
		struct kernfs_elem_symlink___13 symlink;
		struct kernfs_elem_attr___13 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___13;

struct kernfs_ops___13 {
	int (*open)(struct kernfs_open_file___13 *);
	void (*release)(struct kernfs_open_file___13 *);
	int (*seq_show)(struct seq_file___15 *, void *);
	void * (*seq_start)(struct seq_file___15 *, loff_t *);
	void * (*seq_next)(struct seq_file___15 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___15 *, void *);
	ssize_t (*read)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___13 *, struct poll_table_struct___10 *);
	int (*mmap)(struct kernfs_open_file___13 *, struct vm_area_struct___13 *);
};

struct kernfs_syscall_ops___13 {
	int (*show_options)(struct seq_file___15 *, struct kernfs_root___13 *);
	int (*mkdir)(struct kernfs_node___13 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___13 *);
	int (*rename)(struct kernfs_node___13 *, struct kernfs_node___13 *, const char *);
	int (*show_path)(struct seq_file___15 *, struct kernfs_node___13 *, struct kernfs_root___13 *);
};

struct seq_operations___13;

struct seq_file___15 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___13 *op;
	int poll_event;
	const struct file___14 *file;
	void *private;
};

struct kernfs_open_file___13 {
	struct kernfs_node___13 *kn;
	struct file___14 *file;
	struct seq_file___15 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___13 *vm_ops;
};

typedef void (*poll_queue_proc___10)(struct file___14 *, wait_queue_head_t *, struct poll_table_struct___10 *);

struct poll_table_struct___10 {
	poll_queue_proc___10 _qproc;
	__poll_t _key;
};

struct upid___12 {
	int nr;
	struct pid_namespace___12 *ns;
};

struct pid_namespace___12 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___15 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___12 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___12 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___12 numbers[1];
};

struct signal_struct___14 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___15 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___15 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___12 *pids[4];
	struct pid___12 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___14 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___13 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___12 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct cgroup_subsys_state___8;

struct cgroup___8;

struct css_set___8 {
	struct cgroup_subsys_state___8 *subsys[14];
	refcount_t refcount;
	struct css_set___8 *dom_cset;
	struct cgroup___8 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___8 *mg_src_cgrp;
	struct cgroup___8 *mg_dst_cgrp;
	struct css_set___8 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___8 {
	struct pmu___8 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___15 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___8 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___13 {
	struct vm_struct___13 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___14 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___13;

struct attribute_group___13 {
	const char *name;
	umode_t (*is_visible)(struct kobject___13 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___13 *, struct bin_attribute___13 *, int);
	struct attribute **attrs;
	struct bin_attribute___13 **bin_attrs;
};

struct bin_attribute___13 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___13 * (*f_mapping)();
	ssize_t (*read)(struct file___14 *, struct kobject___13 *, struct bin_attribute___13 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___14 *, struct kobject___13 *, struct bin_attribute___13 *, char *, loff_t, size_t);
	int (*mmap)(struct file___14 *, struct kobject___13 *, struct bin_attribute___13 *, struct vm_area_struct___13 *);
};

struct sysfs_ops___13 {
	ssize_t (*show)(struct kobject___13 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___13 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___13;

struct kset___13 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___13 kobj;
	const struct kset_uevent_ops___13 *uevent_ops;
};

struct kobj_type___13 {
	void (*release)(struct kobject___13 *);
	const struct sysfs_ops___13 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___13 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___13 *);
	const void * (*namespace)(struct kobject___13 *);
	void (*get_ownership)(struct kobject___13 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___13 {
	int (* const filter)(struct kset___13 *, struct kobject___13 *);
	const char * (* const name)(struct kset___13 *, struct kobject___13 *);
	int (* const uevent)(struct kset___13 *, struct kobject___13 *, struct kobj_uevent_env *);
};

struct platform_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

struct fwnode_operations___11;

struct device___11;

struct fwnode_handle___11 {
	struct fwnode_handle___11 *secondary;
	const struct fwnode_operations___11 *ops;
	struct device___11 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___11;

struct fwnode_endpoint___11;

struct fwnode_operations___11 {
	struct fwnode_handle___11 * (*get)(struct fwnode_handle___11 *);
	void (*put)(struct fwnode_handle___11 *);
	bool (*device_is_available)(const struct fwnode_handle___11 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___11 *, const struct device___11 *);
	bool (*property_present)(const struct fwnode_handle___11 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___11 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___11 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___11 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_parent)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_next_child_node)(const struct fwnode_handle___11 *, struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*get_named_child_node)(const struct fwnode_handle___11 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___11 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___11 *);
	struct fwnode_handle___11 * (*graph_get_next_endpoint)(const struct fwnode_handle___11 *, struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*graph_get_remote_endpoint)(const struct fwnode_handle___11 *);
	struct fwnode_handle___11 * (*graph_get_port_parent)(struct fwnode_handle___11 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___11 *, struct fwnode_endpoint___11 *);
	int (*add_links)(struct fwnode_handle___11 *);
};

struct wakeup_source___11;

struct dev_pm_info___11 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___11 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___11 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___11;

struct bus_type___11;

struct device_driver___11;

struct dev_pm_domain___11;

struct device_node___7;

struct class___11;

struct device___11 {
	struct kobject___13 kobj;
	struct device___11 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___11 *type;
	struct bus_type___11 *bus;
	struct device_driver___11 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___11 power;
	struct dev_pm_domain___11 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___6 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___7 *of_node;
	struct fwnode_handle___11 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___11 *class;
	const struct attribute_group___13 **groups;
	void (*release)(struct device___11 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___11 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___11 *local_fwnode;
};

struct fwnode_reference_args___11 {
	struct fwnode_handle___11 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___6 {
	char *name;
	int length;
	void *value;
	struct property___6 *next;
	long unsigned int _flags;
	struct bin_attribute___13 attr;
};

struct device_node___7 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___11 fwnode;
	struct property___6 *properties;
	struct property___6 *deadprops;
	struct device_node___7 *parent;
	struct device_node___7 *child;
	struct device_node___7 *sibling;
	struct kobject___13 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___6 {
	struct fwnode_handle___11 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___6 {
	int (*match)(struct irq_domain___6 *, struct device_node___7 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___6 *, struct irq_fwspec___6 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___6 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___6 *, unsigned int);
	int (*xlate)(struct irq_domain___6 *, struct device_node___7 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___6 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___6 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___6 *, struct irq_data___6 *, bool);
	void (*deactivate)(struct irq_domain___6 *, struct irq_data___6 *);
	int (*translate)(struct irq_domain___6 *, struct irq_fwspec___6 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___6;

struct irq_domain___6 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___6 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___11 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___6 *gc;
	struct irq_domain___6 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___6 *revmap[0];
};

struct irq_chip_generic___6;

struct irq_domain_chip_generic___6 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___6 *gc[0];
};

struct dev_pm_ops___11 {
	int (*prepare)(struct device___11 *);
	void (*complete)(struct device___11 *);
	int (*suspend)(struct device___11 *);
	int (*resume)(struct device___11 *);
	int (*freeze)(struct device___11 *);
	int (*thaw)(struct device___11 *);
	int (*poweroff)(struct device___11 *);
	int (*restore)(struct device___11 *);
	int (*suspend_late)(struct device___11 *);
	int (*resume_early)(struct device___11 *);
	int (*freeze_late)(struct device___11 *);
	int (*thaw_early)(struct device___11 *);
	int (*poweroff_late)(struct device___11 *);
	int (*restore_early)(struct device___11 *);
	int (*suspend_noirq)(struct device___11 *);
	int (*resume_noirq)(struct device___11 *);
	int (*freeze_noirq)(struct device___11 *);
	int (*thaw_noirq)(struct device___11 *);
	int (*poweroff_noirq)(struct device___11 *);
	int (*restore_noirq)(struct device___11 *);
	int (*runtime_suspend)(struct device___11 *);
	int (*runtime_resume)(struct device___11 *);
	int (*runtime_idle)(struct device___11 *);
};

struct wakeup_source___11 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___11 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___11 {
	struct dev_pm_ops___11 ops;
	int (*start)(struct device___11 *);
	void (*detach)(struct device___11 *, bool);
	int (*activate)(struct device___11 *);
	void (*sync)(struct device___11 *);
	void (*dismiss)(struct device___11 *);
};

struct bus_type___11 {
	const char *name;
	const char *dev_name;
	struct device___11 *dev_root;
	const struct attribute_group___13 **bus_groups;
	const struct attribute_group___13 **dev_groups;
	const struct attribute_group___13 **drv_groups;
	int (*match)(struct device___11 *, struct device_driver___11 *);
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	int (*probe)(struct device___11 *);
	void (*sync_state)(struct device___11 *);
	void (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*online)(struct device___11 *);
	int (*offline)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	int (*num_vf)(struct device___11 *);
	int (*dma_configure)(struct device___11 *);
	const struct dev_pm_ops___11 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___11 {
	const char *name;
	struct bus_type___11 *bus;
	struct module___15 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___11 *);
	void (*sync_state)(struct device___11 *);
	int (*remove)(struct device___11 *);
	void (*shutdown)(struct device___11 *);
	int (*suspend)(struct device___11 *, pm_message_t);
	int (*resume)(struct device___11 *);
	const struct attribute_group___13 **groups;
	const struct attribute_group___13 **dev_groups;
	const struct dev_pm_ops___11 *pm;
	void (*coredump)(struct device___11 *);
	struct driver_private *p;
};

struct device_type___11 {
	const char *name;
	const struct attribute_group___13 **groups;
	int (*uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___11 *);
	const struct dev_pm_ops___11 *pm;
};

struct class___11 {
	const char *name;
	struct module___15 *owner;
	const struct attribute_group___13 **class_groups;
	const struct attribute_group___13 **dev_groups;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___11 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___11 *, umode_t *);
	void (*class_release)(struct class___11 *);
	void (*dev_release)(struct device___11 *);
	int (*shutdown_pre)(struct device___11 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___11 *);
	void (*get_ownership)(struct device___11 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___11 *pm;
	struct subsys_private *p;
};

struct pdev_archdata {};

struct device_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device___11 *, struct device_attribute___2 *, char *);
	ssize_t (*store)(struct device___11 *, struct device_attribute___2 *, const char *, size_t);
};

struct dentry_operations___13;

struct dentry___14 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___14 *d_parent;
	struct qstr d_name;
	struct inode___15 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___13 *d_op;
	struct super_block___14 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___13;

struct cdev___7;

struct inode___15 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___13 *i_op;
	struct super_block___14 *i_sb;
	struct address_space___13 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___13 *i_fop;
		void (*free_inode)(struct inode___15 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___13 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___7 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___13 {
	int (*d_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___14 *, unsigned int);
	int (*d_hash)(const struct dentry___14 *, struct qstr *);
	int (*d_compare)(const struct dentry___14 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___14 *);
	int (*d_init)(struct dentry___14 *);
	void (*d_release)(struct dentry___14 *);
	void (*d_prune)(struct dentry___14 *);
	void (*d_iput)(struct dentry___14 *, struct inode___15 *);
	char * (*d_dname)(struct dentry___14 *, char *, int);
	struct vfsmount___13 * (*d_automount)(struct path___13 *);
	int (*d_manage)(const struct path___13 *, bool);
	struct dentry___14 * (*d_real)(struct dentry___14 *, const struct inode___15 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___13;

struct mem_dqinfo___13 {
	struct quota_format_type___13 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___13;

struct quota_info___13 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___15 *files[3];
	struct mem_dqinfo___13 info[3];
	const struct quota_format_ops___13 *ops[3];
};

struct rcuwait___13 {
	struct task_struct___15 *task;
};

struct percpu_rw_semaphore___13 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___13 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___13 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___13 rw_sem[3];
};

struct super_operations___13;

struct dquot_operations___13;

struct quotactl_ops___13;

struct super_block___14 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___13 *s_type;
	const struct super_operations___13 *s_op;
	const struct dquot_operations___13 *dq_op;
	const struct quotactl_ops___13 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___14 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___13 s_dquot;
	struct sb_writers___13 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___13 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___13 {
	struct dentry___14 *mnt_root;
	struct super_block___14 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___8;

struct cgroup_subsys_state___8 {
	struct cgroup___8 *cgroup;
	struct cgroup_subsys___8 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___8 *parent;
};

struct cgroup_file___8 {
	struct kernfs_node___13 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___8 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___15 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___8;

struct cgroup_rstat_cpu___8;

struct cgroup___8 {
	struct cgroup_subsys_state___8 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___13 *kn;
	struct cgroup_file___8 procs_file;
	struct cgroup_file___8 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___8 *subsys[14];
	struct cgroup_root___8 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___8 *dom_cgrp;
	struct cgroup___8 *old_dom_cgrp;
	struct cgroup_rstat_cpu___8 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___8 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___13 {
	struct file___14 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___13 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___14 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___14 *ia_file;
};

struct dquot___13 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___14 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___13 {
	int qf_fmt_id;
	const struct quota_format_ops___13 *qf_ops;
	struct module___15 *qf_owner;
	struct quota_format_type___13 *qf_next;
};

struct quota_format_ops___13 {
	int (*check_quota_file)(struct super_block___14 *, int);
	int (*read_file_info)(struct super_block___14 *, int);
	int (*write_file_info)(struct super_block___14 *, int);
	int (*free_file_info)(struct super_block___14 *, int);
	int (*read_dqblk)(struct dquot___13 *);
	int (*commit_dqblk)(struct dquot___13 *);
	int (*release_dqblk)(struct dquot___13 *);
	int (*get_next_id)(struct super_block___14 *, struct kqid *);
};

struct dquot_operations___13 {
	int (*write_dquot)(struct dquot___13 *);
	struct dquot___13 * (*alloc_dquot)(struct super_block___14 *, int);
	void (*destroy_dquot)(struct dquot___13 *);
	int (*acquire_dquot)(struct dquot___13 *);
	int (*release_dquot)(struct dquot___13 *);
	int (*mark_dirty)(struct dquot___13 *);
	int (*write_info)(struct super_block___14 *, int);
	qsize_t * (*get_reserved_space)(struct inode___15 *);
	int (*get_projid)(struct inode___15 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___15 *, qsize_t *);
	int (*get_next_id)(struct super_block___14 *, struct kqid *);
};

struct quotactl_ops___13 {
	int (*quota_on)(struct super_block___14 *, int, int, const struct path___13 *);
	int (*quota_off)(struct super_block___14 *, int);
	int (*quota_enable)(struct super_block___14 *, unsigned int);
	int (*quota_disable)(struct super_block___14 *, unsigned int);
	int (*quota_sync)(struct super_block___14 *, int);
	int (*set_info)(struct super_block___14 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___14 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___14 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___14 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___14 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___14 *, unsigned int);
};

struct address_space_operations___13 {
	int (*writepage)(struct page___14 *, struct writeback_control___3 *);
	int (*readpage)(struct file___14 *, struct page___14 *);
	int (*writepages)(struct address_space___13 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___14 *);
	int (*readpages)(struct file___14 *, struct address_space___13 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___14 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___14 **, void **);
	int (*write_end)(struct file___14 *, struct address_space___13 *, loff_t, unsigned int, unsigned int, struct page___14 *, void *);
	sector_t (*bmap)(struct address_space___13 *, sector_t);
	void (*invalidatepage)(struct page___14 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___14 *, gfp_t);
	void (*freepage)(struct page___14 *);
	ssize_t (*direct_IO)(struct kiocb___13 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___13 *, struct page___14 *, struct page___14 *, enum migrate_mode);
	bool (*isolate_page)(struct page___14 *, isolate_mode_t);
	void (*putback_page)(struct page___14 *);
	int (*launder_page)(struct page___14 *);
	int (*is_partially_uptodate)(struct page___14 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___14 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___13 *, struct page___14 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___14 *, sector_t *);
	void (*swap_deactivate)(struct file___14 *);
};

struct cdev___7 {
	struct kobject___13 kobj;
	struct module___15 *owner;
	const struct file_operations___13 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___13 {
	struct dentry___14 * (*lookup)(struct inode___15 *, struct dentry___14 *, unsigned int);
	const char * (*get_link)(struct dentry___14 *, struct inode___15 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___15 *, int);
	struct posix_acl * (*get_acl)(struct inode___15 *, int, bool);
	int (*readlink)(struct dentry___14 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___15 *, struct dentry___14 *, umode_t, bool);
	int (*link)(struct dentry___14 *, struct inode___15 *, struct dentry___14 *);
	int (*unlink)(struct inode___15 *, struct dentry___14 *);
	int (*symlink)(struct user_namespace *, struct inode___15 *, struct dentry___14 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___15 *, struct dentry___14 *, umode_t);
	int (*rmdir)(struct inode___15 *, struct dentry___14 *);
	int (*mknod)(struct user_namespace *, struct inode___15 *, struct dentry___14 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___15 *, struct dentry___14 *, struct inode___15 *, struct dentry___14 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___14 *, struct iattr___14 *);
	int (*getattr)(struct user_namespace *, const struct path___13 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___14 *, char *, size_t);
	int (*fiemap)(struct inode___15 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___15 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___15 *, struct dentry___14 *, struct file___14 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___15 *, struct dentry___14 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___15 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___14 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___14 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___13 {
	void (*fl_copy_lock)(struct file_lock___13 *, struct file_lock___13 *);
	void (*fl_release_private)(struct file_lock___13 *);
};

struct lock_manager_operations___13;

struct file_lock___13 {
	struct file_lock___13 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___14 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___13 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___13 *fl_ops;
	const struct lock_manager_operations___13 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___13 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___13 *);
	int (*lm_grant)(struct file_lock___13 *, int);
	bool (*lm_break)(struct file_lock___13 *);
	int (*lm_change)(struct file_lock___13 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___13 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___13 *);
};

struct fasync_struct___13 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___13 *fa_next;
	struct file___14 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___13 {
	struct inode___15 * (*alloc_inode)(struct super_block___14 *);
	void (*destroy_inode)(struct inode___15 *);
	void (*free_inode)(struct inode___15 *);
	void (*dirty_inode)(struct inode___15 *, int);
	int (*write_inode)(struct inode___15 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___15 *);
	void (*evict_inode)(struct inode___15 *);
	void (*put_super)(struct super_block___14 *);
	int (*sync_fs)(struct super_block___14 *, int);
	int (*freeze_super)(struct super_block___14 *);
	int (*freeze_fs)(struct super_block___14 *);
	int (*thaw_super)(struct super_block___14 *);
	int (*unfreeze_fs)(struct super_block___14 *);
	int (*statfs)(struct dentry___14 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___14 *, int *, char *);
	void (*umount_begin)(struct super_block___14 *);
	int (*show_options)(struct seq_file___15 *, struct dentry___14 *);
	int (*show_devname)(struct seq_file___15 *, struct dentry___14 *);
	int (*show_path)(struct seq_file___15 *, struct dentry___14 *);
	int (*show_stats)(struct seq_file___15 *, struct dentry___14 *);
	ssize_t (*quota_read)(struct super_block___14 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___14 *, int, const char *, size_t, loff_t);
	struct dquot___13 ** (*get_dquots)(struct inode___15 *);
	long int (*nr_cached_objects)(struct super_block___14 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___14 *, struct shrink_control___3 *);
	struct file___14 * (*real_loop)(struct file___14 *);
};

struct kernel_param_ops___13 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___13 *);
	int (*get)(char *, const struct kernel_param___13 *);
	void (*free)(void *);
};

struct kparam_array___13;

struct kernel_param___13 {
	const char *name;
	struct module___15 *mod;
	const struct kernel_param_ops___13 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___13 *arr;
	};
};

struct kparam_array___13 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___13 *ops;
	void *elem;
};

struct module_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___13 *, struct module_kobject___13 *, char *);
	ssize_t (*store)(struct module_attribute___13 *, struct module_kobject___13 *, const char *, size_t);
	void (*setup)(struct module___15 *, const char *);
	int (*test)(struct module___15 *);
	void (*free)(struct module___15 *);
};

struct msi_desc___2 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___11 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___2 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___6 {
	struct device___11 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___6 *);
	void (*irq_shutdown)(struct irq_data___6 *);
	void (*irq_enable)(struct irq_data___6 *);
	void (*irq_disable)(struct irq_data___6 *);
	void (*irq_ack)(struct irq_data___6 *);
	void (*irq_mask)(struct irq_data___6 *);
	void (*irq_mask_ack)(struct irq_data___6 *);
	void (*irq_unmask)(struct irq_data___6 *);
	void (*irq_eoi)(struct irq_data___6 *);
	int (*irq_set_affinity)(struct irq_data___6 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___6 *);
	int (*irq_set_type)(struct irq_data___6 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___6 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___6 *);
	void (*irq_bus_sync_unlock)(struct irq_data___6 *);
	void (*irq_cpu_online)(struct irq_data___6 *);
	void (*irq_cpu_offline)(struct irq_data___6 *);
	void (*irq_suspend)(struct irq_data___6 *);
	void (*irq_resume)(struct irq_data___6 *);
	void (*irq_pm_shutdown)(struct irq_data___6 *);
	void (*irq_calc_mask)(struct irq_data___6 *);
	void (*irq_print_chip)(struct irq_data___6 *, struct seq_file___15 *);
	int (*irq_request_resources)(struct irq_data___6 *);
	void (*irq_release_resources)(struct irq_data___6 *);
	void (*irq_compose_msi_msg)(struct irq_data___6 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___6 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___6 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___6 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___6 *, void *);
	void (*ipi_send_single)(struct irq_data___6 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___6 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___6 *);
	void (*irq_nmi_teardown)(struct irq_data___6 *);
	long unsigned int flags;
};

struct irqaction___5 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___5 *next;
	irq_handler_t thread_fn;
	struct task_struct___15 *thread;
	struct irqaction___5 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___6 {
	struct irq_chip___6 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___6 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___6 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___6 *);
	void (*resume)(struct irq_chip_generic___6 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___6 *domain;
	struct list_head list;
	struct irq_chip_type___6 chip_types[0];
};

struct seq_operations___13 {
	void * (*start)(struct seq_file___15 *, loff_t *);
	void (*stop)(struct seq_file___15 *, void *);
	void * (*next)(struct seq_file___15 *, void *, loff_t *);
	int (*show)(struct seq_file___15 *, void *);
};

struct dev_pagemap_ops___13 {
	void (*page_free)(struct page___14 *);
	void (*kill)(struct dev_pagemap___13 *);
	void (*cleanup)(struct dev_pagemap___13 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___13 *);
};

struct cgroup_namespace___2 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___8 *root_cset;
};

enum perf_hw_id {
	PERF_COUNT_HW_CPU_CYCLES = 0,
	PERF_COUNT_HW_INSTRUCTIONS = 1,
	PERF_COUNT_HW_CACHE_REFERENCES = 2,
	PERF_COUNT_HW_CACHE_MISSES = 3,
	PERF_COUNT_HW_BRANCH_INSTRUCTIONS = 4,
	PERF_COUNT_HW_BRANCH_MISSES = 5,
	PERF_COUNT_HW_BUS_CYCLES = 6,
	PERF_COUNT_HW_STALLED_CYCLES_FRONTEND = 7,
	PERF_COUNT_HW_STALLED_CYCLES_BACKEND = 8,
	PERF_COUNT_HW_REF_CPU_CYCLES = 9,
	PERF_COUNT_HW_MAX = 10,
};

enum perf_hw_cache_id {
	PERF_COUNT_HW_CACHE_L1D = 0,
	PERF_COUNT_HW_CACHE_L1I = 1,
	PERF_COUNT_HW_CACHE_LL = 2,
	PERF_COUNT_HW_CACHE_DTLB = 3,
	PERF_COUNT_HW_CACHE_ITLB = 4,
	PERF_COUNT_HW_CACHE_BPU = 5,
	PERF_COUNT_HW_CACHE_NODE = 6,
	PERF_COUNT_HW_CACHE_MAX = 7,
};

enum perf_hw_cache_op_id {
	PERF_COUNT_HW_CACHE_OP_READ = 0,
	PERF_COUNT_HW_CACHE_OP_WRITE = 1,
	PERF_COUNT_HW_CACHE_OP_PREFETCH = 2,
	PERF_COUNT_HW_CACHE_OP_MAX = 3,
};

enum perf_hw_cache_op_result_id {
	PERF_COUNT_HW_CACHE_RESULT_ACCESS = 0,
	PERF_COUNT_HW_CACHE_RESULT_MISS = 1,
	PERF_COUNT_HW_CACHE_RESULT_MAX = 2,
};

struct perf_event_mmap_page {
	__u32 version;
	__u32 compat_version;
	__u32 lock;
	__u32 index;
	__s64 offset;
	__u64 time_enabled;
	__u64 time_running;
	union {
		__u64 capabilities;
		struct {
			__u64 cap_bit0: 1;
			__u64 cap_bit0_is_deprecated: 1;
			__u64 cap_user_rdpmc: 1;
			__u64 cap_user_time: 1;
			__u64 cap_user_time_zero: 1;
			__u64 cap_user_time_short: 1;
			__u64 cap_____res: 58;
		};
	};
	__u16 pmc_width;
	__u16 time_shift;
	__u32 time_mult;
	__u64 time_offset;
	__u64 time_zero;
	__u32 size;
	__u32 __reserved_1;
	__u64 time_cycles;
	__u64 time_mask;
	__u8 __reserved[928];
	__u64 data_head;
	__u64 data_tail;
	__u64 data_offset;
	__u64 data_size;
	__u64 aux_head;
	__u64 aux_tail;
	__u64 aux_offset;
	__u64 aux_size;
};

struct cftype___8;

struct cgroup_subsys___8 {
	struct cgroup_subsys_state___8 * (*css_alloc)(struct cgroup_subsys_state___8 *);
	int (*css_online)(struct cgroup_subsys_state___8 *);
	void (*css_offline)(struct cgroup_subsys_state___8 *);
	void (*css_released)(struct cgroup_subsys_state___8 *);
	void (*css_free)(struct cgroup_subsys_state___8 *);
	void (*css_reset)(struct cgroup_subsys_state___8 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___8 *, int);
	int (*css_extra_stat_show)(struct seq_file___15 *, struct cgroup_subsys_state___8 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___15 *, struct css_set___8 *);
	void (*cancel_fork)(struct task_struct___15 *, struct css_set___8 *);
	void (*fork)(struct task_struct___15 *);
	void (*exit)(struct task_struct___15 *);
	void (*release)(struct task_struct___15 *);
	void (*bind)(struct cgroup_subsys_state___8 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___8 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___8 *dfl_cftypes;
	struct cftype___8 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___8 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___8 *updated_children;
	struct cgroup___8 *updated_next;
};

struct cgroup_root___8 {
	struct kernfs_root___13 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___8 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___8 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___8 *ss;
	struct list_head node;
	struct kernfs_ops___13 *kf_ops;
	int (*open)(struct kernfs_open_file___13 *);
	void (*release)(struct kernfs_open_file___13 *);
	u64 (*read_u64)(struct cgroup_subsys_state___8 *, struct cftype___8 *);
	s64 (*read_s64)(struct cgroup_subsys_state___8 *, struct cftype___8 *);
	int (*seq_show)(struct seq_file___15 *, void *);
	void * (*seq_start)(struct seq_file___15 *, loff_t *);
	void * (*seq_next)(struct seq_file___15 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___15 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___8 *, struct cftype___8 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___8 *, struct cftype___8 *, s64);
	ssize_t (*write)(struct kernfs_open_file___13 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___13 *, struct poll_table_struct___10 *);
};

struct perf_cpu_context___8;

struct perf_output_handle___8;

struct pmu___8 {
	struct list_head entry;
	struct module___15 *module;
	struct device___11 *dev;
	const struct attribute_group___13 **attr_groups;
	const struct attribute_group___13 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___8 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___8 *);
	void (*pmu_disable)(struct pmu___8 *);
	int (*event_init)(struct perf_event___8 *);
	void (*event_mapped)(struct perf_event___8 *, struct mm_struct___14 *);
	void (*event_unmapped)(struct perf_event___8 *, struct mm_struct___14 *);
	int (*add)(struct perf_event___8 *, int);
	void (*del)(struct perf_event___8 *, int);
	void (*start)(struct perf_event___8 *, int);
	void (*stop)(struct perf_event___8 *, int);
	void (*read)(struct perf_event___8 *);
	void (*start_txn)(struct pmu___8 *, unsigned int);
	int (*commit_txn)(struct pmu___8 *);
	void (*cancel_txn)(struct pmu___8 *);
	int (*event_idx)(struct perf_event___8 *);
	void (*sched_task)(struct perf_event_context___8 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___8 *, struct perf_event_context___8 *);
	void * (*setup_aux)(struct perf_event___8 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___8 *, struct perf_output_handle___8 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___8 *);
	int (*aux_output_match)(struct perf_event___8 *);
	int (*filter_match)(struct perf_event___8 *);
	int (*check_period)(struct perf_event___8 *, u64);
};

struct perf_cpu_context___8 {
	struct perf_event_context___8 ctx;
	struct perf_event_context___8 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___8 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___8 **heap;
	struct perf_event___8 *heap_default[2];
};

struct perf_output_handle___8 {
	struct perf_event___8 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___8 {
	struct cgroup_subsys_state___8 css;
	struct perf_cgroup_info *info;
};

struct perf_pmu_events_attr {
	struct device_attribute___2 attr;
	u64 id;
	const char *event_str;
};

struct mfd_cell;

struct platform_device {
	const char *name;
	int id;
	bool id_auto;
	struct device___11 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver {
	int (*probe)(struct platform_device *);
	int (*remove)(struct platform_device *);
	void (*shutdown)(struct platform_device *);
	int (*suspend)(struct platform_device *, pm_message_t);
	int (*resume)(struct platform_device *);
	struct device_driver___11 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct arm_pmu;

struct pmu_hw_events {
	struct perf_event___8 *events[32];
	long unsigned int used_mask[1];
	raw_spinlock_t pmu_lock;
	struct arm_pmu *percpu_pmu;
	int irq;
};

struct arm_pmu {
	struct pmu___8 pmu;
	cpumask_t supported_cpus;
	char *name;
	int pmuver;
	irqreturn_t (*handle_irq)(struct arm_pmu *);
	void (*enable)(struct perf_event___8 *);
	void (*disable)(struct perf_event___8 *);
	int (*get_event_idx)(struct pmu_hw_events *, struct perf_event___8 *);
	void (*clear_event_idx)(struct pmu_hw_events *, struct perf_event___8 *);
	int (*set_event_filter)(struct hw_perf_event___8 *, struct perf_event_attr *);
	u64 (*read_counter)(struct perf_event___8 *);
	void (*write_counter)(struct perf_event___8 *, u64);
	void (*start)(struct arm_pmu *);
	void (*stop)(struct arm_pmu *);
	void (*reset)(void *);
	int (*map_event)(struct perf_event___8 *);
	int (*filter_match)(struct perf_event___8 *);
	int num_events;
	bool secure_access;
	long unsigned int pmceid_bitmap[1];
	long unsigned int pmceid_ext_bitmap[1];
	struct platform_device *plat_device;
	struct pmu_hw_events *hw_events;
	struct hlist_node node;
	struct notifier_block cpu_pm_nb;
	const struct attribute_group___13 *attr_groups[5];
	u64 reg_pmmir;
	long unsigned int acpi_cpuid;
};

enum armpmu_attr_groups {
	ARMPMU_ATTR_GROUP_COMMON = 0,
	ARMPMU_ATTR_GROUP_EVENTS = 1,
	ARMPMU_ATTR_GROUP_FORMATS = 2,
	ARMPMU_ATTR_GROUP_CAPS = 3,
	ARMPMU_NR_ATTR_GROUPS = 4,
};

typedef int (*armpmu_init_fn)(struct arm_pmu *);

struct pmu_probe_info {
	unsigned int cpuid;
	unsigned int mask;
	armpmu_init_fn init;
};

struct clock_read_data {
	u64 epoch_ns;
	u64 epoch_cyc;
	u64 sched_clock_mask;
	u64 (*read_sched_clock)();
	u32 mult;
	u32 shift;
};

struct armv8pmu_probe_info {
	struct arm_pmu *pmu;
	bool present;
};

enum hw_breakpoint_ops {
	HW_BREAKPOINT_INSTALL = 0,
	HW_BREAKPOINT_UNINSTALL = 1,
	HW_BREAKPOINT_RESTORE = 2,
};

struct arm_cpuidle_irq_context___2 {
	long unsigned int pmr;
	long unsigned int daif_bits;
};

struct cpu_suspend_ctx {
	u64 ctx_regs[13];
	u64 sp;
};

struct sleep_stack_data {
	struct cpu_suspend_ctx system_regs;
	long unsigned int callee_saved_regs[12];
};

struct irq_desc___7;

typedef void (*irq_flow_handler_t___7)(struct irq_desc___7 *);

struct irq_chip___7;

struct irq_domain___7;

struct irq_data___7 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___7 *chip;
	struct irq_domain___7 *domain;
	struct irq_data___7 *parent_data;
	void *chip_data;
};

struct irq_desc___7 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___7 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___7 handle_irq;
	struct irqaction___5 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___13 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___15 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___12;

struct device___12;

struct fwnode_handle___12 {
	struct fwnode_handle___12 *secondary;
	const struct fwnode_operations___12 *ops;
	struct device___12 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___12;

struct fwnode_endpoint___12;

struct fwnode_operations___12 {
	struct fwnode_handle___12 * (*get)(struct fwnode_handle___12 *);
	void (*put)(struct fwnode_handle___12 *);
	bool (*device_is_available)(const struct fwnode_handle___12 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___12 *, const struct device___12 *);
	bool (*property_present)(const struct fwnode_handle___12 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___12 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___12 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___12 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_parent)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_next_child_node)(const struct fwnode_handle___12 *, struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*get_named_child_node)(const struct fwnode_handle___12 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___12 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___12 *);
	struct fwnode_handle___12 * (*graph_get_next_endpoint)(const struct fwnode_handle___12 *, struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*graph_get_remote_endpoint)(const struct fwnode_handle___12 *);
	struct fwnode_handle___12 * (*graph_get_port_parent)(struct fwnode_handle___12 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___12 *, struct fwnode_endpoint___12 *);
	int (*add_links)(struct fwnode_handle___12 *);
};

struct wakeup_source___12;

struct dev_pm_qos___3;

struct dev_pm_info___12 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___12 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___12 *, s32);
	struct dev_pm_qos___3 *qos;
};

struct device_type___12;

struct bus_type___12;

struct device_driver___12;

struct dev_pm_domain___12;

struct device_node___8;

struct class___12;

struct device___12 {
	struct kobject___13 kobj;
	struct device___12 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___12 *type;
	struct bus_type___12 *bus;
	struct device_driver___12 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___12 power;
	struct dev_pm_domain___12 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___7 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___8 *of_node;
	struct fwnode_handle___12 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___12 *class;
	const struct attribute_group___13 **groups;
	void (*release)(struct device___12 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___12 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___12 *local_fwnode;
};

struct fwnode_reference_args___12 {
	struct fwnode_handle___12 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___8 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___12 fwnode;
	struct property___6 *properties;
	struct property___6 *deadprops;
	struct device_node___8 *parent;
	struct device_node___8 *child;
	struct device_node___8 *sibling;
	struct kobject___13 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___7 {
	struct fwnode_handle___12 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___7 {
	int (*match)(struct irq_domain___7 *, struct device_node___8 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___7 *, struct irq_fwspec___7 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___7 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___7 *, unsigned int);
	int (*xlate)(struct irq_domain___7 *, struct device_node___8 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___7 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___7 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___7 *, struct irq_data___7 *, bool);
	void (*deactivate)(struct irq_domain___7 *, struct irq_data___7 *);
	int (*translate)(struct irq_domain___7 *, struct irq_fwspec___7 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___7;

struct irq_domain___7 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___7 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___12 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___7 *gc;
	struct irq_domain___7 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___7 *revmap[0];
};

struct irq_chip_generic___7;

struct irq_domain_chip_generic___7 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___7 *gc[0];
};

struct dev_pm_ops___12 {
	int (*prepare)(struct device___12 *);
	void (*complete)(struct device___12 *);
	int (*suspend)(struct device___12 *);
	int (*resume)(struct device___12 *);
	int (*freeze)(struct device___12 *);
	int (*thaw)(struct device___12 *);
	int (*poweroff)(struct device___12 *);
	int (*restore)(struct device___12 *);
	int (*suspend_late)(struct device___12 *);
	int (*resume_early)(struct device___12 *);
	int (*freeze_late)(struct device___12 *);
	int (*thaw_early)(struct device___12 *);
	int (*poweroff_late)(struct device___12 *);
	int (*restore_early)(struct device___12 *);
	int (*suspend_noirq)(struct device___12 *);
	int (*resume_noirq)(struct device___12 *);
	int (*freeze_noirq)(struct device___12 *);
	int (*thaw_noirq)(struct device___12 *);
	int (*poweroff_noirq)(struct device___12 *);
	int (*restore_noirq)(struct device___12 *);
	int (*runtime_suspend)(struct device___12 *);
	int (*runtime_resume)(struct device___12 *);
	int (*runtime_idle)(struct device___12 *);
};

struct wakeup_source___12 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___12 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___3;

struct dev_pm_qos___3 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___3 *resume_latency_req;
	struct dev_pm_qos_request___3 *latency_tolerance_req;
	struct dev_pm_qos_request___3 *flags_req;
};

struct dev_pm_domain___12 {
	struct dev_pm_ops___12 ops;
	int (*start)(struct device___12 *);
	void (*detach)(struct device___12 *, bool);
	int (*activate)(struct device___12 *);
	void (*sync)(struct device___12 *);
	void (*dismiss)(struct device___12 *);
};

struct bus_type___12 {
	const char *name;
	const char *dev_name;
	struct device___12 *dev_root;
	const struct attribute_group___13 **bus_groups;
	const struct attribute_group___13 **dev_groups;
	const struct attribute_group___13 **drv_groups;
	int (*match)(struct device___12 *, struct device_driver___12 *);
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	int (*probe)(struct device___12 *);
	void (*sync_state)(struct device___12 *);
	void (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*online)(struct device___12 *);
	int (*offline)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	int (*num_vf)(struct device___12 *);
	int (*dma_configure)(struct device___12 *);
	const struct dev_pm_ops___12 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___12 {
	const char *name;
	struct bus_type___12 *bus;
	struct module___15 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___12 *);
	void (*sync_state)(struct device___12 *);
	int (*remove)(struct device___12 *);
	void (*shutdown)(struct device___12 *);
	int (*suspend)(struct device___12 *, pm_message_t);
	int (*resume)(struct device___12 *);
	const struct attribute_group___13 **groups;
	const struct attribute_group___13 **dev_groups;
	const struct dev_pm_ops___12 *pm;
	void (*coredump)(struct device___12 *);
	struct driver_private *p;
};

struct device_type___12 {
	const char *name;
	const struct attribute_group___13 **groups;
	int (*uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___12 *);
	const struct dev_pm_ops___12 *pm;
};

struct class___12 {
	const char *name;
	struct module___15 *owner;
	const struct attribute_group___13 **class_groups;
	const struct attribute_group___13 **dev_groups;
	struct kobject___13 *dev_kobj;
	int (*dev_uevent)(struct device___12 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___12 *, umode_t *);
	void (*class_release)(struct class___12 *);
	void (*dev_release)(struct device___12 *);
	int (*shutdown_pre)(struct device___12 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___12 *);
	void (*get_ownership)(struct device___12 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___12 *pm;
	struct subsys_private *p;
};

typedef void *acpi_handle;

struct irq_chip___7 {
	struct device___12 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___7 *);
	void (*irq_shutdown)(struct irq_data___7 *);
	void (*irq_enable)(struct irq_data___7 *);
	void (*irq_disable)(struct irq_data___7 *);
	void (*irq_ack)(struct irq_data___7 *);
	void (*irq_mask)(struct irq_data___7 *);
	void (*irq_mask_ack)(struct irq_data___7 *);
	void (*irq_unmask)(struct irq_data___7 *);
	void (*irq_eoi)(struct irq_data___7 *);
	int (*irq_set_affinity)(struct irq_data___7 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___7 *);
	int (*irq_set_type)(struct irq_data___7 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___7 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___7 *);
	void (*irq_bus_sync_unlock)(struct irq_data___7 *);
	void (*irq_cpu_online)(struct irq_data___7 *);
	void (*irq_cpu_offline)(struct irq_data___7 *);
	void (*irq_suspend)(struct irq_data___7 *);
	void (*irq_resume)(struct irq_data___7 *);
	void (*irq_pm_shutdown)(struct irq_data___7 *);
	void (*irq_calc_mask)(struct irq_data___7 *);
	void (*irq_print_chip)(struct irq_data___7 *, struct seq_file___15 *);
	int (*irq_request_resources)(struct irq_data___7 *);
	void (*irq_release_resources)(struct irq_data___7 *);
	void (*irq_compose_msi_msg)(struct irq_data___7 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___7 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___7 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___7 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___7 *, void *);
	void (*ipi_send_single)(struct irq_data___7 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___7 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___7 *);
	void (*irq_nmi_teardown)(struct irq_data___7 *);
	long unsigned int flags;
};

struct irq_chip_type___7 {
	struct irq_chip___7 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___7 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___7 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___7 *);
	void (*resume)(struct irq_chip_generic___7 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___7 *domain;
	struct list_head list;
	struct irq_chip_type___7 chip_types[0];
};

typedef u64 phys_cpuid_t;

struct dev_pm_qos_request___3 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___12 *dev;
};

struct thermal_cooling_device_ops___2;

struct thermal_cooling_device___2 {
	int id;
	char *type;
	struct device___12 device;
	struct device_node___8 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___2 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___2 {
	int (*get_max_state)(struct thermal_cooling_device___2 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___2 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___2 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___2 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___2 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___2 *, u32, long unsigned int *);
};

struct acpi_processor_cx {
	u8 valid;
	u8 type;
	u32 address;
	u8 entry_method;
	u8 index;
	u32 latency;
	u8 bm_sts_skip;
	char desc[32];
};

struct acpi_lpi_state {
	u32 min_residency;
	u32 wake_latency;
	u32 flags;
	u32 arch_flags;
	u32 res_cnt_freq;
	u32 enable_parent_state;
	u64 address;
	u8 index;
	u8 entry_method;
	char desc[32];
};

struct acpi_processor_power {
	int count;
	union {
		struct acpi_processor_cx states[8];
		struct acpi_lpi_state lpi_states[8];
	};
	int timer_broadcast_on_state;
};

struct acpi_psd_package {
	u64 num_entries;
	u64 revision;
	u64 domain;
	u64 coord_type;
	u64 num_processors;
};

struct acpi_pct_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_processor_px {
	u64 core_frequency;
	u64 power;
	u64 transition_latency;
	u64 bus_master_latency;
	u64 control;
	u64 status;
};

struct acpi_processor_performance {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_px *states;
	struct acpi_psd_package domain_info;
	cpumask_var_t shared_cpu_map;
	unsigned int shared_type;
	int: 32;
} __attribute__((packed));

struct acpi_tsd_package {
	u64 num_entries;
	u64 revision;
	u64 domain;
	u64 coord_type;
	u64 num_processors;
};

struct acpi_processor_tx_tss {
	u64 freqpercentage;
	u64 power;
	u64 transition_latency;
	u64 control;
	u64 status;
};

struct acpi_processor_tx {
	u16 power;
	u16 performance;
};

struct acpi_processor;

struct acpi_processor_throttling {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor *);
	int (*acpi_processor_set_throttling)(struct acpi_processor *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor_flags {
	u8 power: 1;
	u8 performance: 1;
	u8 throttling: 1;
	u8 limit: 1;
	u8 bm_control: 1;
	u8 bm_check: 1;
	u8 has_cst: 1;
	u8 has_lpi: 1;
	u8 power_setup_done: 1;
	u8 bm_rld_set: 1;
	u8 need_hotplug_init: 1;
	short: 15;
};

struct acpi_processor_lx {
	int px;
	int tx;
};

struct acpi_processor_limit {
	struct acpi_processor_lx state;
	struct acpi_processor_lx thermal;
	struct acpi_processor_lx user;
};

struct acpi_processor {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device___2 *cdev;
	struct device___12 *dev;
	struct freq_qos_request perflib_req;
	struct freq_qos_request thermal_req;
};

enum jump_label_type {
	JUMP_LABEL_NOP = 0,
	JUMP_LABEL_JMP = 1,
};

struct die_args {
	struct pt_regs *regs;
	const char *str;
	long int err;
	int trapnr;
	int signr;
};

enum kgdb_bptype {
	BP_BREAKPOINT = 0,
	BP_HARDWARE_BREAKPOINT = 1,
	BP_WRITE_WATCHPOINT = 2,
	BP_READ_WATCHPOINT = 3,
	BP_ACCESS_WATCHPOINT = 4,
	BP_POKE_BREAKPOINT = 5,
};

enum kgdb_bpstate {
	BP_UNDEFINED = 0,
	BP_REMOVED = 1,
	BP_SET = 2,
	BP_ACTIVE = 3,
};

struct kgdb_bkpt {
	long unsigned int bpt_addr;
	unsigned char saved_instr[4];
	enum kgdb_bptype type;
	enum kgdb_bpstate state;
};

struct dbg_reg_def_t {
	char *name;
	int size;
	int offset;
};

struct kgdb_arch {
	unsigned char gdb_bpt_instr[4];
	long unsigned int flags;
	int (*set_breakpoint)(long unsigned int, char *);
	int (*remove_breakpoint)(long unsigned int, char *);
	int (*set_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	int (*remove_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	void (*disable_hw_break)(struct pt_regs *);
	void (*remove_all_hw_break)();
	void (*correct_hw_break)();
	void (*enable_nmi)(bool);
};

struct dentry___15;

struct super_block___15;

struct module___16;

struct file_system_type___14 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___15 * (*mount)(struct file_system_type___14 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___15 *);
	struct module___16 *owner;
	struct file_system_type___14 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___15;

struct kiocb___14;

struct poll_table_struct___11;

struct vm_area_struct___14;

struct inode___16;

struct file_lock___14;

struct page___15;

struct seq_file___16;

struct file_operations___14 {
	struct module___16 *owner;
	loff_t (*llseek)(struct file___15 *, loff_t, int);
	ssize_t (*read)(struct file___15 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___15 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___14 *, struct iov_iter___5 *);
	ssize_t (*write_iter)(struct kiocb___14 *, struct iov_iter___5 *);
	int (*iopoll)(struct kiocb___14 *, bool);
	int (*iterate)(struct file___15 *, struct dir_context *);
	int (*iterate_shared)(struct file___15 *, struct dir_context *);
	__poll_t (*poll)(struct file___15 *, struct poll_table_struct___11 *);
	long int (*unlocked_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___15 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___15 *, struct vm_area_struct___14 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___16 *, struct file___15 *);
	int (*flush)(struct file___15 *, fl_owner_t);
	int (*release)(struct inode___16 *, struct file___15 *);
	int (*fsync)(struct file___15 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___15 *, int);
	int (*lock)(struct file___15 *, int, struct file_lock___14 *);
	ssize_t (*sendpage)(struct file___15 *, struct page___15 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___15 *, long unsigned int);
	int (*flock)(struct file___15 *, int, struct file_lock___14 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___15 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___15 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___15 *, long int, struct file_lock___14 **, void **);
	long int (*fallocate)(struct file___15 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___16 *, struct file___15 *);
	ssize_t (*copy_file_range)(struct file___15 *, loff_t, struct file___15 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___15 *, loff_t, struct file___15 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___15 *, loff_t, loff_t, int);
};

struct vmacache___14 {
	u64 seqnum;
	struct vm_area_struct___14 *vmas[4];
};

struct page_frag___14 {
	struct page___15 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___15;

struct pid___13;

struct nsproxy___14;

struct signal_struct___15;

struct vm_struct___14;

struct task_struct___16 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___16 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___15 *mm;
	struct mm_struct___15 *active_mm;
	struct vmacache___14 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___16 *real_parent;
	struct task_struct___16 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___16 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___13 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___14 *nsproxy;
	struct signal_struct___15 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___16 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___5 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___14 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___16 *oom_reaper_list;
	struct vm_struct___14 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___8 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___14;

struct kobj_type___14;

struct kernfs_node___14;

struct kobject___14 {
	const char *name;
	struct list_head entry;
	struct kobject___14 *parent;
	struct kset___14 *kset;
	struct kobj_type___14 *ktype;
	struct kernfs_node___14 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___14 {
	struct kobject___14 kobj;
	struct module___16 *mod;
	struct kobject___14 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___14 {
	struct module___16 *mod;
	struct latch_tree_node node;
};

struct module_layout___14 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___14 mtn;
};

struct module_attribute___14;

struct kernel_param___14;

struct module___16 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___14 mkobj;
	struct module_attribute___14 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___14 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___14 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___14 core_layout;
	struct module_layout___14 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___14;

struct dentry___15 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___15 *d_parent;
	struct qstr d_name;
	struct inode___16 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___14 *d_op;
	struct super_block___15 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___14;

struct address_space___14 {
	struct inode___16 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___14 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___14;

struct cdev___8;

struct inode___16 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___14 *i_op;
	struct super_block___15 *i_sb;
	struct address_space___14 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___14 *i_fop;
		void (*free_inode)(struct inode___16 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___14 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___8 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___14;

struct path___14;

struct dentry_operations___14 {
	int (*d_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___15 *, unsigned int);
	int (*d_hash)(const struct dentry___15 *, struct qstr *);
	int (*d_compare)(const struct dentry___15 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___15 *);
	int (*d_init)(struct dentry___15 *);
	void (*d_release)(struct dentry___15 *);
	void (*d_prune)(struct dentry___15 *);
	void (*d_iput)(struct dentry___15 *, struct inode___16 *);
	char * (*d_dname)(struct dentry___15 *, char *, int);
	struct vfsmount___14 * (*d_automount)(struct path___14 *);
	int (*d_manage)(const struct path___14 *, bool);
	struct dentry___15 * (*d_real)(struct dentry___15 *, const struct inode___16 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___14;

struct mem_dqinfo___14 {
	struct quota_format_type___14 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___14;

struct quota_info___14 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___16 *files[3];
	struct mem_dqinfo___14 info[3];
	const struct quota_format_ops___14 *ops[3];
};

struct rcuwait___14 {
	struct task_struct___16 *task;
};

struct percpu_rw_semaphore___14 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___14 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___14 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___14 rw_sem[3];
};

struct super_operations___14;

struct dquot_operations___14;

struct quotactl_ops___14;

struct super_block___15 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___14 *s_type;
	const struct super_operations___14 *s_op;
	const struct dquot_operations___14 *dq_op;
	const struct quotactl_ops___14 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___15 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___14 s_dquot;
	struct sb_writers___14 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___14 *s_d_op;
	int cleancache_poolid;
	struct shrinker___3 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___14 {
	struct dentry___15 *mnt_root;
	struct super_block___15 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___14 {
	struct vfsmount___14 *mnt;
	struct dentry___15 *dentry;
};

struct pid_namespace___13;

struct upid___13 {
	int nr;
	struct pid_namespace___13 *ns;
};

struct pid_namespace___13 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___16 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___13 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___2 ns;
};

struct pid___13 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___13 numbers[1];
};

typedef struct page___15 *pgtable_t___14;

struct dev_pagemap___14;

struct page___15 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___14 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___15 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___14 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___15 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___14 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___14;

struct vm_area_struct___14 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___14 *vm_next;
	struct vm_area_struct___14 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___15 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___14 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___15 *vm_file;
	struct file___15 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___15 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___16 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___16 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___13 *pids[4];
	struct pid___13 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___15 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___14;

struct mm_struct___15 {
	struct {
		struct vm_area_struct___14 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___15 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___14 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___16 *owner;
		struct user_namespace *user_ns;
		struct file___15 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___14 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___13 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___14 {
	struct vm_struct___14 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___15 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___14;

struct dev_pagemap___14 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___14 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___13 {
	rwlock_t lock;
	struct pid___13 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___15 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___14 f_path;
	struct inode___16 *f_inode;
	const struct file_operations___14 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___13 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___14 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___14;

struct vm_operations_struct___14 {
	void (*open)(struct vm_area_struct___14 *);
	void (*close)(struct vm_area_struct___14 *);
	int (*may_split)(struct vm_area_struct___14 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___14 *);
	int (*mprotect)(struct vm_area_struct___14 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___14 *);
	vm_fault_t (*huge_fault)(struct vm_fault___14 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___14 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___14 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___14 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___14 *);
	int (*access)(struct vm_area_struct___14 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___14 *);
	int (*set_policy)(struct vm_area_struct___14 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___14 *, long unsigned int);
	struct page___15 * (*find_special_page)(struct vm_area_struct___14 *, long unsigned int);
};

struct core_thread___14 {
	struct task_struct___16 *task;
	struct core_thread___14 *next;
};

struct core_state___14 {
	atomic_t nr_threads;
	struct core_thread___14 dumper;
	struct completion startup;
};

struct vm_fault___14 {
	const struct {
		struct vm_area_struct___14 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___15 *cow_page;
	struct page___15 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___14 prealloc_pte;
};

struct kiocb___14 {
	struct file___15 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___14 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___2 *ki_waitq;
	};
};

struct iattr___15 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___15 *ia_file;
};

struct dquot___14 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___15 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___14 {
	int qf_fmt_id;
	const struct quota_format_ops___14 *qf_ops;
	struct module___16 *qf_owner;
	struct quota_format_type___14 *qf_next;
};

struct quota_format_ops___14 {
	int (*check_quota_file)(struct super_block___15 *, int);
	int (*read_file_info)(struct super_block___15 *, int);
	int (*write_file_info)(struct super_block___15 *, int);
	int (*free_file_info)(struct super_block___15 *, int);
	int (*read_dqblk)(struct dquot___14 *);
	int (*commit_dqblk)(struct dquot___14 *);
	int (*release_dqblk)(struct dquot___14 *);
	int (*get_next_id)(struct super_block___15 *, struct kqid *);
};

struct dquot_operations___14 {
	int (*write_dquot)(struct dquot___14 *);
	struct dquot___14 * (*alloc_dquot)(struct super_block___15 *, int);
	void (*destroy_dquot)(struct dquot___14 *);
	int (*acquire_dquot)(struct dquot___14 *);
	int (*release_dquot)(struct dquot___14 *);
	int (*mark_dirty)(struct dquot___14 *);
	int (*write_info)(struct super_block___15 *, int);
	qsize_t * (*get_reserved_space)(struct inode___16 *);
	int (*get_projid)(struct inode___16 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___16 *, qsize_t *);
	int (*get_next_id)(struct super_block___15 *, struct kqid *);
};

struct quotactl_ops___14 {
	int (*quota_on)(struct super_block___15 *, int, int, const struct path___14 *);
	int (*quota_off)(struct super_block___15 *, int);
	int (*quota_enable)(struct super_block___15 *, unsigned int);
	int (*quota_disable)(struct super_block___15 *, unsigned int);
	int (*quota_sync)(struct super_block___15 *, int);
	int (*set_info)(struct super_block___15 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___15 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___15 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___15 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___15 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___15 *, unsigned int);
};

struct address_space_operations___14 {
	int (*writepage)(struct page___15 *, struct writeback_control___3 *);
	int (*readpage)(struct file___15 *, struct page___15 *);
	int (*writepages)(struct address_space___14 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___15 *);
	int (*readpages)(struct file___15 *, struct address_space___14 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___15 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___15 **, void **);
	int (*write_end)(struct file___15 *, struct address_space___14 *, loff_t, unsigned int, unsigned int, struct page___15 *, void *);
	sector_t (*bmap)(struct address_space___14 *, sector_t);
	void (*invalidatepage)(struct page___15 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___15 *, gfp_t);
	void (*freepage)(struct page___15 *);
	ssize_t (*direct_IO)(struct kiocb___14 *, struct iov_iter___5 *);
	int (*migratepage)(struct address_space___14 *, struct page___15 *, struct page___15 *, enum migrate_mode);
	bool (*isolate_page)(struct page___15 *, isolate_mode_t);
	void (*putback_page)(struct page___15 *);
	int (*launder_page)(struct page___15 *);
	int (*is_partially_uptodate)(struct page___15 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___15 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___14 *, struct page___15 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___15 *, sector_t *);
	void (*swap_deactivate)(struct file___15 *);
};

struct cdev___8 {
	struct kobject___14 kobj;
	struct module___16 *owner;
	const struct file_operations___14 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___14 {
	struct dentry___15 * (*lookup)(struct inode___16 *, struct dentry___15 *, unsigned int);
	const char * (*get_link)(struct dentry___15 *, struct inode___16 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___16 *, int);
	struct posix_acl * (*get_acl)(struct inode___16 *, int, bool);
	int (*readlink)(struct dentry___15 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___16 *, struct dentry___15 *, umode_t, bool);
	int (*link)(struct dentry___15 *, struct inode___16 *, struct dentry___15 *);
	int (*unlink)(struct inode___16 *, struct dentry___15 *);
	int (*symlink)(struct user_namespace *, struct inode___16 *, struct dentry___15 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___16 *, struct dentry___15 *, umode_t);
	int (*rmdir)(struct inode___16 *, struct dentry___15 *);
	int (*mknod)(struct user_namespace *, struct inode___16 *, struct dentry___15 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___16 *, struct dentry___15 *, struct inode___16 *, struct dentry___15 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___15 *, struct iattr___15 *);
	int (*getattr)(struct user_namespace *, const struct path___14 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___15 *, char *, size_t);
	int (*fiemap)(struct inode___16 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___16 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___16 *, struct dentry___15 *, struct file___15 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___16 *, struct dentry___15 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___16 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___15 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___15 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___14 {
	void (*fl_copy_lock)(struct file_lock___14 *, struct file_lock___14 *);
	void (*fl_release_private)(struct file_lock___14 *);
};

struct fasync_struct___14;

struct lock_manager_operations___14;

struct file_lock___14 {
	struct file_lock___14 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___15 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___14 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___14 *fl_ops;
	const struct lock_manager_operations___14 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___14 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___14 *);
	int (*lm_grant)(struct file_lock___14 *, int);
	bool (*lm_break)(struct file_lock___14 *);
	int (*lm_change)(struct file_lock___14 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___14 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___14 *);
};

struct fasync_struct___14 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___14 *fa_next;
	struct file___15 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___14 {
	struct inode___16 * (*alloc_inode)(struct super_block___15 *);
	void (*destroy_inode)(struct inode___16 *);
	void (*free_inode)(struct inode___16 *);
	void (*dirty_inode)(struct inode___16 *, int);
	int (*write_inode)(struct inode___16 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___16 *);
	void (*evict_inode)(struct inode___16 *);
	void (*put_super)(struct super_block___15 *);
	int (*sync_fs)(struct super_block___15 *, int);
	int (*freeze_super)(struct super_block___15 *);
	int (*freeze_fs)(struct super_block___15 *);
	int (*thaw_super)(struct super_block___15 *);
	int (*unfreeze_fs)(struct super_block___15 *);
	int (*statfs)(struct dentry___15 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___15 *, int *, char *);
	void (*umount_begin)(struct super_block___15 *);
	int (*show_options)(struct seq_file___16 *, struct dentry___15 *);
	int (*show_devname)(struct seq_file___16 *, struct dentry___15 *);
	int (*show_path)(struct seq_file___16 *, struct dentry___15 *);
	int (*show_stats)(struct seq_file___16 *, struct dentry___15 *);
	ssize_t (*quota_read)(struct super_block___15 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___15 *, int, const char *, size_t, loff_t);
	struct dquot___14 ** (*get_dquots)(struct inode___16 *);
	long int (*nr_cached_objects)(struct super_block___15 *, struct shrink_control___3 *);
	long int (*free_cached_objects)(struct super_block___15 *, struct shrink_control___3 *);
	struct file___15 * (*real_loop)(struct file___15 *);
};

typedef void (*poll_queue_proc___11)(struct file___15 *, wait_queue_head_t *, struct poll_table_struct___11 *);

struct poll_table_struct___11 {
	poll_queue_proc___11 _qproc;
	__poll_t _key;
};

struct seq_operations___14;

struct seq_file___16 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___14 *op;
	int poll_event;
	const struct file___15 *file;
	void *private;
};

struct kernfs_root___14;

struct kernfs_elem_dir___14 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___14 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___14;

struct kernfs_root___14 {
	struct kernfs_node___14 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___14 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___14 {
	struct kernfs_node___14 *target_kn;
};

struct kernfs_ops___14;

struct kernfs_elem_attr___14 {
	const struct kernfs_ops___14 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___14 *notify_next;
};

struct kernfs_node___14 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___14 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___14 dir;
		struct kernfs_elem_symlink___14 symlink;
		struct kernfs_elem_attr___14 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___14;

struct kernfs_ops___14 {
	int (*open)(struct kernfs_open_file___14 *);
	void (*release)(struct kernfs_open_file___14 *);
	int (*seq_show)(struct seq_file___16 *, void *);
	void * (*seq_start)(struct seq_file___16 *, loff_t *);
	void * (*seq_next)(struct seq_file___16 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___16 *, void *);
	ssize_t (*read)(struct kernfs_open_file___14 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___14 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___14 *, struct poll_table_struct___11 *);
	int (*mmap)(struct kernfs_open_file___14 *, struct vm_area_struct___14 *);
};

struct kernfs_syscall_ops___14 {
	int (*show_options)(struct seq_file___16 *, struct kernfs_root___14 *);
	int (*mkdir)(struct kernfs_node___14 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___14 *);
	int (*rename)(struct kernfs_node___14 *, struct kernfs_node___14 *, const char *);
	int (*show_path)(struct seq_file___16 *, struct kernfs_node___14 *, struct kernfs_root___14 *);
};

struct kernfs_open_file___14 {
	struct kernfs_node___14 *kn;
	struct file___15 *file;
	struct seq_file___16 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___14 *vm_ops;
};

struct bin_attribute___14;

struct attribute_group___14 {
	const char *name;
	umode_t (*is_visible)(struct kobject___14 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___14 *, struct bin_attribute___14 *, int);
	struct attribute **attrs;
	struct bin_attribute___14 **bin_attrs;
};

struct bin_attribute___14 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___14 * (*f_mapping)();
	ssize_t (*read)(struct file___15 *, struct kobject___14 *, struct bin_attribute___14 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___15 *, struct kobject___14 *, struct bin_attribute___14 *, char *, loff_t, size_t);
	int (*mmap)(struct file___15 *, struct kobject___14 *, struct bin_attribute___14 *, struct vm_area_struct___14 *);
};

struct sysfs_ops___14 {
	ssize_t (*show)(struct kobject___14 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___14 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___14;

struct kset___14 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___14 kobj;
	const struct kset_uevent_ops___14 *uevent_ops;
};

struct kobj_type___14 {
	void (*release)(struct kobject___14 *);
	const struct sysfs_ops___14 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___14 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___14 *);
	const void * (*namespace)(struct kobject___14 *);
	void (*get_ownership)(struct kobject___14 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___14 {
	int (* const filter)(struct kset___14 *, struct kobject___14 *);
	const char * (* const name)(struct kset___14 *, struct kobject___14 *);
	int (* const uevent)(struct kset___14 *, struct kobject___14 *, struct kobj_uevent_env *);
};

struct seq_operations___14 {
	void * (*start)(struct seq_file___16 *, loff_t *);
	void (*stop)(struct seq_file___16 *, void *);
	void * (*next)(struct seq_file___16 *, void *, loff_t *);
	int (*show)(struct seq_file___16 *, void *);
};

struct screen_info {
	__u8 orig_x;
	__u8 orig_y;
	__u16 ext_mem_k;
	__u16 orig_video_page;
	__u8 orig_video_mode;
	__u8 orig_video_cols;
	__u8 flags;
	__u8 unused2;
	__u16 orig_video_ega_bx;
	__u16 unused3;
	__u8 orig_video_lines;
	__u8 orig_video_isVGA;
	__u16 orig_video_points;
	__u16 lfb_width;
	__u16 lfb_height;
	__u16 lfb_depth;
	__u32 lfb_base;
	__u32 lfb_size;
	__u16 cl_magic;
	__u16 cl_offset;
	__u16 lfb_linelength;
	__u8 red_size;
	__u8 red_pos;
	__u8 green_size;
	__u8 green_pos;
	__u8 blue_size;
	__u8 blue_pos;
	__u8 rsvd_size;
	__u8 rsvd_pos;
	__u16 vesapm_seg;
	__u16 vesapm_off;
	__u16 pages;
	__u16 vesa_attributes;
	__u32 capabilities;
	__u32 ext_lfb_base;
	__u8 _reserved[2];
} __attribute__((packed));

struct dev_pagemap_ops___14 {
	void (*page_free)(struct page___15 *);
	void (*kill)(struct dev_pagemap___14 *);
	void (*cleanup)(struct dev_pagemap___14 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___14 *);
};

typedef int (*pte_fn_t)(pte_t *, long unsigned int, void *);

struct kernel_param_ops___14 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___14 *);
	int (*get)(char *, const struct kernel_param___14 *);
	void (*free)(void *);
};

struct kparam_array___14;

struct kernel_param___14 {
	const char *name;
	struct module___16 *mod;
	const struct kernel_param_ops___14 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___14 *arr;
	};
};

struct kparam_array___14 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___14 *ops;
	void *elem;
};

struct module_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___14 *, struct module_kobject___14 *, char *);
	ssize_t (*store)(struct module_attribute___14 *, struct module_kobject___14 *, const char *, size_t);
	void (*setup)(struct module___16 *, const char *);
	int (*test)(struct module___16 *);
	void (*free)(struct module___16 *);
};

struct pci_device_id {
	__u32 vendor;
	__u32 device;
	__u32 subvendor;
	__u32 subdevice;
	__u32 class;
	__u32 class_mask;
	kernel_ulong_t driver_data;
	__u32 override_only;
};

struct resource_entry {
	struct list_head node;
	struct resource *res;
	resource_size_t offset;
	struct resource __res;
};

typedef u64 acpi_io_address;

typedef u32 acpi_object_type;

union acpi_object {
	acpi_object_type type;
	struct {
		acpi_object_type type;
		u64 value;
	} integer;
	struct {
		acpi_object_type type;
		u32 length;
		char *pointer;
	} string;
	struct {
		acpi_object_type type;
		u32 length;
		u8 *pointer;
	} buffer;
	struct {
		acpi_object_type type;
		u32 count;
		union acpi_object *elements;
	} package;
	struct {
		acpi_object_type type;
		acpi_object_type actual_type;
		acpi_handle handle;
	} reference;
	struct {
		acpi_object_type type;
		u32 proc_id;
		acpi_io_address pblk_address;
		u32 pblk_length;
	} processor;
	struct {
		acpi_object_type type;
		u32 system_level;
		u32 resource_order;
	} power_resource;
};

struct acpi_device;

struct acpi_hotplug_profile {
	struct kobject___13 kobj;
	int (*scan_dependent)(struct acpi_device *);
	void (*notify_online)(struct acpi_device *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_status {
	u32 present: 1;
	u32 enabled: 1;
	u32 show_in_ui: 1;
	u32 functional: 1;
	u32 battery_present: 1;
	u32 reserved: 27;
};

struct acpi_device_flags {
	u32 dynamic_status: 1;
	u32 removable: 1;
	u32 ejectable: 1;
	u32 power_manageable: 1;
	u32 match_driver: 1;
	u32 initialized: 1;
	u32 visited: 1;
	u32 hotplug_notify: 1;
	u32 is_dock_station: 1;
	u32 of_compatible_ok: 1;
	u32 coherent_dma: 1;
	u32 cca_seen: 1;
	u32 enumeration_by_parent: 1;
	u32 reserved: 19;
};

typedef char acpi_bus_id[8];

struct acpi_pnp_type {
	u32 hardware_id: 1;
	u32 bus_address: 1;
	u32 platform_id: 1;
	u32 reserved: 29;
};

typedef u64 acpi_bus_address;

typedef char acpi_device_name[40];

typedef char acpi_device_class[20];

struct acpi_device_pnp {
	acpi_bus_id bus_id;
	int instance_no;
	struct acpi_pnp_type type;
	acpi_bus_address bus_address;
	char *unique_id;
	struct list_head ids;
	acpi_device_name device_name;
	acpi_device_class device_class;
	union acpi_object *str_obj;
};

struct acpi_device_power_flags {
	u32 explicit_get: 1;
	u32 power_resources: 1;
	u32 inrush_current: 1;
	u32 power_removed: 1;
	u32 ignore_parent: 1;
	u32 dsw_present: 1;
	u32 reserved: 26;
};

struct acpi_device_power_state {
	struct {
		u8 valid: 1;
		u8 explicit_set: 1;
		u8 reserved: 6;
	} flags;
	int power;
	int latency;
	struct list_head resources;
};

struct acpi_device_power {
	int state;
	struct acpi_device_power_flags flags;
	struct acpi_device_power_state states[5];
};

struct acpi_device_wakeup_flags {
	u8 valid: 1;
	u8 notifier_present: 1;
};

struct acpi_device_wakeup_context {
	void (*func)(struct acpi_device_wakeup_context *);
	struct device___12 *dev;
};

struct acpi_device_wakeup {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context context;
	struct wakeup_source___12 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_device_perf_flags {
	u8 reserved: 8;
};

struct acpi_device_perf_state;

struct acpi_device_perf {
	int state;
	struct acpi_device_perf_flags flags;
	int state_count;
	struct acpi_device_perf_state *states;
};

struct acpi_device_dir {
	struct proc_dir_entry *entry;
};

struct acpi_device_data {
	const union acpi_object *pointer;
	struct list_head properties;
	const union acpi_object *of_compatible;
	struct list_head subnodes;
};

struct acpi_scan_handler;

struct acpi_hotplug_context;

struct acpi_driver;

struct acpi_gpio_mapping;

struct acpi_device {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___12 fwnode;
	struct acpi_device *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler *handler;
	struct acpi_hotplug_context *hp;
	struct acpi_driver *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___12 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device *);
};

struct acpi_scan_handler {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device *);
	void (*bind)(struct device___12 *);
	void (*unbind)(struct device___12 *);
	struct acpi_hotplug_profile hotplug;
};

struct acpi_hotplug_context {
	struct acpi_device *self;
	int (*notify)(struct acpi_device *, u32);
	void (*uevent)(struct acpi_device *, u32);
	void (*fixup)(struct acpi_device *);
};

typedef int (*acpi_op_add)(struct acpi_device *);

typedef int (*acpi_op_remove)(struct acpi_device *);

typedef void (*acpi_op_notify)(struct acpi_device *, u32);

struct acpi_device_ops {
	acpi_op_add add;
	acpi_op_remove remove;
	acpi_op_notify notify;
};

struct acpi_driver {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops ops;
	struct device_driver___12 drv;
	struct module___15 *owner;
};

struct acpi_device_perf_state {
	struct {
		u8 valid: 1;
		u8 reserved: 7;
	} flags;
	u8 power;
	u8 performance;
	int latency;
};

struct acpi_gpio_params;

struct acpi_gpio_mapping {
	const char *name;
	const struct acpi_gpio_params *data;
	unsigned int size;
	unsigned int quirks;
};

struct pci_bus;

struct acpi_pci_root {
	struct acpi_device *device;
	struct pci_bus *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

typedef short unsigned int pci_bus_flags_t;

struct pci_dev;

struct pci_ops;

struct pci_bus {
	struct list_head node;
	struct pci_bus *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___12 *bridge;
	struct device___12 dev;
	struct bin_attribute___13 *legacy_io;
	struct bin_attribute___13 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_gpio_params {
	unsigned int crs_entry_index;
	unsigned int line_index;
	bool active_low;
};

struct hotplug_slot;

struct pci_slot {
	struct pci_bus *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___13 kobj;
};

enum {
	PCI_STD_RESOURCES = 0,
	PCI_STD_RESOURCE_END = 5,
	PCI_ROM_RESOURCE = 6,
	PCI_IOV_RESOURCES = 7,
	PCI_IOV_RESOURCE_END = 12,
	PCI_BRIDGE_RESOURCES = 13,
	PCI_BRIDGE_RESOURCE_END = 16,
	PCI_NUM_RESOURCES = 17,
	DEVICE_COUNT_RESOURCE = 17,
};

typedef int pci_power_t;

typedef unsigned int pci_channel_state_t;

typedef unsigned int pcie_reset_state_t;

typedef short unsigned int pci_dev_flags_t;

struct pci_vpd {
	struct mutex lock;
	unsigned int len;
	u8 cap;
};

struct aer_stats;

struct rcec_ea;

struct pci_driver;

struct pcie_link_state;

struct pci_sriov;

struct pci_dev {
	struct list_head bus_list;
	struct pci_bus *bus;
	struct pci_bus *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___12 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___13 *res_attr[17];
	struct bin_attribute___13 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___13 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct pci_error_handlers;

struct pci_driver {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev *, const struct pci_device_id *);
	void (*remove)(struct pci_dev *);
	int (*suspend)(struct pci_dev *, pm_message_t);
	int (*resume)(struct pci_dev *);
	void (*shutdown)(struct pci_dev *);
	int (*sriov_configure)(struct pci_dev *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev *);
	const struct pci_error_handlers *err_handler;
	const struct attribute_group___13 **groups;
	const struct attribute_group___13 **dev_groups;
	struct device_driver___12 driver;
	struct pci_dynids dynids;
};

struct pci_host_bridge {
	struct device___12 dev;
	struct pci_bus *bus;
	struct pci_ops *ops;
	struct pci_ops *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev *, u8 *);
	int (*map_irq)(const struct pci_dev *, u8, u8);
	void (*release_fn)(struct pci_host_bridge *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_ops {
	int (*add_bus)(struct pci_bus *);
	void (*remove_bus)(struct pci_bus *);
	void * (*map_bus)(struct pci_bus *, unsigned int, int);
	int (*read)(struct pci_bus *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus *, unsigned int, int, int, u32);
};

typedef unsigned int pci_ers_result_t;

struct pci_error_handlers {
	pci_ers_result_t (*error_detected)(struct pci_dev *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev *);
	pci_ers_result_t (*slot_reset)(struct pci_dev *);
	void (*reset_prepare)(struct pci_dev *);
	void (*reset_done)(struct pci_dev *);
	void (*resume)(struct pci_dev *);
};

struct acpi_pci_root_ops;

struct acpi_pci_root_info {
	struct acpi_pci_root *root;
	struct acpi_device *bridge;
	struct acpi_pci_root_ops *ops;
	struct list_head resources;
	char name[16];
};

struct acpi_pci_root_ops {
	struct pci_ops *pci_ops;
	int (*init_info)(struct acpi_pci_root_info *);
	void (*release_info)(struct acpi_pci_root_info *);
	int (*prepare_resources)(struct acpi_pci_root_info *);
};

struct pci_config_window;

struct pci_ecam_ops {
	unsigned int bus_shift;
	struct pci_ops pci_ops;
	int (*init)(struct pci_config_window *);
};

struct pci_config_window {
	struct resource res;
	struct resource busr;
	unsigned int bus_shift;
	void *priv;
	const struct pci_ecam_ops *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___12 *parent;
};

struct acpi_pci_generic_root_info {
	struct acpi_pci_root_info common;
	struct pci_config_window *cfg;
};

typedef bool (*smp_cond_func_t)(int, void *);

struct trace_event_raw_instruction_emulation {
	struct trace_entry ent;
	u32 __data_loc_instr;
	u64 addr;
	char __data[0];
};

struct trace_event_data_offsets_instruction_emulation {
	u32 instr;
};

typedef void (*btf_trace_instruction_emulation)(void *, const char *, u64);

enum insn_emulation_mode {
	INSN_UNDEF = 0,
	INSN_EMULATE = 1,
	INSN_HW = 2,
};

enum legacy_insn_status {
	INSN_DEPRECATED = 0,
	INSN_OBSOLETE = 1,
};

struct insn_emulation_ops {
	const char *name;
	enum legacy_insn_status status;
	struct undef_hook *hooks;
	int (*set_hw_mode)(bool);
};

struct insn_emulation {
	struct list_head node;
	struct insn_emulation_ops *ops;
	int current_mode;
	int min;
	int max;
};

typedef u64 acpi_size;

typedef u64 acpi_physical_address;

typedef u32 acpi_status;

typedef char *acpi_string;

struct acpi_table_header {
	char signature[4];
	u32 length;
	u8 revision;
	u8 checksum;
	char oem_id[6];
	char oem_table_id[8];
	u32 oem_revision;
	char asl_compiler_id[4];
	u32 asl_compiler_revision;
};

struct acpi_generic_address {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_width;
	u64 address;
} __attribute__((packed));

struct acpi_table_fadt {
	struct acpi_table_header header;
	u32 facs;
	u32 dsdt;
	u8 model;
	u8 preferred_profile;
	u16 sci_interrupt;
	u32 smi_command;
	u8 acpi_enable;
	u8 acpi_disable;
	u8 s4_bios_request;
	u8 pstate_control;
	u32 pm1a_event_block;
	u32 pm1b_event_block;
	u32 pm1a_control_block;
	u32 pm1b_control_block;
	u32 pm2_control_block;
	u32 pm_timer_block;
	u32 gpe0_block;
	u32 gpe1_block;
	u8 pm1_event_length;
	u8 pm1_control_length;
	u8 pm2_control_length;
	u8 pm_timer_length;
	u8 gpe0_block_length;
	u8 gpe1_block_length;
	u8 gpe1_base;
	u8 cst_control;
	u16 c2_latency;
	u16 c3_latency;
	u16 flush_size;
	u16 flush_stride;
	u8 duty_offset;
	u8 duty_width;
	u8 day_alarm;
	u8 month_alarm;
	u8 century;
	u16 boot_flags;
	u8 reserved;
	u32 flags;
	struct acpi_generic_address reset_register;
	u8 reset_value;
	u16 arm_boot_flags;
	u8 minor_revision;
	u64 Xfacs;
	u64 Xdsdt;
	struct acpi_generic_address xpm1a_event_block;
	struct acpi_generic_address xpm1b_event_block;
	struct acpi_generic_address xpm1a_control_block;
	struct acpi_generic_address xpm1b_control_block;
	struct acpi_generic_address xpm2_control_block;
	struct acpi_generic_address xpm_timer_block;
	struct acpi_generic_address xgpe0_block;
	struct acpi_generic_address xgpe1_block;
	struct acpi_generic_address sleep_control;
	struct acpi_generic_address sleep_status;
	u64 hypervisor_id;
} __attribute__((packed));

struct tty_driver___2;

struct tty_operations___2;

struct tty_ldisc___2;

struct tty_port___2;

struct tty_struct {
	int magic;
	struct kref kref;
	struct device___12 *dev;
	struct tty_driver___2 *driver;
	const struct tty_operations___2 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___2 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___12 *pgrp;
		struct pid___12 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct *link;
	struct fasync_struct___13 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___2 *port;
};

typedef int (*acpi_tbl_table_handler)(struct acpi_table_header *);

struct tty_driver___2 {
	int magic;
	struct kref kref;
	struct cdev___7 **cdevs;
	struct module___15 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___2 *other;
	struct tty_struct **ttys;
	struct tty_port___2 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___2 *ops;
	struct list_head tty_drivers;
};

struct tty_operations___2 {
	struct tty_struct * (*lookup)(struct tty_driver___2 *, struct file___14 *, int);
	int (*install)(struct tty_driver___2 *, struct tty_struct *);
	void (*remove)(struct tty_driver___2 *, struct tty_struct *);
	int (*open)(struct tty_struct *, struct file___14 *);
	void (*close)(struct tty_struct *, struct file___14 *);
	void (*shutdown)(struct tty_struct *);
	void (*cleanup)(struct tty_struct *);
	int (*write)(struct tty_struct *, const unsigned char *, int);
	int (*put_char)(struct tty_struct *, unsigned char);
	void (*flush_chars)(struct tty_struct *);
	unsigned int (*write_room)(struct tty_struct *);
	unsigned int (*chars_in_buffer)(struct tty_struct *);
	int (*ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	void (*throttle)(struct tty_struct *);
	void (*unthrottle)(struct tty_struct *);
	void (*stop)(struct tty_struct *);
	void (*start)(struct tty_struct *);
	void (*hangup)(struct tty_struct *);
	int (*break_ctl)(struct tty_struct *, int);
	void (*flush_buffer)(struct tty_struct *);
	void (*set_ldisc)(struct tty_struct *);
	void (*wait_until_sent)(struct tty_struct *, int);
	void (*send_xchar)(struct tty_struct *, char);
	int (*tiocmget)(struct tty_struct *);
	int (*tiocmset)(struct tty_struct *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct *, struct winsize *);
	int (*get_icount)(struct tty_struct *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct *, struct serial_struct *);
	int (*set_serial)(struct tty_struct *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct *, struct seq_file___15 *);
	int (*poll_init)(struct tty_driver___2 *, int, char *);
	int (*poll_get_char)(struct tty_driver___2 *, int);
	void (*poll_put_char)(struct tty_driver___2 *, int, char);
	int (*proc_show)(struct seq_file___15 *, void *);
};

struct serial_icounter_struct {
	int cts;
	int dsr;
	int rng;
	int dcd;
	int rx;
	int tx;
	int frame;
	int overrun;
	int parity;
	int brk;
	int buf_overrun;
	int reserved[9];
};

struct serial_struct {
	int type;
	int line;
	unsigned int port;
	int irq;
	int flags;
	int xmit_fifo_size;
	int custom_divisor;
	int baud_base;
	short unsigned int close_delay;
	char io_type;
	char reserved_char[1];
	int hub6;
	short unsigned int closing_wait;
	short unsigned int closing_wait2;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
	unsigned int port_high;
	long unsigned int iomap_base;
};

struct tty_port_operations___2;

struct tty_port_client_operations___2;

struct tty_port___2 {
	struct tty_bufhead buf;
	struct tty_struct *tty;
	struct tty_struct *itty;
	const struct tty_port_operations___2 *ops;
	const struct tty_port_client_operations___2 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___2 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct *);
	void (*close)(struct tty_struct *);
	void (*flush_buffer)(struct tty_struct *);
	ssize_t (*read)(struct tty_struct *, struct file___14 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct *, struct file___14 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct *, struct file___14 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct *, struct file___14 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct *, struct file___14 *, struct poll_table_struct___10 *);
	int (*hangup)(struct tty_struct *);
	void (*receive_buf)(struct tty_struct *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct *);
	void (*dcd_change)(struct tty_struct *, unsigned int);
	int (*receive_buf2)(struct tty_struct *, const unsigned char *, const char *, int);
	struct module___15 *owner;
};

struct tty_ldisc___2 {
	struct tty_ldisc_ops___2 *ops;
	struct tty_struct *tty;
};

struct tty_port_operations___2 {
	int (*carrier_raised)(struct tty_port___2 *);
	void (*dtr_rts)(struct tty_port___2 *, int);
	void (*shutdown)(struct tty_port___2 *);
	int (*activate)(struct tty_port___2 *, struct tty_struct *);
	void (*destruct)(struct tty_port___2 *);
};

struct tty_port_client_operations___2 {
	int (*receive_buf)(struct tty_port___2 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___2 *);
};

enum acpi_srat_type {
	ACPI_SRAT_TYPE_CPU_AFFINITY = 0,
	ACPI_SRAT_TYPE_MEMORY_AFFINITY = 1,
	ACPI_SRAT_TYPE_X2APIC_CPU_AFFINITY = 2,
	ACPI_SRAT_TYPE_GICC_AFFINITY = 3,
	ACPI_SRAT_TYPE_GIC_ITS_AFFINITY = 4,
	ACPI_SRAT_TYPE_GENERIC_AFFINITY = 5,
	ACPI_SRAT_TYPE_RESERVED = 6,
};

struct acpi_srat_gicc_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u32 acpi_processor_uid;
	u32 flags;
	u32 clock_domain;
} __attribute__((packed));

struct parking_protocol_mailbox {
	__le32 cpu_id;
	__le32 reserved;
	__le64 entry_point;
};

struct cpu_mailbox_entry {
	struct parking_protocol_mailbox *mailbox;
	phys_addr_t mailbox_addr;
	u8 version;
	u8 gic_cpu_id;
};

enum {
	MEMREMAP_WB = 1,
	MEMREMAP_WT = 2,
	MEMREMAP_WC = 4,
	MEMREMAP_ENC = 8,
	MEMREMAP_DEC = 16,
};

struct pvclock_vcpu_stolen_time {
	__le32 revision;
	__le32 attributes;
	__le64 stolen_time;
	u8 padding[48];
};

struct pv_time_stolen_time_region {
	struct pvclock_vcpu_stolen_time *kaddr;
};

typedef __be64 fdt64_t;

enum kaslr_status {
	KASLR_ENABLED = 0,
	KASLR_DISABLED_CMDLINE = 1,
	KASLR_DISABLED_NO_SEED = 2,
	KASLR_DISABLED_FDT_REMAP = 3,
};

struct irq_desc___8;

typedef void (*irq_flow_handler_t___8)(struct irq_desc___8 *);

struct irqaction___6;

struct irq_desc___8 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___7 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___8 handle_irq;
	struct irqaction___6 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___10 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___12 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	IRQD_TRIGGER_MASK = 15,
	IRQD_SETAFFINITY_PENDING = 256,
	IRQD_ACTIVATED = 512,
	IRQD_NO_BALANCING = 1024,
	IRQD_PER_CPU = 2048,
	IRQD_AFFINITY_SET = 4096,
	IRQD_LEVEL = 8192,
	IRQD_WAKEUP_STATE = 16384,
	IRQD_MOVE_PCNTXT = 32768,
	IRQD_IRQ_DISABLED = 65536,
	IRQD_IRQ_MASKED = 131072,
	IRQD_IRQ_INPROGRESS = 262144,
	IRQD_WAKEUP_ARMED = 524288,
	IRQD_FORWARDED_TO_VCPU = 1048576,
	IRQD_AFFINITY_MANAGED = 2097152,
	IRQD_IRQ_STARTED = 4194304,
	IRQD_MANAGED_SHUTDOWN = 8388608,
	IRQD_SINGLE_TARGET = 16777216,
	IRQD_DEFAULT_TRIGGER_SET = 33554432,
	IRQD_CAN_RESERVE = 67108864,
	IRQD_MSI_NOMASK_QUIRK = 134217728,
	IRQD_HANDLE_ENFORCE_IRQCTX = 268435456,
	IRQD_AFFINITY_ON_ACTIVATE = 536870912,
	IRQD_IRQ_ENABLED_ON_SUSPEND = 1073741824,
};

struct irqaction___6 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___6 *next;
	irq_handler_t thread_fn;
	struct task_struct___12 *thread;
	struct irqaction___6 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kimage_arch {
	void *dtb;
	phys_addr_t dtb_mem;
	phys_addr_t kern_reloc;
};

typedef int kexec_probe_t(const char *, long unsigned int);

struct kimage;

typedef void *kexec_load_t(struct kimage *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

typedef int kexec_cleanup_t(void *);

typedef int kexec_verify_sig_t(const char *, long unsigned int);

struct kexec_file_ops {
	kexec_probe_t *probe;
	kexec_load_t *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

typedef long unsigned int kimage_entry_t;

struct kexec_segment {
	union {
		void *buf;
		void *kbuf;
	};
	size_t bufsz;
	long unsigned int mem;
	size_t memsz;
};

struct purgatory_info {
	const Elf64_Ehdr *ehdr;
	Elf64_Shdr *sechdrs;
	void *purgatory_buf;
};

struct kimage {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___11 *control_code_page;
	struct page___11 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type;
	unsigned int preserve_context;
	unsigned int file_mode;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *ima_buffer;
	phys_addr_t ima_buffer_addr;
	size_t ima_buffer_size;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

typedef u8 uint8_t;

struct kexec_buf {
	struct kimage *image;
	void *buffer;
	long unsigned int bufsz;
	long unsigned int mem;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

struct crash_mem_range {
	u64 start;
	u64 end;
};

struct crash_mem {
	unsigned int max_nr_ranges;
	unsigned int nr_ranges;
	struct crash_mem_range ranges[0];
};

typedef __be32 fdt32_t;

struct fdt_header {
	fdt32_t magic;
	fdt32_t totalsize;
	fdt32_t off_dt_struct;
	fdt32_t off_dt_strings;
	fdt32_t off_mem_rsvmap;
	fdt32_t version;
	fdt32_t last_comp_version;
	fdt32_t boot_cpuid_phys;
	fdt32_t size_dt_strings;
	fdt32_t size_dt_struct;
};

enum key_being_used_for {
	VERIFYING_MODULE_SIGNATURE = 0,
	VERIFYING_FIRMWARE_SIGNATURE = 1,
	VERIFYING_KEXEC_PE_SIGNATURE = 2,
	VERIFYING_KEY_SIGNATURE = 3,
	VERIFYING_KEY_SELF_SIGNATURE = 4,
	VERIFYING_UNSPECIFIED_SIGNATURE = 5,
	NR__KEY_BEING_USED_FOR = 6,
};

struct arm64_image_header {
	__le32 code0;
	__le32 code1;
	__le64 text_offset;
	__le64 image_size;
	__le64 flags;
	__le64 res2;
	__le64 res3;
	__le64 res4;
	__le32 magic;
	__le32 res5;
};

typedef int sdei_event_callback(u32, struct pt_regs___2 *, void *);

struct sdei_registered_event___2 {
	struct pt_regs___2 interrupted_regs;
	sdei_event_callback *callback;
	void *callback_arg;
	u32 event_num;
	u8 priority;
};

struct dentry___16;

struct super_block___16;

struct module___17;

struct file_system_type___15 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___16 * (*mount)(struct file_system_type___15 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___16 *);
	struct module___17 *owner;
	struct file_system_type___15 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___16;

struct kiocb___15;

struct iov_iter___6;

struct vm_area_struct___15;

struct inode___17;

struct file_lock___15;

struct page___16;

struct seq_file___17;

struct file_operations___15 {
	struct module___17 *owner;
	loff_t (*llseek)(struct file___16 *, loff_t, int);
	ssize_t (*read)(struct file___16 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___16 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___15 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___15 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___15 *, bool);
	int (*iterate)(struct file___16 *, struct dir_context *);
	int (*iterate_shared)(struct file___16 *, struct dir_context *);
	__poll_t (*poll)(struct file___16 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___16 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___16 *, struct vm_area_struct___15 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___17 *, struct file___16 *);
	int (*flush)(struct file___16 *, fl_owner_t);
	int (*release)(struct inode___17 *, struct file___16 *);
	int (*fsync)(struct file___16 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___16 *, int);
	int (*lock)(struct file___16 *, int, struct file_lock___15 *);
	ssize_t (*sendpage)(struct file___16 *, struct page___16 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___16 *, long unsigned int);
	int (*flock)(struct file___16 *, int, struct file_lock___15 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___16 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___16 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___16 *, long int, struct file_lock___15 **, void **);
	long int (*fallocate)(struct file___16 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___17 *, struct file___16 *);
	ssize_t (*copy_file_range)(struct file___16 *, loff_t, struct file___16 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___16 *, loff_t, struct file___16 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___16 *, loff_t, loff_t, int);
};

struct vmacache___15 {
	u64 seqnum;
	struct vm_area_struct___15 *vmas[4];
};

struct page_frag___15 {
	struct page___16 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___16;

struct pid___14;

struct nsproxy___15;

struct signal_struct___16;

struct bio_list___5;

struct backing_dev_info___4;

struct io_context___6;

struct css_set___9;

struct mem_cgroup___4;

struct request_queue___7;

struct vm_struct___15;

struct task_struct___17 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___17 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___16 *mm;
	struct mm_struct___16 *active_mm;
	struct vmacache___15 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___17 *real_parent;
	struct task_struct___17 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___17 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___14 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___15 *nsproxy;
	struct signal_struct___16 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___17 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___5 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___4 *backing_dev_info;
	struct io_context___6 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___9 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___15 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___4 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___4 *active_memcg;
	struct request_queue___7 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___17 *oom_reaper_list;
	struct vm_struct___15 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___8 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___15;

struct kobj_type___15;

struct kernfs_node___15;

struct kobject___15 {
	const char *name;
	struct list_head entry;
	struct kobject___15 *parent;
	struct kset___15 *kset;
	struct kobj_type___15 *ktype;
	struct kernfs_node___15 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___15 {
	struct kobject___15 kobj;
	struct module___17 *mod;
	struct kobject___15 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___15 {
	struct module___17 *mod;
	struct latch_tree_node node;
};

struct module_layout___15 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___15 mtn;
};

struct module_attribute___15;

struct kernel_param___15;

struct module___17 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___15 mkobj;
	struct module_attribute___15 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___15 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___15 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___15 core_layout;
	struct module_layout___15 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___14;

struct upid___14 {
	int nr;
	struct pid_namespace___14 *ns;
};

struct pid_namespace___14 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___17 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___14 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___14 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___14 numbers[1];
};

typedef struct page___16 *pgtable_t___15;

struct address_space___15;

struct dev_pagemap___15;

struct page___16 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___15 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___16 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___15 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___16 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___15 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___15;

struct vm_area_struct___15 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___15 *vm_next;
	struct vm_area_struct___15 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___16 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___15 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___16 *vm_file;
	struct file___16 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___16 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___17 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___17 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___14 *pids[4];
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___16 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___15;

struct mm_struct___16 {
	struct {
		struct vm_area_struct___15 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___16 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___15 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___17 *owner;
		struct user_namespace *user_ns;
		struct file___16 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___9;

struct nsproxy___15 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___14 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___9 *cgroup_ns;
};

struct bio___5;

struct bio_list___5 {
	struct bio___5 *head;
	struct bio___5 *tail;
};

struct cgroup_subsys_state___9;

struct bdi_writeback___4 {
	struct backing_dev_info___4 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___9 *memcg_css;
	struct cgroup_subsys_state___9 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___13;

struct backing_dev_info___4 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___4 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___13 *dev;
	char dev_name[64];
	struct device___13 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___16 *debug_dir;
};

struct io_cq___5;

struct io_context___6 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___5 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___9;

struct css_set___9 {
	struct cgroup_subsys_state___9 *subsys[14];
	refcount_t refcount;
	struct css_set___9 *dom_cset;
	struct cgroup___9 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___9 *mg_src_cgrp;
	struct cgroup___9 *mg_dst_cgrp;
	struct css_set___9 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___9;

struct cgroup_subsys_state___9 {
	struct cgroup___9 *cgroup;
	struct cgroup_subsys___9 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___9 *parent;
};

struct cgroup_file___9 {
	struct kernfs_node___15 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___4;

struct mem_cgroup_per_node___4;

struct mem_cgroup___4 {
	struct cgroup_subsys_state___9 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___9 events_file;
	struct cgroup_file___9 events_local_file;
	struct cgroup_file___9 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___4 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___17 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___4 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___5;

struct blk_integrity___5 {
	const struct blk_integrity_profile___5 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___5 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___5 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___6;

struct elevator_queue___5;

struct blk_mq_ops___5;

struct blk_mq_hw_ctx___5;

struct gendisk___5;

struct blkcg_gq___5;

struct blk_mq_tag_set___5;

struct request_queue___7 {
	struct request___6 *last_merge;
	struct elevator_queue___5 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___5 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___5 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___5 *disk;
	struct kobject___15 kobj;
	struct kobject___15 *mq_kobj;
	struct blk_integrity___5 integrity;
	struct device___13 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___5 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___5 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___5 bio_split;
	struct dentry___16 *debugfs_dir;
	struct dentry___16 *sched_debugfs_dir;
	struct dentry___16 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___15 {
	struct vm_struct___15 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___16 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___15;

struct address_space___15 {
	struct inode___17 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___15 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___15;

struct dev_pagemap___15 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___15 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___15;

struct path___15 {
	struct vfsmount___15 *mnt;
	struct dentry___16 *dentry;
};

struct fown_struct___14 {
	rwlock_t lock;
	struct pid___14 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___16 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___15 f_path;
	struct inode___17 *f_inode;
	const struct file_operations___15 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___15 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___15;

struct vm_operations_struct___15 {
	void (*open)(struct vm_area_struct___15 *);
	void (*close)(struct vm_area_struct___15 *);
	int (*may_split)(struct vm_area_struct___15 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___15 *);
	int (*mprotect)(struct vm_area_struct___15 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___15 *);
	vm_fault_t (*huge_fault)(struct vm_fault___15 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___15 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___15 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___15 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___15 *);
	int (*access)(struct vm_area_struct___15 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___15 *);
	int (*set_policy)(struct vm_area_struct___15 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___15 *, long unsigned int);
	struct page___16 * (*find_special_page)(struct vm_area_struct___15 *, long unsigned int);
};

struct core_thread___15 {
	struct task_struct___17 *task;
	struct core_thread___15 *next;
};

struct core_state___15 {
	atomic_t nr_threads;
	struct core_thread___15 dumper;
	struct completion startup;
};

struct vm_fault___15 {
	const struct {
		struct vm_area_struct___15 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___16 *cow_page;
	struct page___16 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___15 prealloc_pte;
};

typedef struct {
	long unsigned int val;
} swp_entry_t;

struct pglist_data___5;

struct lruvec___5 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___5 *pgdat;
};

struct zone___5 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___5 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___5 {
	struct zone___5 *zone;
	int zone_idx;
};

struct zonelist___5 {
	struct zoneref___5 _zonerefs[321];
};

struct pglist_data___5 {
	struct zone___5 node_zones[5];
	struct zonelist___5 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___17 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___17 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___5 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___15;

struct kernfs_elem_dir___15 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___15 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___15;

struct kernfs_root___15 {
	struct kernfs_node___15 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___15 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___15 {
	struct kernfs_node___15 *target_kn;
};

struct kernfs_ops___15;

struct kernfs_elem_attr___15 {
	const struct kernfs_ops___15 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___15 *notify_next;
};

struct kernfs_node___15 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___15 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___15 dir;
		struct kernfs_elem_symlink___15 symlink;
		struct kernfs_elem_attr___15 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___15;

struct kernfs_ops___15 {
	int (*open)(struct kernfs_open_file___15 *);
	void (*release)(struct kernfs_open_file___15 *);
	int (*seq_show)(struct seq_file___17 *, void *);
	void * (*seq_start)(struct seq_file___17 *, loff_t *);
	void * (*seq_next)(struct seq_file___17 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___17 *, void *);
	ssize_t (*read)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___15 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___15 *, struct vm_area_struct___15 *);
};

struct kernfs_syscall_ops___15 {
	int (*show_options)(struct seq_file___17 *, struct kernfs_root___15 *);
	int (*mkdir)(struct kernfs_node___15 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___15 *);
	int (*rename)(struct kernfs_node___15 *, struct kernfs_node___15 *, const char *);
	int (*show_path)(struct seq_file___17 *, struct kernfs_node___15 *, struct kernfs_root___15 *);
};

struct seq_operations___15;

struct seq_file___17 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___15 *op;
	int poll_event;
	const struct file___16 *file;
	void *private;
};

struct kernfs_open_file___15 {
	struct kernfs_node___15 *kn;
	struct file___16 *file;
	struct seq_file___17 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___15 *vm_ops;
};

struct bin_attribute___15;

struct attribute_group___15 {
	const char *name;
	umode_t (*is_visible)(struct kobject___15 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___15 *, struct bin_attribute___15 *, int);
	struct attribute **attrs;
	struct bin_attribute___15 **bin_attrs;
};

struct bin_attribute___15 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___15 * (*f_mapping)();
	ssize_t (*read)(struct file___16 *, struct kobject___15 *, struct bin_attribute___15 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___16 *, struct kobject___15 *, struct bin_attribute___15 *, char *, loff_t, size_t);
	int (*mmap)(struct file___16 *, struct kobject___15 *, struct bin_attribute___15 *, struct vm_area_struct___15 *);
};

struct sysfs_ops___15 {
	ssize_t (*show)(struct kobject___15 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___15 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___15;

struct kset___15 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___15 kobj;
	const struct kset_uevent_ops___15 *uevent_ops;
};

struct kobj_type___15 {
	void (*release)(struct kobject___15 *);
	const struct sysfs_ops___15 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___15 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___15 *);
	const void * (*namespace)(struct kobject___15 *);
	void (*get_ownership)(struct kobject___15 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___15 {
	int (* const filter)(struct kset___15 *, struct kobject___15 *);
	const char * (* const name)(struct kset___15 *, struct kobject___15 *);
	int (* const uevent)(struct kset___15 *, struct kobject___15 *, struct kobj_uevent_env *);
};

struct wakeup_source___13;

struct dev_pm_info___13 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___13 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___13 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___13;

struct bus_type___13;

struct device_driver___13;

struct dev_pm_domain___13;

struct fwnode_handle___13;

struct class___13;

struct device___13 {
	struct kobject___15 kobj;
	struct device___13 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___13 *type;
	struct bus_type___13 *bus;
	struct device_driver___13 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___13 power;
	struct dev_pm_domain___13 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___13 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___13 *class;
	const struct attribute_group___15 **groups;
	void (*release)(struct device___13 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___13 {
	int (*prepare)(struct device___13 *);
	void (*complete)(struct device___13 *);
	int (*suspend)(struct device___13 *);
	int (*resume)(struct device___13 *);
	int (*freeze)(struct device___13 *);
	int (*thaw)(struct device___13 *);
	int (*poweroff)(struct device___13 *);
	int (*restore)(struct device___13 *);
	int (*suspend_late)(struct device___13 *);
	int (*resume_early)(struct device___13 *);
	int (*freeze_late)(struct device___13 *);
	int (*thaw_early)(struct device___13 *);
	int (*poweroff_late)(struct device___13 *);
	int (*restore_early)(struct device___13 *);
	int (*suspend_noirq)(struct device___13 *);
	int (*resume_noirq)(struct device___13 *);
	int (*freeze_noirq)(struct device___13 *);
	int (*thaw_noirq)(struct device___13 *);
	int (*poweroff_noirq)(struct device___13 *);
	int (*restore_noirq)(struct device___13 *);
	int (*runtime_suspend)(struct device___13 *);
	int (*runtime_resume)(struct device___13 *);
	int (*runtime_idle)(struct device___13 *);
};

struct wakeup_source___13 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___13 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___13 {
	struct dev_pm_ops___13 ops;
	int (*start)(struct device___13 *);
	void (*detach)(struct device___13 *, bool);
	int (*activate)(struct device___13 *);
	void (*sync)(struct device___13 *);
	void (*dismiss)(struct device___13 *);
};

struct bus_type___13 {
	const char *name;
	const char *dev_name;
	struct device___13 *dev_root;
	const struct attribute_group___15 **bus_groups;
	const struct attribute_group___15 **dev_groups;
	const struct attribute_group___15 **drv_groups;
	int (*match)(struct device___13 *, struct device_driver___13 *);
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	int (*probe)(struct device___13 *);
	void (*sync_state)(struct device___13 *);
	void (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*online)(struct device___13 *);
	int (*offline)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	int (*num_vf)(struct device___13 *);
	int (*dma_configure)(struct device___13 *);
	const struct dev_pm_ops___13 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___13 {
	const char *name;
	struct bus_type___13 *bus;
	struct module___17 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___13 *);
	void (*sync_state)(struct device___13 *);
	int (*remove)(struct device___13 *);
	void (*shutdown)(struct device___13 *);
	int (*suspend)(struct device___13 *, pm_message_t);
	int (*resume)(struct device___13 *);
	const struct attribute_group___15 **groups;
	const struct attribute_group___15 **dev_groups;
	const struct dev_pm_ops___13 *pm;
	void (*coredump)(struct device___13 *);
	struct driver_private *p;
};

struct device_type___13 {
	const char *name;
	const struct attribute_group___15 **groups;
	int (*uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___13 *);
	const struct dev_pm_ops___13 *pm;
};

struct class___13 {
	const char *name;
	struct module___17 *owner;
	const struct attribute_group___15 **class_groups;
	const struct attribute_group___15 **dev_groups;
	struct kobject___15 *dev_kobj;
	int (*dev_uevent)(struct device___13 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___13 *, umode_t *);
	void (*class_release)(struct class___13 *);
	void (*dev_release)(struct device___13 *);
	int (*shutdown_pre)(struct device___13 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___13 *);
	void (*get_ownership)(struct device___13 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___13 *pm;
	struct subsys_private *p;
};

struct device_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device___13 *, struct device_attribute___3 *, char *);
	ssize_t (*store)(struct device___13 *, struct device_attribute___3 *, const char *, size_t);
};

struct fwnode_operations___13;

struct fwnode_handle___13 {
	struct fwnode_handle___13 *secondary;
	const struct fwnode_operations___13 *ops;
	struct device___13 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct shrink_control___4 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___4 *memcg;
};

struct shrinker___4 {
	long unsigned int (*count_objects)(struct shrinker___4 *, struct shrink_control___4 *);
	long unsigned int (*scan_objects)(struct shrinker___4 *, struct shrink_control___4 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___15 {
	void (*page_free)(struct page___16 *);
	void (*kill)(struct dev_pagemap___15 *);
	void (*cleanup)(struct dev_pagemap___15 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___15 *);
};

struct dentry_operations___15;

struct dentry___16 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___16 *d_parent;
	struct qstr d_name;
	struct inode___17 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___15 *d_op;
	struct super_block___16 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___15;

struct inode___17 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___15 *i_op;
	struct super_block___16 *i_sb;
	struct address_space___15 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___4 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___15 *i_fop;
		void (*free_inode)(struct inode___17 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___15 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___8 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___15 {
	int (*d_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___16 *, unsigned int);
	int (*d_hash)(const struct dentry___16 *, struct qstr *);
	int (*d_compare)(const struct dentry___16 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___16 *);
	int (*d_init)(struct dentry___16 *);
	void (*d_release)(struct dentry___16 *);
	void (*d_prune)(struct dentry___16 *);
	void (*d_iput)(struct dentry___16 *, struct inode___17 *);
	char * (*d_dname)(struct dentry___16 *, char *, int);
	struct vfsmount___15 * (*d_automount)(struct path___15 *);
	int (*d_manage)(const struct path___15 *, bool);
	struct dentry___16 * (*d_real)(struct dentry___16 *, const struct inode___17 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___15;

struct mem_dqinfo___15 {
	struct quota_format_type___15 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___15;

struct quota_info___15 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___17 *files[3];
	struct mem_dqinfo___15 info[3];
	const struct quota_format_ops___15 *ops[3];
};

struct rcuwait___15 {
	struct task_struct___17 *task;
};

struct percpu_rw_semaphore___15 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___15 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___15 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___15 rw_sem[3];
};

struct super_operations___15;

struct dquot_operations___15;

struct quotactl_ops___15;

struct block_device___6;

struct super_block___16 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___15 *s_type;
	const struct super_operations___15 *s_op;
	const struct dquot_operations___15 *dq_op;
	const struct quotactl_ops___15 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___16 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___6 *s_bdev;
	struct backing_dev_info___4 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___15 s_dquot;
	struct sb_writers___15 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___15 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___15 {
	struct dentry___16 *mnt_root;
	struct super_block___16 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct psi_group___9 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___17 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___9;

struct cgroup_rstat_cpu___9;

struct cgroup___9 {
	struct cgroup_subsys_state___9 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___15 *kn;
	struct cgroup_file___9 procs_file;
	struct cgroup_file___9 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___9 *subsys[14];
	struct cgroup_root___9 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___9 *dom_cgrp;
	struct cgroup___9 *old_dom_cgrp;
	struct cgroup_rstat_cpu___9 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___9 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___5 {
	struct request_queue___7 *q;
	struct io_context___6 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___3;

struct kiocb___15 {
	struct file___16 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___15 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___3 *ki_waitq;
	};
};

struct iattr___16 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___16 *ia_file;
};

struct dquot___15 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___16 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___15 {
	int qf_fmt_id;
	const struct quota_format_ops___15 *qf_ops;
	struct module___17 *qf_owner;
	struct quota_format_type___15 *qf_next;
};

struct quota_format_ops___15 {
	int (*check_quota_file)(struct super_block___16 *, int);
	int (*read_file_info)(struct super_block___16 *, int);
	int (*write_file_info)(struct super_block___16 *, int);
	int (*free_file_info)(struct super_block___16 *, int);
	int (*read_dqblk)(struct dquot___15 *);
	int (*commit_dqblk)(struct dquot___15 *);
	int (*release_dqblk)(struct dquot___15 *);
	int (*get_next_id)(struct super_block___16 *, struct kqid *);
};

struct dquot_operations___15 {
	int (*write_dquot)(struct dquot___15 *);
	struct dquot___15 * (*alloc_dquot)(struct super_block___16 *, int);
	void (*destroy_dquot)(struct dquot___15 *);
	int (*acquire_dquot)(struct dquot___15 *);
	int (*release_dquot)(struct dquot___15 *);
	int (*mark_dirty)(struct dquot___15 *);
	int (*write_info)(struct super_block___16 *, int);
	qsize_t * (*get_reserved_space)(struct inode___17 *);
	int (*get_projid)(struct inode___17 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___17 *, qsize_t *);
	int (*get_next_id)(struct super_block___16 *, struct kqid *);
};

struct quotactl_ops___15 {
	int (*quota_on)(struct super_block___16 *, int, int, const struct path___15 *);
	int (*quota_off)(struct super_block___16 *, int);
	int (*quota_enable)(struct super_block___16 *, unsigned int);
	int (*quota_disable)(struct super_block___16 *, unsigned int);
	int (*quota_sync)(struct super_block___16 *, int);
	int (*set_info)(struct super_block___16 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___16 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___16 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___16 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___16 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___16 *, unsigned int);
};

struct wait_page_queue___3 {
	struct page___16 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___4;

struct readahead_control___4;

struct swap_info_struct___4;

struct address_space_operations___15 {
	int (*writepage)(struct page___16 *, struct writeback_control___4 *);
	int (*readpage)(struct file___16 *, struct page___16 *);
	int (*writepages)(struct address_space___15 *, struct writeback_control___4 *);
	int (*set_page_dirty)(struct page___16 *);
	int (*readpages)(struct file___16 *, struct address_space___15 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___4 *);
	int (*write_begin)(struct file___16 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___16 **, void **);
	int (*write_end)(struct file___16 *, struct address_space___15 *, loff_t, unsigned int, unsigned int, struct page___16 *, void *);
	sector_t (*bmap)(struct address_space___15 *, sector_t);
	void (*invalidatepage)(struct page___16 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___16 *, gfp_t);
	void (*freepage)(struct page___16 *);
	ssize_t (*direct_IO)(struct kiocb___15 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___15 *, struct page___16 *, struct page___16 *, enum migrate_mode);
	bool (*isolate_page)(struct page___16 *, isolate_mode_t);
	void (*putback_page)(struct page___16 *);
	int (*launder_page)(struct page___16 *);
	int (*is_partially_uptodate)(struct page___16 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___16 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___15 *, struct page___16 *);
	int (*swap_activate)(struct swap_info_struct___4 *, struct file___16 *, sector_t *);
	void (*swap_deactivate)(struct file___16 *);
};

struct writeback_control___4 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___4 *wb;
	struct inode___17 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___4 {
	struct file___16 *file;
	struct address_space___15 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___6;

struct iov_iter___6 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___6 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___4 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___6 *bdev;
	struct file___16 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___15 {
	struct dentry___16 * (*lookup)(struct inode___17 *, struct dentry___16 *, unsigned int);
	const char * (*get_link)(struct dentry___16 *, struct inode___17 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___17 *, int);
	struct posix_acl * (*get_acl)(struct inode___17 *, int, bool);
	int (*readlink)(struct dentry___16 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___17 *, struct dentry___16 *, umode_t, bool);
	int (*link)(struct dentry___16 *, struct inode___17 *, struct dentry___16 *);
	int (*unlink)(struct inode___17 *, struct dentry___16 *);
	int (*symlink)(struct user_namespace *, struct inode___17 *, struct dentry___16 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___17 *, struct dentry___16 *, umode_t);
	int (*rmdir)(struct inode___17 *, struct dentry___16 *);
	int (*mknod)(struct user_namespace *, struct inode___17 *, struct dentry___16 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___17 *, struct dentry___16 *, struct inode___17 *, struct dentry___16 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___16 *, struct iattr___16 *);
	int (*getattr)(struct user_namespace *, const struct path___15 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___16 *, char *, size_t);
	int (*fiemap)(struct inode___17 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___17 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___17 *, struct dentry___16 *, struct file___16 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___17 *, struct dentry___16 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___17 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___16 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___16 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___15 {
	void (*fl_copy_lock)(struct file_lock___15 *, struct file_lock___15 *);
	void (*fl_release_private)(struct file_lock___15 *);
};

struct fasync_struct___15;

struct lock_manager_operations___15;

struct file_lock___15 {
	struct file_lock___15 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___16 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___15 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___15 *fl_ops;
	const struct lock_manager_operations___15 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___15 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___15 *);
	int (*lm_grant)(struct file_lock___15 *, int);
	bool (*lm_break)(struct file_lock___15 *);
	int (*lm_change)(struct file_lock___15 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___15 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___15 *);
};

struct fasync_struct___15 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___15 *fa_next;
	struct file___16 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___15 {
	struct inode___17 * (*alloc_inode)(struct super_block___16 *);
	void (*destroy_inode)(struct inode___17 *);
	void (*free_inode)(struct inode___17 *);
	void (*dirty_inode)(struct inode___17 *, int);
	int (*write_inode)(struct inode___17 *, struct writeback_control___4 *);
	int (*drop_inode)(struct inode___17 *);
	void (*evict_inode)(struct inode___17 *);
	void (*put_super)(struct super_block___16 *);
	int (*sync_fs)(struct super_block___16 *, int);
	int (*freeze_super)(struct super_block___16 *);
	int (*freeze_fs)(struct super_block___16 *);
	int (*thaw_super)(struct super_block___16 *);
	int (*unfreeze_fs)(struct super_block___16 *);
	int (*statfs)(struct dentry___16 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___16 *, int *, char *);
	void (*umount_begin)(struct super_block___16 *);
	int (*show_options)(struct seq_file___17 *, struct dentry___16 *);
	int (*show_devname)(struct seq_file___17 *, struct dentry___16 *);
	int (*show_path)(struct seq_file___17 *, struct dentry___16 *);
	int (*show_stats)(struct seq_file___17 *, struct dentry___16 *);
	ssize_t (*quota_read)(struct super_block___16 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___16 *, int, const char *, size_t, loff_t);
	struct dquot___15 ** (*get_dquots)(struct inode___17 *);
	long int (*nr_cached_objects)(struct super_block___16 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___16 *, struct shrink_control___4 *);
	struct file___16 * (*real_loop)(struct file___16 *);
};

struct block_device___6 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___17 *bd_inode;
	struct super_block___16 *bd_super;
	void *bd_claiming;
	struct device___13 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___15 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___5 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___16 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___5(struct bio___5 *);

struct bio_vec___6 {
	struct page___16 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___5;

struct bio___5 {
	struct bio___5 *bi_next;
	struct block_device___6 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___5 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___5 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___5 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___6 *bi_io_vec;
	struct bio_set___5 *bi_pool;
	struct bio_vec___6 bi_inline_vecs[0];
};

struct seq_operations___15 {
	void * (*start)(struct seq_file___17 *, loff_t *);
	void (*stop)(struct seq_file___17 *, void *);
	void * (*next)(struct seq_file___17 *, void *, loff_t *);
	int (*show)(struct seq_file___17 *, void *);
};

struct cgroup_namespace___9 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___9 *root_cset;
};

struct fwnode_reference_args___13;

struct fwnode_endpoint___13;

struct fwnode_operations___13 {
	struct fwnode_handle___13 * (*get)(struct fwnode_handle___13 *);
	void (*put)(struct fwnode_handle___13 *);
	bool (*device_is_available)(const struct fwnode_handle___13 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___13 *, const struct device___13 *);
	bool (*property_present)(const struct fwnode_handle___13 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___13 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___13 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___13 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_parent)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_next_child_node)(const struct fwnode_handle___13 *, struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*get_named_child_node)(const struct fwnode_handle___13 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___13 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___13 *);
	struct fwnode_handle___13 * (*graph_get_next_endpoint)(const struct fwnode_handle___13 *, struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*graph_get_remote_endpoint)(const struct fwnode_handle___13 *);
	struct fwnode_handle___13 * (*graph_get_port_parent)(struct fwnode_handle___13 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___13 *, struct fwnode_endpoint___13 *);
	int (*add_links)(struct fwnode_handle___13 *);
};

struct fwnode_endpoint___13 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___13 *local_fwnode;
};

struct fwnode_reference_args___13 {
	struct fwnode_handle___13 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___15 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___15 *);
	int (*get)(char *, const struct kernel_param___15 *);
	void (*free)(void *);
};

struct kparam_array___15;

struct kernel_param___15 {
	const char *name;
	struct module___17 *mod;
	const struct kernel_param_ops___15 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___15 *arr;
	};
};

struct kparam_array___15 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___15 *ops;
	void *elem;
};

struct module_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___15 *, struct module_kobject___15 *, char *);
	ssize_t (*store)(struct module_attribute___15 *, struct module_kobject___15 *, const char *, size_t);
	void (*setup)(struct module___17 *, const char *);
	int (*test)(struct module___17 *);
	void (*free)(struct module___17 *);
};

enum cgroup_bpf_attach_type___2 {
	CGROUP_BPF_ATTACH_TYPE_INVALID___2 = 0,
	CGROUP_INET_INGRESS___2 = 0,
	CGROUP_INET_EGRESS___2 = 1,
	CGROUP_INET_SOCK_CREATE___2 = 2,
	CGROUP_SOCK_OPS___2 = 3,
	CGROUP_DEVICE___2 = 4,
	CGROUP_INET4_BIND___2 = 5,
	CGROUP_INET6_BIND___2 = 6,
	CGROUP_INET4_CONNECT___2 = 7,
	CGROUP_INET6_CONNECT___2 = 8,
	CGROUP_INET4_POST_BIND___2 = 9,
	CGROUP_INET6_POST_BIND___2 = 10,
	CGROUP_UDP4_SENDMSG___2 = 11,
	CGROUP_UDP6_SENDMSG___2 = 12,
	CGROUP_SYSCTL___2 = 13,
	CGROUP_UDP4_RECVMSG___2 = 14,
	CGROUP_UDP6_RECVMSG___2 = 15,
	CGROUP_GETSOCKOPT___2 = 16,
	CGROUP_SETSOCKOPT___2 = 17,
	CGROUP_INET4_GETPEERNAME___2 = 18,
	CGROUP_INET6_GETPEERNAME___2 = 19,
	CGROUP_INET4_GETSOCKNAME___2 = 20,
	CGROUP_INET6_GETSOCKNAME___2 = 21,
	CGROUP_INET_SOCK_RELEASE___2 = 22,
	MAX_CGROUP_BPF_ATTACH_TYPE___2 = 23,
};

struct cftype___9;

struct cgroup_subsys___9 {
	struct cgroup_subsys_state___9 * (*css_alloc)(struct cgroup_subsys_state___9 *);
	int (*css_online)(struct cgroup_subsys_state___9 *);
	void (*css_offline)(struct cgroup_subsys_state___9 *);
	void (*css_released)(struct cgroup_subsys_state___9 *);
	void (*css_free)(struct cgroup_subsys_state___9 *);
	void (*css_reset)(struct cgroup_subsys_state___9 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___9 *, int);
	int (*css_extra_stat_show)(struct seq_file___17 *, struct cgroup_subsys_state___9 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___17 *, struct css_set___9 *);
	void (*cancel_fork)(struct task_struct___17 *, struct css_set___9 *);
	void (*fork)(struct task_struct___17 *);
	void (*exit)(struct task_struct___17 *);
	void (*release)(struct task_struct___17 *);
	void (*bind)(struct cgroup_subsys_state___9 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___9 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___9 *dfl_cftypes;
	struct cftype___9 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___9 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___9 *updated_children;
	struct cgroup___9 *updated_next;
};

struct cgroup_root___9 {
	struct kernfs_root___15 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___9 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___9 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___9 *ss;
	struct list_head node;
	struct kernfs_ops___15 *kf_ops;
	int (*open)(struct kernfs_open_file___15 *);
	void (*release)(struct kernfs_open_file___15 *);
	u64 (*read_u64)(struct cgroup_subsys_state___9 *, struct cftype___9 *);
	s64 (*read_s64)(struct cgroup_subsys_state___9 *, struct cftype___9 *);
	int (*seq_show)(struct seq_file___17 *, void *);
	void * (*seq_start)(struct seq_file___17 *, loff_t *);
	void * (*seq_next)(struct seq_file___17 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___17 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___9 *, struct cftype___9 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___9 *, struct cftype___9 *, s64);
	ssize_t (*write)(struct kernfs_open_file___15 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___15 *, struct poll_table_struct___5 *);
};

struct block_device_operations___5;

struct gendisk___5 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___6 *part0;
	const struct block_device_operations___5 *fops;
	struct request_queue___7 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___4 *bdi;
	struct kobject___15 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___15 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___5 {
	struct bio___5 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___6 *bip_vec;
	struct bio_vec___6 bip_inline_vecs[0];
};

struct blkcg___4;

struct blkg_policy_data___4;

struct blkcg_gq___5 {
	struct request_queue___7 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___4 *blkcg;
	struct blkcg_gq___5 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___4 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___5 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___5(struct request___6 *);

typedef void integrity_complete_fn___5(struct request___6 *, unsigned int);

struct blk_integrity_profile___5 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___5 *prepare_fn;
	integrity_complete_fn___5 *complete_fn;
	const char *name;
};

struct block_device_operations___5 {
	blk_qc_t (*submit_bio)(struct bio___5 *);
	int (*open)(struct block_device___6 *, fmode_t);
	void (*release)(struct gendisk___5 *, fmode_t);
	int (*rw_page)(struct block_device___6 *, sector_t, struct page___16 *, unsigned int);
	int (*ioctl)(struct block_device___6 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___6 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___5 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___5 *);
	int (*getgeo)(struct block_device___6 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___6 *, bool);
	void (*swap_slot_free_notify)(struct block_device___6 *, long unsigned int);
	int (*report_zones)(struct gendisk___5 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___5 *, umode_t *);
	struct module___17 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___5 *, sector_t *);
};

typedef void rq_end_io_fn___5(struct request___6 *, blk_status_t);

struct request___6 {
	struct request_queue___7 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___5 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___5 *bio;
	struct bio___5 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___6 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___5 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___5 *saved_end_io;
		} flush;
	};
	struct gendisk___5 *rq_disk;
	struct block_device___6 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___5 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___5 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___7 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___15 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___16 *debugfs_dir;
	struct dentry___16 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___5;

struct elevator_mq_ops___5 {
	int (*init_sched)(struct request_queue___7 *, struct elevator_type___5 *);
	void (*exit_sched)(struct elevator_queue___5 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___5 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___5 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___5 *);
	bool (*allow_merge)(struct request_queue___7 *, struct request___6 *, struct bio___5 *);
	bool (*bio_merge)(struct request_queue___7 *, struct bio___5 *, unsigned int);
	int (*request_merge)(struct request_queue___7 *, struct request___6 **, struct bio___5 *);
	void (*request_merged)(struct request_queue___7 *, struct request___6 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___7 *, struct request___6 *, struct request___6 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___6 *);
	void (*finish_request)(struct request___6 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___5 *, struct list_head *, bool);
	struct request___6 * (*dispatch_request)(struct blk_mq_hw_ctx___5 *);
	bool (*has_work)(struct blk_mq_hw_ctx___5 *);
	void (*completed_request)(struct request___6 *, u64);
	void (*requeue_request)(struct request___6 *);
	struct request___6 * (*former_request)(struct request_queue___7 *, struct request___6 *);
	struct request___6 * (*next_request)(struct request_queue___7 *, struct request___6 *);
	void (*init_icq)(struct io_cq___5 *);
	void (*exit_icq)(struct io_cq___5 *);
};

struct elv_fs_entry___5;

struct elevator_type___5 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___5 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___5 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___17 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___5 {
	struct elevator_type___5 *type;
	void *elevator_data;
	struct kobject___15 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___5 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___5 *, char *);
	ssize_t (*store)(struct elevator_queue___5 *, const char *, size_t);
};

struct blk_mq_queue_data___5;

struct blk_mq_ops___5 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___5 *, const struct blk_mq_queue_data___5 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___5 *);
	int (*get_budget)(struct request_queue___7 *);
	void (*put_budget)(struct request_queue___7 *, int);
	void (*set_rq_budget_token)(struct request___6 *, int);
	int (*get_rq_budget_token)(struct request___6 *);
	enum blk_eh_timer_return (*timeout)(struct request___6 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___5 *);
	void (*complete)(struct request___6 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___5 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___5 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___5 *, struct request___6 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___5 *, struct request___6 *, unsigned int);
	void (*initialize_rq_fn)(struct request___6 *);
	void (*cleanup_rq)(struct request___6 *);
	bool (*busy)(struct request_queue___7 *);
	int (*map_queues)(struct blk_mq_tag_set___5 *);
	void (*show_rq)(struct seq_file___17 *, struct request___6 *);
};

struct blk_mq_tag_set___5 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___5 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___5 {
	struct request___6 *rq;
	bool last;
};

struct blkcg_policy_data___4;

struct blkcg___4 {
	struct cgroup_subsys_state___9 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___5 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___4 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___4 {
	struct blkcg___4 *blkcg;
	int plid;
};

struct blkg_policy_data___4 {
	struct blkcg_gq___5 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___4 {
	struct mem_cgroup___4 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___4 {
	struct lruvec___5 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___4 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___4 *memcg;
};

struct obj_cgroup___4 {
	struct percpu_ref refcnt;
	struct mem_cgroup___4 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct break_hook___2 {
	struct list_head node;
	int (*fn)(struct pt_regs___2 *, unsigned int);
	u16 imm;
	u16 mask;
};

typedef u32 probe_opcode_t;

typedef void probes_handler_t(u32, long int, struct pt_regs___2 *);

struct arch_probe_insn {
	probe_opcode_t *insn;
	pstate_check_t *pstate_cc;
	probes_handler_t *handler;
	long unsigned int restore;
};

typedef u32 kprobe_opcode_t;

struct arch_specific_insn {
	struct arch_probe_insn api;
};

struct freelist_node {
	atomic_t refs;
	struct freelist_node *next;
};

struct freelist_head {
	struct freelist_node *head;
};

struct kprobe;

struct prev_kprobe {
	struct kprobe *kp;
	unsigned int status;
};

typedef int (*kprobe_pre_handler_t)(struct kprobe *, struct pt_regs___2 *);

typedef void (*kprobe_post_handler_t)(struct kprobe *, struct pt_regs___2 *, long unsigned int);

struct kprobe {
	struct hlist_node hlist;
	struct list_head list;
	long unsigned int nmissed;
	kprobe_opcode_t *addr;
	const char *symbol_name;
	unsigned int offset;
	kprobe_pre_handler_t pre_handler;
	kprobe_post_handler_t post_handler;
	kprobe_opcode_t opcode;
	struct arch_specific_insn ainsn;
	u32 flags;
};

struct kprobe_ctlblk {
	unsigned int kprobe_status;
	long unsigned int saved_irqflag;
	struct prev_kprobe prev_kprobe;
};

struct kretprobe_instance;

typedef int (*kretprobe_handler_t)(struct kretprobe_instance *, struct pt_regs___2 *);

struct kretprobe_holder;

struct kretprobe_instance {
	union {
		struct freelist_node freelist;
		struct callback_head rcu;
	};
	struct llist_node llist;
	struct kretprobe_holder *rph;
	kprobe_opcode_t *ret_addr;
	void *fp;
	char data[0];
};

struct kretprobe;

struct kretprobe_holder {
	struct kretprobe *rp;
	refcount_t ref;
};

struct kretprobe {
	struct kprobe kp;
	kretprobe_handler_t handler;
	kretprobe_handler_t entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct freelist_head freelist;
	struct kretprobe_holder *rph;
};

struct kprobe_insn_cache {
	struct mutex mutex;
	void * (*alloc)();
	void (*free)(void *);
	const char *sym;
	struct list_head pages;
	size_t insn_size;
	int nr_garbage;
};

enum probe_insn {
	INSN_REJECTED = 0,
	INSN_GOOD_NO_SLOT = 1,
	INSN_GOOD = 2,
};

enum aarch64_insn_encoding_class {
	AARCH64_INSN_CLS_UNKNOWN = 0,
	AARCH64_INSN_CLS_SVE = 1,
	AARCH64_INSN_CLS_DP_IMM = 2,
	AARCH64_INSN_CLS_DP_REG = 3,
	AARCH64_INSN_CLS_DP_FPSIMD = 4,
	AARCH64_INSN_CLS_LDST = 5,
	AARCH64_INSN_CLS_BR_SYS = 6,
};

enum aarch64_insn_special_register {
	AARCH64_INSN_SPCLREG_SPSR_EL1 = 49664,
	AARCH64_INSN_SPCLREG_ELR_EL1 = 49665,
	AARCH64_INSN_SPCLREG_SP_EL0 = 49672,
	AARCH64_INSN_SPCLREG_SPSEL = 49680,
	AARCH64_INSN_SPCLREG_CURRENTEL = 49682,
	AARCH64_INSN_SPCLREG_DAIF = 55825,
	AARCH64_INSN_SPCLREG_NZCV = 55824,
	AARCH64_INSN_SPCLREG_FPCR = 55840,
	AARCH64_INSN_SPCLREG_DSPSR_EL0 = 55848,
	AARCH64_INSN_SPCLREG_DLR_EL0 = 55849,
	AARCH64_INSN_SPCLREG_SPSR_EL2 = 57856,
	AARCH64_INSN_SPCLREG_ELR_EL2 = 57857,
	AARCH64_INSN_SPCLREG_SP_EL1 = 57864,
	AARCH64_INSN_SPCLREG_SPSR_INQ = 57880,
	AARCH64_INSN_SPCLREG_SPSR_ABT = 57881,
	AARCH64_INSN_SPCLREG_SPSR_UND = 57882,
	AARCH64_INSN_SPCLREG_SPSR_FIQ = 57883,
	AARCH64_INSN_SPCLREG_SPSR_EL3 = 61952,
	AARCH64_INSN_SPCLREG_ELR_EL3 = 61953,
	AARCH64_INSN_SPCLREG_SP_EL2 = 61968,
};

struct arch_probe_insn___2 {
	probe_opcode_t *insn;
	pstate_check_t *pstate_cc;
	probes_handler_t *handler;
	long unsigned int restore;
};

struct arch_specific_insn___2 {
	struct arch_probe_insn___2 api;
};

typedef void probes_handler_t___2(u32, long int, struct pt_regs *);

struct arch_probe_insn___3 {
	probe_opcode_t *insn;
	pstate_check_t *pstate_cc;
	probes_handler_t___2 *handler;
	long unsigned int restore;
};

struct arch_uprobe {
	union {
		u8 insn[4];
		u8 ixol[4];
	};
	struct arch_probe_insn___3 api;
	bool simulate;
};

enum rp_check {
	RP_CHECK_CALL = 0,
	RP_CHECK_CHAIN_CALL = 1,
	RP_CHECK_RET = 2,
};

struct io_tlb_slot;

struct io_tlb_mem {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___4 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct iommu_fault_param;

struct iopf_device_param;

struct iommu_fwspec;

struct dev_iommu {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec *fwspec;
	struct iommu_device *iommu_dev;
	void *priv;
};

struct sg_table {
	struct scatterlist *sgl;
	unsigned int nents;
	unsigned int orig_nents;
};

struct of_phandle_args {
	struct device_node___2 *np;
	int args_count;
	uint32_t args[16];
};

struct iommu_fault_unrecoverable {
	__u32 reason;
	__u32 flags;
	__u32 pasid;
	__u32 perm;
	__u64 addr;
	__u64 fetch_addr;
};

struct iommu_fault_page_request {
	__u32 flags;
	__u32 pasid;
	__u32 grpid;
	__u32 perm;
	__u64 addr;
	__u64 private_data[2];
};

struct iommu_fault {
	__u32 type;
	__u32 padding;
	union {
		struct iommu_fault_unrecoverable event;
		struct iommu_fault_page_request prm;
		__u8 padding2[56];
	};
};

struct iommu_page_response {
	__u32 argsz;
	__u32 version;
	__u32 flags;
	__u32 pasid;
	__u32 grpid;
	__u32 code;
};

struct iommu_inv_addr_info {
	__u32 flags;
	__u32 archid;
	__u64 pasid;
	__u64 addr;
	__u64 granule_size;
	__u64 nb_granules;
};

struct iommu_inv_pasid_info {
	__u32 flags;
	__u32 archid;
	__u64 pasid;
};

struct iommu_cache_invalidate_info {
	__u32 argsz;
	__u32 version;
	__u8 cache;
	__u8 granularity;
	__u8 padding[6];
	union {
		struct iommu_inv_pasid_info pasid_info;
		struct iommu_inv_addr_info addr_info;
	} granu;
};

struct iommu_gpasid_bind_data_vtd {
	__u64 flags;
	__u32 pat;
	__u32 emt;
};

struct iommu_gpasid_bind_data {
	__u32 argsz;
	__u32 version;
	__u32 format;
	__u32 addr_width;
	__u64 flags;
	__u64 gpgd;
	__u64 hpasid;
	__u64 gpasid;
	__u8 padding[8];
	union {
		struct iommu_gpasid_bind_data_vtd vtd;
	} vendor;
};

typedef int (*iommu_fault_handler_t)(struct iommu_domain *, struct device___2 *, long unsigned int, int, void *);

struct iommu_domain_geometry {
	dma_addr_t aperture_start;
	dma_addr_t aperture_end;
	bool force_aperture;
};

struct iommu_dma_cookie;

struct iommu_domain {
	unsigned int type;
	const struct iommu_ops *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

typedef int (*iommu_dev_fault_handler_t)(struct iommu_fault *, void *);

enum iommu_resv_type {
	IOMMU_RESV_DIRECT = 0,
	IOMMU_RESV_DIRECT_RELAXABLE = 1,
	IOMMU_RESV_RESERVED = 2,
	IOMMU_RESV_MSI = 3,
	IOMMU_RESV_SW_MSI = 4,
};

struct iommu_resv_region {
	struct list_head list;
	phys_addr_t start;
	size_t length;
	int prot;
	enum iommu_resv_type type;
};

struct iommu_iotlb_gather {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___3 *freelist;
	bool queued;
};

struct iommu_device {
	struct list_head list;
	const struct iommu_ops *ops;
	struct fwnode_handle___6 *fwnode;
	struct device___2 *dev;
};

struct iommu_sva {
	struct device___2 *dev;
};

struct iommu_fault_event {
	struct iommu_fault fault;
	struct list_head list;
};

struct iommu_fault_param {
	iommu_dev_fault_handler_t handler;
	void *data;
	struct list_head faults;
	struct mutex lock;
};

struct iommu_fwspec {
	const struct iommu_ops *ops;
	struct fwnode_handle___6 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

enum xen_domain_type {
	XEN_NATIVE = 0,
	XEN_PV_DOMAIN = 1,
	XEN_HVM_DOMAIN = 2,
};

struct io_tlb_slot {
	phys_addr_t orig_addr;
	size_t alloc_size;
	unsigned int list;
};

struct irq_desc___9;

typedef void (*irq_flow_handler_t___9)(struct irq_desc___9 *);

struct irq_chip___8;

struct irq_domain___8;

struct irq_data___8 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___8 *chip;
	struct irq_domain___8 *domain;
	struct irq_data___8 *parent_data;
	void *chip_data;
};

struct kset___16;

struct kobj_type___16;

struct kernfs_node___16;

struct kobject___16 {
	const char *name;
	struct list_head entry;
	struct kobject___16 *parent;
	struct kset___16 *kset;
	struct kobj_type___16 *ktype;
	struct kernfs_node___16 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___7;

struct module___18;

struct irq_desc___9 {
	struct irq_common_data irq_common_data;
	struct irq_data___8 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___9 handle_irq;
	struct irqaction___7 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___16 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___18 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___17;

struct super_block___17;

struct file_system_type___16 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___17 * (*mount)(struct file_system_type___16 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___17 *);
	struct module___18 *owner;
	struct file_system_type___16 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___17;

struct kiocb___16;

struct poll_table_struct___12;

struct vm_area_struct___16;

struct inode___18;

struct file_lock___16;

struct page___17;

struct seq_file___18;

struct file_operations___16 {
	struct module___18 *owner;
	loff_t (*llseek)(struct file___17 *, loff_t, int);
	ssize_t (*read)(struct file___17 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___17 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___16 *, struct iov_iter *);
	ssize_t (*write_iter)(struct kiocb___16 *, struct iov_iter *);
	int (*iopoll)(struct kiocb___16 *, bool);
	int (*iterate)(struct file___17 *, struct dir_context *);
	int (*iterate_shared)(struct file___17 *, struct dir_context *);
	__poll_t (*poll)(struct file___17 *, struct poll_table_struct___12 *);
	long int (*unlocked_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___17 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___17 *, struct vm_area_struct___16 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___18 *, struct file___17 *);
	int (*flush)(struct file___17 *, fl_owner_t);
	int (*release)(struct inode___18 *, struct file___17 *);
	int (*fsync)(struct file___17 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___17 *, int);
	int (*lock)(struct file___17 *, int, struct file_lock___16 *);
	ssize_t (*sendpage)(struct file___17 *, struct page___17 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___17 *, long unsigned int);
	int (*flock)(struct file___17 *, int, struct file_lock___16 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___17 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___17 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___17 *, long int, struct file_lock___16 **, void **);
	long int (*fallocate)(struct file___17 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___18 *, struct file___17 *);
	ssize_t (*copy_file_range)(struct file___17 *, loff_t, struct file___17 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___17 *, loff_t, struct file___17 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___17 *, loff_t, loff_t, int);
};

struct vmacache___16 {
	u64 seqnum;
	struct vm_area_struct___16 *vmas[4];
};

struct page_frag___16 {
	struct page___17 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___9;

struct debug_info___9 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___9 *hbp_break[16];
	struct perf_event___9 *hbp_watch[16];
};

struct thread_struct___9 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___9 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___17;

struct pid___15;

struct nsproxy___16;

struct signal_struct___17;

struct css_set___10;

struct perf_event_context___9;

struct vm_struct___16;

struct task_struct___18 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___18 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___17 *mm;
	struct mm_struct___17 *active_mm;
	struct vmacache___16 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___18 *real_parent;
	struct task_struct___18 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___18 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___15 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___16 *nsproxy;
	struct signal_struct___17 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___18 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___10 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___9 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___16 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___18 *oom_reaper_list;
	struct vm_struct___16 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___9 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct {
	pgd_t pgd;
} p4d_t;

struct module_kobject___16 {
	struct kobject___16 kobj;
	struct module___18 *mod;
	struct kobject___16 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___16 {
	struct module___18 *mod;
	struct latch_tree_node node;
};

struct module_layout___16 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___16 mtn;
};

struct module_attribute___16;

struct kernel_param___16;

struct module___18 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___16 mkobj;
	struct module_attribute___16 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___16 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___16 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___16 core_layout;
	struct module_layout___16 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___9 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___18 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___9)(struct perf_event___9 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___9;

struct fasync_struct___16;

struct pid_namespace___15;

struct perf_cgroup___9;

struct perf_event___9 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___9 *group_leader;
	struct pmu___9 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___9 hw;
	struct perf_event_context___9 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___9 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___18 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___16 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___9 *aux_event;
	void (*destroy)(struct perf_event___9 *);
	struct callback_head callback_head;
	struct pid_namespace___15 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___9 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___9 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___9 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___17 *pgtable_t___16;

struct address_space___16;

struct dev_pagemap___16;

struct page___17 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___16 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___17 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___16 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___17 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___16 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___16;

struct vm_area_struct___16 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___16 *vm_next;
	struct vm_area_struct___16 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___17 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___16 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___17 *vm_file;
	struct file___17 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___16;

struct mm_struct___17 {
	struct {
		struct vm_area_struct___16 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___17 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___16 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___18 *owner;
		struct user_namespace *user_ns;
		struct file___17 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct arch_specific_insn___3 {
	struct arch_probe_insn___3 api;
};

struct address_space_operations___16;

struct address_space___16 {
	struct inode___18 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___16 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___16;

struct dev_pagemap___16 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___16 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___16;

struct path___16 {
	struct vfsmount___16 *mnt;
	struct dentry___17 *dentry;
};

struct fown_struct___15 {
	rwlock_t lock;
	struct pid___15 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___17 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___16 f_path;
	struct inode___18 *f_inode;
	const struct file_operations___16 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___15 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___16 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___16;

struct vm_operations_struct___16 {
	void (*open)(struct vm_area_struct___16 *);
	void (*close)(struct vm_area_struct___16 *);
	int (*may_split)(struct vm_area_struct___16 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___16 *);
	int (*mprotect)(struct vm_area_struct___16 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___16 *);
	vm_fault_t (*huge_fault)(struct vm_fault___16 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___16 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___16 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___16 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___16 *);
	int (*access)(struct vm_area_struct___16 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___16 *);
	int (*set_policy)(struct vm_area_struct___16 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___16 *, long unsigned int);
	struct page___17 * (*find_special_page)(struct vm_area_struct___16 *, long unsigned int);
};

struct core_thread___16 {
	struct task_struct___18 *task;
	struct core_thread___16 *next;
};

struct core_state___16 {
	atomic_t nr_threads;
	struct core_thread___16 dumper;
	struct completion startup;
};

struct vm_fault___16 {
	const struct {
		struct vm_area_struct___16 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___17 *cow_page;
	struct page___17 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___16 prealloc_pte;
};

struct kernfs_root___16;

struct kernfs_elem_dir___16 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___16 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___16;

struct kernfs_root___16 {
	struct kernfs_node___16 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___16 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___16 {
	struct kernfs_node___16 *target_kn;
};

struct kernfs_ops___16;

struct kernfs_elem_attr___16 {
	const struct kernfs_ops___16 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___16 *notify_next;
};

struct kernfs_node___16 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___16 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___16 dir;
		struct kernfs_elem_symlink___16 symlink;
		struct kernfs_elem_attr___16 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___16;

struct kernfs_ops___16 {
	int (*open)(struct kernfs_open_file___16 *);
	void (*release)(struct kernfs_open_file___16 *);
	int (*seq_show)(struct seq_file___18 *, void *);
	void * (*seq_start)(struct seq_file___18 *, loff_t *);
	void * (*seq_next)(struct seq_file___18 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___18 *, void *);
	ssize_t (*read)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___16 *, struct poll_table_struct___12 *);
	int (*mmap)(struct kernfs_open_file___16 *, struct vm_area_struct___16 *);
};

struct kernfs_syscall_ops___16 {
	int (*show_options)(struct seq_file___18 *, struct kernfs_root___16 *);
	int (*mkdir)(struct kernfs_node___16 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___16 *);
	int (*rename)(struct kernfs_node___16 *, struct kernfs_node___16 *, const char *);
	int (*show_path)(struct seq_file___18 *, struct kernfs_node___16 *, struct kernfs_root___16 *);
};

struct seq_operations___16;

struct seq_file___18 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___16 *op;
	int poll_event;
	const struct file___17 *file;
	void *private;
};

struct kernfs_open_file___16 {
	struct kernfs_node___16 *kn;
	struct file___17 *file;
	struct seq_file___18 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___16 *vm_ops;
};

typedef void (*poll_queue_proc___12)(struct file___17 *, wait_queue_head_t *, struct poll_table_struct___12 *);

struct poll_table_struct___12 {
	poll_queue_proc___12 _qproc;
	__poll_t _key;
};

struct upid___15 {
	int nr;
	struct pid_namespace___15 *ns;
};

struct pid_namespace___15 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___18 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___15 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___15 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___15 numbers[1];
};

struct signal_struct___17 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___18 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___18 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___15 *pids[4];
	struct pid___15 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___17 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___10;

struct nsproxy___16 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___15 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___10 *cgroup_ns;
};

struct cgroup_subsys_state___10;

struct cgroup___10;

struct css_set___10 {
	struct cgroup_subsys_state___10 *subsys[14];
	refcount_t refcount;
	struct css_set___10 *dom_cset;
	struct cgroup___10 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___10 *mg_src_cgrp;
	struct cgroup___10 *mg_dst_cgrp;
	struct css_set___10 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___9 {
	struct pmu___9 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___18 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___9 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___16 {
	struct vm_struct___16 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___17 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___16;

struct attribute_group___16 {
	const char *name;
	umode_t (*is_visible)(struct kobject___16 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___16 *, struct bin_attribute___16 *, int);
	struct attribute **attrs;
	struct bin_attribute___16 **bin_attrs;
};

struct bin_attribute___16 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___16 * (*f_mapping)();
	ssize_t (*read)(struct file___17 *, struct kobject___16 *, struct bin_attribute___16 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___17 *, struct kobject___16 *, struct bin_attribute___16 *, char *, loff_t, size_t);
	int (*mmap)(struct file___17 *, struct kobject___16 *, struct bin_attribute___16 *, struct vm_area_struct___16 *);
};

struct sysfs_ops___16 {
	ssize_t (*show)(struct kobject___16 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___16 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___16;

struct kset___16 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___16 kobj;
	const struct kset_uevent_ops___16 *uevent_ops;
};

struct kobj_type___16 {
	void (*release)(struct kobject___16 *);
	const struct sysfs_ops___16 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___16 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___16 *);
	const void * (*namespace)(struct kobject___16 *);
	void (*get_ownership)(struct kobject___16 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___16 {
	int (* const filter)(struct kset___16 *, struct kobject___16 *);
	const char * (* const name)(struct kset___16 *, struct kobject___16 *);
	int (* const uevent)(struct kset___16 *, struct kobject___16 *, struct kobj_uevent_env *);
};

struct fwnode_operations___14;

struct device___14;

struct fwnode_handle___14 {
	struct fwnode_handle___14 *secondary;
	const struct fwnode_operations___14 *ops;
	struct device___14 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___14;

struct fwnode_endpoint___14;

struct fwnode_operations___14 {
	struct fwnode_handle___14 * (*get)(struct fwnode_handle___14 *);
	void (*put)(struct fwnode_handle___14 *);
	bool (*device_is_available)(const struct fwnode_handle___14 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___14 *, const struct device___14 *);
	bool (*property_present)(const struct fwnode_handle___14 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___14 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___14 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___14 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_parent)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_next_child_node)(const struct fwnode_handle___14 *, struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*get_named_child_node)(const struct fwnode_handle___14 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___14 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___14 *);
	struct fwnode_handle___14 * (*graph_get_next_endpoint)(const struct fwnode_handle___14 *, struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*graph_get_remote_endpoint)(const struct fwnode_handle___14 *);
	struct fwnode_handle___14 * (*graph_get_port_parent)(struct fwnode_handle___14 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___14 *, struct fwnode_endpoint___14 *);
	int (*add_links)(struct fwnode_handle___14 *);
};

struct wakeup_source___14;

struct dev_pm_info___14 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___14 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___14 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___14;

struct bus_type___14;

struct device_driver___14;

struct dev_pm_domain___14;

struct device_node___9;

struct class___14;

struct device___14 {
	struct kobject___16 kobj;
	struct device___14 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___14 *type;
	struct bus_type___14 *bus;
	struct device_driver___14 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___14 power;
	struct dev_pm_domain___14 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___8 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___9 *of_node;
	struct fwnode_handle___14 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___14 *class;
	const struct attribute_group___16 **groups;
	void (*release)(struct device___14 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___14 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___14 *local_fwnode;
};

struct fwnode_reference_args___14 {
	struct fwnode_handle___14 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___7 {
	char *name;
	int length;
	void *value;
	struct property___7 *next;
	long unsigned int _flags;
	struct bin_attribute___16 attr;
};

struct device_node___9 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___14 fwnode;
	struct property___7 *properties;
	struct property___7 *deadprops;
	struct device_node___9 *parent;
	struct device_node___9 *child;
	struct device_node___9 *sibling;
	struct kobject___16 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___8 {
	struct fwnode_handle___14 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___8 {
	int (*match)(struct irq_domain___8 *, struct device_node___9 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___8 *, struct irq_fwspec___8 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___8 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___8 *, unsigned int);
	int (*xlate)(struct irq_domain___8 *, struct device_node___9 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___8 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___8 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___8 *, struct irq_data___8 *, bool);
	void (*deactivate)(struct irq_domain___8 *, struct irq_data___8 *);
	int (*translate)(struct irq_domain___8 *, struct irq_fwspec___8 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___8;

struct irq_domain___8 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___8 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___14 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___8 *gc;
	struct irq_domain___8 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___8 *revmap[0];
};

struct irq_chip_generic___8;

struct irq_domain_chip_generic___8 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___8 *gc[0];
};

struct dev_pm_ops___14 {
	int (*prepare)(struct device___14 *);
	void (*complete)(struct device___14 *);
	int (*suspend)(struct device___14 *);
	int (*resume)(struct device___14 *);
	int (*freeze)(struct device___14 *);
	int (*thaw)(struct device___14 *);
	int (*poweroff)(struct device___14 *);
	int (*restore)(struct device___14 *);
	int (*suspend_late)(struct device___14 *);
	int (*resume_early)(struct device___14 *);
	int (*freeze_late)(struct device___14 *);
	int (*thaw_early)(struct device___14 *);
	int (*poweroff_late)(struct device___14 *);
	int (*restore_early)(struct device___14 *);
	int (*suspend_noirq)(struct device___14 *);
	int (*resume_noirq)(struct device___14 *);
	int (*freeze_noirq)(struct device___14 *);
	int (*thaw_noirq)(struct device___14 *);
	int (*poweroff_noirq)(struct device___14 *);
	int (*restore_noirq)(struct device___14 *);
	int (*runtime_suspend)(struct device___14 *);
	int (*runtime_resume)(struct device___14 *);
	int (*runtime_idle)(struct device___14 *);
};

struct wakeup_source___14 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___14 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___14 {
	struct dev_pm_ops___14 ops;
	int (*start)(struct device___14 *);
	void (*detach)(struct device___14 *, bool);
	int (*activate)(struct device___14 *);
	void (*sync)(struct device___14 *);
	void (*dismiss)(struct device___14 *);
};

struct bus_type___14 {
	const char *name;
	const char *dev_name;
	struct device___14 *dev_root;
	const struct attribute_group___16 **bus_groups;
	const struct attribute_group___16 **dev_groups;
	const struct attribute_group___16 **drv_groups;
	int (*match)(struct device___14 *, struct device_driver___14 *);
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	int (*probe)(struct device___14 *);
	void (*sync_state)(struct device___14 *);
	void (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*online)(struct device___14 *);
	int (*offline)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	int (*num_vf)(struct device___14 *);
	int (*dma_configure)(struct device___14 *);
	const struct dev_pm_ops___14 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___14 {
	const char *name;
	struct bus_type___14 *bus;
	struct module___18 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___14 *);
	void (*sync_state)(struct device___14 *);
	int (*remove)(struct device___14 *);
	void (*shutdown)(struct device___14 *);
	int (*suspend)(struct device___14 *, pm_message_t);
	int (*resume)(struct device___14 *);
	const struct attribute_group___16 **groups;
	const struct attribute_group___16 **dev_groups;
	const struct dev_pm_ops___14 *pm;
	void (*coredump)(struct device___14 *);
	struct driver_private *p;
};

struct device_type___14 {
	const char *name;
	const struct attribute_group___16 **groups;
	int (*uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___14 *);
	const struct dev_pm_ops___14 *pm;
};

struct class___14 {
	const char *name;
	struct module___18 *owner;
	const struct attribute_group___16 **class_groups;
	const struct attribute_group___16 **dev_groups;
	struct kobject___16 *dev_kobj;
	int (*dev_uevent)(struct device___14 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___14 *, umode_t *);
	void (*class_release)(struct class___14 *);
	void (*dev_release)(struct device___14 *);
	int (*shutdown_pre)(struct device___14 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___14 *);
	void (*get_ownership)(struct device___14 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___14 *pm;
	struct subsys_private *p;
};

struct dentry_operations___16;

struct dentry___17 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___17 *d_parent;
	struct qstr d_name;
	struct inode___18 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___16 *d_op;
	struct super_block___17 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___16;

struct cdev___9;

struct inode___18 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___16 *i_op;
	struct super_block___17 *i_sb;
	struct address_space___16 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___16 *i_fop;
		void (*free_inode)(struct inode___18 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___16 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___9 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___16 {
	int (*d_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___17 *, unsigned int);
	int (*d_hash)(const struct dentry___17 *, struct qstr *);
	int (*d_compare)(const struct dentry___17 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___17 *);
	int (*d_init)(struct dentry___17 *);
	void (*d_release)(struct dentry___17 *);
	void (*d_prune)(struct dentry___17 *);
	void (*d_iput)(struct dentry___17 *, struct inode___18 *);
	char * (*d_dname)(struct dentry___17 *, char *, int);
	struct vfsmount___16 * (*d_automount)(struct path___16 *);
	int (*d_manage)(const struct path___16 *, bool);
	struct dentry___17 * (*d_real)(struct dentry___17 *, const struct inode___18 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___16;

struct mem_dqinfo___16 {
	struct quota_format_type___16 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___16;

struct quota_info___16 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___18 *files[3];
	struct mem_dqinfo___16 info[3];
	const struct quota_format_ops___16 *ops[3];
};

struct rcuwait___16 {
	struct task_struct___18 *task;
};

struct percpu_rw_semaphore___16 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___16 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___16 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___16 rw_sem[3];
};

struct super_operations___16;

struct dquot_operations___16;

struct quotactl_ops___16;

struct super_block___17 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___16 *s_type;
	const struct super_operations___16 *s_op;
	const struct dquot_operations___16 *dq_op;
	const struct quotactl_ops___16 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___17 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___16 s_dquot;
	struct sb_writers___16 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___16 *s_d_op;
	int cleancache_poolid;
	struct shrinker s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___16 {
	struct dentry___17 *mnt_root;
	struct super_block___17 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___10;

struct cgroup_subsys_state___10 {
	struct cgroup___10 *cgroup;
	struct cgroup_subsys___10 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___10 *parent;
};

struct cgroup_file___10 {
	struct kernfs_node___16 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___10 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___18 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___10;

struct cgroup_rstat_cpu___10;

struct cgroup___10 {
	struct cgroup_subsys_state___10 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___16 *kn;
	struct cgroup_file___10 procs_file;
	struct cgroup_file___10 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___10 *subsys[14];
	struct cgroup_root___10 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___10 *dom_cgrp;
	struct cgroup___10 *old_dom_cgrp;
	struct cgroup_rstat_cpu___10 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___10 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___4;

struct kiocb___16 {
	struct file___17 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___16 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___4 *ki_waitq;
	};
};

struct iattr___17 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___17 *ia_file;
};

struct dquot___16 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___17 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___16 {
	int qf_fmt_id;
	const struct quota_format_ops___16 *qf_ops;
	struct module___18 *qf_owner;
	struct quota_format_type___16 *qf_next;
};

struct quota_format_ops___16 {
	int (*check_quota_file)(struct super_block___17 *, int);
	int (*read_file_info)(struct super_block___17 *, int);
	int (*write_file_info)(struct super_block___17 *, int);
	int (*free_file_info)(struct super_block___17 *, int);
	int (*read_dqblk)(struct dquot___16 *);
	int (*commit_dqblk)(struct dquot___16 *);
	int (*release_dqblk)(struct dquot___16 *);
	int (*get_next_id)(struct super_block___17 *, struct kqid *);
};

struct dquot_operations___16 {
	int (*write_dquot)(struct dquot___16 *);
	struct dquot___16 * (*alloc_dquot)(struct super_block___17 *, int);
	void (*destroy_dquot)(struct dquot___16 *);
	int (*acquire_dquot)(struct dquot___16 *);
	int (*release_dquot)(struct dquot___16 *);
	int (*mark_dirty)(struct dquot___16 *);
	int (*write_info)(struct super_block___17 *, int);
	qsize_t * (*get_reserved_space)(struct inode___18 *);
	int (*get_projid)(struct inode___18 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___18 *, qsize_t *);
	int (*get_next_id)(struct super_block___17 *, struct kqid *);
};

struct quotactl_ops___16 {
	int (*quota_on)(struct super_block___17 *, int, int, const struct path___16 *);
	int (*quota_off)(struct super_block___17 *, int);
	int (*quota_enable)(struct super_block___17 *, unsigned int);
	int (*quota_disable)(struct super_block___17 *, unsigned int);
	int (*quota_sync)(struct super_block___17 *, int);
	int (*set_info)(struct super_block___17 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___17 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___17 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___17 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___17 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___17 *, unsigned int);
};

struct wait_page_queue___4 {
	struct page___17 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___5;

struct address_space_operations___16 {
	int (*writepage)(struct page___17 *, struct writeback_control___3 *);
	int (*readpage)(struct file___17 *, struct page___17 *);
	int (*writepages)(struct address_space___16 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___17 *);
	int (*readpages)(struct file___17 *, struct address_space___16 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___5 *);
	int (*write_begin)(struct file___17 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___17 **, void **);
	int (*write_end)(struct file___17 *, struct address_space___16 *, loff_t, unsigned int, unsigned int, struct page___17 *, void *);
	sector_t (*bmap)(struct address_space___16 *, sector_t);
	void (*invalidatepage)(struct page___17 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___17 *, gfp_t);
	void (*freepage)(struct page___17 *);
	ssize_t (*direct_IO)(struct kiocb___16 *, struct iov_iter *);
	int (*migratepage)(struct address_space___16 *, struct page___17 *, struct page___17 *, enum migrate_mode);
	bool (*isolate_page)(struct page___17 *, isolate_mode_t);
	void (*putback_page)(struct page___17 *);
	int (*launder_page)(struct page___17 *);
	int (*is_partially_uptodate)(struct page___17 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___17 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___16 *, struct page___17 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___17 *, sector_t *);
	void (*swap_deactivate)(struct file___17 *);
};

struct readahead_control___5 {
	struct file___17 *file;
	struct address_space___16 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct cdev___9 {
	struct kobject___16 kobj;
	struct module___18 *owner;
	const struct file_operations___16 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___16 {
	struct dentry___17 * (*lookup)(struct inode___18 *, struct dentry___17 *, unsigned int);
	const char * (*get_link)(struct dentry___17 *, struct inode___18 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___18 *, int);
	struct posix_acl * (*get_acl)(struct inode___18 *, int, bool);
	int (*readlink)(struct dentry___17 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___18 *, struct dentry___17 *, umode_t, bool);
	int (*link)(struct dentry___17 *, struct inode___18 *, struct dentry___17 *);
	int (*unlink)(struct inode___18 *, struct dentry___17 *);
	int (*symlink)(struct user_namespace *, struct inode___18 *, struct dentry___17 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___18 *, struct dentry___17 *, umode_t);
	int (*rmdir)(struct inode___18 *, struct dentry___17 *);
	int (*mknod)(struct user_namespace *, struct inode___18 *, struct dentry___17 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___18 *, struct dentry___17 *, struct inode___18 *, struct dentry___17 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___17 *, struct iattr___17 *);
	int (*getattr)(struct user_namespace *, const struct path___16 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___17 *, char *, size_t);
	int (*fiemap)(struct inode___18 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___18 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___18 *, struct dentry___17 *, struct file___17 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___18 *, struct dentry___17 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___18 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___17 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___17 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___16 {
	void (*fl_copy_lock)(struct file_lock___16 *, struct file_lock___16 *);
	void (*fl_release_private)(struct file_lock___16 *);
};

struct lock_manager_operations___16;

struct file_lock___16 {
	struct file_lock___16 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___17 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___16 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___16 *fl_ops;
	const struct lock_manager_operations___16 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___16 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___16 *);
	int (*lm_grant)(struct file_lock___16 *, int);
	bool (*lm_break)(struct file_lock___16 *);
	int (*lm_change)(struct file_lock___16 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___16 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___16 *);
};

struct fasync_struct___16 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___16 *fa_next;
	struct file___17 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___16 {
	struct inode___18 * (*alloc_inode)(struct super_block___17 *);
	void (*destroy_inode)(struct inode___18 *);
	void (*free_inode)(struct inode___18 *);
	void (*dirty_inode)(struct inode___18 *, int);
	int (*write_inode)(struct inode___18 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___18 *);
	void (*evict_inode)(struct inode___18 *);
	void (*put_super)(struct super_block___17 *);
	int (*sync_fs)(struct super_block___17 *, int);
	int (*freeze_super)(struct super_block___17 *);
	int (*freeze_fs)(struct super_block___17 *);
	int (*thaw_super)(struct super_block___17 *);
	int (*unfreeze_fs)(struct super_block___17 *);
	int (*statfs)(struct dentry___17 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___17 *, int *, char *);
	void (*umount_begin)(struct super_block___17 *);
	int (*show_options)(struct seq_file___18 *, struct dentry___17 *);
	int (*show_devname)(struct seq_file___18 *, struct dentry___17 *);
	int (*show_path)(struct seq_file___18 *, struct dentry___17 *);
	int (*show_stats)(struct seq_file___18 *, struct dentry___17 *);
	ssize_t (*quota_read)(struct super_block___17 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___17 *, int, const char *, size_t, loff_t);
	struct dquot___16 ** (*get_dquots)(struct inode___18 *);
	long int (*nr_cached_objects)(struct super_block___17 *, struct shrink_control *);
	long int (*free_cached_objects)(struct super_block___17 *, struct shrink_control *);
	struct file___17 * (*real_loop)(struct file___17 *);
};

struct kernel_param_ops___16 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___16 *);
	int (*get)(char *, const struct kernel_param___16 *);
	void (*free)(void *);
};

struct kparam_array___16;

struct kernel_param___16 {
	const char *name;
	struct module___18 *mod;
	const struct kernel_param_ops___16 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___16 *arr;
	};
};

struct kparam_array___16 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___16 *ops;
	void *elem;
};

struct module_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___16 *, struct module_kobject___16 *, char *);
	ssize_t (*store)(struct module_attribute___16 *, struct module_kobject___16 *, const char *, size_t);
	void (*setup)(struct module___18 *, const char *);
	int (*test)(struct module___18 *);
	void (*free)(struct module___18 *);
};

struct irq_chip___8 {
	struct device___14 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___8 *);
	void (*irq_shutdown)(struct irq_data___8 *);
	void (*irq_enable)(struct irq_data___8 *);
	void (*irq_disable)(struct irq_data___8 *);
	void (*irq_ack)(struct irq_data___8 *);
	void (*irq_mask)(struct irq_data___8 *);
	void (*irq_mask_ack)(struct irq_data___8 *);
	void (*irq_unmask)(struct irq_data___8 *);
	void (*irq_eoi)(struct irq_data___8 *);
	int (*irq_set_affinity)(struct irq_data___8 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___8 *);
	int (*irq_set_type)(struct irq_data___8 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___8 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___8 *);
	void (*irq_bus_sync_unlock)(struct irq_data___8 *);
	void (*irq_cpu_online)(struct irq_data___8 *);
	void (*irq_cpu_offline)(struct irq_data___8 *);
	void (*irq_suspend)(struct irq_data___8 *);
	void (*irq_resume)(struct irq_data___8 *);
	void (*irq_pm_shutdown)(struct irq_data___8 *);
	void (*irq_calc_mask)(struct irq_data___8 *);
	void (*irq_print_chip)(struct irq_data___8 *, struct seq_file___18 *);
	int (*irq_request_resources)(struct irq_data___8 *);
	void (*irq_release_resources)(struct irq_data___8 *);
	void (*irq_compose_msi_msg)(struct irq_data___8 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___8 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___8 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___8 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___8 *, void *);
	void (*ipi_send_single)(struct irq_data___8 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___8 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___8 *);
	void (*irq_nmi_teardown)(struct irq_data___8 *);
	long unsigned int flags;
};

struct irqaction___7 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___7 *next;
	irq_handler_t thread_fn;
	struct task_struct___18 *thread;
	struct irqaction___7 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___8 {
	struct irq_chip___8 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___9 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___8 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___8 *);
	void (*resume)(struct irq_chip_generic___8 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___8 *domain;
	struct list_head list;
	struct irq_chip_type___8 chip_types[0];
};

struct seq_operations___16 {
	void * (*start)(struct seq_file___18 *, loff_t *);
	void (*stop)(struct seq_file___18 *, void *);
	void * (*next)(struct seq_file___18 *, void *, loff_t *);
	int (*show)(struct seq_file___18 *, void *);
};

struct dev_pagemap_ops___16 {
	void (*page_free)(struct page___17 *);
	void (*kill)(struct dev_pagemap___16 *);
	void (*cleanup)(struct dev_pagemap___16 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___16 *);
};

struct cgroup_namespace___10 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___10 *root_cset;
};

struct kprobe___2;

typedef int (*kprobe_pre_handler_t___2)(struct kprobe___2 *, struct pt_regs *);

typedef void (*kprobe_post_handler_t___2)(struct kprobe___2 *, struct pt_regs *, long unsigned int);

struct kprobe___2 {
	struct hlist_node hlist;
	struct list_head list;
	long unsigned int nmissed;
	kprobe_opcode_t *addr;
	const char *symbol_name;
	unsigned int offset;
	kprobe_pre_handler_t___2 pre_handler;
	kprobe_post_handler_t___2 post_handler;
	kprobe_opcode_t opcode;
	struct arch_specific_insn___3 ainsn;
	u32 flags;
};

struct cftype___10;

struct cgroup_subsys___10 {
	struct cgroup_subsys_state___10 * (*css_alloc)(struct cgroup_subsys_state___10 *);
	int (*css_online)(struct cgroup_subsys_state___10 *);
	void (*css_offline)(struct cgroup_subsys_state___10 *);
	void (*css_released)(struct cgroup_subsys_state___10 *);
	void (*css_free)(struct cgroup_subsys_state___10 *);
	void (*css_reset)(struct cgroup_subsys_state___10 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___10 *, int);
	int (*css_extra_stat_show)(struct seq_file___18 *, struct cgroup_subsys_state___10 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___18 *, struct css_set___10 *);
	void (*cancel_fork)(struct task_struct___18 *, struct css_set___10 *);
	void (*fork)(struct task_struct___18 *);
	void (*exit)(struct task_struct___18 *);
	void (*release)(struct task_struct___18 *);
	void (*bind)(struct cgroup_subsys_state___10 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___10 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___10 *dfl_cftypes;
	struct cftype___10 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___10 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___10 *updated_children;
	struct cgroup___10 *updated_next;
};

struct cgroup_root___10 {
	struct kernfs_root___16 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___10 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___10 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___10 *ss;
	struct list_head node;
	struct kernfs_ops___16 *kf_ops;
	int (*open)(struct kernfs_open_file___16 *);
	void (*release)(struct kernfs_open_file___16 *);
	u64 (*read_u64)(struct cgroup_subsys_state___10 *, struct cftype___10 *);
	s64 (*read_s64)(struct cgroup_subsys_state___10 *, struct cftype___10 *);
	int (*seq_show)(struct seq_file___18 *, void *);
	void * (*seq_start)(struct seq_file___18 *, loff_t *);
	void * (*seq_next)(struct seq_file___18 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___18 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___10 *, struct cftype___10 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___10 *, struct cftype___10 *, s64);
	ssize_t (*write)(struct kernfs_open_file___16 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___16 *, struct poll_table_struct___12 *);
};

struct perf_cpu_context___9;

struct perf_output_handle___9;

struct pmu___9 {
	struct list_head entry;
	struct module___18 *module;
	struct device___14 *dev;
	const struct attribute_group___16 **attr_groups;
	const struct attribute_group___16 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___9 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___9 *);
	void (*pmu_disable)(struct pmu___9 *);
	int (*event_init)(struct perf_event___9 *);
	void (*event_mapped)(struct perf_event___9 *, struct mm_struct___17 *);
	void (*event_unmapped)(struct perf_event___9 *, struct mm_struct___17 *);
	int (*add)(struct perf_event___9 *, int);
	void (*del)(struct perf_event___9 *, int);
	void (*start)(struct perf_event___9 *, int);
	void (*stop)(struct perf_event___9 *, int);
	void (*read)(struct perf_event___9 *);
	void (*start_txn)(struct pmu___9 *, unsigned int);
	int (*commit_txn)(struct pmu___9 *);
	void (*cancel_txn)(struct pmu___9 *);
	int (*event_idx)(struct perf_event___9 *);
	void (*sched_task)(struct perf_event_context___9 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___9 *, struct perf_event_context___9 *);
	void * (*setup_aux)(struct perf_event___9 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___9 *, struct perf_output_handle___9 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___9 *);
	int (*aux_output_match)(struct perf_event___9 *);
	int (*filter_match)(struct perf_event___9 *);
	int (*check_period)(struct perf_event___9 *, u64);
};

struct perf_cpu_context___9 {
	struct perf_event_context___9 ctx;
	struct perf_event_context___9 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___9 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___9 **heap;
	struct perf_event___9 *heap_default[2];
};

struct perf_output_handle___9 {
	struct perf_event___9 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___9 {
	struct cgroup_subsys_state___10 css;
	struct perf_cgroup_info *info;
};

struct hstate {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___10 cgroup_files_dfl[7];
	struct cftype___10 cgroup_files_legacy[9];
	char name[32];
};

struct fault_info {
	int (*fn)(long unsigned int, unsigned int, struct pt_regs *);
	int sig;
	int code;
	const char *name;
};

struct dentry___18;

struct super_block___18;

struct module___19;

struct file_system_type___17 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___18 * (*mount)(struct file_system_type___17 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___18 *);
	struct module___19 *owner;
	struct file_system_type___17 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___18;

struct kiocb___17;

struct iov_iter___7;

struct poll_table_struct___13;

struct vm_area_struct___17;

struct inode___19;

struct file_lock___17;

struct page___18;

struct seq_file___19;

struct file_operations___17 {
	struct module___19 *owner;
	loff_t (*llseek)(struct file___18 *, loff_t, int);
	ssize_t (*read)(struct file___18 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___18 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___17 *, struct iov_iter___7 *);
	ssize_t (*write_iter)(struct kiocb___17 *, struct iov_iter___7 *);
	int (*iopoll)(struct kiocb___17 *, bool);
	int (*iterate)(struct file___18 *, struct dir_context *);
	int (*iterate_shared)(struct file___18 *, struct dir_context *);
	__poll_t (*poll)(struct file___18 *, struct poll_table_struct___13 *);
	long int (*unlocked_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___18 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___18 *, struct vm_area_struct___17 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___19 *, struct file___18 *);
	int (*flush)(struct file___18 *, fl_owner_t);
	int (*release)(struct inode___19 *, struct file___18 *);
	int (*fsync)(struct file___18 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___18 *, int);
	int (*lock)(struct file___18 *, int, struct file_lock___17 *);
	ssize_t (*sendpage)(struct file___18 *, struct page___18 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___18 *, long unsigned int);
	int (*flock)(struct file___18 *, int, struct file_lock___17 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___18 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___18 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___18 *, long int, struct file_lock___17 **, void **);
	long int (*fallocate)(struct file___18 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___19 *, struct file___18 *);
	ssize_t (*copy_file_range)(struct file___18 *, loff_t, struct file___18 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___18 *, loff_t, struct file___18 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___18 *, loff_t, loff_t, int);
};

struct vmacache___17 {
	u64 seqnum;
	struct vm_area_struct___17 *vmas[4];
};

struct page_frag___17 {
	struct page___18 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___10;

struct debug_info___10 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___10 *hbp_break[16];
	struct perf_event___10 *hbp_watch[16];
};

struct thread_struct___10 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___10 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___18;

struct pid___16;

struct nsproxy___17;

struct signal_struct___18;

struct bio_list___6;

struct backing_dev_info___5;

struct io_context___7;

struct css_set___11;

struct perf_event_context___10;

struct mem_cgroup___5;

struct request_queue___8;

struct vm_struct___17;

struct task_struct___19 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___19 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___18 *mm;
	struct mm_struct___18 *active_mm;
	struct vmacache___17 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___19 *real_parent;
	struct task_struct___19 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___19 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___16 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___17 *nsproxy;
	struct signal_struct___18 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___19 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___6 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___5 *backing_dev_info;
	struct io_context___7 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___11 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___10 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___17 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___5 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___5 *active_memcg;
	struct request_queue___8 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___19 *oom_reaper_list;
	struct vm_struct___17 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___10 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___17;

struct kobj_type___17;

struct kernfs_node___17;

struct kobject___17 {
	const char *name;
	struct list_head entry;
	struct kobject___17 *parent;
	struct kset___17 *kset;
	struct kobj_type___17 *ktype;
	struct kernfs_node___17 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___17 {
	struct kobject___17 kobj;
	struct module___19 *mod;
	struct kobject___17 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___17 {
	struct module___19 *mod;
	struct latch_tree_node node;
};

struct module_layout___17 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___17 mtn;
};

struct module_attribute___17;

struct kernel_param___17;

struct module___19 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___17 mkobj;
	struct module_attribute___17 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___17 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___17 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___17 core_layout;
	struct module_layout___17 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___10 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___19 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___10)(struct perf_event___10 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___10;

struct fasync_struct___17;

struct pid_namespace___16;

struct perf_cgroup___10;

struct perf_event___10 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___10 *group_leader;
	struct pmu___10 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___10 hw;
	struct perf_event_context___10 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___10 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___19 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___17 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___10 *aux_event;
	void (*destroy)(struct perf_event___10 *);
	struct callback_head callback_head;
	struct pid_namespace___16 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___10 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___10 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___10 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___18 *pgtable_t___17;

struct address_space___17;

struct dev_pagemap___17;

struct page___18 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___17 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___18 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___17 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___18 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___17 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___17;

struct vm_area_struct___17 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___17 *vm_next;
	struct vm_area_struct___17 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___18 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___17 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___18 *vm_file;
	struct file___18 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___17;

struct mm_struct___18 {
	struct {
		struct vm_area_struct___17 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___18 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___17 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___19 *owner;
		struct user_namespace *user_ns;
		struct file___18 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___17;

struct address_space___17 {
	struct inode___19 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___17 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___17;

struct dev_pagemap___17 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___17 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___17;

struct path___17 {
	struct vfsmount___17 *mnt;
	struct dentry___18 *dentry;
};

struct fown_struct___16 {
	rwlock_t lock;
	struct pid___16 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___18 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___17 f_path;
	struct inode___19 *f_inode;
	const struct file_operations___17 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___16 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___17 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___17;

struct vm_operations_struct___17 {
	void (*open)(struct vm_area_struct___17 *);
	void (*close)(struct vm_area_struct___17 *);
	int (*may_split)(struct vm_area_struct___17 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___17 *);
	int (*mprotect)(struct vm_area_struct___17 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___17 *);
	vm_fault_t (*huge_fault)(struct vm_fault___17 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___17 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___17 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___17 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___17 *);
	int (*access)(struct vm_area_struct___17 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___17 *);
	int (*set_policy)(struct vm_area_struct___17 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___17 *, long unsigned int);
	struct page___18 * (*find_special_page)(struct vm_area_struct___17 *, long unsigned int);
};

struct core_thread___17 {
	struct task_struct___19 *task;
	struct core_thread___17 *next;
};

struct core_state___17 {
	atomic_t nr_threads;
	struct core_thread___17 dumper;
	struct completion startup;
};

struct vm_fault___17 {
	const struct {
		struct vm_area_struct___17 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___18 *cow_page;
	struct page___18 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___17 prealloc_pte;
};

struct pglist_data___6;

struct lruvec___6 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___6 *pgdat;
};

struct zone___6 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___6 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___6 {
	struct zone___6 *zone;
	int zone_idx;
};

struct zonelist___6 {
	struct zoneref___6 _zonerefs[321];
};

struct pglist_data___6 {
	struct zone___6 node_zones[5];
	struct zonelist___6 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___19 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___19 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___6 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct mem_section_usage {
	long unsigned int subsection_map[1];
	long unsigned int pageblock_flags[0];
};

struct mem_section {
	long unsigned int section_mem_map;
	struct mem_section_usage *usage;
};

struct upid___16 {
	int nr;
	struct pid_namespace___16 *ns;
};

struct pid_namespace___16 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___19 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___16 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___16 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___16 numbers[1];
};

struct signal_struct___18 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___19 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___19 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___16 *pids[4];
	struct pid___16 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___18 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___11;

struct nsproxy___17 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___16 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___11 *cgroup_ns;
};

struct bio___6;

struct bio_list___6 {
	struct bio___6 *head;
	struct bio___6 *tail;
};

struct cgroup_subsys_state___11;

struct bdi_writeback___5 {
	struct backing_dev_info___5 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___11 *memcg_css;
	struct cgroup_subsys_state___11 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___15;

struct backing_dev_info___5 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___5 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___15 *dev;
	char dev_name[64];
	struct device___15 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___18 *debug_dir;
};

struct io_cq___6;

struct io_context___7 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___6 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___11;

struct css_set___11 {
	struct cgroup_subsys_state___11 *subsys[14];
	refcount_t refcount;
	struct css_set___11 *dom_cset;
	struct cgroup___11 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___11 *mg_src_cgrp;
	struct cgroup___11 *mg_dst_cgrp;
	struct css_set___11 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___10 {
	struct pmu___10 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___19 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___10 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___11;

struct cgroup_subsys_state___11 {
	struct cgroup___11 *cgroup;
	struct cgroup_subsys___11 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___11 *parent;
};

struct cgroup_file___11 {
	struct kernfs_node___17 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___5;

struct mem_cgroup_per_node___5;

struct mem_cgroup___5 {
	struct cgroup_subsys_state___11 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___11 events_file;
	struct cgroup_file___11 events_local_file;
	struct cgroup_file___11 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___5 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___19 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___5 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___6;

struct blk_integrity___6 {
	const struct blk_integrity_profile___6 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___6 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___6 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___7;

struct elevator_queue___6;

struct blk_mq_ops___6;

struct blk_mq_hw_ctx___6;

struct gendisk___6;

struct blkcg_gq___6;

struct blk_mq_tag_set___6;

struct request_queue___8 {
	struct request___7 *last_merge;
	struct elevator_queue___6 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___6 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___6 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___6 *disk;
	struct kobject___17 kobj;
	struct kobject___17 *mq_kobj;
	struct blk_integrity___6 integrity;
	struct device___15 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___6 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___6 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___6 bio_split;
	struct dentry___18 *debugfs_dir;
	struct dentry___18 *sched_debugfs_dir;
	struct dentry___18 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___17 {
	struct vm_struct___17 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___18 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___17;

struct dentry___18 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___18 *d_parent;
	struct qstr d_name;
	struct inode___19 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___17 *d_op;
	struct super_block___18 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___17;

struct cdev___10;

struct inode___19 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___17 *i_op;
	struct super_block___18 *i_sb;
	struct address_space___17 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___5 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___17 *i_fop;
		void (*free_inode)(struct inode___19 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___17 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___10 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___17 {
	int (*d_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___18 *, unsigned int);
	int (*d_hash)(const struct dentry___18 *, struct qstr *);
	int (*d_compare)(const struct dentry___18 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___18 *);
	int (*d_init)(struct dentry___18 *);
	void (*d_release)(struct dentry___18 *);
	void (*d_prune)(struct dentry___18 *);
	void (*d_iput)(struct dentry___18 *, struct inode___19 *);
	char * (*d_dname)(struct dentry___18 *, char *, int);
	struct vfsmount___17 * (*d_automount)(struct path___17 *);
	int (*d_manage)(const struct path___17 *, bool);
	struct dentry___18 * (*d_real)(struct dentry___18 *, const struct inode___19 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___17;

struct mem_dqinfo___17 {
	struct quota_format_type___17 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___17;

struct quota_info___17 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___19 *files[3];
	struct mem_dqinfo___17 info[3];
	const struct quota_format_ops___17 *ops[3];
};

struct rcuwait___17 {
	struct task_struct___19 *task;
};

struct percpu_rw_semaphore___17 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___17 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___17 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___17 rw_sem[3];
};

struct shrink_control___5;

struct shrinker___5 {
	long unsigned int (*count_objects)(struct shrinker___5 *, struct shrink_control___5 *);
	long unsigned int (*scan_objects)(struct shrinker___5 *, struct shrink_control___5 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___17;

struct dquot_operations___17;

struct quotactl_ops___17;

struct block_device___7;

struct super_block___18 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___17 *s_type;
	const struct super_operations___17 *s_op;
	const struct dquot_operations___17 *dq_op;
	const struct quotactl_ops___17 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___18 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___7 *s_bdev;
	struct backing_dev_info___5 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___17 s_dquot;
	struct sb_writers___17 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___17 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___17 {
	struct dentry___18 *mnt_root;
	struct super_block___18 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___5 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___5 *memcg;
};

struct psi_group___11 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___19 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___11;

struct cgroup_rstat_cpu___11;

struct cgroup___11 {
	struct cgroup_subsys_state___11 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___17 *kn;
	struct cgroup_file___11 procs_file;
	struct cgroup_file___11 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___11 *subsys[14];
	struct cgroup_root___11 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___11 *dom_cgrp;
	struct cgroup___11 *old_dom_cgrp;
	struct cgroup_rstat_cpu___11 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___11 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___6 {
	struct request_queue___8 *q;
	struct io_context___7 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___5;

struct kiocb___17 {
	struct file___18 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___17 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___5 *ki_waitq;
	};
};

struct iattr___18 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___18 *ia_file;
};

struct dquot___17 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___18 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___17 {
	int qf_fmt_id;
	const struct quota_format_ops___17 *qf_ops;
	struct module___19 *qf_owner;
	struct quota_format_type___17 *qf_next;
};

struct quota_format_ops___17 {
	int (*check_quota_file)(struct super_block___18 *, int);
	int (*read_file_info)(struct super_block___18 *, int);
	int (*write_file_info)(struct super_block___18 *, int);
	int (*free_file_info)(struct super_block___18 *, int);
	int (*read_dqblk)(struct dquot___17 *);
	int (*commit_dqblk)(struct dquot___17 *);
	int (*release_dqblk)(struct dquot___17 *);
	int (*get_next_id)(struct super_block___18 *, struct kqid *);
};

struct dquot_operations___17 {
	int (*write_dquot)(struct dquot___17 *);
	struct dquot___17 * (*alloc_dquot)(struct super_block___18 *, int);
	void (*destroy_dquot)(struct dquot___17 *);
	int (*acquire_dquot)(struct dquot___17 *);
	int (*release_dquot)(struct dquot___17 *);
	int (*mark_dirty)(struct dquot___17 *);
	int (*write_info)(struct super_block___18 *, int);
	qsize_t * (*get_reserved_space)(struct inode___19 *);
	int (*get_projid)(struct inode___19 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___19 *, qsize_t *);
	int (*get_next_id)(struct super_block___18 *, struct kqid *);
};

struct quotactl_ops___17 {
	int (*quota_on)(struct super_block___18 *, int, int, const struct path___17 *);
	int (*quota_off)(struct super_block___18 *, int);
	int (*quota_enable)(struct super_block___18 *, unsigned int);
	int (*quota_disable)(struct super_block___18 *, unsigned int);
	int (*quota_sync)(struct super_block___18 *, int);
	int (*set_info)(struct super_block___18 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___18 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___18 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___18 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___18 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___18 *, unsigned int);
};

struct wait_page_queue___5 {
	struct page___18 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___5;

struct readahead_control___6;

struct address_space_operations___17 {
	int (*writepage)(struct page___18 *, struct writeback_control___5 *);
	int (*readpage)(struct file___18 *, struct page___18 *);
	int (*writepages)(struct address_space___17 *, struct writeback_control___5 *);
	int (*set_page_dirty)(struct page___18 *);
	int (*readpages)(struct file___18 *, struct address_space___17 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___6 *);
	int (*write_begin)(struct file___18 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___18 **, void **);
	int (*write_end)(struct file___18 *, struct address_space___17 *, loff_t, unsigned int, unsigned int, struct page___18 *, void *);
	sector_t (*bmap)(struct address_space___17 *, sector_t);
	void (*invalidatepage)(struct page___18 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___18 *, gfp_t);
	void (*freepage)(struct page___18 *);
	ssize_t (*direct_IO)(struct kiocb___17 *, struct iov_iter___7 *);
	int (*migratepage)(struct address_space___17 *, struct page___18 *, struct page___18 *, enum migrate_mode);
	bool (*isolate_page)(struct page___18 *, isolate_mode_t);
	void (*putback_page)(struct page___18 *);
	int (*launder_page)(struct page___18 *);
	int (*is_partially_uptodate)(struct page___18 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___18 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___17 *, struct page___18 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___18 *, sector_t *);
	void (*swap_deactivate)(struct file___18 *);
};

struct writeback_control___5 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___5 *wb;
	struct inode___19 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___6 {
	struct file___18 *file;
	struct address_space___17 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___7;

struct iov_iter___7 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___7 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___3 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___7 *bdev;
	struct file___18 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___10 {
	struct kobject___17 kobj;
	struct module___19 *owner;
	const struct file_operations___17 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___17 {
	struct dentry___18 * (*lookup)(struct inode___19 *, struct dentry___18 *, unsigned int);
	const char * (*get_link)(struct dentry___18 *, struct inode___19 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___19 *, int);
	struct posix_acl * (*get_acl)(struct inode___19 *, int, bool);
	int (*readlink)(struct dentry___18 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___19 *, struct dentry___18 *, umode_t, bool);
	int (*link)(struct dentry___18 *, struct inode___19 *, struct dentry___18 *);
	int (*unlink)(struct inode___19 *, struct dentry___18 *);
	int (*symlink)(struct user_namespace *, struct inode___19 *, struct dentry___18 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___19 *, struct dentry___18 *, umode_t);
	int (*rmdir)(struct inode___19 *, struct dentry___18 *);
	int (*mknod)(struct user_namespace *, struct inode___19 *, struct dentry___18 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___19 *, struct dentry___18 *, struct inode___19 *, struct dentry___18 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___18 *, struct iattr___18 *);
	int (*getattr)(struct user_namespace *, const struct path___17 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___18 *, char *, size_t);
	int (*fiemap)(struct inode___19 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___19 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___19 *, struct dentry___18 *, struct file___18 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___19 *, struct dentry___18 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___19 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___18 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___18 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___17 {
	void (*fl_copy_lock)(struct file_lock___17 *, struct file_lock___17 *);
	void (*fl_release_private)(struct file_lock___17 *);
};

struct lock_manager_operations___17;

struct file_lock___17 {
	struct file_lock___17 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___18 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___17 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___17 *fl_ops;
	const struct lock_manager_operations___17 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___17 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___17 *);
	int (*lm_grant)(struct file_lock___17 *, int);
	bool (*lm_break)(struct file_lock___17 *);
	int (*lm_change)(struct file_lock___17 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___17 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___17 *);
};

struct fasync_struct___17 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___17 *fa_next;
	struct file___18 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___17 {
	struct inode___19 * (*alloc_inode)(struct super_block___18 *);
	void (*destroy_inode)(struct inode___19 *);
	void (*free_inode)(struct inode___19 *);
	void (*dirty_inode)(struct inode___19 *, int);
	int (*write_inode)(struct inode___19 *, struct writeback_control___5 *);
	int (*drop_inode)(struct inode___19 *);
	void (*evict_inode)(struct inode___19 *);
	void (*put_super)(struct super_block___18 *);
	int (*sync_fs)(struct super_block___18 *, int);
	int (*freeze_super)(struct super_block___18 *);
	int (*freeze_fs)(struct super_block___18 *);
	int (*thaw_super)(struct super_block___18 *);
	int (*unfreeze_fs)(struct super_block___18 *);
	int (*statfs)(struct dentry___18 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___18 *, int *, char *);
	void (*umount_begin)(struct super_block___18 *);
	int (*show_options)(struct seq_file___19 *, struct dentry___18 *);
	int (*show_devname)(struct seq_file___19 *, struct dentry___18 *);
	int (*show_path)(struct seq_file___19 *, struct dentry___18 *);
	int (*show_stats)(struct seq_file___19 *, struct dentry___18 *);
	ssize_t (*quota_read)(struct super_block___18 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___18 *, int, const char *, size_t, loff_t);
	struct dquot___17 ** (*get_dquots)(struct inode___19 *);
	long int (*nr_cached_objects)(struct super_block___18 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___18 *, struct shrink_control___5 *);
	struct file___18 * (*real_loop)(struct file___18 *);
};

struct wakeup_source___15;

struct dev_pm_info___15 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___15 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___15 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___15;

struct bus_type___15;

struct device_driver___15;

struct dev_pm_domain___15;

struct irq_domain___9;

struct dma_map_ops___2;

struct io_tlb_mem___2;

struct device_node___10;

struct fwnode_handle___15;

struct class___15;

struct attribute_group___17;

struct device___15 {
	struct kobject___17 kobj;
	struct device___15 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___15 *type;
	struct bus_type___15 *bus;
	struct device_driver___15 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___15 power;
	struct dev_pm_domain___15 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___9 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___2 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem___2 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___10 *of_node;
	struct fwnode_handle___15 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___15 *class;
	const struct attribute_group___17 **groups;
	void (*release)(struct device___15 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___7 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___19 *bd_inode;
	struct super_block___18 *bd_super;
	void *bd_claiming;
	struct device___15 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___17 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___6 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___18 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___13)(struct file___18 *, wait_queue_head_t *, struct poll_table_struct___13 *);

struct poll_table_struct___13 {
	poll_queue_proc___13 _qproc;
	__poll_t _key;
};

struct seq_operations___17;

struct seq_file___19 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___17 *op;
	int poll_event;
	const struct file___18 *file;
	void *private;
};

typedef void bio_end_io_t___6(struct bio___6 *);

struct bio_vec___7 {
	struct page___18 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___6;

struct bio___6 {
	struct bio___6 *bi_next;
	struct block_device___7 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___6 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___6 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___6 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___7 *bi_io_vec;
	struct bio_set___6 *bi_pool;
	struct bio_vec___7 bi_inline_vecs[0];
};

struct seq_operations___17 {
	void * (*start)(struct seq_file___19 *, loff_t *);
	void (*stop)(struct seq_file___19 *, void *);
	void * (*next)(struct seq_file___19 *, void *, loff_t *);
	int (*show)(struct seq_file___19 *, void *);
};

struct kernfs_root___17;

struct kernfs_elem_dir___17 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___17 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___17;

struct kernfs_root___17 {
	struct kernfs_node___17 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___17 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___17 {
	struct kernfs_node___17 *target_kn;
};

struct kernfs_ops___17;

struct kernfs_elem_attr___17 {
	const struct kernfs_ops___17 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___17 *notify_next;
};

struct kernfs_node___17 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___17 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___17 dir;
		struct kernfs_elem_symlink___17 symlink;
		struct kernfs_elem_attr___17 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___17;

struct kernfs_ops___17 {
	int (*open)(struct kernfs_open_file___17 *);
	void (*release)(struct kernfs_open_file___17 *);
	int (*seq_show)(struct seq_file___19 *, void *);
	void * (*seq_start)(struct seq_file___19 *, loff_t *);
	void * (*seq_next)(struct seq_file___19 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___19 *, void *);
	ssize_t (*read)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___17 *, struct poll_table_struct___13 *);
	int (*mmap)(struct kernfs_open_file___17 *, struct vm_area_struct___17 *);
};

struct kernfs_syscall_ops___17 {
	int (*show_options)(struct seq_file___19 *, struct kernfs_root___17 *);
	int (*mkdir)(struct kernfs_node___17 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___17 *);
	int (*rename)(struct kernfs_node___17 *, struct kernfs_node___17 *, const char *);
	int (*show_path)(struct seq_file___19 *, struct kernfs_node___17 *, struct kernfs_root___17 *);
};

struct kernfs_open_file___17 {
	struct kernfs_node___17 *kn;
	struct file___18 *file;
	struct seq_file___19 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___17 *vm_ops;
};

struct cgroup_namespace___11 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___11 *root_cset;
};

struct irq_desc___10;

typedef void (*irq_flow_handler_t___10)(struct irq_desc___10 *);

struct irq_chip___9;

struct irq_data___9 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data *common;
	struct irq_chip___9 *chip;
	struct irq_domain___9 *domain;
	struct irq_data___9 *parent_data;
	void *chip_data;
};

struct irqaction___8;

struct irq_desc___10 {
	struct irq_common_data irq_common_data;
	struct irq_data___9 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___10 handle_irq;
	struct irqaction___8 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___17 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___19 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___15;

struct fwnode_handle___15 {
	struct fwnode_handle___15 *secondary;
	const struct fwnode_operations___15 *ops;
	struct device___15 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___15;

struct fwnode_endpoint___15;

struct fwnode_operations___15 {
	struct fwnode_handle___15 * (*get)(struct fwnode_handle___15 *);
	void (*put)(struct fwnode_handle___15 *);
	bool (*device_is_available)(const struct fwnode_handle___15 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___15 *, const struct device___15 *);
	bool (*property_present)(const struct fwnode_handle___15 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___15 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___15 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___15 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_parent)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_next_child_node)(const struct fwnode_handle___15 *, struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*get_named_child_node)(const struct fwnode_handle___15 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___15 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___15 *);
	struct fwnode_handle___15 * (*graph_get_next_endpoint)(const struct fwnode_handle___15 *, struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*graph_get_remote_endpoint)(const struct fwnode_handle___15 *);
	struct fwnode_handle___15 * (*graph_get_port_parent)(struct fwnode_handle___15 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___15 *, struct fwnode_endpoint___15 *);
	int (*add_links)(struct fwnode_handle___15 *);
};

struct fwnode_endpoint___15 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___15 *local_fwnode;
};

struct fwnode_reference_args___15 {
	struct fwnode_handle___15 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___9 {
	struct device___15 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___9 *);
	void (*irq_shutdown)(struct irq_data___9 *);
	void (*irq_enable)(struct irq_data___9 *);
	void (*irq_disable)(struct irq_data___9 *);
	void (*irq_ack)(struct irq_data___9 *);
	void (*irq_mask)(struct irq_data___9 *);
	void (*irq_mask_ack)(struct irq_data___9 *);
	void (*irq_unmask)(struct irq_data___9 *);
	void (*irq_eoi)(struct irq_data___9 *);
	int (*irq_set_affinity)(struct irq_data___9 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___9 *);
	int (*irq_set_type)(struct irq_data___9 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___9 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___9 *);
	void (*irq_bus_sync_unlock)(struct irq_data___9 *);
	void (*irq_cpu_online)(struct irq_data___9 *);
	void (*irq_cpu_offline)(struct irq_data___9 *);
	void (*irq_suspend)(struct irq_data___9 *);
	void (*irq_resume)(struct irq_data___9 *);
	void (*irq_pm_shutdown)(struct irq_data___9 *);
	void (*irq_calc_mask)(struct irq_data___9 *);
	void (*irq_print_chip)(struct irq_data___9 *, struct seq_file___19 *);
	int (*irq_request_resources)(struct irq_data___9 *);
	void (*irq_release_resources)(struct irq_data___9 *);
	void (*irq_compose_msi_msg)(struct irq_data___9 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___9 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___9 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___9 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___9 *, void *);
	void (*ipi_send_single)(struct irq_data___9 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___9 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___9 *);
	void (*irq_nmi_teardown)(struct irq_data___9 *);
	long unsigned int flags;
};

struct irq_domain_ops___9;

struct irq_domain_chip_generic___9;

struct irq_domain___9 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___9 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___15 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___9 *gc;
	struct irq_domain___9 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___9 *revmap[0];
};

struct bin_attribute___17;

struct attribute_group___17 {
	const char *name;
	umode_t (*is_visible)(struct kobject___17 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___17 *, struct bin_attribute___17 *, int);
	struct attribute **attrs;
	struct bin_attribute___17 **bin_attrs;
};

struct bin_attribute___17 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___17 * (*f_mapping)();
	ssize_t (*read)(struct file___18 *, struct kobject___17 *, struct bin_attribute___17 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___18 *, struct kobject___17 *, struct bin_attribute___17 *, char *, loff_t, size_t);
	int (*mmap)(struct file___18 *, struct kobject___17 *, struct bin_attribute___17 *, struct vm_area_struct___17 *);
};

struct sysfs_ops___17 {
	ssize_t (*show)(struct kobject___17 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___17 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___17;

struct kset___17 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___17 kobj;
	const struct kset_uevent_ops___17 *uevent_ops;
};

struct kobj_type___17 {
	void (*release)(struct kobject___17 *);
	const struct sysfs_ops___17 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___17 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___17 *);
	const void * (*namespace)(struct kobject___17 *);
	void (*get_ownership)(struct kobject___17 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___17 {
	int (* const filter)(struct kset___17 *, struct kobject___17 *);
	const char * (* const name)(struct kset___17 *, struct kobject___17 *);
	int (* const uevent)(struct kset___17 *, struct kobject___17 *, struct kobj_uevent_env *);
};

struct irqaction___8 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___8 *next;
	irq_handler_t thread_fn;
	struct task_struct___19 *thread;
	struct irqaction___8 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___9 {
	struct irq_chip___9 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___10 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___9 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___9 *);
	void (*resume)(struct irq_chip_generic___9 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___9 *domain;
	struct list_head list;
	struct irq_chip_type___9 chip_types[0];
};

struct irq_domain_chip_generic___9 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___9 *gc[0];
};

struct kernel_param_ops___17 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___17 *);
	int (*get)(char *, const struct kernel_param___17 *);
	void (*free)(void *);
};

struct kparam_array___17;

struct kernel_param___17 {
	const char *name;
	struct module___19 *mod;
	const struct kernel_param_ops___17 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___17 *arr;
	};
};

struct kparam_array___17 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___17 *ops;
	void *elem;
};

struct module_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___17 *, struct module_kobject___17 *, char *);
	ssize_t (*store)(struct module_attribute___17 *, struct module_kobject___17 *, const char *, size_t);
	void (*setup)(struct module___19 *, const char *);
	int (*test)(struct module___19 *);
	void (*free)(struct module___19 *);
};

struct dev_pagemap_ops___17 {
	void (*page_free)(struct page___18 *);
	void (*kill)(struct dev_pagemap___17 *);
	void (*cleanup)(struct dev_pagemap___17 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___17 *);
};

struct cftype___11;

struct cgroup_subsys___11 {
	struct cgroup_subsys_state___11 * (*css_alloc)(struct cgroup_subsys_state___11 *);
	int (*css_online)(struct cgroup_subsys_state___11 *);
	void (*css_offline)(struct cgroup_subsys_state___11 *);
	void (*css_released)(struct cgroup_subsys_state___11 *);
	void (*css_free)(struct cgroup_subsys_state___11 *);
	void (*css_reset)(struct cgroup_subsys_state___11 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___11 *, int);
	int (*css_extra_stat_show)(struct seq_file___19 *, struct cgroup_subsys_state___11 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___19 *, struct css_set___11 *);
	void (*cancel_fork)(struct task_struct___19 *, struct css_set___11 *);
	void (*fork)(struct task_struct___19 *);
	void (*exit)(struct task_struct___19 *);
	void (*release)(struct task_struct___19 *);
	void (*bind)(struct cgroup_subsys_state___11 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___11 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___11 *dfl_cftypes;
	struct cftype___11 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___11 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___11 *updated_children;
	struct cgroup___11 *updated_next;
};

struct cgroup_root___11 {
	struct kernfs_root___17 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___11 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___11 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___11 *ss;
	struct list_head node;
	struct kernfs_ops___17 *kf_ops;
	int (*open)(struct kernfs_open_file___17 *);
	void (*release)(struct kernfs_open_file___17 *);
	u64 (*read_u64)(struct cgroup_subsys_state___11 *, struct cftype___11 *);
	s64 (*read_s64)(struct cgroup_subsys_state___11 *, struct cftype___11 *);
	int (*seq_show)(struct seq_file___19 *, void *);
	void * (*seq_start)(struct seq_file___19 *, loff_t *);
	void * (*seq_next)(struct seq_file___19 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___19 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___11 *, struct cftype___11 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___11 *, struct cftype___11 *, s64);
	ssize_t (*write)(struct kernfs_open_file___17 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___17 *, struct poll_table_struct___13 *);
};

struct dev_pm_ops___15 {
	int (*prepare)(struct device___15 *);
	void (*complete)(struct device___15 *);
	int (*suspend)(struct device___15 *);
	int (*resume)(struct device___15 *);
	int (*freeze)(struct device___15 *);
	int (*thaw)(struct device___15 *);
	int (*poweroff)(struct device___15 *);
	int (*restore)(struct device___15 *);
	int (*suspend_late)(struct device___15 *);
	int (*resume_early)(struct device___15 *);
	int (*freeze_late)(struct device___15 *);
	int (*thaw_early)(struct device___15 *);
	int (*poweroff_late)(struct device___15 *);
	int (*restore_early)(struct device___15 *);
	int (*suspend_noirq)(struct device___15 *);
	int (*resume_noirq)(struct device___15 *);
	int (*freeze_noirq)(struct device___15 *);
	int (*thaw_noirq)(struct device___15 *);
	int (*poweroff_noirq)(struct device___15 *);
	int (*restore_noirq)(struct device___15 *);
	int (*runtime_suspend)(struct device___15 *);
	int (*runtime_resume)(struct device___15 *);
	int (*runtime_idle)(struct device___15 *);
};

struct wakeup_source___15 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___15 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___15 {
	struct dev_pm_ops___15 ops;
	int (*start)(struct device___15 *);
	void (*detach)(struct device___15 *, bool);
	int (*activate)(struct device___15 *);
	void (*sync)(struct device___15 *);
	void (*dismiss)(struct device___15 *);
};

struct bus_type___15 {
	const char *name;
	const char *dev_name;
	struct device___15 *dev_root;
	const struct attribute_group___17 **bus_groups;
	const struct attribute_group___17 **dev_groups;
	const struct attribute_group___17 **drv_groups;
	int (*match)(struct device___15 *, struct device_driver___15 *);
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	int (*probe)(struct device___15 *);
	void (*sync_state)(struct device___15 *);
	void (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*online)(struct device___15 *);
	int (*offline)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	int (*num_vf)(struct device___15 *);
	int (*dma_configure)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___15 {
	const char *name;
	struct bus_type___15 *bus;
	struct module___19 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___15 *);
	void (*sync_state)(struct device___15 *);
	int (*remove)(struct device___15 *);
	void (*shutdown)(struct device___15 *);
	int (*suspend)(struct device___15 *, pm_message_t);
	int (*resume)(struct device___15 *);
	const struct attribute_group___17 **groups;
	const struct attribute_group___17 **dev_groups;
	const struct dev_pm_ops___15 *pm;
	void (*coredump)(struct device___15 *);
	struct driver_private *p;
};

struct device_type___15 {
	const char *name;
	const struct attribute_group___17 **groups;
	int (*uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___15 *);
	const struct dev_pm_ops___15 *pm;
};

struct class___15 {
	const char *name;
	struct module___19 *owner;
	const struct attribute_group___17 **class_groups;
	const struct attribute_group___17 **dev_groups;
	struct kobject___17 *dev_kobj;
	int (*dev_uevent)(struct device___15 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___15 *, umode_t *);
	void (*class_release)(struct class___15 *);
	void (*dev_release)(struct device___15 *);
	int (*shutdown_pre)(struct device___15 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___15 *);
	void (*get_ownership)(struct device___15 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___15 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___2 {
	void * (*alloc)(struct device___15 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___15 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___18 * (*alloc_pages)(struct device___15 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___15 *, size_t, struct page___18 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___15 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___15 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___15 *, struct vm_area_struct___17 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___15 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___15 *, struct page___18 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___15 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___15 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___15 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___15 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___15 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___15 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___15 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___15 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___15 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___15 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___15 *, u64);
	u64 (*get_required_mask)(struct device___15 *);
	size_t (*max_mapping_size)(struct device___15 *);
	long unsigned int (*get_merge_boundary)(struct device___15 *);
};

struct io_tlb_mem___2 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___18 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct property___8;

struct device_node___10 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___15 fwnode;
	struct property___8 *properties;
	struct property___8 *deadprops;
	struct device_node___10 *parent;
	struct device_node___10 *child;
	struct device_node___10 *sibling;
	struct kobject___17 kobj;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___6;

struct gendisk___6 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___7 *part0;
	const struct block_device_operations___6 *fops;
	struct request_queue___8 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___5 *bdi;
	struct kobject___17 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___17 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___6 {
	struct bio___6 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___7 *bip_vec;
	struct bio_vec___7 bip_inline_vecs[0];
};

struct blkcg___5;

struct blkg_policy_data___5;

struct blkcg_gq___6 {
	struct request_queue___8 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___5 *blkcg;
	struct blkcg_gq___6 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___5 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___6 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___6(struct request___7 *);

typedef void integrity_complete_fn___6(struct request___7 *, unsigned int);

struct blk_integrity_profile___6 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___6 *prepare_fn;
	integrity_complete_fn___6 *complete_fn;
	const char *name;
};

struct block_device_operations___6 {
	blk_qc_t (*submit_bio)(struct bio___6 *);
	int (*open)(struct block_device___7 *, fmode_t);
	void (*release)(struct gendisk___6 *, fmode_t);
	int (*rw_page)(struct block_device___7 *, sector_t, struct page___18 *, unsigned int);
	int (*ioctl)(struct block_device___7 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___7 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___6 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___6 *);
	int (*getgeo)(struct block_device___7 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___7 *, bool);
	void (*swap_slot_free_notify)(struct block_device___7 *, long unsigned int);
	int (*report_zones)(struct gendisk___6 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___6 *, umode_t *);
	struct module___19 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___6 *, sector_t *);
};

typedef void rq_end_io_fn___6(struct request___7 *, blk_status_t);

struct request___7 {
	struct request_queue___8 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___6 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___6 *bio;
	struct bio___6 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___7 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___6 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___6 *saved_end_io;
		} flush;
	};
	struct gendisk___6 *rq_disk;
	struct block_device___7 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___6 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___6 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___8 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___17 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___18 *debugfs_dir;
	struct dentry___18 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___6;

struct elevator_mq_ops___6 {
	int (*init_sched)(struct request_queue___8 *, struct elevator_type___6 *);
	void (*exit_sched)(struct elevator_queue___6 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___6 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___6 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___6 *);
	bool (*allow_merge)(struct request_queue___8 *, struct request___7 *, struct bio___6 *);
	bool (*bio_merge)(struct request_queue___8 *, struct bio___6 *, unsigned int);
	int (*request_merge)(struct request_queue___8 *, struct request___7 **, struct bio___6 *);
	void (*request_merged)(struct request_queue___8 *, struct request___7 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___8 *, struct request___7 *, struct request___7 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___7 *);
	void (*finish_request)(struct request___7 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___6 *, struct list_head *, bool);
	struct request___7 * (*dispatch_request)(struct blk_mq_hw_ctx___6 *);
	bool (*has_work)(struct blk_mq_hw_ctx___6 *);
	void (*completed_request)(struct request___7 *, u64);
	void (*requeue_request)(struct request___7 *);
	struct request___7 * (*former_request)(struct request_queue___8 *, struct request___7 *);
	struct request___7 * (*next_request)(struct request_queue___8 *, struct request___7 *);
	void (*init_icq)(struct io_cq___6 *);
	void (*exit_icq)(struct io_cq___6 *);
};

struct elv_fs_entry___6;

struct elevator_type___6 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___6 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___6 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___19 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___6 {
	struct elevator_type___6 *type;
	void *elevator_data;
	struct kobject___17 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___6 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___6 *, char *);
	ssize_t (*store)(struct elevator_queue___6 *, const char *, size_t);
};

struct blk_mq_queue_data___6;

struct blk_mq_ops___6 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___6 *, const struct blk_mq_queue_data___6 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___6 *);
	int (*get_budget)(struct request_queue___8 *);
	void (*put_budget)(struct request_queue___8 *, int);
	void (*set_rq_budget_token)(struct request___7 *, int);
	int (*get_rq_budget_token)(struct request___7 *);
	enum blk_eh_timer_return (*timeout)(struct request___7 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___6 *);
	void (*complete)(struct request___7 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___6 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___6 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___6 *, struct request___7 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___6 *, struct request___7 *, unsigned int);
	void (*initialize_rq_fn)(struct request___7 *);
	void (*cleanup_rq)(struct request___7 *);
	bool (*busy)(struct request_queue___8 *);
	int (*map_queues)(struct blk_mq_tag_set___6 *);
	void (*show_rq)(struct seq_file___19 *, struct request___7 *);
};

struct blk_mq_tag_set___6 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___6 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___6 {
	struct request___7 *rq;
	bool last;
};

struct blkcg_policy_data___5;

struct blkcg___5 {
	struct cgroup_subsys_state___11 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___6 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___5 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___5 {
	struct blkcg___5 *blkcg;
	int plid;
};

struct blkg_policy_data___5 {
	struct blkcg_gq___6 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___5 {
	struct mem_cgroup___5 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___5 {
	struct lruvec___6 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___5 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___5 *memcg;
};

struct obj_cgroup___5 {
	struct percpu_ref refcnt;
	struct mem_cgroup___5 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct property___8 {
	char *name;
	int length;
	void *value;
	struct property___8 *next;
	long unsigned int _flags;
	struct bin_attribute___17 attr;
};

enum swiotlb_force {
	SWIOTLB_NORMAL = 0,
	SWIOTLB_FORCE = 1,
	SWIOTLB_NO_FORCE = 2,
};

struct irq_fwspec___9 {
	struct fwnode_handle___15 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___9 {
	int (*match)(struct irq_domain___9 *, struct device_node___10 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___9 *, struct irq_fwspec___9 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___9 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___9 *, unsigned int);
	int (*xlate)(struct irq_domain___9 *, struct device_node___10 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___9 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___9 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___9 *, struct irq_data___9 *, bool);
	void (*deactivate)(struct irq_domain___9 *, struct irq_data___9 *);
	int (*translate)(struct irq_domain___9 *, struct irq_fwspec___9 *, long unsigned int *, unsigned int *);
};

struct perf_cpu_context___10;

struct perf_output_handle___10;

struct pmu___10 {
	struct list_head entry;
	struct module___19 *module;
	struct device___15 *dev;
	const struct attribute_group___17 **attr_groups;
	const struct attribute_group___17 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___10 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___10 *);
	void (*pmu_disable)(struct pmu___10 *);
	int (*event_init)(struct perf_event___10 *);
	void (*event_mapped)(struct perf_event___10 *, struct mm_struct___18 *);
	void (*event_unmapped)(struct perf_event___10 *, struct mm_struct___18 *);
	int (*add)(struct perf_event___10 *, int);
	void (*del)(struct perf_event___10 *, int);
	void (*start)(struct perf_event___10 *, int);
	void (*stop)(struct perf_event___10 *, int);
	void (*read)(struct perf_event___10 *);
	void (*start_txn)(struct pmu___10 *, unsigned int);
	int (*commit_txn)(struct pmu___10 *);
	void (*cancel_txn)(struct pmu___10 *);
	int (*event_idx)(struct perf_event___10 *);
	void (*sched_task)(struct perf_event_context___10 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___10 *, struct perf_event_context___10 *);
	void * (*setup_aux)(struct perf_event___10 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___10 *, struct perf_output_handle___10 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___10 *);
	int (*aux_output_match)(struct perf_event___10 *);
	int (*filter_match)(struct perf_event___10 *);
	int (*check_period)(struct perf_event___10 *, u64);
};

struct perf_cpu_context___10 {
	struct perf_event_context___10 ctx;
	struct perf_event_context___10 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___10 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___10 **heap;
	struct perf_event___10 *heap_default[2];
};

struct perf_output_handle___10 {
	struct perf_event___10 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___10 {
	struct cgroup_subsys_state___11 css;
	struct perf_cgroup_info *info;
};

struct dentry___19;

struct super_block___19;

struct module___20;

struct file_system_type___18 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___19 * (*mount)(struct file_system_type___18 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___19 *);
	struct module___20 *owner;
	struct file_system_type___18 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___19;

struct kiocb___18;

struct vm_area_struct___18;

struct inode___20;

struct file_lock___18;

struct page___19;

struct file_operations___18 {
	struct module___20 *owner;
	loff_t (*llseek)(struct file___19 *, loff_t, int);
	ssize_t (*read)(struct file___19 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___19 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___18 *, struct iov_iter___7 *);
	ssize_t (*write_iter)(struct kiocb___18 *, struct iov_iter___7 *);
	int (*iopoll)(struct kiocb___18 *, bool);
	int (*iterate)(struct file___19 *, struct dir_context *);
	int (*iterate_shared)(struct file___19 *, struct dir_context *);
	__poll_t (*poll)(struct file___19 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___19 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___19 *, struct vm_area_struct___18 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___20 *, struct file___19 *);
	int (*flush)(struct file___19 *, fl_owner_t);
	int (*release)(struct inode___20 *, struct file___19 *);
	int (*fsync)(struct file___19 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___19 *, int);
	int (*lock)(struct file___19 *, int, struct file_lock___18 *);
	ssize_t (*sendpage)(struct file___19 *, struct page___19 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___19 *, long unsigned int);
	int (*flock)(struct file___19 *, int, struct file_lock___18 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___19 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___19 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___19 *, long int, struct file_lock___18 **, void **);
	long int (*fallocate)(struct file___19 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___19 *);
	ssize_t (*copy_file_range)(struct file___19 *, loff_t, struct file___19 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___19 *, loff_t, struct file___19 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___19 *, loff_t, loff_t, int);
};

struct vmacache___18 {
	u64 seqnum;
	struct vm_area_struct___18 *vmas[4];
};

struct page_frag___18 {
	struct page___19 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___19;

struct pid___17;

struct nsproxy___18;

struct signal_struct___19;

struct vm_struct___18;

struct task_struct___20 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___20 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___19 *mm;
	struct mm_struct___19 *active_mm;
	struct vmacache___18 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___20 *real_parent;
	struct task_struct___20 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___20 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___17 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___18 *nsproxy;
	struct signal_struct___19 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___20 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___7 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___18 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___20 *oom_reaper_list;
	struct vm_struct___18 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___10 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___18;

struct kobj_type___18;

struct kernfs_node___18;

struct kobject___18 {
	const char *name;
	struct list_head entry;
	struct kobject___18 *parent;
	struct kset___18 *kset;
	struct kobj_type___18 *ktype;
	struct kernfs_node___18 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___18 {
	struct kobject___18 kobj;
	struct module___20 *mod;
	struct kobject___18 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___18 {
	struct module___20 *mod;
	struct latch_tree_node node;
};

struct module_layout___18 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___18 mtn;
};

struct module_attribute___18;

struct kernel_param___18;

struct module___20 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___18 mkobj;
	struct module_attribute___18 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___18 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___18 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___18 core_layout;
	struct module_layout___18 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___19 *pgtable_t___18;

struct address_space___18;

struct dev_pagemap___18;

struct page___19 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___18 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___19 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___18 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___19 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___18 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___18;

struct vm_area_struct___18 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___18 *vm_next;
	struct vm_area_struct___18 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___19 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___18 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___19 *vm_file;
	struct file___19 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___18;

struct mm_struct___19 {
	struct {
		struct vm_area_struct___18 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___19 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___18 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___20 *owner;
		struct user_namespace *user_ns;
		struct file___19 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___18;

struct address_space___18 {
	struct inode___20 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___18 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___18;

struct dev_pagemap___18 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___18 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___18;

struct path___18 {
	struct vfsmount___18 *mnt;
	struct dentry___19 *dentry;
};

struct fown_struct___17 {
	rwlock_t lock;
	struct pid___17 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___19 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___18 f_path;
	struct inode___20 *f_inode;
	const struct file_operations___18 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___17 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___18 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___18;

struct vm_operations_struct___18 {
	void (*open)(struct vm_area_struct___18 *);
	void (*close)(struct vm_area_struct___18 *);
	int (*may_split)(struct vm_area_struct___18 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___18 *);
	int (*mprotect)(struct vm_area_struct___18 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___18 *);
	vm_fault_t (*huge_fault)(struct vm_fault___18 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___18 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___18 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___18 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___18 *);
	int (*access)(struct vm_area_struct___18 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___18 *);
	int (*set_policy)(struct vm_area_struct___18 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___18 *, long unsigned int);
	struct page___19 * (*find_special_page)(struct vm_area_struct___18 *, long unsigned int);
};

struct core_thread___18 {
	struct task_struct___20 *task;
	struct core_thread___18 *next;
};

struct core_state___18 {
	atomic_t nr_threads;
	struct core_thread___18 dumper;
	struct completion startup;
};

struct vm_fault___18 {
	const struct {
		struct vm_area_struct___18 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___19 *cow_page;
	struct page___19 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___18 prealloc_pte;
};

struct dev_pagemap_ops___18 {
	void (*page_free)(struct page___19 *);
	void (*kill)(struct dev_pagemap___18 *);
	void (*cleanup)(struct dev_pagemap___18 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___18 *);
};

struct pid_namespace___17;

struct upid___17 {
	int nr;
	struct pid_namespace___17 *ns;
};

struct pid_namespace___17 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___20 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___17 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___17 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___17 numbers[1];
};

struct signal_struct___19 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___20 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___20 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___17 *pids[4];
	struct pid___17 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___19 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___18 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___17 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___18 {
	struct vm_struct___18 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___19 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___18;

struct dentry___19 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___19 *d_parent;
	struct qstr d_name;
	struct inode___20 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___18 *d_op;
	struct super_block___19 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___18;

struct inode___20 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___18 *i_op;
	struct super_block___19 *i_sb;
	struct address_space___18 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___18 *i_fop;
		void (*free_inode)(struct inode___20 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___18 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___10 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___18 {
	int (*d_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___19 *, unsigned int);
	int (*d_hash)(const struct dentry___19 *, struct qstr *);
	int (*d_compare)(const struct dentry___19 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___19 *);
	int (*d_init)(struct dentry___19 *);
	void (*d_release)(struct dentry___19 *);
	void (*d_prune)(struct dentry___19 *);
	void (*d_iput)(struct dentry___19 *, struct inode___20 *);
	char * (*d_dname)(struct dentry___19 *, char *, int);
	struct vfsmount___18 * (*d_automount)(struct path___18 *);
	int (*d_manage)(const struct path___18 *, bool);
	struct dentry___19 * (*d_real)(struct dentry___19 *, const struct inode___20 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___18;

struct mem_dqinfo___18 {
	struct quota_format_type___18 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___18;

struct quota_info___18 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___20 *files[3];
	struct mem_dqinfo___18 info[3];
	const struct quota_format_ops___18 *ops[3];
};

struct rcuwait___18 {
	struct task_struct___20 *task;
};

struct percpu_rw_semaphore___18 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___18 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___18 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___18 rw_sem[3];
};

struct super_operations___18;

struct dquot_operations___18;

struct quotactl_ops___18;

struct super_block___19 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___18 *s_type;
	const struct super_operations___18 *s_op;
	const struct dquot_operations___18 *dq_op;
	const struct quotactl_ops___18 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___19 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___18 s_dquot;
	struct sb_writers___18 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___18 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___18 {
	struct dentry___19 *mnt_root;
	struct super_block___19 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___6;

struct kiocb___18 {
	struct file___19 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___18 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___6 *ki_waitq;
	};
};

struct iattr___19 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___19 *ia_file;
};

struct dquot___18 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___19 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___18 {
	int qf_fmt_id;
	const struct quota_format_ops___18 *qf_ops;
	struct module___20 *qf_owner;
	struct quota_format_type___18 *qf_next;
};

struct quota_format_ops___18 {
	int (*check_quota_file)(struct super_block___19 *, int);
	int (*read_file_info)(struct super_block___19 *, int);
	int (*write_file_info)(struct super_block___19 *, int);
	int (*free_file_info)(struct super_block___19 *, int);
	int (*read_dqblk)(struct dquot___18 *);
	int (*commit_dqblk)(struct dquot___18 *);
	int (*release_dqblk)(struct dquot___18 *);
	int (*get_next_id)(struct super_block___19 *, struct kqid *);
};

struct dquot_operations___18 {
	int (*write_dquot)(struct dquot___18 *);
	struct dquot___18 * (*alloc_dquot)(struct super_block___19 *, int);
	void (*destroy_dquot)(struct dquot___18 *);
	int (*acquire_dquot)(struct dquot___18 *);
	int (*release_dquot)(struct dquot___18 *);
	int (*mark_dirty)(struct dquot___18 *);
	int (*write_info)(struct super_block___19 *, int);
	qsize_t * (*get_reserved_space)(struct inode___20 *);
	int (*get_projid)(struct inode___20 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___20 *, qsize_t *);
	int (*get_next_id)(struct super_block___19 *, struct kqid *);
};

struct quotactl_ops___18 {
	int (*quota_on)(struct super_block___19 *, int, int, const struct path___18 *);
	int (*quota_off)(struct super_block___19 *, int);
	int (*quota_enable)(struct super_block___19 *, unsigned int);
	int (*quota_disable)(struct super_block___19 *, unsigned int);
	int (*quota_sync)(struct super_block___19 *, int);
	int (*set_info)(struct super_block___19 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___19 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___19 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___19 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___19 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___19 *, unsigned int);
};

struct wait_page_queue___6 {
	struct page___19 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct address_space_operations___18 {
	int (*writepage)(struct page___19 *, struct writeback_control___3 *);
	int (*readpage)(struct file___19 *, struct page___19 *);
	int (*writepages)(struct address_space___18 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___19 *);
	int (*readpages)(struct file___19 *, struct address_space___18 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___19 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___19 **, void **);
	int (*write_end)(struct file___19 *, struct address_space___18 *, loff_t, unsigned int, unsigned int, struct page___19 *, void *);
	sector_t (*bmap)(struct address_space___18 *, sector_t);
	void (*invalidatepage)(struct page___19 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___19 *, gfp_t);
	void (*freepage)(struct page___19 *);
	ssize_t (*direct_IO)(struct kiocb___18 *, struct iov_iter___7 *);
	int (*migratepage)(struct address_space___18 *, struct page___19 *, struct page___19 *, enum migrate_mode);
	bool (*isolate_page)(struct page___19 *, isolate_mode_t);
	void (*putback_page)(struct page___19 *);
	int (*launder_page)(struct page___19 *);
	int (*is_partially_uptodate)(struct page___19 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___19 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___18 *, struct page___19 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___19 *, sector_t *);
	void (*swap_deactivate)(struct file___19 *);
};

struct readahead_control___3 {
	struct file___19 *file;
	struct address_space___18 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___18 {
	struct dentry___19 * (*lookup)(struct inode___20 *, struct dentry___19 *, unsigned int);
	const char * (*get_link)(struct dentry___19 *, struct inode___20 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___20 *, int);
	struct posix_acl * (*get_acl)(struct inode___20 *, int, bool);
	int (*readlink)(struct dentry___19 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___20 *, struct dentry___19 *, umode_t, bool);
	int (*link)(struct dentry___19 *, struct inode___20 *, struct dentry___19 *);
	int (*unlink)(struct inode___20 *, struct dentry___19 *);
	int (*symlink)(struct user_namespace *, struct inode___20 *, struct dentry___19 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___20 *, struct dentry___19 *, umode_t);
	int (*rmdir)(struct inode___20 *, struct dentry___19 *);
	int (*mknod)(struct user_namespace *, struct inode___20 *, struct dentry___19 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___20 *, struct dentry___19 *, struct inode___20 *, struct dentry___19 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___19 *, struct iattr___19 *);
	int (*getattr)(struct user_namespace *, const struct path___18 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___19 *, char *, size_t);
	int (*fiemap)(struct inode___20 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___20 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___20 *, struct dentry___19 *, struct file___19 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___20 *, struct dentry___19 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___20 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___19 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___19 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___18 {
	void (*fl_copy_lock)(struct file_lock___18 *, struct file_lock___18 *);
	void (*fl_release_private)(struct file_lock___18 *);
};

struct fasync_struct___18;

struct lock_manager_operations___18;

struct file_lock___18 {
	struct file_lock___18 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___19 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___18 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___18 *fl_ops;
	const struct lock_manager_operations___18 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___18 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___18 *);
	int (*lm_grant)(struct file_lock___18 *, int);
	bool (*lm_break)(struct file_lock___18 *);
	int (*lm_change)(struct file_lock___18 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___18 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___18 *);
};

struct fasync_struct___18 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___18 *fa_next;
	struct file___19 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___18 {
	struct inode___20 * (*alloc_inode)(struct super_block___19 *);
	void (*destroy_inode)(struct inode___20 *);
	void (*free_inode)(struct inode___20 *);
	void (*dirty_inode)(struct inode___20 *, int);
	int (*write_inode)(struct inode___20 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___20 *);
	void (*evict_inode)(struct inode___20 *);
	void (*put_super)(struct super_block___19 *);
	int (*sync_fs)(struct super_block___19 *, int);
	int (*freeze_super)(struct super_block___19 *);
	int (*freeze_fs)(struct super_block___19 *);
	int (*thaw_super)(struct super_block___19 *);
	int (*unfreeze_fs)(struct super_block___19 *);
	int (*statfs)(struct dentry___19 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___19 *, int *, char *);
	void (*umount_begin)(struct super_block___19 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___19 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___19 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___19 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___19 *);
	ssize_t (*quota_read)(struct super_block___19 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___19 *, int, const char *, size_t, loff_t);
	struct dquot___18 ** (*get_dquots)(struct inode___20 *);
	long int (*nr_cached_objects)(struct super_block___19 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___19 *, struct shrink_control___5 *);
	struct file___19 * (*real_loop)(struct file___19 *);
};

struct kernfs_root___18;

struct kernfs_elem_dir___18 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___18 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___18;

struct kernfs_root___18 {
	struct kernfs_node___18 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___18 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___18 {
	struct kernfs_node___18 *target_kn;
};

struct kernfs_ops___18;

struct kernfs_elem_attr___18 {
	const struct kernfs_ops___18 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___18 *notify_next;
};

struct kernfs_node___18 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___18 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___18 dir;
		struct kernfs_elem_symlink___18 symlink;
		struct kernfs_elem_attr___18 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___18;

struct kernfs_ops___18 {
	int (*open)(struct kernfs_open_file___18 *);
	void (*release)(struct kernfs_open_file___18 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___18 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___18 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___18 *, struct vm_area_struct___18 *);
};

struct kernfs_syscall_ops___18 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___18 *);
	int (*mkdir)(struct kernfs_node___18 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___18 *);
	int (*rename)(struct kernfs_node___18 *, struct kernfs_node___18 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___18 *, struct kernfs_root___18 *);
};

struct kernfs_open_file___18 {
	struct kernfs_node___18 *kn;
	struct file___19 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___18 *vm_ops;
};

struct bin_attribute___18;

struct attribute_group___18 {
	const char *name;
	umode_t (*is_visible)(struct kobject___18 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___18 *, struct bin_attribute___18 *, int);
	struct attribute **attrs;
	struct bin_attribute___18 **bin_attrs;
};

struct bin_attribute___18 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___18 * (*f_mapping)();
	ssize_t (*read)(struct file___19 *, struct kobject___18 *, struct bin_attribute___18 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___19 *, struct kobject___18 *, struct bin_attribute___18 *, char *, loff_t, size_t);
	int (*mmap)(struct file___19 *, struct kobject___18 *, struct bin_attribute___18 *, struct vm_area_struct___18 *);
};

struct sysfs_ops___18 {
	ssize_t (*show)(struct kobject___18 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___18 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___18;

struct kset___18 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___18 kobj;
	const struct kset_uevent_ops___18 *uevent_ops;
};

struct kobj_type___18 {
	void (*release)(struct kobject___18 *);
	const struct sysfs_ops___18 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___18 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___18 *);
	const void * (*namespace)(struct kobject___18 *);
	void (*get_ownership)(struct kobject___18 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___18 {
	int (* const filter)(struct kset___18 *, struct kobject___18 *);
	const char * (* const name)(struct kset___18 *, struct kobject___18 *);
	int (* const uevent)(struct kset___18 *, struct kobject___18 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___18 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___18 *);
	int (*get)(char *, const struct kernel_param___18 *);
	void (*free)(void *);
};

struct kparam_array___18;

struct kernel_param___18 {
	const char *name;
	struct module___20 *mod;
	const struct kernel_param_ops___18 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___18 *arr;
	};
};

struct kparam_array___18 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___18 *ops;
	void *elem;
};

struct module_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___18 *, struct module_kobject___18 *, char *);
	ssize_t (*store)(struct module_attribute___18 *, struct module_kobject___18 *, const char *, size_t);
	void (*setup)(struct module___20 *, const char *);
	int (*test)(struct module___20 *);
	void (*free)(struct module___20 *);
};

typedef u64 p4dval_t;

struct mhp_params {
	struct vmem_altmap *altmap;
	pgprot_t pgprot;
};

struct memory_notify {
	long unsigned int start_pfn;
	long unsigned int nr_pages;
	int status_change_nid_normal;
	int status_change_nid_high;
	int status_change_nid;
};

struct secondary_data___3 {
	struct task_struct___20 *task;
	long int status;
};

struct page_change_data {
	pgprot_t set_mask;
	pgprot_t clear_mask;
};

typedef long unsigned int vm_flags_t;

struct hstate___2 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___11 cgroup_files_dfl[7];
	struct cftype___11 cgroup_files_legacy[9];
	char name[32];
};

struct ptdump_range {
	long unsigned int start;
	long unsigned int end;
};

struct ptdump_state {
	void (*note_page)(struct ptdump_state *, long unsigned int, int, u64);
	void (*effective_prot)(struct ptdump_state *, int, u64);
	const struct ptdump_range *range;
};

struct addr_marker {
	long unsigned int start_address;
	char *name;
};

struct ptdump_info {
	struct mm_struct___7 *mm;
	const struct addr_marker *markers;
	long unsigned int base_addr;
};

enum address_markers_idx {
	PAGE_OFFSET_NR = 0,
	PAGE_END_NR = 1,
};

struct pg_state {
	struct ptdump_state ptdump;
	struct seq_file___9 *seq;
	const struct addr_marker *marker;
	long unsigned int start_address;
	int level;
	u64 current_prot;
	bool check_wx;
	long unsigned int wx_pages;
	long unsigned int uxn_pages;
};

struct prot_bits {
	u64 mask;
	u64 val;
	const char *set;
	const char *clear;
};

struct pg_level {
	const struct prot_bits *bits;
	const char *name;
	size_t num;
	u64 mask;
};

struct xa_node {
	unsigned char shift;
	unsigned char offset;
	unsigned char count;
	unsigned char nr_values;
	struct xa_node *parent;
	struct xarray *array;
	union {
		struct list_head private_list;
		struct callback_head callback_head;
	};
	long: 64;
	long: 64;
	void *slots[64];
	union {
		long unsigned int tags[3];
		long unsigned int marks[3];
	};
};

typedef void (*xa_update_node_t)(struct xa_node *);

struct xa_state {
	struct xarray *xa;
	long unsigned int xa_index;
	unsigned char xa_shift;
	unsigned char xa_sibs;
	unsigned char xa_offset;
	unsigned char xa_pad;
	struct xa_node *xa_node;
	struct xa_node *xa_alloc;
	xa_update_node_t xa_update;
};

typedef __kernel_long_t __kernel_off_t;

typedef __kernel_off_t off_t;

enum {
	BPF_REG_0 = 0,
	BPF_REG_1 = 1,
	BPF_REG_2 = 2,
	BPF_REG_3 = 3,
	BPF_REG_4 = 4,
	BPF_REG_5 = 5,
	BPF_REG_6 = 6,
	BPF_REG_7 = 7,
	BPF_REG_8 = 8,
	BPF_REG_9 = 9,
	BPF_REG_10 = 10,
	__MAX_BPF_REG = 11,
};

enum aarch64_insn_hint_cr_op {
	AARCH64_INSN_HINT_NOP = 0,
	AARCH64_INSN_HINT_YIELD = 32,
	AARCH64_INSN_HINT_WFE = 64,
	AARCH64_INSN_HINT_WFI = 96,
	AARCH64_INSN_HINT_SEV = 128,
	AARCH64_INSN_HINT_SEVL = 160,
	AARCH64_INSN_HINT_XPACLRI = 224,
	AARCH64_INSN_HINT_PACIA_1716 = 256,
	AARCH64_INSN_HINT_PACIB_1716 = 320,
	AARCH64_INSN_HINT_AUTIA_1716 = 384,
	AARCH64_INSN_HINT_AUTIB_1716 = 448,
	AARCH64_INSN_HINT_PACIAZ = 768,
	AARCH64_INSN_HINT_PACIASP = 800,
	AARCH64_INSN_HINT_PACIBZ = 832,
	AARCH64_INSN_HINT_PACIBSP = 864,
	AARCH64_INSN_HINT_AUTIAZ = 896,
	AARCH64_INSN_HINT_AUTIASP = 928,
	AARCH64_INSN_HINT_AUTIBZ = 960,
	AARCH64_INSN_HINT_AUTIBSP = 992,
	AARCH64_INSN_HINT_ESB = 512,
	AARCH64_INSN_HINT_PSB = 544,
	AARCH64_INSN_HINT_TSB = 576,
	AARCH64_INSN_HINT_CSDB = 640,
	AARCH64_INSN_HINT_CLEARBHB = 704,
	AARCH64_INSN_HINT_BTI = 1024,
	AARCH64_INSN_HINT_BTIC = 1088,
	AARCH64_INSN_HINT_BTIJ = 1152,
	AARCH64_INSN_HINT_BTIJC = 1216,
};

enum aarch64_insn_condition {
	AARCH64_INSN_COND_EQ = 0,
	AARCH64_INSN_COND_NE = 1,
	AARCH64_INSN_COND_CS = 2,
	AARCH64_INSN_COND_CC = 3,
	AARCH64_INSN_COND_MI = 4,
	AARCH64_INSN_COND_PL = 5,
	AARCH64_INSN_COND_VS = 6,
	AARCH64_INSN_COND_VC = 7,
	AARCH64_INSN_COND_HI = 8,
	AARCH64_INSN_COND_LS = 9,
	AARCH64_INSN_COND_GE = 10,
	AARCH64_INSN_COND_LT = 11,
	AARCH64_INSN_COND_GT = 12,
	AARCH64_INSN_COND_LE = 13,
	AARCH64_INSN_COND_AL = 14,
};

enum aarch64_insn_size_type {
	AARCH64_INSN_SIZE_8 = 0,
	AARCH64_INSN_SIZE_16 = 1,
	AARCH64_INSN_SIZE_32 = 2,
	AARCH64_INSN_SIZE_64 = 3,
};

enum aarch64_insn_ldst_type {
	AARCH64_INSN_LDST_LOAD_REG_OFFSET = 0,
	AARCH64_INSN_LDST_STORE_REG_OFFSET = 1,
	AARCH64_INSN_LDST_LOAD_PAIR_PRE_INDEX = 2,
	AARCH64_INSN_LDST_STORE_PAIR_PRE_INDEX = 3,
	AARCH64_INSN_LDST_LOAD_PAIR_POST_INDEX = 4,
	AARCH64_INSN_LDST_STORE_PAIR_POST_INDEX = 5,
	AARCH64_INSN_LDST_LOAD_EX = 6,
	AARCH64_INSN_LDST_STORE_EX = 7,
};

enum aarch64_insn_bitfield_type {
	AARCH64_INSN_BITFIELD_MOVE = 0,
	AARCH64_INSN_BITFIELD_MOVE_UNSIGNED = 1,
	AARCH64_INSN_BITFIELD_MOVE_SIGNED = 2,
};

enum aarch64_insn_data1_type {
	AARCH64_INSN_DATA1_REVERSE_16 = 0,
	AARCH64_INSN_DATA1_REVERSE_32 = 1,
	AARCH64_INSN_DATA1_REVERSE_64 = 2,
};

enum aarch64_insn_data2_type {
	AARCH64_INSN_DATA2_UDIV = 0,
	AARCH64_INSN_DATA2_SDIV = 1,
	AARCH64_INSN_DATA2_LSLV = 2,
	AARCH64_INSN_DATA2_LSRV = 3,
	AARCH64_INSN_DATA2_ASRV = 4,
	AARCH64_INSN_DATA2_RORV = 5,
};

enum aarch64_insn_data3_type {
	AARCH64_INSN_DATA3_MADD = 0,
	AARCH64_INSN_DATA3_MSUB = 1,
};

struct dentry___20;

struct super_block___20;

struct module___21;

struct file_system_type___19 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___20 * (*mount)(struct file_system_type___19 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___20 *);
	struct module___21 *owner;
	struct file_system_type___19 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___20;

struct kiocb___19;

struct iov_iter___8;

struct vm_area_struct___19;

struct inode___21;

struct file_lock___19;

struct page___20;

struct pipe_inode_info___4;

struct seq_file___20;

struct file_operations___19 {
	struct module___21 *owner;
	loff_t (*llseek)(struct file___20 *, loff_t, int);
	ssize_t (*read)(struct file___20 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___20 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___19 *, struct iov_iter___8 *);
	ssize_t (*write_iter)(struct kiocb___19 *, struct iov_iter___8 *);
	int (*iopoll)(struct kiocb___19 *, bool);
	int (*iterate)(struct file___20 *, struct dir_context *);
	int (*iterate_shared)(struct file___20 *, struct dir_context *);
	__poll_t (*poll)(struct file___20 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___20 *, struct vm_area_struct___19 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___21 *, struct file___20 *);
	int (*flush)(struct file___20 *, fl_owner_t);
	int (*release)(struct inode___21 *, struct file___20 *);
	int (*fsync)(struct file___20 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___20 *, int);
	int (*lock)(struct file___20 *, int, struct file_lock___19 *);
	ssize_t (*sendpage)(struct file___20 *, struct page___20 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___20 *, long unsigned int);
	int (*flock)(struct file___20 *, int, struct file_lock___19 *);
	ssize_t (*splice_write)(struct pipe_inode_info___4 *, struct file___20 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___20 *, loff_t *, struct pipe_inode_info___4 *, size_t, unsigned int);
	int (*setlease)(struct file___20 *, long int, struct file_lock___19 **, void **);
	long int (*fallocate)(struct file___20 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___20 *, struct file___20 *);
	ssize_t (*copy_file_range)(struct file___20 *, loff_t, struct file___20 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___20 *, loff_t, struct file___20 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___20 *, loff_t, loff_t, int);
};

enum {
	DUMP_PREFIX_NONE = 0,
	DUMP_PREFIX_ADDRESS = 1,
	DUMP_PREFIX_OFFSET = 2,
};

struct vmacache___19 {
	u64 seqnum;
	struct vm_area_struct___19 *vmas[4];
};

struct page_frag___19 {
	struct page___20 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___20;

struct pid___18;

struct nsproxy___19;

struct signal_struct___20;

struct css_set___12;

struct vm_struct___19;

struct task_struct___21 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___21 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___20 *mm;
	struct mm_struct___20 *active_mm;
	struct vmacache___19 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___21 *real_parent;
	struct task_struct___21 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___21 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___18 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___19 *nsproxy;
	struct signal_struct___20 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___21 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___7 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___12 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___4 *splice_pipe;
	struct page_frag___19 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___21 *oom_reaper_list;
	struct vm_struct___19 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___10 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___19;

struct kobj_type___19;

struct kernfs_node___19;

struct kobject___19 {
	const char *name;
	struct list_head entry;
	struct kobject___19 *parent;
	struct kset___19 *kset;
	struct kobj_type___19 *ktype;
	struct kernfs_node___19 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___19 {
	struct kobject___19 kobj;
	struct module___21 *mod;
	struct kobject___19 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___19 {
	struct module___21 *mod;
	struct latch_tree_node node;
};

struct module_layout___19 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___19 mtn;
};

struct module_attribute___19;

struct kernel_param___19;

struct module___21 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___19 mkobj;
	struct module_attribute___19 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___19 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___19 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___19 core_layout;
	struct module_layout___19 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___19;

struct path___19 {
	struct vfsmount___19 *mnt;
	struct dentry___20 *dentry;
};

struct fown_struct___18 {
	rwlock_t lock;
	struct pid___18 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___19;

struct file___20 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___19 f_path;
	struct inode___21 *f_inode;
	const struct file_operations___19 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___18 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___19 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___20 *pgtable_t___19;

struct page_pool___4;

struct dev_pagemap___19;

struct page___20 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___19 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___20 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___19 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___20 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___19 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___19;

struct vm_area_struct___19 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___19 *vm_next;
	struct vm_area_struct___19 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___20 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___19 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___20 *vm_file;
	struct file___20 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___19;

struct mm_struct___20 {
	struct {
		struct vm_area_struct___19 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___19 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___21 *owner;
		struct user_namespace *user_ns;
		struct file___20 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___19;

struct address_space___19 {
	struct inode___21 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___19 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___16;

struct page_pool_params___4 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___16 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___4 {
	u32 count;
	struct page___20 *cache[128];
};

struct page_pool___4 {
	struct page_pool_params___4 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___20 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___4 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___19;

struct dev_pagemap___19 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___19 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___19;

struct vm_operations_struct___19 {
	void (*open)(struct vm_area_struct___19 *);
	void (*close)(struct vm_area_struct___19 *);
	int (*may_split)(struct vm_area_struct___19 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___19 *);
	int (*mprotect)(struct vm_area_struct___19 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___19 *);
	vm_fault_t (*huge_fault)(struct vm_fault___19 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___19 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___19 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___19 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___19 *);
	int (*access)(struct vm_area_struct___19 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___19 *);
	int (*set_policy)(struct vm_area_struct___19 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___19 *, long unsigned int);
	struct page___20 * (*find_special_page)(struct vm_area_struct___19 *, long unsigned int);
};

struct core_thread___19 {
	struct task_struct___21 *task;
	struct core_thread___19 *next;
};

struct core_state___19 {
	atomic_t nr_threads;
	struct core_thread___19 dumper;
	struct completion startup;
};

struct vm_fault___19 {
	const struct {
		struct vm_area_struct___19 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___20 *cow_page;
	struct page___20 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___19 prealloc_pte;
};

struct pid_namespace___18;

struct upid___18 {
	int nr;
	struct pid_namespace___18 *ns;
};

struct pid_namespace___18 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___21 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___18 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___18 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___18 numbers[1];
};

struct signal_struct___20 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___21 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___21 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___18 *pids[4];
	struct pid___18 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___20 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___4;

struct cgroup_namespace___12;

struct nsproxy___19 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___18 *pid_ns_for_children;
	struct net___4 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___12 *cgroup_ns;
};

struct cgroup_subsys_state___12;

struct cgroup___12;

struct css_set___12 {
	struct cgroup_subsys_state___12 *subsys[14];
	refcount_t refcount;
	struct css_set___12 *dom_cset;
	struct cgroup___12 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___12 *mg_src_cgrp;
	struct cgroup___12 *mg_dst_cgrp;
	struct css_set___12 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___19;

struct pipe_buffer___4;

struct pipe_inode_info___4 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___20 *tmp_page;
	struct fasync_struct___19 *fasync_readers;
	struct fasync_struct___19 *fasync_writers;
	struct pipe_buffer___4 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___19 {
	struct vm_struct___19 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___20 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___19;

struct dentry___20 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___20 *d_parent;
	struct qstr d_name;
	struct inode___21 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___19 *d_op;
	struct super_block___20 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___19;

struct inode___21 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___19 *i_op;
	struct super_block___20 *i_sb;
	struct address_space___19 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___19 *i_fop;
		void (*free_inode)(struct inode___21 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___19 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___19 {
	int (*d_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___20 *, unsigned int);
	int (*d_hash)(const struct dentry___20 *, struct qstr *);
	int (*d_compare)(const struct dentry___20 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___20 *);
	int (*d_init)(struct dentry___20 *);
	void (*d_release)(struct dentry___20 *);
	void (*d_prune)(struct dentry___20 *);
	void (*d_iput)(struct dentry___20 *, struct inode___21 *);
	char * (*d_dname)(struct dentry___20 *, char *, int);
	struct vfsmount___19 * (*d_automount)(struct path___19 *);
	int (*d_manage)(const struct path___19 *, bool);
	struct dentry___20 * (*d_real)(struct dentry___20 *, const struct inode___21 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___19;

struct mem_dqinfo___19 {
	struct quota_format_type___19 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___19;

struct quota_info___19 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___21 *files[3];
	struct mem_dqinfo___19 info[3];
	const struct quota_format_ops___19 *ops[3];
};

struct rcuwait___19 {
	struct task_struct___21 *task;
};

struct percpu_rw_semaphore___19 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___19 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___19 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___19 rw_sem[3];
};

struct super_operations___19;

struct dquot_operations___19;

struct quotactl_ops___19;

struct super_block___20 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___19 *s_type;
	const struct super_operations___19 *s_op;
	const struct dquot_operations___19 *dq_op;
	const struct quotactl_ops___19 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___20 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___19 s_dquot;
	struct sb_writers___19 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___19 *s_d_op;
	int cleancache_poolid;
	struct shrinker___5 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___19 {
	struct dentry___20 *mnt_root;
	struct super_block___20 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___12;

struct cgroup_subsys_state___12 {
	struct cgroup___12 *cgroup;
	struct cgroup_subsys___12 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___12 *parent;
};

struct cgroup_file___12 {
	struct kernfs_node___19 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___12 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___21 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___2;

struct cgroup_bpf___2 {
	struct bpf_prog_array___2 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___2 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___12;

struct cgroup_rstat_cpu___12;

struct cgroup___12 {
	struct cgroup_subsys_state___12 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___19 *kn;
	struct cgroup_file___12 procs_file;
	struct cgroup_file___12 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___12 *subsys[14];
	struct cgroup_root___12 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___12 *dom_cgrp;
	struct cgroup___12 *old_dom_cgrp;
	struct cgroup_rstat_cpu___12 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___12 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___19 {
	struct file___20 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___19 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___6 *ki_waitq;
	};
};

struct iattr___20 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___20 *ia_file;
};

struct dquot___19 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___20 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___19 {
	int qf_fmt_id;
	const struct quota_format_ops___19 *qf_ops;
	struct module___21 *qf_owner;
	struct quota_format_type___19 *qf_next;
};

struct quota_format_ops___19 {
	int (*check_quota_file)(struct super_block___20 *, int);
	int (*read_file_info)(struct super_block___20 *, int);
	int (*write_file_info)(struct super_block___20 *, int);
	int (*free_file_info)(struct super_block___20 *, int);
	int (*read_dqblk)(struct dquot___19 *);
	int (*commit_dqblk)(struct dquot___19 *);
	int (*release_dqblk)(struct dquot___19 *);
	int (*get_next_id)(struct super_block___20 *, struct kqid *);
};

struct dquot_operations___19 {
	int (*write_dquot)(struct dquot___19 *);
	struct dquot___19 * (*alloc_dquot)(struct super_block___20 *, int);
	void (*destroy_dquot)(struct dquot___19 *);
	int (*acquire_dquot)(struct dquot___19 *);
	int (*release_dquot)(struct dquot___19 *);
	int (*mark_dirty)(struct dquot___19 *);
	int (*write_info)(struct super_block___20 *, int);
	qsize_t * (*get_reserved_space)(struct inode___21 *);
	int (*get_projid)(struct inode___21 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___21 *, qsize_t *);
	int (*get_next_id)(struct super_block___20 *, struct kqid *);
};

struct quotactl_ops___19 {
	int (*quota_on)(struct super_block___20 *, int, int, const struct path___19 *);
	int (*quota_off)(struct super_block___20 *, int);
	int (*quota_enable)(struct super_block___20 *, unsigned int);
	int (*quota_disable)(struct super_block___20 *, unsigned int);
	int (*quota_sync)(struct super_block___20 *, int);
	int (*set_info)(struct super_block___20 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___20 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___20 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___20 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___20 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___20 *, unsigned int);
};

struct address_space_operations___19 {
	int (*writepage)(struct page___20 *, struct writeback_control___3 *);
	int (*readpage)(struct file___20 *, struct page___20 *);
	int (*writepages)(struct address_space___19 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___20 *);
	int (*readpages)(struct file___20 *, struct address_space___19 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___20 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___20 **, void **);
	int (*write_end)(struct file___20 *, struct address_space___19 *, loff_t, unsigned int, unsigned int, struct page___20 *, void *);
	sector_t (*bmap)(struct address_space___19 *, sector_t);
	void (*invalidatepage)(struct page___20 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___20 *, gfp_t);
	void (*freepage)(struct page___20 *);
	ssize_t (*direct_IO)(struct kiocb___19 *, struct iov_iter___8 *);
	int (*migratepage)(struct address_space___19 *, struct page___20 *, struct page___20 *, enum migrate_mode);
	bool (*isolate_page)(struct page___20 *, isolate_mode_t);
	void (*putback_page)(struct page___20 *);
	int (*launder_page)(struct page___20 *);
	int (*is_partially_uptodate)(struct page___20 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___20 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___19 *, struct page___20 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___20 *, sector_t *);
	void (*swap_deactivate)(struct file___20 *);
};

struct bio_vec___8;

struct iov_iter___8 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___8 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___4 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___19 {
	struct dentry___20 * (*lookup)(struct inode___21 *, struct dentry___20 *, unsigned int);
	const char * (*get_link)(struct dentry___20 *, struct inode___21 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___21 *, int);
	struct posix_acl * (*get_acl)(struct inode___21 *, int, bool);
	int (*readlink)(struct dentry___20 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___21 *, struct dentry___20 *, umode_t, bool);
	int (*link)(struct dentry___20 *, struct inode___21 *, struct dentry___20 *);
	int (*unlink)(struct inode___21 *, struct dentry___20 *);
	int (*symlink)(struct user_namespace *, struct inode___21 *, struct dentry___20 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___21 *, struct dentry___20 *, umode_t);
	int (*rmdir)(struct inode___21 *, struct dentry___20 *);
	int (*mknod)(struct user_namespace *, struct inode___21 *, struct dentry___20 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___21 *, struct dentry___20 *, struct inode___21 *, struct dentry___20 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___20 *, struct iattr___20 *);
	int (*getattr)(struct user_namespace *, const struct path___19 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___20 *, char *, size_t);
	int (*fiemap)(struct inode___21 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___21 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___21 *, struct dentry___20 *, struct file___20 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___21 *, struct dentry___20 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___21 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___20 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___20 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___19 {
	void (*fl_copy_lock)(struct file_lock___19 *, struct file_lock___19 *);
	void (*fl_release_private)(struct file_lock___19 *);
};

struct lock_manager_operations___19;

struct file_lock___19 {
	struct file_lock___19 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___20 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___19 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___19 *fl_ops;
	const struct lock_manager_operations___19 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___19 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___19 *);
	int (*lm_grant)(struct file_lock___19 *, int);
	bool (*lm_break)(struct file_lock___19 *);
	int (*lm_change)(struct file_lock___19 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___19 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___19 *);
};

struct fasync_struct___19 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___19 *fa_next;
	struct file___20 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___19 {
	struct inode___21 * (*alloc_inode)(struct super_block___20 *);
	void (*destroy_inode)(struct inode___21 *);
	void (*free_inode)(struct inode___21 *);
	void (*dirty_inode)(struct inode___21 *, int);
	int (*write_inode)(struct inode___21 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___21 *);
	void (*evict_inode)(struct inode___21 *);
	void (*put_super)(struct super_block___20 *);
	int (*sync_fs)(struct super_block___20 *, int);
	int (*freeze_super)(struct super_block___20 *);
	int (*freeze_fs)(struct super_block___20 *);
	int (*thaw_super)(struct super_block___20 *);
	int (*unfreeze_fs)(struct super_block___20 *);
	int (*statfs)(struct dentry___20 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___20 *, int *, char *);
	void (*umount_begin)(struct super_block___20 *);
	int (*show_options)(struct seq_file___20 *, struct dentry___20 *);
	int (*show_devname)(struct seq_file___20 *, struct dentry___20 *);
	int (*show_path)(struct seq_file___20 *, struct dentry___20 *);
	int (*show_stats)(struct seq_file___20 *, struct dentry___20 *);
	ssize_t (*quota_read)(struct super_block___20 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___20 *, int, const char *, size_t, loff_t);
	struct dquot___19 ** (*get_dquots)(struct inode___21 *);
	long int (*nr_cached_objects)(struct super_block___20 *, struct shrink_control___5 *);
	long int (*free_cached_objects)(struct super_block___20 *, struct shrink_control___5 *);
	struct file___20 * (*real_loop)(struct file___20 *);
};

struct seq_operations___18;

struct seq_file___20 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___18 *op;
	int poll_event;
	const struct file___20 *file;
	void *private;
};

struct kernfs_root___19;

struct kernfs_elem_dir___19 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___19 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___19;

struct kernfs_root___19 {
	struct kernfs_node___19 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___19 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___19 {
	struct kernfs_node___19 *target_kn;
};

struct kernfs_ops___19;

struct kernfs_elem_attr___19 {
	const struct kernfs_ops___19 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___19 *notify_next;
};

struct kernfs_node___19 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___19 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___19 dir;
		struct kernfs_elem_symlink___19 symlink;
		struct kernfs_elem_attr___19 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___19;

struct kernfs_ops___19 {
	int (*open)(struct kernfs_open_file___19 *);
	void (*release)(struct kernfs_open_file___19 *);
	int (*seq_show)(struct seq_file___20 *, void *);
	void * (*seq_start)(struct seq_file___20 *, loff_t *);
	void * (*seq_next)(struct seq_file___20 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___20 *, void *);
	ssize_t (*read)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___19 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___19 *, struct vm_area_struct___19 *);
};

struct kernfs_syscall_ops___19 {
	int (*show_options)(struct seq_file___20 *, struct kernfs_root___19 *);
	int (*mkdir)(struct kernfs_node___19 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___19 *);
	int (*rename)(struct kernfs_node___19 *, struct kernfs_node___19 *, const char *);
	int (*show_path)(struct seq_file___20 *, struct kernfs_node___19 *, struct kernfs_root___19 *);
};

struct kernfs_open_file___19 {
	struct kernfs_node___19 *kn;
	struct file___20 *file;
	struct seq_file___20 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___19 *vm_ops;
};

struct bin_attribute___19;

struct attribute_group___19 {
	const char *name;
	umode_t (*is_visible)(struct kobject___19 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___19 *, struct bin_attribute___19 *, int);
	struct attribute **attrs;
	struct bin_attribute___19 **bin_attrs;
};

struct bin_attribute___19 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___19 * (*f_mapping)();
	ssize_t (*read)(struct file___20 *, struct kobject___19 *, struct bin_attribute___19 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___20 *, struct kobject___19 *, struct bin_attribute___19 *, char *, loff_t, size_t);
	int (*mmap)(struct file___20 *, struct kobject___19 *, struct bin_attribute___19 *, struct vm_area_struct___19 *);
};

struct sysfs_ops___19 {
	ssize_t (*show)(struct kobject___19 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___19 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___19;

struct kset___19 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___19 kobj;
	const struct kset_uevent_ops___19 *uevent_ops;
};

struct kobj_type___19 {
	void (*release)(struct kobject___19 *);
	const struct sysfs_ops___19 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___19 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___19 *);
	const void * (*namespace)(struct kobject___19 *);
	void (*get_ownership)(struct kobject___19 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___19 {
	int (* const filter)(struct kset___19 *, struct kobject___19 *);
	const char * (* const name)(struct kset___19 *, struct kobject___19 *);
	int (* const uevent)(struct kset___19 *, struct kobject___19 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___19 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___19 *);
	int (*get)(char *, const struct kernel_param___19 *);
	void (*free)(void *);
};

struct kparam_array___19;

struct kernel_param___19 {
	const char *name;
	struct module___21 *mod;
	const struct kernel_param_ops___19 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___19 *arr;
	};
};

struct kparam_array___19 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___19 *ops;
	void *elem;
};

struct module_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___19 *, struct module_kobject___19 *, char *);
	ssize_t (*store)(struct module_attribute___19 *, struct module_kobject___19 *, const char *, size_t);
	void (*setup)(struct module___21 *, const char *);
	int (*test)(struct module___21 *);
	void (*free)(struct module___21 *);
};

struct dev_pagemap_ops___19 {
	void (*page_free)(struct page___20 *);
	void (*kill)(struct dev_pagemap___19 *);
	void (*cleanup)(struct dev_pagemap___19 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___19 *);
};

struct bpf_iter_aux_info___2;

typedef int (*bpf_iter_init_seq_priv_t___2)(void *, struct bpf_iter_aux_info___2 *);

struct bpf_map___2;

struct bpf_iter_aux_info___2 {
	struct bpf_map___2 *map;
};

struct bpf_iter_seq_info___2 {
	const struct seq_operations___18 *seq_ops;
	bpf_iter_init_seq_priv_t___2 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___18 {
	void * (*start)(struct seq_file___20 *, loff_t *);
	void (*stop)(struct seq_file___20 *, void *);
	void * (*next)(struct seq_file___20 *, void *, loff_t *);
	int (*show)(struct seq_file___20 *, void *);
};

struct bpf_prog_aux___2;

struct bpf_prog___2;

struct bpf_map_ops___2 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___2 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___2 *, struct file___20 *);
	void (*map_free)(struct bpf_map___2 *);
	int (*map_get_next_key)(struct bpf_map___2 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___2 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___2 *, void *);
	int (*map_lookup_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___2 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___2 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___2 *, void *);
	int (*map_update_elem)(struct bpf_map___2 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___2 *, void *);
	int (*map_push_elem)(struct bpf_map___2 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___2 *, void *);
	int (*map_peek_elem)(struct bpf_map___2 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___2 *, struct file___20 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___2 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___2 *, void *, struct seq_file___20 *);
	int (*map_check_btf)(const struct bpf_map___2 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___2 *, struct bpf_prog_aux___2 *);
	void (*map_poke_untrack)(struct bpf_map___2 *, struct bpf_prog_aux___2 *);
	void (*map_poke_run)(struct bpf_map___2 *, u32, struct bpf_prog___2 *, struct bpf_prog___2 *);
	int (*map_direct_value_addr)(const struct bpf_map___2 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___2 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___2 *, struct vm_area_struct___19 *);
	__poll_t (*map_poll)(struct bpf_map___2 *, struct file___20 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___2 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___2 *, const struct bpf_map___2 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___2 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___2 *iter_seq_info;
};

struct bpf_map___2 {
	const struct bpf_map_ops___2 *ops;
	struct bpf_map___2 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___2;

struct bpf_jit_poke_descriptor___2;

struct bpf_prog_ops___2;

struct btf_mod_pair___2;

struct bpf_prog_offload___2;

struct bpf_prog_aux___2 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___2 *dst_prog;
	struct bpf_trampoline___2 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___2 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___2 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___2 *ops;
	struct bpf_map___2 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___2 *used_btfs;
	struct bpf_prog___2 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___2 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___2 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___2 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___2 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___2;

struct bpf_map_dev_ops___2 {
	int (*map_get_next_key)(struct bpf_offloaded_map___2 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___2 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___2 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___2 *, void *);
};

struct net_device___7;

struct bpf_offloaded_map___2 {
	struct bpf_map___2 map;
	struct net_device___7 *netdev;
	const struct bpf_map_dev_ops___2 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___3;

typedef rx_handler_result_t rx_handler_func_t___2(struct sk_buff___3 **);

typedef struct {
	struct net___4 *net;
} possible_net_t___2;

struct wakeup_source___16;

struct dev_pm_info___16 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___16 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___16 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___16;

struct bus_type___16;

struct device_driver___16;

struct dev_pm_domain___16;

struct fwnode_handle___16;

struct class___16;

struct device___16 {
	struct kobject___19 kobj;
	struct device___16 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___16 *type;
	struct bus_type___16 *bus;
	struct device_driver___16 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___16 power;
	struct dev_pm_domain___16 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___16 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___16 *class;
	const struct attribute_group___19 **groups;
	void (*release)(struct device___16 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___2 {
	struct bpf_prog___2 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___2;

struct net_device_ops___2;

struct l3mdev_ops___2;

struct xfrmdev_ops___2;

struct header_ops___2;

struct netdev_rx_queue___2;

struct mini_Qdisc___2;

struct netdev_queue___2;

struct Qdisc___2;

struct rtnl_link_ops___2;

struct dcbnl_rtnl_ops___2;

struct net_device___7 {
	char name[16];
	struct netdev_name_node___2 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___2 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___2 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___2 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___19 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___2 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___2 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___2 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___2 *miniq_ingress;
	struct netdev_queue___2 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___2 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___2 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___2 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___2 = 0,
		NETREG_REGISTERED___2 = 1,
		NETREG_UNREGISTERING___2 = 2,
		NETREG_UNREGISTERED___2 = 3,
		NETREG_RELEASED___2 = 4,
		NETREG_DUMMY___2 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___2 = 0,
		RTNL_LINK_INITIALIZING___2 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___7 *);
	struct netpoll_info *npinfo;
	possible_net_t___2 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___16 dev;
	const struct attribute_group___19 *sysfs_groups[4];
	const struct attribute_group___19 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___2 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___2 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___2 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___2 {
	int (*test_run)(struct bpf_prog___2 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___2 {
	struct bpf_prog___2 *prog;
	struct net_device___7 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___2 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___2 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___21 *mod;
};

struct bpf_jit_poke_descriptor___2 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___2 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___2 {
	struct btf *btf;
	struct module___21 *module;
};

struct bpf_prog_array_item___2 {
	struct bpf_prog___2 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___2 {
	struct callback_head rcu;
	struct bpf_prog_array_item___2 items[0];
};

struct sk_buff___3 {
	union {
		struct {
			struct sk_buff___3 *next;
			struct sk_buff___3 *prev;
			union {
				struct net_device___7 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___3 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bio_vec___8 {
	struct page___20 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fwnode_operations___16;

struct fwnode_handle___16 {
	struct fwnode_handle___16 *secondary;
	const struct fwnode_operations___16 *ops;
	struct device___16 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___16;

struct fwnode_endpoint___16;

struct fwnode_operations___16 {
	struct fwnode_handle___16 * (*get)(struct fwnode_handle___16 *);
	void (*put)(struct fwnode_handle___16 *);
	bool (*device_is_available)(const struct fwnode_handle___16 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___16 *, const struct device___16 *);
	bool (*property_present)(const struct fwnode_handle___16 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___16 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___16 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___16 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_parent)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_next_child_node)(const struct fwnode_handle___16 *, struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*get_named_child_node)(const struct fwnode_handle___16 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___16 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___16 *);
	struct fwnode_handle___16 * (*graph_get_next_endpoint)(const struct fwnode_handle___16 *, struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*graph_get_remote_endpoint)(const struct fwnode_handle___16 *);
	struct fwnode_handle___16 * (*graph_get_port_parent)(struct fwnode_handle___16 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___16 *, struct fwnode_endpoint___16 *);
	int (*add_links)(struct fwnode_handle___16 *);
};

struct fwnode_endpoint___16 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___16 *local_fwnode;
};

struct fwnode_reference_args___16 {
	struct fwnode_handle___16 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fqdir___3;

struct netns_ipv4___3 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___3 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___3 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___3 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___7 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___3 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___3 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___3 *);
	int (*local_out)(struct net___4 *, struct sock *, struct sk_buff___3 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___3 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___3 {
	struct dst_ops___3 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___3 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___3 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___3 *fqdir;
};

struct sk_buff_head___2 {
	struct sk_buff___3 *next;
	struct sk_buff___3 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___2 {
	struct bpf_prog_array___2 *run_array[2];
	struct bpf_prog___2 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___3 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___3 xfrm4_dst_ops;
	struct dst_ops___3 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___4 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___7 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___3 ipv4;
	struct netns_ipv6___3 ipv6;
	struct netns_ieee802154_lowpan___3 ieee802154_lowpan;
	struct netns_sctp sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___2 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___2 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___3 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___12 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___12 *root_cset;
};

struct dev_pm_ops___16 {
	int (*prepare)(struct device___16 *);
	void (*complete)(struct device___16 *);
	int (*suspend)(struct device___16 *);
	int (*resume)(struct device___16 *);
	int (*freeze)(struct device___16 *);
	int (*thaw)(struct device___16 *);
	int (*poweroff)(struct device___16 *);
	int (*restore)(struct device___16 *);
	int (*suspend_late)(struct device___16 *);
	int (*resume_early)(struct device___16 *);
	int (*freeze_late)(struct device___16 *);
	int (*thaw_early)(struct device___16 *);
	int (*poweroff_late)(struct device___16 *);
	int (*restore_early)(struct device___16 *);
	int (*suspend_noirq)(struct device___16 *);
	int (*resume_noirq)(struct device___16 *);
	int (*freeze_noirq)(struct device___16 *);
	int (*thaw_noirq)(struct device___16 *);
	int (*poweroff_noirq)(struct device___16 *);
	int (*restore_noirq)(struct device___16 *);
	int (*runtime_suspend)(struct device___16 *);
	int (*runtime_resume)(struct device___16 *);
	int (*runtime_idle)(struct device___16 *);
};

struct wakeup_source___16 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___16 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___16 {
	struct dev_pm_ops___16 ops;
	int (*start)(struct device___16 *);
	void (*detach)(struct device___16 *, bool);
	int (*activate)(struct device___16 *);
	void (*sync)(struct device___16 *);
	void (*dismiss)(struct device___16 *);
};

struct bus_type___16 {
	const char *name;
	const char *dev_name;
	struct device___16 *dev_root;
	const struct attribute_group___19 **bus_groups;
	const struct attribute_group___19 **dev_groups;
	const struct attribute_group___19 **drv_groups;
	int (*match)(struct device___16 *, struct device_driver___16 *);
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	int (*probe)(struct device___16 *);
	void (*sync_state)(struct device___16 *);
	void (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*online)(struct device___16 *);
	int (*offline)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	int (*num_vf)(struct device___16 *);
	int (*dma_configure)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___16 {
	const char *name;
	struct bus_type___16 *bus;
	struct module___21 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___16 *);
	void (*sync_state)(struct device___16 *);
	int (*remove)(struct device___16 *);
	void (*shutdown)(struct device___16 *);
	int (*suspend)(struct device___16 *, pm_message_t);
	int (*resume)(struct device___16 *);
	const struct attribute_group___19 **groups;
	const struct attribute_group___19 **dev_groups;
	const struct dev_pm_ops___16 *pm;
	void (*coredump)(struct device___16 *);
	struct driver_private *p;
};

struct device_type___16 {
	const char *name;
	const struct attribute_group___19 **groups;
	int (*uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___16 *);
	const struct dev_pm_ops___16 *pm;
};

struct class___16 {
	const char *name;
	struct module___21 *owner;
	const struct attribute_group___19 **class_groups;
	const struct attribute_group___19 **dev_groups;
	struct kobject___19 *dev_kobj;
	int (*dev_uevent)(struct device___16 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___16 *, umode_t *);
	void (*class_release)(struct class___16 *);
	void (*dev_release)(struct device___16 *);
	int (*shutdown_pre)(struct device___16 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___16 *);
	void (*get_ownership)(struct device___16 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___16 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___4;

struct pipe_buffer___4 {
	struct page___20 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___4 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___4 {
	int (*confirm)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	void (*release)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	bool (*try_steal)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
	bool (*get)(struct pipe_inode_info___4 *, struct pipe_buffer___4 *);
};

struct inet_frags___3;

struct fqdir___3 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___3 *f;
	struct net___4 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___3;

struct inet_frags___3 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___3 *, const void *);
	void (*destructor)(struct inet_frag_queue___3 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___3 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___3 *fragments_tail;
	struct sk_buff___3 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___3 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___2 {
	int (*ieee_getets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___7 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___7 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___7 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___7 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___7 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___7 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___7 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___7 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___7 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___7 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___7 *);
	u8 (*setstate)(struct net_device___7 *, u8);
	void (*getpermhwaddr)(struct net_device___7 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___7 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___7 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___7 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___7 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___7 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___7 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___7 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___7 *, int, u8 *);
	void (*setpfccfg)(struct net_device___7 *, int, u8);
	void (*getpfccfg)(struct net_device___7 *, int, u8 *);
	u8 (*setall)(struct net_device___7 *);
	u8 (*getcap)(struct net_device___7 *, int, u8 *);
	int (*getnumtcs)(struct net_device___7 *, int, u8 *);
	int (*setnumtcs)(struct net_device___7 *, int, u8);
	u8 (*getpfcstate)(struct net_device___7 *);
	void (*setpfcstate)(struct net_device___7 *, u8);
	void (*getbcncfg)(struct net_device___7 *, int, u32 *);
	void (*setbcncfg)(struct net_device___7 *, int, u32);
	void (*getbcnrp)(struct net_device___7 *, int, u8 *);
	void (*setbcnrp)(struct net_device___7 *, int, u8);
	int (*setapp)(struct net_device___7 *, u8, u16, u8);
	int (*getapp)(struct net_device___7 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___7 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___7 *, int, u8);
	u8 (*getdcbx)(struct net_device___7 *);
	u8 (*setdcbx)(struct net_device___7 *, u8);
	int (*peer_getappinfo)(struct net_device___7 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___7 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___7 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___7 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___7 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___7 *, struct dcbnl_buffer *);
};

struct cftype___12;

struct cgroup_subsys___12 {
	struct cgroup_subsys_state___12 * (*css_alloc)(struct cgroup_subsys_state___12 *);
	int (*css_online)(struct cgroup_subsys_state___12 *);
	void (*css_offline)(struct cgroup_subsys_state___12 *);
	void (*css_released)(struct cgroup_subsys_state___12 *);
	void (*css_free)(struct cgroup_subsys_state___12 *);
	void (*css_reset)(struct cgroup_subsys_state___12 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___12 *, int);
	int (*css_extra_stat_show)(struct seq_file___20 *, struct cgroup_subsys_state___12 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___21 *, struct css_set___12 *);
	void (*cancel_fork)(struct task_struct___21 *, struct css_set___12 *);
	void (*fork)(struct task_struct___21 *);
	void (*exit)(struct task_struct___21 *);
	void (*release)(struct task_struct___21 *);
	void (*bind)(struct cgroup_subsys_state___12 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___12 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___12 *dfl_cftypes;
	struct cftype___12 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___12 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___12 *updated_children;
	struct cgroup___12 *updated_next;
};

struct cgroup_root___12 {
	struct kernfs_root___19 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___12 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___12 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___12 *ss;
	struct list_head node;
	struct kernfs_ops___19 *kf_ops;
	int (*open)(struct kernfs_open_file___19 *);
	void (*release)(struct kernfs_open_file___19 *);
	u64 (*read_u64)(struct cgroup_subsys_state___12 *, struct cftype___12 *);
	s64 (*read_s64)(struct cgroup_subsys_state___12 *, struct cftype___12 *);
	int (*seq_show)(struct seq_file___20 *, void *);
	void * (*seq_start)(struct seq_file___20 *, loff_t *);
	void * (*seq_next)(struct seq_file___20 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___20 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___12 *, struct cftype___12 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___12 *, struct cftype___12 *, s64);
	ssize_t (*write)(struct kernfs_open_file___19 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___19 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___2 {
	struct net_device___7 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___2 {
	struct net_device___7 *dev;
};

struct xdp_buff___2 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___2 *rxq;
	struct xdp_txq_info___2 *txq;
	u32 frame_sz;
};

struct xdp_frame___2 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___7 *dev_rx;
};

struct netlink_callback___2 {
	struct sk_buff___3 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___3 *, struct netlink_callback___2 *);
	int (*done)(struct netlink_callback___2 *);
	void *data;
	struct module___21 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___2 {
	int (*create)(struct sk_buff___3 *, struct net_device___7 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___3 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___7 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___3 *);
};

struct netdev_queue___2 {
	struct net_device___7 *dev;
	struct Qdisc___2 *qdisc;
	struct Qdisc___2 *qdisc_sleeping;
	struct kobject___19 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___7 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___2 {
	struct sk_buff___3 *head;
	struct sk_buff___3 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___2;

struct Qdisc___2 {
	int (*enqueue)(struct sk_buff___3 *, struct Qdisc___2 *, struct sk_buff___3 **);
	struct sk_buff___3 * (*dequeue)(struct Qdisc___2 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___2 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___2 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___2 gso_skb;
	struct qdisc_skb_head___2 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___2 *next_sched;
	struct sk_buff_head___2 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___2 {
	struct xdp_rxq_info___2 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___19 kobj;
	struct net_device___7 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___2 {
	enum net_device_path_type type;
	const struct net_device___7 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___2 = 0,
				DEV_PATH_BR_VLAN_TAG___2 = 1,
				DEV_PATH_BR_VLAN_UNTAG___2 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___2 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___2 {
	const struct net_device___7 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___2 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___2 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___2 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___2 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___3 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___2 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___7 *dev;
	const char *name;
};

struct neigh_parms___2;

struct net_device_ops___2 {
	int (*ndo_init)(struct net_device___7 *);
	void (*ndo_uninit)(struct net_device___7 *);
	int (*ndo_open)(struct net_device___7 *);
	int (*ndo_stop)(struct net_device___7 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___3 *, struct net_device___7 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___3 *, struct net_device___7 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___7 *, struct sk_buff___3 *, struct net_device___7 *);
	void (*ndo_change_rx_flags)(struct net_device___7 *, int);
	void (*ndo_set_rx_mode)(struct net_device___7 *);
	int (*ndo_set_mac_address)(struct net_device___7 *, void *);
	int (*ndo_validate_addr)(struct net_device___7 *);
	int (*ndo_do_ioctl)(struct net_device___7 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___7 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___7 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___7 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___7 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___7 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___7 *, int);
	int (*ndo_neigh_setup)(struct net_device___7 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___7 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___7 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___7 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___7 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___7 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___7 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___7 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___7 *);
	int (*ndo_netpoll_setup)(struct net_device___7 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___7 *);
	int (*ndo_set_vf_mac)(struct net_device___7 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___7 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___7 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___7 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___7 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___7 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___7 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___7 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___7 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___7 *, int, struct sk_buff___3 *);
	int (*ndo_get_vf_guid)(struct net_device___7 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___7 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___7 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___7 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___7 *);
	int (*ndo_fcoe_disable)(struct net_device___7 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___7 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___7 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___7 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___7 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___7 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___7 *, const struct sk_buff___3 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___7 *, struct net_device___7 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___7 *, struct net_device___7 *);
	struct net_device___7 * (*ndo_get_xmit_slave)(struct net_device___7 *, struct sk_buff___3 *, bool);
	struct net_device___7 * (*ndo_sk_get_lower_dev)(struct net_device___7 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___7 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___7 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___7 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___7 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___3 *, struct netlink_callback___2 *, struct net_device___7 *, struct net_device___7 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___3 *, struct nlattr **, struct net_device___7 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___7 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___3 *, u32, u32, struct net_device___7 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___7 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___7 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___7 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___7 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___7 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___7 *, struct net_device___7 *);
	void (*ndo_dfwd_del_station)(struct net_device___7 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___7 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___7 *);
	int (*ndo_change_proto_down)(struct net_device___7 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___7 *, struct sk_buff___3 *);
	void (*ndo_set_rx_headroom)(struct net_device___7 *, int);
	int (*ndo_bpf)(struct net_device___7 *, struct netdev_bpf___2 *);
	int (*ndo_xdp_xmit)(struct net_device___7 *, int, struct xdp_frame___2 **, u32);
	struct net_device___7 * (*ndo_xdp_get_xmit_slave)(struct net_device___7 *, struct xdp_buff___2 *);
	int (*ndo_xsk_wakeup)(struct net_device___7 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___7 *);
	int (*ndo_tunnel_ctl)(struct net_device___7 *, struct ip_tunnel_parm *, int);
	struct net_device___7 * (*ndo_get_peer_dev)(struct net_device___7 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___2 *, struct net_device_path___2 *);
};

struct net_device___8;

struct sk_buff___4;

struct sock___4;

struct dst_entry___2;

struct l3mdev_ops___2 {
	u32 (*l3mdev_fib_table)(const struct net_device___8 *);
	struct sk_buff___4 * (*l3mdev_l3_rcv)(struct net_device___8 *, struct sk_buff___4 *, u16);
	struct sk_buff___4 * (*l3mdev_l3_out)(struct net_device___8 *, struct sock___4 *, struct sk_buff___4 *, u16);
	struct dst_entry___2 * (*l3mdev_link_scope_lookup)(const struct net_device___8 *, struct flowi6 *);
};

struct tcf_proto___2;

struct tcf_block___2;

struct mini_Qdisc___2 {
	struct tcf_proto___2 *filter_list;
	struct tcf_block___2 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___2 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___7 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___7 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___4 *, struct net_device___7 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___7 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___7 *, struct list_head *);
	size_t (*get_size)(const struct net_device___7 *);
	int (*fill_info)(struct sk_buff___3 *, const struct net_device___7 *);
	size_t (*get_xstats_size)(const struct net_device___7 *);
	int (*fill_xstats)(struct sk_buff___3 *, const struct net_device___7 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___7 *, struct net_device___7 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___7 *, const struct net_device___7 *);
	int (*fill_slave_info)(struct sk_buff___3 *, const struct net_device___7 *, const struct net_device___7 *);
	struct net___4 * (*get_link_net)(const struct net_device___7 *);
	size_t (*get_linkxstats_size)(const struct net_device___7 *, int);
	int (*fill_linkxstats)(struct sk_buff___3 *, const struct net_device___7 *, int *, int);
};

struct gnet_dump___2 {
	spinlock_t *lock;
	struct sk_buff___3 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___2;

struct Qdisc_ops___2 {
	struct Qdisc_ops___2 *next;
	const struct Qdisc_class_ops___2 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___3 *, struct Qdisc___2 *, struct sk_buff___3 **);
	struct sk_buff___3 * (*dequeue)(struct Qdisc___2 *);
	struct sk_buff___3 * (*peek)(struct Qdisc___2 *);
	int (*init)(struct Qdisc___2 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___2 *);
	void (*destroy)(struct Qdisc___2 *);
	int (*change)(struct Qdisc___2 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___2 *);
	int (*change_tx_queue_len)(struct Qdisc___2 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___2 *, unsigned int);
	int (*dump)(struct Qdisc___2 *, struct sk_buff___3 *);
	int (*dump_stats)(struct Qdisc___2 *, struct gnet_dump___2 *);
	void (*ingress_block_set)(struct Qdisc___2 *, u32);
	void (*egress_block_set)(struct Qdisc___2 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___2 *);
	u32 (*egress_block_get)(struct Qdisc___2 *);
	struct module___21 *owner;
};

struct Qdisc_class_ops___2 {
	unsigned int flags;
	struct netdev_queue___2 * (*select_queue)(struct Qdisc___2 *, struct tcmsg *);
	int (*graft)(struct Qdisc___2 *, long unsigned int, struct Qdisc___2 *, struct Qdisc___2 **, struct netlink_ext_ack *);
	struct Qdisc___2 * (*leaf)(struct Qdisc___2 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___2 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___2 *, u32);
	int (*change)(struct Qdisc___2 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___2 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___2 *, struct qdisc_walker *);
	struct tcf_block___2 * (*tcf_block)(struct Qdisc___2 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___2 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___2 *, long unsigned int);
	int (*dump)(struct Qdisc___2 *, long unsigned int, struct sk_buff___3 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___2 *, long unsigned int, struct gnet_dump___2 *);
};

struct tcf_chain___2;

struct tcf_block___2 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___4 *net;
	struct Qdisc___2 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___2 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___2;

struct tcf_proto_ops___2;

struct tcf_proto___2 {
	struct tcf_proto___2 *next;
	void *root;
	int (*classify)(struct sk_buff___3 *, const struct tcf_proto___2 *, struct tcf_result___2 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___2 *ops;
	struct tcf_chain___2 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___2 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___2 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___2 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___3 *, const struct tcf_proto___2 *, struct tcf_result___2 *);
	int (*init)(struct tcf_proto___2 *);
	void (*destroy)(struct tcf_proto___2 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___2 *, u32);
	void (*put)(struct tcf_proto___2 *, void *);
	int (*change)(struct net___4 *, struct sk_buff___3 *, struct tcf_proto___2 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___2 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___2 *);
	void (*walk)(struct tcf_proto___2 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___2 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___2 *, void *);
	void (*hw_del)(struct tcf_proto___2 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___4 *, struct tcf_chain___2 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___4 *, struct tcf_proto___2 *, void *, struct sk_buff___3 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___4 *, struct tcf_proto___2 *, void *, struct sk_buff___3 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___3 *, struct net___4 *, void *);
	struct module___21 *owner;
	int flags;
};

struct tcf_chain___2 {
	struct mutex filter_chain_lock;
	struct tcf_proto___2 *filter_chain;
	struct list_head list;
	struct tcf_block___2 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___2 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_binary_header {
	u32 pages;
	int: 32;
	u8 image[0];
};

typedef void (*bpf_jit_fill_hole_t)(void *, unsigned int);

struct jit_ctx {
	const struct bpf_prog___2 *prog;
	int idx;
	int epilogue_offset;
	int *offset;
	int exentry_idx;
	__le32 *image;
	u32 stack_size;
};

struct arm64_jit_data {
	struct bpf_binary_header *header;
	u8 *image;
	struct jit_ctx ctx;
};

typedef u64 gpa_t;

typedef u64 gfn_t;

typedef long unsigned int hva_t;

typedef u64 hpa_t;

typedef u64 hfn_t;

typedef hfn_t kvm_pfn_t;

struct kvm_memory_slot;

struct gfn_to_hva_cache {
	u64 generation;
	gpa_t gpa;
	long unsigned int hva;
	long unsigned int len;
	struct kvm_memory_slot *memslot;
};

struct kvm_arch_memory_slot {};

struct kvm_memory_slot {
	gfn_t base_gfn;
	long unsigned int npages;
	long unsigned int *dirty_bitmap;
	struct kvm_arch_memory_slot arch;
	long unsigned int userspace_addr;
	u32 flags;
	short int id;
	u16 as_id;
};

struct gfn_to_pfn_cache {
	u64 generation;
	gfn_t gfn;
	kvm_pfn_t pfn;
	bool dirty;
};

struct kvm_mmu_memory_cache {
	int nobjs;
	gfp_t gfp_zero;
	struct kmem_cache *kmem_cache;
	void *objects[40];
};

struct kvm_vm_stat_generic {
	u64 remote_tlb_flush;
	u64 remote_tlb_flush_requests;
};

struct kvm_vcpu_stat_generic {
	u64 halt_successful_poll;
	u64 halt_attempted_poll;
	u64 halt_poll_invalid;
	u64 halt_wakeup;
	u64 halt_poll_success_ns;
	u64 halt_poll_fail_ns;
	u64 halt_wait_ns;
	u64 halt_poll_success_hist[32];
	u64 halt_poll_fail_hist[32];
	u64 halt_wait_hist[32];
};

struct kvm_vcpu;

struct kvm_io_device;

struct kvm_io_device_ops {
	int (*read)(struct kvm_vcpu *, struct kvm_io_device *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu *, struct kvm_io_device *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device *);
};

struct preempt_ops;

struct preempt_notifier {
	struct hlist_node link;
	struct preempt_ops *ops;
};

struct task_struct___22;

struct rcuwait___20 {
	struct task_struct___22 *task;
};

struct kvm_mmio_fragment {
	gpa_t gpa;
	void *data;
	unsigned int len;
};

struct kvm_cpu_context {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu *__hyp_running_vcpu;
	long: 64;
};

struct kvm_vcpu_fault_info {
	u32 esr_el2;
	u64 far_el2;
	u64 hpfar_el2;
	u64 disr_el1;
};

struct kvm_guest_debug_arch {
	__u64 dbg_bcr[16];
	__u64 dbg_bvr[16];
	__u64 dbg_wcr[16];
	__u64 dbg_wvr[16];
};

struct vgic_v2_cpu_if {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_apr;
	u32 vgic_lr[64];
	unsigned int used_lrs;
};

struct page___21;

struct its_vm;

struct fwnode_handle___17;

struct its_vpe {
	struct page___21 *vpt_page;
	struct its_vm *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___17 *fwnode;
			struct irq_domain___2 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct vgic_v3_cpu_if {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe its_vpe;
	unsigned int used_lrs;
};

enum vgic_irq_config {
	VGIC_CONFIG_EDGE = 0,
	VGIC_CONFIG_LEVEL = 1,
};

struct irq_ops;

struct vgic_irq {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu *vcpu;
	struct kvm_vcpu *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

enum iodev_type {
	IODEV_CPUIF = 0,
	IODEV_DIST = 1,
	IODEV_REDIST = 2,
	IODEV_ITS = 3,
};

struct kvm_io_device {
	const struct kvm_io_device_ops *ops;
};

struct vgic_its;

struct vgic_register_region;

struct vgic_io_device {
	gpa_t base_addr;
	union {
		struct kvm_vcpu *redist_vcpu;
		struct vgic_its *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device dev;
};

struct vgic_redist_region;

struct vgic_cpu {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if vgic_v3;
	};
	struct vgic_irq private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct kvm_irq_level {
	union {
		__u32 irq;
		__s32 status;
	};
	__u32 level;
};

struct arch_timer_context {
	struct kvm_vcpu *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu {
	struct arch_timer_context timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct perf_event___11;

struct kvm_pmc {
	u8 idx;
	struct perf_event___11 *perf_event;
};

struct kvm_pmu {
	int irq_num;
	struct kvm_pmc pmc[32];
	long unsigned int chained[1];
	bool created;
	bool irq_level;
	struct irq_work overflow_work;
};

struct vcpu_reset_state {
	long unsigned int pc;
	long unsigned int r0;
	bool be;
	bool reset;
};

struct kvm_s2_mmu;

struct kvm_vcpu_arch {
	struct kvm_cpu_context ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu vgic_cpu;
	struct arch_timer_cpu timer_cpu;
	struct kvm_pmu pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm_vcpu_stat {
	struct kvm_vcpu_stat_generic generic;
	u64 hvc_exit_stat;
	u64 wfe_exit_stat;
	u64 wfi_exit_stat;
	u64 mmio_exit_user;
	u64 mmio_exit_kernel;
	u64 signal_exits;
	u64 exits;
};

struct kvm_dirty_gfn;

struct kvm_dirty_ring {
	u32 dirty_index;
	u32 reset_index;
	u32 size;
	u32 soft_limit;
	struct kvm_dirty_gfn *dirty_gfns;
	int index;
};

struct kvm;

struct kvm_run;

struct pid___19;

struct kvm_vcpu {
	struct kvm *kvm;
	struct preempt_notifier preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___20 wait;
	struct pid___19 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct dentry___21;

struct super_block___21;

struct module___22;

struct file_system_type___20 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___21 * (*mount)(struct file_system_type___20 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___21 *);
	struct module___22 *owner;
	struct file_system_type___20 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___21;

struct kiocb___20;

struct iov_iter___9;

struct poll_table_struct___14;

struct vm_area_struct___20;

struct inode___22;

struct file_lock___20;

struct seq_file___21;

struct file_operations___20 {
	struct module___22 *owner;
	loff_t (*llseek)(struct file___21 *, loff_t, int);
	ssize_t (*read)(struct file___21 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___21 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___20 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___20 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___20 *, bool);
	int (*iterate)(struct file___21 *, struct dir_context *);
	int (*iterate_shared)(struct file___21 *, struct dir_context *);
	__poll_t (*poll)(struct file___21 *, struct poll_table_struct___14 *);
	long int (*unlocked_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___21 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___21 *, struct vm_area_struct___20 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___22 *, struct file___21 *);
	int (*flush)(struct file___21 *, fl_owner_t);
	int (*release)(struct inode___22 *, struct file___21 *);
	int (*fsync)(struct file___21 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___21 *, int);
	int (*lock)(struct file___21 *, int, struct file_lock___20 *);
	ssize_t (*sendpage)(struct file___21 *, struct page___21 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___21 *, long unsigned int);
	int (*flock)(struct file___21 *, int, struct file_lock___20 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___21 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___21 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___21 *, long int, struct file_lock___20 **, void **);
	long int (*fallocate)(struct file___21 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___21 *, struct file___21 *);
	ssize_t (*copy_file_range)(struct file___21 *, loff_t, struct file___21 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___21 *, loff_t, struct file___21 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___21 *, loff_t, loff_t, int);
};

struct preempt_ops {
	void (*sched_in)(struct preempt_notifier *, int);
	void (*sched_out)(struct preempt_notifier *, struct task_struct___22 *);
};

struct vmacache___20 {
	u64 seqnum;
	struct vm_area_struct___20 *vmas[4];
};

struct page_frag___20 {
	struct page___21 *page;
	__u32 offset;
	__u32 size;
};

struct debug_info___11 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___11 *hbp_break[16];
	struct perf_event___11 *hbp_watch[16];
};

struct thread_struct___11 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___11 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___21;

struct nsproxy___20;

struct signal_struct___21;

struct bio_list___7;

struct backing_dev_info___6;

struct io_context___8;

struct css_set___13;

struct perf_event_context___11;

struct mem_cgroup___6;

struct request_queue___9;

struct vm_struct___20;

struct task_struct___22 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___22 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___21 *mm;
	struct mm_struct___21 *active_mm;
	struct vmacache___20 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___22 *real_parent;
	struct task_struct___22 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___22 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___19 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___20 *nsproxy;
	struct signal_struct___21 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___22 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___7 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___6 *backing_dev_info;
	struct io_context___8 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___13 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___11 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___20 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___6 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___6 *active_memcg;
	struct request_queue___9 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___22 *oom_reaper_list;
	struct vm_struct___20 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___11 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___20;

struct kobj_type___20;

struct kernfs_node___20;

struct kobject___20 {
	const char *name;
	struct list_head entry;
	struct kobject___20 *parent;
	struct kset___20 *kset;
	struct kobj_type___20 *ktype;
	struct kernfs_node___20 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___20 {
	struct kobject___20 kobj;
	struct module___22 *mod;
	struct kobject___20 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___20 {
	struct module___22 *mod;
	struct latch_tree_node node;
};

struct module_layout___20 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___20 mtn;
};

struct module_attribute___20;

struct kernel_param___20;

struct trace_event_call___8;

struct module___22 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___20 mkobj;
	struct module_attribute___20 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___20 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___20 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___20 core_layout;
	struct module_layout___20 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___8 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___11 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___22 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___11)(struct perf_event___11 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___11;

struct fasync_struct___20;

struct pid_namespace___19;

struct perf_cgroup___11;

struct perf_event___11 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___11 *group_leader;
	struct pmu___11 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___11 hw;
	struct perf_event_context___11 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___11 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___22 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___20 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___11 *aux_event;
	void (*destroy)(struct perf_event___11 *);
	struct callback_head callback_head;
	struct pid_namespace___19 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___11 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___11 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___8 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___11 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___19 {
	int nr;
	struct pid_namespace___19 *ns;
};

struct pid_namespace___19 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___22 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___19 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___19 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___19 numbers[1];
};

typedef struct page___21 *pgtable_t___20;

struct address_space___20;

struct dev_pagemap___20;

struct page___21 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___20 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___21 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___20 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___21 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___20 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___20;

struct vm_area_struct___20 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___20 *vm_next;
	struct vm_area_struct___20 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___21 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___20 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___21 *vm_file;
	struct file___21 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___21 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___22 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___22 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___19 *pids[4];
	struct pid___19 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___21 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___20;

struct mm_struct___21 {
	struct {
		struct vm_area_struct___20 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___21 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___20 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___22 *owner;
		struct user_namespace *user_ns;
		struct file___21 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___13;

struct nsproxy___20 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___19 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___13 *cgroup_ns;
};

struct bio___7;

struct bio_list___7 {
	struct bio___7 *head;
	struct bio___7 *tail;
};

struct cgroup_subsys_state___13;

struct bdi_writeback___6 {
	struct backing_dev_info___6 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___13 *memcg_css;
	struct cgroup_subsys_state___13 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___17;

struct backing_dev_info___6 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___6 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___17 *dev;
	char dev_name[64];
	struct device___17 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___21 *debug_dir;
};

struct io_cq___7;

struct io_context___8 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___7 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___13;

struct css_set___13 {
	struct cgroup_subsys_state___13 *subsys[14];
	refcount_t refcount;
	struct css_set___13 *dom_cset;
	struct cgroup___13 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___13 *mg_src_cgrp;
	struct cgroup___13 *mg_dst_cgrp;
	struct css_set___13 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___11 {
	struct pmu___11 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___22 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___11 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___13;

struct cgroup_subsys_state___13 {
	struct cgroup___13 *cgroup;
	struct cgroup_subsys___13 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___13 *parent;
};

struct cgroup_file___13 {
	struct kernfs_node___20 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___6;

struct mem_cgroup_per_node___6;

struct mem_cgroup___6 {
	struct cgroup_subsys_state___13 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___13 events_file;
	struct cgroup_file___13 events_local_file;
	struct cgroup_file___13 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___6 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___22 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___6 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___7;

struct blk_integrity___7 {
	const struct blk_integrity_profile___7 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___7 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___7 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___8;

struct elevator_queue___7;

struct blk_mq_ops___7;

struct blk_mq_hw_ctx___7;

struct gendisk___7;

struct blkcg_gq___7;

struct blk_mq_tag_set___7;

struct request_queue___9 {
	struct request___8 *last_merge;
	struct elevator_queue___7 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___7 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___7 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___7 *disk;
	struct kobject___20 kobj;
	struct kobject___20 *mq_kobj;
	struct blk_integrity___7 integrity;
	struct device___17 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___7 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___7 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___7 bio_split;
	struct dentry___21 *debugfs_dir;
	struct dentry___21 *sched_debugfs_dir;
	struct dentry___21 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___20 {
	struct vm_struct___20 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___21 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___20;

struct address_space___20 {
	struct inode___22 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___20 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___20;

struct dev_pagemap___20 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___20 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___20;

struct path___20 {
	struct vfsmount___20 *mnt;
	struct dentry___21 *dentry;
};

struct fown_struct___19 {
	rwlock_t lock;
	struct pid___19 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___21 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___20 f_path;
	struct inode___22 *f_inode;
	const struct file_operations___20 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___19 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___20 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___20;

struct vm_operations_struct___20 {
	void (*open)(struct vm_area_struct___20 *);
	void (*close)(struct vm_area_struct___20 *);
	int (*may_split)(struct vm_area_struct___20 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___20 *);
	int (*mprotect)(struct vm_area_struct___20 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___20 *);
	vm_fault_t (*huge_fault)(struct vm_fault___20 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___20 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___20 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___20 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___20 *);
	int (*access)(struct vm_area_struct___20 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___20 *);
	int (*set_policy)(struct vm_area_struct___20 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___20 *, long unsigned int);
	struct page___21 * (*find_special_page)(struct vm_area_struct___20 *, long unsigned int);
};

struct core_thread___20 {
	struct task_struct___22 *task;
	struct core_thread___20 *next;
};

struct core_state___20 {
	atomic_t nr_threads;
	struct core_thread___20 dumper;
	struct completion startup;
};

struct vm_fault___20 {
	const struct {
		struct vm_area_struct___20 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___21 *cow_page;
	struct page___21 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___20 prealloc_pte;
};

struct pglist_data___7;

struct lruvec___7 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___7 *pgdat;
};

struct zone___7 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___7 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___7 {
	struct zone___7 *zone;
	int zone_idx;
};

struct zonelist___7 {
	struct zoneref___7 _zonerefs[321];
};

struct pglist_data___7 {
	struct zone___7 node_zones[5];
	struct zonelist___7 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___22 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___22 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___7 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct fwnode_operations___17;

struct fwnode_handle___17 {
	struct fwnode_handle___17 *secondary;
	const struct fwnode_operations___17 *ops;
	struct device___17 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___17;

struct fwnode_endpoint___17;

struct fwnode_operations___17 {
	struct fwnode_handle___17 * (*get)(struct fwnode_handle___17 *);
	void (*put)(struct fwnode_handle___17 *);
	bool (*device_is_available)(const struct fwnode_handle___17 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___17 *, const struct device___17 *);
	bool (*property_present)(const struct fwnode_handle___17 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___17 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___17 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___17 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_parent)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_next_child_node)(const struct fwnode_handle___17 *, struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*get_named_child_node)(const struct fwnode_handle___17 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___17 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___17 *);
	struct fwnode_handle___17 * (*graph_get_next_endpoint)(const struct fwnode_handle___17 *, struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*graph_get_remote_endpoint)(const struct fwnode_handle___17 *);
	struct fwnode_handle___17 * (*graph_get_port_parent)(struct fwnode_handle___17 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___17 *, struct fwnode_endpoint___17 *);
	int (*add_links)(struct fwnode_handle___17 *);
};

struct wakeup_source___17;

struct dev_pm_info___17 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___17 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___17 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___17;

struct bus_type___17;

struct device_driver___17;

struct dev_pm_domain___17;

struct device_node___11;

struct class___17;

struct attribute_group___20;

struct device___17 {
	struct kobject___20 kobj;
	struct device___17 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___17 *type;
	struct bus_type___17 *bus;
	struct device_driver___17 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___17 power;
	struct dev_pm_domain___17 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___11 *of_node;
	struct fwnode_handle___17 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___17 *class;
	const struct attribute_group___20 **groups;
	void (*release)(struct device___17 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___17 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___17 *local_fwnode;
};

struct fwnode_reference_args___17 {
	struct fwnode_handle___17 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___19;

struct seq_file___21 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___19 *op;
	int poll_event;
	const struct file___21 *file;
	void *private;
};

struct kernfs_root___20;

struct kernfs_elem_dir___20 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___20 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___20;

struct kernfs_root___20 {
	struct kernfs_node___20 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___20 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___20 {
	struct kernfs_node___20 *target_kn;
};

struct kernfs_ops___20;

struct kernfs_elem_attr___20 {
	const struct kernfs_ops___20 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___20 *notify_next;
};

struct kernfs_node___20 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___20 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___20 dir;
		struct kernfs_elem_symlink___20 symlink;
		struct kernfs_elem_attr___20 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___20;

struct kernfs_ops___20 {
	int (*open)(struct kernfs_open_file___20 *);
	void (*release)(struct kernfs_open_file___20 *);
	int (*seq_show)(struct seq_file___21 *, void *);
	void * (*seq_start)(struct seq_file___21 *, loff_t *);
	void * (*seq_next)(struct seq_file___21 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___21 *, void *);
	ssize_t (*read)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___20 *, struct poll_table_struct___14 *);
	int (*mmap)(struct kernfs_open_file___20 *, struct vm_area_struct___20 *);
};

struct kernfs_syscall_ops___20 {
	int (*show_options)(struct seq_file___21 *, struct kernfs_root___20 *);
	int (*mkdir)(struct kernfs_node___20 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___20 *);
	int (*rename)(struct kernfs_node___20 *, struct kernfs_node___20 *, const char *);
	int (*show_path)(struct seq_file___21 *, struct kernfs_node___20 *, struct kernfs_root___20 *);
};

struct kernfs_open_file___20 {
	struct kernfs_node___20 *kn;
	struct file___21 *file;
	struct seq_file___21 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___20 *vm_ops;
};

typedef void (*poll_queue_proc___14)(struct file___21 *, wait_queue_head_t *, struct poll_table_struct___14 *);

struct poll_table_struct___14 {
	poll_queue_proc___14 _qproc;
	__poll_t _key;
};

struct bin_attribute___20;

struct attribute_group___20 {
	const char *name;
	umode_t (*is_visible)(struct kobject___20 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___20 *, struct bin_attribute___20 *, int);
	struct attribute **attrs;
	struct bin_attribute___20 **bin_attrs;
};

struct bin_attribute___20 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___20 * (*f_mapping)();
	ssize_t (*read)(struct file___21 *, struct kobject___20 *, struct bin_attribute___20 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___21 *, struct kobject___20 *, struct bin_attribute___20 *, char *, loff_t, size_t);
	int (*mmap)(struct file___21 *, struct kobject___20 *, struct bin_attribute___20 *, struct vm_area_struct___20 *);
};

struct sysfs_ops___20 {
	ssize_t (*show)(struct kobject___20 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___20 *, struct attribute *, const char *, size_t);
};

enum kobject_action {
	KOBJ_ADD = 0,
	KOBJ_REMOVE = 1,
	KOBJ_CHANGE = 2,
	KOBJ_MOVE = 3,
	KOBJ_ONLINE = 4,
	KOBJ_OFFLINE = 5,
	KOBJ_BIND = 6,
	KOBJ_UNBIND = 7,
};

struct kset_uevent_ops___20;

struct kset___20 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___20 kobj;
	const struct kset_uevent_ops___20 *uevent_ops;
};

struct kobj_type___20 {
	void (*release)(struct kobject___20 *);
	const struct sysfs_ops___20 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___20 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___20 *);
	const void * (*namespace)(struct kobject___20 *);
	void (*get_ownership)(struct kobject___20 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___20 {
	int (* const filter)(struct kset___20 *, struct kobject___20 *);
	const char * (* const name)(struct kset___20 *, struct kobject___20 *);
	int (* const uevent)(struct kset___20 *, struct kobject___20 *, struct kobj_uevent_env *);
};

struct trace_print_flags {
	long unsigned int mask;
	const char *name;
};

struct shrink_control___6 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___6 *memcg;
};

struct shrinker___6 {
	long unsigned int (*count_objects)(struct shrinker___6 *, struct shrink_control___6 *);
	long unsigned int (*scan_objects)(struct shrinker___6 *, struct shrink_control___6 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___20 {
	void (*page_free)(struct page___21 *);
	void (*kill)(struct dev_pagemap___20 *);
	void (*cleanup)(struct dev_pagemap___20 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___20 *);
};

struct dentry_operations___20;

struct dentry___21 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___21 *d_parent;
	struct qstr d_name;
	struct inode___22 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___20 *d_op;
	struct super_block___21 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___20;

struct inode___22 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___20 *i_op;
	struct super_block___21 *i_sb;
	struct address_space___20 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___6 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___20 *i_fop;
		void (*free_inode)(struct inode___22 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___20 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___20 {
	int (*d_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___21 *, unsigned int);
	int (*d_hash)(const struct dentry___21 *, struct qstr *);
	int (*d_compare)(const struct dentry___21 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___21 *);
	int (*d_init)(struct dentry___21 *);
	void (*d_release)(struct dentry___21 *);
	void (*d_prune)(struct dentry___21 *);
	void (*d_iput)(struct dentry___21 *, struct inode___22 *);
	char * (*d_dname)(struct dentry___21 *, char *, int);
	struct vfsmount___20 * (*d_automount)(struct path___20 *);
	int (*d_manage)(const struct path___20 *, bool);
	struct dentry___21 * (*d_real)(struct dentry___21 *, const struct inode___22 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___20;

struct mem_dqinfo___20 {
	struct quota_format_type___20 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___20;

struct quota_info___20 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___22 *files[3];
	struct mem_dqinfo___20 info[3];
	const struct quota_format_ops___20 *ops[3];
};

struct percpu_rw_semaphore___20 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___20 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___20 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___20 rw_sem[3];
};

struct super_operations___20;

struct dquot_operations___20;

struct quotactl_ops___20;

struct block_device___8;

struct super_block___21 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___20 *s_type;
	const struct super_operations___20 *s_op;
	const struct dquot_operations___20 *dq_op;
	const struct quotactl_ops___20 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___21 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___8 *s_bdev;
	struct backing_dev_info___6 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___20 s_dquot;
	struct sb_writers___20 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___20 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___20 {
	struct dentry___21 *mnt_root;
	struct super_block___21 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct psi_group___13 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___22 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___13;

struct cgroup_rstat_cpu___13;

struct cgroup___13 {
	struct cgroup_subsys_state___13 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___20 *kn;
	struct cgroup_file___13 procs_file;
	struct cgroup_file___13 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___13 *subsys[14];
	struct cgroup_root___13 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___13 *dom_cgrp;
	struct cgroup___13 *old_dom_cgrp;
	struct cgroup_rstat_cpu___13 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___13 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___7 {
	struct request_queue___9 *q;
	struct io_context___8 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___7;

struct kiocb___20 {
	struct file___21 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___20 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___7 *ki_waitq;
	};
};

struct iattr___21 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___21 *ia_file;
};

struct dquot___20 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___21 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___20 {
	int qf_fmt_id;
	const struct quota_format_ops___20 *qf_ops;
	struct module___22 *qf_owner;
	struct quota_format_type___20 *qf_next;
};

struct quota_format_ops___20 {
	int (*check_quota_file)(struct super_block___21 *, int);
	int (*read_file_info)(struct super_block___21 *, int);
	int (*write_file_info)(struct super_block___21 *, int);
	int (*free_file_info)(struct super_block___21 *, int);
	int (*read_dqblk)(struct dquot___20 *);
	int (*commit_dqblk)(struct dquot___20 *);
	int (*release_dqblk)(struct dquot___20 *);
	int (*get_next_id)(struct super_block___21 *, struct kqid *);
};

struct dquot_operations___20 {
	int (*write_dquot)(struct dquot___20 *);
	struct dquot___20 * (*alloc_dquot)(struct super_block___21 *, int);
	void (*destroy_dquot)(struct dquot___20 *);
	int (*acquire_dquot)(struct dquot___20 *);
	int (*release_dquot)(struct dquot___20 *);
	int (*mark_dirty)(struct dquot___20 *);
	int (*write_info)(struct super_block___21 *, int);
	qsize_t * (*get_reserved_space)(struct inode___22 *);
	int (*get_projid)(struct inode___22 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___22 *, qsize_t *);
	int (*get_next_id)(struct super_block___21 *, struct kqid *);
};

struct quotactl_ops___20 {
	int (*quota_on)(struct super_block___21 *, int, int, const struct path___20 *);
	int (*quota_off)(struct super_block___21 *, int);
	int (*quota_enable)(struct super_block___21 *, unsigned int);
	int (*quota_disable)(struct super_block___21 *, unsigned int);
	int (*quota_sync)(struct super_block___21 *, int);
	int (*set_info)(struct super_block___21 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___21 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___21 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___21 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___21 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___21 *, unsigned int);
};

struct wait_page_queue___7 {
	struct page___21 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___6;

struct readahead_control___7;

struct swap_info_struct___5;

struct address_space_operations___20 {
	int (*writepage)(struct page___21 *, struct writeback_control___6 *);
	int (*readpage)(struct file___21 *, struct page___21 *);
	int (*writepages)(struct address_space___20 *, struct writeback_control___6 *);
	int (*set_page_dirty)(struct page___21 *);
	int (*readpages)(struct file___21 *, struct address_space___20 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___7 *);
	int (*write_begin)(struct file___21 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___21 **, void **);
	int (*write_end)(struct file___21 *, struct address_space___20 *, loff_t, unsigned int, unsigned int, struct page___21 *, void *);
	sector_t (*bmap)(struct address_space___20 *, sector_t);
	void (*invalidatepage)(struct page___21 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___21 *, gfp_t);
	void (*freepage)(struct page___21 *);
	ssize_t (*direct_IO)(struct kiocb___20 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___20 *, struct page___21 *, struct page___21 *, enum migrate_mode);
	bool (*isolate_page)(struct page___21 *, isolate_mode_t);
	void (*putback_page)(struct page___21 *);
	int (*launder_page)(struct page___21 *);
	int (*is_partially_uptodate)(struct page___21 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___21 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___20 *, struct page___21 *);
	int (*swap_activate)(struct swap_info_struct___5 *, struct file___21 *, sector_t *);
	void (*swap_deactivate)(struct file___21 *);
};

struct writeback_control___6 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___6 *wb;
	struct inode___22 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___7 {
	struct file___21 *file;
	struct address_space___20 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___9;

struct iov_iter___9 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___9 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___5 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___8 *bdev;
	struct file___21 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___20 {
	struct dentry___21 * (*lookup)(struct inode___22 *, struct dentry___21 *, unsigned int);
	const char * (*get_link)(struct dentry___21 *, struct inode___22 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___22 *, int);
	struct posix_acl * (*get_acl)(struct inode___22 *, int, bool);
	int (*readlink)(struct dentry___21 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___22 *, struct dentry___21 *, umode_t, bool);
	int (*link)(struct dentry___21 *, struct inode___22 *, struct dentry___21 *);
	int (*unlink)(struct inode___22 *, struct dentry___21 *);
	int (*symlink)(struct user_namespace *, struct inode___22 *, struct dentry___21 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___22 *, struct dentry___21 *, umode_t);
	int (*rmdir)(struct inode___22 *, struct dentry___21 *);
	int (*mknod)(struct user_namespace *, struct inode___22 *, struct dentry___21 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___22 *, struct dentry___21 *, struct inode___22 *, struct dentry___21 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___21 *, struct iattr___21 *);
	int (*getattr)(struct user_namespace *, const struct path___20 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___21 *, char *, size_t);
	int (*fiemap)(struct inode___22 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___22 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___22 *, struct dentry___21 *, struct file___21 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___22 *, struct dentry___21 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___22 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___21 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___21 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___20 {
	void (*fl_copy_lock)(struct file_lock___20 *, struct file_lock___20 *);
	void (*fl_release_private)(struct file_lock___20 *);
};

struct lock_manager_operations___20;

struct file_lock___20 {
	struct file_lock___20 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___21 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___20 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___20 *fl_ops;
	const struct lock_manager_operations___20 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___20 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___20 *);
	int (*lm_grant)(struct file_lock___20 *, int);
	bool (*lm_break)(struct file_lock___20 *);
	int (*lm_change)(struct file_lock___20 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___20 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___20 *);
};

struct fasync_struct___20 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___20 *fa_next;
	struct file___21 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___20 {
	struct inode___22 * (*alloc_inode)(struct super_block___21 *);
	void (*destroy_inode)(struct inode___22 *);
	void (*free_inode)(struct inode___22 *);
	void (*dirty_inode)(struct inode___22 *, int);
	int (*write_inode)(struct inode___22 *, struct writeback_control___6 *);
	int (*drop_inode)(struct inode___22 *);
	void (*evict_inode)(struct inode___22 *);
	void (*put_super)(struct super_block___21 *);
	int (*sync_fs)(struct super_block___21 *, int);
	int (*freeze_super)(struct super_block___21 *);
	int (*freeze_fs)(struct super_block___21 *);
	int (*thaw_super)(struct super_block___21 *);
	int (*unfreeze_fs)(struct super_block___21 *);
	int (*statfs)(struct dentry___21 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___21 *, int *, char *);
	void (*umount_begin)(struct super_block___21 *);
	int (*show_options)(struct seq_file___21 *, struct dentry___21 *);
	int (*show_devname)(struct seq_file___21 *, struct dentry___21 *);
	int (*show_path)(struct seq_file___21 *, struct dentry___21 *);
	int (*show_stats)(struct seq_file___21 *, struct dentry___21 *);
	ssize_t (*quota_read)(struct super_block___21 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___21 *, int, const char *, size_t, loff_t);
	struct dquot___20 ** (*get_dquots)(struct inode___22 *);
	long int (*nr_cached_objects)(struct super_block___21 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___21 *, struct shrink_control___6 *);
	struct file___21 * (*real_loop)(struct file___21 *);
};

struct block_device___8 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___22 *bd_inode;
	struct super_block___21 *bd_super;
	void *bd_claiming;
	struct device___17 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___20 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___7 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___21 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___7(struct bio___7 *);

struct bio_vec___9 {
	struct page___21 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___7;

struct bio___7 {
	struct bio___7 *bi_next;
	struct block_device___8 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___7 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___7 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___7 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___9 *bi_io_vec;
	struct bio_set___7 *bi_pool;
	struct bio_vec___9 bi_inline_vecs[0];
};

enum mmu_notifier_event {
	MMU_NOTIFY_UNMAP = 0,
	MMU_NOTIFY_CLEAR = 1,
	MMU_NOTIFY_PROTECTION_VMA = 2,
	MMU_NOTIFY_PROTECTION_PAGE = 3,
	MMU_NOTIFY_SOFT_DIRTY = 4,
	MMU_NOTIFY_RELEASE = 5,
	MMU_NOTIFY_MIGRATE = 6,
	MMU_NOTIFY_EXCLUSIVE = 7,
};

struct mmu_notifier;

struct mmu_notifier_range;

struct mmu_notifier_ops {
	void (*release)(struct mmu_notifier *, struct mm_struct___21 *);
	int (*clear_flush_young)(struct mmu_notifier *, struct mm_struct___21 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier *, struct mm_struct___21 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier *, struct mm_struct___21 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier *, struct mm_struct___21 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier *, const struct mmu_notifier_range *);
	void (*invalidate_range_end)(struct mmu_notifier *, const struct mmu_notifier_range *);
	void (*invalidate_range)(struct mmu_notifier *, struct mm_struct___21 *, long unsigned int, long unsigned int);
	struct mmu_notifier * (*alloc_notifier)(struct mm_struct___21 *);
	void (*free_notifier)(struct mmu_notifier *);
};

struct mmu_notifier {
	struct hlist_node hlist;
	const struct mmu_notifier_ops *ops;
	struct mm_struct___21 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range {
	struct vm_area_struct___20 *vma;
	struct mm_struct___21 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct kernel_param_ops___20 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___20 *);
	int (*get)(char *, const struct kernel_param___20 *);
	void (*free)(void *);
};

struct kparam_array___20;

struct kernel_param___20 {
	const char *name;
	struct module___22 *mod;
	const struct kernel_param_ops___20 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___20 *arr;
	};
};

struct kparam_array___20 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___20 *ops;
	void *elem;
};

struct module_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___20 *, struct module_kobject___20 *, char *);
	ssize_t (*store)(struct module_attribute___20 *, struct module_kobject___20 *, const char *, size_t);
	void (*setup)(struct module___22 *, const char *);
	int (*test)(struct module___22 *);
	void (*free)(struct module___22 *);
};

struct trace_event_class___8;

struct trace_event_call___8 {
	struct list_head list;
	struct trace_event_class___8 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___8 *, struct perf_event___11 *);
};

struct cgroup_namespace___13 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___13 *root_cset;
};

struct kvm_regs {
	struct user_pt_regs regs;
	__u64 sp_el1;
	__u64 elr_el1;
	__u64 spsr[5];
	long: 64;
	struct user_fpsimd_state fp_regs;
};

struct kvm_sregs {};

struct kvm_fpu {};

struct kvm_debug_exit_arch {
	__u32 hsr;
	__u64 far;
};

struct kvm_sync_regs {
	__u64 device_irq_level;
};

struct kvm_userspace_memory_region {
	__u32 slot;
	__u32 flags;
	__u64 guest_phys_addr;
	__u64 memory_size;
	__u64 userspace_addr;
};

struct kvm_hyperv_exit {
	__u32 type;
	__u32 pad1;
	union {
		struct {
			__u32 msr;
			__u32 pad2;
			__u64 control;
			__u64 evt_page;
			__u64 msg_page;
		} synic;
		struct {
			__u64 input;
			__u64 result;
			__u64 params[2];
		} hcall;
		struct {
			__u32 msr;
			__u32 pad2;
			__u64 control;
			__u64 status;
			__u64 send_page;
			__u64 recv_page;
			__u64 pending_page;
		} syndbg;
	} u;
};

struct kvm_xen_exit {
	__u32 type;
	union {
		struct {
			__u32 longmode;
			__u32 cpl;
			__u64 input;
			__u64 result;
			__u64 params[6];
		} hcall;
	} u;
};

struct kvm_run {
	__u8 request_interrupt_window;
	__u8 immediate_exit;
	__u8 padding1[6];
	__u32 exit_reason;
	__u8 ready_for_interrupt_injection;
	__u8 if_flag;
	__u16 flags;
	__u64 cr8;
	__u64 apic_base;
	union {
		struct {
			__u64 hardware_exit_reason;
		} hw;
		struct {
			__u64 hardware_entry_failure_reason;
			__u32 cpu;
		} fail_entry;
		struct {
			__u32 exception;
			__u32 error_code;
		} ex;
		struct {
			__u8 direction;
			__u8 size;
			__u16 port;
			__u32 count;
			__u64 data_offset;
		} io;
		struct {
			struct kvm_debug_exit_arch arch;
		} debug;
		struct {
			__u64 phys_addr;
			__u8 data[8];
			__u32 len;
			__u8 is_write;
		} mmio;
		struct {
			__u64 nr;
			__u64 args[6];
			__u64 ret;
			__u32 longmode;
			__u32 pad;
		} hypercall;
		struct {
			__u64 rip;
			__u32 is_write;
			__u32 pad;
		} tpr_access;
		struct {
			__u8 icptcode;
			__u16 ipa;
			__u32 ipb;
		} s390_sieic;
		__u64 s390_reset_flags;
		struct {
			__u64 trans_exc_code;
			__u32 pgm_code;
		} s390_ucontrol;
		struct {
			__u32 dcrn;
			__u32 data;
			__u8 is_write;
		} dcr;
		struct {
			__u32 suberror;
			__u32 ndata;
			__u64 data[16];
		} internal;
		struct {
			__u32 suberror;
			__u32 ndata;
			__u64 flags;
			__u8 insn_size;
			__u8 insn_bytes[15];
		} emulation_failure;
		struct {
			__u64 gprs[32];
		} osi;
		struct {
			__u64 nr;
			__u64 ret;
			__u64 args[9];
		} papr_hcall;
		struct {
			__u16 subchannel_id;
			__u16 subchannel_nr;
			__u32 io_int_parm;
			__u32 io_int_word;
			__u32 ipb;
			__u8 dequeued;
		} s390_tsch;
		struct {
			__u32 epr;
		} epr;
		struct {
			__u32 type;
			__u64 flags;
		} system_event;
		struct {
			__u64 addr;
			__u8 ar;
			__u8 reserved;
			__u8 fc;
			__u8 sel1;
			__u16 sel2;
		} s390_stsi;
		struct {
			__u8 vector;
		} eoi;
		struct kvm_hyperv_exit hyperv;
		struct {
			__u64 esr_iss;
			__u64 fault_ipa;
		} arm_nisv;
		struct {
			__u8 error;
			__u8 pad[7];
			__u32 reason;
			__u32 index;
			__u64 data;
		} msr;
		struct kvm_xen_exit xen;
		char padding[256];
	};
	__u64 kvm_valid_regs;
	__u64 kvm_dirty_regs;
	union {
		struct kvm_sync_regs regs;
		char padding[2048];
	} s;
};

struct kvm_coalesced_mmio_zone {
	__u64 addr;
	__u32 size;
	union {
		__u32 pad;
		__u32 pio;
	};
};

struct kvm_coalesced_mmio {
	__u64 phys_addr;
	__u32 len;
	union {
		__u32 pad;
		__u32 pio;
	};
	__u8 data[8];
};

struct kvm_coalesced_mmio_ring {
	__u32 first;
	__u32 last;
	struct kvm_coalesced_mmio coalesced_mmio[0];
};

struct kvm_translation {
	__u64 linear_address;
	__u64 physical_address;
	__u8 valid;
	__u8 writeable;
	__u8 usermode;
	__u8 pad[5];
};

struct kvm_dirty_log {
	__u32 slot;
	__u32 padding1;
	union {
		void *dirty_bitmap;
		__u64 padding2;
	};
};

struct kvm_clear_dirty_log {
	__u32 slot;
	__u32 num_pages;
	__u64 first_page;
	union {
		void *dirty_bitmap;
		__u64 padding2;
	};
};

struct kvm_signal_mask {
	__u32 len;
	__u8 sigset[0];
};

struct kvm_mp_state {
	__u32 mp_state;
};

struct kvm_guest_debug {
	__u32 control;
	__u32 pad;
	struct kvm_guest_debug_arch arch;
};

struct kvm_ioeventfd {
	__u64 datamatch;
	__u64 addr;
	__u32 len;
	__s32 fd;
	__u32 flags;
	__u8 pad[36];
};

struct kvm_enable_cap {
	__u32 cap;
	__u32 flags;
	__u64 args[4];
	__u8 pad[64];
};

struct kvm_irq_routing_irqchip {
	__u32 irqchip;
	__u32 pin;
};

struct kvm_irq_routing_msi {
	__u32 address_lo;
	__u32 address_hi;
	__u32 data;
	union {
		__u32 pad;
		__u32 devid;
	};
};

struct kvm_irq_routing_s390_adapter {
	__u64 ind_addr;
	__u64 summary_addr;
	__u64 ind_offset;
	__u32 summary_offset;
	__u32 adapter_id;
};

struct kvm_irq_routing_hv_sint {
	__u32 vcpu;
	__u32 sint;
};

struct kvm_irq_routing_entry {
	__u32 gsi;
	__u32 type;
	__u32 flags;
	__u32 pad;
	union {
		struct kvm_irq_routing_irqchip irqchip;
		struct kvm_irq_routing_msi msi;
		struct kvm_irq_routing_s390_adapter adapter;
		struct kvm_irq_routing_hv_sint hv_sint;
		__u32 pad[8];
	} u;
};

struct kvm_irq_routing {
	__u32 nr;
	__u32 flags;
	struct kvm_irq_routing_entry entries[0];
};

struct kvm_irqfd {
	__u32 fd;
	__u32 gsi;
	__u32 flags;
	__u32 resamplefd;
	__u8 pad[16];
};

struct kvm_msi {
	__u32 address_lo;
	__u32 address_hi;
	__u32 data;
	__u32 flags;
	__u32 devid;
	__u8 pad[12];
};

struct kvm_create_device {
	__u32 type;
	__u32 fd;
	__u32 flags;
};

struct kvm_device_attr {
	__u32 flags;
	__u32 group;
	__u64 attr;
	__u64 addr;
};

enum kvm_device_type {
	KVM_DEV_TYPE_FSL_MPIC_20 = 1,
	KVM_DEV_TYPE_FSL_MPIC_42 = 2,
	KVM_DEV_TYPE_XICS = 3,
	KVM_DEV_TYPE_VFIO = 4,
	KVM_DEV_TYPE_ARM_VGIC_V2 = 5,
	KVM_DEV_TYPE_FLIC = 6,
	KVM_DEV_TYPE_ARM_VGIC_V3 = 7,
	KVM_DEV_TYPE_ARM_VGIC_ITS = 8,
	KVM_DEV_TYPE_XIVE = 9,
	KVM_DEV_TYPE_ARM_PV_TIME = 10,
	KVM_DEV_TYPE_MAX = 11,
};

struct kvm_dirty_gfn {
	__u32 flags;
	__u32 slot;
	__u64 offset;
};

struct kvm_stats_header {
	__u32 flags;
	__u32 name_size;
	__u32 num_desc;
	__u32 id_offset;
	__u32 desc_offset;
	__u32 data_offset;
};

struct kvm_stats_desc {
	__u32 flags;
	__s16 exponent;
	__u16 size;
	__u32 offset;
	__u32 bucket_size;
	char name[0];
};

struct its_vm {
	struct fwnode_handle___17 *fwnode;
	struct irq_domain___2 *domain;
	struct page___21 *vprop_page;
	struct its_vpe **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct irq_ops {
	long unsigned int flags;
	bool (*get_input_level)(int);
};

struct kvm_device;

struct vgic_its {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device iodev;
	struct kvm_device *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_vcpu___2;

struct kvm___2;

struct vgic_its___2;

struct vgic_register_region {
	unsigned int reg_offset;
	unsigned int len;
	unsigned int bits_per_irq;
	unsigned int access_flags;
	union {
		long unsigned int (*read)(struct kvm_vcpu___2 *, gpa_t, unsigned int);
		long unsigned int (*its_read)(struct kvm___2 *, struct vgic_its___2 *, gpa_t, unsigned int);
	};
	union {
		void (*write)(struct kvm_vcpu___2 *, gpa_t, unsigned int, long unsigned int);
		void (*its_write)(struct kvm___2 *, struct vgic_its___2 *, gpa_t, unsigned int, long unsigned int);
	};
	long unsigned int (*uaccess_read)(struct kvm_vcpu___2 *, gpa_t, unsigned int);
	union {
		int (*uaccess_write)(struct kvm_vcpu___2 *, gpa_t, unsigned int, long unsigned int);
		int (*uaccess_its_write)(struct kvm___2 *, struct vgic_its___2 *, gpa_t, unsigned int, long unsigned int);
	};
};

struct kvm_device_ops;

struct kvm_device {
	const struct kvm_device_ops *ops;
	struct kvm *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_redist_region {
	u32 index;
	gpa_t base;
	u32 count;
	u32 free_index;
	struct list_head list;
};

struct vgic_state_iter;

struct vgic_dist {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq *spis;
	struct vgic_io_device dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm its_vm;
};

struct property___9 {
	char *name;
	int length;
	void *value;
	struct property___9 *next;
	long unsigned int _flags;
	struct bin_attribute___20 attr;
};

struct device_node___11 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___17 fwnode;
	struct property___9 *properties;
	struct property___9 *deadprops;
	struct device_node___11 *parent;
	struct device_node___11 *child;
	struct device_node___11 *sibling;
	struct kobject___20 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___17 {
	int (*prepare)(struct device___17 *);
	void (*complete)(struct device___17 *);
	int (*suspend)(struct device___17 *);
	int (*resume)(struct device___17 *);
	int (*freeze)(struct device___17 *);
	int (*thaw)(struct device___17 *);
	int (*poweroff)(struct device___17 *);
	int (*restore)(struct device___17 *);
	int (*suspend_late)(struct device___17 *);
	int (*resume_early)(struct device___17 *);
	int (*freeze_late)(struct device___17 *);
	int (*thaw_early)(struct device___17 *);
	int (*poweroff_late)(struct device___17 *);
	int (*restore_early)(struct device___17 *);
	int (*suspend_noirq)(struct device___17 *);
	int (*resume_noirq)(struct device___17 *);
	int (*freeze_noirq)(struct device___17 *);
	int (*thaw_noirq)(struct device___17 *);
	int (*poweroff_noirq)(struct device___17 *);
	int (*restore_noirq)(struct device___17 *);
	int (*runtime_suspend)(struct device___17 *);
	int (*runtime_resume)(struct device___17 *);
	int (*runtime_idle)(struct device___17 *);
};

struct wakeup_source___17 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___17 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___17 {
	struct dev_pm_ops___17 ops;
	int (*start)(struct device___17 *);
	void (*detach)(struct device___17 *, bool);
	int (*activate)(struct device___17 *);
	void (*sync)(struct device___17 *);
	void (*dismiss)(struct device___17 *);
};

struct bus_type___17 {
	const char *name;
	const char *dev_name;
	struct device___17 *dev_root;
	const struct attribute_group___20 **bus_groups;
	const struct attribute_group___20 **dev_groups;
	const struct attribute_group___20 **drv_groups;
	int (*match)(struct device___17 *, struct device_driver___17 *);
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	int (*probe)(struct device___17 *);
	void (*sync_state)(struct device___17 *);
	void (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*online)(struct device___17 *);
	int (*offline)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	int (*num_vf)(struct device___17 *);
	int (*dma_configure)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___17 {
	const char *name;
	struct bus_type___17 *bus;
	struct module___22 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___17 *);
	void (*sync_state)(struct device___17 *);
	int (*remove)(struct device___17 *);
	void (*shutdown)(struct device___17 *);
	int (*suspend)(struct device___17 *, pm_message_t);
	int (*resume)(struct device___17 *);
	const struct attribute_group___20 **groups;
	const struct attribute_group___20 **dev_groups;
	const struct dev_pm_ops___17 *pm;
	void (*coredump)(struct device___17 *);
	struct driver_private *p;
};

struct device_type___17 {
	const char *name;
	const struct attribute_group___20 **groups;
	int (*uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___17 *);
	const struct dev_pm_ops___17 *pm;
};

struct class___17 {
	const char *name;
	struct module___22 *owner;
	const struct attribute_group___20 **class_groups;
	const struct attribute_group___20 **dev_groups;
	struct kobject___20 *dev_kobj;
	int (*dev_uevent)(struct device___17 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___17 *, umode_t *);
	void (*class_release)(struct class___17 *);
	void (*dev_release)(struct device___17 *);
	int (*shutdown_pre)(struct device___17 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___17 *);
	void (*get_ownership)(struct device___17 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___17 *pm;
	struct subsys_private *p;
};

struct seq_operations___19 {
	void * (*start)(struct seq_file___21 *, loff_t *);
	void (*stop)(struct seq_file___21 *, void *);
	void * (*next)(struct seq_file___21 *, void *, loff_t *);
	int (*show)(struct seq_file___21 *, void *);
};

struct cftype___13;

struct cgroup_subsys___13 {
	struct cgroup_subsys_state___13 * (*css_alloc)(struct cgroup_subsys_state___13 *);
	int (*css_online)(struct cgroup_subsys_state___13 *);
	void (*css_offline)(struct cgroup_subsys_state___13 *);
	void (*css_released)(struct cgroup_subsys_state___13 *);
	void (*css_free)(struct cgroup_subsys_state___13 *);
	void (*css_reset)(struct cgroup_subsys_state___13 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___13 *, int);
	int (*css_extra_stat_show)(struct seq_file___21 *, struct cgroup_subsys_state___13 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___22 *, struct css_set___13 *);
	void (*cancel_fork)(struct task_struct___22 *, struct css_set___13 *);
	void (*fork)(struct task_struct___22 *);
	void (*exit)(struct task_struct___22 *);
	void (*release)(struct task_struct___22 *);
	void (*bind)(struct cgroup_subsys_state___13 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___13 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___13 *dfl_cftypes;
	struct cftype___13 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___13 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___13 *updated_children;
	struct cgroup___13 *updated_next;
};

struct cgroup_root___13 {
	struct kernfs_root___20 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___13 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___13 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___13 *ss;
	struct list_head node;
	struct kernfs_ops___20 *kf_ops;
	int (*open)(struct kernfs_open_file___20 *);
	void (*release)(struct kernfs_open_file___20 *);
	u64 (*read_u64)(struct cgroup_subsys_state___13 *, struct cftype___13 *);
	s64 (*read_s64)(struct cgroup_subsys_state___13 *, struct cftype___13 *);
	int (*seq_show)(struct seq_file___21 *, void *);
	void * (*seq_start)(struct seq_file___21 *, loff_t *);
	void * (*seq_next)(struct seq_file___21 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___21 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___13 *, struct cftype___13 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___13 *, struct cftype___13 *, s64);
	ssize_t (*write)(struct kernfs_open_file___20 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___20 *, struct poll_table_struct___14 *);
};

struct perf_cpu_context___11;

struct perf_output_handle___11;

struct pmu___11 {
	struct list_head entry;
	struct module___22 *module;
	struct device___17 *dev;
	const struct attribute_group___20 **attr_groups;
	const struct attribute_group___20 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___11 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___11 *);
	void (*pmu_disable)(struct pmu___11 *);
	int (*event_init)(struct perf_event___11 *);
	void (*event_mapped)(struct perf_event___11 *, struct mm_struct___21 *);
	void (*event_unmapped)(struct perf_event___11 *, struct mm_struct___21 *);
	int (*add)(struct perf_event___11 *, int);
	void (*del)(struct perf_event___11 *, int);
	void (*start)(struct perf_event___11 *, int);
	void (*stop)(struct perf_event___11 *, int);
	void (*read)(struct perf_event___11 *);
	void (*start_txn)(struct pmu___11 *, unsigned int);
	int (*commit_txn)(struct pmu___11 *);
	void (*cancel_txn)(struct pmu___11 *);
	int (*event_idx)(struct perf_event___11 *);
	void (*sched_task)(struct perf_event_context___11 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___11 *, struct perf_event_context___11 *);
	void * (*setup_aux)(struct perf_event___11 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___11 *, struct perf_output_handle___11 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___11 *);
	int (*aux_output_match)(struct perf_event___11 *);
	int (*filter_match)(struct perf_event___11 *);
	int (*check_period)(struct perf_event___11 *, u64);
};

struct perf_cpu_context___11 {
	struct perf_event_context___11 ctx;
	struct perf_event_context___11 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___11 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___11 **heap;
	struct perf_event___11 *heap_default[2];
};

struct perf_output_handle___11 {
	struct perf_event___11 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___11 {
	struct cgroup_subsys_state___13 css;
	struct perf_cgroup_info *info;
};

struct kvm_vmid {
	u64 vmid_gen;
	u32 vmid;
};

struct kvm_pgtable;

struct kvm_arch;

struct kvm_s2_mmu {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable *pgt;
	int *last_vcpu_ran;
	struct kvm_arch *arch;
};

struct kvm_arch {
	struct kvm_s2_mmu mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_vm_stat {
	struct kvm_vm_stat_generic generic;
};

struct kvm_io_range {
	gpa_t addr;
	int len;
	struct kvm_io_device *dev;
};

struct kvm_io_bus {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range range[0];
};

struct kvm_gfn_range {
	struct kvm_memory_slot *slot;
	gfn_t start;
	gfn_t end;
	pte_t pte;
	bool may_block;
};

enum {
	OUTSIDE_GUEST_MODE = 0,
	IN_GUEST_MODE = 1,
	EXITING_GUEST_MODE = 2,
	READING_SHADOW_PAGE_TABLES = 3,
};

struct kvm_host_map {
	struct page___21 *page;
	void *hva;
	kvm_pfn_t pfn;
	kvm_pfn_t gfn;
};

struct kvm_memslots;

struct kvm_irq_routing_table;

struct kvm_stat_data;

struct kvm {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___21 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___20 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___21 *debugfs_dentry;
	struct kvm_stat_data **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_irq_routing_table {
	int chip[988];
	u32 nr_rt_entries;
	struct hlist_head map[0];
};

struct kvm_memslots {
	u64 generation;
	short int id_to_index[32767];
	atomic_t last_used_slot;
	int used_slots;
	struct kvm_memory_slot memslots[0];
};

enum kvm_stat_kind {
	KVM_STAT_VM = 0,
	KVM_STAT_VCPU = 1,
};

struct _kvm_stats_desc;

struct kvm_stat_data {
	struct kvm *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

enum kvm_mr_change {
	KVM_MR_CREATE = 0,
	KVM_MR_DELETE = 1,
	KVM_MR_MOVE = 2,
	KVM_MR_FLAGS_ONLY = 3,
};

struct _kvm_stats_desc {
	struct kvm_stats_desc desc;
	char name[48];
};

struct kvm_device_ops {
	const char *name;
	int (*create)(struct kvm_device *, u32);
	void (*init)(struct kvm_device *);
	void (*destroy)(struct kvm_device *);
	void (*release)(struct kvm_device *);
	int (*set_attr)(struct kvm_device *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device *, struct vm_area_struct___20 *);
};

typedef int (*kvm_vm_thread_fn_t)(struct kvm *, uintptr_t);

struct miscdevice {
	int minor;
	const char *name;
	const struct file_operations___20 *fops;
	struct list_head list;
	struct device___17 *parent;
	struct device___17 *this_device;
	const struct attribute_group___20 **groups;
	const char *nodename;
	umode_t mode;
};

struct syscore_ops {
	struct list_head node;
	int (*suspend)();
	void (*resume)();
	void (*shutdown)();
};

struct block_device_operations___7;

struct gendisk___7 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___8 *part0;
	const struct block_device_operations___7 *fops;
	struct request_queue___9 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___6 *bdi;
	struct kobject___20 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___20 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___7 {
	struct bio___7 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___9 *bip_vec;
	struct bio_vec___9 bip_inline_vecs[0];
};

struct blkcg___6;

struct blkg_policy_data___6;

struct blkcg_gq___7 {
	struct request_queue___9 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___6 *blkcg;
	struct blkcg_gq___7 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___6 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___7 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___7(struct request___8 *);

typedef void integrity_complete_fn___7(struct request___8 *, unsigned int);

struct blk_integrity_profile___7 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___7 *prepare_fn;
	integrity_complete_fn___7 *complete_fn;
	const char *name;
};

struct block_device_operations___7 {
	blk_qc_t (*submit_bio)(struct bio___7 *);
	int (*open)(struct block_device___8 *, fmode_t);
	void (*release)(struct gendisk___7 *, fmode_t);
	int (*rw_page)(struct block_device___8 *, sector_t, struct page___21 *, unsigned int);
	int (*ioctl)(struct block_device___8 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___8 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___7 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___7 *);
	int (*getgeo)(struct block_device___8 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___8 *, bool);
	void (*swap_slot_free_notify)(struct block_device___8 *, long unsigned int);
	int (*report_zones)(struct gendisk___7 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___7 *, umode_t *);
	struct module___22 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___7 *, sector_t *);
};

typedef void rq_end_io_fn___7(struct request___8 *, blk_status_t);

struct request___8 {
	struct request_queue___9 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___7 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___7 *bio;
	struct bio___7 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___9 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___7 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___7 *saved_end_io;
		} flush;
	};
	struct gendisk___7 *rq_disk;
	struct block_device___8 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___7 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___7 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___9 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___20 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___21 *debugfs_dir;
	struct dentry___21 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___7;

struct elevator_mq_ops___7 {
	int (*init_sched)(struct request_queue___9 *, struct elevator_type___7 *);
	void (*exit_sched)(struct elevator_queue___7 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___7 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___7 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___7 *);
	bool (*allow_merge)(struct request_queue___9 *, struct request___8 *, struct bio___7 *);
	bool (*bio_merge)(struct request_queue___9 *, struct bio___7 *, unsigned int);
	int (*request_merge)(struct request_queue___9 *, struct request___8 **, struct bio___7 *);
	void (*request_merged)(struct request_queue___9 *, struct request___8 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___9 *, struct request___8 *, struct request___8 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___8 *);
	void (*finish_request)(struct request___8 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___7 *, struct list_head *, bool);
	struct request___8 * (*dispatch_request)(struct blk_mq_hw_ctx___7 *);
	bool (*has_work)(struct blk_mq_hw_ctx___7 *);
	void (*completed_request)(struct request___8 *, u64);
	void (*requeue_request)(struct request___8 *);
	struct request___8 * (*former_request)(struct request_queue___9 *, struct request___8 *);
	struct request___8 * (*next_request)(struct request_queue___9 *, struct request___8 *);
	void (*init_icq)(struct io_cq___7 *);
	void (*exit_icq)(struct io_cq___7 *);
};

struct elv_fs_entry___7;

struct elevator_type___7 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___7 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___7 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___22 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___7 {
	struct elevator_type___7 *type;
	void *elevator_data;
	struct kobject___20 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___7 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___7 *, char *);
	ssize_t (*store)(struct elevator_queue___7 *, const char *, size_t);
};

struct blk_mq_queue_data___7;

struct blk_mq_ops___7 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___7 *, const struct blk_mq_queue_data___7 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___7 *);
	int (*get_budget)(struct request_queue___9 *);
	void (*put_budget)(struct request_queue___9 *, int);
	void (*set_rq_budget_token)(struct request___8 *, int);
	int (*get_rq_budget_token)(struct request___8 *);
	enum blk_eh_timer_return (*timeout)(struct request___8 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___7 *);
	void (*complete)(struct request___8 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___7 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___7 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___7 *, struct request___8 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___7 *, struct request___8 *, unsigned int);
	void (*initialize_rq_fn)(struct request___8 *);
	void (*cleanup_rq)(struct request___8 *);
	bool (*busy)(struct request_queue___9 *);
	int (*map_queues)(struct blk_mq_tag_set___7 *);
	void (*show_rq)(struct seq_file___21 *, struct request___8 *);
};

struct blk_mq_tag_set___7 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___7 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___7 {
	struct request___8 *rq;
	bool last;
};

struct blkcg_policy_data___6;

struct blkcg___6 {
	struct cgroup_subsys_state___13 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___7 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___6 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___6 {
	struct blkcg___6 *blkcg;
	int plid;
};

struct blkg_policy_data___6 {
	struct blkcg_gq___7 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___6 {
	struct mem_cgroup___6 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___6 {
	struct lruvec___7 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___6 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___6 *memcg;
};

struct obj_cgroup___6 {
	struct percpu_ref refcnt;
	struct mem_cgroup___6 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct trace_event_fields___8 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___8 *);
	};
};

struct trace_event_class___8 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___8 *, enum trace_reg, void *);
	struct trace_event_fields___8 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___8 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___8 *);
};

struct trace_event_file___4;

struct trace_event_buffer___4 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___4 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___4 {
	struct list_head list;
	struct trace_event_call___8 *event_call;
	struct event_filter *filter;
	struct dentry___21 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kvm_userspace_exit {
	struct trace_entry ent;
	__u32 reason;
	int errno;
	char __data[0];
};

struct trace_event_raw_kvm_vcpu_wakeup {
	struct trace_entry ent;
	__u64 ns;
	bool waited;
	bool valid;
	char __data[0];
};

struct trace_event_raw_kvm_set_irq {
	struct trace_entry ent;
	unsigned int gsi;
	int level;
	int irq_source_id;
	char __data[0];
};

struct trace_event_raw_kvm_ack_irq {
	struct trace_entry ent;
	unsigned int irqchip;
	unsigned int pin;
	char __data[0];
};

struct trace_event_raw_kvm_mmio {
	struct trace_entry ent;
	u32 type;
	u32 len;
	u64 gpa;
	u64 val;
	char __data[0];
};

struct trace_event_raw_kvm_fpu {
	struct trace_entry ent;
	u32 load;
	char __data[0];
};

struct trace_event_raw_kvm_halt_poll_ns {
	struct trace_entry ent;
	bool grow;
	unsigned int vcpu_id;
	unsigned int new;
	unsigned int old;
	char __data[0];
};

struct trace_event_raw_kvm_dirty_ring_push {
	struct trace_entry ent;
	int index;
	u32 dirty_index;
	u32 reset_index;
	u32 slot;
	u64 offset;
	char __data[0];
};

struct trace_event_raw_kvm_dirty_ring_reset {
	struct trace_entry ent;
	int index;
	u32 dirty_index;
	u32 reset_index;
	char __data[0];
};

struct trace_event_raw_kvm_dirty_ring_exit {
	struct trace_entry ent;
	int vcpu_id;
	char __data[0];
};

struct trace_event_raw_kvm_unmap_hva_range {
	struct trace_entry ent;
	long unsigned int start;
	long unsigned int end;
	char __data[0];
};

struct trace_event_raw_kvm_set_spte_hva {
	struct trace_entry ent;
	long unsigned int hva;
	char __data[0];
};

struct trace_event_raw_kvm_age_hva {
	struct trace_entry ent;
	long unsigned int start;
	long unsigned int end;
	char __data[0];
};

struct trace_event_raw_kvm_test_age_hva {
	struct trace_entry ent;
	long unsigned int hva;
	char __data[0];
};

struct trace_event_data_offsets_kvm_userspace_exit {};

struct trace_event_data_offsets_kvm_vcpu_wakeup {};

struct trace_event_data_offsets_kvm_set_irq {};

struct trace_event_data_offsets_kvm_ack_irq {};

struct trace_event_data_offsets_kvm_mmio {};

struct trace_event_data_offsets_kvm_fpu {};

struct trace_event_data_offsets_kvm_halt_poll_ns {};

struct trace_event_data_offsets_kvm_dirty_ring_push {};

struct trace_event_data_offsets_kvm_dirty_ring_reset {};

struct trace_event_data_offsets_kvm_dirty_ring_exit {};

struct trace_event_data_offsets_kvm_unmap_hva_range {};

struct trace_event_data_offsets_kvm_set_spte_hva {};

struct trace_event_data_offsets_kvm_age_hva {};

struct trace_event_data_offsets_kvm_test_age_hva {};

typedef void (*btf_trace_kvm_userspace_exit)(void *, __u32, int);

typedef void (*btf_trace_kvm_vcpu_wakeup)(void *, __u64, bool, bool);

typedef void (*btf_trace_kvm_set_irq)(void *, unsigned int, int, int);

typedef void (*btf_trace_kvm_ack_irq)(void *, unsigned int, unsigned int);

typedef void (*btf_trace_kvm_mmio)(void *, int, int, u64, void *);

typedef void (*btf_trace_kvm_fpu)(void *, int);

typedef void (*btf_trace_kvm_halt_poll_ns)(void *, bool, unsigned int, unsigned int, unsigned int);

typedef void (*btf_trace_kvm_dirty_ring_push)(void *, struct kvm_dirty_ring *, u32, u64);

typedef void (*btf_trace_kvm_dirty_ring_reset)(void *, struct kvm_dirty_ring *);

typedef void (*btf_trace_kvm_dirty_ring_exit)(void *, struct kvm_vcpu *);

typedef void (*btf_trace_kvm_unmap_hva_range)(void *, long unsigned int, long unsigned int);

typedef void (*btf_trace_kvm_set_spte_hva)(void *, long unsigned int);

typedef void (*btf_trace_kvm_age_hva)(void *, long unsigned int, long unsigned int);

typedef void (*btf_trace_kvm_test_age_hva)(void *, long unsigned int);

typedef bool (*hva_handler_t)(struct kvm *, struct kvm_gfn_range *);

typedef void (*on_lock_fn_t)(struct kvm *, long unsigned int, long unsigned int);

struct kvm_hva_range {
	long unsigned int start;
	long unsigned int end;
	pte_t pte;
	hva_handler_t handler;
	on_lock_fn_t on_lock;
	bool flush_on_ret;
	bool may_block;
};

struct kvm_cpu_compat_check {
	void *opaque;
	int *ret;
};

struct kvm_vm_worker_thread_context {
	struct kvm *kvm;
	struct task_struct___22 *parent;
	struct completion init_done;
	kvm_vm_thread_fn_t thread_fn;
	uintptr_t data;
	int err;
};

struct kvm_vcpu___3;

struct kvm_io_device___2;

struct kvm_io_device_ops___2 {
	int (*read)(struct kvm_vcpu___3 *, struct kvm_io_device___2 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___3 *, struct kvm_io_device___2 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___2 *);
};

struct preempt_ops___2;

struct preempt_notifier___2 {
	struct hlist_node link;
	struct preempt_ops___2 *ops;
};

struct kvm_cpu_context___2 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___3 *__hyp_running_vcpu;
	long: 64;
};

struct its_vm___2;

struct its_vpe___2 {
	struct page___18 *vpt_page;
	struct its_vm___2 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___15 *fwnode;
			struct irq_domain___2 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct vgic_v3_cpu_if___2 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___2 its_vpe;
	unsigned int used_lrs;
};

struct vgic_irq___2 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___3 *vcpu;
	struct kvm_vcpu___3 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___2 {
	const struct kvm_io_device_ops___2 *ops;
};

struct vgic_its___3;

struct vgic_io_device___2 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___3 *redist_vcpu;
		struct vgic_its___3 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___2 dev;
};

struct vgic_cpu___2 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___2 vgic_v3;
	};
	struct vgic_irq___2 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___2 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___2 {
	struct kvm_vcpu___3 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___2 {
	struct arch_timer_context___2 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___2 {
	u8 idx;
	struct perf_event___10 *perf_event;
};

struct kvm_pmu___2 {
	int irq_num;
	struct kvm_pmc___2 pmc[32];
	long unsigned int chained[1];
	bool created;
	bool irq_level;
	struct irq_work overflow_work;
};

struct kvm_s2_mmu___2;

struct kvm_vcpu_arch___2 {
	struct kvm_cpu_context___2 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___2 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___2 vgic_cpu;
	struct arch_timer_cpu___2 timer_cpu;
	struct kvm_pmu___2 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___3;

struct kvm_vcpu___3 {
	struct kvm___3 *kvm;
	struct preempt_notifier___2 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___17 wait;
	struct pid___16 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___2 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct preempt_ops___2 {
	void (*sched_in)(struct preempt_notifier___2 *, int);
	void (*sched_out)(struct preempt_notifier___2 *, struct task_struct___19 *);
};

struct mmu_notifier___2;

struct mmu_notifier_range___2;

struct mmu_notifier_ops___2 {
	void (*release)(struct mmu_notifier___2 *, struct mm_struct___18 *);
	int (*clear_flush_young)(struct mmu_notifier___2 *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___2 *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___2 *, struct mm_struct___18 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___2 *, struct mm_struct___18 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___2 *, const struct mmu_notifier_range___2 *);
	void (*invalidate_range_end)(struct mmu_notifier___2 *, const struct mmu_notifier_range___2 *);
	void (*invalidate_range)(struct mmu_notifier___2 *, struct mm_struct___18 *, long unsigned int, long unsigned int);
	struct mmu_notifier___2 * (*alloc_notifier)(struct mm_struct___18 *);
	void (*free_notifier)(struct mmu_notifier___2 *);
};

struct mmu_notifier___2 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___2 *ops;
	struct mm_struct___18 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___2 {
	struct vm_area_struct___17 *vma;
	struct mm_struct___18 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct its_vm___2 {
	struct fwnode_handle___15 *fwnode;
	struct irq_domain___2 *domain;
	struct page___18 *vprop_page;
	struct its_vpe___2 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___2;

struct vgic_its___3 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___2 iodev;
	struct kvm_device___2 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___2;

struct kvm_device___2 {
	const struct kvm_device_ops___2 *ops;
	struct kvm___3 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___2 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___2 *spis;
	struct vgic_io_device___2 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___2 its_vm;
};

struct kvm_arch___2;

struct kvm_s2_mmu___2 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___2 *arch;
};

struct kvm_arch___2 {
	struct kvm_s2_mmu___2 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___2 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___2 {
	gpa_t addr;
	int len;
	struct kvm_io_device___2 *dev;
};

struct kvm_io_bus___2 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___2 range[0];
};

struct kvm_stat_data___2;

struct kvm___3 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___18 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___3 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___17 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___2 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___2 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___2 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___18 *debugfs_dentry;
	struct kvm_stat_data___2 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___2 {
	struct kvm___3 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___2 {
	const char *name;
	int (*create)(struct kvm_device___2 *, u32);
	void (*init)(struct kvm_device___2 *);
	void (*destroy)(struct kvm_device___2 *);
	void (*release)(struct kvm_device___2 *);
	int (*set_attr)(struct kvm_device___2 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___2 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___2 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___2 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___2 *, struct vm_area_struct___17 *);
};

struct kvm_coalesced_mmio_dev {
	struct list_head list;
	struct kvm_io_device___2 dev;
	struct kvm___3 *kvm;
	struct kvm_coalesced_mmio_zone zone;
};

enum {
	WORK_STRUCT_PENDING_BIT = 0,
	WORK_STRUCT_INACTIVE_BIT = 1,
	WORK_STRUCT_PWQ_BIT = 2,
	WORK_STRUCT_LINKED_BIT = 3,
	WORK_STRUCT_COLOR_SHIFT = 4,
	WORK_STRUCT_COLOR_BITS = 4,
	WORK_STRUCT_PENDING = 1,
	WORK_STRUCT_INACTIVE = 2,
	WORK_STRUCT_PWQ = 4,
	WORK_STRUCT_LINKED = 8,
	WORK_STRUCT_STATIC = 0,
	WORK_NR_COLORS = 16,
	WORK_CPU_UNBOUND = 256,
	WORK_STRUCT_FLAG_BITS = 8,
	WORK_OFFQ_FLAG_BASE = 4,
	__WORK_OFFQ_CANCELING = 4,
	WORK_OFFQ_CANCELING = 16,
	WORK_OFFQ_FLAG_BITS = 1,
	WORK_OFFQ_POOL_SHIFT = 5,
	WORK_OFFQ_LEFT = 59,
	WORK_OFFQ_POOL_BITS = 31,
	WORK_OFFQ_POOL_NONE = 2147483647,
	WORK_STRUCT_FLAG_MASK = 255,
	WORK_STRUCT_WQ_DATA_MASK = 4294967040,
	WORK_STRUCT_NO_POOL = 4294967264,
	WORK_BUSY_PENDING = 1,
	WORK_BUSY_RUNNING = 2,
	WORKER_DESC_LEN = 24,
};

struct irq_bypass_consumer;

struct irq_bypass_producer {
	struct list_head node;
	void *token;
	int irq;
	int (*add_consumer)(struct irq_bypass_producer *, struct irq_bypass_consumer *);
	void (*del_consumer)(struct irq_bypass_producer *, struct irq_bypass_consumer *);
	void (*stop)(struct irq_bypass_producer *);
	void (*start)(struct irq_bypass_producer *);
};

struct irq_bypass_consumer {
	struct list_head node;
	void *token;
	int (*add_producer)(struct irq_bypass_consumer *, struct irq_bypass_producer *);
	void (*del_producer)(struct irq_bypass_consumer *, struct irq_bypass_producer *);
	void (*stop)(struct irq_bypass_consumer *);
	void (*start)(struct irq_bypass_consumer *);
};

enum {
	kvm_ioeventfd_flag_nr_datamatch = 0,
	kvm_ioeventfd_flag_nr_pio = 1,
	kvm_ioeventfd_flag_nr_deassign = 2,
	kvm_ioeventfd_flag_nr_virtio_ccw_notify = 3,
	kvm_ioeventfd_flag_nr_fast_mmio = 4,
	kvm_ioeventfd_flag_nr_max = 5,
};

struct fd {
	struct file___18 *file;
	unsigned int flags;
};

struct kvm_s390_adapter_int {
	u64 ind_addr;
	u64 summary_addr;
	u64 ind_offset;
	u32 summary_offset;
	u32 adapter_id;
};

struct kvm_hv_sint {
	u32 vcpu;
	u32 sint;
};

struct kvm_kernel_irq_routing_entry {
	u32 gsi;
	u32 type;
	int (*set)(struct kvm_kernel_irq_routing_entry *, struct kvm___3 *, int, int, bool);
	union {
		struct {
			unsigned int irqchip;
			unsigned int pin;
		} irqchip;
		struct {
			u32 address_lo;
			u32 address_hi;
			u32 data;
			u32 flags;
			u32 devid;
		} msi;
		struct kvm_s390_adapter_int adapter;
		struct kvm_hv_sint hv_sint;
	};
	struct hlist_node link;
};

struct kvm_irq_ack_notifier {
	struct hlist_node link;
	unsigned int gsi;
	void (*irq_acked)(struct kvm_irq_ack_notifier *);
};

typedef struct poll_table_struct___13 poll_table;

struct kvm_kernel_irqfd_resampler {
	struct kvm___3 *kvm;
	struct list_head list;
	struct kvm_irq_ack_notifier notifier;
	struct list_head link;
};

struct kvm_kernel_irqfd {
	struct kvm___3 *kvm;
	wait_queue_entry_t wait;
	struct kvm_kernel_irq_routing_entry irq_entry;
	seqcount_spinlock_t irq_entry_sc;
	int gsi;
	struct work_struct inject;
	struct kvm_kernel_irqfd_resampler *resampler;
	struct eventfd_ctx *resamplefd;
	struct list_head resampler_link;
	struct eventfd_ctx *eventfd;
	struct list_head list;
	poll_table pt;
	struct work_struct shutdown;
	struct irq_bypass_consumer consumer;
	struct irq_bypass_producer *producer;
};

struct _ioeventfd {
	struct list_head list;
	u64 addr;
	int length;
	struct eventfd_ctx *eventfd;
	u64 datamatch;
	struct kvm_io_device___2 dev;
	u8 bus_idx;
	bool wildcard;
};

struct file___22;

struct fd___2 {
	struct file___22 *file;
	unsigned int flags;
};

struct vfsmount___21;

struct dentry___22;

struct path___21 {
	struct vfsmount___21 *mnt;
	struct dentry___22 *dentry;
};

struct pid___20;

struct fown_struct___20 {
	rwlock_t lock;
	struct pid___20 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___23;

struct file_operations___21;

struct address_space___21;

struct file___22 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___21 f_path;
	struct inode___23 *f_inode;
	const struct file_operations___21 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___20 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___21 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct super_block___22;

struct module___23;

struct file_system_type___21 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___22 * (*mount)(struct file_system_type___21 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___22 *);
	struct module___23 *owner;
	struct file_system_type___21 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___21;

struct poll_table_struct___15;

struct vm_area_struct___21;

struct file_lock___21;

struct page___22;

struct seq_file___22;

struct file_operations___21 {
	struct module___23 *owner;
	loff_t (*llseek)(struct file___22 *, loff_t, int);
	ssize_t (*read)(struct file___22 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___22 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___21 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___21 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___21 *, bool);
	int (*iterate)(struct file___22 *, struct dir_context *);
	int (*iterate_shared)(struct file___22 *, struct dir_context *);
	__poll_t (*poll)(struct file___22 *, struct poll_table_struct___15 *);
	long int (*unlocked_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___22 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___22 *, struct vm_area_struct___21 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___23 *, struct file___22 *);
	int (*flush)(struct file___22 *, fl_owner_t);
	int (*release)(struct inode___23 *, struct file___22 *);
	int (*fsync)(struct file___22 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___22 *, int);
	int (*lock)(struct file___22 *, int, struct file_lock___21 *);
	ssize_t (*sendpage)(struct file___22 *, struct page___22 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___22 *, long unsigned int);
	int (*flock)(struct file___22 *, int, struct file_lock___21 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___22 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___22 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___22 *, long int, struct file_lock___21 **, void **);
	long int (*fallocate)(struct file___22 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___22 *, struct file___22 *);
	ssize_t (*copy_file_range)(struct file___22 *, loff_t, struct file___22 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___22 *, loff_t, struct file___22 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___22 *, loff_t, loff_t, int);
};

struct preempt_notifier___3;

struct task_struct___23;

struct preempt_ops___3 {
	void (*sched_in)(struct preempt_notifier___3 *, int);
	void (*sched_out)(struct preempt_notifier___3 *, struct task_struct___23 *);
};

struct preempt_notifier___3 {
	struct hlist_node link;
	struct preempt_ops___3 *ops;
};

struct vmacache___21 {
	u64 seqnum;
	struct vm_area_struct___21 *vmas[4];
};

struct page_frag___21 {
	struct page___22 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___12;

struct debug_info___12 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___12 *hbp_break[16];
	struct perf_event___12 *hbp_watch[16];
};

struct thread_struct___12 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___12 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___22;

struct nsproxy___21;

struct signal_struct___22;

struct css_set___14;

struct perf_event_context___12;

struct vm_struct___21;

struct task_struct___23 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___23 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___22 *mm;
	struct mm_struct___22 *active_mm;
	struct vmacache___21 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___23 *real_parent;
	struct task_struct___23 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___23 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___20 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___21 *nsproxy;
	struct signal_struct___22 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___23 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___8 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___14 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___12 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___21 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___23 *oom_reaper_list;
	struct vm_struct___21 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___12 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___21;

struct kobj_type___21;

struct kernfs_node___21;

struct kobject___21 {
	const char *name;
	struct list_head entry;
	struct kobject___21 *parent;
	struct kset___21 *kset;
	struct kobj_type___21 *ktype;
	struct kernfs_node___21 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___21 {
	struct kobject___21 kobj;
	struct module___23 *mod;
	struct kobject___21 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___21 {
	struct module___23 *mod;
	struct latch_tree_node node;
};

struct module_layout___21 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___21 mtn;
};

struct module_attribute___21;

struct kernel_param___21;

struct module___23 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___21 mkobj;
	struct module_attribute___21 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___21 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___21 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___21 core_layout;
	struct module_layout___21 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___12 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___23 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___12)(struct perf_event___12 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___12;

struct fasync_struct___21;

struct pid_namespace___20;

struct perf_cgroup___12;

struct perf_event___12 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___12 *group_leader;
	struct pmu___12 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___12 hw;
	struct perf_event_context___12 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___12 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___23 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___21 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___12 *aux_event;
	void (*destroy)(struct perf_event___12 *);
	struct callback_head callback_head;
	struct pid_namespace___20 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___12 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___12 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___12 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___20 {
	int nr;
	struct pid_namespace___20 *ns;
};

struct pid_namespace___20 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___23 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___20 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___20 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___20 numbers[1];
};

typedef struct page___22 *pgtable_t___21;

struct dev_pagemap___21;

struct page___22 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___21 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___22 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___21 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___22 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___21 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___21;

struct vm_area_struct___21 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___21 *vm_next;
	struct vm_area_struct___21 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___22 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___21 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___22 *vm_file;
	struct file___22 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___22 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___23 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___23 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___20 *pids[4];
	struct pid___20 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___22 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___21;

struct mm_struct___22 {
	struct {
		struct vm_area_struct___21 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___22 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___21 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___23 *owner;
		struct user_namespace *user_ns;
		struct file___22 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___14;

struct nsproxy___21 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___20 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___14 *cgroup_ns;
};

struct cgroup_subsys_state___14;

struct cgroup___14;

struct css_set___14 {
	struct cgroup_subsys_state___14 *subsys[14];
	refcount_t refcount;
	struct css_set___14 *dom_cset;
	struct cgroup___14 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___14 *mg_src_cgrp;
	struct cgroup___14 *mg_dst_cgrp;
	struct css_set___14 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___12 {
	struct pmu___12 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___23 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___12 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___21 {
	struct vm_struct___21 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___22 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___21;

struct address_space___21 {
	struct inode___23 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___21 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___21;

struct dev_pagemap___21 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___21 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___21;

struct vm_operations_struct___21 {
	void (*open)(struct vm_area_struct___21 *);
	void (*close)(struct vm_area_struct___21 *);
	int (*may_split)(struct vm_area_struct___21 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___21 *);
	int (*mprotect)(struct vm_area_struct___21 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___21 *);
	vm_fault_t (*huge_fault)(struct vm_fault___21 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___21 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___21 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___21 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___21 *);
	int (*access)(struct vm_area_struct___21 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___21 *);
	int (*set_policy)(struct vm_area_struct___21 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___21 *, long unsigned int);
	struct page___22 * (*find_special_page)(struct vm_area_struct___21 *, long unsigned int);
};

struct core_thread___21 {
	struct task_struct___23 *task;
	struct core_thread___21 *next;
};

struct core_state___21 {
	atomic_t nr_threads;
	struct core_thread___21 dumper;
	struct completion startup;
};

struct vm_fault___21 {
	const struct {
		struct vm_area_struct___21 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___22 *cow_page;
	struct page___22 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___21 prealloc_pte;
};

struct fwnode_operations___18;

struct device___18;

struct fwnode_handle___18 {
	struct fwnode_handle___18 *secondary;
	const struct fwnode_operations___18 *ops;
	struct device___18 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___18;

struct fwnode_endpoint___18;

struct fwnode_operations___18 {
	struct fwnode_handle___18 * (*get)(struct fwnode_handle___18 *);
	void (*put)(struct fwnode_handle___18 *);
	bool (*device_is_available)(const struct fwnode_handle___18 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___18 *, const struct device___18 *);
	bool (*property_present)(const struct fwnode_handle___18 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___18 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___18 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___18 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_parent)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_next_child_node)(const struct fwnode_handle___18 *, struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*get_named_child_node)(const struct fwnode_handle___18 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___18 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___18 *);
	struct fwnode_handle___18 * (*graph_get_next_endpoint)(const struct fwnode_handle___18 *, struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*graph_get_remote_endpoint)(const struct fwnode_handle___18 *);
	struct fwnode_handle___18 * (*graph_get_port_parent)(struct fwnode_handle___18 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___18 *, struct fwnode_endpoint___18 *);
	int (*add_links)(struct fwnode_handle___18 *);
};

struct wakeup_source___18;

struct dev_pm_info___18 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___18 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___18 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___18;

struct bus_type___18;

struct device_driver___18;

struct dev_pm_domain___18;

struct device_node___12;

struct class___18;

struct attribute_group___21;

struct dev_iommu___2;

struct device___18 {
	struct kobject___21 kobj;
	struct device___18 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___18 *type;
	struct bus_type___18 *bus;
	struct device_driver___18 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___18 power;
	struct dev_pm_domain___18 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___12 *of_node;
	struct fwnode_handle___18 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___18 *class;
	const struct attribute_group___21 **groups;
	void (*release)(struct device___18 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___2 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___18 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___18 *local_fwnode;
};

struct fwnode_reference_args___18 {
	struct fwnode_handle___18 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___20;

struct seq_file___22 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___20 *op;
	int poll_event;
	const struct file___22 *file;
	void *private;
};

struct kernfs_root___21;

struct kernfs_elem_dir___21 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___21 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___21;

struct kernfs_root___21 {
	struct kernfs_node___21 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___21 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___21 {
	struct kernfs_node___21 *target_kn;
};

struct kernfs_ops___21;

struct kernfs_elem_attr___21 {
	const struct kernfs_ops___21 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___21 *notify_next;
};

struct kernfs_node___21 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___21 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___21 dir;
		struct kernfs_elem_symlink___21 symlink;
		struct kernfs_elem_attr___21 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___21;

struct kernfs_ops___21 {
	int (*open)(struct kernfs_open_file___21 *);
	void (*release)(struct kernfs_open_file___21 *);
	int (*seq_show)(struct seq_file___22 *, void *);
	void * (*seq_start)(struct seq_file___22 *, loff_t *);
	void * (*seq_next)(struct seq_file___22 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___22 *, void *);
	ssize_t (*read)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___21 *, struct poll_table_struct___15 *);
	int (*mmap)(struct kernfs_open_file___21 *, struct vm_area_struct___21 *);
};

struct kernfs_syscall_ops___21 {
	int (*show_options)(struct seq_file___22 *, struct kernfs_root___21 *);
	int (*mkdir)(struct kernfs_node___21 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___21 *);
	int (*rename)(struct kernfs_node___21 *, struct kernfs_node___21 *, const char *);
	int (*show_path)(struct seq_file___22 *, struct kernfs_node___21 *, struct kernfs_root___21 *);
};

struct kernfs_open_file___21 {
	struct kernfs_node___21 *kn;
	struct file___22 *file;
	struct seq_file___22 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___21 *vm_ops;
};

typedef void (*poll_queue_proc___15)(struct file___22 *, wait_queue_head_t *, struct poll_table_struct___15 *);

struct poll_table_struct___15 {
	poll_queue_proc___15 _qproc;
	__poll_t _key;
};

struct bin_attribute___21;

struct attribute_group___21 {
	const char *name;
	umode_t (*is_visible)(struct kobject___21 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___21 *, struct bin_attribute___21 *, int);
	struct attribute **attrs;
	struct bin_attribute___21 **bin_attrs;
};

struct bin_attribute___21 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___21 * (*f_mapping)();
	ssize_t (*read)(struct file___22 *, struct kobject___21 *, struct bin_attribute___21 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___22 *, struct kobject___21 *, struct bin_attribute___21 *, char *, loff_t, size_t);
	int (*mmap)(struct file___22 *, struct kobject___21 *, struct bin_attribute___21 *, struct vm_area_struct___21 *);
};

struct sysfs_ops___21 {
	ssize_t (*show)(struct kobject___21 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___21 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___21;

struct kset___21 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___21 kobj;
	const struct kset_uevent_ops___21 *uevent_ops;
};

struct kobj_type___21 {
	void (*release)(struct kobject___21 *);
	const struct sysfs_ops___21 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___21 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___21 *);
	const void * (*namespace)(struct kobject___21 *);
	void (*get_ownership)(struct kobject___21 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___21 {
	int (* const filter)(struct kset___21 *, struct kobject___21 *);
	const char * (* const name)(struct kset___21 *, struct kobject___21 *);
	int (* const uevent)(struct kset___21 *, struct kobject___21 *, struct kobj_uevent_env *);
};

struct dev_pagemap_ops___21 {
	void (*page_free)(struct page___22 *);
	void (*kill)(struct dev_pagemap___21 *);
	void (*cleanup)(struct dev_pagemap___21 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___21 *);
};

struct dentry_operations___21;

struct dentry___22 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___22 *d_parent;
	struct qstr d_name;
	struct inode___23 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___21 *d_op;
	struct super_block___22 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___21;

struct inode___23 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___21 *i_op;
	struct super_block___22 *i_sb;
	struct address_space___21 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___21 *i_fop;
		void (*free_inode)(struct inode___23 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___21 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___4 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___21 {
	int (*d_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___22 *, unsigned int);
	int (*d_hash)(const struct dentry___22 *, struct qstr *);
	int (*d_compare)(const struct dentry___22 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___22 *);
	int (*d_init)(struct dentry___22 *);
	void (*d_release)(struct dentry___22 *);
	void (*d_prune)(struct dentry___22 *);
	void (*d_iput)(struct dentry___22 *, struct inode___23 *);
	char * (*d_dname)(struct dentry___22 *, char *, int);
	struct vfsmount___21 * (*d_automount)(struct path___21 *);
	int (*d_manage)(const struct path___21 *, bool);
	struct dentry___22 * (*d_real)(struct dentry___22 *, const struct inode___23 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___21;

struct mem_dqinfo___21 {
	struct quota_format_type___21 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___21;

struct quota_info___21 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___23 *files[3];
	struct mem_dqinfo___21 info[3];
	const struct quota_format_ops___21 *ops[3];
};

struct rcuwait___21 {
	struct task_struct___23 *task;
};

struct percpu_rw_semaphore___21 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___21 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___21 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___21 rw_sem[3];
};

struct super_operations___21;

struct dquot_operations___21;

struct quotactl_ops___21;

struct super_block___22 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___21 *s_type;
	const struct super_operations___21 *s_op;
	const struct dquot_operations___21 *dq_op;
	const struct quotactl_ops___21 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___22 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___21 s_dquot;
	struct sb_writers___21 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___21 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___21 {
	struct dentry___22 *mnt_root;
	struct super_block___22 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___14;

struct cgroup_subsys_state___14 {
	struct cgroup___14 *cgroup;
	struct cgroup_subsys___14 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___14 *parent;
};

struct cgroup_file___14 {
	struct kernfs_node___21 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___14 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___23 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___14;

struct cgroup_rstat_cpu___14;

struct cgroup___14 {
	struct cgroup_subsys_state___14 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___21 *kn;
	struct cgroup_file___14 procs_file;
	struct cgroup_file___14 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___14 *subsys[14];
	struct cgroup_root___14 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___14 *dom_cgrp;
	struct cgroup___14 *old_dom_cgrp;
	struct cgroup_rstat_cpu___14 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___14 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___21 {
	struct file___22 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___21 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___7 *ki_waitq;
	};
};

struct iattr___22 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___22 *ia_file;
};

struct dquot___21 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___22 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___21 {
	int qf_fmt_id;
	const struct quota_format_ops___21 *qf_ops;
	struct module___23 *qf_owner;
	struct quota_format_type___21 *qf_next;
};

struct quota_format_ops___21 {
	int (*check_quota_file)(struct super_block___22 *, int);
	int (*read_file_info)(struct super_block___22 *, int);
	int (*write_file_info)(struct super_block___22 *, int);
	int (*free_file_info)(struct super_block___22 *, int);
	int (*read_dqblk)(struct dquot___21 *);
	int (*commit_dqblk)(struct dquot___21 *);
	int (*release_dqblk)(struct dquot___21 *);
	int (*get_next_id)(struct super_block___22 *, struct kqid *);
};

struct dquot_operations___21 {
	int (*write_dquot)(struct dquot___21 *);
	struct dquot___21 * (*alloc_dquot)(struct super_block___22 *, int);
	void (*destroy_dquot)(struct dquot___21 *);
	int (*acquire_dquot)(struct dquot___21 *);
	int (*release_dquot)(struct dquot___21 *);
	int (*mark_dirty)(struct dquot___21 *);
	int (*write_info)(struct super_block___22 *, int);
	qsize_t * (*get_reserved_space)(struct inode___23 *);
	int (*get_projid)(struct inode___23 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___23 *, qsize_t *);
	int (*get_next_id)(struct super_block___22 *, struct kqid *);
};

struct quotactl_ops___21 {
	int (*quota_on)(struct super_block___22 *, int, int, const struct path___21 *);
	int (*quota_off)(struct super_block___22 *, int);
	int (*quota_enable)(struct super_block___22 *, unsigned int);
	int (*quota_disable)(struct super_block___22 *, unsigned int);
	int (*quota_sync)(struct super_block___22 *, int);
	int (*set_info)(struct super_block___22 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___22 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___22 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___22 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___22 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___22 *, unsigned int);
};

struct address_space_operations___21 {
	int (*writepage)(struct page___22 *, struct writeback_control___3 *);
	int (*readpage)(struct file___22 *, struct page___22 *);
	int (*writepages)(struct address_space___21 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___22 *);
	int (*readpages)(struct file___22 *, struct address_space___21 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___22 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___22 **, void **);
	int (*write_end)(struct file___22 *, struct address_space___21 *, loff_t, unsigned int, unsigned int, struct page___22 *, void *);
	sector_t (*bmap)(struct address_space___21 *, sector_t);
	void (*invalidatepage)(struct page___22 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___22 *, gfp_t);
	void (*freepage)(struct page___22 *);
	ssize_t (*direct_IO)(struct kiocb___21 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___21 *, struct page___22 *, struct page___22 *, enum migrate_mode);
	bool (*isolate_page)(struct page___22 *, isolate_mode_t);
	void (*putback_page)(struct page___22 *);
	int (*launder_page)(struct page___22 *);
	int (*is_partially_uptodate)(struct page___22 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___22 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___21 *, struct page___22 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___22 *, sector_t *);
	void (*swap_deactivate)(struct file___22 *);
};

struct inode_operations___21 {
	struct dentry___22 * (*lookup)(struct inode___23 *, struct dentry___22 *, unsigned int);
	const char * (*get_link)(struct dentry___22 *, struct inode___23 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___23 *, int);
	struct posix_acl * (*get_acl)(struct inode___23 *, int, bool);
	int (*readlink)(struct dentry___22 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___23 *, struct dentry___22 *, umode_t, bool);
	int (*link)(struct dentry___22 *, struct inode___23 *, struct dentry___22 *);
	int (*unlink)(struct inode___23 *, struct dentry___22 *);
	int (*symlink)(struct user_namespace *, struct inode___23 *, struct dentry___22 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___23 *, struct dentry___22 *, umode_t);
	int (*rmdir)(struct inode___23 *, struct dentry___22 *);
	int (*mknod)(struct user_namespace *, struct inode___23 *, struct dentry___22 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___23 *, struct dentry___22 *, struct inode___23 *, struct dentry___22 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___22 *, struct iattr___22 *);
	int (*getattr)(struct user_namespace *, const struct path___21 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___22 *, char *, size_t);
	int (*fiemap)(struct inode___23 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___23 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___23 *, struct dentry___22 *, struct file___22 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___23 *, struct dentry___22 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___23 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___22 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___22 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___21 {
	void (*fl_copy_lock)(struct file_lock___21 *, struct file_lock___21 *);
	void (*fl_release_private)(struct file_lock___21 *);
};

struct lock_manager_operations___21;

struct file_lock___21 {
	struct file_lock___21 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___22 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___21 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___21 *fl_ops;
	const struct lock_manager_operations___21 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___21 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___21 *);
	int (*lm_grant)(struct file_lock___21 *, int);
	bool (*lm_break)(struct file_lock___21 *);
	int (*lm_change)(struct file_lock___21 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___21 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___21 *);
};

struct fasync_struct___21 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___21 *fa_next;
	struct file___22 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___21 {
	struct inode___23 * (*alloc_inode)(struct super_block___22 *);
	void (*destroy_inode)(struct inode___23 *);
	void (*free_inode)(struct inode___23 *);
	void (*dirty_inode)(struct inode___23 *, int);
	int (*write_inode)(struct inode___23 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___23 *);
	void (*evict_inode)(struct inode___23 *);
	void (*put_super)(struct super_block___22 *);
	int (*sync_fs)(struct super_block___22 *, int);
	int (*freeze_super)(struct super_block___22 *);
	int (*freeze_fs)(struct super_block___22 *);
	int (*thaw_super)(struct super_block___22 *);
	int (*unfreeze_fs)(struct super_block___22 *);
	int (*statfs)(struct dentry___22 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___22 *, int *, char *);
	void (*umount_begin)(struct super_block___22 *);
	int (*show_options)(struct seq_file___22 *, struct dentry___22 *);
	int (*show_devname)(struct seq_file___22 *, struct dentry___22 *);
	int (*show_path)(struct seq_file___22 *, struct dentry___22 *);
	int (*show_stats)(struct seq_file___22 *, struct dentry___22 *);
	ssize_t (*quota_read)(struct super_block___22 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___22 *, int, const char *, size_t, loff_t);
	struct dquot___21 ** (*get_dquots)(struct inode___23 *);
	long int (*nr_cached_objects)(struct super_block___22 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___22 *, struct shrink_control___6 *);
	struct file___22 * (*real_loop)(struct file___22 *);
};

struct mmu_notifier___3;

struct mmu_notifier_range___3;

struct mmu_notifier_ops___3 {
	void (*release)(struct mmu_notifier___3 *, struct mm_struct___22 *);
	int (*clear_flush_young)(struct mmu_notifier___3 *, struct mm_struct___22 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___3 *, struct mm_struct___22 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___3 *, struct mm_struct___22 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___3 *, struct mm_struct___22 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___3 *, const struct mmu_notifier_range___3 *);
	void (*invalidate_range_end)(struct mmu_notifier___3 *, const struct mmu_notifier_range___3 *);
	void (*invalidate_range)(struct mmu_notifier___3 *, struct mm_struct___22 *, long unsigned int, long unsigned int);
	struct mmu_notifier___3 * (*alloc_notifier)(struct mm_struct___22 *);
	void (*free_notifier)(struct mmu_notifier___3 *);
};

struct mmu_notifier___3 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___3 *ops;
	struct mm_struct___22 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___3 {
	struct vm_area_struct___21 *vma;
	struct mm_struct___22 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct kernel_param_ops___21 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___21 *);
	int (*get)(char *, const struct kernel_param___21 *);
	void (*free)(void *);
};

struct kparam_array___21;

struct kernel_param___21 {
	const char *name;
	struct module___23 *mod;
	const struct kernel_param_ops___21 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___21 *arr;
	};
};

struct kparam_array___21 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___21 *ops;
	void *elem;
};

struct module_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___21 *, struct module_kobject___21 *, char *);
	ssize_t (*store)(struct module_attribute___21 *, struct module_kobject___21 *, const char *, size_t);
	void (*setup)(struct module___23 *, const char *);
	int (*test)(struct module___23 *);
	void (*free)(struct module___23 *);
};

struct cgroup_namespace___14 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___14 *root_cset;
};

struct kvm_vcpu___4;

struct kvm_io_device___3;

struct kvm_io_device_ops___3 {
	int (*read)(struct kvm_vcpu___4 *, struct kvm_io_device___3 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___4 *, struct kvm_io_device___3 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___3 *);
};

struct kvm_cpu_context___3 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___4 *__hyp_running_vcpu;
	long: 64;
};

struct its_vm___3;

struct its_vpe___3 {
	struct page___22 *vpt_page;
	struct its_vm___3 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___18 *fwnode;
			struct irq_domain___2 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct vgic_v3_cpu_if___3 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___3 its_vpe;
	unsigned int used_lrs;
};

struct vgic_irq___3 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___4 *vcpu;
	struct kvm_vcpu___4 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___3 {
	const struct kvm_io_device_ops___3 *ops;
};

struct vgic_its___4;

struct vgic_io_device___3 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___4 *redist_vcpu;
		struct vgic_its___4 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___3 dev;
};

struct vgic_cpu___3 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___3 vgic_v3;
	};
	struct vgic_irq___3 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___3 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___3 {
	struct kvm_vcpu___4 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___3 {
	struct arch_timer_context___3 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___3 {
	u8 idx;
	struct perf_event___12 *perf_event;
};

struct kvm_pmu___3 {
	int irq_num;
	struct kvm_pmc___3 pmc[32];
	long unsigned int chained[1];
	bool created;
	bool irq_level;
	struct irq_work overflow_work;
};

struct kvm_s2_mmu___3;

struct kvm_vcpu_arch___3 {
	struct kvm_cpu_context___3 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___3 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___3 vgic_cpu;
	struct arch_timer_cpu___3 timer_cpu;
	struct kvm_pmu___3 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___4;

struct kvm_vcpu___4 {
	struct kvm___4 *kvm;
	struct preempt_notifier___3 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___21 wait;
	struct pid___20 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___3 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct its_vm___3 {
	struct fwnode_handle___18 *fwnode;
	struct irq_domain___2 *domain;
	struct page___22 *vprop_page;
	struct its_vpe___3 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___3;

struct vgic_its___4 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___3 iodev;
	struct kvm_device___3 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___3;

struct kvm_device___3 {
	const struct kvm_device_ops___3 *ops;
	struct kvm___4 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___3 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___3 *spis;
	struct vgic_io_device___3 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___3 its_vm;
};

struct property___10 {
	char *name;
	int length;
	void *value;
	struct property___10 *next;
	long unsigned int _flags;
	struct bin_attribute___21 attr;
};

struct device_node___12 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___18 fwnode;
	struct property___10 *properties;
	struct property___10 *deadprops;
	struct device_node___12 *parent;
	struct device_node___12 *child;
	struct device_node___12 *sibling;
	struct kobject___21 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___2 {
	struct device_node___12 *np;
	int args_count;
	uint32_t args[16];
};

struct dev_pm_ops___18 {
	int (*prepare)(struct device___18 *);
	void (*complete)(struct device___18 *);
	int (*suspend)(struct device___18 *);
	int (*resume)(struct device___18 *);
	int (*freeze)(struct device___18 *);
	int (*thaw)(struct device___18 *);
	int (*poweroff)(struct device___18 *);
	int (*restore)(struct device___18 *);
	int (*suspend_late)(struct device___18 *);
	int (*resume_early)(struct device___18 *);
	int (*freeze_late)(struct device___18 *);
	int (*thaw_early)(struct device___18 *);
	int (*poweroff_late)(struct device___18 *);
	int (*restore_early)(struct device___18 *);
	int (*suspend_noirq)(struct device___18 *);
	int (*resume_noirq)(struct device___18 *);
	int (*freeze_noirq)(struct device___18 *);
	int (*thaw_noirq)(struct device___18 *);
	int (*poweroff_noirq)(struct device___18 *);
	int (*restore_noirq)(struct device___18 *);
	int (*runtime_suspend)(struct device___18 *);
	int (*runtime_resume)(struct device___18 *);
	int (*runtime_idle)(struct device___18 *);
};

struct wakeup_source___18 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___18 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___18 {
	struct dev_pm_ops___18 ops;
	int (*start)(struct device___18 *);
	void (*detach)(struct device___18 *, bool);
	int (*activate)(struct device___18 *);
	void (*sync)(struct device___18 *);
	void (*dismiss)(struct device___18 *);
};

struct iommu_ops___2;

struct bus_type___18 {
	const char *name;
	const char *dev_name;
	struct device___18 *dev_root;
	const struct attribute_group___21 **bus_groups;
	const struct attribute_group___21 **dev_groups;
	const struct attribute_group___21 **drv_groups;
	int (*match)(struct device___18 *, struct device_driver___18 *);
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	int (*probe)(struct device___18 *);
	void (*sync_state)(struct device___18 *);
	void (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*online)(struct device___18 *);
	int (*offline)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	int (*num_vf)(struct device___18 *);
	int (*dma_configure)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
	const struct iommu_ops___2 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___18 {
	const char *name;
	struct bus_type___18 *bus;
	struct module___23 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___18 *);
	void (*sync_state)(struct device___18 *);
	int (*remove)(struct device___18 *);
	void (*shutdown)(struct device___18 *);
	int (*suspend)(struct device___18 *, pm_message_t);
	int (*resume)(struct device___18 *);
	const struct attribute_group___21 **groups;
	const struct attribute_group___21 **dev_groups;
	const struct dev_pm_ops___18 *pm;
	void (*coredump)(struct device___18 *);
	struct driver_private *p;
};

struct iommu_domain___2;

struct iommu_iotlb_gather___2;

struct iommu_device___2;

struct iommu_sva___2;

struct iommu_ops___2 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___2 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___2 *);
	int (*attach_dev)(struct iommu_domain___2 *, struct device___18 *);
	void (*detach_dev)(struct iommu_domain___2 *, struct device___18 *);
	int (*map)(struct iommu_domain___2 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___2 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___2 *, long unsigned int, size_t, struct iommu_iotlb_gather___2 *);
	size_t (*unmap_pages)(struct iommu_domain___2 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___2 *);
	void (*flush_iotlb_all)(struct iommu_domain___2 *);
	void (*iotlb_sync_map)(struct iommu_domain___2 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___2 *, struct iommu_iotlb_gather___2 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___2 *, dma_addr_t);
	struct iommu_device___2 * (*probe_device)(struct device___18 *);
	void (*release_device)(struct device___18 *);
	void (*probe_finalize)(struct device___18 *);
	struct iommu_group * (*device_group)(struct device___18 *);
	int (*enable_nesting)(struct iommu_domain___2 *);
	int (*set_pgtable_quirks)(struct iommu_domain___2 *, long unsigned int);
	void (*get_resv_regions)(struct device___18 *, struct list_head *);
	void (*put_resv_regions)(struct device___18 *, struct list_head *);
	void (*apply_resv_region)(struct device___18 *, struct iommu_domain___2 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___18 *, struct of_phandle_args___2 *);
	bool (*is_attach_deferred)(struct iommu_domain___2 *, struct device___18 *);
	bool (*dev_has_feat)(struct device___18 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___18 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___18 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___18 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___2 *, struct device___18 *);
	void (*aux_detach_dev)(struct iommu_domain___2 *, struct device___18 *);
	int (*aux_get_pasid)(struct iommu_domain___2 *, struct device___18 *);
	struct iommu_sva___2 * (*sva_bind)(struct device___18 *, struct mm_struct___22 *, void *);
	void (*sva_unbind)(struct iommu_sva___2 *);
	u32 (*sva_get_pasid)(struct iommu_sva___2 *);
	int (*page_response)(struct device___18 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___2 *, struct device___18 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___2 *, struct device___18 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___18 *, u32);
	int (*def_domain_type)(struct device___18 *);
	long unsigned int pgsize_bitmap;
	struct module___23 *owner;
};

struct device_type___18 {
	const char *name;
	const struct attribute_group___21 **groups;
	int (*uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___18 *);
	const struct dev_pm_ops___18 *pm;
};

struct class___18 {
	const char *name;
	struct module___23 *owner;
	const struct attribute_group___21 **class_groups;
	const struct attribute_group___21 **dev_groups;
	struct kobject___21 *dev_kobj;
	int (*dev_uevent)(struct device___18 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___18 *, umode_t *);
	void (*class_release)(struct class___18 *);
	void (*dev_release)(struct device___18 *);
	int (*shutdown_pre)(struct device___18 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___18 *);
	void (*get_ownership)(struct device___18 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___18 *pm;
	struct subsys_private *p;
};

struct iommu_fwspec___2;

struct dev_iommu___2 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___2 *fwspec;
	struct iommu_device___2 *iommu_dev;
	void *priv;
};

struct seq_operations___20 {
	void * (*start)(struct seq_file___22 *, loff_t *);
	void (*stop)(struct seq_file___22 *, void *);
	void * (*next)(struct seq_file___22 *, void *, loff_t *);
	int (*show)(struct seq_file___22 *, void *);
};

struct cftype___14;

struct cgroup_subsys___14 {
	struct cgroup_subsys_state___14 * (*css_alloc)(struct cgroup_subsys_state___14 *);
	int (*css_online)(struct cgroup_subsys_state___14 *);
	void (*css_offline)(struct cgroup_subsys_state___14 *);
	void (*css_released)(struct cgroup_subsys_state___14 *);
	void (*css_free)(struct cgroup_subsys_state___14 *);
	void (*css_reset)(struct cgroup_subsys_state___14 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___14 *, int);
	int (*css_extra_stat_show)(struct seq_file___22 *, struct cgroup_subsys_state___14 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___23 *, struct css_set___14 *);
	void (*cancel_fork)(struct task_struct___23 *, struct css_set___14 *);
	void (*fork)(struct task_struct___23 *);
	void (*exit)(struct task_struct___23 *);
	void (*release)(struct task_struct___23 *);
	void (*bind)(struct cgroup_subsys_state___14 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___14 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___14 *dfl_cftypes;
	struct cftype___14 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___14 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___14 *updated_children;
	struct cgroup___14 *updated_next;
};

struct cgroup_root___14 {
	struct kernfs_root___21 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___14 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___14 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___14 *ss;
	struct list_head node;
	struct kernfs_ops___21 *kf_ops;
	int (*open)(struct kernfs_open_file___21 *);
	void (*release)(struct kernfs_open_file___21 *);
	u64 (*read_u64)(struct cgroup_subsys_state___14 *, struct cftype___14 *);
	s64 (*read_s64)(struct cgroup_subsys_state___14 *, struct cftype___14 *);
	int (*seq_show)(struct seq_file___22 *, void *);
	void * (*seq_start)(struct seq_file___22 *, loff_t *);
	void * (*seq_next)(struct seq_file___22 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___22 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___14 *, struct cftype___14 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___14 *, struct cftype___14 *, s64);
	ssize_t (*write)(struct kernfs_open_file___21 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___21 *, struct poll_table_struct___15 *);
};

struct perf_cpu_context___12;

struct perf_output_handle___12;

struct pmu___12 {
	struct list_head entry;
	struct module___23 *module;
	struct device___18 *dev;
	const struct attribute_group___21 **attr_groups;
	const struct attribute_group___21 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___12 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___12 *);
	void (*pmu_disable)(struct pmu___12 *);
	int (*event_init)(struct perf_event___12 *);
	void (*event_mapped)(struct perf_event___12 *, struct mm_struct___22 *);
	void (*event_unmapped)(struct perf_event___12 *, struct mm_struct___22 *);
	int (*add)(struct perf_event___12 *, int);
	void (*del)(struct perf_event___12 *, int);
	void (*start)(struct perf_event___12 *, int);
	void (*stop)(struct perf_event___12 *, int);
	void (*read)(struct perf_event___12 *);
	void (*start_txn)(struct pmu___12 *, unsigned int);
	int (*commit_txn)(struct pmu___12 *);
	void (*cancel_txn)(struct pmu___12 *);
	int (*event_idx)(struct perf_event___12 *);
	void (*sched_task)(struct perf_event_context___12 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___12 *, struct perf_event_context___12 *);
	void * (*setup_aux)(struct perf_event___12 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___12 *, struct perf_output_handle___12 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___12 *);
	int (*aux_output_match)(struct perf_event___12 *);
	int (*filter_match)(struct perf_event___12 *);
	int (*check_period)(struct perf_event___12 *, u64);
};

struct perf_cpu_context___12 {
	struct perf_event_context___12 ctx;
	struct perf_event_context___12 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___12 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___12 **heap;
	struct perf_event___12 *heap_default[2];
};

struct perf_output_handle___12 {
	struct perf_event___12 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___12 {
	struct cgroup_subsys_state___14 css;
	struct perf_cgroup_info *info;
};

struct kvm_arch___3;

struct kvm_s2_mmu___3 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___3 *arch;
};

struct kvm_arch___3 {
	struct kvm_s2_mmu___3 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___3 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___3 {
	gpa_t addr;
	int len;
	struct kvm_io_device___3 *dev;
};

struct kvm_io_bus___3 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___3 range[0];
};

struct kvm_stat_data___3;

struct kvm___4 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___22 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___4 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___21 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___3 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___3 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___3 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___22 *debugfs_dentry;
	struct kvm_stat_data___3 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___3 {
	struct kvm___4 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___3 {
	const char *name;
	int (*create)(struct kvm_device___3 *, u32);
	void (*init)(struct kvm_device___3 *);
	void (*destroy)(struct kvm_device___3 *);
	void (*release)(struct kvm_device___3 *);
	int (*set_attr)(struct kvm_device___3 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___3 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___3 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___3 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___3 *, struct vm_area_struct___21 *);
};

typedef int (*iommu_fault_handler_t___2)(struct iommu_domain___2 *, struct device___18 *, long unsigned int, int, void *);

struct iommu_domain___2 {
	unsigned int type;
	const struct iommu_ops___2 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___2 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___2 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___22 *freelist;
	bool queued;
};

struct iommu_device___2 {
	struct list_head list;
	const struct iommu_ops___2 *ops;
	struct fwnode_handle___18 *fwnode;
	struct device___18 *dev;
};

struct iommu_sva___2 {
	struct device___18 *dev;
};

struct iommu_fwspec___2 {
	const struct iommu_ops___2 *ops;
	struct fwnode_handle___18 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct vfio_group;

struct kvm_vfio_group {
	struct list_head node;
	struct vfio_group *vfio_group;
};

struct kvm_vfio {
	struct list_head group_list;
	struct mutex lock;
	bool noncoherent;
};

typedef struct poll_table_struct___14 poll_table___2;

struct psci_0_1_function_ids {
	u32 cpu_suspend;
	u32 cpu_on;
	u32 cpu_off;
	u32 migrate;
};

struct kvm_vcpu_init {
	__u32 target;
	__u32 features[7];
};

struct kvm_vcpu_events {
	struct {
		__u8 serror_pending;
		__u8 serror_has_esr;
		__u8 ext_dabt_pending;
		__u8 pad[5];
		__u64 serror_esr;
	} exception;
	__u32 reserved[12];
};

struct kvm_arm_copy_mte_tags {
	__u64 guest_ipa;
	__u64 length;
	void *addr;
	__u64 flags;
	__u64 reserved[2];
};

struct kvm_reg_list {
	__u64 n;
	__u64 reg[0];
};

struct kvm_one_reg {
	__u64 id;
	__u64 addr;
};

struct kvm_arm_device_addr {
	__u64 id;
	__u64 addr;
};

struct kvm_nvhe_init_params {
	long unsigned int mair_el2;
	long unsigned int tcr_el2;
	long unsigned int tpidr_el2;
	long unsigned int stack_hyp_va;
	phys_addr_t pgd_pa;
	long unsigned int hcr_el2;
	long unsigned int vttbr;
	long unsigned int vtcr;
};

enum vgic_type {
	VGIC_V2 = 0,
	VGIC_V3 = 1,
};

struct vgic_global {
	enum vgic_type type;
	phys_addr_t vcpu_base;
	void *vcpu_base_va;
	void *vcpu_hyp_va;
	void *vctrl_base;
	void *vctrl_hyp;
	int nr_lr;
	unsigned int maint_irq;
	int max_gic_vcpus;
	bool can_emulate_gicv2;
	bool has_gicv4;
	bool has_gicv4_1;
	bool no_hw_deactivation;
	struct static_key_false gicv3_cpuif;
	u32 ich_vtr_el2;
};

enum kvm_arch_timers {
	TIMER_PTIMER = 0,
	TIMER_VTIMER = 1,
	NR_KVM_TIMERS = 2,
};

struct timer_map {
	struct arch_timer_context *direct_vtimer;
	struct arch_timer_context *direct_ptimer;
	struct arch_timer_context *emul_ptimer;
};

typedef u64 kvm_pte_t;

enum kvm_pgtable_stage2_flags {
	KVM_PGTABLE_S2_NOFWB = 1,
	KVM_PGTABLE_S2_IDMAP = 2,
};

enum kvm_pgtable_prot {
	KVM_PGTABLE_PROT_X = 1,
	KVM_PGTABLE_PROT_W = 2,
	KVM_PGTABLE_PROT_R = 4,
	KVM_PGTABLE_PROT_DEVICE = 8,
	KVM_PGTABLE_PROT_SW0 = 0,
	KVM_PGTABLE_PROT_SW1 = 0,
	KVM_PGTABLE_PROT_SW2 = 0,
	KVM_PGTABLE_PROT_SW3 = 0,
};

typedef bool (*kvm_pgtable_force_pte_cb_t)(u64, u64, enum kvm_pgtable_prot);

struct kvm_pgtable_mm_ops;

struct kvm_pgtable {
	u32 ia_bits;
	u32 start_level;
	kvm_pte_t *pgd;
	struct kvm_pgtable_mm_ops *mm_ops;
	struct kvm_s2_mmu *mmu;
	enum kvm_pgtable_stage2_flags flags;
	kvm_pgtable_force_pte_cb_t force_pte_cb;
};

struct kvm_pmu_events {
	u32 events_host;
	u32 events_guest;
};

struct kvm_host_data {
	struct kvm_cpu_context host_ctxt;
	struct kvm_pmu_events pmu_events;
	long: 64;
};

struct kvm_host_psci_config {
	u32 version;
	struct psci_0_1_function_ids function_ids_0_1;
	bool psci_0_1_cpu_suspend_implemented;
	bool psci_0_1_cpu_on_implemented;
	bool psci_0_1_cpu_off_implemented;
	bool psci_0_1_migrate_implemented;
};

struct kvm_kernel_irq_routing_entry___2 {
	u32 gsi;
	u32 type;
	int (*set)(struct kvm_kernel_irq_routing_entry___2 *, struct kvm *, int, int, bool);
	union {
		struct {
			unsigned int irqchip;
			unsigned int pin;
		} irqchip;
		struct {
			u32 address_lo;
			u32 address_hi;
			u32 data;
			u32 flags;
			u32 devid;
		} msi;
		struct kvm_s390_adapter_int adapter;
		struct kvm_hv_sint hv_sint;
	};
	struct hlist_node link;
};

struct kvm_kernel_irqfd_resampler___2 {
	struct kvm *kvm;
	struct list_head list;
	struct kvm_irq_ack_notifier notifier;
	struct list_head link;
};

struct kvm_kernel_irqfd___2 {
	struct kvm *kvm;
	wait_queue_entry_t wait;
	struct kvm_kernel_irq_routing_entry___2 irq_entry;
	seqcount_spinlock_t irq_entry_sc;
	int gsi;
	struct work_struct inject;
	struct kvm_kernel_irqfd_resampler___2 *resampler;
	struct eventfd_ctx *resamplefd;
	struct list_head resampler_link;
	struct eventfd_ctx *eventfd;
	struct list_head list;
	poll_table___2 pt;
	struct work_struct shutdown;
	struct irq_bypass_consumer consumer;
	struct irq_bypass_producer *producer;
};

struct trace_event_raw_kvm_entry {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	char __data[0];
};

struct trace_event_raw_kvm_exit {
	struct trace_entry ent;
	int ret;
	unsigned int esr_ec;
	long unsigned int vcpu_pc;
	char __data[0];
};

struct trace_event_raw_kvm_guest_fault {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	long unsigned int hsr;
	long unsigned int hxfar;
	long long unsigned int ipa;
	char __data[0];
};

struct trace_event_raw_kvm_access_fault {
	struct trace_entry ent;
	long unsigned int ipa;
	char __data[0];
};

struct trace_event_raw_kvm_irq_line {
	struct trace_entry ent;
	unsigned int type;
	int vcpu_idx;
	int irq_num;
	int level;
	char __data[0];
};

struct trace_event_raw_kvm_mmio_emulate {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	long unsigned int instr;
	long unsigned int cpsr;
	char __data[0];
};

struct trace_event_raw_kvm_set_way_flush {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool cache;
	char __data[0];
};

struct trace_event_raw_kvm_toggle_cache {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool was;
	bool now;
	char __data[0];
};

struct trace_event_raw_kvm_timer_update_irq {
	struct trace_entry ent;
	long unsigned int vcpu_id;
	__u32 irq;
	int level;
	char __data[0];
};

struct trace_event_raw_kvm_get_timer_map {
	struct trace_entry ent;
	long unsigned int vcpu_id;
	int direct_vtimer;
	int direct_ptimer;
	int emul_ptimer;
	char __data[0];
};

struct trace_event_raw_kvm_timer_save_state {
	struct trace_entry ent;
	long unsigned int ctl;
	long long unsigned int cval;
	int timer_idx;
	char __data[0];
};

struct trace_event_raw_kvm_timer_restore_state {
	struct trace_entry ent;
	long unsigned int ctl;
	long long unsigned int cval;
	int timer_idx;
	char __data[0];
};

struct trace_event_raw_kvm_timer_hrtimer_expire {
	struct trace_entry ent;
	int timer_idx;
	char __data[0];
};

struct trace_event_raw_kvm_timer_emulate {
	struct trace_entry ent;
	int timer_idx;
	bool should_fire;
	char __data[0];
};

struct trace_event_data_offsets_kvm_entry {};

struct trace_event_data_offsets_kvm_exit {};

struct trace_event_data_offsets_kvm_guest_fault {};

struct trace_event_data_offsets_kvm_access_fault {};

struct trace_event_data_offsets_kvm_irq_line {};

struct trace_event_data_offsets_kvm_mmio_emulate {};

struct trace_event_data_offsets_kvm_set_way_flush {};

struct trace_event_data_offsets_kvm_toggle_cache {};

struct trace_event_data_offsets_kvm_timer_update_irq {};

struct trace_event_data_offsets_kvm_get_timer_map {};

struct trace_event_data_offsets_kvm_timer_save_state {};

struct trace_event_data_offsets_kvm_timer_restore_state {};

struct trace_event_data_offsets_kvm_timer_hrtimer_expire {};

struct trace_event_data_offsets_kvm_timer_emulate {};

typedef void (*btf_trace_kvm_entry)(void *, long unsigned int);

typedef void (*btf_trace_kvm_exit)(void *, int, unsigned int, long unsigned int);

typedef void (*btf_trace_kvm_guest_fault)(void *, long unsigned int, long unsigned int, long unsigned int, long long unsigned int);

typedef void (*btf_trace_kvm_access_fault)(void *, long unsigned int);

typedef void (*btf_trace_kvm_irq_line)(void *, unsigned int, int, int, int);

typedef void (*btf_trace_kvm_mmio_emulate)(void *, long unsigned int, long unsigned int, long unsigned int);

typedef void (*btf_trace_kvm_set_way_flush)(void *, long unsigned int, bool);

typedef void (*btf_trace_kvm_toggle_cache)(void *, long unsigned int, bool, bool);

typedef void (*btf_trace_kvm_timer_update_irq)(void *, long unsigned int, __u32, int);

typedef void (*btf_trace_kvm_get_timer_map)(void *, long unsigned int, struct timer_map *);

typedef void (*btf_trace_kvm_timer_save_state)(void *, struct arch_timer_context *);

typedef void (*btf_trace_kvm_timer_restore_state)(void *, struct arch_timer_context *);

typedef void (*btf_trace_kvm_timer_hrtimer_expire)(void *, struct arch_timer_context *);

typedef void (*btf_trace_kvm_timer_emulate)(void *, struct arch_timer_context *, bool);

struct kvm_pgtable_mm_ops {
	void * (*zalloc_page)(void *);
	void * (*zalloc_pages_exact)(size_t);
	void (*free_pages_exact)(void *, size_t);
	void (*get_page)(void *);
	void (*put_page)(void *);
	int (*page_count)(void *);
	void * (*phys_to_virt)(phys_addr_t);
	phys_addr_t (*virt_to_phys)(void *);
	void (*dcache_clean_inval_poc)(void *, size_t);
	void (*icache_inval_pou)(void *, size_t);
};

struct dentry___23;

struct super_block___23;

struct module___24;

struct file_system_type___22 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___23 * (*mount)(struct file_system_type___22 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___23 *);
	struct module___24 *owner;
	struct file_system_type___22 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___23;

struct kiocb___22;

struct poll_table_struct___16;

struct vm_area_struct___22;

struct inode___24;

struct file_lock___22;

struct page___23;

struct seq_file___23;

struct file_operations___22 {
	struct module___24 *owner;
	loff_t (*llseek)(struct file___23 *, loff_t, int);
	ssize_t (*read)(struct file___23 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___23 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___22 *, struct iov_iter___9 *);
	ssize_t (*write_iter)(struct kiocb___22 *, struct iov_iter___9 *);
	int (*iopoll)(struct kiocb___22 *, bool);
	int (*iterate)(struct file___23 *, struct dir_context *);
	int (*iterate_shared)(struct file___23 *, struct dir_context *);
	__poll_t (*poll)(struct file___23 *, struct poll_table_struct___16 *);
	long int (*unlocked_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___23 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___23 *, struct vm_area_struct___22 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___24 *, struct file___23 *);
	int (*flush)(struct file___23 *, fl_owner_t);
	int (*release)(struct inode___24 *, struct file___23 *);
	int (*fsync)(struct file___23 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___23 *, int);
	int (*lock)(struct file___23 *, int, struct file_lock___22 *);
	ssize_t (*sendpage)(struct file___23 *, struct page___23 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___23 *, long unsigned int);
	int (*flock)(struct file___23 *, int, struct file_lock___22 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___23 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___23 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___23 *, long int, struct file_lock___22 **, void **);
	long int (*fallocate)(struct file___23 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___23 *, struct file___23 *);
	ssize_t (*copy_file_range)(struct file___23 *, loff_t, struct file___23 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___23 *, loff_t, struct file___23 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___23 *, loff_t, loff_t, int);
};

struct preempt_notifier___4;

struct task_struct___24;

struct preempt_ops___4 {
	void (*sched_in)(struct preempt_notifier___4 *, int);
	void (*sched_out)(struct preempt_notifier___4 *, struct task_struct___24 *);
};

struct preempt_notifier___4 {
	struct hlist_node link;
	struct preempt_ops___4 *ops;
};

struct vmacache___22 {
	u64 seqnum;
	struct vm_area_struct___22 *vmas[4];
};

struct page_frag___22 {
	struct page___23 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___13;

struct debug_info___13 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___13 *hbp_break[16];
	struct perf_event___13 *hbp_watch[16];
};

struct thread_struct___13 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___13 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___23;

struct pid___21;

struct nsproxy___22;

struct signal_struct___23;

struct css_set___15;

struct perf_event_context___13;

struct vm_struct___22;

struct task_struct___24 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___24 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___23 *mm;
	struct mm_struct___23 *active_mm;
	struct vmacache___22 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___24 *real_parent;
	struct task_struct___24 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___24 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___21 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___22 *nsproxy;
	struct signal_struct___23 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___24 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___8 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___15 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___13 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___22 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___24 *oom_reaper_list;
	struct vm_struct___22 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___13 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___22;

struct kobj_type___22;

struct kernfs_node___22;

struct kobject___22 {
	const char *name;
	struct list_head entry;
	struct kobject___22 *parent;
	struct kset___22 *kset;
	struct kobj_type___22 *ktype;
	struct kernfs_node___22 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___22 {
	struct kobject___22 kobj;
	struct module___24 *mod;
	struct kobject___22 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___22 {
	struct module___24 *mod;
	struct latch_tree_node node;
};

struct module_layout___22 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___22 mtn;
};

struct module_attribute___22;

struct kernel_param___22;

struct module___24 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___22 mkobj;
	struct module_attribute___22 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___22 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___22 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___22 core_layout;
	struct module_layout___22 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___13 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___24 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___13)(struct perf_event___13 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___13;

struct fasync_struct___22;

struct pid_namespace___21;

struct perf_cgroup___13;

struct perf_event___13 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___13 *group_leader;
	struct pmu___13 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___13 hw;
	struct perf_event_context___13 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___13 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___24 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___22 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___13 *aux_event;
	void (*destroy)(struct perf_event___13 *);
	struct callback_head callback_head;
	struct pid_namespace___21 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___13 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___13 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___13 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___23 *pgtable_t___22;

struct address_space___22;

struct dev_pagemap___22;

struct page___23 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___22 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___4 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___23 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___22 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___23 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___22 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___22;

struct vm_area_struct___22 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___22 *vm_next;
	struct vm_area_struct___22 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___23 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___22 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___23 *vm_file;
	struct file___23 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___22;

struct mm_struct___23 {
	struct {
		struct vm_area_struct___22 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___23 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___22 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___24 *owner;
		struct user_namespace *user_ns;
		struct file___23 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___22;

struct address_space___22 {
	struct inode___24 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___22 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___22;

struct dev_pagemap___22 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___22 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___22;

struct path___22 {
	struct vfsmount___22 *mnt;
	struct dentry___23 *dentry;
};

struct fown_struct___21 {
	rwlock_t lock;
	struct pid___21 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___23 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___22 f_path;
	struct inode___24 *f_inode;
	const struct file_operations___22 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___21 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___22 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___22;

struct vm_operations_struct___22 {
	void (*open)(struct vm_area_struct___22 *);
	void (*close)(struct vm_area_struct___22 *);
	int (*may_split)(struct vm_area_struct___22 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___22 *);
	int (*mprotect)(struct vm_area_struct___22 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___22 *);
	vm_fault_t (*huge_fault)(struct vm_fault___22 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___22 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___22 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___22 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___22 *);
	int (*access)(struct vm_area_struct___22 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___22 *);
	int (*set_policy)(struct vm_area_struct___22 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___22 *, long unsigned int);
	struct page___23 * (*find_special_page)(struct vm_area_struct___22 *, long unsigned int);
};

struct core_thread___22 {
	struct task_struct___24 *task;
	struct core_thread___22 *next;
};

struct core_state___22 {
	atomic_t nr_threads;
	struct core_thread___22 dumper;
	struct completion startup;
};

struct vm_fault___22 {
	const struct {
		struct vm_area_struct___22 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___23 *cow_page;
	struct page___23 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___22 prealloc_pte;
};

struct dev_pagemap_ops___22 {
	void (*page_free)(struct page___23 *);
	void (*kill)(struct dev_pagemap___22 *);
	void (*cleanup)(struct dev_pagemap___22 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___22 *);
};

struct upid___21 {
	int nr;
	struct pid_namespace___21 *ns;
};

struct pid_namespace___21 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___24 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___21 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___21 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___21 numbers[1];
};

struct signal_struct___23 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___24 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___24 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___21 *pids[4];
	struct pid___21 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___23 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___15;

struct nsproxy___22 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___21 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___15 *cgroup_ns;
};

struct cgroup_subsys_state___15;

struct cgroup___15;

struct css_set___15 {
	struct cgroup_subsys_state___15 *subsys[14];
	refcount_t refcount;
	struct css_set___15 *dom_cset;
	struct cgroup___15 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___15 *mg_src_cgrp;
	struct cgroup___15 *mg_dst_cgrp;
	struct css_set___15 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___13 {
	struct pmu___13 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___24 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___13 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___22 {
	struct vm_struct___22 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___23 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___22;

struct dentry___23 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___23 *d_parent;
	struct qstr d_name;
	struct inode___24 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___22 *d_op;
	struct super_block___23 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___22;

struct cdev___11;

struct inode___24 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___22 *i_op;
	struct super_block___23 *i_sb;
	struct address_space___22 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___22 *i_fop;
		void (*free_inode)(struct inode___24 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___22 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___11 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___22 {
	int (*d_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___23 *, unsigned int);
	int (*d_hash)(const struct dentry___23 *, struct qstr *);
	int (*d_compare)(const struct dentry___23 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___23 *);
	int (*d_init)(struct dentry___23 *);
	void (*d_release)(struct dentry___23 *);
	void (*d_prune)(struct dentry___23 *);
	void (*d_iput)(struct dentry___23 *, struct inode___24 *);
	char * (*d_dname)(struct dentry___23 *, char *, int);
	struct vfsmount___22 * (*d_automount)(struct path___22 *);
	int (*d_manage)(const struct path___22 *, bool);
	struct dentry___23 * (*d_real)(struct dentry___23 *, const struct inode___24 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___22;

struct mem_dqinfo___22 {
	struct quota_format_type___22 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___22;

struct quota_info___22 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___24 *files[3];
	struct mem_dqinfo___22 info[3];
	const struct quota_format_ops___22 *ops[3];
};

struct rcuwait___22 {
	struct task_struct___24 *task;
};

struct percpu_rw_semaphore___22 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___22 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___22 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___22 rw_sem[3];
};

struct super_operations___22;

struct dquot_operations___22;

struct quotactl_ops___22;

struct super_block___23 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___22 *s_type;
	const struct super_operations___22 *s_op;
	const struct dquot_operations___22 *dq_op;
	const struct quotactl_ops___22 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___23 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___22 s_dquot;
	struct sb_writers___22 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___22 *s_d_op;
	int cleancache_poolid;
	struct shrinker___6 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___22 {
	struct dentry___23 *mnt_root;
	struct super_block___23 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct cgroup_subsys___15;

struct cgroup_subsys_state___15 {
	struct cgroup___15 *cgroup;
	struct cgroup_subsys___15 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___15 *parent;
};

struct cgroup_file___15 {
	struct kernfs_node___22 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___15 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___24 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___15;

struct cgroup_rstat_cpu___15;

struct cgroup___15 {
	struct cgroup_subsys_state___15 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___22 *kn;
	struct cgroup_file___15 procs_file;
	struct cgroup_file___15 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___15 *subsys[14];
	struct cgroup_root___15 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___15 *dom_cgrp;
	struct cgroup___15 *old_dom_cgrp;
	struct cgroup_rstat_cpu___15 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___15 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___8;

struct kiocb___22 {
	struct file___23 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___22 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___8 *ki_waitq;
	};
};

struct iattr___23 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___23 *ia_file;
};

struct dquot___22 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___23 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___22 {
	int qf_fmt_id;
	const struct quota_format_ops___22 *qf_ops;
	struct module___24 *qf_owner;
	struct quota_format_type___22 *qf_next;
};

struct quota_format_ops___22 {
	int (*check_quota_file)(struct super_block___23 *, int);
	int (*read_file_info)(struct super_block___23 *, int);
	int (*write_file_info)(struct super_block___23 *, int);
	int (*free_file_info)(struct super_block___23 *, int);
	int (*read_dqblk)(struct dquot___22 *);
	int (*commit_dqblk)(struct dquot___22 *);
	int (*release_dqblk)(struct dquot___22 *);
	int (*get_next_id)(struct super_block___23 *, struct kqid *);
};

struct dquot_operations___22 {
	int (*write_dquot)(struct dquot___22 *);
	struct dquot___22 * (*alloc_dquot)(struct super_block___23 *, int);
	void (*destroy_dquot)(struct dquot___22 *);
	int (*acquire_dquot)(struct dquot___22 *);
	int (*release_dquot)(struct dquot___22 *);
	int (*mark_dirty)(struct dquot___22 *);
	int (*write_info)(struct super_block___23 *, int);
	qsize_t * (*get_reserved_space)(struct inode___24 *);
	int (*get_projid)(struct inode___24 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___24 *, qsize_t *);
	int (*get_next_id)(struct super_block___23 *, struct kqid *);
};

struct quotactl_ops___22 {
	int (*quota_on)(struct super_block___23 *, int, int, const struct path___22 *);
	int (*quota_off)(struct super_block___23 *, int);
	int (*quota_enable)(struct super_block___23 *, unsigned int);
	int (*quota_disable)(struct super_block___23 *, unsigned int);
	int (*quota_sync)(struct super_block___23 *, int);
	int (*set_info)(struct super_block___23 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___23 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___23 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___23 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___23 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___23 *, unsigned int);
};

struct wait_page_queue___8 {
	struct page___23 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___8;

struct address_space_operations___22 {
	int (*writepage)(struct page___23 *, struct writeback_control___3 *);
	int (*readpage)(struct file___23 *, struct page___23 *);
	int (*writepages)(struct address_space___22 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___23 *);
	int (*readpages)(struct file___23 *, struct address_space___22 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___8 *);
	int (*write_begin)(struct file___23 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___23 **, void **);
	int (*write_end)(struct file___23 *, struct address_space___22 *, loff_t, unsigned int, unsigned int, struct page___23 *, void *);
	sector_t (*bmap)(struct address_space___22 *, sector_t);
	void (*invalidatepage)(struct page___23 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___23 *, gfp_t);
	void (*freepage)(struct page___23 *);
	ssize_t (*direct_IO)(struct kiocb___22 *, struct iov_iter___9 *);
	int (*migratepage)(struct address_space___22 *, struct page___23 *, struct page___23 *, enum migrate_mode);
	bool (*isolate_page)(struct page___23 *, isolate_mode_t);
	void (*putback_page)(struct page___23 *);
	int (*launder_page)(struct page___23 *);
	int (*is_partially_uptodate)(struct page___23 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___23 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___22 *, struct page___23 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___23 *, sector_t *);
	void (*swap_deactivate)(struct file___23 *);
};

struct readahead_control___8 {
	struct file___23 *file;
	struct address_space___22 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct cdev___11 {
	struct kobject___22 kobj;
	struct module___24 *owner;
	const struct file_operations___22 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___22 {
	struct dentry___23 * (*lookup)(struct inode___24 *, struct dentry___23 *, unsigned int);
	const char * (*get_link)(struct dentry___23 *, struct inode___24 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___24 *, int);
	struct posix_acl * (*get_acl)(struct inode___24 *, int, bool);
	int (*readlink)(struct dentry___23 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___24 *, struct dentry___23 *, umode_t, bool);
	int (*link)(struct dentry___23 *, struct inode___24 *, struct dentry___23 *);
	int (*unlink)(struct inode___24 *, struct dentry___23 *);
	int (*symlink)(struct user_namespace *, struct inode___24 *, struct dentry___23 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___24 *, struct dentry___23 *, umode_t);
	int (*rmdir)(struct inode___24 *, struct dentry___23 *);
	int (*mknod)(struct user_namespace *, struct inode___24 *, struct dentry___23 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___24 *, struct dentry___23 *, struct inode___24 *, struct dentry___23 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___23 *, struct iattr___23 *);
	int (*getattr)(struct user_namespace *, const struct path___22 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___23 *, char *, size_t);
	int (*fiemap)(struct inode___24 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___24 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___24 *, struct dentry___23 *, struct file___23 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___24 *, struct dentry___23 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___24 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___23 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___23 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___22 {
	void (*fl_copy_lock)(struct file_lock___22 *, struct file_lock___22 *);
	void (*fl_release_private)(struct file_lock___22 *);
};

struct lock_manager_operations___22;

struct file_lock___22 {
	struct file_lock___22 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___23 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___22 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___22 *fl_ops;
	const struct lock_manager_operations___22 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___22 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___22 *);
	int (*lm_grant)(struct file_lock___22 *, int);
	bool (*lm_break)(struct file_lock___22 *);
	int (*lm_change)(struct file_lock___22 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___22 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___22 *);
};

struct fasync_struct___22 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___22 *fa_next;
	struct file___23 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___22 {
	struct inode___24 * (*alloc_inode)(struct super_block___23 *);
	void (*destroy_inode)(struct inode___24 *);
	void (*free_inode)(struct inode___24 *);
	void (*dirty_inode)(struct inode___24 *, int);
	int (*write_inode)(struct inode___24 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___24 *);
	void (*evict_inode)(struct inode___24 *);
	void (*put_super)(struct super_block___23 *);
	int (*sync_fs)(struct super_block___23 *, int);
	int (*freeze_super)(struct super_block___23 *);
	int (*freeze_fs)(struct super_block___23 *);
	int (*thaw_super)(struct super_block___23 *);
	int (*unfreeze_fs)(struct super_block___23 *);
	int (*statfs)(struct dentry___23 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___23 *, int *, char *);
	void (*umount_begin)(struct super_block___23 *);
	int (*show_options)(struct seq_file___23 *, struct dentry___23 *);
	int (*show_devname)(struct seq_file___23 *, struct dentry___23 *);
	int (*show_path)(struct seq_file___23 *, struct dentry___23 *);
	int (*show_stats)(struct seq_file___23 *, struct dentry___23 *);
	ssize_t (*quota_read)(struct super_block___23 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___23 *, int, const char *, size_t, loff_t);
	struct dquot___22 ** (*get_dquots)(struct inode___24 *);
	long int (*nr_cached_objects)(struct super_block___23 *, struct shrink_control___6 *);
	long int (*free_cached_objects)(struct super_block___23 *, struct shrink_control___6 *);
	struct file___23 * (*real_loop)(struct file___23 *);
};

typedef void (*poll_queue_proc___16)(struct file___23 *, wait_queue_head_t *, struct poll_table_struct___16 *);

struct poll_table_struct___16 {
	poll_queue_proc___16 _qproc;
	__poll_t _key;
};

struct seq_operations___21;

struct seq_file___23 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___21 *op;
	int poll_event;
	const struct file___23 *file;
	void *private;
};

struct irq_desc___11;

typedef void (*irq_flow_handler_t___11)(struct irq_desc___11 *);

struct msi_desc___3;

struct irq_common_data___3 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___3 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___10;

struct irq_domain___10;

struct irq_data___10 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___3 *common;
	struct irq_chip___10 *chip;
	struct irq_domain___10 *domain;
	struct irq_data___10 *parent_data;
	void *chip_data;
};

struct irqaction___9;

struct irq_desc___11 {
	struct irq_common_data___3 irq_common_data;
	struct irq_data___10 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___11 handle_irq;
	struct irqaction___9 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___22 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___24 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___19;

struct device___19;

struct fwnode_handle___19 {
	struct fwnode_handle___19 *secondary;
	const struct fwnode_operations___19 *ops;
	struct device___19 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___19;

struct fwnode_endpoint___19;

struct fwnode_operations___19 {
	struct fwnode_handle___19 * (*get)(struct fwnode_handle___19 *);
	void (*put)(struct fwnode_handle___19 *);
	bool (*device_is_available)(const struct fwnode_handle___19 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___19 *, const struct device___19 *);
	bool (*property_present)(const struct fwnode_handle___19 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___19 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___19 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___19 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_parent)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_next_child_node)(const struct fwnode_handle___19 *, struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*get_named_child_node)(const struct fwnode_handle___19 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___19 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___19 *);
	struct fwnode_handle___19 * (*graph_get_next_endpoint)(const struct fwnode_handle___19 *, struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*graph_get_remote_endpoint)(const struct fwnode_handle___19 *);
	struct fwnode_handle___19 * (*graph_get_port_parent)(struct fwnode_handle___19 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___19 *, struct fwnode_endpoint___19 *);
	int (*add_links)(struct fwnode_handle___19 *);
};

struct wakeup_source___19;

struct dev_pm_info___19 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___19 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___19 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___19;

struct bus_type___19;

struct device_driver___19;

struct dev_pm_domain___19;

struct device_node___13;

struct class___19;

struct attribute_group___22;

struct device___19 {
	struct kobject___22 kobj;
	struct device___19 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___19 *type;
	struct bus_type___19 *bus;
	struct device_driver___19 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___19 power;
	struct dev_pm_domain___19 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___10 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___13 *of_node;
	struct fwnode_handle___19 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___19 *class;
	const struct attribute_group___22 **groups;
	void (*release)(struct device___19 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___19 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___19 *local_fwnode;
};

struct fwnode_reference_args___19 {
	struct fwnode_handle___19 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msi_desc___3 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___19 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___3 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___10 {
	struct device___19 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___10 *);
	void (*irq_shutdown)(struct irq_data___10 *);
	void (*irq_enable)(struct irq_data___10 *);
	void (*irq_disable)(struct irq_data___10 *);
	void (*irq_ack)(struct irq_data___10 *);
	void (*irq_mask)(struct irq_data___10 *);
	void (*irq_mask_ack)(struct irq_data___10 *);
	void (*irq_unmask)(struct irq_data___10 *);
	void (*irq_eoi)(struct irq_data___10 *);
	int (*irq_set_affinity)(struct irq_data___10 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___10 *);
	int (*irq_set_type)(struct irq_data___10 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___10 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___10 *);
	void (*irq_bus_sync_unlock)(struct irq_data___10 *);
	void (*irq_cpu_online)(struct irq_data___10 *);
	void (*irq_cpu_offline)(struct irq_data___10 *);
	void (*irq_suspend)(struct irq_data___10 *);
	void (*irq_resume)(struct irq_data___10 *);
	void (*irq_pm_shutdown)(struct irq_data___10 *);
	void (*irq_calc_mask)(struct irq_data___10 *);
	void (*irq_print_chip)(struct irq_data___10 *, struct seq_file___23 *);
	int (*irq_request_resources)(struct irq_data___10 *);
	void (*irq_release_resources)(struct irq_data___10 *);
	void (*irq_compose_msi_msg)(struct irq_data___10 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___10 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___10 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___10 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___10 *, void *);
	void (*ipi_send_single)(struct irq_data___10 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___10 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___10 *);
	void (*irq_nmi_teardown)(struct irq_data___10 *);
	long unsigned int flags;
};

struct irq_domain_ops___10;

struct irq_domain_chip_generic___10;

struct irq_domain___10 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___10 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___19 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___10 *gc;
	struct irq_domain___10 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___10 *revmap[0];
};

struct kernfs_root___22;

struct kernfs_elem_dir___22 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___22 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___22;

struct kernfs_root___22 {
	struct kernfs_node___22 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___22 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___22 {
	struct kernfs_node___22 *target_kn;
};

struct kernfs_ops___22;

struct kernfs_elem_attr___22 {
	const struct kernfs_ops___22 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___22 *notify_next;
};

struct kernfs_node___22 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___22 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___22 dir;
		struct kernfs_elem_symlink___22 symlink;
		struct kernfs_elem_attr___22 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___22;

struct kernfs_ops___22 {
	int (*open)(struct kernfs_open_file___22 *);
	void (*release)(struct kernfs_open_file___22 *);
	int (*seq_show)(struct seq_file___23 *, void *);
	void * (*seq_start)(struct seq_file___23 *, loff_t *);
	void * (*seq_next)(struct seq_file___23 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___23 *, void *);
	ssize_t (*read)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___22 *, struct poll_table_struct___16 *);
	int (*mmap)(struct kernfs_open_file___22 *, struct vm_area_struct___22 *);
};

struct kernfs_syscall_ops___22 {
	int (*show_options)(struct seq_file___23 *, struct kernfs_root___22 *);
	int (*mkdir)(struct kernfs_node___22 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___22 *);
	int (*rename)(struct kernfs_node___22 *, struct kernfs_node___22 *, const char *);
	int (*show_path)(struct seq_file___23 *, struct kernfs_node___22 *, struct kernfs_root___22 *);
};

struct kernfs_open_file___22 {
	struct kernfs_node___22 *kn;
	struct file___23 *file;
	struct seq_file___23 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___22 *vm_ops;
};

struct bin_attribute___22;

struct attribute_group___22 {
	const char *name;
	umode_t (*is_visible)(struct kobject___22 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___22 *, struct bin_attribute___22 *, int);
	struct attribute **attrs;
	struct bin_attribute___22 **bin_attrs;
};

struct bin_attribute___22 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___22 * (*f_mapping)();
	ssize_t (*read)(struct file___23 *, struct kobject___22 *, struct bin_attribute___22 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___23 *, struct kobject___22 *, struct bin_attribute___22 *, char *, loff_t, size_t);
	int (*mmap)(struct file___23 *, struct kobject___22 *, struct bin_attribute___22 *, struct vm_area_struct___22 *);
};

struct sysfs_ops___22 {
	ssize_t (*show)(struct kobject___22 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___22 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___22;

struct kset___22 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___22 kobj;
	const struct kset_uevent_ops___22 *uevent_ops;
};

struct kobj_type___22 {
	void (*release)(struct kobject___22 *);
	const struct sysfs_ops___22 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___22 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___22 *);
	const void * (*namespace)(struct kobject___22 *);
	void (*get_ownership)(struct kobject___22 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___22 {
	int (* const filter)(struct kset___22 *, struct kobject___22 *);
	const char * (* const name)(struct kset___22 *, struct kobject___22 *);
	int (* const uevent)(struct kset___22 *, struct kobject___22 *, struct kobj_uevent_env *);
};

struct irqaction___9 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___9 *next;
	irq_handler_t thread_fn;
	struct task_struct___24 *thread;
	struct irqaction___9 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___10 {
	struct irq_chip___10 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___11 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___10 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___10 *);
	void (*resume)(struct irq_chip_generic___10 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___10 *domain;
	struct list_head list;
	struct irq_chip_type___10 chip_types[0];
};

struct irq_domain_chip_generic___10 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___10 *gc[0];
};

struct mmu_notifier___4;

struct mmu_notifier_range___4;

struct mmu_notifier_ops___4 {
	void (*release)(struct mmu_notifier___4 *, struct mm_struct___23 *);
	int (*clear_flush_young)(struct mmu_notifier___4 *, struct mm_struct___23 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___4 *, struct mm_struct___23 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___4 *, struct mm_struct___23 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___4 *, struct mm_struct___23 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___4 *, const struct mmu_notifier_range___4 *);
	void (*invalidate_range_end)(struct mmu_notifier___4 *, const struct mmu_notifier_range___4 *);
	void (*invalidate_range)(struct mmu_notifier___4 *, struct mm_struct___23 *, long unsigned int, long unsigned int);
	struct mmu_notifier___4 * (*alloc_notifier)(struct mm_struct___23 *);
	void (*free_notifier)(struct mmu_notifier___4 *);
};

struct mmu_notifier___4 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___4 *ops;
	struct mm_struct___23 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___4 {
	struct vm_area_struct___22 *vma;
	struct mm_struct___23 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct kernel_param_ops___22 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___22 *);
	int (*get)(char *, const struct kernel_param___22 *);
	void (*free)(void *);
};

struct kparam_array___22;

struct kernel_param___22 {
	const char *name;
	struct module___24 *mod;
	const struct kernel_param_ops___22 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___22 *arr;
	};
};

struct kparam_array___22 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___22 *ops;
	void *elem;
};

struct module_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___22 *, struct module_kobject___22 *, char *);
	ssize_t (*store)(struct module_attribute___22 *, struct module_kobject___22 *, const char *, size_t);
	void (*setup)(struct module___24 *, const char *);
	int (*test)(struct module___24 *);
	void (*free)(struct module___24 *);
};

struct cgroup_namespace___15 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___15 *root_cset;
};

struct kvm_vcpu___5;

struct kvm_io_device___4;

struct kvm_io_device_ops___4 {
	int (*read)(struct kvm_vcpu___5 *, struct kvm_io_device___4 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___5 *, struct kvm_io_device___4 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___4 *);
};

struct kvm_cpu_context___4 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___5 *__hyp_running_vcpu;
	long: 64;
};

struct its_vm___4;

struct its_vpe___4 {
	struct page___23 *vpt_page;
	struct its_vm___4 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___19 *fwnode;
			struct irq_domain___10 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct vgic_v3_cpu_if___4 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___4 its_vpe;
	unsigned int used_lrs;
};

struct vgic_irq___4 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___5 *vcpu;
	struct kvm_vcpu___5 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___4 {
	const struct kvm_io_device_ops___4 *ops;
};

struct vgic_its___5;

struct vgic_io_device___4 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___5 *redist_vcpu;
		struct vgic_its___5 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___4 dev;
};

struct vgic_cpu___4 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___4 vgic_v3;
	};
	struct vgic_irq___4 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___4 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___4 {
	struct kvm_vcpu___5 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___4 {
	struct arch_timer_context___4 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___4 {
	u8 idx;
	struct perf_event___13 *perf_event;
};

struct kvm_pmu___4 {
	int irq_num;
	struct kvm_pmc___4 pmc[32];
	long unsigned int chained[1];
	bool created;
	bool irq_level;
	struct irq_work overflow_work;
};

struct kvm_s2_mmu___4;

struct kvm_vcpu_arch___4 {
	struct kvm_cpu_context___4 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___4 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___4 vgic_cpu;
	struct arch_timer_cpu___4 timer_cpu;
	struct kvm_pmu___4 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___5;

struct kvm_vcpu___5 {
	struct kvm___5 *kvm;
	struct preempt_notifier___4 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___22 wait;
	struct pid___21 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___4 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct its_vm___4 {
	struct fwnode_handle___19 *fwnode;
	struct irq_domain___10 *domain;
	struct page___23 *vprop_page;
	struct its_vpe___4 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___4;

struct vgic_its___5 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___4 iodev;
	struct kvm_device___4 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___4;

struct kvm_device___4 {
	const struct kvm_device_ops___4 *ops;
	struct kvm___5 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___4 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___4 *spis;
	struct vgic_io_device___4 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___4 its_vm;
};

struct property___11 {
	char *name;
	int length;
	void *value;
	struct property___11 *next;
	long unsigned int _flags;
	struct bin_attribute___22 attr;
};

struct device_node___13 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___19 fwnode;
	struct property___11 *properties;
	struct property___11 *deadprops;
	struct device_node___13 *parent;
	struct device_node___13 *child;
	struct device_node___13 *sibling;
	struct kobject___22 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___19 {
	int (*prepare)(struct device___19 *);
	void (*complete)(struct device___19 *);
	int (*suspend)(struct device___19 *);
	int (*resume)(struct device___19 *);
	int (*freeze)(struct device___19 *);
	int (*thaw)(struct device___19 *);
	int (*poweroff)(struct device___19 *);
	int (*restore)(struct device___19 *);
	int (*suspend_late)(struct device___19 *);
	int (*resume_early)(struct device___19 *);
	int (*freeze_late)(struct device___19 *);
	int (*thaw_early)(struct device___19 *);
	int (*poweroff_late)(struct device___19 *);
	int (*restore_early)(struct device___19 *);
	int (*suspend_noirq)(struct device___19 *);
	int (*resume_noirq)(struct device___19 *);
	int (*freeze_noirq)(struct device___19 *);
	int (*thaw_noirq)(struct device___19 *);
	int (*poweroff_noirq)(struct device___19 *);
	int (*restore_noirq)(struct device___19 *);
	int (*runtime_suspend)(struct device___19 *);
	int (*runtime_resume)(struct device___19 *);
	int (*runtime_idle)(struct device___19 *);
};

struct wakeup_source___19 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___19 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___19 {
	struct dev_pm_ops___19 ops;
	int (*start)(struct device___19 *);
	void (*detach)(struct device___19 *, bool);
	int (*activate)(struct device___19 *);
	void (*sync)(struct device___19 *);
	void (*dismiss)(struct device___19 *);
};

struct bus_type___19 {
	const char *name;
	const char *dev_name;
	struct device___19 *dev_root;
	const struct attribute_group___22 **bus_groups;
	const struct attribute_group___22 **dev_groups;
	const struct attribute_group___22 **drv_groups;
	int (*match)(struct device___19 *, struct device_driver___19 *);
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	int (*probe)(struct device___19 *);
	void (*sync_state)(struct device___19 *);
	void (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*online)(struct device___19 *);
	int (*offline)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	int (*num_vf)(struct device___19 *);
	int (*dma_configure)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___19 {
	const char *name;
	struct bus_type___19 *bus;
	struct module___24 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___19 *);
	void (*sync_state)(struct device___19 *);
	int (*remove)(struct device___19 *);
	void (*shutdown)(struct device___19 *);
	int (*suspend)(struct device___19 *, pm_message_t);
	int (*resume)(struct device___19 *);
	const struct attribute_group___22 **groups;
	const struct attribute_group___22 **dev_groups;
	const struct dev_pm_ops___19 *pm;
	void (*coredump)(struct device___19 *);
	struct driver_private *p;
};

struct device_type___19 {
	const char *name;
	const struct attribute_group___22 **groups;
	int (*uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___19 *);
	const struct dev_pm_ops___19 *pm;
};

struct class___19 {
	const char *name;
	struct module___24 *owner;
	const struct attribute_group___22 **class_groups;
	const struct attribute_group___22 **dev_groups;
	struct kobject___22 *dev_kobj;
	int (*dev_uevent)(struct device___19 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___19 *, umode_t *);
	void (*class_release)(struct class___19 *);
	void (*dev_release)(struct device___19 *);
	int (*shutdown_pre)(struct device___19 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___19 *);
	void (*get_ownership)(struct device___19 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___19 *pm;
	struct subsys_private *p;
};

struct seq_operations___21 {
	void * (*start)(struct seq_file___23 *, loff_t *);
	void (*stop)(struct seq_file___23 *, void *);
	void * (*next)(struct seq_file___23 *, void *, loff_t *);
	int (*show)(struct seq_file___23 *, void *);
};

struct cftype___15;

struct cgroup_subsys___15 {
	struct cgroup_subsys_state___15 * (*css_alloc)(struct cgroup_subsys_state___15 *);
	int (*css_online)(struct cgroup_subsys_state___15 *);
	void (*css_offline)(struct cgroup_subsys_state___15 *);
	void (*css_released)(struct cgroup_subsys_state___15 *);
	void (*css_free)(struct cgroup_subsys_state___15 *);
	void (*css_reset)(struct cgroup_subsys_state___15 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___15 *, int);
	int (*css_extra_stat_show)(struct seq_file___23 *, struct cgroup_subsys_state___15 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___24 *, struct css_set___15 *);
	void (*cancel_fork)(struct task_struct___24 *, struct css_set___15 *);
	void (*fork)(struct task_struct___24 *);
	void (*exit)(struct task_struct___24 *);
	void (*release)(struct task_struct___24 *);
	void (*bind)(struct cgroup_subsys_state___15 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___15 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___15 *dfl_cftypes;
	struct cftype___15 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___15 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___15 *updated_children;
	struct cgroup___15 *updated_next;
};

struct cgroup_root___15 {
	struct kernfs_root___22 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___15 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___15 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___15 *ss;
	struct list_head node;
	struct kernfs_ops___22 *kf_ops;
	int (*open)(struct kernfs_open_file___22 *);
	void (*release)(struct kernfs_open_file___22 *);
	u64 (*read_u64)(struct cgroup_subsys_state___15 *, struct cftype___15 *);
	s64 (*read_s64)(struct cgroup_subsys_state___15 *, struct cftype___15 *);
	int (*seq_show)(struct seq_file___23 *, void *);
	void * (*seq_start)(struct seq_file___23 *, loff_t *);
	void * (*seq_next)(struct seq_file___23 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___23 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___15 *, struct cftype___15 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___15 *, struct cftype___15 *, s64);
	ssize_t (*write)(struct kernfs_open_file___22 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___22 *, struct poll_table_struct___16 *);
};

struct perf_cpu_context___13;

struct perf_output_handle___13;

struct pmu___13 {
	struct list_head entry;
	struct module___24 *module;
	struct device___19 *dev;
	const struct attribute_group___22 **attr_groups;
	const struct attribute_group___22 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___13 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___13 *);
	void (*pmu_disable)(struct pmu___13 *);
	int (*event_init)(struct perf_event___13 *);
	void (*event_mapped)(struct perf_event___13 *, struct mm_struct___23 *);
	void (*event_unmapped)(struct perf_event___13 *, struct mm_struct___23 *);
	int (*add)(struct perf_event___13 *, int);
	void (*del)(struct perf_event___13 *, int);
	void (*start)(struct perf_event___13 *, int);
	void (*stop)(struct perf_event___13 *, int);
	void (*read)(struct perf_event___13 *);
	void (*start_txn)(struct pmu___13 *, unsigned int);
	int (*commit_txn)(struct pmu___13 *);
	void (*cancel_txn)(struct pmu___13 *);
	int (*event_idx)(struct perf_event___13 *);
	void (*sched_task)(struct perf_event_context___13 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___13 *, struct perf_event_context___13 *);
	void * (*setup_aux)(struct perf_event___13 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___13 *, struct perf_output_handle___13 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___13 *);
	int (*aux_output_match)(struct perf_event___13 *);
	int (*filter_match)(struct perf_event___13 *);
	int (*check_period)(struct perf_event___13 *, u64);
};

struct perf_cpu_context___13 {
	struct perf_event_context___13 ctx;
	struct perf_event_context___13 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___13 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___13 **heap;
	struct perf_event___13 *heap_default[2];
};

struct perf_output_handle___13 {
	struct perf_event___13 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___13 {
	struct cgroup_subsys_state___15 css;
	struct perf_cgroup_info *info;
};

struct kvm_pgtable___2;

struct kvm_arch___4;

struct kvm_s2_mmu___4 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable___2 *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___4 *arch;
};

struct kvm_pgtable___2 {
	u32 ia_bits;
	u32 start_level;
	kvm_pte_t *pgd;
	struct kvm_pgtable_mm_ops *mm_ops;
	struct kvm_s2_mmu___4 *mmu;
	enum kvm_pgtable_stage2_flags flags;
	kvm_pgtable_force_pte_cb_t force_pte_cb;
};

struct kvm_arch___4 {
	struct kvm_s2_mmu___4 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___4 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___4 {
	gpa_t addr;
	int len;
	struct kvm_io_device___4 *dev;
};

struct kvm_io_bus___4 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___4 range[0];
};

struct kvm_stat_data___4;

struct kvm___5 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___23 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___5 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___22 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___4 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___4 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___4 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___23 *debugfs_dentry;
	struct kvm_stat_data___4 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___4 {
	struct kvm___5 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___4 {
	const char *name;
	int (*create)(struct kvm_device___4 *, u32);
	void (*init)(struct kvm_device___4 *);
	void (*destroy)(struct kvm_device___4 *);
	void (*release)(struct kvm_device___4 *);
	int (*set_attr)(struct kvm_device___4 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___4 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___4 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___4 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___4 *, struct vm_area_struct___22 *);
};

struct hstate___3;

struct hugepage_subpool {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___3 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___3 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___15 cgroup_files_dfl[7];
	struct cftype___15 cgroup_files_legacy[9];
	char name[32];
};

struct hugetlbfs_sb_info {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___3 *hstate;
	struct hugepage_subpool *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct irq_fwspec___10 {
	struct fwnode_handle___19 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___10 {
	int (*match)(struct irq_domain___10 *, struct device_node___13 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___10 *, struct irq_fwspec___10 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___10 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___10 *, unsigned int);
	int (*xlate)(struct irq_domain___10 *, struct device_node___13 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___10 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___10 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___10 *, struct irq_data___10 *, bool);
	void (*deactivate)(struct irq_domain___10 *, struct irq_data___10 *);
	int (*translate)(struct irq_domain___10 *, struct irq_fwspec___10 *, long unsigned int *, unsigned int *);
};

enum clocksource_ids {
	CSID_GENERIC = 0,
	CSID_ARM_ARCH_COUNTER = 1,
	CSID_MAX = 2,
};

struct system_time_snapshot {
	u64 cycles;
	ktime_t real;
	ktime_t raw;
	enum clocksource_ids cs_id;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
};

struct kvm_vcpu___6;

struct kvm_io_device___5;

struct kvm_io_device_ops___5 {
	int (*read)(struct kvm_vcpu___6 *, struct kvm_io_device___5 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___6 *, struct kvm_io_device___5 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___5 *);
};

struct kvm_cpu_context___5 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___6 *__hyp_running_vcpu;
	long: 64;
};

struct vgic_irq___5 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___6 *vcpu;
	struct kvm_vcpu___6 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___5 {
	const struct kvm_io_device_ops___5 *ops;
};

struct vgic_its___6;

struct vgic_io_device___5 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___6 *redist_vcpu;
		struct vgic_its___6 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___5 dev;
};

struct vgic_cpu___5 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___3 vgic_v3;
	};
	struct vgic_irq___5 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___5 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___5 {
	struct kvm_vcpu___6 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___5 {
	struct arch_timer_context___5 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_s2_mmu___5;

struct kvm_vcpu_arch___5 {
	struct kvm_cpu_context___5 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___5 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___5 vgic_cpu;
	struct arch_timer_cpu___5 timer_cpu;
	struct kvm_pmu___3 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___6;

struct kvm_vcpu___6 {
	struct kvm___6 *kvm;
	struct preempt_notifier___3 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___21 wait;
	struct pid___20 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___5 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct kvm_device___5;

struct vgic_its___6 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___5 iodev;
	struct kvm_device___5 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___5;

struct kvm_device___5 {
	const struct kvm_device_ops___5 *ops;
	struct kvm___6 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___5 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___5 *spis;
	struct vgic_io_device___5 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___3 its_vm;
};

struct kvm_pgtable___3;

struct kvm_arch___5;

struct kvm_s2_mmu___5 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable___3 *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___5 *arch;
};

struct kvm_pgtable___3 {
	u32 ia_bits;
	u32 start_level;
	kvm_pte_t *pgd;
	struct kvm_pgtable_mm_ops *mm_ops;
	struct kvm_s2_mmu___5 *mmu;
	enum kvm_pgtable_stage2_flags flags;
	kvm_pgtable_force_pte_cb_t force_pte_cb;
};

struct kvm_arch___5 {
	struct kvm_s2_mmu___5 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___5 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___5 {
	gpa_t addr;
	int len;
	struct kvm_io_device___5 *dev;
};

struct kvm_io_bus___5 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___5 range[0];
};

struct kvm_stat_data___5;

struct kvm___6 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___22 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___6 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___21 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___5 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___5 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___3 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___22 *debugfs_dentry;
	struct kvm_stat_data___5 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___5 {
	struct kvm___6 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___5 {
	const char *name;
	int (*create)(struct kvm_device___5 *, u32);
	void (*init)(struct kvm_device___5 *);
	void (*destroy)(struct kvm_device___5 *);
	void (*release)(struct kvm_device___5 *);
	int (*set_attr)(struct kvm_device___5 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___5 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___5 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___5 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___5 *, struct vm_area_struct___21 *);
};

struct sys_reg_params {
	u8 Op0;
	u8 Op1;
	u8 CRn;
	u8 CRm;
	u8 Op2;
	u64 regval;
	bool is_write;
};

struct sys_reg_desc {
	const char *name;
	enum {
		AA32_ZEROHIGH = 0,
		AA32_LO = 1,
		AA32_HI = 2,
	} aarch32_map;
	u8 Op0;
	u8 Op1;
	u8 CRn;
	u8 CRm;
	u8 Op2;
	bool (*access)(struct kvm_vcpu___6 *, struct sys_reg_params *, const struct sys_reg_desc *);
	void (*reset)(struct kvm_vcpu___6 *, const struct sys_reg_desc *);
	int reg;
	u64 val;
	int (*__get_user)(struct kvm_vcpu___6 *, const struct sys_reg_desc *, const struct kvm_one_reg *, void *);
	int (*set_user)(struct kvm_vcpu___6 *, const struct sys_reg_desc *, const struct kvm_one_reg *, void *);
	unsigned int (*visibility)(const struct kvm_vcpu___6 *, const struct sys_reg_desc *);
};

struct trace_event_raw_kvm_wfx_arm64 {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool is_wfe;
	char __data[0];
};

struct trace_event_raw_kvm_hvc_arm64 {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	long unsigned int r0;
	long unsigned int imm;
	char __data[0];
};

struct trace_event_raw_kvm_arm_setup_debug {
	struct trace_entry ent;
	struct kvm_vcpu___6 *vcpu;
	__u32 guest_debug;
	char __data[0];
};

struct trace_event_raw_kvm_arm_clear_debug {
	struct trace_entry ent;
	__u32 guest_debug;
	char __data[0];
};

struct trace_event_raw_kvm_arm_set_dreg32 {
	struct trace_entry ent;
	const char *name;
	__u64 value;
	char __data[0];
};

struct trace_event_raw_kvm_arm_set_regset {
	struct trace_entry ent;
	const char *name;
	int len;
	u64 ctrls[16];
	u64 values[16];
	char __data[0];
};

struct trace_event_raw_trap_reg {
	struct trace_entry ent;
	const char *fn;
	int reg;
	bool is_write;
	u64 write_value;
	char __data[0];
};

struct trace_event_raw_kvm_handle_sys_reg {
	struct trace_entry ent;
	long unsigned int hsr;
	char __data[0];
};

struct trace_event_raw_kvm_sys_access {
	struct trace_entry ent;
	long unsigned int vcpu_pc;
	bool is_write;
	const char *name;
	u8 Op0;
	u8 Op1;
	u8 CRn;
	u8 CRm;
	u8 Op2;
	char __data[0];
};

struct trace_event_raw_kvm_set_guest_debug {
	struct trace_entry ent;
	struct kvm_vcpu___6 *vcpu;
	__u32 guest_debug;
	char __data[0];
};

struct trace_event_data_offsets_kvm_wfx_arm64 {};

struct trace_event_data_offsets_kvm_hvc_arm64 {};

struct trace_event_data_offsets_kvm_arm_setup_debug {};

struct trace_event_data_offsets_kvm_arm_clear_debug {};

struct trace_event_data_offsets_kvm_arm_set_dreg32 {};

struct trace_event_data_offsets_kvm_arm_set_regset {};

struct trace_event_data_offsets_trap_reg {};

struct trace_event_data_offsets_kvm_handle_sys_reg {};

struct trace_event_data_offsets_kvm_sys_access {};

struct trace_event_data_offsets_kvm_set_guest_debug {};

typedef void (*btf_trace_kvm_wfx_arm64)(void *, long unsigned int, bool);

typedef void (*btf_trace_kvm_hvc_arm64)(void *, long unsigned int, long unsigned int, long unsigned int);

typedef void (*btf_trace_kvm_arm_setup_debug)(void *, struct kvm_vcpu___6 *, __u32);

typedef void (*btf_trace_kvm_arm_clear_debug)(void *, __u32);

typedef void (*btf_trace_kvm_arm_set_dreg32)(void *, const char *, __u64);

typedef void (*btf_trace_kvm_arm_set_regset)(void *, const char *, int, __u64 *, __u64 *);

typedef void (*btf_trace_trap_reg)(void *, const char *, int, bool, u64);

typedef void (*btf_trace_kvm_handle_sys_reg)(void *, long unsigned int);

typedef void (*btf_trace_kvm_sys_access)(void *, long unsigned int, struct sys_reg_params *, const struct sys_reg_desc *);

typedef void (*btf_trace_kvm_set_guest_debug)(void *, struct kvm_vcpu___6 *, __u32);

typedef int (*exit_handle_fn)(struct kvm_vcpu___6 *);

struct sve_state_reg_region {
	unsigned int koffset;
	unsigned int klen;
	unsigned int upad;
};

struct va_format {
	const char *fmt;
	va_list *va;
};

enum kvm_arch_timer_regs {
	TIMER_REG_CNT = 0,
	TIMER_REG_CVAL = 1,
	TIMER_REG_TVAL = 2,
	TIMER_REG_CTL = 3,
};

struct vgic_vmcr {
	u32 grpen0;
	u32 grpen1;
	u32 ackctl;
	u32 fiqen;
	u32 cbpr;
	u32 eoim;
	u32 abpr;
	u32 bpr;
	u32 pmr;
};

struct kvm_host_data___2 {
	struct kvm_cpu_context___5 host_ctxt;
	struct kvm_pmu_events pmu_events;
	long: 64;
};

struct cyclecounter {
	u64 (*read)(const struct cyclecounter *);
	u64 mask;
	u32 mult;
	u32 shift;
};

struct timecounter {
	const struct cyclecounter *cc;
	u64 cycle_last;
	u64 nsec;
	u64 mask;
	u64 frac;
};

struct arch_timer_kvm_info {
	struct timecounter timecounter;
	int virtual_irq;
	int physical_irq;
};

enum hrtimer_mode {
	HRTIMER_MODE_ABS = 0,
	HRTIMER_MODE_REL = 1,
	HRTIMER_MODE_PINNED = 2,
	HRTIMER_MODE_SOFT = 4,
	HRTIMER_MODE_HARD = 8,
	HRTIMER_MODE_ABS_PINNED = 2,
	HRTIMER_MODE_REL_PINNED = 3,
	HRTIMER_MODE_ABS_SOFT = 4,
	HRTIMER_MODE_REL_SOFT = 5,
	HRTIMER_MODE_ABS_PINNED_SOFT = 6,
	HRTIMER_MODE_REL_PINNED_SOFT = 7,
	HRTIMER_MODE_ABS_HARD = 8,
	HRTIMER_MODE_REL_HARD = 9,
	HRTIMER_MODE_ABS_PINNED_HARD = 10,
	HRTIMER_MODE_REL_PINNED_HARD = 11,
};

struct timer_map___2 {
	struct arch_timer_context___4 *direct_vtimer;
	struct arch_timer_context___4 *direct_ptimer;
	struct arch_timer_context___4 *emul_ptimer;
};

enum {
	IRQCHIP_FWNODE_REAL = 0,
	IRQCHIP_FWNODE_NAMED = 1,
	IRQCHIP_FWNODE_NAMED_ID = 2,
};

typedef int (*list_cmp_func_t)(void *, const struct list_head *, const struct list_head *);

struct trace_event_raw_vgic_update_irq_pending {
	struct trace_entry ent;
	long unsigned int vcpu_id;
	__u32 irq;
	bool level;
	char __data[0];
};

struct trace_event_data_offsets_vgic_update_irq_pending {};

typedef void (*btf_trace_vgic_update_irq_pending)(void *, long unsigned int, __u32, bool);

enum gic_type {
	GIC_V2 = 0,
	GIC_V3 = 1,
};

struct gic_kvm_info {
	enum gic_type type;
	struct resource vcpu;
	unsigned int maint_irq;
	bool no_maint_irq_mask;
	struct resource vctrl;
	bool has_v4;
	bool has_v4_1;
	bool no_hw_deactivation;
};

struct preempt_notifier___5;

struct preempt_ops___5 {
	void (*sched_in)(struct preempt_notifier___5 *, int);
	void (*sched_out)(struct preempt_notifier___5 *, struct task_struct___15 *);
};

struct preempt_notifier___5 {
	struct hlist_node link;
	struct preempt_ops___5 *ops;
};

struct mmu_notifier___5;

struct mmu_notifier_range___5;

struct mmu_notifier_ops___5 {
	void (*release)(struct mmu_notifier___5 *, struct mm_struct___14 *);
	int (*clear_flush_young)(struct mmu_notifier___5 *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___5 *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___5 *, struct mm_struct___14 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___5 *, struct mm_struct___14 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___5 *, const struct mmu_notifier_range___5 *);
	void (*invalidate_range_end)(struct mmu_notifier___5 *, const struct mmu_notifier_range___5 *);
	void (*invalidate_range)(struct mmu_notifier___5 *, struct mm_struct___14 *, long unsigned int, long unsigned int);
	struct mmu_notifier___5 * (*alloc_notifier)(struct mm_struct___14 *);
	void (*free_notifier)(struct mmu_notifier___5 *);
};

struct mmu_notifier___5 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___5 *ops;
	struct mm_struct___14 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___5 {
	struct vm_area_struct___13 *vma;
	struct mm_struct___14 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct kvm_io_device___6;

struct kvm_io_device_ops___6 {
	int (*read)(struct kvm_vcpu___2 *, struct kvm_io_device___6 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___2 *, struct kvm_io_device___6 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___6 *);
};

struct kvm_cpu_context___6 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___2 *__hyp_running_vcpu;
	long: 64;
};

struct its_vm___5;

struct its_vpe___5 {
	struct page___14 *vpt_page;
	struct its_vm___5 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___11 *fwnode;
			struct irq_domain___6 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct vgic_v3_cpu_if___5 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___5 its_vpe;
	unsigned int used_lrs;
};

struct vgic_irq___6 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___2 *vcpu;
	struct kvm_vcpu___2 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___6 {
	const struct kvm_io_device_ops___6 *ops;
};

struct vgic_io_device___6 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___2 *redist_vcpu;
		struct vgic_its___2 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___6 dev;
};

struct vgic_cpu___6 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___5 vgic_v3;
	};
	struct vgic_irq___6 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___6 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___6 {
	struct kvm_vcpu___2 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___6 {
	struct arch_timer_context___6 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___5 {
	u8 idx;
	struct perf_event___8 *perf_event;
};

struct kvm_pmu___5 {
	int irq_num;
	struct kvm_pmc___5 pmc[32];
	long unsigned int chained[1];
	bool created;
	bool irq_level;
	struct irq_work overflow_work;
};

struct kvm_s2_mmu___6;

struct kvm_vcpu_arch___6 {
	struct kvm_cpu_context___6 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___6 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___6 vgic_cpu;
	struct arch_timer_cpu___6 timer_cpu;
	struct kvm_pmu___5 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm_vcpu___2 {
	struct kvm___2 *kvm;
	struct preempt_notifier___5 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___13 wait;
	struct pid___12 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___6 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct its_vm___5 {
	struct fwnode_handle___11 *fwnode;
	struct irq_domain___6 *domain;
	struct page___14 *vprop_page;
	struct its_vpe___5 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct its_vlpi_map {
	struct its_vm___5 *vm;
	struct its_vpe___5 *vpe;
	u32 vintid;
	u8 properties;
	bool db_enabled;
};

struct kvm_device___6;

struct vgic_its___2 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___6 iodev;
	struct kvm_device___6 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___6;

struct kvm_device___6 {
	const struct kvm_device_ops___6 *ops;
	struct kvm___2 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___6 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___6 *spis;
	struct vgic_io_device___6 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___5 its_vm;
};

struct kvm_arch___6;

struct kvm_s2_mmu___6 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___6 *arch;
};

struct kvm_arch___6 {
	struct kvm_s2_mmu___6 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___6 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___6 {
	gpa_t addr;
	int len;
	struct kvm_io_device___6 *dev;
};

struct kvm_io_bus___6 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___6 range[0];
};

struct kvm_stat_data___6;

struct kvm___2 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___14 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___2 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___13 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___6 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___6 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___5 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___14 *debugfs_dentry;
	struct kvm_stat_data___6 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_kernel_irq_routing_entry___3 {
	u32 gsi;
	u32 type;
	int (*set)(struct kvm_kernel_irq_routing_entry___3 *, struct kvm___2 *, int, int, bool);
	union {
		struct {
			unsigned int irqchip;
			unsigned int pin;
		} irqchip;
		struct {
			u32 address_lo;
			u32 address_hi;
			u32 data;
			u32 flags;
			u32 devid;
		} msi;
		struct kvm_s390_adapter_int adapter;
		struct kvm_hv_sint hv_sint;
	};
	struct hlist_node link;
};

struct kvm_stat_data___6 {
	struct kvm___2 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___6 {
	const char *name;
	int (*create)(struct kvm_device___6 *, u32);
	void (*init)(struct kvm_device___6 *);
	void (*destroy)(struct kvm_device___6 *);
	void (*release)(struct kvm_device___6 *);
	int (*set_attr)(struct kvm_device___6 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___6 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___6 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___6 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___6 *, struct vm_area_struct___13 *);
};

struct kvm_vcpu___7;

struct kvm_io_device___7;

struct kvm_io_device_ops___7 {
	int (*read)(struct kvm_vcpu___7 *, struct kvm_io_device___7 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___7 *, struct kvm_io_device___7 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___7 *);
};

struct kvm_cpu_context___7 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___7 *__hyp_running_vcpu;
	long: 64;
};

struct vgic_irq___7 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___7 *vcpu;
	struct kvm_vcpu___7 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___7 {
	const struct kvm_io_device_ops___7 *ops;
};

struct vgic_its___7;

struct vgic_register_region___2;

struct vgic_io_device___7 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___7 *redist_vcpu;
		struct vgic_its___7 *its;
	};
	const struct vgic_register_region___2 *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___7 dev;
};

struct vgic_cpu___7 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___5 vgic_v3;
	};
	struct vgic_irq___7 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___7 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___7 {
	struct kvm_vcpu___7 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___7 {
	struct arch_timer_context___7 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_s2_mmu___7;

struct kvm_vcpu_arch___7 {
	struct kvm_cpu_context___7 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___7 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___7 vgic_cpu;
	struct arch_timer_cpu___7 timer_cpu;
	struct kvm_pmu___5 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___7;

struct kvm_vcpu___7 {
	struct kvm___7 *kvm;
	struct preempt_notifier___5 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___13 wait;
	struct pid___12 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___7 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct kvm_device___7;

struct vgic_its___7 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___7 iodev;
	struct kvm_device___7 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct vgic_register_region___2 {
	unsigned int reg_offset;
	unsigned int len;
	unsigned int bits_per_irq;
	unsigned int access_flags;
	union {
		long unsigned int (*read)(struct kvm_vcpu___7 *, gpa_t, unsigned int);
		long unsigned int (*its_read)(struct kvm___7 *, struct vgic_its___7 *, gpa_t, unsigned int);
	};
	union {
		void (*write)(struct kvm_vcpu___7 *, gpa_t, unsigned int, long unsigned int);
		void (*its_write)(struct kvm___7 *, struct vgic_its___7 *, gpa_t, unsigned int, long unsigned int);
	};
	long unsigned int (*uaccess_read)(struct kvm_vcpu___7 *, gpa_t, unsigned int);
	union {
		int (*uaccess_write)(struct kvm_vcpu___7 *, gpa_t, unsigned int, long unsigned int);
		int (*uaccess_its_write)(struct kvm___7 *, struct vgic_its___7 *, gpa_t, unsigned int, long unsigned int);
	};
};

struct kvm_device_ops___7;

struct kvm_device___7 {
	const struct kvm_device_ops___7 *ops;
	struct kvm___7 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___7 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___7 *spis;
	struct vgic_io_device___7 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___5 its_vm;
};

struct kvm_arch___7;

struct kvm_s2_mmu___7 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___7 *arch;
};

struct kvm_arch___7 {
	struct kvm_s2_mmu___7 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___7 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___7 {
	gpa_t addr;
	int len;
	struct kvm_io_device___7 *dev;
};

struct kvm_io_bus___7 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___7 range[0];
};

struct kvm_stat_data___7;

struct kvm___7 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___14 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___7 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___13 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___7 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___7 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___5 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___14 *debugfs_dentry;
	struct kvm_stat_data___7 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___7 {
	struct kvm___7 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___7 {
	const char *name;
	int (*create)(struct kvm_device___7 *, u32);
	void (*init)(struct kvm_device___7 *);
	void (*destroy)(struct kvm_device___7 *);
	void (*release)(struct kvm_device___7 *);
	int (*set_attr)(struct kvm_device___7 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___7 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___7 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___7 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___7 *, struct vm_area_struct___13 *);
};

struct vgic_reg_attr {
	struct kvm_vcpu___7 *vcpu;
	gpa_t addr;
};

struct kvm_vcpu___8;

struct kvm_io_device___8;

struct kvm_io_device_ops___8 {
	int (*read)(struct kvm_vcpu___8 *, struct kvm_io_device___8 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___8 *, struct kvm_io_device___8 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___8 *);
};

struct kvm_cpu_context___8 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___8 *__hyp_running_vcpu;
	long: 64;
};

struct vgic_irq___8 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___8 *vcpu;
	struct kvm_vcpu___8 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___8 {
	const struct kvm_io_device_ops___8 *ops;
};

struct vgic_its___8;

struct vgic_register_region___3;

struct vgic_io_device___8 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___8 *redist_vcpu;
		struct vgic_its___8 *its;
	};
	const struct vgic_register_region___3 *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___8 dev;
};

struct vgic_cpu___8 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___5 vgic_v3;
	};
	struct vgic_irq___8 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___8 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___8 {
	struct kvm_vcpu___8 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___8 {
	struct arch_timer_context___8 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_s2_mmu___8;

struct kvm_vcpu_arch___8 {
	struct kvm_cpu_context___8 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___8 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___8 vgic_cpu;
	struct arch_timer_cpu___8 timer_cpu;
	struct kvm_pmu___5 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___8;

struct kvm_vcpu___8 {
	struct kvm___8 *kvm;
	struct preempt_notifier___5 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___21 wait;
	struct pid___20 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___8 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct kvm_device___8;

struct vgic_its___8 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___8 iodev;
	struct kvm_device___8 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct vgic_register_region___3 {
	unsigned int reg_offset;
	unsigned int len;
	unsigned int bits_per_irq;
	unsigned int access_flags;
	union {
		long unsigned int (*read)(struct kvm_vcpu___8 *, gpa_t, unsigned int);
		long unsigned int (*its_read)(struct kvm___8 *, struct vgic_its___8 *, gpa_t, unsigned int);
	};
	union {
		void (*write)(struct kvm_vcpu___8 *, gpa_t, unsigned int, long unsigned int);
		void (*its_write)(struct kvm___8 *, struct vgic_its___8 *, gpa_t, unsigned int, long unsigned int);
	};
	long unsigned int (*uaccess_read)(struct kvm_vcpu___8 *, gpa_t, unsigned int);
	union {
		int (*uaccess_write)(struct kvm_vcpu___8 *, gpa_t, unsigned int, long unsigned int);
		int (*uaccess_its_write)(struct kvm___8 *, struct vgic_its___8 *, gpa_t, unsigned int, long unsigned int);
	};
};

struct kvm_device_ops___8;

struct kvm_device___8 {
	const struct kvm_device_ops___8 *ops;
	struct kvm___8 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___8 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___8 *spis;
	struct vgic_io_device___8 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___5 its_vm;
};

struct kvm_pgtable___4;

struct kvm_arch___8;

struct kvm_s2_mmu___8 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable___4 *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___8 *arch;
};

struct kvm_pgtable___4 {
	u32 ia_bits;
	u32 start_level;
	kvm_pte_t *pgd;
	struct kvm_pgtable_mm_ops *mm_ops;
	struct kvm_s2_mmu___8 *mmu;
	enum kvm_pgtable_stage2_flags flags;
	kvm_pgtable_force_pte_cb_t force_pte_cb;
};

struct kvm_arch___8 {
	struct kvm_s2_mmu___8 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___8 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___8 {
	gpa_t addr;
	int len;
	struct kvm_io_device___8 *dev;
};

struct kvm_io_bus___8 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___8 range[0];
};

struct kvm_stat_data___8;

struct kvm___8 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___22 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___8 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___21 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___8 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___8 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___5 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___22 *debugfs_dentry;
	struct kvm_stat_data___8 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___8 {
	struct kvm___8 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___8 {
	const char *name;
	int (*create)(struct kvm_device___8 *, u32);
	void (*init)(struct kvm_device___8 *);
	void (*destroy)(struct kvm_device___8 *);
	void (*release)(struct kvm_device___8 *);
	int (*set_attr)(struct kvm_device___8 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___8 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___8 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___8 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___8 *, struct vm_area_struct___21 *);
};

struct vgic_reg_attr___2 {
	struct kvm_vcpu___8 *vcpu;
	gpa_t addr;
};

struct its_device {
	struct list_head dev_list;
	struct list_head itt_head;
	u32 num_eventid_bits;
	gpa_t itt_addr;
	u32 device_id;
};

struct its_collection {
	struct list_head coll_list;
	u32 collection_id;
	u32 target_addr;
};

struct its_ite {
	struct list_head ite_list;
	struct vgic_irq___8 *irq;
	struct its_collection *collection;
	u32 event_id;
};

struct vgic_translation_cache_entry {
	struct list_head entry;
	phys_addr_t db;
	u32 devid;
	u32 eventid;
	struct vgic_irq___8 *irq;
};

struct vgic_its_abi {
	int cte_esz;
	int dte_esz;
	int ite_esz;
	int (*save_tables)(struct vgic_its___8 *);
	int (*restore_tables)(struct vgic_its___8 *);
	int (*commit)(struct vgic_its___8 *);
};

typedef int (*entry_fn_t)(struct vgic_its___8 *, u32, void *, void *);

struct vgic_state_iter {
	int nr_cpus;
	int nr_spis;
	int nr_lpis;
	int dist_id;
	int vcpu_id;
	int intid;
	int lpi_idx;
	u32 *lpi_array;
};

struct kvm_pmu_event_filter {
	__u16 base_event;
	__u16 nevents;
	__u8 action;
	__u8 pad[3];
};

struct platform_device___2 {
	const char *name;
	int id;
	bool id_auto;
	struct device___19 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct arm_pmu___2;

struct pmu_hw_events___2 {
	struct perf_event___13 *events[32];
	long unsigned int used_mask[1];
	raw_spinlock_t pmu_lock;
	struct arm_pmu___2 *percpu_pmu;
	int irq;
};

struct arm_pmu___2 {
	struct pmu___13 pmu;
	cpumask_t supported_cpus;
	char *name;
	int pmuver;
	irqreturn_t (*handle_irq)(struct arm_pmu___2 *);
	void (*enable)(struct perf_event___13 *);
	void (*disable)(struct perf_event___13 *);
	int (*get_event_idx)(struct pmu_hw_events___2 *, struct perf_event___13 *);
	void (*clear_event_idx)(struct pmu_hw_events___2 *, struct perf_event___13 *);
	int (*set_event_filter)(struct hw_perf_event___13 *, struct perf_event_attr *);
	u64 (*read_counter)(struct perf_event___13 *);
	void (*write_counter)(struct perf_event___13 *, u64);
	void (*start)(struct arm_pmu___2 *);
	void (*stop)(struct arm_pmu___2 *);
	void (*reset)(void *);
	int (*map_event)(struct perf_event___13 *);
	int (*filter_match)(struct perf_event___13 *);
	int num_events;
	bool secure_access;
	long unsigned int pmceid_bitmap[1];
	long unsigned int pmceid_ext_bitmap[1];
	struct platform_device___2 *plat_device;
	struct pmu_hw_events___2 *hw_events;
	struct hlist_node node;
	struct notifier_block cpu_pm_nb;
	const struct attribute_group___22 *attr_groups[5];
	u64 reg_pmmir;
	long unsigned int acpi_cpuid;
};

struct kvm_host_data___3 {
	struct kvm_cpu_context___8 host_ctxt;
	struct kvm_pmu_events pmu_events;
	long: 64;
};

struct tlb_inv_context {
	long unsigned int flags;
	u64 tcr;
	u64 sctlr;
};

struct kvm_vcpu___9;

struct kvm_io_device___9;

struct kvm_io_device_ops___9 {
	int (*read)(struct kvm_vcpu___9 *, struct kvm_io_device___9 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___9 *, struct kvm_io_device___9 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___9 *);
};

struct kvm_cpu_context___9 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___9 *__hyp_running_vcpu;
	long: 64;
};

struct vgic_irq___9 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___9 *vcpu;
	struct kvm_vcpu___9 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___9 {
	const struct kvm_io_device_ops___9 *ops;
};

struct vgic_its___9;

struct vgic_io_device___9 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___9 *redist_vcpu;
		struct vgic_its___9 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___9 dev;
};

struct vgic_cpu___9 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___5 vgic_v3;
	};
	struct vgic_irq___9 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___9 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___9 {
	struct kvm_vcpu___9 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___9 {
	struct arch_timer_context___9 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_s2_mmu___9;

struct kvm_vcpu_arch___9 {
	struct kvm_cpu_context___9 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___9 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___9 vgic_cpu;
	struct arch_timer_cpu___9 timer_cpu;
	struct kvm_pmu___5 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___9;

struct kvm_vcpu___9 {
	struct kvm___9 *kvm;
	struct preempt_notifier___5 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___13 wait;
	struct pid___12 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___9 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct kvm_device___9;

struct vgic_its___9 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___9 iodev;
	struct kvm_device___9 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___9;

struct kvm_device___9 {
	const struct kvm_device_ops___9 *ops;
	struct kvm___9 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___9 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___9 *spis;
	struct vgic_io_device___9 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___5 its_vm;
};

struct kvm_pgtable___5;

struct kvm_arch___9;

struct kvm_s2_mmu___9 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable___5 *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___9 *arch;
};

struct kvm_pgtable___5 {
	u32 ia_bits;
	u32 start_level;
	kvm_pte_t *pgd;
	struct kvm_pgtable_mm_ops *mm_ops;
	struct kvm_s2_mmu___9 *mmu;
	enum kvm_pgtable_stage2_flags flags;
	kvm_pgtable_force_pte_cb_t force_pte_cb;
};

struct kvm_arch___9 {
	struct kvm_s2_mmu___9 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___9 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___9 {
	gpa_t addr;
	int len;
	struct kvm_io_device___9 *dev;
};

struct kvm_io_bus___9 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___9 range[0];
};

struct kvm_stat_data___9;

struct kvm___9 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___14 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___9 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___13 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___9 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___9 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___5 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___14 *debugfs_dentry;
	struct kvm_stat_data___9 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___9 {
	struct kvm___9 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___9 {
	const char *name;
	int (*create)(struct kvm_device___9 *, u32);
	void (*init)(struct kvm_device___9 *);
	void (*destroy)(struct kvm_device___9 *);
	void (*release)(struct kvm_device___9 *);
	int (*set_attr)(struct kvm_device___9 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___9 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___9 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___9 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___9 *, struct vm_area_struct___13 *);
};

enum exception_type {
	except_type_sync = 0,
	except_type_irq = 128,
	except_type_fiq = 256,
	except_type_serror = 384,
};

union hyp_spinlock {
	u32 __val;
	struct {
		u16 owner;
		u16 next;
	};
};

typedef union hyp_spinlock hyp_spinlock_t;

struct host_kvm {
	struct kvm_arch___9 arch;
	struct kvm_pgtable___5 pgt;
	struct kvm_pgtable_mm_ops mm_ops;
	hyp_spinlock_t lock;
};

struct tlb_inv_context___2 {
	u64 tcr;
};

typedef void (*hcall_t)(struct kvm_cpu_context___9 *);

struct psci_boot_args {
	atomic_t lock;
	long unsigned int pc;
	long unsigned int r0;
};

struct hyp_page {
	short unsigned int refcount;
	short unsigned int order;
};

struct hyp_pool {
	hyp_spinlock_t lock;
	struct list_head free_area[13];
	phys_addr_t range_start;
	phys_addr_t range_end;
	short unsigned int max_order;
};

enum kvm_pgtable_walk_flags {
	KVM_PGTABLE_WALK_LEAF = 1,
	KVM_PGTABLE_WALK_TABLE_PRE = 2,
	KVM_PGTABLE_WALK_TABLE_POST = 4,
};

typedef int (*kvm_pgtable_visitor_fn_t)(u64, u64, u32, kvm_pte_t *, enum kvm_pgtable_walk_flags, void * const);

struct kvm_pgtable_walker {
	const kvm_pgtable_visitor_fn_t cb;
	void * const arg;
	const enum kvm_pgtable_walk_flags flags;
};

enum pkvm_page_state {
	PKVM_PAGE_OWNED = 0,
	PKVM_PAGE_SHARED_OWNED = 0,
	PKVM_PAGE_SHARED_BORROWED = 0,
};

struct kvm_mem_range {
	u64 start;
	u64 end;
};

struct kvm_pgtable_walk_data {
	struct kvm_pgtable___5 *pgt;
	struct kvm_pgtable_walker *walker;
	u64 addr;
	u64 end;
};

struct leaf_walk_data {
	kvm_pte_t pte;
	u32 level;
};

struct hyp_map_data {
	u64 phys;
	kvm_pte_t attr;
	struct kvm_pgtable_mm_ops *mm_ops;
};

struct stage2_map_data {
	u64 phys;
	kvm_pte_t attr;
	u8 owner_id;
	kvm_pte_t *anchor;
	kvm_pte_t *childp;
	struct kvm_s2_mmu___9 *mmu;
	void *memcache;
	struct kvm_pgtable_mm_ops *mm_ops;
	bool force_pte;
};

struct stage2_attr_data {
	kvm_pte_t attr_set;
	kvm_pte_t attr_clr;
	kvm_pte_t pte;
	u32 level;
	struct kvm_pgtable_mm_ops *mm_ops;
};

typedef s8 int8_t;

typedef s16 int16_t;

typedef u16 uint16_t;

typedef u64 uint64_t;

typedef s64 int64_t;

typedef uint64_t xen_pfn_t;

typedef uint64_t xen_ulong_t;

typedef int64_t xen_long_t;

typedef struct {
	union {
		unsigned char *p;
		uint64_t q;
	};
} __guest_handle_uchar;

typedef struct {
	union {
		char *p;
		uint64_t q;
	};
} __guest_handle_char;

typedef struct {
	union {
		void *p;
		uint64_t q;
	};
} __guest_handle_void;

typedef struct {
	union {
		uint64_t *p;
		uint64_t q;
	};
} __guest_handle_uint64_t;

typedef struct {
	union {
		uint32_t *p;
		uint64_t q;
	};
} __guest_handle_uint32_t;

struct arch_vcpu_info {};

struct arch_shared_info {};

struct pvclock_vcpu_time_info {
	u32 version;
	u32 pad0;
	u64 tsc_timestamp;
	u64 system_time;
	u32 tsc_to_system_mul;
	s8 tsc_shift;
	u8 flags;
	u8 pad[2];
};

struct pvclock_wall_clock {
	u32 version;
	u32 sec;
	u32 nsec;
	u32 sec_hi;
};

typedef uint16_t domid_t;

struct multicall_entry {
	xen_ulong_t op;
	xen_long_t result;
	xen_ulong_t args[6];
};

struct vcpu_info {
	uint8_t evtchn_upcall_pending;
	uint8_t evtchn_upcall_mask;
	xen_ulong_t evtchn_pending_sel;
	struct arch_vcpu_info arch;
	struct pvclock_vcpu_time_info time;
};

struct shared_info {
	struct vcpu_info vcpu_info[1];
	xen_ulong_t evtchn_pending[64];
	xen_ulong_t evtchn_mask[64];
	struct pvclock_wall_clock wc;
	uint32_t wc_sec_hi;
	struct arch_shared_info arch;
};

struct start_info {
	char magic[32];
	long unsigned int nr_pages;
	long unsigned int shared_info;
	uint32_t flags;
	xen_pfn_t store_mfn;
	uint32_t store_evtchn;
	union {
		struct {
			xen_pfn_t mfn;
			uint32_t evtchn;
		} domU;
		struct {
			uint32_t info_off;
			uint32_t info_size;
		} dom0;
	} console;
	long unsigned int pt_base;
	long unsigned int nr_pt_frames;
	long unsigned int mfn_list;
	long unsigned int mod_start;
	long unsigned int mod_len;
	int8_t cmd_line[1024];
	long unsigned int first_p2m_pfn;
	long unsigned int nr_p2m_frames;
};

enum vdso_clock_mode {
	VDSO_CLOCKMODE_NONE = 0,
	VDSO_CLOCKMODE_ARCHTIMER = 1,
	VDSO_CLOCKMODE_ARCHTIMER_NOCOMPAT = 2,
	VDSO_CLOCKMODE_MAX = 3,
	VDSO_CLOCKMODE_TIMENS = 2147483647,
};

struct clocksource {
	u64 (*read)(struct clocksource *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	u32 uncertainty_margin;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	enum clocksource_ids id;
	enum vdso_clock_mode vdso_clock_mode;
	long unsigned int flags;
	int (*enable)(struct clocksource *);
	void (*disable)(struct clocksource *);
	void (*suspend)(struct clocksource *);
	void (*resume)(struct clocksource *);
	void (*mark_unstable)(struct clocksource *);
	void (*tick_stable)(struct clocksource *);
	struct module *owner;
};

struct irq_desc___12;

typedef void (*irq_flow_handler_t___12)(struct irq_desc___12 *);

struct msi_desc___4;

struct irq_common_data___4 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___4 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___11;

struct irq_domain___11;

struct irq_data___11 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___11 *chip;
	struct irq_domain___11 *domain;
	struct irq_data___11 *parent_data;
	void *chip_data;
};

struct irq_desc___12 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___11 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___12 handle_irq;
	struct irqaction *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___20;

struct device___20;

struct fwnode_handle___20 {
	struct fwnode_handle___20 *secondary;
	const struct fwnode_operations___20 *ops;
	struct device___20 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___20;

struct fwnode_endpoint___20;

struct fwnode_operations___20 {
	struct fwnode_handle___20 * (*get)(struct fwnode_handle___20 *);
	void (*put)(struct fwnode_handle___20 *);
	bool (*device_is_available)(const struct fwnode_handle___20 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___20 *, const struct device___20 *);
	bool (*property_present)(const struct fwnode_handle___20 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___20 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___20 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___20 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_parent)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_next_child_node)(const struct fwnode_handle___20 *, struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*get_named_child_node)(const struct fwnode_handle___20 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___20 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___20 *);
	struct fwnode_handle___20 * (*graph_get_next_endpoint)(const struct fwnode_handle___20 *, struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*graph_get_remote_endpoint)(const struct fwnode_handle___20 *);
	struct fwnode_handle___20 * (*graph_get_port_parent)(struct fwnode_handle___20 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___20 *, struct fwnode_endpoint___20 *);
	int (*add_links)(struct fwnode_handle___20 *);
};

struct wakeup_source___20;

struct dev_pm_qos___4;

struct dev_pm_info___20 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___20 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___20 *, s32);
	struct dev_pm_qos___4 *qos;
};

struct device_type___20;

struct bus_type___20;

struct device_driver___20;

struct dev_pm_domain___20;

struct device_node___14;

struct class___20;

struct device___20 {
	struct kobject kobj;
	struct device___20 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___20 *type;
	struct bus_type___20 *bus;
	struct device_driver___20 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___20 power;
	struct dev_pm_domain___20 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___11 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___14 *of_node;
	struct fwnode_handle___20 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___20 *class;
	const struct attribute_group **groups;
	void (*release)(struct device___20 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___20 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___20 *local_fwnode;
};

struct fwnode_reference_args___20 {
	struct fwnode_handle___20 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msi_desc___4 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___20 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___4 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___11 {
	struct device___20 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___11 *);
	void (*irq_shutdown)(struct irq_data___11 *);
	void (*irq_enable)(struct irq_data___11 *);
	void (*irq_disable)(struct irq_data___11 *);
	void (*irq_ack)(struct irq_data___11 *);
	void (*irq_mask)(struct irq_data___11 *);
	void (*irq_mask_ack)(struct irq_data___11 *);
	void (*irq_unmask)(struct irq_data___11 *);
	void (*irq_eoi)(struct irq_data___11 *);
	int (*irq_set_affinity)(struct irq_data___11 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___11 *);
	int (*irq_set_type)(struct irq_data___11 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___11 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___11 *);
	void (*irq_bus_sync_unlock)(struct irq_data___11 *);
	void (*irq_cpu_online)(struct irq_data___11 *);
	void (*irq_cpu_offline)(struct irq_data___11 *);
	void (*irq_suspend)(struct irq_data___11 *);
	void (*irq_resume)(struct irq_data___11 *);
	void (*irq_pm_shutdown)(struct irq_data___11 *);
	void (*irq_calc_mask)(struct irq_data___11 *);
	void (*irq_print_chip)(struct irq_data___11 *, struct seq_file *);
	int (*irq_request_resources)(struct irq_data___11 *);
	void (*irq_release_resources)(struct irq_data___11 *);
	void (*irq_compose_msi_msg)(struct irq_data___11 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___11 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___11 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___11 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___11 *, void *);
	void (*ipi_send_single)(struct irq_data___11 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___11 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___11 *);
	void (*irq_nmi_teardown)(struct irq_data___11 *);
	long unsigned int flags;
};

struct irq_domain_ops___11;

struct irq_domain_chip_generic___11;

struct irq_domain___11 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___11 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___20 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___11 *gc;
	struct irq_domain___11 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___11 *revmap[0];
};

struct irq_chip_type___11 {
	struct irq_chip___11 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___12 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___11 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___11 *);
	void (*resume)(struct irq_chip_generic___11 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___11 *domain;
	struct list_head list;
	struct irq_chip_type___11 chip_types[0];
};

struct irq_domain_chip_generic___11 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___11 *gc[0];
};

struct sched_shutdown {
	unsigned int reason;
};

struct xenpf_settime32 {
	uint32_t secs;
	uint32_t nsecs;
	uint64_t system_time;
};

struct xenpf_settime64 {
	uint64_t secs;
	uint32_t nsecs;
	uint32_t mbz;
	uint64_t system_time;
};

struct xenpf_add_memtype {
	xen_pfn_t mfn;
	uint64_t nr_mfns;
	uint32_t type;
	uint32_t handle;
	uint32_t reg;
};

struct xenpf_del_memtype {
	uint32_t handle;
	uint32_t reg;
};

struct xenpf_read_memtype {
	uint32_t reg;
	xen_pfn_t mfn;
	uint64_t nr_mfns;
	uint32_t type;
};

struct xenpf_microcode_update {
	__guest_handle_void data;
	uint32_t length;
};

struct xenpf_platform_quirk {
	uint32_t quirk_id;
};

struct xenpf_efi_time {
	uint16_t year;
	uint8_t month;
	uint8_t day;
	uint8_t hour;
	uint8_t min;
	uint8_t sec;
	uint32_t ns;
	int16_t tz;
	uint8_t daylight;
};

struct xenpf_efi_guid {
	uint32_t data1;
	uint16_t data2;
	uint16_t data3;
	uint8_t data4[8];
};

struct xenpf_efi_runtime_call {
	uint32_t function;
	uint32_t misc;
	xen_ulong_t status;
	union {
		struct {
			struct xenpf_efi_time time;
			uint32_t resolution;
			uint32_t accuracy;
		} get_time;
		struct xenpf_efi_time set_time;
		struct xenpf_efi_time get_wakeup_time;
		struct xenpf_efi_time set_wakeup_time;
		struct {
			__guest_handle_void name;
			xen_ulong_t size;
			__guest_handle_void data;
			struct xenpf_efi_guid vendor_guid;
		} get_variable;
		struct {
			__guest_handle_void name;
			xen_ulong_t size;
			__guest_handle_void data;
			struct xenpf_efi_guid vendor_guid;
		} set_variable;
		struct {
			xen_ulong_t size;
			__guest_handle_void name;
			struct xenpf_efi_guid vendor_guid;
		} get_next_variable_name;
		struct {
			uint32_t attr;
			uint64_t max_store_size;
			uint64_t remain_store_size;
			uint64_t max_size;
		} query_variable_info;
		struct {
			__guest_handle_void capsule_header_array;
			xen_ulong_t capsule_count;
			uint64_t max_capsule_size;
			uint32_t reset_type;
		} query_capsule_capabilities;
		struct {
			__guest_handle_void capsule_header_array;
			xen_ulong_t capsule_count;
			uint64_t sg_list;
		} update_capsule;
	} u;
};

union xenpf_efi_info {
	uint32_t version;
	struct {
		uint64_t addr;
		uint32_t nent;
	} cfg;
	struct {
		uint32_t revision;
		uint32_t bufsz;
		__guest_handle_void name;
	} vendor;
	struct {
		uint64_t addr;
		uint64_t size;
		uint64_t attr;
		uint32_t type;
	} mem;
};

struct xenpf_firmware_info {
	uint32_t type;
	uint32_t index;
	union {
		struct {
			uint8_t device;
			uint8_t version;
			uint16_t interface_support;
			uint16_t legacy_max_cylinder;
			uint8_t legacy_max_head;
			uint8_t legacy_sectors_per_track;
			__guest_handle_void edd_params;
		} disk_info;
		struct {
			uint8_t device;
			uint32_t mbr_signature;
		} disk_mbr_signature;
		struct {
			uint8_t capabilities;
			uint8_t edid_transfer_time;
			__guest_handle_uchar edid;
		} vbeddc_info;
		union xenpf_efi_info efi_info;
		uint8_t kbd_shift_flags;
	} u;
};

struct xenpf_enter_acpi_sleep {
	uint16_t val_a;
	uint16_t val_b;
	uint32_t sleep_state;
	uint32_t flags;
};

struct xenpf_change_freq {
	uint32_t flags;
	uint32_t cpu;
	uint64_t freq;
};

struct xenpf_getidletime {
	__guest_handle_uchar cpumap_bitmap;
	uint32_t cpumap_nr_cpus;
	__guest_handle_uint64_t idletime;
	uint64_t now;
};

struct xen_power_register {
	uint32_t space_id;
	uint32_t bit_width;
	uint32_t bit_offset;
	uint32_t access_size;
	uint64_t address;
};

struct xen_processor_csd {
	uint32_t domain;
	uint32_t coord_type;
	uint32_t num;
};

typedef struct {
	union {
		struct xen_processor_csd *p;
		uint64_t q;
	};
} __guest_handle_xen_processor_csd;

struct xen_processor_cx {
	struct xen_power_register reg;
	uint8_t type;
	uint32_t latency;
	uint32_t power;
	uint32_t dpcnt;
	__guest_handle_xen_processor_csd dp;
};

typedef struct {
	union {
		struct xen_processor_cx *p;
		uint64_t q;
	};
} __guest_handle_xen_processor_cx;

struct xen_processor_flags {
	uint32_t bm_control: 1;
	uint32_t bm_check: 1;
	uint32_t has_cst: 1;
	uint32_t power_setup_done: 1;
	uint32_t bm_rld_set: 1;
};

struct xen_processor_power {
	uint32_t count;
	struct xen_processor_flags flags;
	__guest_handle_xen_processor_cx states;
};

struct xen_pct_register {
	uint8_t descriptor;
	uint16_t length;
	uint8_t space_id;
	uint8_t bit_width;
	uint8_t bit_offset;
	uint8_t reserved;
	uint64_t address;
};

struct xen_processor_px {
	uint64_t core_frequency;
	uint64_t power;
	uint64_t transition_latency;
	uint64_t bus_master_latency;
	uint64_t control;
	uint64_t status;
};

typedef struct {
	union {
		struct xen_processor_px *p;
		uint64_t q;
	};
} __guest_handle_xen_processor_px;

struct xen_psd_package {
	uint64_t num_entries;
	uint64_t revision;
	uint64_t domain;
	uint64_t coord_type;
	uint64_t num_processors;
};

struct xen_processor_performance {
	uint32_t flags;
	uint32_t platform_limit;
	struct xen_pct_register control_register;
	struct xen_pct_register status_register;
	uint32_t state_count;
	__guest_handle_xen_processor_px states;
	struct xen_psd_package domain_info;
	uint32_t shared_type;
};

struct xenpf_set_processor_pminfo {
	uint32_t id;
	uint32_t type;
	union {
		struct xen_processor_power power;
		struct xen_processor_performance perf;
		__guest_handle_uint32_t pdc;
	};
};

struct xenpf_pcpuinfo {
	uint32_t xen_cpuid;
	uint32_t max_present;
	uint32_t flags;
	uint32_t apic_id;
	uint32_t acpi_id;
};

struct xenpf_cpu_ol {
	uint32_t cpuid;
};

struct xenpf_cpu_hotadd {
	uint32_t apic_id;
	uint32_t acpi_id;
	uint32_t pxm;
};

struct xenpf_mem_hotadd {
	uint64_t spfn;
	uint64_t epfn;
	uint32_t pxm;
	uint32_t flags;
};

struct xenpf_core_parking {
	uint32_t type;
	uint32_t idle_nums;
};

struct xenpf_symdata {
	uint32_t namelen;
	uint32_t symnum;
	__guest_handle_char name;
	uint64_t address;
	char type;
};

struct xen_platform_op {
	uint32_t cmd;
	uint32_t interface_version;
	union {
		struct xenpf_settime32 settime32;
		struct xenpf_settime64 settime64;
		struct xenpf_add_memtype add_memtype;
		struct xenpf_del_memtype del_memtype;
		struct xenpf_read_memtype read_memtype;
		struct xenpf_microcode_update microcode;
		struct xenpf_platform_quirk platform_quirk;
		struct xenpf_efi_runtime_call efi_runtime_call;
		struct xenpf_firmware_info firmware_info;
		struct xenpf_enter_acpi_sleep enter_acpi_sleep;
		struct xenpf_change_freq change_freq;
		struct xenpf_getidletime getidletime;
		struct xenpf_set_processor_pminfo set_pminfo;
		struct xenpf_pcpuinfo pcpu_info;
		struct xenpf_cpu_ol cpu_ol;
		struct xenpf_cpu_hotadd cpu_add;
		struct xenpf_mem_hotadd mem_add;
		struct xenpf_core_parking core_parking;
		struct xenpf_symdata symdata;
		uint8_t pad[128];
	} u;
};

struct dev_pm_ops___20 {
	int (*prepare)(struct device___20 *);
	void (*complete)(struct device___20 *);
	int (*suspend)(struct device___20 *);
	int (*resume)(struct device___20 *);
	int (*freeze)(struct device___20 *);
	int (*thaw)(struct device___20 *);
	int (*poweroff)(struct device___20 *);
	int (*restore)(struct device___20 *);
	int (*suspend_late)(struct device___20 *);
	int (*resume_early)(struct device___20 *);
	int (*freeze_late)(struct device___20 *);
	int (*thaw_early)(struct device___20 *);
	int (*poweroff_late)(struct device___20 *);
	int (*restore_early)(struct device___20 *);
	int (*suspend_noirq)(struct device___20 *);
	int (*resume_noirq)(struct device___20 *);
	int (*freeze_noirq)(struct device___20 *);
	int (*thaw_noirq)(struct device___20 *);
	int (*poweroff_noirq)(struct device___20 *);
	int (*restore_noirq)(struct device___20 *);
	int (*runtime_suspend)(struct device___20 *);
	int (*runtime_resume)(struct device___20 *);
	int (*runtime_idle)(struct device___20 *);
};

struct wakeup_source___20 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___20 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___4;

struct dev_pm_qos___4 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___4 *resume_latency_req;
	struct dev_pm_qos_request___4 *latency_tolerance_req;
	struct dev_pm_qos_request___4 *flags_req;
};

struct dev_pm_domain___20 {
	struct dev_pm_ops___20 ops;
	int (*start)(struct device___20 *);
	void (*detach)(struct device___20 *, bool);
	int (*activate)(struct device___20 *);
	void (*sync)(struct device___20 *);
	void (*dismiss)(struct device___20 *);
};

struct bus_type___20 {
	const char *name;
	const char *dev_name;
	struct device___20 *dev_root;
	const struct attribute_group **bus_groups;
	const struct attribute_group **dev_groups;
	const struct attribute_group **drv_groups;
	int (*match)(struct device___20 *, struct device_driver___20 *);
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	int (*probe)(struct device___20 *);
	void (*sync_state)(struct device___20 *);
	void (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*online)(struct device___20 *);
	int (*offline)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	int (*num_vf)(struct device___20 *);
	int (*dma_configure)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___20 {
	const char *name;
	struct bus_type___20 *bus;
	struct module *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___20 *);
	void (*sync_state)(struct device___20 *);
	int (*remove)(struct device___20 *);
	void (*shutdown)(struct device___20 *);
	int (*suspend)(struct device___20 *, pm_message_t);
	int (*resume)(struct device___20 *);
	const struct attribute_group **groups;
	const struct attribute_group **dev_groups;
	const struct dev_pm_ops___20 *pm;
	void (*coredump)(struct device___20 *);
	struct driver_private *p;
};

struct device_type___20 {
	const char *name;
	const struct attribute_group **groups;
	int (*uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___20 *);
	const struct dev_pm_ops___20 *pm;
};

struct class___20 {
	const char *name;
	struct module *owner;
	const struct attribute_group **class_groups;
	const struct attribute_group **dev_groups;
	struct kobject *dev_kobj;
	int (*dev_uevent)(struct device___20 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___20 *, umode_t *);
	void (*class_release)(struct class___20 *);
	void (*dev_release)(struct device___20 *);
	int (*shutdown_pre)(struct device___20 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___20 *);
	void (*get_ownership)(struct device___20 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___20 *pm;
	struct subsys_private *p;
};

struct device_node___14 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___20 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___14 *parent;
	struct device_node___14 *child;
	struct device_node___14 *sibling;
	struct kobject kobj;
	long unsigned int _flags;
	void *data;
};

struct xen_memory_region {
	long unsigned int start_pfn;
	long unsigned int n_pfns;
};

struct grant_frames {
	xen_pfn_t *pfn;
	unsigned int count;
	void *vaddr;
};

struct xen_hvm_param {
	domid_t domid;
	uint32_t index;
	uint64_t value;
};

struct vcpu_register_vcpu_info {
	uint64_t mfn;
	uint32_t offset;
	uint32_t rsvd;
};

struct xen_add_to_physmap {
	domid_t domid;
	uint16_t size;
	unsigned int space;
	xen_ulong_t idx;
	xen_pfn_t gpfn;
};

struct xsd_errors {
	int errnum;
	const char *errstring;
};

struct irq_fwspec___11 {
	struct fwnode_handle___20 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___11 {
	int (*match)(struct irq_domain___11 *, struct device_node___14 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___11 *, struct irq_fwspec___11 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___11 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___11 *, unsigned int);
	int (*xlate)(struct irq_domain___11 *, struct device_node___14 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___11 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___11 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___11 *, struct irq_data___11 *, bool);
	void (*deactivate)(struct irq_domain___11 *, struct irq_data___11 *);
	int (*translate)(struct irq_domain___11 *, struct irq_fwspec___11 *, long unsigned int *, unsigned int *);
};

struct dev_pm_qos_request___4 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___20 *dev;
};

struct tk_read_base {
	struct clocksource *clock;
	u64 mask;
	u64 cycle_last;
	u32 mult;
	u32 shift;
	u64 xtime_nsec;
	ktime_t base;
	u64 base_real;
};

struct timekeeper {
	struct tk_read_base tkr_mono;
	struct tk_read_base tkr_raw;
	u64 xtime_sec;
	long unsigned int ktime_sec;
	struct timespec64 wall_to_monotonic;
	ktime_t offs_real;
	ktime_t offs_boot;
	ktime_t offs_tai;
	s32 tai_offset;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
	ktime_t next_leap_ktime;
	u64 raw_sec;
	struct timespec64 monotonic_to_boot;
	u64 cycle_interval;
	u64 xtime_interval;
	s64 xtime_remainder;
	u64 raw_interval;
	u64 ntp_tick;
	s64 ntp_error;
	u32 ntp_error_shift;
	u32 ntp_err_mult;
	u32 skip_second_overflow;
};

struct xen_dm_op_buf;

typedef uint16_t grant_status_t;

typedef uint32_t grant_ref_t;

typedef uint32_t grant_handle_t;

struct gnttab_map_grant_ref {
	uint64_t host_addr;
	uint32_t flags;
	grant_ref_t ref;
	domid_t dom;
	int16_t status;
	grant_handle_t handle;
	uint64_t dev_bus_addr;
};

struct gnttab_unmap_grant_ref {
	uint64_t host_addr;
	uint64_t dev_bus_addr;
	grant_handle_t handle;
	int16_t status;
};

struct xen_p2m_entry {
	long unsigned int pfn;
	long unsigned int mfn;
	long unsigned int nr_pages;
	struct rb_node rbnode_phys;
};

struct gnttab_cache_flush {
	union {
		uint64_t dev_bus_addr;
		grant_ref_t ref;
	} a;
	uint16_t offset;
	uint16_t length;
	uint32_t op;
};

struct arm_smccc_1_2_regs {
	long unsigned int a0;
	long unsigned int a1;
	long unsigned int a2;
	long unsigned int a3;
	long unsigned int a4;
	long unsigned int a5;
	long unsigned int a6;
	long unsigned int a7;
	long unsigned int a8;
	long unsigned int a9;
	long unsigned int a10;
	long unsigned int a11;
	long unsigned int a12;
	long unsigned int a13;
	long unsigned int a14;
	long unsigned int a15;
	long unsigned int a16;
	long unsigned int a17;
};

struct hv_get_vp_registers_output {
	union {
		struct {
			u32 a;
			u32 b;
			u32 c;
			u32 d;
		} as32;
		struct {
			u64 low;
			u64 high;
		} as64;
	};
};

struct ms_hyperv_info {
	u32 features;
	u32 priv_high;
	u32 misc_features;
	u32 hints;
	u32 nested_features;
	u32 max_vp_index;
	u32 max_lp_index;
	u32 isolation_config_a;
	u32 isolation_config_b;
};

typedef void (*rcu_callback_t)(struct callback_head *);

struct fs_context___3;

struct fs_parameter_spec___3;

struct dentry___24;

struct super_block___24;

struct module___25;

struct file_system_type___23 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___3 *);
	const struct fs_parameter_spec___3 *parameters;
	struct dentry___24 * (*mount)(struct file_system_type___23 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___24 *);
	struct module___25 *owner;
	struct file_system_type___23 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___24;

struct kiocb___23;

struct iov_iter___10;

struct poll_table_struct___17;

struct vm_area_struct___23;

struct inode___25;

struct file_lock___23;

struct page___24;

struct pipe_inode_info___5;

struct seq_file___24;

struct file_operations___23 {
	struct module___25 *owner;
	loff_t (*llseek)(struct file___24 *, loff_t, int);
	ssize_t (*read)(struct file___24 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___24 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___23 *, struct iov_iter___10 *);
	ssize_t (*write_iter)(struct kiocb___23 *, struct iov_iter___10 *);
	int (*iopoll)(struct kiocb___23 *, bool);
	int (*iterate)(struct file___24 *, struct dir_context *);
	int (*iterate_shared)(struct file___24 *, struct dir_context *);
	__poll_t (*poll)(struct file___24 *, struct poll_table_struct___17 *);
	long int (*unlocked_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___24 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___24 *, struct vm_area_struct___23 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___25 *, struct file___24 *);
	int (*flush)(struct file___24 *, fl_owner_t);
	int (*release)(struct inode___25 *, struct file___24 *);
	int (*fsync)(struct file___24 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___24 *, int);
	int (*lock)(struct file___24 *, int, struct file_lock___23 *);
	ssize_t (*sendpage)(struct file___24 *, struct page___24 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___24 *, long unsigned int);
	int (*flock)(struct file___24 *, int, struct file_lock___23 *);
	ssize_t (*splice_write)(struct pipe_inode_info___5 *, struct file___24 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___24 *, loff_t *, struct pipe_inode_info___5 *, size_t, unsigned int);
	int (*setlease)(struct file___24 *, long int, struct file_lock___23 **, void **);
	long int (*fallocate)(struct file___24 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___24 *, struct file___24 *);
	ssize_t (*copy_file_range)(struct file___24 *, loff_t, struct file___24 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___24 *, loff_t, struct file___24 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___24 *, loff_t, loff_t, int);
};

struct vmacache___23 {
	u64 seqnum;
	struct vm_area_struct___23 *vmas[4];
};

struct page_frag___23 {
	struct page___24 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___14;

struct debug_info___14 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___14 *hbp_break[16];
	struct perf_event___14 *hbp_watch[16];
};

struct thread_struct___14 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___14 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___24;

struct pid___22;

struct nsproxy___23;

struct signal_struct___24;

struct bio_list___8;

struct backing_dev_info___7;

struct io_context___9;

struct css_set___16;

struct perf_event_context___14;

struct mem_cgroup___7;

struct request_queue___10;

struct vm_struct___23;

struct task_struct___25 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___25 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___24 *mm;
	struct mm_struct___24 *active_mm;
	struct vmacache___23 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___25 *real_parent;
	struct task_struct___25 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___25 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___22 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___23 *nsproxy;
	struct signal_struct___24 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___25 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___8 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___7 *backing_dev_info;
	struct io_context___9 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___16 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___14 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___5 *splice_pipe;
	struct page_frag___23 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___7 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___7 *active_memcg;
	struct request_queue___10 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___25 *oom_reaper_list;
	struct vm_struct___23 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___14 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___23;

struct kobj_type___23;

struct kernfs_node___23;

struct kobject___23 {
	const char *name;
	struct list_head entry;
	struct kobject___23 *parent;
	struct kset___23 *kset;
	struct kobj_type___23 *ktype;
	struct kernfs_node___23 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___23 {
	struct kobject___23 kobj;
	struct module___25 *mod;
	struct kobject___23 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___23 {
	struct module___25 *mod;
	struct latch_tree_node node;
};

struct module_layout___23 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___23 mtn;
};

struct module_attribute___23;

struct kernel_param___23;

struct trace_event_call___9;

struct module___25 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___23 mkobj;
	struct module_attribute___23 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___23 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___23 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___23 core_layout;
	struct module_layout___23 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___9 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___14 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___25 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___14)(struct perf_event___14 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___14;

struct fasync_struct___23;

struct pid_namespace___22;

struct perf_cgroup___14;

struct perf_event___14 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___14 *group_leader;
	struct pmu___14 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___14 hw;
	struct perf_event_context___14 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___14 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___25 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___23 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___14 *aux_event;
	void (*destroy)(struct perf_event___14 *);
	struct callback_head callback_head;
	struct pid_namespace___22 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___14 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___14 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___9 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___14 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___24 *pgtable_t___23;

struct address_space___23;

struct page_pool___5;

struct dev_pagemap___23;

struct page___24 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___23 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___5 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___24 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___23 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___24 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___23 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___23;

struct vm_area_struct___23 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___23 *vm_next;
	struct vm_area_struct___23 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___24 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___23 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___24 *vm_file;
	struct file___24 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___2;

struct core_state___23;

struct mm_struct___24 {
	struct {
		struct vm_area_struct___23 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___24 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___2 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___23 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___25 *owner;
		struct user_namespace *user_ns;
		struct file___24 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

enum tk_offsets {
	TK_OFFS_REAL = 0,
	TK_OFFS_BOOT = 1,
	TK_OFFS_TAI = 2,
	TK_OFFS_MAX = 3,
};

struct address_space_operations___23;

struct address_space___23 {
	struct inode___25 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___23 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___21;

struct page_pool_params___5 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___21 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___5 {
	u32 count;
	struct page___24 *cache[128];
};

struct page_pool___5 {
	struct page_pool_params___5 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___24 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___5 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___23;

struct dev_pagemap___23 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___23 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___23;

struct path___23 {
	struct vfsmount___23 *mnt;
	struct dentry___24 *dentry;
};

struct fown_struct___22 {
	rwlock_t lock;
	struct pid___22 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___24 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___23 f_path;
	struct inode___25 *f_inode;
	const struct file_operations___23 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___22 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___23 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___23;

struct vm_operations_struct___23 {
	void (*open)(struct vm_area_struct___23 *);
	void (*close)(struct vm_area_struct___23 *);
	int (*may_split)(struct vm_area_struct___23 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___23 *);
	int (*mprotect)(struct vm_area_struct___23 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___23 *);
	vm_fault_t (*huge_fault)(struct vm_fault___23 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___23 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___23 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___23 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___23 *);
	int (*access)(struct vm_area_struct___23 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___23 *);
	int (*set_policy)(struct vm_area_struct___23 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___23 *, long unsigned int);
	struct page___24 * (*find_special_page)(struct vm_area_struct___23 *, long unsigned int);
};

struct core_thread___23 {
	struct task_struct___25 *task;
	struct core_thread___23 *next;
};

struct core_state___23 {
	atomic_t nr_threads;
	struct core_thread___23 dumper;
	struct completion startup;
};

struct linux_binprm___3;

struct coredump_params___2;

struct linux_binfmt___2 {
	struct list_head lh;
	struct module___25 *module;
	int (*load_binary)(struct linux_binprm___3 *);
	int (*load_shlib)(struct file___24 *);
	int (*core_dump)(struct coredump_params___2 *);
	long unsigned int min_coredump;
};

struct vm_fault___23 {
	const struct {
		struct vm_area_struct___23 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___24 *cow_page;
	struct page___24 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___23 prealloc_pte;
};

struct pglist_data___8;

struct lruvec___8 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___8 *pgdat;
};

struct zone___8 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___8 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___8 {
	struct zone___8 *zone;
	int zone_idx;
};

struct zonelist___8 {
	struct zoneref___8 _zonerefs[321];
};

struct pglist_data___8 {
	struct zone___8 node_zones[5];
	struct zonelist___8 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___25 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___25 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___8 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct clone_args {
	__u64 flags;
	__u64 pidfd;
	__u64 child_tid;
	__u64 parent_tid;
	__u64 exit_signal;
	__u64 stack;
	__u64 stack_size;
	__u64 tls;
	__u64 set_tid;
	__u64 set_tid_size;
	__u64 cgroup;
};

struct upid___22 {
	int nr;
	struct pid_namespace___22 *ns;
};

struct pid_namespace___22 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___25 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___22 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___22 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___22 numbers[1];
};

struct tty_struct___3;

struct signal_struct___24 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___25 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___25 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___22 *pids[4];
	struct pid___22 *tty_old_pgrp;
	int leader;
	struct tty_struct___3 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___24 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___23 root;
	struct path___23 pwd;
};

struct fdtable {
	unsigned int max_fds;
	struct file___24 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable *fdt;
	struct fdtable fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___24 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___16;

struct nsproxy___23 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___22 *pid_ns_for_children;
	struct net___4 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___16 *cgroup_ns;
};

struct bio___8;

struct bio_list___8 {
	struct bio___8 *head;
	struct bio___8 *tail;
};

struct cgroup_subsys_state___16;

struct bdi_writeback___7 {
	struct backing_dev_info___7 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___16 *memcg_css;
	struct cgroup_subsys_state___16 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___7 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___7 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___21 *dev;
	char dev_name[64];
	struct device___21 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___24 *debug_dir;
};

struct io_cq___8;

struct io_context___9 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___8 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___16;

struct css_set___16 {
	struct cgroup_subsys_state___16 *subsys[14];
	refcount_t refcount;
	struct css_set___16 *dom_cset;
	struct cgroup___16 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___16 *mg_src_cgrp;
	struct cgroup___16 *mg_dst_cgrp;
	struct css_set___16 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct robust_list {
	struct robust_list *next;
};

struct robust_list_head {
	struct robust_list list;
	long int futex_offset;
	struct robust_list *list_op_pending;
};

struct perf_event_context___14 {
	struct pmu___14 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___25 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___14 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___5;

struct pipe_inode_info___5 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___24 *tmp_page;
	struct fasync_struct___23 *fasync_readers;
	struct fasync_struct___23 *fasync_writers;
	struct pipe_buffer___5 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___16;

struct cgroup_subsys_state___16 {
	struct cgroup___16 *cgroup;
	struct cgroup_subsys___16 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___16 *parent;
};

struct cgroup_file___16 {
	struct kernfs_node___23 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___7;

struct mem_cgroup_per_node___7;

struct mem_cgroup___7 {
	struct cgroup_subsys_state___16 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___16 events_file;
	struct cgroup_file___16 events_local_file;
	struct cgroup_file___16 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___7 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___25 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___7 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___8;

struct blk_integrity___8 {
	const struct blk_integrity_profile___8 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___8 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___8 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___9;

struct elevator_queue___8;

struct blk_mq_ops___8;

struct blk_mq_hw_ctx___8;

struct gendisk___8;

struct blkcg_gq___8;

struct blk_mq_tag_set___8;

struct request_queue___10 {
	struct request___9 *last_merge;
	struct elevator_queue___8 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___8 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___8 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___8 *disk;
	struct kobject___23 kobj;
	struct kobject___23 *mq_kobj;
	struct blk_integrity___8 integrity;
	struct device___21 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___8 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___8 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___8 bio_split;
	struct dentry___24 *debugfs_dir;
	struct dentry___24 *sched_debugfs_dir;
	struct dentry___24 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___23 {
	struct vm_struct___23 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___24 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kernel_clone_args {
	u64 flags;
	int *pidfd;
	int *child_tid;
	int *parent_tid;
	int exit_signal;
	long unsigned int stack;
	long unsigned int stack_size;
	long unsigned int tls;
	pid_t *set_tid;
	size_t set_tid_size;
	int cgroup;
	int io_thread;
	struct cgroup___16 *cgrp;
	struct css_set___16 *cset;
};

struct psi_group___16 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___25 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___16;

struct cgroup_rstat_cpu___16;

struct cgroup___16 {
	struct cgroup_subsys_state___16 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___23 *kn;
	struct cgroup_file___16 procs_file;
	struct cgroup_file___16 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___16 *subsys[14];
	struct cgroup_root___16 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___16 *dom_cgrp;
	struct cgroup___16 *old_dom_cgrp;
	struct cgroup_rstat_cpu___16 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___16 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct multiprocess_signals {
	sigset_t signal;
	struct hlist_node node;
};

struct tty_driver___3;

struct tty_operations___3;

struct tty_ldisc___3;

struct tty_port___3;

struct tty_struct___3 {
	int magic;
	struct kref kref;
	struct device___21 *dev;
	struct tty_driver___3 *driver;
	const struct tty_operations___3 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___3 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___22 *pgrp;
		struct pid___22 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___3 *link;
	struct fasync_struct___23 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___3 *port;
};

typedef int (*proc_visitor)(struct task_struct___25 *, void *);

struct dentry_operations___23;

struct dentry___24 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___24 *d_parent;
	struct qstr d_name;
	struct inode___25 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___23 *d_op;
	struct super_block___24 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___23;

struct cdev___12;

struct inode___25 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___23 *i_op;
	struct super_block___24 *i_sb;
	struct address_space___23 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___7 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___23 *i_fop;
		void (*free_inode)(struct inode___25 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___23 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___5 *i_pipe;
		struct cdev___12 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___23 {
	int (*d_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___24 *, unsigned int);
	int (*d_hash)(const struct dentry___24 *, struct qstr *);
	int (*d_compare)(const struct dentry___24 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___24 *);
	int (*d_init)(struct dentry___24 *);
	void (*d_release)(struct dentry___24 *);
	void (*d_prune)(struct dentry___24 *);
	void (*d_iput)(struct dentry___24 *, struct inode___25 *);
	char * (*d_dname)(struct dentry___24 *, char *, int);
	struct vfsmount___23 * (*d_automount)(struct path___23 *);
	int (*d_manage)(const struct path___23 *, bool);
	struct dentry___24 * (*d_real)(struct dentry___24 *, const struct inode___25 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___23;

struct mem_dqinfo___23 {
	struct quota_format_type___23 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___23;

struct quota_info___23 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___25 *files[3];
	struct mem_dqinfo___23 info[3];
	const struct quota_format_ops___23 *ops[3];
};

struct rcuwait___23 {
	struct task_struct___25 *task;
};

struct percpu_rw_semaphore___23 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___23 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___23 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___23 rw_sem[3];
};

struct shrink_control___7;

struct shrinker___7 {
	long unsigned int (*count_objects)(struct shrinker___7 *, struct shrink_control___7 *);
	long unsigned int (*scan_objects)(struct shrinker___7 *, struct shrink_control___7 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___23;

struct dquot_operations___23;

struct quotactl_ops___23;

struct xattr_handler___3;

struct block_device___9;

struct super_block___24 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___23 *s_type;
	const struct super_operations___23 *s_op;
	const struct dquot_operations___23 *dq_op;
	const struct quotactl_ops___23 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___24 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___3 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___9 *s_bdev;
	struct backing_dev_info___7 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___23 s_dquot;
	struct sb_writers___23 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___23 *s_d_op;
	int cleancache_poolid;
	struct shrinker___7 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___23 {
	struct dentry___24 *mnt_root;
	struct super_block___24 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___7 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___7 *memcg;
};

struct io_cq___8 {
	struct request_queue___10 *q;
	struct io_context___9 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

enum {
	IOPRIO_CLASS_NONE = 0,
	IOPRIO_CLASS_RT = 1,
	IOPRIO_CLASS_BE = 2,
	IOPRIO_CLASS_IDLE = 3,
};

struct wait_page_queue___9;

struct kiocb___23 {
	struct file___24 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___23 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___9 *ki_waitq;
	};
};

struct iattr___24 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___24 *ia_file;
};

struct dquot___23 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___24 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___23 {
	int qf_fmt_id;
	const struct quota_format_ops___23 *qf_ops;
	struct module___25 *qf_owner;
	struct quota_format_type___23 *qf_next;
};

struct quota_format_ops___23 {
	int (*check_quota_file)(struct super_block___24 *, int);
	int (*read_file_info)(struct super_block___24 *, int);
	int (*write_file_info)(struct super_block___24 *, int);
	int (*free_file_info)(struct super_block___24 *, int);
	int (*read_dqblk)(struct dquot___23 *);
	int (*commit_dqblk)(struct dquot___23 *);
	int (*release_dqblk)(struct dquot___23 *);
	int (*get_next_id)(struct super_block___24 *, struct kqid *);
};

struct dquot_operations___23 {
	int (*write_dquot)(struct dquot___23 *);
	struct dquot___23 * (*alloc_dquot)(struct super_block___24 *, int);
	void (*destroy_dquot)(struct dquot___23 *);
	int (*acquire_dquot)(struct dquot___23 *);
	int (*release_dquot)(struct dquot___23 *);
	int (*mark_dirty)(struct dquot___23 *);
	int (*write_info)(struct super_block___24 *, int);
	qsize_t * (*get_reserved_space)(struct inode___25 *);
	int (*get_projid)(struct inode___25 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___25 *, qsize_t *);
	int (*get_next_id)(struct super_block___24 *, struct kqid *);
};

struct quotactl_ops___23 {
	int (*quota_on)(struct super_block___24 *, int, int, const struct path___23 *);
	int (*quota_off)(struct super_block___24 *, int);
	int (*quota_enable)(struct super_block___24 *, unsigned int);
	int (*quota_disable)(struct super_block___24 *, unsigned int);
	int (*quota_sync)(struct super_block___24 *, int);
	int (*set_info)(struct super_block___24 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___24 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___24 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___24 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___24 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___24 *, unsigned int);
};

struct wait_page_queue___9 {
	struct page___24 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___7;

struct readahead_control___9;

struct swap_info_struct___6;

struct address_space_operations___23 {
	int (*writepage)(struct page___24 *, struct writeback_control___7 *);
	int (*readpage)(struct file___24 *, struct page___24 *);
	int (*writepages)(struct address_space___23 *, struct writeback_control___7 *);
	int (*set_page_dirty)(struct page___24 *);
	int (*readpages)(struct file___24 *, struct address_space___23 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___9 *);
	int (*write_begin)(struct file___24 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___24 **, void **);
	int (*write_end)(struct file___24 *, struct address_space___23 *, loff_t, unsigned int, unsigned int, struct page___24 *, void *);
	sector_t (*bmap)(struct address_space___23 *, sector_t);
	void (*invalidatepage)(struct page___24 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___24 *, gfp_t);
	void (*freepage)(struct page___24 *);
	ssize_t (*direct_IO)(struct kiocb___23 *, struct iov_iter___10 *);
	int (*migratepage)(struct address_space___23 *, struct page___24 *, struct page___24 *, enum migrate_mode);
	bool (*isolate_page)(struct page___24 *, isolate_mode_t);
	void (*putback_page)(struct page___24 *);
	int (*launder_page)(struct page___24 *);
	int (*is_partially_uptodate)(struct page___24 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___24 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___23 *, struct page___24 *);
	int (*swap_activate)(struct swap_info_struct___6 *, struct file___24 *, sector_t *);
	void (*swap_deactivate)(struct file___24 *);
};

struct writeback_control___7 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___7 *wb;
	struct inode___25 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___9 {
	struct file___24 *file;
	struct address_space___23 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___10;

struct iov_iter___10 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___10 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___5 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___6 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___9 *bdev;
	struct file___24 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___12 {
	struct kobject___23 kobj;
	struct module___25 *owner;
	const struct file_operations___23 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___23 {
	struct dentry___24 * (*lookup)(struct inode___25 *, struct dentry___24 *, unsigned int);
	const char * (*get_link)(struct dentry___24 *, struct inode___25 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___25 *, int);
	struct posix_acl * (*get_acl)(struct inode___25 *, int, bool);
	int (*readlink)(struct dentry___24 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___25 *, struct dentry___24 *, umode_t, bool);
	int (*link)(struct dentry___24 *, struct inode___25 *, struct dentry___24 *);
	int (*unlink)(struct inode___25 *, struct dentry___24 *);
	int (*symlink)(struct user_namespace *, struct inode___25 *, struct dentry___24 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___25 *, struct dentry___24 *, umode_t);
	int (*rmdir)(struct inode___25 *, struct dentry___24 *);
	int (*mknod)(struct user_namespace *, struct inode___25 *, struct dentry___24 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___25 *, struct dentry___24 *, struct inode___25 *, struct dentry___24 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___24 *, struct iattr___24 *);
	int (*getattr)(struct user_namespace *, const struct path___23 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___24 *, char *, size_t);
	int (*fiemap)(struct inode___25 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___25 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___25 *, struct dentry___24 *, struct file___24 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___25 *, struct dentry___24 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___25 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___24 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___24 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___23 {
	void (*fl_copy_lock)(struct file_lock___23 *, struct file_lock___23 *);
	void (*fl_release_private)(struct file_lock___23 *);
};

struct lock_manager_operations___23;

struct file_lock___23 {
	struct file_lock___23 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___24 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___23 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___23 *fl_ops;
	const struct lock_manager_operations___23 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___23 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___23 *);
	int (*lm_grant)(struct file_lock___23 *, int);
	bool (*lm_break)(struct file_lock___23 *);
	int (*lm_change)(struct file_lock___23 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___23 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___23 *);
};

struct fasync_struct___23 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___23 *fa_next;
	struct file___24 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___23 {
	struct inode___25 * (*alloc_inode)(struct super_block___24 *);
	void (*destroy_inode)(struct inode___25 *);
	void (*free_inode)(struct inode___25 *);
	void (*dirty_inode)(struct inode___25 *, int);
	int (*write_inode)(struct inode___25 *, struct writeback_control___7 *);
	int (*drop_inode)(struct inode___25 *);
	void (*evict_inode)(struct inode___25 *);
	void (*put_super)(struct super_block___24 *);
	int (*sync_fs)(struct super_block___24 *, int);
	int (*freeze_super)(struct super_block___24 *);
	int (*freeze_fs)(struct super_block___24 *);
	int (*thaw_super)(struct super_block___24 *);
	int (*unfreeze_fs)(struct super_block___24 *);
	int (*statfs)(struct dentry___24 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___24 *, int *, char *);
	void (*umount_begin)(struct super_block___24 *);
	int (*show_options)(struct seq_file___24 *, struct dentry___24 *);
	int (*show_devname)(struct seq_file___24 *, struct dentry___24 *);
	int (*show_path)(struct seq_file___24 *, struct dentry___24 *);
	int (*show_stats)(struct seq_file___24 *, struct dentry___24 *);
	ssize_t (*quota_read)(struct super_block___24 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___24 *, int, const char *, size_t, loff_t);
	struct dquot___23 ** (*get_dquots)(struct inode___25 *);
	long int (*nr_cached_objects)(struct super_block___24 *, struct shrink_control___7 *);
	long int (*free_cached_objects)(struct super_block___24 *, struct shrink_control___7 *);
	struct file___24 * (*real_loop)(struct file___24 *);
};

struct xattr_handler___3 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___24 *);
	int (*get)(const struct xattr_handler___3 *, struct dentry___24 *, struct inode___25 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___3 *, struct user_namespace *, struct dentry___24 *, struct inode___25 *, const char *, const void *, size_t, int);
};

struct wakeup_source___21;

struct dev_pm_info___21 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___21 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___21 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___21;

struct bus_type___21;

struct device_driver___21;

struct dev_pm_domain___21;

struct fwnode_handle___21;

struct class___21;

struct attribute_group___23;

struct device___21 {
	struct kobject___23 kobj;
	struct device___21 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___21 *type;
	struct bus_type___21 *bus;
	struct device_driver___21 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___21 power;
	struct dev_pm_domain___21 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___21 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___21 *class;
	const struct attribute_group___23 **groups;
	void (*release)(struct device___21 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___9 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___25 *bd_inode;
	struct super_block___24 *bd_super;
	void *bd_claiming;
	struct device___21 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___23 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___8 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___24 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___17)(struct file___24 *, wait_queue_head_t *, struct poll_table_struct___17 *);

struct poll_table_struct___17 {
	poll_queue_proc___17 _qproc;
	__poll_t _key;
};

struct seq_operations___22;

struct seq_file___24 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___22 *op;
	int poll_event;
	const struct file___24 *file;
	void *private;
};

struct fc_log___3;

struct p_log___3 {
	const char *prefix;
	struct fc_log___3 *log;
};

struct fs_context_operations___3;

struct fs_context___3 {
	const struct fs_context_operations___3 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___23 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___24 *root;
	struct user_namespace *user_ns;
	struct net___4 *net_ns;
	const struct cred *cred;
	struct p_log___3 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___3;

typedef int fs_param_type___3(struct p_log___3 *, const struct fs_parameter_spec___3 *, struct fs_parameter___3 *, struct fs_parse_result *);

struct fs_parameter_spec___3 {
	const char *name;
	fs_param_type___3 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___8(struct bio___8 *);

struct bio_vec___10 {
	struct page___24 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___8;

struct bio___8 {
	struct bio___8 *bi_next;
	struct block_device___9 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___8 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___8 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___8 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___10 *bi_io_vec;
	struct bio_set___8 *bi_pool;
	struct bio_vec___10 bi_inline_vecs[0];
};

struct seq_operations___22 {
	void * (*start)(struct seq_file___24 *, loff_t *);
	void (*stop)(struct seq_file___24 *, void *);
	void * (*next)(struct seq_file___24 *, void *, loff_t *);
	int (*show)(struct seq_file___24 *, void *);
};

struct kernfs_root___23;

struct kernfs_elem_dir___23 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___23 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___23;

struct kernfs_root___23 {
	struct kernfs_node___23 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___23 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___23 {
	struct kernfs_node___23 *target_kn;
};

struct kernfs_ops___23;

struct kernfs_elem_attr___23 {
	const struct kernfs_ops___23 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___23 *notify_next;
};

struct kernfs_node___23 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___23 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___23 dir;
		struct kernfs_elem_symlink___23 symlink;
		struct kernfs_elem_attr___23 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___23;

struct kernfs_ops___23 {
	int (*open)(struct kernfs_open_file___23 *);
	void (*release)(struct kernfs_open_file___23 *);
	int (*seq_show)(struct seq_file___24 *, void *);
	void * (*seq_start)(struct seq_file___24 *, loff_t *);
	void * (*seq_next)(struct seq_file___24 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___24 *, void *);
	ssize_t (*read)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___23 *, struct poll_table_struct___17 *);
	int (*mmap)(struct kernfs_open_file___23 *, struct vm_area_struct___23 *);
};

struct kernfs_syscall_ops___23 {
	int (*show_options)(struct seq_file___24 *, struct kernfs_root___23 *);
	int (*mkdir)(struct kernfs_node___23 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___23 *);
	int (*rename)(struct kernfs_node___23 *, struct kernfs_node___23 *, const char *);
	int (*show_path)(struct seq_file___24 *, struct kernfs_node___23 *, struct kernfs_root___23 *);
};

struct kernfs_open_file___23 {
	struct kernfs_node___23 *kn;
	struct file___24 *file;
	struct seq_file___24 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___23 *vm_ops;
};

struct bin_attribute___23;

struct attribute_group___23 {
	const char *name;
	umode_t (*is_visible)(struct kobject___23 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___23 *, struct bin_attribute___23 *, int);
	struct attribute **attrs;
	struct bin_attribute___23 **bin_attrs;
};

struct bin_attribute___23 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___23 * (*f_mapping)();
	ssize_t (*read)(struct file___24 *, struct kobject___23 *, struct bin_attribute___23 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___24 *, struct kobject___23 *, struct bin_attribute___23 *, char *, loff_t, size_t);
	int (*mmap)(struct file___24 *, struct kobject___23 *, struct bin_attribute___23 *, struct vm_area_struct___23 *);
};

struct sysfs_ops___23 {
	ssize_t (*show)(struct kobject___23 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___23 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___23;

struct kset___23 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___23 kobj;
	const struct kset_uevent_ops___23 *uevent_ops;
};

struct kobj_type___23 {
	void (*release)(struct kobject___23 *);
	const struct sysfs_ops___23 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___23 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___23 *);
	const void * (*namespace)(struct kobject___23 *);
	void (*get_ownership)(struct kobject___23 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___23 {
	int (* const filter)(struct kset___23 *, struct kobject___23 *);
	const char * (* const name)(struct kset___23 *, struct kobject___23 *);
	int (* const uevent)(struct kset___23 *, struct kobject___23 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___23 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___23 *);
	int (*get)(char *, const struct kernel_param___23 *);
	void (*free)(void *);
};

struct kparam_array___23;

struct kernel_param___23 {
	const char *name;
	struct module___25 *mod;
	const struct kernel_param_ops___23 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___23 *arr;
	};
};

struct kparam_array___23 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___23 *ops;
	void *elem;
};

struct module_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___23 *, struct module_kobject___23 *, char *);
	ssize_t (*store)(struct module_attribute___23 *, struct module_kobject___23 *, const char *, size_t);
	void (*setup)(struct module___25 *, const char *);
	int (*test)(struct module___25 *);
	void (*free)(struct module___25 *);
};

struct trace_event_class___9;

struct trace_event_call___9 {
	struct list_head list;
	struct trace_event_class___9 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___9 *, struct perf_event___14 *);
};

struct dev_pagemap_ops___23 {
	void (*page_free)(struct page___24 *);
	void (*kill)(struct dev_pagemap___23 *);
	void (*cleanup)(struct dev_pagemap___23 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___23 *);
};

struct fwnode_operations___21;

struct fwnode_handle___21 {
	struct fwnode_handle___21 *secondary;
	const struct fwnode_operations___21 *ops;
	struct device___21 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___21;

struct fwnode_endpoint___21;

struct fwnode_operations___21 {
	struct fwnode_handle___21 * (*get)(struct fwnode_handle___21 *);
	void (*put)(struct fwnode_handle___21 *);
	bool (*device_is_available)(const struct fwnode_handle___21 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___21 *, const struct device___21 *);
	bool (*property_present)(const struct fwnode_handle___21 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___21 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___21 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___21 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_parent)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_next_child_node)(const struct fwnode_handle___21 *, struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*get_named_child_node)(const struct fwnode_handle___21 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___21 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___21 *);
	struct fwnode_handle___21 * (*graph_get_next_endpoint)(const struct fwnode_handle___21 *, struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*graph_get_remote_endpoint)(const struct fwnode_handle___21 *);
	struct fwnode_handle___21 * (*graph_get_port_parent)(struct fwnode_handle___21 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___21 *, struct fwnode_endpoint___21 *);
	int (*add_links)(struct fwnode_handle___21 *);
};

struct fwnode_endpoint___21 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___21 *local_fwnode;
};

struct fwnode_reference_args___21 {
	struct fwnode_handle___21 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___16 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___16 *root_cset;
};

struct linux_binprm___3 {
	struct vm_area_struct___23 *vma;
	long unsigned int vma_pages;
	struct mm_struct___24 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___24 *executable;
	struct file___24 *interpreter;
	struct file___24 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___2 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___24 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dev_pm_ops___21 {
	int (*prepare)(struct device___21 *);
	void (*complete)(struct device___21 *);
	int (*suspend)(struct device___21 *);
	int (*resume)(struct device___21 *);
	int (*freeze)(struct device___21 *);
	int (*thaw)(struct device___21 *);
	int (*poweroff)(struct device___21 *);
	int (*restore)(struct device___21 *);
	int (*suspend_late)(struct device___21 *);
	int (*resume_early)(struct device___21 *);
	int (*freeze_late)(struct device___21 *);
	int (*thaw_early)(struct device___21 *);
	int (*poweroff_late)(struct device___21 *);
	int (*restore_early)(struct device___21 *);
	int (*suspend_noirq)(struct device___21 *);
	int (*resume_noirq)(struct device___21 *);
	int (*freeze_noirq)(struct device___21 *);
	int (*thaw_noirq)(struct device___21 *);
	int (*poweroff_noirq)(struct device___21 *);
	int (*restore_noirq)(struct device___21 *);
	int (*runtime_suspend)(struct device___21 *);
	int (*runtime_resume)(struct device___21 *);
	int (*runtime_idle)(struct device___21 *);
};

struct wakeup_source___21 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___21 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___21 {
	struct dev_pm_ops___21 ops;
	int (*start)(struct device___21 *);
	void (*detach)(struct device___21 *, bool);
	int (*activate)(struct device___21 *);
	void (*sync)(struct device___21 *);
	void (*dismiss)(struct device___21 *);
};

struct bus_type___21 {
	const char *name;
	const char *dev_name;
	struct device___21 *dev_root;
	const struct attribute_group___23 **bus_groups;
	const struct attribute_group___23 **dev_groups;
	const struct attribute_group___23 **drv_groups;
	int (*match)(struct device___21 *, struct device_driver___21 *);
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	int (*probe)(struct device___21 *);
	void (*sync_state)(struct device___21 *);
	void (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*online)(struct device___21 *);
	int (*offline)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	int (*num_vf)(struct device___21 *);
	int (*dma_configure)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___21 {
	const char *name;
	struct bus_type___21 *bus;
	struct module___25 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___21 *);
	void (*sync_state)(struct device___21 *);
	int (*remove)(struct device___21 *);
	void (*shutdown)(struct device___21 *);
	int (*suspend)(struct device___21 *, pm_message_t);
	int (*resume)(struct device___21 *);
	const struct attribute_group___23 **groups;
	const struct attribute_group___23 **dev_groups;
	const struct dev_pm_ops___21 *pm;
	void (*coredump)(struct device___21 *);
	struct driver_private *p;
};

struct device_type___21 {
	const char *name;
	const struct attribute_group___23 **groups;
	int (*uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___21 *);
	const struct dev_pm_ops___21 *pm;
};

struct class___21 {
	const char *name;
	struct module___25 *owner;
	const struct attribute_group___23 **class_groups;
	const struct attribute_group___23 **dev_groups;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___21 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___21 *, umode_t *);
	void (*class_release)(struct class___21 *);
	void (*dev_release)(struct device___21 *);
	int (*shutdown_pre)(struct device___21 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___21 *);
	void (*get_ownership)(struct device___21 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___21 *pm;
	struct subsys_private *p;
};

struct cftype___16;

struct cgroup_subsys___16 {
	struct cgroup_subsys_state___16 * (*css_alloc)(struct cgroup_subsys_state___16 *);
	int (*css_online)(struct cgroup_subsys_state___16 *);
	void (*css_offline)(struct cgroup_subsys_state___16 *);
	void (*css_released)(struct cgroup_subsys_state___16 *);
	void (*css_free)(struct cgroup_subsys_state___16 *);
	void (*css_reset)(struct cgroup_subsys_state___16 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___16 *, int);
	int (*css_extra_stat_show)(struct seq_file___24 *, struct cgroup_subsys_state___16 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___25 *, struct css_set___16 *);
	void (*cancel_fork)(struct task_struct___25 *, struct css_set___16 *);
	void (*fork)(struct task_struct___25 *);
	void (*exit)(struct task_struct___25 *);
	void (*release)(struct task_struct___25 *);
	void (*bind)(struct cgroup_subsys_state___16 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___16 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___16 *dfl_cftypes;
	struct cftype___16 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___16 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___16 *updated_children;
	struct cgroup___16 *updated_next;
};

struct cgroup_root___16 {
	struct kernfs_root___23 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___16 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___16 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___16 *ss;
	struct list_head node;
	struct kernfs_ops___23 *kf_ops;
	int (*open)(struct kernfs_open_file___23 *);
	void (*release)(struct kernfs_open_file___23 *);
	u64 (*read_u64)(struct cgroup_subsys_state___16 *, struct cftype___16 *);
	s64 (*read_s64)(struct cgroup_subsys_state___16 *, struct cftype___16 *);
	int (*seq_show)(struct seq_file___24 *, void *);
	void * (*seq_start)(struct seq_file___24 *, loff_t *);
	void * (*seq_next)(struct seq_file___24 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___24 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___16 *, struct cftype___16 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___16 *, struct cftype___16 *, s64);
	ssize_t (*write)(struct kernfs_open_file___23 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___23 *, struct poll_table_struct___17 *);
};

struct block_device_operations___8;

struct gendisk___8 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___9 *part0;
	const struct block_device_operations___8 *fops;
	struct request_queue___10 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___7 *bdi;
	struct kobject___23 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___23 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___8 {
	struct bio___8 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___10 *bip_vec;
	struct bio_vec___10 bip_inline_vecs[0];
};

struct blkcg___7;

struct blkg_policy_data___7;

struct blkcg_gq___8 {
	struct request_queue___10 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___7 *blkcg;
	struct blkcg_gq___8 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___7 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___8 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___8(struct request___9 *);

typedef void integrity_complete_fn___8(struct request___9 *, unsigned int);

struct blk_integrity_profile___8 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___8 *prepare_fn;
	integrity_complete_fn___8 *complete_fn;
	const char *name;
};

struct block_device_operations___8 {
	blk_qc_t (*submit_bio)(struct bio___8 *);
	int (*open)(struct block_device___9 *, fmode_t);
	void (*release)(struct gendisk___8 *, fmode_t);
	int (*rw_page)(struct block_device___9 *, sector_t, struct page___24 *, unsigned int);
	int (*ioctl)(struct block_device___9 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___9 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___8 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___8 *);
	int (*getgeo)(struct block_device___9 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___9 *, bool);
	void (*swap_slot_free_notify)(struct block_device___9 *, long unsigned int);
	int (*report_zones)(struct gendisk___8 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___8 *, umode_t *);
	struct module___25 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___8 *, sector_t *);
};

typedef void rq_end_io_fn___8(struct request___9 *, blk_status_t);

struct request___9 {
	struct request_queue___10 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___8 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___8 *bio;
	struct bio___8 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___10 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___8 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___8 *saved_end_io;
		} flush;
	};
	struct gendisk___8 *rq_disk;
	struct block_device___9 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___8 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___8 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___10 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___23 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___24 *debugfs_dir;
	struct dentry___24 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___8;

struct elevator_mq_ops___8 {
	int (*init_sched)(struct request_queue___10 *, struct elevator_type___8 *);
	void (*exit_sched)(struct elevator_queue___8 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___8 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___8 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___8 *);
	bool (*allow_merge)(struct request_queue___10 *, struct request___9 *, struct bio___8 *);
	bool (*bio_merge)(struct request_queue___10 *, struct bio___8 *, unsigned int);
	int (*request_merge)(struct request_queue___10 *, struct request___9 **, struct bio___8 *);
	void (*request_merged)(struct request_queue___10 *, struct request___9 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___10 *, struct request___9 *, struct request___9 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___9 *);
	void (*finish_request)(struct request___9 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___8 *, struct list_head *, bool);
	struct request___9 * (*dispatch_request)(struct blk_mq_hw_ctx___8 *);
	bool (*has_work)(struct blk_mq_hw_ctx___8 *);
	void (*completed_request)(struct request___9 *, u64);
	void (*requeue_request)(struct request___9 *);
	struct request___9 * (*former_request)(struct request_queue___10 *, struct request___9 *);
	struct request___9 * (*next_request)(struct request_queue___10 *, struct request___9 *);
	void (*init_icq)(struct io_cq___8 *);
	void (*exit_icq)(struct io_cq___8 *);
};

struct elv_fs_entry___8;

struct elevator_type___8 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___8 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___8 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___25 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___8 {
	struct elevator_type___8 *type;
	void *elevator_data;
	struct kobject___23 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___8 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___8 *, char *);
	ssize_t (*store)(struct elevator_queue___8 *, const char *, size_t);
};

struct blk_mq_queue_data___8;

struct blk_mq_ops___8 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___8 *, const struct blk_mq_queue_data___8 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___8 *);
	int (*get_budget)(struct request_queue___10 *);
	void (*put_budget)(struct request_queue___10 *, int);
	void (*set_rq_budget_token)(struct request___9 *, int);
	int (*get_rq_budget_token)(struct request___9 *);
	enum blk_eh_timer_return (*timeout)(struct request___9 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___8 *);
	void (*complete)(struct request___9 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___8 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___8 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___8 *, struct request___9 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___8 *, struct request___9 *, unsigned int);
	void (*initialize_rq_fn)(struct request___9 *);
	void (*cleanup_rq)(struct request___9 *);
	bool (*busy)(struct request_queue___10 *);
	int (*map_queues)(struct blk_mq_tag_set___8 *);
	void (*show_rq)(struct seq_file___24 *, struct request___9 *);
};

struct blk_mq_tag_set___8 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___8 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___8 {
	struct request___9 *rq;
	bool last;
};

struct blkcg_policy_data___7;

struct blkcg___7 {
	struct cgroup_subsys_state___16 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___8 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___7 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___7 {
	struct blkcg___7 *blkcg;
	int plid;
};

struct blkg_policy_data___7 {
	struct blkcg_gq___8 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___7 {
	struct mem_cgroup___7 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___7 {
	struct lruvec___8 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___7 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___7 *memcg;
};

struct obj_cgroup___7 {
	struct percpu_ref refcnt;
	struct mem_cgroup___7 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

typedef struct poll_table_struct___17 poll_table___3;

struct perf_cpu_context___14;

struct perf_output_handle___14;

struct pmu___14 {
	struct list_head entry;
	struct module___25 *module;
	struct device___21 *dev;
	const struct attribute_group___23 **attr_groups;
	const struct attribute_group___23 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___14 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___14 *);
	void (*pmu_disable)(struct pmu___14 *);
	int (*event_init)(struct perf_event___14 *);
	void (*event_mapped)(struct perf_event___14 *, struct mm_struct___24 *);
	void (*event_unmapped)(struct perf_event___14 *, struct mm_struct___24 *);
	int (*add)(struct perf_event___14 *, int);
	void (*del)(struct perf_event___14 *, int);
	void (*start)(struct perf_event___14 *, int);
	void (*stop)(struct perf_event___14 *, int);
	void (*read)(struct perf_event___14 *);
	void (*start_txn)(struct pmu___14 *, unsigned int);
	int (*commit_txn)(struct pmu___14 *);
	void (*cancel_txn)(struct pmu___14 *);
	int (*event_idx)(struct perf_event___14 *);
	void (*sched_task)(struct perf_event_context___14 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___14 *, struct perf_event_context___14 *);
	void * (*setup_aux)(struct perf_event___14 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___14 *, struct perf_output_handle___14 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___14 *);
	int (*aux_output_match)(struct perf_event___14 *);
	int (*filter_match)(struct perf_event___14 *);
	int (*check_period)(struct perf_event___14 *, u64);
};

struct perf_cpu_context___14 {
	struct perf_event_context___14 ctx;
	struct perf_event_context___14 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___14 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___14 **heap;
	struct perf_event___14 *heap_default[2];
};

struct perf_output_handle___14 {
	struct perf_event___14 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___14 {
	struct cgroup_subsys_state___16 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___9 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___9 *);
	};
};

struct trace_event_class___9 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___9 *, enum trace_reg, void *);
	struct trace_event_fields___9 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___9 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___9 *);
};

struct trace_event_file___5;

struct trace_event_buffer___5 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___5 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___5 {
	struct list_head list;
	struct trace_event_call___9 *event_call;
	struct event_filter *filter;
	struct dentry___24 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___2 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___9 *enter_event;
	struct trace_event_call___9 *exit_event;
};

enum {
	FUTEX_STATE_OK = 0,
	FUTEX_STATE_EXITING = 1,
	FUTEX_STATE_DEAD = 2,
};

enum proc_hidepid {
	HIDEPID_OFF = 0,
	HIDEPID_NO_ACCESS = 1,
	HIDEPID_INVISIBLE = 2,
	HIDEPID_NOT_PTRACEABLE = 4,
};

enum proc_pidonly {
	PROC_PIDONLY_OFF = 0,
	PROC_PIDONLY_ON = 1,
};

struct proc_fs_info {
	struct pid_namespace___22 *pid_ns;
	struct dentry___24 *proc_self;
	struct dentry___24 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

struct tty_operations___3 {
	struct tty_struct___3 * (*lookup)(struct tty_driver___3 *, struct file___24 *, int);
	int (*install)(struct tty_driver___3 *, struct tty_struct___3 *);
	void (*remove)(struct tty_driver___3 *, struct tty_struct___3 *);
	int (*open)(struct tty_struct___3 *, struct file___24 *);
	void (*close)(struct tty_struct___3 *, struct file___24 *);
	void (*shutdown)(struct tty_struct___3 *);
	void (*cleanup)(struct tty_struct___3 *);
	int (*write)(struct tty_struct___3 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___3 *, unsigned char);
	void (*flush_chars)(struct tty_struct___3 *);
	unsigned int (*write_room)(struct tty_struct___3 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___3 *);
	int (*ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___3 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	void (*throttle)(struct tty_struct___3 *);
	void (*unthrottle)(struct tty_struct___3 *);
	void (*stop)(struct tty_struct___3 *);
	void (*start)(struct tty_struct___3 *);
	void (*hangup)(struct tty_struct___3 *);
	int (*break_ctl)(struct tty_struct___3 *, int);
	void (*flush_buffer)(struct tty_struct___3 *);
	void (*set_ldisc)(struct tty_struct___3 *);
	void (*wait_until_sent)(struct tty_struct___3 *, int);
	void (*send_xchar)(struct tty_struct___3 *, char);
	int (*tiocmget)(struct tty_struct___3 *);
	int (*tiocmset)(struct tty_struct___3 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___3 *, struct winsize *);
	int (*get_icount)(struct tty_struct___3 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___3 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___3 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___3 *, struct seq_file___24 *);
	int (*poll_init)(struct tty_driver___3 *, int, char *);
	int (*poll_get_char)(struct tty_driver___3 *, int);
	void (*poll_put_char)(struct tty_driver___3 *, int, char);
	int (*proc_show)(struct seq_file___24 *, void *);
};

struct tty_driver___3 {
	int magic;
	struct kref kref;
	struct cdev___12 **cdevs;
	struct module___25 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___3 *other;
	struct tty_struct___3 **ttys;
	struct tty_port___3 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___3 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___3;

struct tty_port_client_operations___3;

struct tty_port___3 {
	struct tty_bufhead buf;
	struct tty_struct___3 *tty;
	struct tty_struct___3 *itty;
	const struct tty_port_operations___3 *ops;
	const struct tty_port_client_operations___3 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___3 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___3 *);
	void (*close)(struct tty_struct___3 *);
	void (*flush_buffer)(struct tty_struct___3 *);
	ssize_t (*read)(struct tty_struct___3 *, struct file___24 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___3 *, struct file___24 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___3 *, struct file___24 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___3 *, struct file___24 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___3 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___3 *, struct file___24 *, struct poll_table_struct___17 *);
	int (*hangup)(struct tty_struct___3 *);
	void (*receive_buf)(struct tty_struct___3 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___3 *);
	void (*dcd_change)(struct tty_struct___3 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___3 *, const unsigned char *, const char *, int);
	struct module___25 *owner;
};

struct tty_ldisc___3 {
	struct tty_ldisc_ops___3 *ops;
	struct tty_struct___3 *tty;
};

struct tty_port_operations___3 {
	int (*carrier_raised)(struct tty_port___3 *);
	void (*dtr_rts)(struct tty_port___3 *, int);
	void (*shutdown)(struct tty_port___3 *);
	int (*activate)(struct tty_port___3 *, struct tty_struct___3 *);
	void (*destruct)(struct tty_port___3 *);
};

struct tty_port_client_operations___3 {
	int (*receive_buf)(struct tty_port___3 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___3 *);
};

struct fs_parameter___3 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___24 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___3 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___25 *owner;
	char *buffer[8];
};

struct fs_context_operations___3 {
	void (*free)(struct fs_context___3 *);
	int (*dup)(struct fs_context___3 *, struct fs_context___3 *);
	int (*parse_param)(struct fs_context___3 *, struct fs_parameter___3 *);
	int (*parse_monolithic)(struct fs_context___3 *, void *);
	int (*get_tree)(struct fs_context___3 *);
	int (*reconfigure)(struct fs_context___3 *);
};

struct trace_event_raw_task_newtask {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	long unsigned int clone_flags;
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_raw_task_rename {
	struct trace_entry ent;
	pid_t pid;
	char oldcomm[16];
	char newcomm[16];
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_data_offsets_task_newtask {};

struct trace_event_data_offsets_task_rename {};

typedef void (*btf_trace_task_newtask)(void *, struct task_struct___25 *, long unsigned int);

typedef void (*btf_trace_task_rename)(void *, struct task_struct___25 *, const char *);

struct pipe_buf_operations___5;

struct pipe_buffer___5 {
	struct page___24 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___5 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___5 {
	int (*confirm)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	void (*release)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	bool (*try_steal)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
	bool (*get)(struct pipe_inode_info___5 *, struct pipe_buffer___5 *);
};

struct taint_flag {
	char c_true;
	char c_false;
	bool module;
};

enum ftrace_dump_mode {
	DUMP_NONE = 0,
	DUMP_ALL = 1,
	DUMP_ORIG = 2,
};

enum kmsg_dump_reason {
	KMSG_DUMP_UNDEF = 0,
	KMSG_DUMP_PANIC = 1,
	KMSG_DUMP_OOPS = 2,
	KMSG_DUMP_EMERG = 3,
	KMSG_DUMP_SHUTDOWN = 4,
	KMSG_DUMP_MAX = 5,
};

enum reboot_mode___2 {
	REBOOT_UNDEFINED___2 = 0,
	REBOOT_COLD___2 = 0,
	REBOOT_WARM___2 = 1,
	REBOOT_HARD___2 = 2,
	REBOOT_SOFT___2 = 3,
	REBOOT_GPIO___2 = 4,
};

enum con_flush_mode {
	CONSOLE_FLUSH_PENDING = 0,
	CONSOLE_REPLAY_ALL = 1,
};

struct warn_args {
	const char *fmt;
	va_list args;
};

struct dentry___25;

struct super_block___25;

struct module___26;

struct file_system_type___24 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___25 * (*mount)(struct file_system_type___24 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___25 *);
	struct module___26 *owner;
	struct file_system_type___24 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___25;

struct kiocb___24;

struct iov_iter___11;

struct poll_table_struct___18;

struct vm_area_struct___24;

struct inode___26;

struct file_lock___24;

struct page___25;

struct seq_file___25;

struct file_operations___24 {
	struct module___26 *owner;
	loff_t (*llseek)(struct file___25 *, loff_t, int);
	ssize_t (*read)(struct file___25 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___25 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___24 *, struct iov_iter___11 *);
	ssize_t (*write_iter)(struct kiocb___24 *, struct iov_iter___11 *);
	int (*iopoll)(struct kiocb___24 *, bool);
	int (*iterate)(struct file___25 *, struct dir_context *);
	int (*iterate_shared)(struct file___25 *, struct dir_context *);
	__poll_t (*poll)(struct file___25 *, struct poll_table_struct___18 *);
	long int (*unlocked_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___25 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___25 *, struct vm_area_struct___24 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___26 *, struct file___25 *);
	int (*flush)(struct file___25 *, fl_owner_t);
	int (*release)(struct inode___26 *, struct file___25 *);
	int (*fsync)(struct file___25 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___25 *, int);
	int (*lock)(struct file___25 *, int, struct file_lock___24 *);
	ssize_t (*sendpage)(struct file___25 *, struct page___25 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___25 *, long unsigned int);
	int (*flock)(struct file___25 *, int, struct file_lock___24 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___25 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___25 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___25 *, long int, struct file_lock___24 **, void **);
	long int (*fallocate)(struct file___25 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___25 *, struct file___25 *);
	ssize_t (*copy_file_range)(struct file___25 *, loff_t, struct file___25 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___25 *, loff_t, struct file___25 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___25 *, loff_t, loff_t, int);
};

struct vmacache___24 {
	u64 seqnum;
	struct vm_area_struct___24 *vmas[4];
};

struct page_frag___24 {
	struct page___25 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___15;

struct debug_info___15 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___15 *hbp_break[16];
	struct perf_event___15 *hbp_watch[16];
};

struct thread_struct___15 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___15 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___25;

struct pid___23;

struct nsproxy___24;

struct signal_struct___25;

struct bio_list___9;

struct backing_dev_info___8;

struct io_context___10;

struct css_set___17;

struct perf_event_context___15;

struct mem_cgroup___8;

struct request_queue___11;

struct vm_struct___24;

struct task_struct___26 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___26 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___25 *mm;
	struct mm_struct___25 *active_mm;
	struct vmacache___24 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___26 *real_parent;
	struct task_struct___26 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___26 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___23 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___24 *nsproxy;
	struct signal_struct___25 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___26 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___9 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___8 *backing_dev_info;
	struct io_context___10 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___17 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___15 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___24 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___8 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___8 *active_memcg;
	struct request_queue___11 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___26 *oom_reaper_list;
	struct vm_struct___24 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___15 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___24;

struct kobj_type___24;

struct kernfs_node___24;

struct kobject___24 {
	const char *name;
	struct list_head entry;
	struct kobject___24 *parent;
	struct kset___24 *kset;
	struct kobj_type___24 *ktype;
	struct kernfs_node___24 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___24 {
	struct kobject___24 kobj;
	struct module___26 *mod;
	struct kobject___24 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___24 {
	struct module___26 *mod;
	struct latch_tree_node node;
};

struct module_layout___24 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___24 mtn;
};

struct module_attribute___24;

struct kernel_param___24;

struct trace_event_call___10;

struct module___26 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___24 mkobj;
	struct module_attribute___24 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___24 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___24 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___24 core_layout;
	struct module_layout___24 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___10 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___15 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___26 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___15)(struct perf_event___15 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___15;

struct fasync_struct___24;

struct pid_namespace___23;

struct perf_cgroup___15;

struct perf_event___15 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___15 *group_leader;
	struct pmu___15 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___15 hw;
	struct perf_event_context___15 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___15 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___26 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___24 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___15 *aux_event;
	void (*destroy)(struct perf_event___15 *);
	struct callback_head callback_head;
	struct pid_namespace___23 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___15 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___15 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___10 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___15 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___23 {
	int nr;
	struct pid_namespace___23 *ns;
};

struct pid_namespace___23 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___26 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___23 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___23 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___23 numbers[1];
};

typedef struct page___25 *pgtable_t___24;

struct address_space___24;

struct dev_pagemap___24;

struct page___25 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___24 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___5 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___25 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___24 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___25 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___24 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___24;

struct vm_area_struct___24 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___24 *vm_next;
	struct vm_area_struct___24 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___25 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___24 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___25 *vm_file;
	struct file___25 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___25 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___26 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___26 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___23 *pids[4];
	struct pid___23 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___25 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___24;

struct mm_struct___25 {
	struct {
		struct vm_area_struct___24 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___25 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___24 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___26 *owner;
		struct user_namespace *user_ns;
		struct file___25 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___17;

struct nsproxy___24 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___23 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___17 *cgroup_ns;
};

struct bio___9;

struct bio_list___9 {
	struct bio___9 *head;
	struct bio___9 *tail;
};

struct cgroup_subsys_state___17;

struct bdi_writeback___8 {
	struct backing_dev_info___8 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___17 *memcg_css;
	struct cgroup_subsys_state___17 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___22;

struct backing_dev_info___8 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___8 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___22 *dev;
	char dev_name[64];
	struct device___22 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___25 *debug_dir;
};

struct io_cq___9;

struct io_context___10 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___9 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___17;

struct css_set___17 {
	struct cgroup_subsys_state___17 *subsys[14];
	refcount_t refcount;
	struct css_set___17 *dom_cset;
	struct cgroup___17 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___17 *mg_src_cgrp;
	struct cgroup___17 *mg_dst_cgrp;
	struct css_set___17 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___15 {
	struct pmu___15 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___26 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___15 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___17;

struct cgroup_subsys_state___17 {
	struct cgroup___17 *cgroup;
	struct cgroup_subsys___17 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___17 *parent;
};

struct cgroup_file___17 {
	struct kernfs_node___24 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___8;

struct mem_cgroup_per_node___8;

struct mem_cgroup___8 {
	struct cgroup_subsys_state___17 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___17 events_file;
	struct cgroup_file___17 events_local_file;
	struct cgroup_file___17 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___8 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___26 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___8 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___9;

struct blk_integrity___9 {
	const struct blk_integrity_profile___9 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___9 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___9 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___10;

struct elevator_queue___9;

struct blk_mq_ops___9;

struct blk_mq_hw_ctx___9;

struct gendisk___9;

struct blkcg_gq___9;

struct blk_mq_tag_set___9;

struct request_queue___11 {
	struct request___10 *last_merge;
	struct elevator_queue___9 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___9 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___9 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___9 *disk;
	struct kobject___24 kobj;
	struct kobject___24 *mq_kobj;
	struct blk_integrity___9 integrity;
	struct device___22 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___9 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___9 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___9 bio_split;
	struct dentry___25 *debugfs_dir;
	struct dentry___25 *sched_debugfs_dir;
	struct dentry___25 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___24 {
	struct vm_struct___24 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___25 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___24;

struct address_space___24 {
	struct inode___26 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___24 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___24;

struct dev_pagemap___24 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___24 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___24;

struct path___24 {
	struct vfsmount___24 *mnt;
	struct dentry___25 *dentry;
};

struct fown_struct___23 {
	rwlock_t lock;
	struct pid___23 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___25 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___24 f_path;
	struct inode___26 *f_inode;
	const struct file_operations___24 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___23 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___24 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___24;

struct vm_operations_struct___24 {
	void (*open)(struct vm_area_struct___24 *);
	void (*close)(struct vm_area_struct___24 *);
	int (*may_split)(struct vm_area_struct___24 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___24 *);
	int (*mprotect)(struct vm_area_struct___24 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___24 *);
	vm_fault_t (*huge_fault)(struct vm_fault___24 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___24 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___24 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___24 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___24 *);
	int (*access)(struct vm_area_struct___24 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___24 *);
	int (*set_policy)(struct vm_area_struct___24 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___24 *, long unsigned int);
	struct page___25 * (*find_special_page)(struct vm_area_struct___24 *, long unsigned int);
};

struct core_thread___24 {
	struct task_struct___26 *task;
	struct core_thread___24 *next;
};

struct core_state___24 {
	atomic_t nr_threads;
	struct core_thread___24 dumper;
	struct completion startup;
};

struct vm_fault___24 {
	const struct {
		struct vm_area_struct___24 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___25 *cow_page;
	struct page___25 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___24 prealloc_pte;
};

struct pglist_data___9;

struct lruvec___9 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___9 *pgdat;
};

struct zone___9 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___9 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___9 {
	struct zone___9 *zone;
	int zone_idx;
};

struct zonelist___9 {
	struct zoneref___9 _zonerefs[321];
};

struct pglist_data___9 {
	struct zone___9 node_zones[5];
	struct zonelist___9 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___26 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___26 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___9 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___24;

struct dentry___25 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___25 *d_parent;
	struct qstr d_name;
	struct inode___26 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___24 *d_op;
	struct super_block___25 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___24;

struct inode___26 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___24 *i_op;
	struct super_block___25 *i_sb;
	struct address_space___24 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___8 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___24 *i_fop;
		void (*free_inode)(struct inode___26 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___24 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___5 *i_pipe;
		struct cdev___12 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___24 {
	int (*d_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___25 *, unsigned int);
	int (*d_hash)(const struct dentry___25 *, struct qstr *);
	int (*d_compare)(const struct dentry___25 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___25 *);
	int (*d_init)(struct dentry___25 *);
	void (*d_release)(struct dentry___25 *);
	void (*d_prune)(struct dentry___25 *);
	void (*d_iput)(struct dentry___25 *, struct inode___26 *);
	char * (*d_dname)(struct dentry___25 *, char *, int);
	struct vfsmount___24 * (*d_automount)(struct path___24 *);
	int (*d_manage)(const struct path___24 *, bool);
	struct dentry___25 * (*d_real)(struct dentry___25 *, const struct inode___26 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___24;

struct mem_dqinfo___24 {
	struct quota_format_type___24 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___24;

struct quota_info___24 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___26 *files[3];
	struct mem_dqinfo___24 info[3];
	const struct quota_format_ops___24 *ops[3];
};

struct rcuwait___24 {
	struct task_struct___26 *task;
};

struct percpu_rw_semaphore___24 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___24 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___24 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___24 rw_sem[3];
};

struct shrink_control___8;

struct shrinker___8 {
	long unsigned int (*count_objects)(struct shrinker___8 *, struct shrink_control___8 *);
	long unsigned int (*scan_objects)(struct shrinker___8 *, struct shrink_control___8 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___24;

struct dquot_operations___24;

struct quotactl_ops___24;

struct block_device___10;

struct super_block___25 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___24 *s_type;
	const struct super_operations___24 *s_op;
	const struct dquot_operations___24 *dq_op;
	const struct quotactl_ops___24 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___25 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___10 *s_bdev;
	struct backing_dev_info___8 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___24 s_dquot;
	struct sb_writers___24 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___24 *s_d_op;
	int cleancache_poolid;
	struct shrinker___8 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___24 {
	struct dentry___25 *mnt_root;
	struct super_block___25 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___8 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___8 *memcg;
};

struct psi_group___17 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___26 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___17;

struct cgroup_rstat_cpu___17;

struct cgroup___17 {
	struct cgroup_subsys_state___17 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___24 *kn;
	struct cgroup_file___17 procs_file;
	struct cgroup_file___17 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___17 *subsys[14];
	struct cgroup_root___17 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___17 *dom_cgrp;
	struct cgroup___17 *old_dom_cgrp;
	struct cgroup_rstat_cpu___17 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___17 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___9 {
	struct request_queue___11 *q;
	struct io_context___10 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___10;

struct kiocb___24 {
	struct file___25 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___24 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___10 *ki_waitq;
	};
};

struct iattr___25 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___25 *ia_file;
};

struct dquot___24 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___25 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___24 {
	int qf_fmt_id;
	const struct quota_format_ops___24 *qf_ops;
	struct module___26 *qf_owner;
	struct quota_format_type___24 *qf_next;
};

struct quota_format_ops___24 {
	int (*check_quota_file)(struct super_block___25 *, int);
	int (*read_file_info)(struct super_block___25 *, int);
	int (*write_file_info)(struct super_block___25 *, int);
	int (*free_file_info)(struct super_block___25 *, int);
	int (*read_dqblk)(struct dquot___24 *);
	int (*commit_dqblk)(struct dquot___24 *);
	int (*release_dqblk)(struct dquot___24 *);
	int (*get_next_id)(struct super_block___25 *, struct kqid *);
};

struct dquot_operations___24 {
	int (*write_dquot)(struct dquot___24 *);
	struct dquot___24 * (*alloc_dquot)(struct super_block___25 *, int);
	void (*destroy_dquot)(struct dquot___24 *);
	int (*acquire_dquot)(struct dquot___24 *);
	int (*release_dquot)(struct dquot___24 *);
	int (*mark_dirty)(struct dquot___24 *);
	int (*write_info)(struct super_block___25 *, int);
	qsize_t * (*get_reserved_space)(struct inode___26 *);
	int (*get_projid)(struct inode___26 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___26 *, qsize_t *);
	int (*get_next_id)(struct super_block___25 *, struct kqid *);
};

struct quotactl_ops___24 {
	int (*quota_on)(struct super_block___25 *, int, int, const struct path___24 *);
	int (*quota_off)(struct super_block___25 *, int);
	int (*quota_enable)(struct super_block___25 *, unsigned int);
	int (*quota_disable)(struct super_block___25 *, unsigned int);
	int (*quota_sync)(struct super_block___25 *, int);
	int (*set_info)(struct super_block___25 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___25 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___25 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___25 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___25 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___25 *, unsigned int);
};

struct wait_page_queue___10 {
	struct page___25 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___8;

struct readahead_control___10;

struct swap_info_struct___7;

struct address_space_operations___24 {
	int (*writepage)(struct page___25 *, struct writeback_control___8 *);
	int (*readpage)(struct file___25 *, struct page___25 *);
	int (*writepages)(struct address_space___24 *, struct writeback_control___8 *);
	int (*set_page_dirty)(struct page___25 *);
	int (*readpages)(struct file___25 *, struct address_space___24 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___10 *);
	int (*write_begin)(struct file___25 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___25 **, void **);
	int (*write_end)(struct file___25 *, struct address_space___24 *, loff_t, unsigned int, unsigned int, struct page___25 *, void *);
	sector_t (*bmap)(struct address_space___24 *, sector_t);
	void (*invalidatepage)(struct page___25 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___25 *, gfp_t);
	void (*freepage)(struct page___25 *);
	ssize_t (*direct_IO)(struct kiocb___24 *, struct iov_iter___11 *);
	int (*migratepage)(struct address_space___24 *, struct page___25 *, struct page___25 *, enum migrate_mode);
	bool (*isolate_page)(struct page___25 *, isolate_mode_t);
	void (*putback_page)(struct page___25 *);
	int (*launder_page)(struct page___25 *);
	int (*is_partially_uptodate)(struct page___25 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___25 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___24 *, struct page___25 *);
	int (*swap_activate)(struct swap_info_struct___7 *, struct file___25 *, sector_t *);
	void (*swap_deactivate)(struct file___25 *);
};

struct writeback_control___8 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___8 *wb;
	struct inode___26 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___10 {
	struct file___25 *file;
	struct address_space___24 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___11;

struct iov_iter___11 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___11 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___7 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___10 *bdev;
	struct file___25 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___24 {
	struct dentry___25 * (*lookup)(struct inode___26 *, struct dentry___25 *, unsigned int);
	const char * (*get_link)(struct dentry___25 *, struct inode___26 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___26 *, int);
	struct posix_acl * (*get_acl)(struct inode___26 *, int, bool);
	int (*readlink)(struct dentry___25 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___26 *, struct dentry___25 *, umode_t, bool);
	int (*link)(struct dentry___25 *, struct inode___26 *, struct dentry___25 *);
	int (*unlink)(struct inode___26 *, struct dentry___25 *);
	int (*symlink)(struct user_namespace *, struct inode___26 *, struct dentry___25 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___26 *, struct dentry___25 *, umode_t);
	int (*rmdir)(struct inode___26 *, struct dentry___25 *);
	int (*mknod)(struct user_namespace *, struct inode___26 *, struct dentry___25 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___26 *, struct dentry___25 *, struct inode___26 *, struct dentry___25 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___25 *, struct iattr___25 *);
	int (*getattr)(struct user_namespace *, const struct path___24 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___25 *, char *, size_t);
	int (*fiemap)(struct inode___26 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___26 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___26 *, struct dentry___25 *, struct file___25 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___26 *, struct dentry___25 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___26 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___25 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___25 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___24 {
	void (*fl_copy_lock)(struct file_lock___24 *, struct file_lock___24 *);
	void (*fl_release_private)(struct file_lock___24 *);
};

struct lock_manager_operations___24;

struct file_lock___24 {
	struct file_lock___24 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___25 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___24 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___24 *fl_ops;
	const struct lock_manager_operations___24 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___24 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___24 *);
	int (*lm_grant)(struct file_lock___24 *, int);
	bool (*lm_break)(struct file_lock___24 *);
	int (*lm_change)(struct file_lock___24 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___24 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___24 *);
};

struct fasync_struct___24 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___24 *fa_next;
	struct file___25 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___24 {
	struct inode___26 * (*alloc_inode)(struct super_block___25 *);
	void (*destroy_inode)(struct inode___26 *);
	void (*free_inode)(struct inode___26 *);
	void (*dirty_inode)(struct inode___26 *, int);
	int (*write_inode)(struct inode___26 *, struct writeback_control___8 *);
	int (*drop_inode)(struct inode___26 *);
	void (*evict_inode)(struct inode___26 *);
	void (*put_super)(struct super_block___25 *);
	int (*sync_fs)(struct super_block___25 *, int);
	int (*freeze_super)(struct super_block___25 *);
	int (*freeze_fs)(struct super_block___25 *);
	int (*thaw_super)(struct super_block___25 *);
	int (*unfreeze_fs)(struct super_block___25 *);
	int (*statfs)(struct dentry___25 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___25 *, int *, char *);
	void (*umount_begin)(struct super_block___25 *);
	int (*show_options)(struct seq_file___25 *, struct dentry___25 *);
	int (*show_devname)(struct seq_file___25 *, struct dentry___25 *);
	int (*show_path)(struct seq_file___25 *, struct dentry___25 *);
	int (*show_stats)(struct seq_file___25 *, struct dentry___25 *);
	ssize_t (*quota_read)(struct super_block___25 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___25 *, int, const char *, size_t, loff_t);
	struct dquot___24 ** (*get_dquots)(struct inode___26 *);
	long int (*nr_cached_objects)(struct super_block___25 *, struct shrink_control___8 *);
	long int (*free_cached_objects)(struct super_block___25 *, struct shrink_control___8 *);
	struct file___25 * (*real_loop)(struct file___25 *);
};

struct wakeup_source___22;

struct dev_pm_qos___5;

struct dev_pm_info___22 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___22 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___22 *, s32);
	struct dev_pm_qos___5 *qos;
};

struct device_type___22;

struct bus_type___22;

struct device_driver___22;

struct dev_pm_domain___22;

struct device_node___15;

struct fwnode_handle___22;

struct class___22;

struct attribute_group___24;

struct device___22 {
	struct kobject___24 kobj;
	struct device___22 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___22 *type;
	struct bus_type___22 *bus;
	struct device_driver___22 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___22 power;
	struct dev_pm_domain___22 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___15 *of_node;
	struct fwnode_handle___22 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___22 *class;
	const struct attribute_group___24 **groups;
	void (*release)(struct device___22 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___10 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___26 *bd_inode;
	struct super_block___25 *bd_super;
	void *bd_claiming;
	struct device___22 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___24 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___9 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___25 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___18)(struct file___25 *, wait_queue_head_t *, struct poll_table_struct___18 *);

struct poll_table_struct___18 {
	poll_queue_proc___18 _qproc;
	__poll_t _key;
};

struct seq_operations___23;

struct seq_file___25 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___23 *op;
	int poll_event;
	const struct file___25 *file;
	void *private;
};

typedef void bio_end_io_t___9(struct bio___9 *);

struct bio_vec___11 {
	struct page___25 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___9;

struct bio___9 {
	struct bio___9 *bi_next;
	struct block_device___10 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___9 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___9 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___9 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___11 *bi_io_vec;
	struct bio_set___9 *bi_pool;
	struct bio_vec___11 bi_inline_vecs[0];
};

struct kernfs_root___24;

struct kernfs_elem_dir___24 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___24 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___24;

struct kernfs_root___24 {
	struct kernfs_node___24 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___24 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___24 {
	struct kernfs_node___24 *target_kn;
};

struct kernfs_ops___24;

struct kernfs_elem_attr___24 {
	const struct kernfs_ops___24 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___24 *notify_next;
};

struct kernfs_node___24 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___24 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___24 dir;
		struct kernfs_elem_symlink___24 symlink;
		struct kernfs_elem_attr___24 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___24;

struct kernfs_ops___24 {
	int (*open)(struct kernfs_open_file___24 *);
	void (*release)(struct kernfs_open_file___24 *);
	int (*seq_show)(struct seq_file___25 *, void *);
	void * (*seq_start)(struct seq_file___25 *, loff_t *);
	void * (*seq_next)(struct seq_file___25 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___25 *, void *);
	ssize_t (*read)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___24 *, struct poll_table_struct___18 *);
	int (*mmap)(struct kernfs_open_file___24 *, struct vm_area_struct___24 *);
};

struct kernfs_syscall_ops___24 {
	int (*show_options)(struct seq_file___25 *, struct kernfs_root___24 *);
	int (*mkdir)(struct kernfs_node___24 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___24 *);
	int (*rename)(struct kernfs_node___24 *, struct kernfs_node___24 *, const char *);
	int (*show_path)(struct seq_file___25 *, struct kernfs_node___24 *, struct kernfs_root___24 *);
};

struct kernfs_open_file___24 {
	struct kernfs_node___24 *kn;
	struct file___25 *file;
	struct seq_file___25 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___24 *vm_ops;
};

struct bin_attribute___24;

struct attribute_group___24 {
	const char *name;
	umode_t (*is_visible)(struct kobject___24 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___24 *, struct bin_attribute___24 *, int);
	struct attribute **attrs;
	struct bin_attribute___24 **bin_attrs;
};

struct bin_attribute___24 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___24 * (*f_mapping)();
	ssize_t (*read)(struct file___25 *, struct kobject___24 *, struct bin_attribute___24 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___25 *, struct kobject___24 *, struct bin_attribute___24 *, char *, loff_t, size_t);
	int (*mmap)(struct file___25 *, struct kobject___24 *, struct bin_attribute___24 *, struct vm_area_struct___24 *);
};

struct sysfs_ops___24 {
	ssize_t (*show)(struct kobject___24 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___24 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___24;

struct kset___24 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___24 kobj;
	const struct kset_uevent_ops___24 *uevent_ops;
};

struct kobj_type___24 {
	void (*release)(struct kobject___24 *);
	const struct sysfs_ops___24 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___24 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___24 *);
	const void * (*namespace)(struct kobject___24 *);
	void (*get_ownership)(struct kobject___24 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___24 {
	int (* const filter)(struct kset___24 *, struct kobject___24 *);
	const char * (* const name)(struct kset___24 *, struct kobject___24 *);
	int (* const uevent)(struct kset___24 *, struct kobject___24 *, struct kobj_uevent_env *);
};

struct fwnode_operations___22;

struct fwnode_handle___22 {
	struct fwnode_handle___22 *secondary;
	const struct fwnode_operations___22 *ops;
	struct device___22 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___22;

struct fwnode_endpoint___22;

struct fwnode_operations___22 {
	struct fwnode_handle___22 * (*get)(struct fwnode_handle___22 *);
	void (*put)(struct fwnode_handle___22 *);
	bool (*device_is_available)(const struct fwnode_handle___22 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___22 *, const struct device___22 *);
	bool (*property_present)(const struct fwnode_handle___22 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___22 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___22 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___22 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_parent)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_next_child_node)(const struct fwnode_handle___22 *, struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*get_named_child_node)(const struct fwnode_handle___22 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___22 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___22 *);
	struct fwnode_handle___22 * (*graph_get_next_endpoint)(const struct fwnode_handle___22 *, struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*graph_get_remote_endpoint)(const struct fwnode_handle___22 *);
	struct fwnode_handle___22 * (*graph_get_port_parent)(struct fwnode_handle___22 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___22 *, struct fwnode_endpoint___22 *);
	int (*add_links)(struct fwnode_handle___22 *);
};

struct fwnode_endpoint___22 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___22 *local_fwnode;
};

struct fwnode_reference_args___22 {
	struct fwnode_handle___22 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___12 {
	char *name;
	int length;
	void *value;
	struct property___12 *next;
	long unsigned int _flags;
	struct bin_attribute___24 attr;
};

struct device_node___15 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___22 fwnode;
	struct property___12 *properties;
	struct property___12 *deadprops;
	struct device_node___15 *parent;
	struct device_node___15 *child;
	struct device_node___15 *sibling;
	struct kobject___24 kobj;
	long unsigned int _flags;
	void *data;
};

enum hk_flags {
	HK_FLAG_TIMER = 1,
	HK_FLAG_RCU = 2,
	HK_FLAG_MISC = 4,
	HK_FLAG_SCHED = 8,
	HK_FLAG_TICK = 16,
	HK_FLAG_DOMAIN = 32,
	HK_FLAG_WQ = 64,
	HK_FLAG_MANAGED_IRQ = 128,
	HK_FLAG_KTHREAD = 256,
};

struct dev_pm_ops___22 {
	int (*prepare)(struct device___22 *);
	void (*complete)(struct device___22 *);
	int (*suspend)(struct device___22 *);
	int (*resume)(struct device___22 *);
	int (*freeze)(struct device___22 *);
	int (*thaw)(struct device___22 *);
	int (*poweroff)(struct device___22 *);
	int (*restore)(struct device___22 *);
	int (*suspend_late)(struct device___22 *);
	int (*resume_early)(struct device___22 *);
	int (*freeze_late)(struct device___22 *);
	int (*thaw_early)(struct device___22 *);
	int (*poweroff_late)(struct device___22 *);
	int (*restore_early)(struct device___22 *);
	int (*suspend_noirq)(struct device___22 *);
	int (*resume_noirq)(struct device___22 *);
	int (*freeze_noirq)(struct device___22 *);
	int (*thaw_noirq)(struct device___22 *);
	int (*poweroff_noirq)(struct device___22 *);
	int (*restore_noirq)(struct device___22 *);
	int (*runtime_suspend)(struct device___22 *);
	int (*runtime_resume)(struct device___22 *);
	int (*runtime_idle)(struct device___22 *);
};

struct wakeup_source___22 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___22 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___5;

struct dev_pm_qos___5 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___5 *resume_latency_req;
	struct dev_pm_qos_request___5 *latency_tolerance_req;
	struct dev_pm_qos_request___5 *flags_req;
};

struct dev_pm_domain___22 {
	struct dev_pm_ops___22 ops;
	int (*start)(struct device___22 *);
	void (*detach)(struct device___22 *, bool);
	int (*activate)(struct device___22 *);
	void (*sync)(struct device___22 *);
	void (*dismiss)(struct device___22 *);
};

struct bus_type___22 {
	const char *name;
	const char *dev_name;
	struct device___22 *dev_root;
	const struct attribute_group___24 **bus_groups;
	const struct attribute_group___24 **dev_groups;
	const struct attribute_group___24 **drv_groups;
	int (*match)(struct device___22 *, struct device_driver___22 *);
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	int (*probe)(struct device___22 *);
	void (*sync_state)(struct device___22 *);
	void (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*online)(struct device___22 *);
	int (*offline)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	int (*num_vf)(struct device___22 *);
	int (*dma_configure)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___22 {
	const char *name;
	struct bus_type___22 *bus;
	struct module___26 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___22 *);
	void (*sync_state)(struct device___22 *);
	int (*remove)(struct device___22 *);
	void (*shutdown)(struct device___22 *);
	int (*suspend)(struct device___22 *, pm_message_t);
	int (*resume)(struct device___22 *);
	const struct attribute_group___24 **groups;
	const struct attribute_group___24 **dev_groups;
	const struct dev_pm_ops___22 *pm;
	void (*coredump)(struct device___22 *);
	struct driver_private *p;
};

struct device_type___22 {
	const char *name;
	const struct attribute_group___24 **groups;
	int (*uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___22 *);
	const struct dev_pm_ops___22 *pm;
};

struct class___22 {
	const char *name;
	struct module___26 *owner;
	const struct attribute_group___24 **class_groups;
	const struct attribute_group___24 **dev_groups;
	struct kobject___24 *dev_kobj;
	int (*dev_uevent)(struct device___22 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___22 *, umode_t *);
	void (*class_release)(struct class___22 *);
	void (*dev_release)(struct device___22 *);
	int (*shutdown_pre)(struct device___22 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___22 *);
	void (*get_ownership)(struct device___22 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___22 *pm;
	struct subsys_private *p;
};

struct device_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct device___22 *, struct device_attribute___4 *, char *);
	ssize_t (*store)(struct device___22 *, struct device_attribute___4 *, const char *, size_t);
};

enum cpuhp_smt_control {
	CPU_SMT_ENABLED = 0,
	CPU_SMT_DISABLED = 1,
	CPU_SMT_FORCE_DISABLED = 2,
	CPU_SMT_NOT_SUPPORTED = 3,
	CPU_SMT_NOT_IMPLEMENTED = 4,
};

struct dev_pagemap_ops___24 {
	void (*page_free)(struct page___25 *);
	void (*kill)(struct dev_pagemap___24 *);
	void (*cleanup)(struct dev_pagemap___24 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___24 *);
};

struct seq_operations___23 {
	void * (*start)(struct seq_file___25 *, loff_t *);
	void (*stop)(struct seq_file___25 *, void *);
	void * (*next)(struct seq_file___25 *, void *, loff_t *);
	int (*show)(struct seq_file___25 *, void *);
};

struct cgroup_namespace___17 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___17 *root_cset;
};

struct kernel_param_ops___24 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___24 *);
	int (*get)(char *, const struct kernel_param___24 *);
	void (*free)(void *);
};

struct kparam_array___24;

struct kernel_param___24 {
	const char *name;
	struct module___26 *mod;
	const struct kernel_param_ops___24 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___24 *arr;
	};
};

struct kparam_array___24 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___24 *ops;
	void *elem;
};

struct module_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___24 *, struct module_kobject___24 *, char *);
	ssize_t (*store)(struct module_attribute___24 *, struct module_kobject___24 *, const char *, size_t);
	void (*setup)(struct module___26 *, const char *);
	int (*test)(struct module___26 *);
	void (*free)(struct module___26 *);
};

struct trace_event_class___10;

struct trace_event_call___10 {
	struct list_head list;
	struct trace_event_class___10 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___2 *prog_array;
	int (*perf_perm)(struct trace_event_call___10 *, struct perf_event___15 *);
};

struct cftype___17;

struct cgroup_subsys___17 {
	struct cgroup_subsys_state___17 * (*css_alloc)(struct cgroup_subsys_state___17 *);
	int (*css_online)(struct cgroup_subsys_state___17 *);
	void (*css_offline)(struct cgroup_subsys_state___17 *);
	void (*css_released)(struct cgroup_subsys_state___17 *);
	void (*css_free)(struct cgroup_subsys_state___17 *);
	void (*css_reset)(struct cgroup_subsys_state___17 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___17 *, int);
	int (*css_extra_stat_show)(struct seq_file___25 *, struct cgroup_subsys_state___17 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___26 *, struct css_set___17 *);
	void (*cancel_fork)(struct task_struct___26 *, struct css_set___17 *);
	void (*fork)(struct task_struct___26 *);
	void (*exit)(struct task_struct___26 *);
	void (*release)(struct task_struct___26 *);
	void (*bind)(struct cgroup_subsys_state___17 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___17 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___17 *dfl_cftypes;
	struct cftype___17 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___17 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___17 *updated_children;
	struct cgroup___17 *updated_next;
};

struct cgroup_root___17 {
	struct kernfs_root___24 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___17 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___17 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___17 *ss;
	struct list_head node;
	struct kernfs_ops___24 *kf_ops;
	int (*open)(struct kernfs_open_file___24 *);
	void (*release)(struct kernfs_open_file___24 *);
	u64 (*read_u64)(struct cgroup_subsys_state___17 *, struct cftype___17 *);
	s64 (*read_s64)(struct cgroup_subsys_state___17 *, struct cftype___17 *);
	int (*seq_show)(struct seq_file___25 *, void *);
	void * (*seq_start)(struct seq_file___25 *, loff_t *);
	void * (*seq_next)(struct seq_file___25 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___25 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___17 *, struct cftype___17 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___17 *, struct cftype___17 *, s64);
	ssize_t (*write)(struct kernfs_open_file___24 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___24 *, struct poll_table_struct___18 *);
};

struct block_device_operations___9;

struct gendisk___9 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___10 *part0;
	const struct block_device_operations___9 *fops;
	struct request_queue___11 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___8 *bdi;
	struct kobject___24 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___24 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___9 {
	struct bio___9 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___11 *bip_vec;
	struct bio_vec___11 bip_inline_vecs[0];
};

struct blkcg___8;

struct blkg_policy_data___8;

struct blkcg_gq___9 {
	struct request_queue___11 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___8 *blkcg;
	struct blkcg_gq___9 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___8 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___9 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___9(struct request___10 *);

typedef void integrity_complete_fn___9(struct request___10 *, unsigned int);

struct blk_integrity_profile___9 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___9 *prepare_fn;
	integrity_complete_fn___9 *complete_fn;
	const char *name;
};

struct block_device_operations___9 {
	blk_qc_t (*submit_bio)(struct bio___9 *);
	int (*open)(struct block_device___10 *, fmode_t);
	void (*release)(struct gendisk___9 *, fmode_t);
	int (*rw_page)(struct block_device___10 *, sector_t, struct page___25 *, unsigned int);
	int (*ioctl)(struct block_device___10 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___10 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___9 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___9 *);
	int (*getgeo)(struct block_device___10 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___10 *, bool);
	void (*swap_slot_free_notify)(struct block_device___10 *, long unsigned int);
	int (*report_zones)(struct gendisk___9 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___9 *, umode_t *);
	struct module___26 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___9 *, sector_t *);
};

typedef void rq_end_io_fn___9(struct request___10 *, blk_status_t);

struct request___10 {
	struct request_queue___11 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___9 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___9 *bio;
	struct bio___9 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___11 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___9 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___9 *saved_end_io;
		} flush;
	};
	struct gendisk___9 *rq_disk;
	struct block_device___10 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___9 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___9 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___11 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___24 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___25 *debugfs_dir;
	struct dentry___25 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___9;

struct elevator_mq_ops___9 {
	int (*init_sched)(struct request_queue___11 *, struct elevator_type___9 *);
	void (*exit_sched)(struct elevator_queue___9 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___9 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___9 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___9 *);
	bool (*allow_merge)(struct request_queue___11 *, struct request___10 *, struct bio___9 *);
	bool (*bio_merge)(struct request_queue___11 *, struct bio___9 *, unsigned int);
	int (*request_merge)(struct request_queue___11 *, struct request___10 **, struct bio___9 *);
	void (*request_merged)(struct request_queue___11 *, struct request___10 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___11 *, struct request___10 *, struct request___10 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___10 *);
	void (*finish_request)(struct request___10 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___9 *, struct list_head *, bool);
	struct request___10 * (*dispatch_request)(struct blk_mq_hw_ctx___9 *);
	bool (*has_work)(struct blk_mq_hw_ctx___9 *);
	void (*completed_request)(struct request___10 *, u64);
	void (*requeue_request)(struct request___10 *);
	struct request___10 * (*former_request)(struct request_queue___11 *, struct request___10 *);
	struct request___10 * (*next_request)(struct request_queue___11 *, struct request___10 *);
	void (*init_icq)(struct io_cq___9 *);
	void (*exit_icq)(struct io_cq___9 *);
};

struct elv_fs_entry___9;

struct elevator_type___9 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___9 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___9 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___26 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___9 {
	struct elevator_type___9 *type;
	void *elevator_data;
	struct kobject___24 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___9 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___9 *, char *);
	ssize_t (*store)(struct elevator_queue___9 *, const char *, size_t);
};

struct blk_mq_queue_data___9;

struct blk_mq_ops___9 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___9 *, const struct blk_mq_queue_data___9 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___9 *);
	int (*get_budget)(struct request_queue___11 *);
	void (*put_budget)(struct request_queue___11 *, int);
	void (*set_rq_budget_token)(struct request___10 *, int);
	int (*get_rq_budget_token)(struct request___10 *);
	enum blk_eh_timer_return (*timeout)(struct request___10 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___9 *);
	void (*complete)(struct request___10 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___9 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___9 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___9 *, struct request___10 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___9 *, struct request___10 *, unsigned int);
	void (*initialize_rq_fn)(struct request___10 *);
	void (*cleanup_rq)(struct request___10 *);
	bool (*busy)(struct request_queue___11 *);
	int (*map_queues)(struct blk_mq_tag_set___9 *);
	void (*show_rq)(struct seq_file___25 *, struct request___10 *);
};

struct blk_mq_tag_set___9 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___9 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___9 {
	struct request___10 *rq;
	bool last;
};

struct blkcg_policy_data___8;

struct blkcg___8 {
	struct cgroup_subsys_state___17 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___9 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___8 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___8 {
	struct blkcg___8 *blkcg;
	int plid;
};

struct blkg_policy_data___8 {
	struct blkcg_gq___9 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___8 {
	struct mem_cgroup___8 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___8 {
	struct lruvec___9 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___8 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___8 *memcg;
};

struct obj_cgroup___8 {
	struct percpu_ref refcnt;
	struct mem_cgroup___8 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct smp_hotplug_thread {
	struct task_struct___26 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct dev_pm_qos_request___5 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___22 *dev;
};

struct perf_cpu_context___15;

struct perf_output_handle___15;

struct pmu___15 {
	struct list_head entry;
	struct module___26 *module;
	struct device___22 *dev;
	const struct attribute_group___24 **attr_groups;
	const struct attribute_group___24 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___15 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___15 *);
	void (*pmu_disable)(struct pmu___15 *);
	int (*event_init)(struct perf_event___15 *);
	void (*event_mapped)(struct perf_event___15 *, struct mm_struct___25 *);
	void (*event_unmapped)(struct perf_event___15 *, struct mm_struct___25 *);
	int (*add)(struct perf_event___15 *, int);
	void (*del)(struct perf_event___15 *, int);
	void (*start)(struct perf_event___15 *, int);
	void (*stop)(struct perf_event___15 *, int);
	void (*read)(struct perf_event___15 *);
	void (*start_txn)(struct pmu___15 *, unsigned int);
	int (*commit_txn)(struct pmu___15 *);
	void (*cancel_txn)(struct pmu___15 *);
	int (*event_idx)(struct perf_event___15 *);
	void (*sched_task)(struct perf_event_context___15 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___15 *, struct perf_event_context___15 *);
	void * (*setup_aux)(struct perf_event___15 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___15 *, struct perf_output_handle___15 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___15 *);
	int (*aux_output_match)(struct perf_event___15 *);
	int (*filter_match)(struct perf_event___15 *);
	int (*check_period)(struct perf_event___15 *, u64);
};

struct perf_cpu_context___15 {
	struct perf_event_context___15 ctx;
	struct perf_event_context___15 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___15 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___15 **heap;
	struct perf_event___15 *heap_default[2];
};

struct perf_output_handle___15 {
	struct perf_event___15 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___15 {
	struct cgroup_subsys_state___17 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___10 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___10 *);
	};
};

struct trace_event_class___10 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___10 *, enum trace_reg, void *);
	struct trace_event_fields___10 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___10 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___10 *);
};

struct trace_event_file___6;

struct trace_event_buffer___6 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___6 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___6 {
	struct list_head list;
	struct trace_event_call___10 *event_call;
	struct event_filter *filter;
	struct dentry___25 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_cpuhp_enter {
	struct trace_entry ent;
	unsigned int cpu;
	int target;
	int idx;
	void *fun;
	char __data[0];
};

struct trace_event_raw_cpuhp_multi_enter {
	struct trace_entry ent;
	unsigned int cpu;
	int target;
	int idx;
	void *fun;
	char __data[0];
};

struct trace_event_raw_cpuhp_exit {
	struct trace_entry ent;
	unsigned int cpu;
	int state;
	int idx;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_cpuhp_enter {};

struct trace_event_data_offsets_cpuhp_multi_enter {};

struct trace_event_data_offsets_cpuhp_exit {};

typedef void (*btf_trace_cpuhp_enter)(void *, unsigned int, int, int, int (*)(unsigned int));

typedef void (*btf_trace_cpuhp_multi_enter)(void *, unsigned int, int, int, int (*)(unsigned int, struct hlist_node *), struct hlist_node *);

typedef void (*btf_trace_cpuhp_exit)(void *, unsigned int, int, int, int);

struct cpuhp_cpu_state {
	enum cpuhp_state state;
	enum cpuhp_state target;
	enum cpuhp_state fail;
	struct task_struct___26 *thread;
	bool should_run;
	bool rollback;
	bool single;
	bool bringup;
	struct hlist_node *node;
	struct hlist_node *last;
	enum cpuhp_state cb_state;
	int result;
	struct completion done_up;
	struct completion done_down;
};

struct cpuhp_step {
	const char *name;
	union {
		int (*single)(unsigned int);
		int (*multi)(unsigned int, struct hlist_node *);
	} startup;
	union {
		int (*single)(unsigned int);
		int (*multi)(unsigned int, struct hlist_node *);
	} teardown;
	struct hlist_head list;
	bool cant_stop;
	bool multi_instance;
};

enum cpu_mitigations {
	CPU_MITIGATIONS_OFF = 0,
	CPU_MITIGATIONS_AUTO = 1,
	CPU_MITIGATIONS_AUTO_NOSMT = 2,
};

struct dentry___26;

struct super_block___26;

struct module___27;

struct file_system_type___25 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___26 * (*mount)(struct file_system_type___25 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___26 *);
	struct module___27 *owner;
	struct file_system_type___25 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___26;

struct kiocb___25;

struct iov_iter___12;

struct poll_table_struct___19;

struct vm_area_struct___25;

struct inode___27;

struct file_lock___25;

struct page___26;

struct pipe_inode_info___6;

struct seq_file___26;

struct file_operations___25 {
	struct module___27 *owner;
	loff_t (*llseek)(struct file___26 *, loff_t, int);
	ssize_t (*read)(struct file___26 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___26 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___25 *, struct iov_iter___12 *);
	ssize_t (*write_iter)(struct kiocb___25 *, struct iov_iter___12 *);
	int (*iopoll)(struct kiocb___25 *, bool);
	int (*iterate)(struct file___26 *, struct dir_context *);
	int (*iterate_shared)(struct file___26 *, struct dir_context *);
	__poll_t (*poll)(struct file___26 *, struct poll_table_struct___19 *);
	long int (*unlocked_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___26 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___26 *, struct vm_area_struct___25 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___27 *, struct file___26 *);
	int (*flush)(struct file___26 *, fl_owner_t);
	int (*release)(struct inode___27 *, struct file___26 *);
	int (*fsync)(struct file___26 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___26 *, int);
	int (*lock)(struct file___26 *, int, struct file_lock___25 *);
	ssize_t (*sendpage)(struct file___26 *, struct page___26 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___26 *, long unsigned int);
	int (*flock)(struct file___26 *, int, struct file_lock___25 *);
	ssize_t (*splice_write)(struct pipe_inode_info___6 *, struct file___26 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___26 *, loff_t *, struct pipe_inode_info___6 *, size_t, unsigned int);
	int (*setlease)(struct file___26 *, long int, struct file_lock___25 **, void **);
	long int (*fallocate)(struct file___26 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___26 *, struct file___26 *);
	ssize_t (*copy_file_range)(struct file___26 *, loff_t, struct file___26 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___26 *, loff_t, struct file___26 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___26 *, loff_t, loff_t, int);
};

struct __kernel_old_timeval {
	__kernel_long_t tv_sec;
	__kernel_long_t tv_usec;
};

struct vmacache___25 {
	u64 seqnum;
	struct vm_area_struct___25 *vmas[4];
};

struct page_frag___25 {
	struct page___26 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___16;

struct debug_info___16 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___16 *hbp_break[16];
	struct perf_event___16 *hbp_watch[16];
};

struct thread_struct___16 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___16 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___26;

struct pid___24;

struct fs_struct___3;

struct files_struct___2;

struct nsproxy___25;

struct signal_struct___26;

struct bio_list___10;

struct backing_dev_info___9;

struct io_context___11;

struct css_set___18;

struct perf_event_context___16;

struct mem_cgroup___9;

struct request_queue___12;

struct vm_struct___25;

struct task_struct___27 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___27 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___26 *mm;
	struct mm_struct___26 *active_mm;
	struct vmacache___25 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___27 *real_parent;
	struct task_struct___27 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___27 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___24 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___3 *fs;
	struct files_struct___2 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___25 *nsproxy;
	struct signal_struct___26 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___27 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___10 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___9 *backing_dev_info;
	struct io_context___11 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___18 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___16 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___6 *splice_pipe;
	struct page_frag___25 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___9 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___9 *active_memcg;
	struct request_queue___12 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___27 *oom_reaper_list;
	struct vm_struct___25 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___16 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___25;

struct kobj_type___25;

struct kernfs_node___25;

struct kobject___25 {
	const char *name;
	struct list_head entry;
	struct kobject___25 *parent;
	struct kset___25 *kset;
	struct kobj_type___25 *ktype;
	struct kernfs_node___25 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___25 {
	struct kobject___25 kobj;
	struct module___27 *mod;
	struct kobject___25 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___25 {
	struct module___27 *mod;
	struct latch_tree_node node;
};

struct module_layout___25 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___25 mtn;
};

struct module_attribute___25;

struct kernel_param___25;

struct trace_event_call___11;

struct module___27 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___25 mkobj;
	struct module_attribute___25 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___25 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___25 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___25 core_layout;
	struct module_layout___25 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___11 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___16 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___27 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___16)(struct perf_event___16 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___16;

struct fasync_struct___25;

struct pid_namespace___24;

struct perf_cgroup___16;

struct perf_event___16 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___16 *group_leader;
	struct pmu___16 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___16 hw;
	struct perf_event_context___16 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___16 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___27 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___25 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___16 *aux_event;
	void (*destroy)(struct perf_event___16 *);
	struct callback_head callback_head;
	struct pid_namespace___24 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___16 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___16 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___11 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___16 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___26 *pgtable_t___25;

struct address_space___25;

struct page_pool___6;

struct dev_pagemap___25;

struct page___26 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___25 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___6 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___26 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___25 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___26 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___25 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___25;

struct vm_area_struct___25 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___25 *vm_next;
	struct vm_area_struct___25 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___26 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___25 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___26 *vm_file;
	struct file___26 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___3;

struct core_state___25;

struct mm_struct___26 {
	struct {
		struct vm_area_struct___25 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___26 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___3 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___25 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___27 *owner;
		struct user_namespace *user_ns;
		struct file___26 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct old_timeval32 {
	old_time32_t tv_sec;
	s32 tv_usec;
};

struct address_space_operations___25;

struct address_space___25 {
	struct inode___27 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___25 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___23;

struct page_pool_params___6 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___23 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___6 {
	u32 count;
	struct page___26 *cache[128];
};

struct page_pool___6 {
	struct page_pool_params___6 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___26 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___6 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___25;

struct dev_pagemap___25 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___25 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___25;

struct path___25 {
	struct vfsmount___25 *mnt;
	struct dentry___26 *dentry;
};

struct fown_struct___24 {
	rwlock_t lock;
	struct pid___24 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___26 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___25 f_path;
	struct inode___27 *f_inode;
	const struct file_operations___25 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___24 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___25 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___25;

struct vm_operations_struct___25 {
	void (*open)(struct vm_area_struct___25 *);
	void (*close)(struct vm_area_struct___25 *);
	int (*may_split)(struct vm_area_struct___25 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___25 *);
	int (*mprotect)(struct vm_area_struct___25 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___25 *);
	vm_fault_t (*huge_fault)(struct vm_fault___25 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___25 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___25 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___25 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___25 *);
	int (*access)(struct vm_area_struct___25 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___25 *);
	int (*set_policy)(struct vm_area_struct___25 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___25 *, long unsigned int);
	struct page___26 * (*find_special_page)(struct vm_area_struct___25 *, long unsigned int);
};

struct core_thread___25 {
	struct task_struct___27 *task;
	struct core_thread___25 *next;
};

struct core_state___25 {
	atomic_t nr_threads;
	struct core_thread___25 dumper;
	struct completion startup;
};

struct linux_binprm___4;

struct coredump_params___3;

struct linux_binfmt___3 {
	struct list_head lh;
	struct module___27 *module;
	int (*load_binary)(struct linux_binprm___4 *);
	int (*load_shlib)(struct file___26 *);
	int (*core_dump)(struct coredump_params___3 *);
	long unsigned int min_coredump;
};

struct vm_fault___25 {
	const struct {
		struct vm_area_struct___25 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___26 *cow_page;
	struct page___26 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___25 prealloc_pte;
};

struct pglist_data___10;

struct lruvec___10 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___10 *pgdat;
};

struct zone___10 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___10 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___10 {
	struct zone___10 *zone;
	int zone_idx;
};

struct zonelist___10 {
	struct zoneref___10 _zonerefs[321];
};

struct pglist_data___10 {
	struct zone___10 node_zones[5];
	struct zonelist___10 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___27 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___27 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___10 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___9 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___9 *memcg;
};

struct cgroup___18;

struct cgroup_subsys___18;

struct cgroup_subsys_state___18 {
	struct cgroup___18 *cgroup;
	struct cgroup_subsys___18 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___18 *parent;
};

struct cgroup_file___18 {
	struct kernfs_node___25 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___9;

struct mem_cgroup_per_node___9;

struct mem_cgroup___9 {
	struct cgroup_subsys_state___18 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___18 events_file;
	struct cgroup_file___18 events_local_file;
	struct cgroup_file___18 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___9 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___27 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___9 *nodeinfo[0];
	long: 64;
};

struct shrinker___9 {
	long unsigned int (*count_objects)(struct shrinker___9 *, struct shrink_control___9 *);
	long unsigned int (*scan_objects)(struct shrinker___9 *, struct shrink_control___9 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct rusage {
	struct __kernel_old_timeval ru_utime;
	struct __kernel_old_timeval ru_stime;
	__kernel_long_t ru_maxrss;
	__kernel_long_t ru_ixrss;
	__kernel_long_t ru_idrss;
	__kernel_long_t ru_isrss;
	__kernel_long_t ru_minflt;
	__kernel_long_t ru_majflt;
	__kernel_long_t ru_nswap;
	__kernel_long_t ru_inblock;
	__kernel_long_t ru_oublock;
	__kernel_long_t ru_msgsnd;
	__kernel_long_t ru_msgrcv;
	__kernel_long_t ru_nsignals;
	__kernel_long_t ru_nvcsw;
	__kernel_long_t ru_nivcsw;
};

struct dev_pagemap_ops___25 {
	void (*page_free)(struct page___26 *);
	void (*kill)(struct dev_pagemap___25 *);
	void (*cleanup)(struct dev_pagemap___25 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___25 *);
};

struct upid___24 {
	int nr;
	struct pid_namespace___24 *ns;
};

struct pid_namespace___24 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___27 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___24 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___24 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___24 numbers[1];
};

struct tty_struct___4;

struct signal_struct___26 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___27 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___27 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___24 *pids[4];
	struct pid___24 *tty_old_pgrp;
	int leader;
	struct tty_struct___4 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___26 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___3 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___25 root;
	struct path___25 pwd;
};

struct fdtable___2 {
	unsigned int max_fds;
	struct file___26 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___2 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___2 *fdt;
	struct fdtable___2 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___26 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___18;

struct nsproxy___25 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___24 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___18 *cgroup_ns;
};

struct bio___10;

struct bio_list___10 {
	struct bio___10 *head;
	struct bio___10 *tail;
};

struct bdi_writeback___9 {
	struct backing_dev_info___9 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___18 *memcg_css;
	struct cgroup_subsys_state___18 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___9 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___9 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___23 *dev;
	char dev_name[64];
	struct device___23 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___26 *debug_dir;
};

struct io_cq___10;

struct io_context___11 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___10 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___18 {
	struct cgroup_subsys_state___18 *subsys[14];
	refcount_t refcount;
	struct css_set___18 *dom_cset;
	struct cgroup___18 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___18 *mg_src_cgrp;
	struct cgroup___18 *mg_dst_cgrp;
	struct css_set___18 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___16 {
	struct pmu___16 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___27 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___16 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___6;

struct pipe_inode_info___6 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___26 *tmp_page;
	struct fasync_struct___25 *fasync_readers;
	struct fasync_struct___25 *fasync_writers;
	struct pipe_buffer___6 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___10;

struct blk_integrity___10 {
	const struct blk_integrity_profile___10 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___10 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___10 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___11;

struct elevator_queue___10;

struct blk_mq_ops___10;

struct blk_mq_hw_ctx___10;

struct gendisk___10;

struct blkcg_gq___10;

struct blk_mq_tag_set___10;

struct request_queue___12 {
	struct request___11 *last_merge;
	struct elevator_queue___10 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___10 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___10 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___10 *disk;
	struct kobject___25 kobj;
	struct kobject___25 *mq_kobj;
	struct blk_integrity___10 integrity;
	struct device___23 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___10 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___10 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___10 bio_split;
	struct dentry___26 *debugfs_dir;
	struct dentry___26 *sched_debugfs_dir;
	struct dentry___26 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___25 {
	struct vm_struct___25 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___26 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___25;

struct dentry___26 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___26 *d_parent;
	struct qstr d_name;
	struct inode___27 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___25 *d_op;
	struct super_block___26 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___25;

struct cdev___13;

struct inode___27 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___25 *i_op;
	struct super_block___26 *i_sb;
	struct address_space___25 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___9 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___25 *i_fop;
		void (*free_inode)(struct inode___27 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___25 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___6 *i_pipe;
		struct cdev___13 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___25 {
	int (*d_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___26 *, unsigned int);
	int (*d_hash)(const struct dentry___26 *, struct qstr *);
	int (*d_compare)(const struct dentry___26 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___26 *);
	int (*d_init)(struct dentry___26 *);
	void (*d_release)(struct dentry___26 *);
	void (*d_prune)(struct dentry___26 *);
	void (*d_iput)(struct dentry___26 *, struct inode___27 *);
	char * (*d_dname)(struct dentry___26 *, char *, int);
	struct vfsmount___25 * (*d_automount)(struct path___25 *);
	int (*d_manage)(const struct path___25 *, bool);
	struct dentry___26 * (*d_real)(struct dentry___26 *, const struct inode___27 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___25;

struct mem_dqinfo___25 {
	struct quota_format_type___25 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___25;

struct quota_info___25 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___27 *files[3];
	struct mem_dqinfo___25 info[3];
	const struct quota_format_ops___25 *ops[3];
};

struct rcuwait___25 {
	struct task_struct___27 *task;
};

struct percpu_rw_semaphore___25 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___25 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___25 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___25 rw_sem[3];
};

struct super_operations___25;

struct dquot_operations___25;

struct quotactl_ops___25;

struct block_device___11;

struct super_block___26 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___25 *s_type;
	const struct super_operations___25 *s_op;
	const struct dquot_operations___25 *dq_op;
	const struct quotactl_ops___25 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___26 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___11 *s_bdev;
	struct backing_dev_info___9 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___25 s_dquot;
	struct sb_writers___25 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___25 *s_d_op;
	int cleancache_poolid;
	struct shrinker___9 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___25 {
	struct dentry___26 *mnt_root;
	struct super_block___26 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

typedef u32 compat_uint_t;

typedef struct {} mm_segment_t;

struct psi_group___18 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___27 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___18;

struct cgroup_rstat_cpu___18;

struct cgroup___18 {
	struct cgroup_subsys_state___18 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___25 *kn;
	struct cgroup_file___18 procs_file;
	struct cgroup_file___18 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___18 *subsys[14];
	struct cgroup_root___18 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___18 *dom_cgrp;
	struct cgroup___18 *old_dom_cgrp;
	struct cgroup_rstat_cpu___18 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___18 psi;
	struct cgroup_bpf___2 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___4;

struct tty_operations___4;

struct tty_ldisc___4;

struct tty_port___4;

struct tty_struct___4 {
	int magic;
	struct kref kref;
	struct device___23 *dev;
	struct tty_driver___4 *driver;
	const struct tty_operations___4 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___4 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___24 *pgrp;
		struct pid___24 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___4 *link;
	struct fasync_struct___25 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___4 *port;
};

struct io_cq___10 {
	struct request_queue___12 *q;
	struct io_context___11 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___11;

struct kiocb___25 {
	struct file___26 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___25 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___11 *ki_waitq;
	};
};

struct iattr___26 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___26 *ia_file;
};

struct dquot___25 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___26 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___25 {
	int qf_fmt_id;
	const struct quota_format_ops___25 *qf_ops;
	struct module___27 *qf_owner;
	struct quota_format_type___25 *qf_next;
};

struct quota_format_ops___25 {
	int (*check_quota_file)(struct super_block___26 *, int);
	int (*read_file_info)(struct super_block___26 *, int);
	int (*write_file_info)(struct super_block___26 *, int);
	int (*free_file_info)(struct super_block___26 *, int);
	int (*read_dqblk)(struct dquot___25 *);
	int (*commit_dqblk)(struct dquot___25 *);
	int (*release_dqblk)(struct dquot___25 *);
	int (*get_next_id)(struct super_block___26 *, struct kqid *);
};

struct dquot_operations___25 {
	int (*write_dquot)(struct dquot___25 *);
	struct dquot___25 * (*alloc_dquot)(struct super_block___26 *, int);
	void (*destroy_dquot)(struct dquot___25 *);
	int (*acquire_dquot)(struct dquot___25 *);
	int (*release_dquot)(struct dquot___25 *);
	int (*mark_dirty)(struct dquot___25 *);
	int (*write_info)(struct super_block___26 *, int);
	qsize_t * (*get_reserved_space)(struct inode___27 *);
	int (*get_projid)(struct inode___27 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___27 *, qsize_t *);
	int (*get_next_id)(struct super_block___26 *, struct kqid *);
};

struct quotactl_ops___25 {
	int (*quota_on)(struct super_block___26 *, int, int, const struct path___25 *);
	int (*quota_off)(struct super_block___26 *, int);
	int (*quota_enable)(struct super_block___26 *, unsigned int);
	int (*quota_disable)(struct super_block___26 *, unsigned int);
	int (*quota_sync)(struct super_block___26 *, int);
	int (*set_info)(struct super_block___26 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___26 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___26 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___26 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___26 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___26 *, unsigned int);
};

struct wait_page_queue___11 {
	struct page___26 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___9;

struct readahead_control___11;

struct address_space_operations___25 {
	int (*writepage)(struct page___26 *, struct writeback_control___9 *);
	int (*readpage)(struct file___26 *, struct page___26 *);
	int (*writepages)(struct address_space___25 *, struct writeback_control___9 *);
	int (*set_page_dirty)(struct page___26 *);
	int (*readpages)(struct file___26 *, struct address_space___25 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___11 *);
	int (*write_begin)(struct file___26 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___26 **, void **);
	int (*write_end)(struct file___26 *, struct address_space___25 *, loff_t, unsigned int, unsigned int, struct page___26 *, void *);
	sector_t (*bmap)(struct address_space___25 *, sector_t);
	void (*invalidatepage)(struct page___26 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___26 *, gfp_t);
	void (*freepage)(struct page___26 *);
	ssize_t (*direct_IO)(struct kiocb___25 *, struct iov_iter___12 *);
	int (*migratepage)(struct address_space___25 *, struct page___26 *, struct page___26 *, enum migrate_mode);
	bool (*isolate_page)(struct page___26 *, isolate_mode_t);
	void (*putback_page)(struct page___26 *);
	int (*launder_page)(struct page___26 *);
	int (*is_partially_uptodate)(struct page___26 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___26 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___25 *, struct page___26 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___26 *, sector_t *);
	void (*swap_deactivate)(struct file___26 *);
};

struct writeback_control___9 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___9 *wb;
	struct inode___27 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___11 {
	struct file___26 *file;
	struct address_space___25 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___12;

struct iov_iter___12 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___12 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___6 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___13 {
	struct kobject___25 kobj;
	struct module___27 *owner;
	const struct file_operations___25 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___25 {
	struct dentry___26 * (*lookup)(struct inode___27 *, struct dentry___26 *, unsigned int);
	const char * (*get_link)(struct dentry___26 *, struct inode___27 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___27 *, int);
	struct posix_acl * (*get_acl)(struct inode___27 *, int, bool);
	int (*readlink)(struct dentry___26 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___27 *, struct dentry___26 *, umode_t, bool);
	int (*link)(struct dentry___26 *, struct inode___27 *, struct dentry___26 *);
	int (*unlink)(struct inode___27 *, struct dentry___26 *);
	int (*symlink)(struct user_namespace *, struct inode___27 *, struct dentry___26 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___27 *, struct dentry___26 *, umode_t);
	int (*rmdir)(struct inode___27 *, struct dentry___26 *);
	int (*mknod)(struct user_namespace *, struct inode___27 *, struct dentry___26 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___27 *, struct dentry___26 *, struct inode___27 *, struct dentry___26 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___26 *, struct iattr___26 *);
	int (*getattr)(struct user_namespace *, const struct path___25 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___26 *, char *, size_t);
	int (*fiemap)(struct inode___27 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___27 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___27 *, struct dentry___26 *, struct file___26 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___27 *, struct dentry___26 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___27 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___26 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___26 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___25 {
	void (*fl_copy_lock)(struct file_lock___25 *, struct file_lock___25 *);
	void (*fl_release_private)(struct file_lock___25 *);
};

struct lock_manager_operations___25;

struct file_lock___25 {
	struct file_lock___25 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___26 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___25 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___25 *fl_ops;
	const struct lock_manager_operations___25 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___25 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___25 *);
	int (*lm_grant)(struct file_lock___25 *, int);
	bool (*lm_break)(struct file_lock___25 *);
	int (*lm_change)(struct file_lock___25 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___25 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___25 *);
};

struct fasync_struct___25 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___25 *fa_next;
	struct file___26 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___25 {
	struct inode___27 * (*alloc_inode)(struct super_block___26 *);
	void (*destroy_inode)(struct inode___27 *);
	void (*free_inode)(struct inode___27 *);
	void (*dirty_inode)(struct inode___27 *, int);
	int (*write_inode)(struct inode___27 *, struct writeback_control___9 *);
	int (*drop_inode)(struct inode___27 *);
	void (*evict_inode)(struct inode___27 *);
	void (*put_super)(struct super_block___26 *);
	int (*sync_fs)(struct super_block___26 *, int);
	int (*freeze_super)(struct super_block___26 *);
	int (*freeze_fs)(struct super_block___26 *);
	int (*thaw_super)(struct super_block___26 *);
	int (*unfreeze_fs)(struct super_block___26 *);
	int (*statfs)(struct dentry___26 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___26 *, int *, char *);
	void (*umount_begin)(struct super_block___26 *);
	int (*show_options)(struct seq_file___26 *, struct dentry___26 *);
	int (*show_devname)(struct seq_file___26 *, struct dentry___26 *);
	int (*show_path)(struct seq_file___26 *, struct dentry___26 *);
	int (*show_stats)(struct seq_file___26 *, struct dentry___26 *);
	ssize_t (*quota_read)(struct super_block___26 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___26 *, int, const char *, size_t, loff_t);
	struct dquot___25 ** (*get_dquots)(struct inode___27 *);
	long int (*nr_cached_objects)(struct super_block___26 *, struct shrink_control___9 *);
	long int (*free_cached_objects)(struct super_block___26 *, struct shrink_control___9 *);
	struct file___26 * (*real_loop)(struct file___26 *);
};

struct wakeup_source___23;

struct dev_pm_info___23 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___23 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___23 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___23;

struct bus_type___23;

struct device_driver___23;

struct dev_pm_domain___23;

struct fwnode_handle___23;

struct class___23;

struct attribute_group___25;

struct device___23 {
	struct kobject___25 kobj;
	struct device___23 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___23 *type;
	struct bus_type___23 *bus;
	struct device_driver___23 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___23 power;
	struct dev_pm_domain___23 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___23 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___23 *class;
	const struct attribute_group___25 **groups;
	void (*release)(struct device___23 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___11 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___27 *bd_inode;
	struct super_block___26 *bd_super;
	void *bd_claiming;
	struct device___23 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___25 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___10 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___26 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___19)(struct file___26 *, wait_queue_head_t *, struct poll_table_struct___19 *);

struct poll_table_struct___19 {
	poll_queue_proc___19 _qproc;
	__poll_t _key;
};

struct seq_operations___24;

struct seq_file___26 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___24 *op;
	int poll_event;
	const struct file___26 *file;
	void *private;
};

typedef void bio_end_io_t___10(struct bio___10 *);

struct bio_vec___12 {
	struct page___26 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___10;

struct bio___10 {
	struct bio___10 *bi_next;
	struct block_device___11 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___10 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___10 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___10 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___12 *bi_io_vec;
	struct bio_set___10 *bi_pool;
	struct bio_vec___12 bi_inline_vecs[0];
};

struct fwnode_operations___23;

struct fwnode_handle___23 {
	struct fwnode_handle___23 *secondary;
	const struct fwnode_operations___23 *ops;
	struct device___23 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___23;

struct fwnode_endpoint___23;

struct fwnode_operations___23 {
	struct fwnode_handle___23 * (*get)(struct fwnode_handle___23 *);
	void (*put)(struct fwnode_handle___23 *);
	bool (*device_is_available)(const struct fwnode_handle___23 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___23 *, const struct device___23 *);
	bool (*property_present)(const struct fwnode_handle___23 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___23 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___23 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___23 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_parent)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_next_child_node)(const struct fwnode_handle___23 *, struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*get_named_child_node)(const struct fwnode_handle___23 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___23 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___23 *);
	struct fwnode_handle___23 * (*graph_get_next_endpoint)(const struct fwnode_handle___23 *, struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*graph_get_remote_endpoint)(const struct fwnode_handle___23 *);
	struct fwnode_handle___23 * (*graph_get_port_parent)(struct fwnode_handle___23 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___23 *, struct fwnode_endpoint___23 *);
	int (*add_links)(struct fwnode_handle___23 *);
};

struct fwnode_endpoint___23 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___23 *local_fwnode;
};

struct fwnode_reference_args___23 {
	struct fwnode_handle___23 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___25;

struct kernfs_elem_dir___25 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___25 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___25;

struct kernfs_root___25 {
	struct kernfs_node___25 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___25 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___25 {
	struct kernfs_node___25 *target_kn;
};

struct kernfs_ops___25;

struct kernfs_elem_attr___25 {
	const struct kernfs_ops___25 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___25 *notify_next;
};

struct kernfs_node___25 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___25 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___25 dir;
		struct kernfs_elem_symlink___25 symlink;
		struct kernfs_elem_attr___25 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___25;

struct kernfs_ops___25 {
	int (*open)(struct kernfs_open_file___25 *);
	void (*release)(struct kernfs_open_file___25 *);
	int (*seq_show)(struct seq_file___26 *, void *);
	void * (*seq_start)(struct seq_file___26 *, loff_t *);
	void * (*seq_next)(struct seq_file___26 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___26 *, void *);
	ssize_t (*read)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___25 *, struct poll_table_struct___19 *);
	int (*mmap)(struct kernfs_open_file___25 *, struct vm_area_struct___25 *);
};

struct kernfs_syscall_ops___25 {
	int (*show_options)(struct seq_file___26 *, struct kernfs_root___25 *);
	int (*mkdir)(struct kernfs_node___25 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___25 *);
	int (*rename)(struct kernfs_node___25 *, struct kernfs_node___25 *, const char *);
	int (*show_path)(struct seq_file___26 *, struct kernfs_node___25 *, struct kernfs_root___25 *);
};

struct kernfs_open_file___25 {
	struct kernfs_node___25 *kn;
	struct file___26 *file;
	struct seq_file___26 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___25 *vm_ops;
};

struct bin_attribute___25;

struct attribute_group___25 {
	const char *name;
	umode_t (*is_visible)(struct kobject___25 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___25 *, struct bin_attribute___25 *, int);
	struct attribute **attrs;
	struct bin_attribute___25 **bin_attrs;
};

struct bin_attribute___25 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___25 * (*f_mapping)();
	ssize_t (*read)(struct file___26 *, struct kobject___25 *, struct bin_attribute___25 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___26 *, struct kobject___25 *, struct bin_attribute___25 *, char *, loff_t, size_t);
	int (*mmap)(struct file___26 *, struct kobject___25 *, struct bin_attribute___25 *, struct vm_area_struct___25 *);
};

struct sysfs_ops___25 {
	ssize_t (*show)(struct kobject___25 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___25 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___25;

struct kset___25 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___25 kobj;
	const struct kset_uevent_ops___25 *uevent_ops;
};

struct kobj_type___25 {
	void (*release)(struct kobject___25 *);
	const struct sysfs_ops___25 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___25 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___25 *);
	const void * (*namespace)(struct kobject___25 *);
	void (*get_ownership)(struct kobject___25 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___25 {
	int (* const filter)(struct kset___25 *, struct kobject___25 *);
	const char * (* const name)(struct kset___25 *, struct kobject___25 *);
	int (* const uevent)(struct kset___25 *, struct kobject___25 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___25 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___25 *);
	int (*get)(char *, const struct kernel_param___25 *);
	void (*free)(void *);
};

struct kparam_array___25;

struct kernel_param___25 {
	const char *name;
	struct module___27 *mod;
	const struct kernel_param_ops___25 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___25 *arr;
	};
};

struct kparam_array___25 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___25 *ops;
	void *elem;
};

struct module_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___25 *, struct module_kobject___25 *, char *);
	ssize_t (*store)(struct module_attribute___25 *, struct module_kobject___25 *, const char *, size_t);
	void (*setup)(struct module___27 *, const char *);
	int (*test)(struct module___27 *);
	void (*free)(struct module___27 *);
};

struct trace_event_class___11;

struct trace_event_call___11 {
	struct list_head list;
	struct trace_event_class___11 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___11 *, struct perf_event___16 *);
};

struct dev_pm_ops___23 {
	int (*prepare)(struct device___23 *);
	void (*complete)(struct device___23 *);
	int (*suspend)(struct device___23 *);
	int (*resume)(struct device___23 *);
	int (*freeze)(struct device___23 *);
	int (*thaw)(struct device___23 *);
	int (*poweroff)(struct device___23 *);
	int (*restore)(struct device___23 *);
	int (*suspend_late)(struct device___23 *);
	int (*resume_early)(struct device___23 *);
	int (*freeze_late)(struct device___23 *);
	int (*thaw_early)(struct device___23 *);
	int (*poweroff_late)(struct device___23 *);
	int (*restore_early)(struct device___23 *);
	int (*suspend_noirq)(struct device___23 *);
	int (*resume_noirq)(struct device___23 *);
	int (*freeze_noirq)(struct device___23 *);
	int (*thaw_noirq)(struct device___23 *);
	int (*poweroff_noirq)(struct device___23 *);
	int (*restore_noirq)(struct device___23 *);
	int (*runtime_suspend)(struct device___23 *);
	int (*runtime_resume)(struct device___23 *);
	int (*runtime_idle)(struct device___23 *);
};

struct wakeup_source___23 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___23 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___23 {
	struct dev_pm_ops___23 ops;
	int (*start)(struct device___23 *);
	void (*detach)(struct device___23 *, bool);
	int (*activate)(struct device___23 *);
	void (*sync)(struct device___23 *);
	void (*dismiss)(struct device___23 *);
};

struct bus_type___23 {
	const char *name;
	const char *dev_name;
	struct device___23 *dev_root;
	const struct attribute_group___25 **bus_groups;
	const struct attribute_group___25 **dev_groups;
	const struct attribute_group___25 **drv_groups;
	int (*match)(struct device___23 *, struct device_driver___23 *);
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	int (*probe)(struct device___23 *);
	void (*sync_state)(struct device___23 *);
	void (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*online)(struct device___23 *);
	int (*offline)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	int (*num_vf)(struct device___23 *);
	int (*dma_configure)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___23 {
	const char *name;
	struct bus_type___23 *bus;
	struct module___27 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___23 *);
	void (*sync_state)(struct device___23 *);
	int (*remove)(struct device___23 *);
	void (*shutdown)(struct device___23 *);
	int (*suspend)(struct device___23 *, pm_message_t);
	int (*resume)(struct device___23 *);
	const struct attribute_group___25 **groups;
	const struct attribute_group___25 **dev_groups;
	const struct dev_pm_ops___23 *pm;
	void (*coredump)(struct device___23 *);
	struct driver_private *p;
};

struct device_type___23 {
	const char *name;
	const struct attribute_group___25 **groups;
	int (*uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___23 *);
	const struct dev_pm_ops___23 *pm;
};

struct class___23 {
	const char *name;
	struct module___27 *owner;
	const struct attribute_group___25 **class_groups;
	const struct attribute_group___25 **dev_groups;
	struct kobject___25 *dev_kobj;
	int (*dev_uevent)(struct device___23 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___23 *, umode_t *);
	void (*class_release)(struct class___23 *);
	void (*dev_release)(struct device___23 *);
	int (*shutdown_pre)(struct device___23 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___23 *);
	void (*get_ownership)(struct device___23 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___23 *pm;
	struct subsys_private *p;
};

struct seq_operations___24 {
	void * (*start)(struct seq_file___26 *, loff_t *);
	void (*stop)(struct seq_file___26 *, void *);
	void * (*next)(struct seq_file___26 *, void *, loff_t *);
	int (*show)(struct seq_file___26 *, void *);
};

struct tty_operations___4 {
	struct tty_struct___4 * (*lookup)(struct tty_driver___4 *, struct file___26 *, int);
	int (*install)(struct tty_driver___4 *, struct tty_struct___4 *);
	void (*remove)(struct tty_driver___4 *, struct tty_struct___4 *);
	int (*open)(struct tty_struct___4 *, struct file___26 *);
	void (*close)(struct tty_struct___4 *, struct file___26 *);
	void (*shutdown)(struct tty_struct___4 *);
	void (*cleanup)(struct tty_struct___4 *);
	int (*write)(struct tty_struct___4 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___4 *, unsigned char);
	void (*flush_chars)(struct tty_struct___4 *);
	unsigned int (*write_room)(struct tty_struct___4 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___4 *);
	int (*ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___4 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	void (*throttle)(struct tty_struct___4 *);
	void (*unthrottle)(struct tty_struct___4 *);
	void (*stop)(struct tty_struct___4 *);
	void (*start)(struct tty_struct___4 *);
	void (*hangup)(struct tty_struct___4 *);
	int (*break_ctl)(struct tty_struct___4 *, int);
	void (*flush_buffer)(struct tty_struct___4 *);
	void (*set_ldisc)(struct tty_struct___4 *);
	void (*wait_until_sent)(struct tty_struct___4 *, int);
	void (*send_xchar)(struct tty_struct___4 *, char);
	int (*tiocmget)(struct tty_struct___4 *);
	int (*tiocmset)(struct tty_struct___4 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___4 *, struct winsize *);
	int (*get_icount)(struct tty_struct___4 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___4 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___4 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___4 *, struct seq_file___26 *);
	int (*poll_init)(struct tty_driver___4 *, int, char *);
	int (*poll_get_char)(struct tty_driver___4 *, int);
	void (*poll_put_char)(struct tty_driver___4 *, int, char);
	int (*proc_show)(struct seq_file___26 *, void *);
};

struct tty_driver___4 {
	int magic;
	struct kref kref;
	struct cdev___13 **cdevs;
	struct module___27 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___4 *other;
	struct tty_struct___4 **ttys;
	struct tty_port___4 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___4 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___4;

struct tty_port_client_operations___4;

struct tty_port___4 {
	struct tty_bufhead buf;
	struct tty_struct___4 *tty;
	struct tty_struct___4 *itty;
	const struct tty_port_operations___4 *ops;
	const struct tty_port_client_operations___4 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___4 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___4 *);
	void (*close)(struct tty_struct___4 *);
	void (*flush_buffer)(struct tty_struct___4 *);
	ssize_t (*read)(struct tty_struct___4 *, struct file___26 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___4 *, struct file___26 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___4 *, struct file___26 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___4 *, struct file___26 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___4 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___4 *, struct file___26 *, struct poll_table_struct___19 *);
	int (*hangup)(struct tty_struct___4 *);
	void (*receive_buf)(struct tty_struct___4 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___4 *);
	void (*dcd_change)(struct tty_struct___4 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___4 *, const unsigned char *, const char *, int);
	struct module___27 *owner;
};

struct tty_ldisc___4 {
	struct tty_ldisc_ops___4 *ops;
	struct tty_struct___4 *tty;
};

struct tty_port_operations___4 {
	int (*carrier_raised)(struct tty_port___4 *);
	void (*dtr_rts)(struct tty_port___4 *, int);
	void (*shutdown)(struct tty_port___4 *);
	int (*activate)(struct tty_port___4 *, struct tty_struct___4 *);
	void (*destruct)(struct tty_port___4 *);
};

struct tty_port_client_operations___4 {
	int (*receive_buf)(struct tty_port___4 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___4 *);
};

struct linux_binprm___4 {
	struct vm_area_struct___25 *vma;
	long unsigned int vma_pages;
	struct mm_struct___26 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___26 *executable;
	struct file___26 *interpreter;
	struct file___26 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___3 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___26 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct cgroup_namespace___18 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___18 *root_cset;
};

struct compat_rusage {
	struct old_timeval32 ru_utime;
	struct old_timeval32 ru_stime;
	compat_long_t ru_maxrss;
	compat_long_t ru_ixrss;
	compat_long_t ru_idrss;
	compat_long_t ru_isrss;
	compat_long_t ru_minflt;
	compat_long_t ru_majflt;
	compat_long_t ru_nswap;
	compat_long_t ru_inblock;
	compat_long_t ru_oublock;
	compat_long_t ru_msgsnd;
	compat_long_t ru_msgrcv;
	compat_long_t ru_nsignals;
	compat_long_t ru_nvcsw;
	compat_long_t ru_nivcsw;
};

struct cftype___18;

struct cgroup_subsys___18 {
	struct cgroup_subsys_state___18 * (*css_alloc)(struct cgroup_subsys_state___18 *);
	int (*css_online)(struct cgroup_subsys_state___18 *);
	void (*css_offline)(struct cgroup_subsys_state___18 *);
	void (*css_released)(struct cgroup_subsys_state___18 *);
	void (*css_free)(struct cgroup_subsys_state___18 *);
	void (*css_reset)(struct cgroup_subsys_state___18 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___18 *, int);
	int (*css_extra_stat_show)(struct seq_file___26 *, struct cgroup_subsys_state___18 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___27 *, struct css_set___18 *);
	void (*cancel_fork)(struct task_struct___27 *, struct css_set___18 *);
	void (*fork)(struct task_struct___27 *);
	void (*exit)(struct task_struct___27 *);
	void (*release)(struct task_struct___27 *);
	void (*bind)(struct cgroup_subsys_state___18 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___18 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___18 *dfl_cftypes;
	struct cftype___18 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___18 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___18 *updated_children;
	struct cgroup___18 *updated_next;
};

struct cgroup_root___18 {
	struct kernfs_root___25 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___18 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___18 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___18 *ss;
	struct list_head node;
	struct kernfs_ops___25 *kf_ops;
	int (*open)(struct kernfs_open_file___25 *);
	void (*release)(struct kernfs_open_file___25 *);
	u64 (*read_u64)(struct cgroup_subsys_state___18 *, struct cftype___18 *);
	s64 (*read_s64)(struct cgroup_subsys_state___18 *, struct cftype___18 *);
	int (*seq_show)(struct seq_file___26 *, void *);
	void * (*seq_start)(struct seq_file___26 *, loff_t *);
	void * (*seq_next)(struct seq_file___26 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___26 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___18 *, struct cftype___18 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___18 *, struct cftype___18 *, s64);
	ssize_t (*write)(struct kernfs_open_file___25 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___25 *, struct poll_table_struct___19 *);
};

struct perf_cpu_context___16;

struct perf_output_handle___16;

struct pmu___16 {
	struct list_head entry;
	struct module___27 *module;
	struct device___23 *dev;
	const struct attribute_group___25 **attr_groups;
	const struct attribute_group___25 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___16 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___16 *);
	void (*pmu_disable)(struct pmu___16 *);
	int (*event_init)(struct perf_event___16 *);
	void (*event_mapped)(struct perf_event___16 *, struct mm_struct___26 *);
	void (*event_unmapped)(struct perf_event___16 *, struct mm_struct___26 *);
	int (*add)(struct perf_event___16 *, int);
	void (*del)(struct perf_event___16 *, int);
	void (*start)(struct perf_event___16 *, int);
	void (*stop)(struct perf_event___16 *, int);
	void (*read)(struct perf_event___16 *);
	void (*start_txn)(struct pmu___16 *, unsigned int);
	int (*commit_txn)(struct pmu___16 *);
	void (*cancel_txn)(struct pmu___16 *);
	int (*event_idx)(struct perf_event___16 *);
	void (*sched_task)(struct perf_event_context___16 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___16 *, struct perf_event_context___16 *);
	void * (*setup_aux)(struct perf_event___16 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___16 *, struct perf_output_handle___16 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___16 *);
	int (*aux_output_match)(struct perf_event___16 *);
	int (*filter_match)(struct perf_event___16 *);
	int (*check_period)(struct perf_event___16 *, u64);
};

struct perf_cpu_context___16 {
	struct perf_event_context___16 ctx;
	struct perf_event_context___16 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___16 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___16 **heap;
	struct perf_event___16 *heap_default[2];
};

struct perf_output_handle___16 {
	struct perf_event___16 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___16 {
	struct cgroup_subsys_state___18 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___11 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___11 *);
	};
};

struct trace_event_class___11 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___11 *, enum trace_reg, void *);
	struct trace_event_fields___11 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___11 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___11 *);
};

struct syscall_metadata___3 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___11 *enter_event;
	struct trace_event_call___11 *exit_event;
};

struct pipe_buf_operations___6;

struct pipe_buffer___6 {
	struct page___26 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___6 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___6 {
	int (*confirm)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	void (*release)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	bool (*try_steal)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
	bool (*get)(struct pipe_inode_info___6 *, struct pipe_buffer___6 *);
};

struct block_device_operations___10;

struct gendisk___10 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___11 *part0;
	const struct block_device_operations___10 *fops;
	struct request_queue___12 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___9 *bdi;
	struct kobject___25 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___25 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___10 {
	struct bio___10 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___12 *bip_vec;
	struct bio_vec___12 bip_inline_vecs[0];
};

struct blkcg___9;

struct blkg_policy_data___9;

struct blkcg_gq___10 {
	struct request_queue___12 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___9 *blkcg;
	struct blkcg_gq___10 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___9 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___10 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___10(struct request___11 *);

typedef void integrity_complete_fn___10(struct request___11 *, unsigned int);

struct blk_integrity_profile___10 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___10 *prepare_fn;
	integrity_complete_fn___10 *complete_fn;
	const char *name;
};

struct block_device_operations___10 {
	blk_qc_t (*submit_bio)(struct bio___10 *);
	int (*open)(struct block_device___11 *, fmode_t);
	void (*release)(struct gendisk___10 *, fmode_t);
	int (*rw_page)(struct block_device___11 *, sector_t, struct page___26 *, unsigned int);
	int (*ioctl)(struct block_device___11 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___11 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___10 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___10 *);
	int (*getgeo)(struct block_device___11 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___11 *, bool);
	void (*swap_slot_free_notify)(struct block_device___11 *, long unsigned int);
	int (*report_zones)(struct gendisk___10 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___10 *, umode_t *);
	struct module___27 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___10 *, sector_t *);
};

typedef void rq_end_io_fn___10(struct request___11 *, blk_status_t);

struct request___11 {
	struct request_queue___12 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___10 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___10 *bio;
	struct bio___10 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___12 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___10 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___10 *saved_end_io;
		} flush;
	};
	struct gendisk___10 *rq_disk;
	struct block_device___11 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___10 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___10 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___12 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___25 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___26 *debugfs_dir;
	struct dentry___26 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___10;

struct elevator_mq_ops___10 {
	int (*init_sched)(struct request_queue___12 *, struct elevator_type___10 *);
	void (*exit_sched)(struct elevator_queue___10 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___10 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___10 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___10 *);
	bool (*allow_merge)(struct request_queue___12 *, struct request___11 *, struct bio___10 *);
	bool (*bio_merge)(struct request_queue___12 *, struct bio___10 *, unsigned int);
	int (*request_merge)(struct request_queue___12 *, struct request___11 **, struct bio___10 *);
	void (*request_merged)(struct request_queue___12 *, struct request___11 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___12 *, struct request___11 *, struct request___11 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___11 *);
	void (*finish_request)(struct request___11 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___10 *, struct list_head *, bool);
	struct request___11 * (*dispatch_request)(struct blk_mq_hw_ctx___10 *);
	bool (*has_work)(struct blk_mq_hw_ctx___10 *);
	void (*completed_request)(struct request___11 *, u64);
	void (*requeue_request)(struct request___11 *);
	struct request___11 * (*former_request)(struct request_queue___12 *, struct request___11 *);
	struct request___11 * (*next_request)(struct request_queue___12 *, struct request___11 *);
	void (*init_icq)(struct io_cq___10 *);
	void (*exit_icq)(struct io_cq___10 *);
};

struct elv_fs_entry___10;

struct elevator_type___10 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___10 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___10 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___27 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___10 {
	struct elevator_type___10 *type;
	void *elevator_data;
	struct kobject___25 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___10 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___10 *, char *);
	ssize_t (*store)(struct elevator_queue___10 *, const char *, size_t);
};

struct blk_mq_queue_data___10;

struct blk_mq_ops___10 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___10 *, const struct blk_mq_queue_data___10 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___10 *);
	int (*get_budget)(struct request_queue___12 *);
	void (*put_budget)(struct request_queue___12 *, int);
	void (*set_rq_budget_token)(struct request___11 *, int);
	int (*get_rq_budget_token)(struct request___11 *);
	enum blk_eh_timer_return (*timeout)(struct request___11 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___10 *);
	void (*complete)(struct request___11 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___10 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___10 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___10 *, struct request___11 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___10 *, struct request___11 *, unsigned int);
	void (*initialize_rq_fn)(struct request___11 *);
	void (*cleanup_rq)(struct request___11 *);
	bool (*busy)(struct request_queue___12 *);
	int (*map_queues)(struct blk_mq_tag_set___10 *);
	void (*show_rq)(struct seq_file___26 *, struct request___11 *);
};

struct blk_mq_tag_set___10 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___10 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___10 {
	struct request___11 *rq;
	bool last;
};

struct blkcg_policy_data___9;

struct blkcg___9 {
	struct cgroup_subsys_state___18 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___10 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___9 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___9 {
	struct blkcg___9 *blkcg;
	int plid;
};

struct blkg_policy_data___9 {
	struct blkcg_gq___10 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___9 {
	struct mem_cgroup___9 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___9 {
	struct lruvec___10 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___9 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___9 *memcg;
};

struct obj_cgroup___9 {
	struct percpu_ref refcnt;
	struct mem_cgroup___9 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct waitid_info {
	pid_t pid;
	uid_t uid;
	int status;
	int cause;
};

struct wait_opts {
	enum pid_type wo_type;
	int wo_flags;
	struct pid___24 *wo_pid;
	struct waitid_info *wo_info;
	int wo_stat;
	struct rusage *wo_rusage;
	wait_queue_entry_t child_wait;
	int notask_error;
};

typedef struct {
	unsigned int __softirq_pending;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
} irq_cpustat_t;

struct softirq_action {
	void (*action)(struct softirq_action *);
};

struct tasklet_struct {
	struct tasklet_struct *next;
	long unsigned int state;
	atomic_t count;
	bool use_callback;
	union {
		void (*func)(long unsigned int);
		void (*callback)(struct tasklet_struct *);
	};
	long unsigned int data;
};

enum {
	TASKLET_STATE_SCHED = 0,
	TASKLET_STATE_RUN = 1,
};

struct kernel_stat {
	long unsigned int irqs_sum;
	unsigned int softirqs[10];
};

struct wait_bit_key {
	void *flags;
	int bit_nr;
	long unsigned int timeout;
};

struct wait_bit_queue_entry {
	struct wait_bit_key key;
	struct wait_queue_entry wq_entry;
};

struct smp_hotplug_thread___2 {
	struct task_struct___23 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct trace_event_raw_irq_handler_entry {
	struct trace_entry ent;
	int irq;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_irq_handler_exit {
	struct trace_entry ent;
	int irq;
	int ret;
	char __data[0];
};

struct trace_event_raw_softirq {
	struct trace_entry ent;
	unsigned int vec;
	char __data[0];
};

struct trace_event_data_offsets_irq_handler_entry {
	u32 name;
};

struct trace_event_data_offsets_irq_handler_exit {};

struct trace_event_data_offsets_softirq {};

typedef void (*btf_trace_irq_handler_entry)(void *, int, struct irqaction___8 *);

typedef void (*btf_trace_irq_handler_exit)(void *, int, struct irqaction___8 *, int);

typedef void (*btf_trace_softirq_entry)(void *, unsigned int);

typedef void (*btf_trace_softirq_exit)(void *, unsigned int);

typedef void (*btf_trace_softirq_raise)(void *, unsigned int);

struct tasklet_head {
	struct tasklet_struct *head;
	struct tasklet_struct **tail;
};

enum {
	IORES_DESC_NONE = 0,
	IORES_DESC_CRASH_KERNEL = 1,
	IORES_DESC_ACPI_TABLES = 2,
	IORES_DESC_ACPI_NV_STORAGE = 3,
	IORES_DESC_PERSISTENT_MEMORY = 4,
	IORES_DESC_PERSISTENT_MEMORY_LEGACY = 5,
	IORES_DESC_DEVICE_PRIVATE_MEMORY = 6,
	IORES_DESC_RESERVED = 7,
	IORES_DESC_SOFT_RESERVED = 8,
};

enum {
	REGION_INTERSECTS = 0,
	REGION_DISJOINT = 1,
	REGION_MIXED = 2,
};

struct pseudo_fs_context {
	const struct super_operations___23 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___23 *dops;
	long unsigned int magic;
};

typedef void (*dr_release_t)(struct device___21 *, void *);

typedef int (*dr_match_t)(struct device___21 *, void *, void *);

struct resource_constraint {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t (*alignf)(void *, const struct resource *, resource_size_t, resource_size_t);
	void *alignf_data;
};

enum {
	MAX_IORES_LEVEL = 5,
};

struct region_devres {
	struct resource *parent;
	resource_size_t start;
	resource_size_t n;
};

typedef __kernel_clock_t clock_t;

struct dentry___27;

struct super_block___27;

struct module___28;

struct file_system_type___26 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___27 * (*mount)(struct file_system_type___26 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___27 *);
	struct module___28 *owner;
	struct file_system_type___26 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___27;

struct kiocb___26;

struct iov_iter___13;

struct poll_table_struct___20;

struct vm_area_struct___26;

struct inode___28;

struct file_lock___26;

struct page___27;

struct pipe_inode_info___7;

struct seq_file___27;

struct file_operations___26 {
	struct module___28 *owner;
	loff_t (*llseek)(struct file___27 *, loff_t, int);
	ssize_t (*read)(struct file___27 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___27 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___26 *, struct iov_iter___13 *);
	ssize_t (*write_iter)(struct kiocb___26 *, struct iov_iter___13 *);
	int (*iopoll)(struct kiocb___26 *, bool);
	int (*iterate)(struct file___27 *, struct dir_context *);
	int (*iterate_shared)(struct file___27 *, struct dir_context *);
	__poll_t (*poll)(struct file___27 *, struct poll_table_struct___20 *);
	long int (*unlocked_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___27 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___27 *, struct vm_area_struct___26 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___28 *, struct file___27 *);
	int (*flush)(struct file___27 *, fl_owner_t);
	int (*release)(struct inode___28 *, struct file___27 *);
	int (*fsync)(struct file___27 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___27 *, int);
	int (*lock)(struct file___27 *, int, struct file_lock___26 *);
	ssize_t (*sendpage)(struct file___27 *, struct page___27 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___27 *, long unsigned int);
	int (*flock)(struct file___27 *, int, struct file_lock___26 *);
	ssize_t (*splice_write)(struct pipe_inode_info___7 *, struct file___27 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___27 *, loff_t *, struct pipe_inode_info___7 *, size_t, unsigned int);
	int (*setlease)(struct file___27 *, long int, struct file_lock___26 **, void **);
	long int (*fallocate)(struct file___27 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___27 *, struct file___27 *);
	ssize_t (*copy_file_range)(struct file___27 *, loff_t, struct file___27 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___27 *, loff_t, struct file___27 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___27 *, loff_t, loff_t, int);
};

struct vmacache___26 {
	u64 seqnum;
	struct vm_area_struct___26 *vmas[4];
};

struct page_frag___26 {
	struct page___27 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___17;

struct debug_info___17 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___17 *hbp_break[16];
	struct perf_event___17 *hbp_watch[16];
};

struct thread_struct___17 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___17 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___27;

struct pid___25;

struct nsproxy___26;

struct signal_struct___27;

struct bio_list___11;

struct backing_dev_info___10;

struct io_context___12;

struct css_set___19;

struct perf_event_context___17;

struct mem_cgroup___10;

struct request_queue___13;

struct vm_struct___26;

struct task_struct___28 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___28 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___27 *mm;
	struct mm_struct___27 *active_mm;
	struct vmacache___26 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___28 *real_parent;
	struct task_struct___28 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___28 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___25 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___26 *nsproxy;
	struct signal_struct___27 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___28 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___11 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___10 *backing_dev_info;
	struct io_context___12 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___19 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___17 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___7 *splice_pipe;
	struct page_frag___26 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___10 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___10 *active_memcg;
	struct request_queue___13 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___28 *oom_reaper_list;
	struct vm_struct___26 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___17 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___26;

struct kobj_type___26;

struct kernfs_node___26;

struct kobject___26 {
	const char *name;
	struct list_head entry;
	struct kobject___26 *parent;
	struct kset___26 *kset;
	struct kobj_type___26 *ktype;
	struct kernfs_node___26 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___26 {
	struct kobject___26 kobj;
	struct module___28 *mod;
	struct kobject___26 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___26 {
	struct module___28 *mod;
	struct latch_tree_node node;
};

struct module_layout___26 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___26 mtn;
};

struct module_attribute___26;

struct kernel_param___26;

struct trace_event_call___12;

struct module___28 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___26 mkobj;
	struct module_attribute___26 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___26 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___26 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___26 core_layout;
	struct module_layout___26 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___12 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___17 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___28 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___17)(struct perf_event___17 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___17;

struct fasync_struct___26;

struct pid_namespace___25;

struct bpf_prog___3;

struct perf_cgroup___17;

struct perf_event___17 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___17 *group_leader;
	struct pmu___17 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___17 hw;
	struct perf_event_context___17 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___17 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___28 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___26 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___17 *aux_event;
	void (*destroy)(struct perf_event___17 *);
	struct callback_head callback_head;
	struct pid_namespace___25 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___17 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___17 orig_overflow_handler;
	struct bpf_prog___3 *prog;
	u64 bpf_cookie;
	struct trace_event_call___12 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___17 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___25 {
	int nr;
	struct pid_namespace___25 *ns;
};

struct pid_namespace___25 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___28 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___25 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___25 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___25 numbers[1];
};

typedef struct page___27 *pgtable_t___26;

struct address_space___26;

struct page_pool___7;

struct dev_pagemap___26;

struct page___27 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___26 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___27 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___26 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___27 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___26 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___26;

struct vm_area_struct___26 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___26 *vm_next;
	struct vm_area_struct___26 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___27 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___26 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___27 *vm_file;
	struct file___27 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___27 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___28 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___28 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___25 *pids[4];
	struct pid___25 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___27 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___4;

struct core_state___26;

struct mm_struct___27 {
	struct {
		struct vm_area_struct___26 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___27 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___4 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___26 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___28 *owner;
		struct user_namespace *user_ns;
		struct file___27 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___5;

struct cgroup_namespace___19;

struct nsproxy___26 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___25 *pid_ns_for_children;
	struct net___5 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___19 *cgroup_ns;
};

struct bio___11;

struct bio_list___11 {
	struct bio___11 *head;
	struct bio___11 *tail;
};

struct cgroup_subsys_state___19;

struct bdi_writeback___10 {
	struct backing_dev_info___10 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___19 *memcg_css;
	struct cgroup_subsys_state___19 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___24;

struct backing_dev_info___10 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___10 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___24 *dev;
	char dev_name[64];
	struct device___24 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___27 *debug_dir;
};

struct io_cq___11;

struct io_context___12 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___11 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___19;

struct css_set___19 {
	struct cgroup_subsys_state___19 *subsys[14];
	refcount_t refcount;
	struct css_set___19 *dom_cset;
	struct cgroup___19 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___19 *mg_src_cgrp;
	struct cgroup___19 *mg_dst_cgrp;
	struct css_set___19 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___17 {
	struct pmu___17 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___28 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___17 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___7;

struct pipe_inode_info___7 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___27 *tmp_page;
	struct fasync_struct___26 *fasync_readers;
	struct fasync_struct___26 *fasync_writers;
	struct pipe_buffer___7 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___19;

struct cgroup_subsys_state___19 {
	struct cgroup___19 *cgroup;
	struct cgroup_subsys___19 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___19 *parent;
};

struct cgroup_file___19 {
	struct kernfs_node___26 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___10;

struct mem_cgroup_per_node___10;

struct mem_cgroup___10 {
	struct cgroup_subsys_state___19 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___19 events_file;
	struct cgroup_file___19 events_local_file;
	struct cgroup_file___19 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___10 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___28 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___10 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___11;

struct blk_integrity___11 {
	const struct blk_integrity_profile___11 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___11 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___11 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___12;

struct elevator_queue___11;

struct blk_mq_ops___11;

struct blk_mq_hw_ctx___11;

struct gendisk___11;

struct blkcg_gq___11;

struct blk_mq_tag_set___11;

struct request_queue___13 {
	struct request___12 *last_merge;
	struct elevator_queue___11 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___11 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___11 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___11 *disk;
	struct kobject___26 kobj;
	struct kobject___26 *mq_kobj;
	struct blk_integrity___11 integrity;
	struct device___24 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___11 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___11 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___11 bio_split;
	struct dentry___27 *debugfs_dir;
	struct dentry___27 *sched_debugfs_dir;
	struct dentry___27 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___26 {
	struct vm_struct___26 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___27 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___26;

struct address_space___26 {
	struct inode___28 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___26 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___7 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___24 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___7 {
	u32 count;
	struct page___27 *cache[128];
};

struct page_pool___7 {
	struct page_pool_params___7 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___27 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___7 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___26;

struct dev_pagemap___26 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___26 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___26;

struct path___26 {
	struct vfsmount___26 *mnt;
	struct dentry___27 *dentry;
};

struct fown_struct___25 {
	rwlock_t lock;
	struct pid___25 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___27 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___26 f_path;
	struct inode___28 *f_inode;
	const struct file_operations___26 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___25 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___26 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___26;

struct vm_operations_struct___26 {
	void (*open)(struct vm_area_struct___26 *);
	void (*close)(struct vm_area_struct___26 *);
	int (*may_split)(struct vm_area_struct___26 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___26 *);
	int (*mprotect)(struct vm_area_struct___26 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___26 *);
	vm_fault_t (*huge_fault)(struct vm_fault___26 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___26 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___26 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___26 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___26 *);
	int (*access)(struct vm_area_struct___26 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___26 *);
	int (*set_policy)(struct vm_area_struct___26 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___26 *, long unsigned int);
	struct page___27 * (*find_special_page)(struct vm_area_struct___26 *, long unsigned int);
};

struct core_thread___26 {
	struct task_struct___28 *task;
	struct core_thread___26 *next;
};

struct core_state___26 {
	atomic_t nr_threads;
	struct core_thread___26 dumper;
	struct completion startup;
};

struct linux_binprm___5;

struct coredump_params___4;

struct linux_binfmt___4 {
	struct list_head lh;
	struct module___28 *module;
	int (*load_binary)(struct linux_binprm___5 *);
	int (*load_shlib)(struct file___27 *);
	int (*core_dump)(struct coredump_params___4 *);
	long unsigned int min_coredump;
};

struct vm_fault___26 {
	const struct {
		struct vm_area_struct___26 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___27 *cow_page;
	struct page___27 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___26 prealloc_pte;
};

struct pglist_data___11;

struct lruvec___11 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___11 *pgdat;
};

struct zone___11 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___11 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___11 {
	struct zone___11 *zone;
	int zone_idx;
};

struct zonelist___11 {
	struct zoneref___11 _zonerefs[321];
};

struct pglist_data___11 {
	struct zone___11 node_zones[5];
	struct zonelist___11 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___28 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___28 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___11 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_stat_t {
	long int nr_dentry;
	long int nr_unused;
	long int age_limit;
	long int want_pages;
	long int nr_negative;
	long int dummy;
};

struct dentry_operations___26;

struct dentry___27 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___27 *d_parent;
	struct qstr d_name;
	struct inode___28 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___26 *d_op;
	struct super_block___27 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___26;

struct cdev___14;

struct inode___28 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___26 *i_op;
	struct super_block___27 *i_sb;
	struct address_space___26 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___10 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___26 *i_fop;
		void (*free_inode)(struct inode___28 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___26 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___7 *i_pipe;
		struct cdev___14 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___26 {
	int (*d_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___27 *, unsigned int);
	int (*d_hash)(const struct dentry___27 *, struct qstr *);
	int (*d_compare)(const struct dentry___27 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___27 *);
	int (*d_init)(struct dentry___27 *);
	void (*d_release)(struct dentry___27 *);
	void (*d_prune)(struct dentry___27 *);
	void (*d_iput)(struct dentry___27 *, struct inode___28 *);
	char * (*d_dname)(struct dentry___27 *, char *, int);
	struct vfsmount___26 * (*d_automount)(struct path___26 *);
	int (*d_manage)(const struct path___26 *, bool);
	struct dentry___27 * (*d_real)(struct dentry___27 *, const struct inode___28 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___26;

struct mem_dqinfo___26 {
	struct quota_format_type___26 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___26;

struct quota_info___26 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___28 *files[3];
	struct mem_dqinfo___26 info[3];
	const struct quota_format_ops___26 *ops[3];
};

struct rcuwait___26 {
	struct task_struct___28 *task;
};

struct percpu_rw_semaphore___26 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___26 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___26 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___26 rw_sem[3];
};

struct shrink_control___10;

struct shrinker___10 {
	long unsigned int (*count_objects)(struct shrinker___10 *, struct shrink_control___10 *);
	long unsigned int (*scan_objects)(struct shrinker___10 *, struct shrink_control___10 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___26;

struct dquot_operations___26;

struct quotactl_ops___26;

struct block_device___12;

struct super_block___27 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___26 *s_type;
	const struct super_operations___26 *s_op;
	const struct dquot_operations___26 *dq_op;
	const struct quotactl_ops___26 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___27 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___12 *s_bdev;
	struct backing_dev_info___10 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___26 s_dquot;
	struct sb_writers___26 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___26 *s_d_op;
	int cleancache_poolid;
	struct shrinker___10 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___26 {
	struct dentry___27 *mnt_root;
	struct super_block___27 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct shrink_control___10 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___10 *memcg;
};

struct psi_group___19 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___28 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___3;

struct cgroup_bpf___3 {
	struct bpf_prog_array___3 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___3 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___19;

struct cgroup_rstat_cpu___19;

struct cgroup___19 {
	struct cgroup_subsys_state___19 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___26 *kn;
	struct cgroup_file___19 procs_file;
	struct cgroup_file___19 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___19 *subsys[14];
	struct cgroup_root___19 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___19 *dom_cgrp;
	struct cgroup___19 *old_dom_cgrp;
	struct cgroup_rstat_cpu___19 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___19 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___11 {
	struct request_queue___13 *q;
	struct io_context___12 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct files_stat_struct {
	long unsigned int nr_files;
	long unsigned int nr_free_files;
	long unsigned int max_files;
};

struct inodes_stat_t {
	long int nr_inodes;
	long int nr_unused;
	long int dummy[5];
};

struct wait_page_queue___12;

struct kiocb___26 {
	struct file___27 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___26 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___12 *ki_waitq;
	};
};

struct iattr___27 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___27 *ia_file;
};

struct dquot___26 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___27 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___26 {
	int qf_fmt_id;
	const struct quota_format_ops___26 *qf_ops;
	struct module___28 *qf_owner;
	struct quota_format_type___26 *qf_next;
};

struct quota_format_ops___26 {
	int (*check_quota_file)(struct super_block___27 *, int);
	int (*read_file_info)(struct super_block___27 *, int);
	int (*write_file_info)(struct super_block___27 *, int);
	int (*free_file_info)(struct super_block___27 *, int);
	int (*read_dqblk)(struct dquot___26 *);
	int (*commit_dqblk)(struct dquot___26 *);
	int (*release_dqblk)(struct dquot___26 *);
	int (*get_next_id)(struct super_block___27 *, struct kqid *);
};

struct dquot_operations___26 {
	int (*write_dquot)(struct dquot___26 *);
	struct dquot___26 * (*alloc_dquot)(struct super_block___27 *, int);
	void (*destroy_dquot)(struct dquot___26 *);
	int (*acquire_dquot)(struct dquot___26 *);
	int (*release_dquot)(struct dquot___26 *);
	int (*mark_dirty)(struct dquot___26 *);
	int (*write_info)(struct super_block___27 *, int);
	qsize_t * (*get_reserved_space)(struct inode___28 *);
	int (*get_projid)(struct inode___28 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___28 *, qsize_t *);
	int (*get_next_id)(struct super_block___27 *, struct kqid *);
};

struct quotactl_ops___26 {
	int (*quota_on)(struct super_block___27 *, int, int, const struct path___26 *);
	int (*quota_off)(struct super_block___27 *, int);
	int (*quota_enable)(struct super_block___27 *, unsigned int);
	int (*quota_disable)(struct super_block___27 *, unsigned int);
	int (*quota_sync)(struct super_block___27 *, int);
	int (*set_info)(struct super_block___27 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___27 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___27 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___27 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___27 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___27 *, unsigned int);
};

struct wait_page_queue___12 {
	struct page___27 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___10;

struct readahead_control___12;

struct swap_info_struct___8;

struct address_space_operations___26 {
	int (*writepage)(struct page___27 *, struct writeback_control___10 *);
	int (*readpage)(struct file___27 *, struct page___27 *);
	int (*writepages)(struct address_space___26 *, struct writeback_control___10 *);
	int (*set_page_dirty)(struct page___27 *);
	int (*readpages)(struct file___27 *, struct address_space___26 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___12 *);
	int (*write_begin)(struct file___27 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___27 **, void **);
	int (*write_end)(struct file___27 *, struct address_space___26 *, loff_t, unsigned int, unsigned int, struct page___27 *, void *);
	sector_t (*bmap)(struct address_space___26 *, sector_t);
	void (*invalidatepage)(struct page___27 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___27 *, gfp_t);
	void (*freepage)(struct page___27 *);
	ssize_t (*direct_IO)(struct kiocb___26 *, struct iov_iter___13 *);
	int (*migratepage)(struct address_space___26 *, struct page___27 *, struct page___27 *, enum migrate_mode);
	bool (*isolate_page)(struct page___27 *, isolate_mode_t);
	void (*putback_page)(struct page___27 *);
	int (*launder_page)(struct page___27 *);
	int (*is_partially_uptodate)(struct page___27 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___27 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___26 *, struct page___27 *);
	int (*swap_activate)(struct swap_info_struct___8 *, struct file___27 *, sector_t *);
	void (*swap_deactivate)(struct file___27 *);
};

struct writeback_control___10 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___10 *wb;
	struct inode___28 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___12 {
	struct file___27 *file;
	struct address_space___26 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___13;

struct iov_iter___13 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___13 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___7 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___8 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___12 *bdev;
	struct file___27 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___14 {
	struct kobject___26 kobj;
	struct module___28 *owner;
	const struct file_operations___26 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___26 {
	struct dentry___27 * (*lookup)(struct inode___28 *, struct dentry___27 *, unsigned int);
	const char * (*get_link)(struct dentry___27 *, struct inode___28 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___28 *, int);
	struct posix_acl * (*get_acl)(struct inode___28 *, int, bool);
	int (*readlink)(struct dentry___27 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___28 *, struct dentry___27 *, umode_t, bool);
	int (*link)(struct dentry___27 *, struct inode___28 *, struct dentry___27 *);
	int (*unlink)(struct inode___28 *, struct dentry___27 *);
	int (*symlink)(struct user_namespace *, struct inode___28 *, struct dentry___27 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___28 *, struct dentry___27 *, umode_t);
	int (*rmdir)(struct inode___28 *, struct dentry___27 *);
	int (*mknod)(struct user_namespace *, struct inode___28 *, struct dentry___27 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___28 *, struct dentry___27 *, struct inode___28 *, struct dentry___27 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___27 *, struct iattr___27 *);
	int (*getattr)(struct user_namespace *, const struct path___26 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___27 *, char *, size_t);
	int (*fiemap)(struct inode___28 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___28 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___28 *, struct dentry___27 *, struct file___27 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___28 *, struct dentry___27 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___28 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___27 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___27 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___26 {
	void (*fl_copy_lock)(struct file_lock___26 *, struct file_lock___26 *);
	void (*fl_release_private)(struct file_lock___26 *);
};

struct lock_manager_operations___26;

struct file_lock___26 {
	struct file_lock___26 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___27 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___26 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___26 *fl_ops;
	const struct lock_manager_operations___26 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___26 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___26 *);
	int (*lm_grant)(struct file_lock___26 *, int);
	bool (*lm_break)(struct file_lock___26 *);
	int (*lm_change)(struct file_lock___26 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___26 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___26 *);
};

struct fasync_struct___26 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___26 *fa_next;
	struct file___27 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___26 {
	struct inode___28 * (*alloc_inode)(struct super_block___27 *);
	void (*destroy_inode)(struct inode___28 *);
	void (*free_inode)(struct inode___28 *);
	void (*dirty_inode)(struct inode___28 *, int);
	int (*write_inode)(struct inode___28 *, struct writeback_control___10 *);
	int (*drop_inode)(struct inode___28 *);
	void (*evict_inode)(struct inode___28 *);
	void (*put_super)(struct super_block___27 *);
	int (*sync_fs)(struct super_block___27 *, int);
	int (*freeze_super)(struct super_block___27 *);
	int (*freeze_fs)(struct super_block___27 *);
	int (*thaw_super)(struct super_block___27 *);
	int (*unfreeze_fs)(struct super_block___27 *);
	int (*statfs)(struct dentry___27 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___27 *, int *, char *);
	void (*umount_begin)(struct super_block___27 *);
	int (*show_options)(struct seq_file___27 *, struct dentry___27 *);
	int (*show_devname)(struct seq_file___27 *, struct dentry___27 *);
	int (*show_path)(struct seq_file___27 *, struct dentry___27 *);
	int (*show_stats)(struct seq_file___27 *, struct dentry___27 *);
	ssize_t (*quota_read)(struct super_block___27 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___27 *, int, const char *, size_t, loff_t);
	struct dquot___26 ** (*get_dquots)(struct inode___28 *);
	long int (*nr_cached_objects)(struct super_block___27 *, struct shrink_control___10 *);
	long int (*free_cached_objects)(struct super_block___27 *, struct shrink_control___10 *);
	struct file___27 * (*real_loop)(struct file___27 *);
};

struct wakeup_source___24;

struct dev_pm_info___24 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___24 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___24 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___24;

struct bus_type___24;

struct device_driver___24;

struct dev_pm_domain___24;

struct irq_domain___12;

struct device_node___16;

struct fwnode_handle___24;

struct class___24;

struct attribute_group___26;

struct device___24 {
	struct kobject___26 kobj;
	struct device___24 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___24 *type;
	struct bus_type___24 *bus;
	struct device_driver___24 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___24 power;
	struct dev_pm_domain___24 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___12 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___16 *of_node;
	struct fwnode_handle___24 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___24 *class;
	const struct attribute_group___26 **groups;
	void (*release)(struct device___24 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___12 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___28 *bd_inode;
	struct super_block___27 *bd_super;
	void *bd_claiming;
	struct device___24 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___26 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___11 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___27 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___20)(struct file___27 *, wait_queue_head_t *, struct poll_table_struct___20 *);

struct poll_table_struct___20 {
	poll_queue_proc___20 _qproc;
	__poll_t _key;
};

struct seq_operations___25;

struct seq_file___27 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___25 *op;
	int poll_event;
	const struct file___27 *file;
	void *private;
};

typedef void bio_end_io_t___11(struct bio___11 *);

struct bio_vec___13 {
	struct page___27 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___11;

struct bio___11 {
	struct bio___11 *bi_next;
	struct block_device___12 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___11 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___11 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___11 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___13 *bi_io_vec;
	struct bio_set___11 *bi_pool;
	struct bio_vec___13 bi_inline_vecs[0];
};

struct kernfs_root___26;

struct kernfs_elem_dir___26 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___26 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___26;

struct kernfs_root___26 {
	struct kernfs_node___26 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___26 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___26 {
	struct kernfs_node___26 *target_kn;
};

struct kernfs_ops___26;

struct kernfs_elem_attr___26 {
	const struct kernfs_ops___26 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___26 *notify_next;
};

struct kernfs_node___26 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___26 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___26 dir;
		struct kernfs_elem_symlink___26 symlink;
		struct kernfs_elem_attr___26 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___26;

struct kernfs_ops___26 {
	int (*open)(struct kernfs_open_file___26 *);
	void (*release)(struct kernfs_open_file___26 *);
	int (*seq_show)(struct seq_file___27 *, void *);
	void * (*seq_start)(struct seq_file___27 *, loff_t *);
	void * (*seq_next)(struct seq_file___27 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___27 *, void *);
	ssize_t (*read)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___26 *, struct poll_table_struct___20 *);
	int (*mmap)(struct kernfs_open_file___26 *, struct vm_area_struct___26 *);
};

struct kernfs_syscall_ops___26 {
	int (*show_options)(struct seq_file___27 *, struct kernfs_root___26 *);
	int (*mkdir)(struct kernfs_node___26 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___26 *);
	int (*rename)(struct kernfs_node___26 *, struct kernfs_node___26 *, const char *);
	int (*show_path)(struct seq_file___27 *, struct kernfs_node___26 *, struct kernfs_root___26 *);
};

struct kernfs_open_file___26 {
	struct kernfs_node___26 *kn;
	struct file___27 *file;
	struct seq_file___27 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___26 *vm_ops;
};

struct sock___5;

struct kobj_ns_type_operations___2 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___5 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___5 *net;
} possible_net_t___3;

struct proto___2;

struct sock_common___2 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___2 *skc_prot;
	possible_net_t___3 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___5 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___5;

struct sk_buff_head___3 {
	struct sk_buff___5 *next;
	struct sk_buff___5 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___2 {
	struct cgroup___19 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___2;

struct socket_wq___2;

struct dst_entry___3;

struct socket___2;

struct net_device___9;

struct sock___5 {
	struct sock_common___2 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___3 sk_error_queue;
	struct sk_buff___5 *sk_rx_skb_cache;
	struct sk_buff_head___3 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___5 *head;
		struct sk_buff___5 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___2 *sk_filter;
	union {
		struct socket_wq___2 *sk_wq;
		struct socket_wq___2 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___3 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___3 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___5 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___5 *sk_tx_skb_cache;
	struct sk_buff_head___3 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___26 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___2 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___25 *sk_peer_pid;
	const struct cred *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___2 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___2 sk_cgrp_data;
	struct mem_cgroup___10 *sk_memcg;
	void (*sk_state_change)(struct sock___5 *);
	void (*sk_data_ready)(struct sock___5 *);
	void (*sk_write_space)(struct sock___5 *);
	void (*sk_error_report)(struct sock___5 *);
	int (*sk_backlog_rcv)(struct sock___5 *, struct sk_buff___5 *);
	struct sk_buff___5 * (*sk_validate_xmit_skb)(struct sock___5 *, struct net_device___9 *, struct sk_buff___5 *);
	void (*sk_destruct)(struct sock___5 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___26;

struct attribute_group___26 {
	const char *name;
	umode_t (*is_visible)(struct kobject___26 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___26 *, struct bin_attribute___26 *, int);
	struct attribute **attrs;
	struct bin_attribute___26 **bin_attrs;
};

struct bin_attribute___26 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___26 * (*f_mapping)();
	ssize_t (*read)(struct file___27 *, struct kobject___26 *, struct bin_attribute___26 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___27 *, struct kobject___26 *, struct bin_attribute___26 *, char *, loff_t, size_t);
	int (*mmap)(struct file___27 *, struct kobject___26 *, struct bin_attribute___26 *, struct vm_area_struct___26 *);
};

struct sysfs_ops___26 {
	ssize_t (*show)(struct kobject___26 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___26 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___26;

struct kset___26 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___26 kobj;
	const struct kset_uevent_ops___26 *uevent_ops;
};

struct kobj_type___26 {
	void (*release)(struct kobject___26 *);
	const struct sysfs_ops___26 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___26 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___26 *);
	const void * (*namespace)(struct kobject___26 *);
	void (*get_ownership)(struct kobject___26 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___26 {
	int (* const filter)(struct kset___26 *, struct kobject___26 *);
	const char * (* const name)(struct kset___26 *, struct kobject___26 *);
	int (* const uevent)(struct kset___26 *, struct kobject___26 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___26 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___26 *);
	int (*get)(char *, const struct kernel_param___26 *);
	void (*free)(void *);
};

struct kparam_array___26;

struct kernel_param___26 {
	const char *name;
	struct module___28 *mod;
	const struct kernel_param_ops___26 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___26 *arr;
	};
};

struct kparam_array___26 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___26 *ops;
	void *elem;
};

struct module_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___26 *, struct module_kobject___26 *, char *);
	ssize_t (*store)(struct module_attribute___26 *, struct module_kobject___26 *, const char *, size_t);
	void (*setup)(struct module___28 *, const char *);
	int (*test)(struct module___28 *);
	void (*free)(struct module___28 *);
};

struct trace_event_class___12;

struct trace_event_call___12 {
	struct list_head list;
	struct trace_event_class___12 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___12 *, struct perf_event___17 *);
};

struct dev_pagemap_ops___26 {
	void (*page_free)(struct page___27 *);
	void (*kill)(struct dev_pagemap___26 *);
	void (*cleanup)(struct dev_pagemap___26 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___26 *);
};

struct seq_operations___25 {
	void * (*start)(struct seq_file___27 *, loff_t *);
	void (*stop)(struct seq_file___27 *, void *);
	void * (*next)(struct seq_file___27 *, void *, loff_t *);
	int (*show)(struct seq_file___27 *, void *);
};

struct fib_rules_ops___2;

struct fqdir___4;

struct fib_notifier_ops___2;

struct netns_ipv4___4 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___2 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___5 *fibnl;
	struct sock___5 **icmp_sk;
	struct sock___5 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___5 **tcp_sk;
	struct fqdir___4 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___2 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___2 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___2 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___2;

struct dst_ops___4 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___4 *);
	struct dst_entry___3 * (*check)(struct dst_entry___3 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___3 *);
	unsigned int (*mtu)(const struct dst_entry___3 *);
	u32 * (*cow_metrics)(struct dst_entry___3 *, long unsigned int);
	void (*destroy)(struct dst_entry___3 *);
	void (*ifdown)(struct dst_entry___3 *, struct net_device___9 *, int);
	struct dst_entry___3 * (*negative_advice)(struct dst_entry___3 *);
	void (*link_failure)(struct sk_buff___5 *);
	void (*update_pmtu)(struct dst_entry___3 *, struct sock___5 *, struct sk_buff___5 *, u32, bool);
	void (*redirect)(struct dst_entry___3 *, struct sock___5 *, struct sk_buff___5 *);
	int (*local_out)(struct net___5 *, struct sock___5 *, struct sk_buff___5 *);
	struct neighbour___2 * (*neigh_lookup)(const struct dst_entry___3 *, struct sk_buff___5 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___3 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___4 {
	struct dst_ops___4 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___4 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___2 *fib6_rules_ops;
	struct sock___5 **icmp_sk;
	struct sock___5 *ndisc_sk;
	struct sock___5 *tcp_sk;
	struct sock___5 *igmp_sk;
	struct sock___5 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___2 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___2 *notifier_ops;
	struct fib_notifier_ops___2 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___4 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___4 *fqdir;
};

struct netns_sctp___2 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___5 *ctl_sock;
	struct sock___5 *udp4_sock;
	struct sock___5 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___3 {
	struct bpf_prog_array___3 *run_array[2];
	struct bpf_prog___3 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___4 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___5 *nlsk;
	struct sock___5 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___4 xfrm4_dst_ops;
	struct dst_ops___4 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___5 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct idr netns_ids;
	struct ns_common ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___5 *rtnl;
	struct sock___5 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___9 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___4 ipv4;
	struct netns_ipv6___4 ipv6;
	struct netns_ieee802154_lowpan___4 ieee802154_lowpan;
	struct netns_sctp___2 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___3 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___3 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___4 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___5 *crypto_nlsk;
	struct sock___5 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___19 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___19 *root_cset;
};

struct irq_desc___13;

typedef void (*irq_flow_handler_t___13)(struct irq_desc___13 *);

struct irq_chip___12;

struct irq_data___12 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___12 *chip;
	struct irq_domain___12 *domain;
	struct irq_data___12 *parent_data;
	void *chip_data;
};

struct irqaction___10;

struct irq_desc___13 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___12 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___13 handle_irq;
	struct irqaction___10 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___26 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___28 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___24;

struct fwnode_handle___24 {
	struct fwnode_handle___24 *secondary;
	const struct fwnode_operations___24 *ops;
	struct device___24 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___24;

struct fwnode_endpoint___24;

struct fwnode_operations___24 {
	struct fwnode_handle___24 * (*get)(struct fwnode_handle___24 *);
	void (*put)(struct fwnode_handle___24 *);
	bool (*device_is_available)(const struct fwnode_handle___24 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___24 *, const struct device___24 *);
	bool (*property_present)(const struct fwnode_handle___24 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___24 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___24 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___24 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_parent)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_next_child_node)(const struct fwnode_handle___24 *, struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*get_named_child_node)(const struct fwnode_handle___24 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___24 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___24 *);
	struct fwnode_handle___24 * (*graph_get_next_endpoint)(const struct fwnode_handle___24 *, struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*graph_get_remote_endpoint)(const struct fwnode_handle___24 *);
	struct fwnode_handle___24 * (*graph_get_port_parent)(struct fwnode_handle___24 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___24 *, struct fwnode_endpoint___24 *);
	int (*add_links)(struct fwnode_handle___24 *);
};

struct fwnode_endpoint___24 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___24 *local_fwnode;
};

struct fwnode_reference_args___24 {
	struct fwnode_handle___24 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___12 {
	struct device___24 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___12 *);
	void (*irq_shutdown)(struct irq_data___12 *);
	void (*irq_enable)(struct irq_data___12 *);
	void (*irq_disable)(struct irq_data___12 *);
	void (*irq_ack)(struct irq_data___12 *);
	void (*irq_mask)(struct irq_data___12 *);
	void (*irq_mask_ack)(struct irq_data___12 *);
	void (*irq_unmask)(struct irq_data___12 *);
	void (*irq_eoi)(struct irq_data___12 *);
	int (*irq_set_affinity)(struct irq_data___12 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___12 *);
	int (*irq_set_type)(struct irq_data___12 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___12 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___12 *);
	void (*irq_bus_sync_unlock)(struct irq_data___12 *);
	void (*irq_cpu_online)(struct irq_data___12 *);
	void (*irq_cpu_offline)(struct irq_data___12 *);
	void (*irq_suspend)(struct irq_data___12 *);
	void (*irq_resume)(struct irq_data___12 *);
	void (*irq_pm_shutdown)(struct irq_data___12 *);
	void (*irq_calc_mask)(struct irq_data___12 *);
	void (*irq_print_chip)(struct irq_data___12 *, struct seq_file___27 *);
	int (*irq_request_resources)(struct irq_data___12 *);
	void (*irq_release_resources)(struct irq_data___12 *);
	void (*irq_compose_msi_msg)(struct irq_data___12 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___12 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___12 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___12 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___12 *, void *);
	void (*ipi_send_single)(struct irq_data___12 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___12 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___12 *);
	void (*irq_nmi_teardown)(struct irq_data___12 *);
	long unsigned int flags;
};

struct irq_domain_ops___12;

struct irq_domain_chip_generic___12;

struct irq_domain___12 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___12 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___24 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___12 *gc;
	struct irq_domain___12 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___12 *revmap[0];
};

struct irqaction___10 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___10 *next;
	irq_handler_t thread_fn;
	struct task_struct___28 *thread;
	struct irqaction___10 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___12 {
	struct irq_chip___12 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___13 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___12 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___12 *);
	void (*resume)(struct irq_chip_generic___12 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___12 *domain;
	struct list_head list;
	struct irq_chip_type___12 chip_types[0];
};

struct irq_domain_chip_generic___12 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___12 *gc[0];
};

struct bpf_iter_aux_info___3;

typedef int (*bpf_iter_init_seq_priv_t___3)(void *, struct bpf_iter_aux_info___3 *);

struct bpf_map___3;

struct bpf_iter_aux_info___3 {
	struct bpf_map___3 *map;
};

struct bpf_iter_seq_info___3 {
	const struct seq_operations___25 *seq_ops;
	bpf_iter_init_seq_priv_t___3 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___3;

struct bpf_map_ops___3 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___3 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___3 *, struct file___27 *);
	void (*map_free)(struct bpf_map___3 *);
	int (*map_get_next_key)(struct bpf_map___3 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___3 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___3 *, void *);
	int (*map_lookup_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___3 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___3 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___3 *, void *);
	int (*map_update_elem)(struct bpf_map___3 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___3 *, void *);
	int (*map_push_elem)(struct bpf_map___3 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___3 *, void *);
	int (*map_peek_elem)(struct bpf_map___3 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___3 *, struct file___27 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___3 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___3 *, void *, struct seq_file___27 *);
	int (*map_check_btf)(const struct bpf_map___3 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___3 *, struct bpf_prog_aux___3 *);
	void (*map_poke_untrack)(struct bpf_map___3 *, struct bpf_prog_aux___3 *);
	void (*map_poke_run)(struct bpf_map___3 *, u32, struct bpf_prog___3 *, struct bpf_prog___3 *);
	int (*map_direct_value_addr)(const struct bpf_map___3 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___3 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___3 *, struct vm_area_struct___26 *);
	__poll_t (*map_poll)(struct bpf_map___3 *, struct file___27 *, struct poll_table_struct___20 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___3 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___3 *, const struct bpf_map___3 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___3 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___3 *iter_seq_info;
};

struct bpf_map___3 {
	const struct bpf_map_ops___3 *ops;
	struct bpf_map___3 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___10 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___3;

struct bpf_jit_poke_descriptor___3;

struct bpf_prog_ops___3;

struct btf_mod_pair___3;

struct bpf_prog_offload___3;

struct bpf_prog_aux___3 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___3 *dst_prog;
	struct bpf_trampoline___3 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___3 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___3 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___3 *ops;
	struct bpf_map___3 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___3 *used_btfs;
	struct bpf_prog___3 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___3 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___3 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___3 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___3 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___3;

struct bpf_map_dev_ops___3 {
	int (*map_get_next_key)(struct bpf_offloaded_map___3 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___3 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___3 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___3 *, void *);
};

struct bpf_offloaded_map___3 {
	struct bpf_map___3 map;
	struct net_device___9 *netdev;
	const struct bpf_map_dev_ops___3 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___3(struct sk_buff___5 **);

struct bpf_xdp_entity___3 {
	struct bpf_prog___3 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___3;

struct net_device_ops___3;

struct l3mdev_ops___3;

struct ndisc_ops___2;

struct xfrmdev_ops___3;

struct header_ops___3;

struct inet6_dev___2;

struct netdev_rx_queue___3;

struct mini_Qdisc___3;

struct netdev_queue___3;

struct Qdisc___3;

struct rtnl_link_ops___3;

struct dcbnl_rtnl_ops___3;

struct net_device___9 {
	char name[16];
	struct netdev_name_node___3 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___3 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___3 *l3mdev_ops;
	const struct ndisc_ops___2 *ndisc_ops;
	const struct xfrmdev_ops___3 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___3 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___26 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___2 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___3 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___3 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___3 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___3 *miniq_ingress;
	struct netdev_queue___3 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___3 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___3 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___3 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___3 = 0,
		NETREG_REGISTERED___3 = 1,
		NETREG_UNREGISTERING___3 = 2,
		NETREG_UNREGISTERED___3 = 3,
		NETREG_RELEASED___3 = 4,
		NETREG_DUMMY___3 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___3 = 0,
		RTNL_LINK_INITIALIZING___3 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___9 *);
	struct netpoll_info *npinfo;
	possible_net_t___3 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___24 dev;
	const struct attribute_group___26 *sysfs_groups[4];
	const struct attribute_group___26 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___3 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___3 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___3 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___3 {
	int (*test_run)(struct bpf_prog___3 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___3 {
	struct bpf_prog___3 *prog;
	struct net_device___9 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___3 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___3 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___28 *mod;
};

struct bpf_jit_poke_descriptor___3 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___3 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___3 {
	struct btf *btf;
	struct module___28 *module;
};

struct bpf_prog_array_item___3 {
	struct bpf_prog___3 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___3 {
	struct callback_head rcu;
	struct bpf_prog_array_item___3 items[0];
};

struct sk_buff___5 {
	union {
		struct {
			struct sk_buff___5 *next;
			struct sk_buff___5 *prev;
			union {
				struct net_device___9 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___5 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___5 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___19;

struct cgroup_subsys___19 {
	struct cgroup_subsys_state___19 * (*css_alloc)(struct cgroup_subsys_state___19 *);
	int (*css_online)(struct cgroup_subsys_state___19 *);
	void (*css_offline)(struct cgroup_subsys_state___19 *);
	void (*css_released)(struct cgroup_subsys_state___19 *);
	void (*css_free)(struct cgroup_subsys_state___19 *);
	void (*css_reset)(struct cgroup_subsys_state___19 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___19 *, int);
	int (*css_extra_stat_show)(struct seq_file___27 *, struct cgroup_subsys_state___19 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___28 *, struct css_set___19 *);
	void (*cancel_fork)(struct task_struct___28 *, struct css_set___19 *);
	void (*fork)(struct task_struct___28 *);
	void (*exit)(struct task_struct___28 *);
	void (*release)(struct task_struct___28 *);
	void (*bind)(struct cgroup_subsys_state___19 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___19 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___19 *dfl_cftypes;
	struct cftype___19 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___19 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___19 *updated_children;
	struct cgroup___19 *updated_next;
};

struct cgroup_root___19 {
	struct kernfs_root___26 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___19 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___19 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___19 *ss;
	struct list_head node;
	struct kernfs_ops___26 *kf_ops;
	int (*open)(struct kernfs_open_file___26 *);
	void (*release)(struct kernfs_open_file___26 *);
	u64 (*read_u64)(struct cgroup_subsys_state___19 *, struct cftype___19 *);
	s64 (*read_s64)(struct cgroup_subsys_state___19 *, struct cftype___19 *);
	int (*seq_show)(struct seq_file___27 *, void *);
	void * (*seq_start)(struct seq_file___27 *, loff_t *);
	void * (*seq_next)(struct seq_file___27 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___27 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___19 *, struct cftype___19 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___19 *, struct cftype___19 *, s64);
	ssize_t (*write)(struct kernfs_open_file___26 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___26 *, struct poll_table_struct___20 *);
};

struct msghdr___2 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___13 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___26 *msg_iocb;
};

struct dev_pm_ops___24 {
	int (*prepare)(struct device___24 *);
	void (*complete)(struct device___24 *);
	int (*suspend)(struct device___24 *);
	int (*resume)(struct device___24 *);
	int (*freeze)(struct device___24 *);
	int (*thaw)(struct device___24 *);
	int (*poweroff)(struct device___24 *);
	int (*restore)(struct device___24 *);
	int (*suspend_late)(struct device___24 *);
	int (*resume_early)(struct device___24 *);
	int (*freeze_late)(struct device___24 *);
	int (*thaw_early)(struct device___24 *);
	int (*poweroff_late)(struct device___24 *);
	int (*restore_early)(struct device___24 *);
	int (*suspend_noirq)(struct device___24 *);
	int (*resume_noirq)(struct device___24 *);
	int (*freeze_noirq)(struct device___24 *);
	int (*thaw_noirq)(struct device___24 *);
	int (*poweroff_noirq)(struct device___24 *);
	int (*restore_noirq)(struct device___24 *);
	int (*runtime_suspend)(struct device___24 *);
	int (*runtime_resume)(struct device___24 *);
	int (*runtime_idle)(struct device___24 *);
};

struct wakeup_source___24 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___24 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___24 {
	struct dev_pm_ops___24 ops;
	int (*start)(struct device___24 *);
	void (*detach)(struct device___24 *, bool);
	int (*activate)(struct device___24 *);
	void (*sync)(struct device___24 *);
	void (*dismiss)(struct device___24 *);
};

struct bus_type___24 {
	const char *name;
	const char *dev_name;
	struct device___24 *dev_root;
	const struct attribute_group___26 **bus_groups;
	const struct attribute_group___26 **dev_groups;
	const struct attribute_group___26 **drv_groups;
	int (*match)(struct device___24 *, struct device_driver___24 *);
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	int (*probe)(struct device___24 *);
	void (*sync_state)(struct device___24 *);
	void (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*online)(struct device___24 *);
	int (*offline)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	int (*num_vf)(struct device___24 *);
	int (*dma_configure)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___24 {
	const char *name;
	struct bus_type___24 *bus;
	struct module___28 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___24 *);
	void (*sync_state)(struct device___24 *);
	int (*remove)(struct device___24 *);
	void (*shutdown)(struct device___24 *);
	int (*suspend)(struct device___24 *, pm_message_t);
	int (*resume)(struct device___24 *);
	const struct attribute_group___26 **groups;
	const struct attribute_group___26 **dev_groups;
	const struct dev_pm_ops___24 *pm;
	void (*coredump)(struct device___24 *);
	struct driver_private *p;
};

struct device_type___24 {
	const char *name;
	const struct attribute_group___26 **groups;
	int (*uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___24 *);
	const struct dev_pm_ops___24 *pm;
};

struct class___24 {
	const char *name;
	struct module___28 *owner;
	const struct attribute_group___26 **class_groups;
	const struct attribute_group___26 **dev_groups;
	struct kobject___26 *dev_kobj;
	int (*dev_uevent)(struct device___24 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___24 *, umode_t *);
	void (*class_release)(struct class___24 *);
	void (*dev_release)(struct device___24 *);
	int (*shutdown_pre)(struct device___24 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___24 *);
	void (*get_ownership)(struct device___24 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___24 *pm;
	struct subsys_private *p;
};

struct property___13;

struct device_node___16 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___24 fwnode;
	struct property___13 *properties;
	struct property___13 *deadprops;
	struct device_node___16 *parent;
	struct device_node___16 *child;
	struct device_node___16 *sibling;
	struct kobject___26 kobj;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___11;

struct gendisk___11 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___12 *part0;
	const struct block_device_operations___11 *fops;
	struct request_queue___13 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___10 *bdi;
	struct kobject___26 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___26 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___11 {
	struct bio___11 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___13 *bip_vec;
	struct bio_vec___13 bip_inline_vecs[0];
};

struct blkcg___10;

struct blkg_policy_data___10;

struct blkcg_gq___11 {
	struct request_queue___13 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___10 *blkcg;
	struct blkcg_gq___11 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___10 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___11 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___11(struct request___12 *);

typedef void integrity_complete_fn___11(struct request___12 *, unsigned int);

struct blk_integrity_profile___11 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___11 *prepare_fn;
	integrity_complete_fn___11 *complete_fn;
	const char *name;
};

struct block_device_operations___11 {
	blk_qc_t (*submit_bio)(struct bio___11 *);
	int (*open)(struct block_device___12 *, fmode_t);
	void (*release)(struct gendisk___11 *, fmode_t);
	int (*rw_page)(struct block_device___12 *, sector_t, struct page___27 *, unsigned int);
	int (*ioctl)(struct block_device___12 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___12 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___11 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___11 *);
	int (*getgeo)(struct block_device___12 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___12 *, bool);
	void (*swap_slot_free_notify)(struct block_device___12 *, long unsigned int);
	int (*report_zones)(struct gendisk___11 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___11 *, umode_t *);
	struct module___28 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___11 *, sector_t *);
};

typedef void rq_end_io_fn___11(struct request___12 *, blk_status_t);

struct request___12 {
	struct request_queue___13 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___11 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___11 *bio;
	struct bio___11 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___13 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___11 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___11 *saved_end_io;
		} flush;
	};
	struct gendisk___11 *rq_disk;
	struct block_device___12 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___11 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___11 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___13 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___26 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___27 *debugfs_dir;
	struct dentry___27 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___11;

struct elevator_mq_ops___11 {
	int (*init_sched)(struct request_queue___13 *, struct elevator_type___11 *);
	void (*exit_sched)(struct elevator_queue___11 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___11 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___11 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___11 *);
	bool (*allow_merge)(struct request_queue___13 *, struct request___12 *, struct bio___11 *);
	bool (*bio_merge)(struct request_queue___13 *, struct bio___11 *, unsigned int);
	int (*request_merge)(struct request_queue___13 *, struct request___12 **, struct bio___11 *);
	void (*request_merged)(struct request_queue___13 *, struct request___12 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___13 *, struct request___12 *, struct request___12 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___12 *);
	void (*finish_request)(struct request___12 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___11 *, struct list_head *, bool);
	struct request___12 * (*dispatch_request)(struct blk_mq_hw_ctx___11 *);
	bool (*has_work)(struct blk_mq_hw_ctx___11 *);
	void (*completed_request)(struct request___12 *, u64);
	void (*requeue_request)(struct request___12 *);
	struct request___12 * (*former_request)(struct request_queue___13 *, struct request___12 *);
	struct request___12 * (*next_request)(struct request_queue___13 *, struct request___12 *);
	void (*init_icq)(struct io_cq___11 *);
	void (*exit_icq)(struct io_cq___11 *);
};

struct elv_fs_entry___11;

struct elevator_type___11 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___11 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___11 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___28 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___11 {
	struct elevator_type___11 *type;
	void *elevator_data;
	struct kobject___26 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___11 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___11 *, char *);
	ssize_t (*store)(struct elevator_queue___11 *, const char *, size_t);
};

struct blk_mq_queue_data___11;

struct blk_mq_ops___11 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___11 *, const struct blk_mq_queue_data___11 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___11 *);
	int (*get_budget)(struct request_queue___13 *);
	void (*put_budget)(struct request_queue___13 *, int);
	void (*set_rq_budget_token)(struct request___12 *, int);
	int (*get_rq_budget_token)(struct request___12 *);
	enum blk_eh_timer_return (*timeout)(struct request___12 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___11 *);
	void (*complete)(struct request___12 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___11 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___11 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___11 *, struct request___12 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___11 *, struct request___12 *, unsigned int);
	void (*initialize_rq_fn)(struct request___12 *);
	void (*cleanup_rq)(struct request___12 *);
	bool (*busy)(struct request_queue___13 *);
	int (*map_queues)(struct blk_mq_tag_set___11 *);
	void (*show_rq)(struct seq_file___27 *, struct request___12 *);
};

struct blk_mq_tag_set___11 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___11 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___11 {
	struct request___12 *rq;
	bool last;
};

struct blkcg_policy_data___10;

struct blkcg___10 {
	struct cgroup_subsys_state___19 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___11 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___10 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___10 {
	struct blkcg___10 *blkcg;
	int plid;
};

struct blkg_policy_data___10 {
	struct blkcg_gq___11 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___10 {
	struct mem_cgroup___10 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___10 {
	struct lruvec___11 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___10 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___10 *memcg;
};

struct obj_cgroup___10 {
	struct percpu_ref refcnt;
	struct mem_cgroup___10 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct socket_wq___2 {
	wait_queue_head_t wait;
	struct fasync_struct___26 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___2;

struct socket___2 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___27 *file;
	struct sock___5 *sk;
	const struct proto_ops___2 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___2 wq;
};

typedef int (*sk_read_actor_t___2)(read_descriptor_t *, struct sk_buff___5 *, unsigned int, size_t);

struct proto_ops___2 {
	int family;
	struct module___28 *owner;
	int (*release)(struct socket___2 *);
	int (*bind)(struct socket___2 *, struct sockaddr *, int);
	int (*connect)(struct socket___2 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___2 *, struct socket___2 *);
	int (*accept)(struct socket___2 *, struct socket___2 *, int, bool);
	int (*getname)(struct socket___2 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___27 *, struct socket___2 *, struct poll_table_struct___20 *);
	int (*ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___2 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___2 *, void *, bool, bool);
	int (*listen)(struct socket___2 *, int);
	int (*shutdown)(struct socket___2 *, int);
	int (*setsockopt)(struct socket___2 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___2 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___27 *, struct socket___2 *);
	int (*sendmsg)(struct socket___2 *, struct msghdr___2 *, size_t);
	int (*recvmsg)(struct socket___2 *, struct msghdr___2 *, size_t, int);
	int (*mmap)(struct file___27 *, struct socket___2 *, struct vm_area_struct___26 *);
	ssize_t (*sendpage)(struct socket___2 *, struct page___27 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___2 *, loff_t *, struct pipe_inode_info___7 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___5 *, int);
	int (*peek_len)(struct socket___2 *);
	int (*read_sock)(struct sock___5 *, read_descriptor_t *, sk_read_actor_t___2);
	int (*sendpage_locked)(struct sock___5 *, struct page___27 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___5 *, struct msghdr___2 *, size_t);
	int (*set_rcvlowat)(struct sock___5 *, int);
};

struct perf_cpu_context___17;

struct perf_output_handle___17;

struct pmu___17 {
	struct list_head entry;
	struct module___28 *module;
	struct device___24 *dev;
	const struct attribute_group___26 **attr_groups;
	const struct attribute_group___26 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___17 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___17 *);
	void (*pmu_disable)(struct pmu___17 *);
	int (*event_init)(struct perf_event___17 *);
	void (*event_mapped)(struct perf_event___17 *, struct mm_struct___27 *);
	void (*event_unmapped)(struct perf_event___17 *, struct mm_struct___27 *);
	int (*add)(struct perf_event___17 *, int);
	void (*del)(struct perf_event___17 *, int);
	void (*start)(struct perf_event___17 *, int);
	void (*stop)(struct perf_event___17 *, int);
	void (*read)(struct perf_event___17 *);
	void (*start_txn)(struct pmu___17 *, unsigned int);
	int (*commit_txn)(struct pmu___17 *);
	void (*cancel_txn)(struct pmu___17 *);
	int (*event_idx)(struct perf_event___17 *);
	void (*sched_task)(struct perf_event_context___17 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___17 *, struct perf_event_context___17 *);
	void * (*setup_aux)(struct perf_event___17 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___17 *, struct perf_output_handle___17 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___17 *);
	int (*aux_output_match)(struct perf_event___17 *);
	int (*filter_match)(struct perf_event___17 *);
	int (*check_period)(struct perf_event___17 *, u64);
};

struct perf_cpu_context___17 {
	struct perf_event_context___17 ctx;
	struct perf_event_context___17 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___17 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___17 **heap;
	struct perf_event___17 *heap_default[2];
};

struct perf_output_handle___17 {
	struct perf_event___17 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___17 {
	struct cgroup_subsys_state___19 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___12 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___12 *);
	};
};

struct trace_event_class___12 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___12 *, enum trace_reg, void *);
	struct trace_event_fields___12 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___12 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___12 *);
};

struct inet_frags___4;

struct fqdir___4 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___4 *f;
	struct net___5 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___4;

struct inet_frags___4 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___4 *, const void *);
	void (*destructor)(struct inet_frag_queue___4 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___4 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___5 *fragments_tail;
	struct sk_buff___5 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___4 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___2;

struct fib_lookup_arg___2;

struct fib_rules_ops___2 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___2 *, struct flowi *, int, struct fib_lookup_arg___2 *);
	bool (*suppress)(struct fib_rule___2 *, int, struct fib_lookup_arg___2 *);
	int (*match)(struct fib_rule___2 *, struct flowi *, int);
	int (*configure)(struct fib_rule___2 *, struct sk_buff___5 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___2 *);
	int (*compare)(struct fib_rule___2 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___2 *, struct sk_buff___5 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___2 *);
	void (*flush_cache)(struct fib_rules_ops___2 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___28 *owner;
	struct net___5 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___2 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___5 *);
	int (*fib_dump)(struct net___5 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___28 *owner;
	struct callback_head rcu;
};

struct dst_entry___3 {
	struct net_device___9 *dev;
	struct dst_ops___4 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___5 *);
	int (*output)(struct net___5 *, struct sock___5 *, struct sk_buff___5 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___2;

struct neigh_parms___3;

struct neigh_ops___2;

struct neighbour___2 {
	struct neighbour___2 *next;
	struct neigh_table___2 *tbl;
	struct neigh_parms___3 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___3 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___2 *, struct sk_buff___5 *);
	const struct neigh_ops___2 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___9 *dev;
	u8 primary_key[0];
};

struct pipe_buf_operations___7;

struct pipe_buffer___7 {
	struct page___27 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___7 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___7 {
	int (*confirm)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	void (*release)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	bool (*try_steal)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
	bool (*get)(struct pipe_inode_info___7 *, struct pipe_buffer___7 *);
};

struct dcbnl_rtnl_ops___3 {
	int (*ieee_getets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___9 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___9 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___9 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___9 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___9 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___9 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___9 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___9 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___9 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___9 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___9 *);
	u8 (*setstate)(struct net_device___9 *, u8);
	void (*getpermhwaddr)(struct net_device___9 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___9 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___9 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___9 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___9 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___9 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___9 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___9 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___9 *, int, u8 *);
	void (*setpfccfg)(struct net_device___9 *, int, u8);
	void (*getpfccfg)(struct net_device___9 *, int, u8 *);
	u8 (*setall)(struct net_device___9 *);
	u8 (*getcap)(struct net_device___9 *, int, u8 *);
	int (*getnumtcs)(struct net_device___9 *, int, u8 *);
	int (*setnumtcs)(struct net_device___9 *, int, u8);
	u8 (*getpfcstate)(struct net_device___9 *);
	void (*setpfcstate)(struct net_device___9 *, u8);
	void (*getbcncfg)(struct net_device___9 *, int, u32 *);
	void (*setbcncfg)(struct net_device___9 *, int, u32);
	void (*getbcnrp)(struct net_device___9 *, int, u8 *);
	void (*setbcnrp)(struct net_device___9 *, int, u8);
	int (*setapp)(struct net_device___9 *, u8, u16, u8);
	int (*getapp)(struct net_device___9 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___9 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___9 *, int, u8);
	u8 (*getdcbx)(struct net_device___9 *);
	u8 (*setdcbx)(struct net_device___9 *, u8);
	int (*peer_getappinfo)(struct net_device___9 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___9 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___9 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___9 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___9 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___9 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___3 {
	struct net_device___9 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___3 {
	struct net_device___9 *dev;
};

struct xdp_buff___3 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___3 *rxq;
	struct xdp_txq_info___3 *txq;
	u32 frame_sz;
};

struct xdp_frame___3 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___9 *dev_rx;
};

struct netlink_callback___3 {
	struct sk_buff___5 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___5 *, struct netlink_callback___3 *);
	int (*done)(struct netlink_callback___3 *);
	void *data;
	struct module___28 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___3 {
	int (*create)(struct sk_buff___5 *, struct net_device___9 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___5 *, unsigned char *);
	int (*cache)(const struct neighbour___2 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___9 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___5 *);
};

struct netdev_queue___3 {
	struct net_device___9 *dev;
	struct Qdisc___3 *qdisc;
	struct Qdisc___3 *qdisc_sleeping;
	struct kobject___26 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___9 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___3 {
	struct sk_buff___5 *head;
	struct sk_buff___5 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___3;

struct Qdisc___3 {
	int (*enqueue)(struct sk_buff___5 *, struct Qdisc___3 *, struct sk_buff___5 **);
	struct sk_buff___5 * (*dequeue)(struct Qdisc___3 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___3 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___3 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___3 gso_skb;
	struct qdisc_skb_head___3 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___3 *next_sched;
	struct sk_buff_head___3 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___3 {
	struct xdp_rxq_info___3 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___26 kobj;
	struct net_device___9 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___3 {
	enum net_device_path_type type;
	const struct net_device___9 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___3 = 0,
				DEV_PATH_BR_VLAN_TAG___3 = 1,
				DEV_PATH_BR_VLAN_UNTAG___3 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___3 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___3 {
	const struct net_device___9 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___3 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___3 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___3 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___3 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___5 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___3 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___9 *dev;
	const char *name;
};

struct net_device_ops___3 {
	int (*ndo_init)(struct net_device___9 *);
	void (*ndo_uninit)(struct net_device___9 *);
	int (*ndo_open)(struct net_device___9 *);
	int (*ndo_stop)(struct net_device___9 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___5 *, struct net_device___9 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___5 *, struct net_device___9 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___9 *, struct sk_buff___5 *, struct net_device___9 *);
	void (*ndo_change_rx_flags)(struct net_device___9 *, int);
	void (*ndo_set_rx_mode)(struct net_device___9 *);
	int (*ndo_set_mac_address)(struct net_device___9 *, void *);
	int (*ndo_validate_addr)(struct net_device___9 *);
	int (*ndo_do_ioctl)(struct net_device___9 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___9 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___9 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___9 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___9 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___9 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___9 *, int);
	int (*ndo_neigh_setup)(struct net_device___9 *, struct neigh_parms___3 *);
	void (*ndo_tx_timeout)(struct net_device___9 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___9 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___9 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___9 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___9 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___9 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___9 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___9 *);
	int (*ndo_netpoll_setup)(struct net_device___9 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___9 *);
	int (*ndo_set_vf_mac)(struct net_device___9 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___9 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___9 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___9 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___9 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___9 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___9 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___9 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___9 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___9 *, int, struct sk_buff___5 *);
	int (*ndo_get_vf_guid)(struct net_device___9 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___9 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___9 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___9 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___9 *);
	int (*ndo_fcoe_disable)(struct net_device___9 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___9 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___9 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___9 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___9 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___9 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___9 *, const struct sk_buff___5 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___9 *, struct net_device___9 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___9 *, struct net_device___9 *);
	struct net_device___9 * (*ndo_get_xmit_slave)(struct net_device___9 *, struct sk_buff___5 *, bool);
	struct net_device___9 * (*ndo_sk_get_lower_dev)(struct net_device___9 *, struct sock___5 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___9 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___9 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___9 *, struct neighbour___2 *);
	void (*ndo_neigh_destroy)(struct net_device___9 *, struct neighbour___2 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___5 *, struct netlink_callback___3 *, struct net_device___9 *, struct net_device___9 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___5 *, struct nlattr **, struct net_device___9 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___9 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___5 *, u32, u32, struct net_device___9 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___9 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___9 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___9 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___9 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___9 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___9 *, struct net_device___9 *);
	void (*ndo_dfwd_del_station)(struct net_device___9 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___9 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___9 *);
	int (*ndo_change_proto_down)(struct net_device___9 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___9 *, struct sk_buff___5 *);
	void (*ndo_set_rx_headroom)(struct net_device___9 *, int);
	int (*ndo_bpf)(struct net_device___9 *, struct netdev_bpf___3 *);
	int (*ndo_xdp_xmit)(struct net_device___9 *, int, struct xdp_frame___3 **, u32);
	struct net_device___9 * (*ndo_xdp_get_xmit_slave)(struct net_device___9 *, struct xdp_buff___3 *);
	int (*ndo_xsk_wakeup)(struct net_device___9 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___9 *);
	int (*ndo_tunnel_ctl)(struct net_device___9 *, struct ip_tunnel_parm *, int);
	struct net_device___9 * (*ndo_get_peer_dev)(struct net_device___9 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___3 *, struct net_device_path___3 *);
};

struct neigh_parms___3 {
	possible_net_t___3 net;
	struct net_device___9 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___2 *);
	struct neigh_table___2 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___3 {
	u32 (*l3mdev_fib_table)(const struct net_device___9 *);
	struct sk_buff___5 * (*l3mdev_l3_rcv)(struct net_device___9 *, struct sk_buff___5 *, u16);
	struct sk_buff___5 * (*l3mdev_l3_out)(struct net_device___9 *, struct sock___5 *, struct sk_buff___5 *, u16);
	struct dst_entry___3 * (*l3mdev_link_scope_lookup)(const struct net_device___9 *, struct flowi6 *);
};

struct ndisc_ops___2 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___9 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___9 *, struct neighbour___2 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___9 *, u8, struct neighbour___2 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___9 *, struct sk_buff___5 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___5 *, struct net_device___9 *, const struct prefix_info *, struct inet6_dev___2 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___2;

struct inet6_dev___2 {
	struct net_device___9 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___2 *mc_list;
	struct ifmcaddr6___2 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___3 mc_query_queue;
	struct sk_buff_head___3 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___3 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___3;

struct tcf_block___3;

struct mini_Qdisc___3 {
	struct tcf_proto___3 *filter_list;
	struct tcf_block___3 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___3 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___9 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___9 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___5 *, struct net_device___9 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___9 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___9 *, struct list_head *);
	size_t (*get_size)(const struct net_device___9 *);
	int (*fill_info)(struct sk_buff___5 *, const struct net_device___9 *);
	size_t (*get_xstats_size)(const struct net_device___9 *);
	int (*fill_xstats)(struct sk_buff___5 *, const struct net_device___9 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___9 *, struct net_device___9 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___9 *, const struct net_device___9 *);
	int (*fill_slave_info)(struct sk_buff___5 *, const struct net_device___9 *, const struct net_device___9 *);
	struct net___5 * (*get_link_net)(const struct net_device___9 *);
	size_t (*get_linkxstats_size)(const struct net_device___9 *, int);
	int (*fill_linkxstats)(struct sk_buff___5 *, const struct net_device___9 *, int *, int);
};

struct gnet_dump___3 {
	spinlock_t *lock;
	struct sk_buff___5 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___3;

struct Qdisc_ops___3 {
	struct Qdisc_ops___3 *next;
	const struct Qdisc_class_ops___3 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___5 *, struct Qdisc___3 *, struct sk_buff___5 **);
	struct sk_buff___5 * (*dequeue)(struct Qdisc___3 *);
	struct sk_buff___5 * (*peek)(struct Qdisc___3 *);
	int (*init)(struct Qdisc___3 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___3 *);
	void (*destroy)(struct Qdisc___3 *);
	int (*change)(struct Qdisc___3 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___3 *);
	int (*change_tx_queue_len)(struct Qdisc___3 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___3 *, unsigned int);
	int (*dump)(struct Qdisc___3 *, struct sk_buff___5 *);
	int (*dump_stats)(struct Qdisc___3 *, struct gnet_dump___3 *);
	void (*ingress_block_set)(struct Qdisc___3 *, u32);
	void (*egress_block_set)(struct Qdisc___3 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___3 *);
	u32 (*egress_block_get)(struct Qdisc___3 *);
	struct module___28 *owner;
};

struct Qdisc_class_ops___3 {
	unsigned int flags;
	struct netdev_queue___3 * (*select_queue)(struct Qdisc___3 *, struct tcmsg *);
	int (*graft)(struct Qdisc___3 *, long unsigned int, struct Qdisc___3 *, struct Qdisc___3 **, struct netlink_ext_ack *);
	struct Qdisc___3 * (*leaf)(struct Qdisc___3 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___3 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___3 *, u32);
	int (*change)(struct Qdisc___3 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___3 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___3 *, struct qdisc_walker *);
	struct tcf_block___3 * (*tcf_block)(struct Qdisc___3 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___3 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___3 *, long unsigned int);
	int (*dump)(struct Qdisc___3 *, long unsigned int, struct sk_buff___5 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___3 *, long unsigned int, struct gnet_dump___3 *);
};

struct tcf_chain___3;

struct tcf_block___3 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___5 *net;
	struct Qdisc___3 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___3 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___3;

struct tcf_proto_ops___3;

struct tcf_proto___3 {
	struct tcf_proto___3 *next;
	void *root;
	int (*classify)(struct sk_buff___5 *, const struct tcf_proto___3 *, struct tcf_result___3 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___3 *ops;
	struct tcf_chain___3 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___3 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___3 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___3 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___5 *, const struct tcf_proto___3 *, struct tcf_result___3 *);
	int (*init)(struct tcf_proto___3 *);
	void (*destroy)(struct tcf_proto___3 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___3 *, u32);
	void (*put)(struct tcf_proto___3 *, void *);
	int (*change)(struct net___5 *, struct sk_buff___5 *, struct tcf_proto___3 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___3 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___3 *);
	void (*walk)(struct tcf_proto___3 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___3 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___3 *, void *);
	void (*hw_del)(struct tcf_proto___3 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___5 *, struct tcf_chain___3 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___5 *, struct tcf_proto___3 *, void *, struct sk_buff___5 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___5 *, struct tcf_proto___3 *, void *, struct sk_buff___5 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___5 *, struct net___5 *, void *);
	struct module___28 *owner;
	int flags;
};

struct tcf_chain___3 {
	struct mutex filter_chain_lock;
	struct tcf_proto___3 *filter_chain;
	struct list_head list;
	struct tcf_block___3 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___3 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___2 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___3 *prog;
};

struct pneigh_entry___2;

struct neigh_hash_table___2;

struct neigh_table___2 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___9 *, __u32 *);
	bool (*key_eq)(const struct neighbour___2 *, const void *);
	int (*constructor)(struct neighbour___2 *);
	int (*pconstructor)(struct pneigh_entry___2 *);
	void (*pdestructor)(struct pneigh_entry___2 *);
	void (*proxy_redo)(struct sk_buff___5 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___9 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___3 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___3 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___2 *nht;
	struct pneigh_entry___2 **phash_buckets;
};

struct neigh_ops___2 {
	int family;
	void (*solicit)(struct neighbour___2 *, struct sk_buff___5 *);
	void (*error_report)(struct neighbour___2 *, struct sk_buff___5 *);
	int (*output)(struct neighbour___2 *, struct sk_buff___5 *);
	int (*connected_output)(struct neighbour___2 *, struct sk_buff___5 *);
};

struct pneigh_entry___2 {
	struct pneigh_entry___2 *next;
	possible_net_t___3 net;
	struct net_device___9 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___2 {
	struct neighbour___2 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___2 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___2 *ctarget;
	struct net___5 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___2 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___2 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___2;

struct timewait_sock_ops___2;

struct proto___2 {
	void (*close)(struct sock___5 *, long int);
	int (*pre_connect)(struct sock___5 *, struct sockaddr *, int);
	int (*connect)(struct sock___5 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___5 *, int);
	struct sock___5 * (*accept)(struct sock___5 *, int, int *, bool);
	int (*ioctl)(struct sock___5 *, int, long unsigned int);
	int (*init)(struct sock___5 *);
	void (*destroy)(struct sock___5 *);
	void (*shutdown)(struct sock___5 *, int);
	int (*setsockopt)(struct sock___5 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___5 *, int, int, char *, int *);
	void (*keepalive)(struct sock___5 *, int);
	int (*compat_ioctl)(struct sock___5 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___5 *, struct msghdr___2 *, size_t);
	int (*recvmsg)(struct sock___5 *, struct msghdr___2 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___5 *, struct page___27 *, int, size_t, int);
	int (*bind)(struct sock___5 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___5 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___5 *, struct sk_buff___5 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___5 *);
	int (*hash)(struct sock___5 *);
	void (*unhash)(struct sock___5 *);
	void (*rehash)(struct sock___5 *);
	int (*get_port)(struct sock___5 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___5 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___5 *, int);
	bool (*sock_is_readable)(struct sock___5 *);
	void (*enter_memory_pressure)(struct sock___5 *);
	void (*leave_memory_pressure)(struct sock___5 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___2 *rsk_prot;
	struct timewait_sock_ops___2 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___28 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___5 *, int);
};

struct request_sock___2;

struct request_sock_ops___2 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___5 *, struct request_sock___2 *);
	void (*send_ack)(const struct sock___5 *, struct sk_buff___5 *, struct request_sock___2 *);
	void (*send_reset)(const struct sock___5 *, struct sk_buff___5 *);
	void (*destructor)(struct request_sock___2 *);
	void (*syn_ack_timeout)(const struct request_sock___2 *);
};

struct timewait_sock_ops___2 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___5 *, struct sock___5 *, void *);
	void (*twsk_destructor)(struct sock___5 *);
};

struct request_sock___2 {
	struct sock_common___2 __req_common;
	struct request_sock___2 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___2 *rsk_ops;
	struct sock___5 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___2 {
	struct in6_addr mca_addr;
	struct inet6_dev___2 *idev;
	struct ifmcaddr6___2 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct property___13 {
	char *name;
	int length;
	void *value;
	struct property___13 *next;
	long unsigned int _flags;
	struct bin_attribute___26 attr;
};

struct irq_fwspec___12 {
	struct fwnode_handle___24 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___12 {
	int (*match)(struct irq_domain___12 *, struct device_node___16 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___12 *, struct irq_fwspec___12 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___12 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___12 *, unsigned int);
	int (*xlate)(struct irq_domain___12 *, struct device_node___16 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___12 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___12 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___12 *, struct irq_data___12 *, bool);
	void (*deactivate)(struct irq_domain___12 *, struct irq_data___12 *);
	int (*translate)(struct irq_domain___12 *, struct irq_fwspec___12 *, long unsigned int *, unsigned int *);
};

struct linux_binprm___5 {
	struct vm_area_struct___26 *vma;
	long unsigned int vma_pages;
	struct mm_struct___27 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___27 *executable;
	struct file___27 *interpreter;
	struct file___27 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___4 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___27 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct core_vma_metadata {
	long unsigned int start;
	long unsigned int end;
	long unsigned int flags;
	long unsigned int dump_size;
	long unsigned int pgoff;
	struct file___27 *file;
};

enum sysctl_writes_mode {
	SYSCTL_WRITES_LEGACY = 4294967295,
	SYSCTL_WRITES_WARN = 0,
	SYSCTL_WRITES_STRICT = 1,
};

struct do_proc_dointvec_minmax_conv_param {
	int *min;
	int *max;
};

struct do_proc_douintvec_minmax_conv_param {
	unsigned int *min;
	unsigned int *max;
};

struct __user_cap_header_struct {
	__u32 version;
	int pid;
};

typedef struct __user_cap_header_struct *cap_user_header_t;

struct __user_cap_data_struct {
	__u32 effective;
	__u32 permitted;
	__u32 inheritable;
};

typedef struct __user_cap_data_struct *cap_user_data_t;

struct dentry___28;

struct super_block___28;

struct module___29;

struct file_system_type___27 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___28 * (*mount)(struct file_system_type___27 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___28 *);
	struct module___29 *owner;
	struct file_system_type___27 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___28;

struct kiocb___27;

struct poll_table_struct___21;

struct vm_area_struct___27;

struct inode___29;

struct file_lock___27;

struct page___28;

struct seq_file___28;

struct file_operations___27 {
	struct module___29 *owner;
	loff_t (*llseek)(struct file___28 *, loff_t, int);
	ssize_t (*read)(struct file___28 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___28 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___27 *, struct iov_iter___13 *);
	ssize_t (*write_iter)(struct kiocb___27 *, struct iov_iter___13 *);
	int (*iopoll)(struct kiocb___27 *, bool);
	int (*iterate)(struct file___28 *, struct dir_context *);
	int (*iterate_shared)(struct file___28 *, struct dir_context *);
	__poll_t (*poll)(struct file___28 *, struct poll_table_struct___21 *);
	long int (*unlocked_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___28 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___28 *, struct vm_area_struct___27 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___29 *, struct file___28 *);
	int (*flush)(struct file___28 *, fl_owner_t);
	int (*release)(struct inode___29 *, struct file___28 *);
	int (*fsync)(struct file___28 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___28 *, int);
	int (*lock)(struct file___28 *, int, struct file_lock___27 *);
	ssize_t (*sendpage)(struct file___28 *, struct page___28 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___28 *, long unsigned int);
	int (*flock)(struct file___28 *, int, struct file_lock___27 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___28 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___28 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___28 *, long int, struct file_lock___27 **, void **);
	long int (*fallocate)(struct file___28 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___28 *, struct file___28 *);
	ssize_t (*copy_file_range)(struct file___28 *, loff_t, struct file___28 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___28 *, loff_t, struct file___28 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___28 *, loff_t, loff_t, int);
};

struct vmacache___27 {
	u64 seqnum;
	struct vm_area_struct___27 *vmas[4];
};

struct page_frag___27 {
	struct page___28 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___18;

struct debug_info___18 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___18 *hbp_break[16];
	struct perf_event___18 *hbp_watch[16];
};

struct thread_struct___18 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___18 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___28;

struct pid___26;

struct nsproxy___27;

struct signal_struct___28;

struct css_set___20;

struct perf_event_context___18;

struct vm_struct___27;

struct task_struct___29 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___29 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___28 *mm;
	struct mm_struct___28 *active_mm;
	struct vmacache___27 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___29 *real_parent;
	struct task_struct___29 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___29 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___26 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___27 *nsproxy;
	struct signal_struct___28 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___29 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___12 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___20 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___18 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___27 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___29 *oom_reaper_list;
	struct vm_struct___27 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___18 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___27;

struct kobj_type___27;

struct kernfs_node___27;

struct kobject___27 {
	const char *name;
	struct list_head entry;
	struct kobject___27 *parent;
	struct kset___27 *kset;
	struct kobj_type___27 *ktype;
	struct kernfs_node___27 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___27 {
	struct kobject___27 kobj;
	struct module___29 *mod;
	struct kobject___27 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___27 {
	struct module___29 *mod;
	struct latch_tree_node node;
};

struct module_layout___27 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___27 mtn;
};

struct module_attribute___27;

struct kernel_param___27;

struct trace_event_call___13;

struct module___29 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___27 mkobj;
	struct module_attribute___27 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___27 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___27 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___27 core_layout;
	struct module_layout___27 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___13 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___18 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___29 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___18)(struct perf_event___18 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___18;

struct fasync_struct___27;

struct pid_namespace___26;

struct perf_cgroup___18;

struct perf_event___18 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___18 *group_leader;
	struct pmu___18 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___18 hw;
	struct perf_event_context___18 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___18 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___29 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___27 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___18 *aux_event;
	void (*destroy)(struct perf_event___18 *);
	struct callback_head callback_head;
	struct pid_namespace___26 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___18 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___18 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___13 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___18 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___26 {
	int nr;
	struct pid_namespace___26 *ns;
};

struct pid_namespace___26 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___29 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___26 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common ns;
};

struct pid___26 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___26 numbers[1];
};

typedef struct page___28 *pgtable_t___27;

struct address_space___27;

struct dev_pagemap___27;

struct page___28 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___27 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___28 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___27 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___28 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___27 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct sigqueue {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct ucounts *ucounts;
};

struct vm_operations_struct___27;

struct vm_area_struct___27 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___27 *vm_next;
	struct vm_area_struct___27 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___28 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___27 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___28 *vm_file;
	struct file___28 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___28 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___29 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___29 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___26 *pids[4];
	struct pid___26 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___28 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___27;

struct mm_struct___28 {
	struct {
		struct vm_area_struct___27 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___28 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___27 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___29 *owner;
		struct user_namespace *user_ns;
		struct file___28 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___20;

struct nsproxy___27 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___26 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___20 *cgroup_ns;
};

struct cgroup_subsys_state___20;

struct cgroup___20;

struct css_set___20 {
	struct cgroup_subsys_state___20 *subsys[14];
	refcount_t refcount;
	struct css_set___20 *dom_cset;
	struct cgroup___20 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___20 *mg_src_cgrp;
	struct cgroup___20 *mg_dst_cgrp;
	struct css_set___20 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___18 {
	struct pmu___18 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___29 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___18 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___27 {
	struct vm_struct___27 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___28 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___27;

struct address_space___27 {
	struct inode___29 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___27 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___27;

struct dev_pagemap___27 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___27 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___27;

struct path___27 {
	struct vfsmount___27 *mnt;
	struct dentry___28 *dentry;
};

struct fown_struct___26 {
	rwlock_t lock;
	struct pid___26 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___28 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___27 f_path;
	struct inode___29 *f_inode;
	const struct file_operations___27 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___26 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___27 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___27;

struct vm_operations_struct___27 {
	void (*open)(struct vm_area_struct___27 *);
	void (*close)(struct vm_area_struct___27 *);
	int (*may_split)(struct vm_area_struct___27 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___27 *);
	int (*mprotect)(struct vm_area_struct___27 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___27 *);
	vm_fault_t (*huge_fault)(struct vm_fault___27 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___27 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___27 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___27 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___27 *);
	int (*access)(struct vm_area_struct___27 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___27 *);
	int (*set_policy)(struct vm_area_struct___27 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___27 *, long unsigned int);
	struct page___28 * (*find_special_page)(struct vm_area_struct___27 *, long unsigned int);
};

struct core_thread___27 {
	struct task_struct___29 *task;
	struct core_thread___27 *next;
};

struct core_state___27 {
	atomic_t nr_threads;
	struct core_thread___27 dumper;
	struct completion startup;
};

struct vm_fault___27 {
	const struct {
		struct vm_area_struct___27 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___28 *cow_page;
	struct page___28 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___27 prealloc_pte;
};

struct cgroup_subsys___20;

struct cgroup_subsys_state___20 {
	struct cgroup___20 *cgroup;
	struct cgroup_subsys___20 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___20 *parent;
};

struct cgroup_file___20 {
	struct kernfs_node___27 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___20 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___29 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___20;

struct cgroup_rstat_cpu___20;

struct cgroup___20 {
	struct cgroup_subsys_state___20 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___27 *kn;
	struct cgroup_file___20 procs_file;
	struct cgroup_file___20 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___20 *subsys[14];
	struct cgroup_root___20 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___20 *dom_cgrp;
	struct cgroup___20 *old_dom_cgrp;
	struct cgroup_rstat_cpu___20 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___20 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct dev_pagemap_ops___27 {
	void (*page_free)(struct page___28 *);
	void (*kill)(struct dev_pagemap___27 *);
	void (*cleanup)(struct dev_pagemap___27 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___27 *);
};

typedef int wait_bit_action_f(struct wait_bit_key *, int);

struct dentry_operations___27;

struct dentry___28 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___28 *d_parent;
	struct qstr d_name;
	struct inode___29 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___27 *d_op;
	struct super_block___28 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___27;

struct inode___29 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___27 *i_op;
	struct super_block___28 *i_sb;
	struct address_space___27 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___27 *i_fop;
		void (*free_inode)(struct inode___29 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___27 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___7 *i_pipe;
		struct cdev___14 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___27 {
	int (*d_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___28 *, unsigned int);
	int (*d_hash)(const struct dentry___28 *, struct qstr *);
	int (*d_compare)(const struct dentry___28 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___28 *);
	int (*d_init)(struct dentry___28 *);
	void (*d_release)(struct dentry___28 *);
	void (*d_prune)(struct dentry___28 *);
	void (*d_iput)(struct dentry___28 *, struct inode___29 *);
	char * (*d_dname)(struct dentry___28 *, char *, int);
	struct vfsmount___27 * (*d_automount)(struct path___27 *);
	int (*d_manage)(const struct path___27 *, bool);
	struct dentry___28 * (*d_real)(struct dentry___28 *, const struct inode___29 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___27;

struct mem_dqinfo___27 {
	struct quota_format_type___27 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___27;

struct quota_info___27 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___29 *files[3];
	struct mem_dqinfo___27 info[3];
	const struct quota_format_ops___27 *ops[3];
};

struct rcuwait___27 {
	struct task_struct___29 *task;
};

struct percpu_rw_semaphore___27 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___27 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___27 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___27 rw_sem[3];
};

struct super_operations___27;

struct dquot_operations___27;

struct quotactl_ops___27;

struct super_block___28 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___27 *s_type;
	const struct super_operations___27 *s_op;
	const struct dquot_operations___27 *dq_op;
	const struct quotactl_ops___27 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___28 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___27 s_dquot;
	struct sb_writers___27 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___27 *s_d_op;
	int cleancache_poolid;
	struct shrinker___10 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___27 {
	struct dentry___28 *mnt_root;
	struct super_block___28 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___13;

struct kiocb___27 {
	struct file___28 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___27 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___13 *ki_waitq;
	};
};

struct iattr___28 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___28 *ia_file;
};

struct dquot___27 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___28 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___27 {
	int qf_fmt_id;
	const struct quota_format_ops___27 *qf_ops;
	struct module___29 *qf_owner;
	struct quota_format_type___27 *qf_next;
};

struct quota_format_ops___27 {
	int (*check_quota_file)(struct super_block___28 *, int);
	int (*read_file_info)(struct super_block___28 *, int);
	int (*write_file_info)(struct super_block___28 *, int);
	int (*free_file_info)(struct super_block___28 *, int);
	int (*read_dqblk)(struct dquot___27 *);
	int (*commit_dqblk)(struct dquot___27 *);
	int (*release_dqblk)(struct dquot___27 *);
	int (*get_next_id)(struct super_block___28 *, struct kqid *);
};

struct dquot_operations___27 {
	int (*write_dquot)(struct dquot___27 *);
	struct dquot___27 * (*alloc_dquot)(struct super_block___28 *, int);
	void (*destroy_dquot)(struct dquot___27 *);
	int (*acquire_dquot)(struct dquot___27 *);
	int (*release_dquot)(struct dquot___27 *);
	int (*mark_dirty)(struct dquot___27 *);
	int (*write_info)(struct super_block___28 *, int);
	qsize_t * (*get_reserved_space)(struct inode___29 *);
	int (*get_projid)(struct inode___29 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___29 *, qsize_t *);
	int (*get_next_id)(struct super_block___28 *, struct kqid *);
};

struct quotactl_ops___27 {
	int (*quota_on)(struct super_block___28 *, int, int, const struct path___27 *);
	int (*quota_off)(struct super_block___28 *, int);
	int (*quota_enable)(struct super_block___28 *, unsigned int);
	int (*quota_disable)(struct super_block___28 *, unsigned int);
	int (*quota_sync)(struct super_block___28 *, int);
	int (*set_info)(struct super_block___28 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___28 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___28 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___28 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___28 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___28 *, unsigned int);
};

struct wait_page_queue___13 {
	struct page___28 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___13;

struct address_space_operations___27 {
	int (*writepage)(struct page___28 *, struct writeback_control___3 *);
	int (*readpage)(struct file___28 *, struct page___28 *);
	int (*writepages)(struct address_space___27 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___28 *);
	int (*readpages)(struct file___28 *, struct address_space___27 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___13 *);
	int (*write_begin)(struct file___28 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___28 **, void **);
	int (*write_end)(struct file___28 *, struct address_space___27 *, loff_t, unsigned int, unsigned int, struct page___28 *, void *);
	sector_t (*bmap)(struct address_space___27 *, sector_t);
	void (*invalidatepage)(struct page___28 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___28 *, gfp_t);
	void (*freepage)(struct page___28 *);
	ssize_t (*direct_IO)(struct kiocb___27 *, struct iov_iter___13 *);
	int (*migratepage)(struct address_space___27 *, struct page___28 *, struct page___28 *, enum migrate_mode);
	bool (*isolate_page)(struct page___28 *, isolate_mode_t);
	void (*putback_page)(struct page___28 *);
	int (*launder_page)(struct page___28 *);
	int (*is_partially_uptodate)(struct page___28 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___28 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___27 *, struct page___28 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___28 *, sector_t *);
	void (*swap_deactivate)(struct file___28 *);
};

struct readahead_control___13 {
	struct file___28 *file;
	struct address_space___27 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___27 {
	struct dentry___28 * (*lookup)(struct inode___29 *, struct dentry___28 *, unsigned int);
	const char * (*get_link)(struct dentry___28 *, struct inode___29 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___29 *, int);
	struct posix_acl * (*get_acl)(struct inode___29 *, int, bool);
	int (*readlink)(struct dentry___28 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___29 *, struct dentry___28 *, umode_t, bool);
	int (*link)(struct dentry___28 *, struct inode___29 *, struct dentry___28 *);
	int (*unlink)(struct inode___29 *, struct dentry___28 *);
	int (*symlink)(struct user_namespace *, struct inode___29 *, struct dentry___28 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___29 *, struct dentry___28 *, umode_t);
	int (*rmdir)(struct inode___29 *, struct dentry___28 *);
	int (*mknod)(struct user_namespace *, struct inode___29 *, struct dentry___28 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___29 *, struct dentry___28 *, struct inode___29 *, struct dentry___28 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___28 *, struct iattr___28 *);
	int (*getattr)(struct user_namespace *, const struct path___27 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___28 *, char *, size_t);
	int (*fiemap)(struct inode___29 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___29 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___29 *, struct dentry___28 *, struct file___28 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___29 *, struct dentry___28 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___29 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___28 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___28 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___27 {
	void (*fl_copy_lock)(struct file_lock___27 *, struct file_lock___27 *);
	void (*fl_release_private)(struct file_lock___27 *);
};

struct lock_manager_operations___27;

struct file_lock___27 {
	struct file_lock___27 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___28 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___27 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___27 *fl_ops;
	const struct lock_manager_operations___27 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___27 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___27 *);
	int (*lm_grant)(struct file_lock___27 *, int);
	bool (*lm_break)(struct file_lock___27 *);
	int (*lm_change)(struct file_lock___27 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___27 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___27 *);
};

struct fasync_struct___27 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___27 *fa_next;
	struct file___28 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___27 {
	struct inode___29 * (*alloc_inode)(struct super_block___28 *);
	void (*destroy_inode)(struct inode___29 *);
	void (*free_inode)(struct inode___29 *);
	void (*dirty_inode)(struct inode___29 *, int);
	int (*write_inode)(struct inode___29 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___29 *);
	void (*evict_inode)(struct inode___29 *);
	void (*put_super)(struct super_block___28 *);
	int (*sync_fs)(struct super_block___28 *, int);
	int (*freeze_super)(struct super_block___28 *);
	int (*freeze_fs)(struct super_block___28 *);
	int (*thaw_super)(struct super_block___28 *);
	int (*unfreeze_fs)(struct super_block___28 *);
	int (*statfs)(struct dentry___28 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___28 *, int *, char *);
	void (*umount_begin)(struct super_block___28 *);
	int (*show_options)(struct seq_file___28 *, struct dentry___28 *);
	int (*show_devname)(struct seq_file___28 *, struct dentry___28 *);
	int (*show_path)(struct seq_file___28 *, struct dentry___28 *);
	int (*show_stats)(struct seq_file___28 *, struct dentry___28 *);
	ssize_t (*quota_read)(struct super_block___28 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___28 *, int, const char *, size_t, loff_t);
	struct dquot___27 ** (*get_dquots)(struct inode___29 *);
	long int (*nr_cached_objects)(struct super_block___28 *, struct shrink_control___10 *);
	long int (*free_cached_objects)(struct super_block___28 *, struct shrink_control___10 *);
	struct file___28 * (*real_loop)(struct file___28 *);
};

typedef void (*poll_queue_proc___21)(struct file___28 *, wait_queue_head_t *, struct poll_table_struct___21 *);

struct poll_table_struct___21 {
	poll_queue_proc___21 _qproc;
	__poll_t _key;
};

struct seq_operations___26;

struct seq_file___28 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___26 *op;
	int poll_event;
	const struct file___28 *file;
	void *private;
};

struct fwnode_operations___25;

struct device___25;

struct fwnode_handle___25 {
	struct fwnode_handle___25 *secondary;
	const struct fwnode_operations___25 *ops;
	struct device___25 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___25;

struct fwnode_endpoint___25;

struct fwnode_operations___25 {
	struct fwnode_handle___25 * (*get)(struct fwnode_handle___25 *);
	void (*put)(struct fwnode_handle___25 *);
	bool (*device_is_available)(const struct fwnode_handle___25 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___25 *, const struct device___25 *);
	bool (*property_present)(const struct fwnode_handle___25 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___25 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___25 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___25 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_parent)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_next_child_node)(const struct fwnode_handle___25 *, struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*get_named_child_node)(const struct fwnode_handle___25 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___25 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___25 *);
	struct fwnode_handle___25 * (*graph_get_next_endpoint)(const struct fwnode_handle___25 *, struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*graph_get_remote_endpoint)(const struct fwnode_handle___25 *);
	struct fwnode_handle___25 * (*graph_get_port_parent)(struct fwnode_handle___25 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___25 *, struct fwnode_endpoint___25 *);
	int (*add_links)(struct fwnode_handle___25 *);
};

struct wakeup_source___25;

struct dev_pm_info___25 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___25 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___25 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___25;

struct bus_type___25;

struct device_driver___25;

struct dev_pm_domain___25;

struct class___25;

struct attribute_group___27;

struct device___25 {
	struct kobject___27 kobj;
	struct device___25 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___25 *type;
	struct bus_type___25 *bus;
	struct device_driver___25 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___25 power;
	struct dev_pm_domain___25 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___25 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___25 *class;
	const struct attribute_group___27 **groups;
	void (*release)(struct device___25 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___25 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___25 *local_fwnode;
};

struct fwnode_reference_args___25 {
	struct fwnode_handle___25 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___27;

struct kernfs_elem_dir___27 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___27 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___27;

struct kernfs_root___27 {
	struct kernfs_node___27 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___27 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___27 {
	struct kernfs_node___27 *target_kn;
};

struct kernfs_ops___27;

struct kernfs_elem_attr___27 {
	const struct kernfs_ops___27 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___27 *notify_next;
};

struct kernfs_node___27 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___27 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___27 dir;
		struct kernfs_elem_symlink___27 symlink;
		struct kernfs_elem_attr___27 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___27;

struct kernfs_ops___27 {
	int (*open)(struct kernfs_open_file___27 *);
	void (*release)(struct kernfs_open_file___27 *);
	int (*seq_show)(struct seq_file___28 *, void *);
	void * (*seq_start)(struct seq_file___28 *, loff_t *);
	void * (*seq_next)(struct seq_file___28 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___28 *, void *);
	ssize_t (*read)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___27 *, struct poll_table_struct___21 *);
	int (*mmap)(struct kernfs_open_file___27 *, struct vm_area_struct___27 *);
};

struct kernfs_syscall_ops___27 {
	int (*show_options)(struct seq_file___28 *, struct kernfs_root___27 *);
	int (*mkdir)(struct kernfs_node___27 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___27 *);
	int (*rename)(struct kernfs_node___27 *, struct kernfs_node___27 *, const char *);
	int (*show_path)(struct seq_file___28 *, struct kernfs_node___27 *, struct kernfs_root___27 *);
};

struct kernfs_open_file___27 {
	struct kernfs_node___27 *kn;
	struct file___28 *file;
	struct seq_file___28 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___27 *vm_ops;
};

struct bin_attribute___27;

struct attribute_group___27 {
	const char *name;
	umode_t (*is_visible)(struct kobject___27 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___27 *, struct bin_attribute___27 *, int);
	struct attribute **attrs;
	struct bin_attribute___27 **bin_attrs;
};

struct bin_attribute___27 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___27 * (*f_mapping)();
	ssize_t (*read)(struct file___28 *, struct kobject___27 *, struct bin_attribute___27 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___28 *, struct kobject___27 *, struct bin_attribute___27 *, char *, loff_t, size_t);
	int (*mmap)(struct file___28 *, struct kobject___27 *, struct bin_attribute___27 *, struct vm_area_struct___27 *);
};

struct sysfs_ops___27 {
	ssize_t (*show)(struct kobject___27 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___27 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___27;

struct kset___27 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___27 kobj;
	const struct kset_uevent_ops___27 *uevent_ops;
};

struct kobj_type___27 {
	void (*release)(struct kobject___27 *);
	const struct sysfs_ops___27 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___27 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___27 *);
	const void * (*namespace)(struct kobject___27 *);
	void (*get_ownership)(struct kobject___27 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___27 {
	int (* const filter)(struct kset___27 *, struct kobject___27 *);
	const char * (* const name)(struct kset___27 *, struct kobject___27 *);
	int (* const uevent)(struct kset___27 *, struct kobject___27 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___27 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___27 *);
	int (*get)(char *, const struct kernel_param___27 *);
	void (*free)(void *);
};

struct kparam_array___27;

struct kernel_param___27 {
	const char *name;
	struct module___29 *mod;
	const struct kernel_param_ops___27 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___27 *arr;
	};
};

struct kparam_array___27 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___27 *ops;
	void *elem;
};

struct module_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___27 *, struct module_kobject___27 *, char *);
	ssize_t (*store)(struct module_attribute___27 *, struct module_kobject___27 *, const char *, size_t);
	void (*setup)(struct module___29 *, const char *);
	int (*test)(struct module___29 *);
	void (*free)(struct module___29 *);
};

struct trace_event_class___13;

struct trace_event_call___13 {
	struct list_head list;
	struct trace_event_class___13 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___13 *, struct perf_event___18 *);
};

struct cgroup_namespace___20 {
	struct ns_common ns;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct css_set___20 *root_cset;
};

struct ptrace_peeksiginfo_args {
	__u64 off;
	__u32 flags;
	__s32 nr;
};

struct ptrace_syscall_info {
	__u8 op;
	__u8 pad[3];
	__u32 arch;
	__u64 instruction_pointer;
	__u64 stack_pointer;
	union {
		struct {
			__u64 nr;
			__u64 args[6];
		} entry;
		struct {
			__s64 rval;
			__u8 is_error;
		} exit;
		struct {
			__u64 nr;
			__u64 args[6];
			__u32 ret_data;
		} seccomp;
	};
};

struct ptrace_rseq_configuration {
	__u64 rseq_abi_pointer;
	__u32 rseq_abi_size;
	__u32 signature;
	__u32 flags;
	__u32 pad;
};

struct compat_iovec {
	compat_uptr_t iov_base;
	compat_size_t iov_len;
};

typedef struct compat_siginfo compat_siginfo_t;

struct dev_pm_ops___25 {
	int (*prepare)(struct device___25 *);
	void (*complete)(struct device___25 *);
	int (*suspend)(struct device___25 *);
	int (*resume)(struct device___25 *);
	int (*freeze)(struct device___25 *);
	int (*thaw)(struct device___25 *);
	int (*poweroff)(struct device___25 *);
	int (*restore)(struct device___25 *);
	int (*suspend_late)(struct device___25 *);
	int (*resume_early)(struct device___25 *);
	int (*freeze_late)(struct device___25 *);
	int (*thaw_early)(struct device___25 *);
	int (*poweroff_late)(struct device___25 *);
	int (*restore_early)(struct device___25 *);
	int (*suspend_noirq)(struct device___25 *);
	int (*resume_noirq)(struct device___25 *);
	int (*freeze_noirq)(struct device___25 *);
	int (*thaw_noirq)(struct device___25 *);
	int (*poweroff_noirq)(struct device___25 *);
	int (*restore_noirq)(struct device___25 *);
	int (*runtime_suspend)(struct device___25 *);
	int (*runtime_resume)(struct device___25 *);
	int (*runtime_idle)(struct device___25 *);
};

struct wakeup_source___25 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___25 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___25 {
	struct dev_pm_ops___25 ops;
	int (*start)(struct device___25 *);
	void (*detach)(struct device___25 *, bool);
	int (*activate)(struct device___25 *);
	void (*sync)(struct device___25 *);
	void (*dismiss)(struct device___25 *);
};

struct bus_type___25 {
	const char *name;
	const char *dev_name;
	struct device___25 *dev_root;
	const struct attribute_group___27 **bus_groups;
	const struct attribute_group___27 **dev_groups;
	const struct attribute_group___27 **drv_groups;
	int (*match)(struct device___25 *, struct device_driver___25 *);
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	int (*probe)(struct device___25 *);
	void (*sync_state)(struct device___25 *);
	void (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*online)(struct device___25 *);
	int (*offline)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	int (*num_vf)(struct device___25 *);
	int (*dma_configure)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___25 {
	const char *name;
	struct bus_type___25 *bus;
	struct module___29 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___25 *);
	void (*sync_state)(struct device___25 *);
	int (*remove)(struct device___25 *);
	void (*shutdown)(struct device___25 *);
	int (*suspend)(struct device___25 *, pm_message_t);
	int (*resume)(struct device___25 *);
	const struct attribute_group___27 **groups;
	const struct attribute_group___27 **dev_groups;
	const struct dev_pm_ops___25 *pm;
	void (*coredump)(struct device___25 *);
	struct driver_private *p;
};

struct device_type___25 {
	const char *name;
	const struct attribute_group___27 **groups;
	int (*uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___25 *);
	const struct dev_pm_ops___25 *pm;
};

struct class___25 {
	const char *name;
	struct module___29 *owner;
	const struct attribute_group___27 **class_groups;
	const struct attribute_group___27 **dev_groups;
	struct kobject___27 *dev_kobj;
	int (*dev_uevent)(struct device___25 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___25 *, umode_t *);
	void (*class_release)(struct class___25 *);
	void (*dev_release)(struct device___25 *);
	int (*shutdown_pre)(struct device___25 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___25 *);
	void (*get_ownership)(struct device___25 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___25 *pm;
	struct subsys_private *p;
};

struct seq_operations___26 {
	void * (*start)(struct seq_file___28 *, loff_t *);
	void (*stop)(struct seq_file___28 *, void *);
	void * (*next)(struct seq_file___28 *, void *, loff_t *);
	int (*show)(struct seq_file___28 *, void *);
};

struct cftype___20;

struct cgroup_subsys___20 {
	struct cgroup_subsys_state___20 * (*css_alloc)(struct cgroup_subsys_state___20 *);
	int (*css_online)(struct cgroup_subsys_state___20 *);
	void (*css_offline)(struct cgroup_subsys_state___20 *);
	void (*css_released)(struct cgroup_subsys_state___20 *);
	void (*css_free)(struct cgroup_subsys_state___20 *);
	void (*css_reset)(struct cgroup_subsys_state___20 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___20 *, int);
	int (*css_extra_stat_show)(struct seq_file___28 *, struct cgroup_subsys_state___20 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___29 *, struct css_set___20 *);
	void (*cancel_fork)(struct task_struct___29 *, struct css_set___20 *);
	void (*fork)(struct task_struct___29 *);
	void (*exit)(struct task_struct___29 *);
	void (*release)(struct task_struct___29 *);
	void (*bind)(struct cgroup_subsys_state___20 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___20 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___20 *dfl_cftypes;
	struct cftype___20 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___20 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___20 *updated_children;
	struct cgroup___20 *updated_next;
};

struct cgroup_root___20 {
	struct kernfs_root___27 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___20 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___20 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___20 *ss;
	struct list_head node;
	struct kernfs_ops___27 *kf_ops;
	int (*open)(struct kernfs_open_file___27 *);
	void (*release)(struct kernfs_open_file___27 *);
	u64 (*read_u64)(struct cgroup_subsys_state___20 *, struct cftype___20 *);
	s64 (*read_s64)(struct cgroup_subsys_state___20 *, struct cftype___20 *);
	int (*seq_show)(struct seq_file___28 *, void *);
	void * (*seq_start)(struct seq_file___28 *, loff_t *);
	void * (*seq_next)(struct seq_file___28 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___28 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___20 *, struct cftype___20 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___20 *, struct cftype___20 *, s64);
	ssize_t (*write)(struct kernfs_open_file___27 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___27 *, struct poll_table_struct___21 *);
};

struct perf_cpu_context___18;

struct perf_output_handle___18;

struct pmu___18 {
	struct list_head entry;
	struct module___29 *module;
	struct device___25 *dev;
	const struct attribute_group___27 **attr_groups;
	const struct attribute_group___27 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___18 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___18 *);
	void (*pmu_disable)(struct pmu___18 *);
	int (*event_init)(struct perf_event___18 *);
	void (*event_mapped)(struct perf_event___18 *, struct mm_struct___28 *);
	void (*event_unmapped)(struct perf_event___18 *, struct mm_struct___28 *);
	int (*add)(struct perf_event___18 *, int);
	void (*del)(struct perf_event___18 *, int);
	void (*start)(struct perf_event___18 *, int);
	void (*stop)(struct perf_event___18 *, int);
	void (*read)(struct perf_event___18 *);
	void (*start_txn)(struct pmu___18 *, unsigned int);
	int (*commit_txn)(struct pmu___18 *);
	void (*cancel_txn)(struct pmu___18 *);
	int (*event_idx)(struct perf_event___18 *);
	void (*sched_task)(struct perf_event_context___18 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___18 *, struct perf_event_context___18 *);
	void * (*setup_aux)(struct perf_event___18 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___18 *, struct perf_output_handle___18 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___18 *);
	int (*aux_output_match)(struct perf_event___18 *);
	int (*filter_match)(struct perf_event___18 *);
	int (*check_period)(struct perf_event___18 *, u64);
};

struct perf_cpu_context___18 {
	struct perf_event_context___18 ctx;
	struct perf_event_context___18 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___18 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___18 **heap;
	struct perf_event___18 *heap_default[2];
};

struct perf_output_handle___18 {
	struct perf_event___18 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___18 {
	struct cgroup_subsys_state___20 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___13 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___13 *);
	};
};

struct trace_event_class___13 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___13 *, enum trace_reg, void *);
	struct trace_event_fields___13 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___13 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___13 *);
};

struct syscall_metadata___4 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___13 *enter_event;
	struct trace_event_call___13 *exit_event;
};

struct user_regset___2;

typedef int user_regset_active_fn___2(struct task_struct___29 *, const struct user_regset___2 *);

typedef int user_regset_get2_fn___2(struct task_struct___29 *, const struct user_regset___2 *, struct membuf);

typedef int user_regset_set_fn___2(struct task_struct___29 *, const struct user_regset___2 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___2(struct task_struct___29 *, const struct user_regset___2 *, int);

struct user_regset___2 {
	user_regset_get2_fn___2 *regset_get;
	user_regset_set_fn___2 *set;
	user_regset_active_fn___2 *active;
	user_regset_writeback_fn___2 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___2 {
	const char *name;
	const struct user_regset___2 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct vm_area_struct___28;

struct vmacache___28 {
	u64 seqnum;
	struct vm_area_struct___28 *vmas[4];
};

struct page___29;

struct page_frag___28 {
	struct page___29 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___29;

struct vm_struct___28;

struct task_struct___30 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___30 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___29 *mm;
	struct mm_struct___29 *active_mm;
	struct vmacache___28 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___30 *real_parent;
	struct task_struct___30 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___30 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___26 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___27 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___30 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___28 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___30 *oom_reaper_list;
	struct vm_struct___28 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___18 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___3;

struct ns_common___3 {
	atomic_long_t stashed;
	const struct proc_ns_operations___3 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___2;

struct user_namespace___2 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___2 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___3 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___2 *ucounts;
	long int ucount_max[16];
};

typedef struct page___29 *pgtable_t___28;

struct page___29 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___27 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___29 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___28 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___29 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___27 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___2 {
	struct hlist_node node;
	struct user_namespace___2 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct file___29;

struct vm_area_struct___28 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___28 *vm_next;
	struct vm_area_struct___28 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___29 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___28;

struct mm_struct___29 {
	struct {
		struct vm_area_struct___28 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___28 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___30 *owner;
		struct user_namespace___2 *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___28 {
	struct vm_struct___28 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___29 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct core_thread___28 {
	struct task_struct___30 *task;
	struct core_thread___28 *next;
};

struct core_state___28 {
	atomic_t nr_threads;
	struct core_thread___28 dumper;
	struct completion startup;
};

struct proc_ns_operations___3 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___3 * (*get)(struct task_struct___30 *);
	void (*put)(struct ns_common___3 *);
	int (*install)(struct nsset *, struct ns_common___3 *);
	struct user_namespace___2 * (*owner)(struct ns_common___3 *);
	struct ns_common___3 * (*get_parent)(struct ns_common___3 *);
};

struct dentry___29;

struct super_block___29;

struct module___30;

struct file_system_type___28 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___29 * (*mount)(struct file_system_type___28 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___29 *);
	struct module___30 *owner;
	struct file_system_type___28 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___30;

struct kiocb___28;

struct iov_iter___14;

struct poll_table_struct___22;

struct vm_area_struct___29;

struct inode___30;

struct file_lock___28;

struct page___30;

struct file_operations___28 {
	struct module___30 *owner;
	loff_t (*llseek)(struct file___30 *, loff_t, int);
	ssize_t (*read)(struct file___30 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___30 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___28 *, struct iov_iter___14 *);
	ssize_t (*write_iter)(struct kiocb___28 *, struct iov_iter___14 *);
	int (*iopoll)(struct kiocb___28 *, bool);
	int (*iterate)(struct file___30 *, struct dir_context *);
	int (*iterate_shared)(struct file___30 *, struct dir_context *);
	__poll_t (*poll)(struct file___30 *, struct poll_table_struct___22 *);
	long int (*unlocked_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___30 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___30 *, struct vm_area_struct___29 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___30 *, struct file___30 *);
	int (*flush)(struct file___30 *, fl_owner_t);
	int (*release)(struct inode___30 *, struct file___30 *);
	int (*fsync)(struct file___30 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___30 *, int);
	int (*lock)(struct file___30 *, int, struct file_lock___28 *);
	ssize_t (*sendpage)(struct file___30 *, struct page___30 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___30 *, long unsigned int);
	int (*flock)(struct file___30 *, int, struct file_lock___28 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___30 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___30 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___30 *, long int, struct file_lock___28 **, void **);
	long int (*fallocate)(struct file___30 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___6 *, struct file___30 *);
	ssize_t (*copy_file_range)(struct file___30 *, loff_t, struct file___30 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___30 *, loff_t, struct file___30 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___30 *, loff_t, loff_t, int);
};

struct vmacache___29 {
	u64 seqnum;
	struct vm_area_struct___29 *vmas[4];
};

struct page_frag___29 {
	struct page___30 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___19;

struct debug_info___19 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___19 *hbp_break[16];
	struct perf_event___19 *hbp_watch[16];
};

struct thread_struct___19 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___19 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___30;

struct pid___27;

struct nsproxy___28;

struct signal_struct___29;

struct bio_list___12;

struct backing_dev_info___11;

struct io_context___13;

struct css_set___21;

struct perf_event_context___19;

struct mem_cgroup___11;

struct vm_struct___29;

struct task_struct___31 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___31 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___30 *mm;
	struct mm_struct___30 *active_mm;
	struct vmacache___29 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___31 *real_parent;
	struct task_struct___31 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___31 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___27 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___28 *nsproxy;
	struct signal_struct___29 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___31 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___12 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___11 *backing_dev_info;
	struct io_context___13 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___21 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___19 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___29 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___11 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___11 *active_memcg;
	struct request_queue___5 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___31 *oom_reaper_list;
	struct vm_struct___29 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___19 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___28;

struct kobj_type___28;

struct kernfs_node___28;

struct kobject___28 {
	const char *name;
	struct list_head entry;
	struct kobject___28 *parent;
	struct kset___28 *kset;
	struct kobj_type___28 *ktype;
	struct kernfs_node___28 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___28 {
	struct kobject___28 kobj;
	struct module___30 *mod;
	struct kobject___28 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___28 {
	struct module___30 *mod;
	struct latch_tree_node node;
};

struct module_layout___28 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___28 mtn;
};

struct module_attribute___28;

struct kernel_param___28;

struct trace_event_call___14;

struct module___30 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___28 mkobj;
	struct module_attribute___28 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___28 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___28 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___28 core_layout;
	struct module_layout___28 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___14 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___19 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___31 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___19)(struct perf_event___19 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___19;

struct fasync_struct___28;

struct pid_namespace___27;

struct perf_cgroup___19;

struct perf_event___19 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___19 *group_leader;
	struct pmu___19 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___19 hw;
	struct perf_event_context___19 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___19 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___31 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___28 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___19 *aux_event;
	void (*destroy)(struct perf_event___19 *);
	struct callback_head callback_head;
	struct pid_namespace___27 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___19 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___19 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___14 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___19 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___30 *pgtable_t___29;

struct address_space___28;

struct dev_pagemap___28;

struct page___30 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___28 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___30 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___29 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___30 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___28 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___28;

struct vm_area_struct___29 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___29 *vm_next;
	struct vm_area_struct___29 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___30 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___28 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___30 *vm_file;
	struct file___30 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___5;

struct core_state___29;

struct mm_struct___30 {
	struct {
		struct vm_area_struct___29 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___30 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___5 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___29 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___31 *owner;
		struct user_namespace___2 *user_ns;
		struct file___30 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___28;

struct address_space___28 {
	struct inode___30 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___28 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___28;

struct dev_pagemap___28 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___28 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___28;

struct path___28 {
	struct vfsmount___28 *mnt;
	struct dentry___29 *dentry;
};

struct fown_struct___27 {
	rwlock_t lock;
	struct pid___27 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___30 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___28 f_path;
	struct inode___30 *f_inode;
	const struct file_operations___28 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___27 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___28 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___28;

struct vm_operations_struct___28 {
	void (*open)(struct vm_area_struct___29 *);
	void (*close)(struct vm_area_struct___29 *);
	int (*may_split)(struct vm_area_struct___29 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___29 *);
	int (*mprotect)(struct vm_area_struct___29 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___28 *);
	vm_fault_t (*huge_fault)(struct vm_fault___28 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___28 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___29 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___28 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___28 *);
	int (*access)(struct vm_area_struct___29 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___29 *);
	int (*set_policy)(struct vm_area_struct___29 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___29 *, long unsigned int);
	struct page___30 * (*find_special_page)(struct vm_area_struct___29 *, long unsigned int);
};

struct core_thread___29 {
	struct task_struct___31 *task;
	struct core_thread___29 *next;
};

struct core_state___29 {
	atomic_t nr_threads;
	struct core_thread___29 dumper;
	struct completion startup;
};

struct linux_binprm___6;

struct coredump_params___5;

struct linux_binfmt___5 {
	struct list_head lh;
	struct module___30 *module;
	int (*load_binary)(struct linux_binprm___6 *);
	int (*load_shlib)(struct file___30 *);
	int (*core_dump)(struct coredump_params___5 *);
	long unsigned int min_coredump;
};

struct vm_fault___28 {
	const struct {
		struct vm_area_struct___29 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___30 *cow_page;
	struct page___30 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___29 prealloc_pte;
};

struct pglist_data___12;

struct lruvec___12 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___12 *pgdat;
};

struct zone___12 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___12 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___12 {
	struct zone___12 *zone;
	int zone_idx;
};

struct zonelist___12 {
	struct zoneref___12 _zonerefs[321];
};

struct pglist_data___12 {
	struct zone___12 node_zones[5];
	struct zonelist___12 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___31 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___31 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___12 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct upid___27 {
	int nr;
	struct pid_namespace___27 *ns;
};

struct pid_namespace___27 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___31 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___27 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___27 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___27 numbers[1];
};

typedef long unsigned int old_sigset_t;

struct tty_struct___5;

struct signal_struct___29 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___31 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___31 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___27 *pids[4];
	struct pid___27 *tty_old_pgrp;
	int leader;
	struct tty_struct___5 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___30 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___21;

struct nsproxy___28 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___27 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___21 *cgroup_ns;
};

struct bio___12;

struct bio_list___12 {
	struct bio___12 *head;
	struct bio___12 *tail;
};

struct cgroup_subsys_state___21;

struct bdi_writeback___11 {
	struct backing_dev_info___11 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___21 *memcg_css;
	struct cgroup_subsys_state___21 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___26;

struct backing_dev_info___11 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___11 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___26 *dev;
	char dev_name[64];
	struct device___26 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___29 *debug_dir;
};

struct io_cq___12;

struct io_context___13 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___12 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___21;

struct css_set___21 {
	struct cgroup_subsys_state___21 *subsys[14];
	refcount_t refcount;
	struct css_set___21 *dom_cset;
	struct cgroup___21 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___21 *mg_src_cgrp;
	struct cgroup___21 *mg_dst_cgrp;
	struct css_set___21 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___19 {
	struct pmu___19 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___31 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___19 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___21;

struct cgroup_subsys_state___21 {
	struct cgroup___21 *cgroup;
	struct cgroup_subsys___21 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___21 *parent;
};

struct cgroup_file___21 {
	struct kernfs_node___28 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___11;

struct mem_cgroup_per_node___11;

struct mem_cgroup___11 {
	struct cgroup_subsys_state___21 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___21 events_file;
	struct cgroup_file___21 events_local_file;
	struct cgroup_file___21 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___11 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___31 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___11 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___12;

struct blk_integrity___12 {
	const struct blk_integrity_profile___12 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___12 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___12 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct elevator_queue___12;

struct gendisk___12;

struct request_queue___5 {
	struct request___4 *last_merge;
	struct elevator_queue___12 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___12 *disk;
	struct kobject___28 kobj;
	struct kobject___28 *mq_kobj;
	struct blk_integrity___12 integrity;
	struct device___26 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___12 bio_split;
	struct dentry___29 *debugfs_dir;
	struct dentry___29 *sched_debugfs_dir;
	struct dentry___29 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___29 {
	struct vm_struct___29 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___30 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___21 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___31 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___21;

struct cgroup_rstat_cpu___21;

struct cgroup___21 {
	struct cgroup_subsys_state___21 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___28 *kn;
	struct cgroup_file___21 procs_file;
	struct cgroup_file___21 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___21 *subsys[14];
	struct cgroup_root___21 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___21 *dom_cgrp;
	struct cgroup___21 *old_dom_cgrp;
	struct cgroup_rstat_cpu___21 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___21 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___5;

struct tty_operations___5;

struct tty_ldisc___5;

struct tty_port___5;

struct tty_struct___5 {
	int magic;
	struct kref kref;
	struct device___26 *dev;
	struct tty_driver___5 *driver;
	const struct tty_operations___5 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___5 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___27 *pgrp;
		struct pid___27 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___5 *link;
	struct fasync_struct___28 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___5 *port;
};

struct fd___3 {
	struct file___30 *file;
	unsigned int flags;
};

struct dentry_operations___28;

struct dentry___29 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___29 *d_parent;
	struct qstr d_name;
	struct inode___30 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___28 *d_op;
	struct super_block___29 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___28;

struct cdev___15;

struct inode___30 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___28 *i_op;
	struct super_block___29 *i_sb;
	struct address_space___28 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___11 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___28 *i_fop;
		void (*free_inode)(struct inode___30 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___28 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___15 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___28 {
	int (*d_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___29 *, unsigned int);
	int (*d_hash)(const struct dentry___29 *, struct qstr *);
	int (*d_compare)(const struct dentry___29 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___29 *);
	int (*d_init)(struct dentry___29 *);
	void (*d_release)(struct dentry___29 *);
	void (*d_prune)(struct dentry___29 *);
	void (*d_iput)(struct dentry___29 *, struct inode___30 *);
	char * (*d_dname)(struct dentry___29 *, char *, int);
	struct vfsmount___28 * (*d_automount)(struct path___28 *);
	int (*d_manage)(const struct path___28 *, bool);
	struct dentry___29 * (*d_real)(struct dentry___29 *, const struct inode___30 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___28;

struct mem_dqinfo___28 {
	struct quota_format_type___28 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___28;

struct quota_info___28 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___30 *files[3];
	struct mem_dqinfo___28 info[3];
	const struct quota_format_ops___28 *ops[3];
};

struct rcuwait___28 {
	struct task_struct___31 *task;
};

struct percpu_rw_semaphore___28 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___28 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___28 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___28 rw_sem[3];
};

struct shrink_control___11;

struct shrinker___11 {
	long unsigned int (*count_objects)(struct shrinker___11 *, struct shrink_control___11 *);
	long unsigned int (*scan_objects)(struct shrinker___11 *, struct shrink_control___11 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___28;

struct dquot_operations___28;

struct quotactl_ops___28;

struct block_device___13;

struct super_block___29 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___28 *s_type;
	const struct super_operations___28 *s_op;
	const struct dquot_operations___28 *dq_op;
	const struct quotactl_ops___28 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___29 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___13 *s_bdev;
	struct backing_dev_info___11 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___28 s_dquot;
	struct sb_writers___28 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___28 *s_d_op;
	int cleancache_poolid;
	struct shrinker___11 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___28 {
	struct dentry___29 *mnt_root;
	struct super_block___29 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

typedef u32 compat_old_sigset_t;

struct shrink_control___11 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___11 *memcg;
};

struct io_cq___12 {
	struct request_queue___5 *q;
	struct io_context___13 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___28 {
	struct file___30 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___28 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___13 *ki_waitq;
	};
};

struct iattr___29 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___30 *ia_file;
};

struct dquot___28 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___29 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___28 {
	int qf_fmt_id;
	const struct quota_format_ops___28 *qf_ops;
	struct module___30 *qf_owner;
	struct quota_format_type___28 *qf_next;
};

struct quota_format_ops___28 {
	int (*check_quota_file)(struct super_block___29 *, int);
	int (*read_file_info)(struct super_block___29 *, int);
	int (*write_file_info)(struct super_block___29 *, int);
	int (*free_file_info)(struct super_block___29 *, int);
	int (*read_dqblk)(struct dquot___28 *);
	int (*commit_dqblk)(struct dquot___28 *);
	int (*release_dqblk)(struct dquot___28 *);
	int (*get_next_id)(struct super_block___29 *, struct kqid *);
};

struct dquot_operations___28 {
	int (*write_dquot)(struct dquot___28 *);
	struct dquot___28 * (*alloc_dquot)(struct super_block___29 *, int);
	void (*destroy_dquot)(struct dquot___28 *);
	int (*acquire_dquot)(struct dquot___28 *);
	int (*release_dquot)(struct dquot___28 *);
	int (*mark_dirty)(struct dquot___28 *);
	int (*write_info)(struct super_block___29 *, int);
	qsize_t * (*get_reserved_space)(struct inode___30 *);
	int (*get_projid)(struct inode___30 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___30 *, qsize_t *);
	int (*get_next_id)(struct super_block___29 *, struct kqid *);
};

struct quotactl_ops___28 {
	int (*quota_on)(struct super_block___29 *, int, int, const struct path___28 *);
	int (*quota_off)(struct super_block___29 *, int);
	int (*quota_enable)(struct super_block___29 *, unsigned int);
	int (*quota_disable)(struct super_block___29 *, unsigned int);
	int (*quota_sync)(struct super_block___29 *, int);
	int (*set_info)(struct super_block___29 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___29 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___29 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___29 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___29 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___29 *, unsigned int);
};

struct writeback_control___11;

struct address_space_operations___28 {
	int (*writepage)(struct page___30 *, struct writeback_control___11 *);
	int (*readpage)(struct file___30 *, struct page___30 *);
	int (*writepages)(struct address_space___28 *, struct writeback_control___11 *);
	int (*set_page_dirty)(struct page___30 *);
	int (*readpages)(struct file___30 *, struct address_space___28 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___30 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___30 **, void **);
	int (*write_end)(struct file___30 *, struct address_space___28 *, loff_t, unsigned int, unsigned int, struct page___30 *, void *);
	sector_t (*bmap)(struct address_space___28 *, sector_t);
	void (*invalidatepage)(struct page___30 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___30 *, gfp_t);
	void (*freepage)(struct page___30 *);
	ssize_t (*direct_IO)(struct kiocb___28 *, struct iov_iter___14 *);
	int (*migratepage)(struct address_space___28 *, struct page___30 *, struct page___30 *, enum migrate_mode);
	bool (*isolate_page)(struct page___30 *, isolate_mode_t);
	void (*putback_page)(struct page___30 *);
	int (*launder_page)(struct page___30 *);
	int (*is_partially_uptodate)(struct page___30 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___30 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___28 *, struct page___30 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___30 *, sector_t *);
	void (*swap_deactivate)(struct file___30 *);
};

struct writeback_control___11 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___11 *wb;
	struct inode___30 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___14;

struct iov_iter___14 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___14 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___15 {
	struct kobject___28 kobj;
	struct module___30 *owner;
	const struct file_operations___28 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___28 {
	struct dentry___29 * (*lookup)(struct inode___30 *, struct dentry___29 *, unsigned int);
	const char * (*get_link)(struct dentry___29 *, struct inode___30 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___30 *, int);
	struct posix_acl * (*get_acl)(struct inode___30 *, int, bool);
	int (*readlink)(struct dentry___29 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___30 *, struct dentry___29 *, umode_t, bool);
	int (*link)(struct dentry___29 *, struct inode___30 *, struct dentry___29 *);
	int (*unlink)(struct inode___30 *, struct dentry___29 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___30 *, struct dentry___29 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___30 *, struct dentry___29 *, umode_t);
	int (*rmdir)(struct inode___30 *, struct dentry___29 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___30 *, struct dentry___29 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___30 *, struct dentry___29 *, struct inode___30 *, struct dentry___29 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___29 *, struct iattr___29 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___28 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___29 *, char *, size_t);
	int (*fiemap)(struct inode___30 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___30 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___30 *, struct dentry___29 *, struct file___30 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___30 *, struct dentry___29 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___30 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___29 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___29 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___28 {
	void (*fl_copy_lock)(struct file_lock___28 *, struct file_lock___28 *);
	void (*fl_release_private)(struct file_lock___28 *);
};

struct lock_manager_operations___28;

struct file_lock___28 {
	struct file_lock___28 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___30 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___28 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___28 *fl_ops;
	const struct lock_manager_operations___28 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___28 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___28 *);
	int (*lm_grant)(struct file_lock___28 *, int);
	bool (*lm_break)(struct file_lock___28 *);
	int (*lm_change)(struct file_lock___28 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___28 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___28 *);
};

struct fasync_struct___28 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___28 *fa_next;
	struct file___30 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___28 {
	struct inode___30 * (*alloc_inode)(struct super_block___29 *);
	void (*destroy_inode)(struct inode___30 *);
	void (*free_inode)(struct inode___30 *);
	void (*dirty_inode)(struct inode___30 *, int);
	int (*write_inode)(struct inode___30 *, struct writeback_control___11 *);
	int (*drop_inode)(struct inode___30 *);
	void (*evict_inode)(struct inode___30 *);
	void (*put_super)(struct super_block___29 *);
	int (*sync_fs)(struct super_block___29 *, int);
	int (*freeze_super)(struct super_block___29 *);
	int (*freeze_fs)(struct super_block___29 *);
	int (*thaw_super)(struct super_block___29 *);
	int (*unfreeze_fs)(struct super_block___29 *);
	int (*statfs)(struct dentry___29 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___29 *, int *, char *);
	void (*umount_begin)(struct super_block___29 *);
	int (*show_options)(struct seq_file___6 *, struct dentry___29 *);
	int (*show_devname)(struct seq_file___6 *, struct dentry___29 *);
	int (*show_path)(struct seq_file___6 *, struct dentry___29 *);
	int (*show_stats)(struct seq_file___6 *, struct dentry___29 *);
	ssize_t (*quota_read)(struct super_block___29 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___29 *, int, const char *, size_t, loff_t);
	struct dquot___28 ** (*get_dquots)(struct inode___30 *);
	long int (*nr_cached_objects)(struct super_block___29 *, struct shrink_control___11 *);
	long int (*free_cached_objects)(struct super_block___29 *, struct shrink_control___11 *);
	struct file___30 * (*real_loop)(struct file___30 *);
};

struct wakeup_source___26;

struct dev_pm_info___26 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___26 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___26 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___26;

struct bus_type___26;

struct device_driver___26;

struct dev_pm_domain___26;

struct fwnode_handle___26;

struct class___26;

struct attribute_group___28;

struct device___26 {
	struct kobject___28 kobj;
	struct device___26 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___26 *type;
	struct bus_type___26 *bus;
	struct device_driver___26 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___26 power;
	struct dev_pm_domain___26 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___26 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___26 *class;
	const struct attribute_group___28 **groups;
	void (*release)(struct device___26 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___13 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___30 *bd_inode;
	struct super_block___29 *bd_super;
	void *bd_claiming;
	struct device___26 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___28 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___12 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___29 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___22)(struct file___30 *, wait_queue_head_t *, struct poll_table_struct___22 *);

struct poll_table_struct___22 {
	poll_queue_proc___22 _qproc;
	__poll_t _key;
};

struct seq_operations___27;

struct seq_file___6 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___27 *op;
	int poll_event;
	const struct file___30 *file;
	void *private;
};

typedef void bio_end_io_t___12(struct bio___12 *);

struct bio_vec___14 {
	struct page___30 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___12;

struct bio___12 {
	struct bio___12 *bi_next;
	struct block_device___13 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___12 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___12 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___14 *bi_io_vec;
	struct bio_set___12 *bi_pool;
	struct bio_vec___14 bi_inline_vecs[0];
};

struct kernfs_root___28;

struct kernfs_elem_dir___28 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___28 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___28;

struct kernfs_root___28 {
	struct kernfs_node___28 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___28 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___28 {
	struct kernfs_node___28 *target_kn;
};

struct kernfs_ops___28;

struct kernfs_elem_attr___28 {
	const struct kernfs_ops___28 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___28 *notify_next;
};

struct kernfs_node___28 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___28 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___28 dir;
		struct kernfs_elem_symlink___28 symlink;
		struct kernfs_elem_attr___28 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___28;

struct kernfs_ops___28 {
	int (*open)(struct kernfs_open_file___28 *);
	void (*release)(struct kernfs_open_file___28 *);
	int (*seq_show)(struct seq_file___6 *, void *);
	void * (*seq_start)(struct seq_file___6 *, loff_t *);
	void * (*seq_next)(struct seq_file___6 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___6 *, void *);
	ssize_t (*read)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___28 *, struct poll_table_struct___22 *);
	int (*mmap)(struct kernfs_open_file___28 *, struct vm_area_struct___29 *);
};

struct kernfs_syscall_ops___28 {
	int (*show_options)(struct seq_file___6 *, struct kernfs_root___28 *);
	int (*mkdir)(struct kernfs_node___28 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___28 *);
	int (*rename)(struct kernfs_node___28 *, struct kernfs_node___28 *, const char *);
	int (*show_path)(struct seq_file___6 *, struct kernfs_node___28 *, struct kernfs_root___28 *);
};

struct kernfs_open_file___28 {
	struct kernfs_node___28 *kn;
	struct file___30 *file;
	struct seq_file___6 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___28 *vm_ops;
};

struct bin_attribute___28;

struct attribute_group___28 {
	const char *name;
	umode_t (*is_visible)(struct kobject___28 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___28 *, struct bin_attribute___28 *, int);
	struct attribute **attrs;
	struct bin_attribute___28 **bin_attrs;
};

struct bin_attribute___28 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___28 * (*f_mapping)();
	ssize_t (*read)(struct file___30 *, struct kobject___28 *, struct bin_attribute___28 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___30 *, struct kobject___28 *, struct bin_attribute___28 *, char *, loff_t, size_t);
	int (*mmap)(struct file___30 *, struct kobject___28 *, struct bin_attribute___28 *, struct vm_area_struct___29 *);
};

struct sysfs_ops___28 {
	ssize_t (*show)(struct kobject___28 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___28 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___28;

struct kset___28 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___28 kobj;
	const struct kset_uevent_ops___28 *uevent_ops;
};

struct kobj_type___28 {
	void (*release)(struct kobject___28 *);
	const struct sysfs_ops___28 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___28 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___28 *);
	const void * (*namespace)(struct kobject___28 *);
	void (*get_ownership)(struct kobject___28 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___28 {
	int (* const filter)(struct kset___28 *, struct kobject___28 *);
	const char * (* const name)(struct kset___28 *, struct kobject___28 *);
	int (* const uevent)(struct kset___28 *, struct kobject___28 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___26 {
	int (*prepare)(struct device___26 *);
	void (*complete)(struct device___26 *);
	int (*suspend)(struct device___26 *);
	int (*resume)(struct device___26 *);
	int (*freeze)(struct device___26 *);
	int (*thaw)(struct device___26 *);
	int (*poweroff)(struct device___26 *);
	int (*restore)(struct device___26 *);
	int (*suspend_late)(struct device___26 *);
	int (*resume_early)(struct device___26 *);
	int (*freeze_late)(struct device___26 *);
	int (*thaw_early)(struct device___26 *);
	int (*poweroff_late)(struct device___26 *);
	int (*restore_early)(struct device___26 *);
	int (*suspend_noirq)(struct device___26 *);
	int (*resume_noirq)(struct device___26 *);
	int (*freeze_noirq)(struct device___26 *);
	int (*thaw_noirq)(struct device___26 *);
	int (*poweroff_noirq)(struct device___26 *);
	int (*restore_noirq)(struct device___26 *);
	int (*runtime_suspend)(struct device___26 *);
	int (*runtime_resume)(struct device___26 *);
	int (*runtime_idle)(struct device___26 *);
};

struct wakeup_source___26 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___26 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___26 {
	struct dev_pm_ops___26 ops;
	int (*start)(struct device___26 *);
	void (*detach)(struct device___26 *, bool);
	int (*activate)(struct device___26 *);
	void (*sync)(struct device___26 *);
	void (*dismiss)(struct device___26 *);
};

struct bus_type___26 {
	const char *name;
	const char *dev_name;
	struct device___26 *dev_root;
	const struct attribute_group___28 **bus_groups;
	const struct attribute_group___28 **dev_groups;
	const struct attribute_group___28 **drv_groups;
	int (*match)(struct device___26 *, struct device_driver___26 *);
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	int (*probe)(struct device___26 *);
	void (*sync_state)(struct device___26 *);
	void (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*online)(struct device___26 *);
	int (*offline)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	int (*num_vf)(struct device___26 *);
	int (*dma_configure)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___26 {
	const char *name;
	struct bus_type___26 *bus;
	struct module___30 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___26 *);
	void (*sync_state)(struct device___26 *);
	int (*remove)(struct device___26 *);
	void (*shutdown)(struct device___26 *);
	int (*suspend)(struct device___26 *, pm_message_t);
	int (*resume)(struct device___26 *);
	const struct attribute_group___28 **groups;
	const struct attribute_group___28 **dev_groups;
	const struct dev_pm_ops___26 *pm;
	void (*coredump)(struct device___26 *);
	struct driver_private *p;
};

struct device_type___26 {
	const char *name;
	const struct attribute_group___28 **groups;
	int (*uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___26 *);
	const struct dev_pm_ops___26 *pm;
};

struct class___26 {
	const char *name;
	struct module___30 *owner;
	const struct attribute_group___28 **class_groups;
	const struct attribute_group___28 **dev_groups;
	struct kobject___28 *dev_kobj;
	int (*dev_uevent)(struct device___26 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___26 *, umode_t *);
	void (*class_release)(struct class___26 *);
	void (*dev_release)(struct device___26 *);
	int (*shutdown_pre)(struct device___26 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___26 *);
	void (*get_ownership)(struct device___26 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___26 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___26;

struct fwnode_handle___26 {
	struct fwnode_handle___26 *secondary;
	const struct fwnode_operations___26 *ops;
	struct device___26 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___27 {
	void * (*start)(struct seq_file___6 *, loff_t *);
	void (*stop)(struct seq_file___6 *, void *);
	void * (*next)(struct seq_file___6 *, void *, loff_t *);
	int (*show)(struct seq_file___6 *, void *);
};

struct tty_operations___5 {
	struct tty_struct___5 * (*lookup)(struct tty_driver___5 *, struct file___30 *, int);
	int (*install)(struct tty_driver___5 *, struct tty_struct___5 *);
	void (*remove)(struct tty_driver___5 *, struct tty_struct___5 *);
	int (*open)(struct tty_struct___5 *, struct file___30 *);
	void (*close)(struct tty_struct___5 *, struct file___30 *);
	void (*shutdown)(struct tty_struct___5 *);
	void (*cleanup)(struct tty_struct___5 *);
	int (*write)(struct tty_struct___5 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___5 *, unsigned char);
	void (*flush_chars)(struct tty_struct___5 *);
	unsigned int (*write_room)(struct tty_struct___5 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___5 *);
	int (*ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___5 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	void (*throttle)(struct tty_struct___5 *);
	void (*unthrottle)(struct tty_struct___5 *);
	void (*stop)(struct tty_struct___5 *);
	void (*start)(struct tty_struct___5 *);
	void (*hangup)(struct tty_struct___5 *);
	int (*break_ctl)(struct tty_struct___5 *, int);
	void (*flush_buffer)(struct tty_struct___5 *);
	void (*set_ldisc)(struct tty_struct___5 *);
	void (*wait_until_sent)(struct tty_struct___5 *, int);
	void (*send_xchar)(struct tty_struct___5 *, char);
	int (*tiocmget)(struct tty_struct___5 *);
	int (*tiocmset)(struct tty_struct___5 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___5 *, struct winsize *);
	int (*get_icount)(struct tty_struct___5 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___5 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___5 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___5 *, struct seq_file___6 *);
	int (*poll_init)(struct tty_driver___5 *, int, char *);
	int (*poll_get_char)(struct tty_driver___5 *, int);
	void (*poll_put_char)(struct tty_driver___5 *, int, char);
	int (*proc_show)(struct seq_file___6 *, void *);
};

struct tty_driver___5 {
	int magic;
	struct kref kref;
	struct cdev___15 **cdevs;
	struct module___30 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___5 *other;
	struct tty_struct___5 **ttys;
	struct tty_port___5 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___5 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___5;

struct tty_port_client_operations___5;

struct tty_port___5 {
	struct tty_bufhead buf;
	struct tty_struct___5 *tty;
	struct tty_struct___5 *itty;
	const struct tty_port_operations___5 *ops;
	const struct tty_port_client_operations___5 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___5 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___5 *);
	void (*close)(struct tty_struct___5 *);
	void (*flush_buffer)(struct tty_struct___5 *);
	ssize_t (*read)(struct tty_struct___5 *, struct file___30 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___5 *, struct file___30 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___5 *, struct file___30 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___5 *, struct file___30 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___5 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___5 *, struct file___30 *, struct poll_table_struct___22 *);
	int (*hangup)(struct tty_struct___5 *);
	void (*receive_buf)(struct tty_struct___5 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___5 *);
	void (*dcd_change)(struct tty_struct___5 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___5 *, const unsigned char *, const char *, int);
	struct module___30 *owner;
};

struct tty_ldisc___5 {
	struct tty_ldisc_ops___5 *ops;
	struct tty_struct___5 *tty;
};

struct tty_port_operations___5 {
	int (*carrier_raised)(struct tty_port___5 *);
	void (*dtr_rts)(struct tty_port___5 *, int);
	void (*shutdown)(struct tty_port___5 *);
	int (*activate)(struct tty_port___5 *, struct tty_struct___5 *);
	void (*destruct)(struct tty_port___5 *);
};

struct tty_port_client_operations___5 {
	int (*receive_buf)(struct tty_port___5 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___5 *);
};

struct linux_binprm___6 {
	struct vm_area_struct___29 *vma;
	long unsigned int vma_pages;
	struct mm_struct___30 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___30 *executable;
	struct file___30 *interpreter;
	struct file___30 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct core_vma_metadata___2;

struct coredump_params___5 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___30 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata___2 *vma_meta;
};

struct core_vma_metadata___2 {
	long unsigned int start;
	long unsigned int end;
	long unsigned int flags;
	long unsigned int dump_size;
	long unsigned int pgoff;
	struct file___30 *file;
};

struct dev_pagemap_ops___28 {
	void (*page_free)(struct page___30 *);
	void (*kill)(struct dev_pagemap___28 *);
	void (*cleanup)(struct dev_pagemap___28 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___28 *);
};

struct fwnode_reference_args___26;

struct fwnode_endpoint___26;

struct fwnode_operations___26 {
	struct fwnode_handle___26 * (*get)(struct fwnode_handle___26 *);
	void (*put)(struct fwnode_handle___26 *);
	bool (*device_is_available)(const struct fwnode_handle___26 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___26 *, const struct device___26 *);
	bool (*property_present)(const struct fwnode_handle___26 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___26 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___26 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___26 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_parent)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_next_child_node)(const struct fwnode_handle___26 *, struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*get_named_child_node)(const struct fwnode_handle___26 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___26 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___26 *);
	struct fwnode_handle___26 * (*graph_get_next_endpoint)(const struct fwnode_handle___26 *, struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*graph_get_remote_endpoint)(const struct fwnode_handle___26 *);
	struct fwnode_handle___26 * (*graph_get_port_parent)(struct fwnode_handle___26 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___26 *, struct fwnode_endpoint___26 *);
	int (*add_links)(struct fwnode_handle___26 *);
};

struct fwnode_endpoint___26 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___26 *local_fwnode;
};

struct fwnode_reference_args___26 {
	struct fwnode_handle___26 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___21 {
	struct ns_common___3 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___21 *root_cset;
};

struct kernel_param_ops___28 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___28 *);
	int (*get)(char *, const struct kernel_param___28 *);
	void (*free)(void *);
};

struct kparam_array___28;

struct kernel_param___28 {
	const char *name;
	struct module___30 *mod;
	const struct kernel_param_ops___28 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___28 *arr;
	};
};

struct kparam_array___28 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___28 *ops;
	void *elem;
};

struct module_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___28 *, struct module_kobject___28 *, char *);
	ssize_t (*store)(struct module_attribute___28 *, struct module_kobject___28 *, const char *, size_t);
	void (*setup)(struct module___30 *, const char *);
	int (*test)(struct module___30 *);
	void (*free)(struct module___30 *);
};

struct trace_event_class___14;

struct trace_event_call___14 {
	struct list_head list;
	struct trace_event_class___14 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___14 *, struct perf_event___19 *);
};

struct compat_sigaction {
	compat_uptr_t sa_handler;
	compat_ulong_t sa_flags;
	compat_uptr_t sa_restorer;
	compat_sigset_t sa_mask;
};

struct compat_old_sigaction {
	compat_uptr_t sa_handler;
	compat_old_sigset_t sa_mask;
	compat_ulong_t sa_flags;
	compat_uptr_t sa_restorer;
};

struct cftype___21;

struct cgroup_subsys___21 {
	struct cgroup_subsys_state___21 * (*css_alloc)(struct cgroup_subsys_state___21 *);
	int (*css_online)(struct cgroup_subsys_state___21 *);
	void (*css_offline)(struct cgroup_subsys_state___21 *);
	void (*css_released)(struct cgroup_subsys_state___21 *);
	void (*css_free)(struct cgroup_subsys_state___21 *);
	void (*css_reset)(struct cgroup_subsys_state___21 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___21 *, int);
	int (*css_extra_stat_show)(struct seq_file___6 *, struct cgroup_subsys_state___21 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___31 *, struct css_set___21 *);
	void (*cancel_fork)(struct task_struct___31 *, struct css_set___21 *);
	void (*fork)(struct task_struct___31 *);
	void (*exit)(struct task_struct___31 *);
	void (*release)(struct task_struct___31 *);
	void (*bind)(struct cgroup_subsys_state___21 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___21 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___21 *dfl_cftypes;
	struct cftype___21 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___21 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___21 *updated_children;
	struct cgroup___21 *updated_next;
};

struct cgroup_root___21 {
	struct kernfs_root___28 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___21 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___21 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___21 *ss;
	struct list_head node;
	struct kernfs_ops___28 *kf_ops;
	int (*open)(struct kernfs_open_file___28 *);
	void (*release)(struct kernfs_open_file___28 *);
	u64 (*read_u64)(struct cgroup_subsys_state___21 *, struct cftype___21 *);
	s64 (*read_s64)(struct cgroup_subsys_state___21 *, struct cftype___21 *);
	int (*seq_show)(struct seq_file___6 *, void *);
	void * (*seq_start)(struct seq_file___6 *, loff_t *);
	void * (*seq_next)(struct seq_file___6 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___6 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___21 *, struct cftype___21 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___21 *, struct cftype___21 *, s64);
	ssize_t (*write)(struct kernfs_open_file___28 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___28 *, struct poll_table_struct___22 *);
};

struct perf_cpu_context___19;

struct perf_output_handle___19;

struct pmu___19 {
	struct list_head entry;
	struct module___30 *module;
	struct device___26 *dev;
	const struct attribute_group___28 **attr_groups;
	const struct attribute_group___28 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___19 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___19 *);
	void (*pmu_disable)(struct pmu___19 *);
	int (*event_init)(struct perf_event___19 *);
	void (*event_mapped)(struct perf_event___19 *, struct mm_struct___30 *);
	void (*event_unmapped)(struct perf_event___19 *, struct mm_struct___30 *);
	int (*add)(struct perf_event___19 *, int);
	void (*del)(struct perf_event___19 *, int);
	void (*start)(struct perf_event___19 *, int);
	void (*stop)(struct perf_event___19 *, int);
	void (*read)(struct perf_event___19 *);
	void (*start_txn)(struct pmu___19 *, unsigned int);
	int (*commit_txn)(struct pmu___19 *);
	void (*cancel_txn)(struct pmu___19 *);
	int (*event_idx)(struct perf_event___19 *);
	void (*sched_task)(struct perf_event_context___19 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___19 *, struct perf_event_context___19 *);
	void * (*setup_aux)(struct perf_event___19 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___19 *, struct perf_output_handle___19 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___19 *);
	int (*aux_output_match)(struct perf_event___19 *);
	int (*filter_match)(struct perf_event___19 *);
	int (*check_period)(struct perf_event___19 *, u64);
};

struct perf_cpu_context___19 {
	struct perf_event_context___19 ctx;
	struct perf_event_context___19 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___19 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___19 **heap;
	struct perf_event___19 *heap_default[2];
};

struct perf_output_handle___19 {
	struct perf_event___19 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___19 {
	struct cgroup_subsys_state___21 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___14 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___14 *);
	};
};

struct trace_event_class___14 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___14 *, enum trace_reg, void *);
	struct trace_event_fields___14 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___14 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___14 *);
};

struct trace_event_file___7;

struct trace_event_buffer___7 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___7 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___7 {
	struct list_head list;
	struct trace_event_call___14 *event_call;
	struct event_filter *filter;
	struct dentry___29 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___5 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___14 *enter_event;
	struct trace_event_call___14 *exit_event;
};

struct block_device_operations___12;

struct gendisk___12 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___13 *part0;
	const struct block_device_operations___12 *fops;
	struct request_queue___5 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___11 *bdi;
	struct kobject___28 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___28 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___12 {
	struct bio___12 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___14 *bip_vec;
	struct bio_vec___14 bip_inline_vecs[0];
};

struct blkcg___11;

struct blkg_policy_data___11;

struct blkcg_gq___3 {
	struct request_queue___5 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___11 *blkcg;
	struct blkcg_gq___3 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___11 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___12 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___12(struct request___4 *);

typedef void integrity_complete_fn___12(struct request___4 *, unsigned int);

struct blk_integrity_profile___12 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___12 *prepare_fn;
	integrity_complete_fn___12 *complete_fn;
	const char *name;
};

struct block_device_operations___12 {
	blk_qc_t (*submit_bio)(struct bio___12 *);
	int (*open)(struct block_device___13 *, fmode_t);
	void (*release)(struct gendisk___12 *, fmode_t);
	int (*rw_page)(struct block_device___13 *, sector_t, struct page___30 *, unsigned int);
	int (*ioctl)(struct block_device___13 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___13 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___12 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___12 *);
	int (*getgeo)(struct block_device___13 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___13 *, bool);
	void (*swap_slot_free_notify)(struct block_device___13 *, long unsigned int);
	int (*report_zones)(struct gendisk___12 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___12 *, umode_t *);
	struct module___30 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___12 *, sector_t *);
};

typedef void rq_end_io_fn___12(struct request___4 *, blk_status_t);

struct request___4 {
	struct request_queue___5 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___12 *bio;
	struct bio___12 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___14 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___12 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___12 *saved_end_io;
		} flush;
	};
	struct gendisk___12 *rq_disk;
	struct block_device___13 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___12 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___3 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___5 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___28 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___29 *debugfs_dir;
	struct dentry___29 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___12;

struct elevator_mq_ops___12 {
	int (*init_sched)(struct request_queue___5 *, struct elevator_type___12 *);
	void (*exit_sched)(struct elevator_queue___12 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
	bool (*allow_merge)(struct request_queue___5 *, struct request___4 *, struct bio___12 *);
	bool (*bio_merge)(struct request_queue___5 *, struct bio___12 *, unsigned int);
	int (*request_merge)(struct request_queue___5 *, struct request___4 **, struct bio___12 *);
	void (*request_merged)(struct request_queue___5 *, struct request___4 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___5 *, struct request___4 *, struct request___4 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___4 *);
	void (*finish_request)(struct request___4 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___4 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___4 *, u64);
	void (*requeue_request)(struct request___4 *);
	struct request___4 * (*former_request)(struct request_queue___5 *, struct request___4 *);
	struct request___4 * (*next_request)(struct request_queue___5 *, struct request___4 *);
	void (*init_icq)(struct io_cq___12 *);
	void (*exit_icq)(struct io_cq___12 *);
};

struct elv_fs_entry___12;

struct elevator_type___12 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___12 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___12 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___30 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___12 {
	struct elevator_type___12 *type;
	void *elevator_data;
	struct kobject___28 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___12 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___12 *, char *);
	ssize_t (*store)(struct elevator_queue___12 *, const char *, size_t);
};

struct blk_mq_tag_set___3 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___3 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___3 {
	struct request___4 *rq;
	bool last;
};

struct blkcg_policy_data___11;

struct blkcg___11 {
	struct cgroup_subsys_state___21 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___3 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___11 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___11 {
	struct blkcg___11 *blkcg;
	int plid;
};

struct blkg_policy_data___11 {
	struct blkcg_gq___3 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___11 {
	struct mem_cgroup___11 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___11 {
	struct lruvec___12 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___11 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___11 *memcg;
};

struct obj_cgroup___11 {
	struct percpu_ref refcnt;
	struct mem_cgroup___11 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum {
	TRACE_SIGNAL_DELIVERED = 0,
	TRACE_SIGNAL_IGNORED = 1,
	TRACE_SIGNAL_ALREADY_PENDING = 2,
	TRACE_SIGNAL_OVERFLOW_FAIL = 3,
	TRACE_SIGNAL_LOSE_INFO = 4,
};

struct trace_event_raw_signal_generate {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	char comm[16];
	pid_t pid;
	int group;
	int result;
	char __data[0];
};

struct trace_event_raw_signal_deliver {
	struct trace_entry ent;
	int sig;
	int errno;
	int code;
	long unsigned int sa_handler;
	long unsigned int sa_flags;
	char __data[0];
};

struct trace_event_data_offsets_signal_generate {};

struct trace_event_data_offsets_signal_deliver {};

typedef void (*btf_trace_signal_generate)(void *, int, struct kernel_siginfo *, struct task_struct___31 *, int, int);

typedef void (*btf_trace_signal_deliver)(void *, int, struct kernel_siginfo *, struct k_sigaction *);

enum sig_handler {
	HANDLER_CURRENT = 0,
	HANDLER_SIG_DFL = 1,
	HANDLER_EXIT = 2,
};

struct dentry___30;

struct super_block___30;

struct module___31;

struct file_system_type___29 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___30 * (*mount)(struct file_system_type___29 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___30 *);
	struct module___31 *owner;
	struct file_system_type___29 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct sysinfo {
	__kernel_long_t uptime;
	__kernel_ulong_t loads[3];
	__kernel_ulong_t totalram;
	__kernel_ulong_t freeram;
	__kernel_ulong_t sharedram;
	__kernel_ulong_t bufferram;
	__kernel_ulong_t totalswap;
	__kernel_ulong_t freeswap;
	__u16 procs;
	__u16 pad;
	__kernel_ulong_t totalhigh;
	__kernel_ulong_t freehigh;
	__u32 mem_unit;
	char _f[0];
};

struct file___31;

struct kiocb___29;

struct iov_iter___15;

struct poll_table_struct___23;

struct vm_area_struct___30;

struct inode___31;

struct file_lock___29;

struct page___31;

struct seq_file___29;

struct file_operations___29 {
	struct module___31 *owner;
	loff_t (*llseek)(struct file___31 *, loff_t, int);
	ssize_t (*read)(struct file___31 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___31 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___29 *, struct iov_iter___15 *);
	ssize_t (*write_iter)(struct kiocb___29 *, struct iov_iter___15 *);
	int (*iopoll)(struct kiocb___29 *, bool);
	int (*iterate)(struct file___31 *, struct dir_context *);
	int (*iterate_shared)(struct file___31 *, struct dir_context *);
	__poll_t (*poll)(struct file___31 *, struct poll_table_struct___23 *);
	long int (*unlocked_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___31 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___31 *, struct vm_area_struct___30 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___31 *, struct file___31 *);
	int (*flush)(struct file___31 *, fl_owner_t);
	int (*release)(struct inode___31 *, struct file___31 *);
	int (*fsync)(struct file___31 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___31 *, int);
	int (*lock)(struct file___31 *, int, struct file_lock___29 *);
	ssize_t (*sendpage)(struct file___31 *, struct page___31 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___31 *, long unsigned int);
	int (*flock)(struct file___31 *, int, struct file_lock___29 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___31 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___31 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___31 *, long int, struct file_lock___29 **, void **);
	long int (*fallocate)(struct file___31 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___29 *, struct file___31 *);
	ssize_t (*copy_file_range)(struct file___31 *, loff_t, struct file___31 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___31 *, loff_t, struct file___31 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___31 *, loff_t, loff_t, int);
};

struct vmacache___30 {
	u64 seqnum;
	struct vm_area_struct___30 *vmas[4];
};

struct page_frag___30 {
	struct page___31 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___20;

struct debug_info___20 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___20 *hbp_break[16];
	struct perf_event___20 *hbp_watch[16];
};

struct thread_struct___20 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___20 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___31;

struct pid___28;

struct fs_struct___4;

struct nsproxy___29;

struct signal_struct___30;

struct bio_list___13;

struct backing_dev_info___12;

struct io_context___14;

struct css_set___22;

struct perf_event_context___20;

struct mem_cgroup___12;

struct request_queue___14;

struct vm_struct___30;

struct task_struct___32 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___32 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___31 *mm;
	struct mm_struct___31 *active_mm;
	struct vmacache___30 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___32 *real_parent;
	struct task_struct___32 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___32 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___28 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___4 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___29 *nsproxy;
	struct signal_struct___30 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___32 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___13 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___12 *backing_dev_info;
	struct io_context___14 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___22 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___20 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___30 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___12 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___12 *active_memcg;
	struct request_queue___14 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___32 *oom_reaper_list;
	struct vm_struct___30 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___20 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct prctl_mm_map {
	__u64 start_code;
	__u64 end_code;
	__u64 start_data;
	__u64 end_data;
	__u64 start_brk;
	__u64 brk;
	__u64 start_stack;
	__u64 arg_start;
	__u64 arg_end;
	__u64 env_start;
	__u64 env_end;
	__u64 *auxv;
	__u32 auxv_size;
	__u32 exe_fd;
};

struct kset___29;

struct kobj_type___29;

struct kernfs_node___29;

struct kobject___29 {
	const char *name;
	struct list_head entry;
	struct kobject___29 *parent;
	struct kset___29 *kset;
	struct kobj_type___29 *ktype;
	struct kernfs_node___29 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___29 {
	struct kobject___29 kobj;
	struct module___31 *mod;
	struct kobject___29 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___29 {
	struct module___31 *mod;
	struct latch_tree_node node;
};

struct module_layout___29 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___29 mtn;
};

struct module_attribute___29;

struct kernel_param___29;

struct trace_event_call___15;

struct module___31 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___29 mkobj;
	struct module_attribute___29 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___29 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___29 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___29 core_layout;
	struct module_layout___29 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___15 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___20 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___32 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___20)(struct perf_event___20 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___20;

struct fasync_struct___29;

struct pid_namespace___28;

struct perf_cgroup___20;

struct perf_event___20 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___20 *group_leader;
	struct pmu___20 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___20 hw;
	struct perf_event_context___20 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___20 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___32 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___29 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___20 *aux_event;
	void (*destroy)(struct perf_event___20 *);
	struct callback_head callback_head;
	struct pid_namespace___28 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___20 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___20 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___15 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___20 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___31 *pgtable_t___30;

struct address_space___29;

struct dev_pagemap___29;

struct page___31 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___29 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___31 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___30 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___31 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___29 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___29;

struct vm_area_struct___30 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___30 *vm_next;
	struct vm_area_struct___30 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___31 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___29 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___31 *vm_file;
	struct file___31 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___6;

struct core_state___30;

struct mm_struct___31 {
	struct {
		struct vm_area_struct___30 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___31 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___6 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___30 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___32 *owner;
		struct user_namespace___2 *user_ns;
		struct file___31 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___29;

struct address_space___29 {
	struct inode___31 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___29 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___29;

struct dev_pagemap___29 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___29 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___29;

struct path___29 {
	struct vfsmount___29 *mnt;
	struct dentry___30 *dentry;
};

struct fown_struct___28 {
	rwlock_t lock;
	struct pid___28 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___31 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___29 f_path;
	struct inode___31 *f_inode;
	const struct file_operations___29 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___28 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___29 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___29;

struct vm_operations_struct___29 {
	void (*open)(struct vm_area_struct___30 *);
	void (*close)(struct vm_area_struct___30 *);
	int (*may_split)(struct vm_area_struct___30 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___30 *);
	int (*mprotect)(struct vm_area_struct___30 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___29 *);
	vm_fault_t (*huge_fault)(struct vm_fault___29 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___29 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___30 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___29 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___29 *);
	int (*access)(struct vm_area_struct___30 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___30 *);
	int (*set_policy)(struct vm_area_struct___30 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___30 *, long unsigned int);
	struct page___31 * (*find_special_page)(struct vm_area_struct___30 *, long unsigned int);
};

struct core_thread___30 {
	struct task_struct___32 *task;
	struct core_thread___30 *next;
};

struct core_state___30 {
	atomic_t nr_threads;
	struct core_thread___30 dumper;
	struct completion startup;
};

struct linux_binprm___7;

struct coredump_params___6;

struct linux_binfmt___6 {
	struct list_head lh;
	struct module___31 *module;
	int (*load_binary)(struct linux_binprm___7 *);
	int (*load_shlib)(struct file___31 *);
	int (*core_dump)(struct coredump_params___6 *);
	long unsigned int min_coredump;
};

struct vm_fault___29 {
	const struct {
		struct vm_area_struct___30 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___31 *cow_page;
	struct page___31 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___30 prealloc_pte;
};

struct pglist_data___13;

struct lruvec___13 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___13 *pgdat;
};

struct zone___13 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___13 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___13 {
	struct zone___13 *zone;
	int zone_idx;
};

struct zonelist___13 {
	struct zoneref___13 _zonerefs[321];
};

struct pglist_data___13 {
	struct zone___13 node_zones[5];
	struct zonelist___13 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___32 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___32 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___13 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___12 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___12 *memcg;
};

struct cgroup___22;

struct cgroup_subsys___22;

struct cgroup_subsys_state___22 {
	struct cgroup___22 *cgroup;
	struct cgroup_subsys___22 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___22 *parent;
};

struct cgroup_file___22 {
	struct kernfs_node___29 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___12;

struct mem_cgroup_per_node___12;

struct mem_cgroup___12 {
	struct cgroup_subsys_state___22 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___22 events_file;
	struct cgroup_file___22 events_local_file;
	struct cgroup_file___22 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___12 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___32 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___12 *nodeinfo[0];
	long: 64;
};

struct shrinker___12 {
	long unsigned int (*count_objects)(struct shrinker___12 *, struct shrink_control___12 *);
	long unsigned int (*scan_objects)(struct shrinker___12 *, struct shrink_control___12 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct rlimit64 {
	__u64 rlim_cur;
	__u64 rlim_max;
};

struct dev_pagemap_ops___29 {
	void (*page_free)(struct page___31 *);
	void (*kill)(struct dev_pagemap___29 *);
	void (*cleanup)(struct dev_pagemap___29 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___29 *);
};

struct upid___28 {
	int nr;
	struct pid_namespace___28 *ns;
};

struct pid_namespace___28 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___32 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___28 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___28 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___28 numbers[1];
};

struct tty_struct___6;

struct signal_struct___30 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___32 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___32 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___28 *pids[4];
	struct pid___28 *tty_old_pgrp;
	int leader;
	struct tty_struct___6 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___31 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___4 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___29 root;
	struct path___29 pwd;
};

struct time_namespace___2;

struct cgroup_namespace___22;

struct nsproxy___29 {
	atomic_t count;
	struct uts_namespace *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___28 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace___2 *time_ns;
	struct time_namespace___2 *time_ns_for_children;
	struct cgroup_namespace___22 *cgroup_ns;
};

struct bio___13;

struct bio_list___13 {
	struct bio___13 *head;
	struct bio___13 *tail;
};

struct bdi_writeback___12 {
	struct backing_dev_info___12 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___22 *memcg_css;
	struct cgroup_subsys_state___22 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___27;

struct backing_dev_info___12 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___12 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___27 *dev;
	char dev_name[64];
	struct device___27 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___30 *debug_dir;
};

struct io_cq___13;

struct io_context___14 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___13 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___22 {
	struct cgroup_subsys_state___22 *subsys[14];
	refcount_t refcount;
	struct css_set___22 *dom_cset;
	struct cgroup___22 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___22 *mg_src_cgrp;
	struct cgroup___22 *mg_dst_cgrp;
	struct css_set___22 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___20 {
	struct pmu___20 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___32 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___20 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___13;

struct blk_integrity___13 {
	const struct blk_integrity_profile___13 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___13 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___13 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___13;

struct elevator_queue___13;

struct blk_mq_ops___12;

struct blk_mq_hw_ctx___12;

struct gendisk___13;

struct blkcg_gq___12;

struct blk_mq_tag_set___12;

struct request_queue___14 {
	struct request___13 *last_merge;
	struct elevator_queue___13 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___12 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___12 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___13 *disk;
	struct kobject___29 kobj;
	struct kobject___29 *mq_kobj;
	struct blk_integrity___13 integrity;
	struct device___27 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___12 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___12 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___13 bio_split;
	struct dentry___30 *debugfs_dir;
	struct dentry___30 *sched_debugfs_dir;
	struct dentry___30 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___30 {
	struct vm_struct___30 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___31 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___29;

struct dentry___30 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___30 *d_parent;
	struct qstr d_name;
	struct inode___31 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___29 *d_op;
	struct super_block___30 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___29;

struct cdev___16;

struct inode___31 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___29 *i_op;
	struct super_block___30 *i_sb;
	struct address_space___29 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___12 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___29 *i_fop;
		void (*free_inode)(struct inode___31 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___29 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___16 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___29 {
	int (*d_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___30 *, unsigned int);
	int (*d_hash)(const struct dentry___30 *, struct qstr *);
	int (*d_compare)(const struct dentry___30 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___30 *);
	int (*d_init)(struct dentry___30 *);
	void (*d_release)(struct dentry___30 *);
	void (*d_prune)(struct dentry___30 *);
	void (*d_iput)(struct dentry___30 *, struct inode___31 *);
	char * (*d_dname)(struct dentry___30 *, char *, int);
	struct vfsmount___29 * (*d_automount)(struct path___29 *);
	int (*d_manage)(const struct path___29 *, bool);
	struct dentry___30 * (*d_real)(struct dentry___30 *, const struct inode___31 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___29;

struct mem_dqinfo___29 {
	struct quota_format_type___29 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___29;

struct quota_info___29 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___31 *files[3];
	struct mem_dqinfo___29 info[3];
	const struct quota_format_ops___29 *ops[3];
};

struct rcuwait___29 {
	struct task_struct___32 *task;
};

struct percpu_rw_semaphore___29 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___29 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___29 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___29 rw_sem[3];
};

struct super_operations___29;

struct dquot_operations___29;

struct quotactl_ops___29;

struct block_device___14;

struct super_block___30 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___29 *s_type;
	const struct super_operations___29 *s_op;
	const struct dquot_operations___29 *dq_op;
	const struct quotactl_ops___29 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___30 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___14 *s_bdev;
	struct backing_dev_info___12 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___29 s_dquot;
	struct sb_writers___29 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___29 *s_d_op;
	int cleancache_poolid;
	struct shrinker___12 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___29 {
	struct dentry___30 *mnt_root;
	struct super_block___30 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct psi_group___22 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___32 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___22;

struct cgroup_rstat_cpu___22;

struct cgroup___22 {
	struct cgroup_subsys_state___22 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___29 *kn;
	struct cgroup_file___22 procs_file;
	struct cgroup_file___22 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___22 *subsys[14];
	struct cgroup_root___22 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___22 *dom_cgrp;
	struct cgroup___22 *old_dom_cgrp;
	struct cgroup_rstat_cpu___22 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___22 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___6;

struct tty_operations___6;

struct tty_ldisc___6;

struct tty_port___6;

struct tty_struct___6 {
	int magic;
	struct kref kref;
	struct device___27 *dev;
	struct tty_driver___6 *driver;
	const struct tty_operations___6 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___6 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___28 *pgrp;
		struct pid___28 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___6 *link;
	struct fasync_struct___29 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___6 *port;
};

typedef int (*proc_visitor___2)(struct task_struct___32 *, void *);

struct io_cq___13 {
	struct request_queue___14 *q;
	struct io_context___14 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___14;

struct kiocb___29 {
	struct file___31 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___29 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___14 *ki_waitq;
	};
};

struct iattr___30 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___31 *ia_file;
};

struct dquot___29 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___30 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___29 {
	int qf_fmt_id;
	const struct quota_format_ops___29 *qf_ops;
	struct module___31 *qf_owner;
	struct quota_format_type___29 *qf_next;
};

struct quota_format_ops___29 {
	int (*check_quota_file)(struct super_block___30 *, int);
	int (*read_file_info)(struct super_block___30 *, int);
	int (*write_file_info)(struct super_block___30 *, int);
	int (*free_file_info)(struct super_block___30 *, int);
	int (*read_dqblk)(struct dquot___29 *);
	int (*commit_dqblk)(struct dquot___29 *);
	int (*release_dqblk)(struct dquot___29 *);
	int (*get_next_id)(struct super_block___30 *, struct kqid *);
};

struct dquot_operations___29 {
	int (*write_dquot)(struct dquot___29 *);
	struct dquot___29 * (*alloc_dquot)(struct super_block___30 *, int);
	void (*destroy_dquot)(struct dquot___29 *);
	int (*acquire_dquot)(struct dquot___29 *);
	int (*release_dquot)(struct dquot___29 *);
	int (*mark_dirty)(struct dquot___29 *);
	int (*write_info)(struct super_block___30 *, int);
	qsize_t * (*get_reserved_space)(struct inode___31 *);
	int (*get_projid)(struct inode___31 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___31 *, qsize_t *);
	int (*get_next_id)(struct super_block___30 *, struct kqid *);
};

struct quotactl_ops___29 {
	int (*quota_on)(struct super_block___30 *, int, int, const struct path___29 *);
	int (*quota_off)(struct super_block___30 *, int);
	int (*quota_enable)(struct super_block___30 *, unsigned int);
	int (*quota_disable)(struct super_block___30 *, unsigned int);
	int (*quota_sync)(struct super_block___30 *, int);
	int (*set_info)(struct super_block___30 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___30 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___30 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___30 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___30 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___30 *, unsigned int);
};

struct wait_page_queue___14 {
	struct page___31 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___12;

struct readahead_control___14;

struct swap_info_struct___9;

struct address_space_operations___29 {
	int (*writepage)(struct page___31 *, struct writeback_control___12 *);
	int (*readpage)(struct file___31 *, struct page___31 *);
	int (*writepages)(struct address_space___29 *, struct writeback_control___12 *);
	int (*set_page_dirty)(struct page___31 *);
	int (*readpages)(struct file___31 *, struct address_space___29 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___14 *);
	int (*write_begin)(struct file___31 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___31 **, void **);
	int (*write_end)(struct file___31 *, struct address_space___29 *, loff_t, unsigned int, unsigned int, struct page___31 *, void *);
	sector_t (*bmap)(struct address_space___29 *, sector_t);
	void (*invalidatepage)(struct page___31 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___31 *, gfp_t);
	void (*freepage)(struct page___31 *);
	ssize_t (*direct_IO)(struct kiocb___29 *, struct iov_iter___15 *);
	int (*migratepage)(struct address_space___29 *, struct page___31 *, struct page___31 *, enum migrate_mode);
	bool (*isolate_page)(struct page___31 *, isolate_mode_t);
	void (*putback_page)(struct page___31 *);
	int (*launder_page)(struct page___31 *);
	int (*is_partially_uptodate)(struct page___31 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___31 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___29 *, struct page___31 *);
	int (*swap_activate)(struct swap_info_struct___9 *, struct file___31 *, sector_t *);
	void (*swap_deactivate)(struct file___31 *);
};

struct writeback_control___12 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___12 *wb;
	struct inode___31 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___14 {
	struct file___31 *file;
	struct address_space___29 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___15;

struct iov_iter___15 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___15 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___9 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___14 *bdev;
	struct file___31 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___16 {
	struct kobject___29 kobj;
	struct module___31 *owner;
	const struct file_operations___29 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___29 {
	struct dentry___30 * (*lookup)(struct inode___31 *, struct dentry___30 *, unsigned int);
	const char * (*get_link)(struct dentry___30 *, struct inode___31 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___31 *, int);
	struct posix_acl * (*get_acl)(struct inode___31 *, int, bool);
	int (*readlink)(struct dentry___30 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___31 *, struct dentry___30 *, umode_t, bool);
	int (*link)(struct dentry___30 *, struct inode___31 *, struct dentry___30 *);
	int (*unlink)(struct inode___31 *, struct dentry___30 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___31 *, struct dentry___30 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___31 *, struct dentry___30 *, umode_t);
	int (*rmdir)(struct inode___31 *, struct dentry___30 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___31 *, struct dentry___30 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___31 *, struct dentry___30 *, struct inode___31 *, struct dentry___30 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___30 *, struct iattr___30 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___29 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___30 *, char *, size_t);
	int (*fiemap)(struct inode___31 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___31 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___31 *, struct dentry___30 *, struct file___31 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___31 *, struct dentry___30 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___31 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___30 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___30 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___29 {
	void (*fl_copy_lock)(struct file_lock___29 *, struct file_lock___29 *);
	void (*fl_release_private)(struct file_lock___29 *);
};

struct lock_manager_operations___29;

struct file_lock___29 {
	struct file_lock___29 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___31 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___29 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___29 *fl_ops;
	const struct lock_manager_operations___29 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___29 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___29 *);
	int (*lm_grant)(struct file_lock___29 *, int);
	bool (*lm_break)(struct file_lock___29 *);
	int (*lm_change)(struct file_lock___29 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___29 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___29 *);
};

struct fasync_struct___29 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___29 *fa_next;
	struct file___31 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___29 {
	struct inode___31 * (*alloc_inode)(struct super_block___30 *);
	void (*destroy_inode)(struct inode___31 *);
	void (*free_inode)(struct inode___31 *);
	void (*dirty_inode)(struct inode___31 *, int);
	int (*write_inode)(struct inode___31 *, struct writeback_control___12 *);
	int (*drop_inode)(struct inode___31 *);
	void (*evict_inode)(struct inode___31 *);
	void (*put_super)(struct super_block___30 *);
	int (*sync_fs)(struct super_block___30 *, int);
	int (*freeze_super)(struct super_block___30 *);
	int (*freeze_fs)(struct super_block___30 *);
	int (*thaw_super)(struct super_block___30 *);
	int (*unfreeze_fs)(struct super_block___30 *);
	int (*statfs)(struct dentry___30 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___30 *, int *, char *);
	void (*umount_begin)(struct super_block___30 *);
	int (*show_options)(struct seq_file___29 *, struct dentry___30 *);
	int (*show_devname)(struct seq_file___29 *, struct dentry___30 *);
	int (*show_path)(struct seq_file___29 *, struct dentry___30 *);
	int (*show_stats)(struct seq_file___29 *, struct dentry___30 *);
	ssize_t (*quota_read)(struct super_block___30 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___30 *, int, const char *, size_t, loff_t);
	struct dquot___29 ** (*get_dquots)(struct inode___31 *);
	long int (*nr_cached_objects)(struct super_block___30 *, struct shrink_control___12 *);
	long int (*free_cached_objects)(struct super_block___30 *, struct shrink_control___12 *);
	struct file___31 * (*real_loop)(struct file___31 *);
};

struct wakeup_source___27;

struct dev_pm_info___27 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___27 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___27 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___27;

struct bus_type___27;

struct device_driver___27;

struct dev_pm_domain___27;

struct fwnode_handle___27;

struct class___27;

struct attribute_group___29;

struct device___27 {
	struct kobject___29 kobj;
	struct device___27 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___27 *type;
	struct bus_type___27 *bus;
	struct device_driver___27 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___27 power;
	struct dev_pm_domain___27 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___27 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___27 *class;
	const struct attribute_group___29 **groups;
	void (*release)(struct device___27 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___14 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___31 *bd_inode;
	struct super_block___30 *bd_super;
	void *bd_claiming;
	struct device___27 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___29 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___13 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___30 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___23)(struct file___31 *, wait_queue_head_t *, struct poll_table_struct___23 *);

struct poll_table_struct___23 {
	poll_queue_proc___23 _qproc;
	__poll_t _key;
};

struct seq_operations___28;

struct seq_file___29 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___28 *op;
	int poll_event;
	const struct file___31 *file;
	void *private;
};

typedef void bio_end_io_t___13(struct bio___13 *);

struct bio_vec___15 {
	struct page___31 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___13;

struct bio___13 {
	struct bio___13 *bi_next;
	struct block_device___14 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___13 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___12 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___13 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___15 *bi_io_vec;
	struct bio_set___13 *bi_pool;
	struct bio_vec___15 bi_inline_vecs[0];
};

struct time_namespace___2 {
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct ns_common___3 ns;
	struct timens_offsets offsets;
	struct page___31 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___22 {
	struct ns_common___3 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___22 *root_cset;
};

enum uts_proc {
	UTS_PROC_OSTYPE = 0,
	UTS_PROC_OSRELEASE = 1,
	UTS_PROC_VERSION = 2,
	UTS_PROC_HOSTNAME = 3,
	UTS_PROC_DOMAINNAME = 4,
};

struct fwnode_operations___27;

struct fwnode_handle___27 {
	struct fwnode_handle___27 *secondary;
	const struct fwnode_operations___27 *ops;
	struct device___27 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___27;

struct fwnode_endpoint___27;

struct fwnode_operations___27 {
	struct fwnode_handle___27 * (*get)(struct fwnode_handle___27 *);
	void (*put)(struct fwnode_handle___27 *);
	bool (*device_is_available)(const struct fwnode_handle___27 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___27 *, const struct device___27 *);
	bool (*property_present)(const struct fwnode_handle___27 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___27 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___27 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___27 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_parent)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_next_child_node)(const struct fwnode_handle___27 *, struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*get_named_child_node)(const struct fwnode_handle___27 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___27 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___27 *);
	struct fwnode_handle___27 * (*graph_get_next_endpoint)(const struct fwnode_handle___27 *, struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*graph_get_remote_endpoint)(const struct fwnode_handle___27 *);
	struct fwnode_handle___27 * (*graph_get_port_parent)(struct fwnode_handle___27 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___27 *, struct fwnode_endpoint___27 *);
	int (*add_links)(struct fwnode_handle___27 *);
};

struct fwnode_endpoint___27 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___27 *local_fwnode;
};

struct fwnode_reference_args___27 {
	struct fwnode_handle___27 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___29;

struct kernfs_elem_dir___29 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___29 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___29;

struct kernfs_root___29 {
	struct kernfs_node___29 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___29 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___29 {
	struct kernfs_node___29 *target_kn;
};

struct kernfs_ops___29;

struct kernfs_elem_attr___29 {
	const struct kernfs_ops___29 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___29 *notify_next;
};

struct kernfs_node___29 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___29 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___29 dir;
		struct kernfs_elem_symlink___29 symlink;
		struct kernfs_elem_attr___29 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___29;

struct kernfs_ops___29 {
	int (*open)(struct kernfs_open_file___29 *);
	void (*release)(struct kernfs_open_file___29 *);
	int (*seq_show)(struct seq_file___29 *, void *);
	void * (*seq_start)(struct seq_file___29 *, loff_t *);
	void * (*seq_next)(struct seq_file___29 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___29 *, void *);
	ssize_t (*read)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___29 *, struct poll_table_struct___23 *);
	int (*mmap)(struct kernfs_open_file___29 *, struct vm_area_struct___30 *);
};

struct kernfs_syscall_ops___29 {
	int (*show_options)(struct seq_file___29 *, struct kernfs_root___29 *);
	int (*mkdir)(struct kernfs_node___29 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___29 *);
	int (*rename)(struct kernfs_node___29 *, struct kernfs_node___29 *, const char *);
	int (*show_path)(struct seq_file___29 *, struct kernfs_node___29 *, struct kernfs_root___29 *);
};

struct kernfs_open_file___29 {
	struct kernfs_node___29 *kn;
	struct file___31 *file;
	struct seq_file___29 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___29 *vm_ops;
};

struct bin_attribute___29;

struct attribute_group___29 {
	const char *name;
	umode_t (*is_visible)(struct kobject___29 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___29 *, struct bin_attribute___29 *, int);
	struct attribute **attrs;
	struct bin_attribute___29 **bin_attrs;
};

struct bin_attribute___29 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___29 * (*f_mapping)();
	ssize_t (*read)(struct file___31 *, struct kobject___29 *, struct bin_attribute___29 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___31 *, struct kobject___29 *, struct bin_attribute___29 *, char *, loff_t, size_t);
	int (*mmap)(struct file___31 *, struct kobject___29 *, struct bin_attribute___29 *, struct vm_area_struct___30 *);
};

struct sysfs_ops___29 {
	ssize_t (*show)(struct kobject___29 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___29 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___29;

struct kset___29 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___29 kobj;
	const struct kset_uevent_ops___29 *uevent_ops;
};

struct kobj_type___29 {
	void (*release)(struct kobject___29 *);
	const struct sysfs_ops___29 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___29 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___29 *);
	const void * (*namespace)(struct kobject___29 *);
	void (*get_ownership)(struct kobject___29 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___29 {
	int (* const filter)(struct kset___29 *, struct kobject___29 *);
	const char * (* const name)(struct kset___29 *, struct kobject___29 *);
	int (* const uevent)(struct kset___29 *, struct kobject___29 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___29 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___29 *);
	int (*get)(char *, const struct kernel_param___29 *);
	void (*free)(void *);
};

struct kparam_array___29;

struct kernel_param___29 {
	const char *name;
	struct module___31 *mod;
	const struct kernel_param_ops___29 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___29 *arr;
	};
};

struct kparam_array___29 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___29 *ops;
	void *elem;
};

struct module_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___29 *, struct module_kobject___29 *, char *);
	ssize_t (*store)(struct module_attribute___29 *, struct module_kobject___29 *, const char *, size_t);
	void (*setup)(struct module___31 *, const char *);
	int (*test)(struct module___31 *);
	void (*free)(struct module___31 *);
};

struct trace_event_class___15;

struct trace_event_call___15 {
	struct list_head list;
	struct trace_event_class___15 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___15 *, struct perf_event___20 *);
};

struct compat_tms {
	compat_clock_t tms_utime;
	compat_clock_t tms_stime;
	compat_clock_t tms_cutime;
	compat_clock_t tms_cstime;
};

struct compat_rlimit {
	compat_ulong_t rlim_cur;
	compat_ulong_t rlim_max;
};

struct dev_pm_ops___27 {
	int (*prepare)(struct device___27 *);
	void (*complete)(struct device___27 *);
	int (*suspend)(struct device___27 *);
	int (*resume)(struct device___27 *);
	int (*freeze)(struct device___27 *);
	int (*thaw)(struct device___27 *);
	int (*poweroff)(struct device___27 *);
	int (*restore)(struct device___27 *);
	int (*suspend_late)(struct device___27 *);
	int (*resume_early)(struct device___27 *);
	int (*freeze_late)(struct device___27 *);
	int (*thaw_early)(struct device___27 *);
	int (*poweroff_late)(struct device___27 *);
	int (*restore_early)(struct device___27 *);
	int (*suspend_noirq)(struct device___27 *);
	int (*resume_noirq)(struct device___27 *);
	int (*freeze_noirq)(struct device___27 *);
	int (*thaw_noirq)(struct device___27 *);
	int (*poweroff_noirq)(struct device___27 *);
	int (*restore_noirq)(struct device___27 *);
	int (*runtime_suspend)(struct device___27 *);
	int (*runtime_resume)(struct device___27 *);
	int (*runtime_idle)(struct device___27 *);
};

struct wakeup_source___27 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___27 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___27 {
	struct dev_pm_ops___27 ops;
	int (*start)(struct device___27 *);
	void (*detach)(struct device___27 *, bool);
	int (*activate)(struct device___27 *);
	void (*sync)(struct device___27 *);
	void (*dismiss)(struct device___27 *);
};

struct bus_type___27 {
	const char *name;
	const char *dev_name;
	struct device___27 *dev_root;
	const struct attribute_group___29 **bus_groups;
	const struct attribute_group___29 **dev_groups;
	const struct attribute_group___29 **drv_groups;
	int (*match)(struct device___27 *, struct device_driver___27 *);
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	int (*probe)(struct device___27 *);
	void (*sync_state)(struct device___27 *);
	void (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*online)(struct device___27 *);
	int (*offline)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	int (*num_vf)(struct device___27 *);
	int (*dma_configure)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___27 {
	const char *name;
	struct bus_type___27 *bus;
	struct module___31 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___27 *);
	void (*sync_state)(struct device___27 *);
	int (*remove)(struct device___27 *);
	void (*shutdown)(struct device___27 *);
	int (*suspend)(struct device___27 *, pm_message_t);
	int (*resume)(struct device___27 *);
	const struct attribute_group___29 **groups;
	const struct attribute_group___29 **dev_groups;
	const struct dev_pm_ops___27 *pm;
	void (*coredump)(struct device___27 *);
	struct driver_private *p;
};

struct device_type___27 {
	const char *name;
	const struct attribute_group___29 **groups;
	int (*uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___27 *);
	const struct dev_pm_ops___27 *pm;
};

struct class___27 {
	const char *name;
	struct module___31 *owner;
	const struct attribute_group___29 **class_groups;
	const struct attribute_group___29 **dev_groups;
	struct kobject___29 *dev_kobj;
	int (*dev_uevent)(struct device___27 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___27 *, umode_t *);
	void (*class_release)(struct class___27 *);
	void (*dev_release)(struct device___27 *);
	int (*shutdown_pre)(struct device___27 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___27 *);
	void (*get_ownership)(struct device___27 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___27 *pm;
	struct subsys_private *p;
};

struct seq_operations___28 {
	void * (*start)(struct seq_file___29 *, loff_t *);
	void (*stop)(struct seq_file___29 *, void *);
	void * (*next)(struct seq_file___29 *, void *, loff_t *);
	int (*show)(struct seq_file___29 *, void *);
};

struct fd___4 {
	struct file___31 *file;
	unsigned int flags;
};

struct cftype___22;

struct cgroup_subsys___22 {
	struct cgroup_subsys_state___22 * (*css_alloc)(struct cgroup_subsys_state___22 *);
	int (*css_online)(struct cgroup_subsys_state___22 *);
	void (*css_offline)(struct cgroup_subsys_state___22 *);
	void (*css_released)(struct cgroup_subsys_state___22 *);
	void (*css_free)(struct cgroup_subsys_state___22 *);
	void (*css_reset)(struct cgroup_subsys_state___22 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___22 *, int);
	int (*css_extra_stat_show)(struct seq_file___29 *, struct cgroup_subsys_state___22 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___32 *, struct css_set___22 *);
	void (*cancel_fork)(struct task_struct___32 *, struct css_set___22 *);
	void (*fork)(struct task_struct___32 *);
	void (*exit)(struct task_struct___32 *);
	void (*release)(struct task_struct___32 *);
	void (*bind)(struct cgroup_subsys_state___22 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___22 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___22 *dfl_cftypes;
	struct cftype___22 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___22 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___22 *updated_children;
	struct cgroup___22 *updated_next;
};

struct cgroup_root___22 {
	struct kernfs_root___29 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___22 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___22 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___22 *ss;
	struct list_head node;
	struct kernfs_ops___29 *kf_ops;
	int (*open)(struct kernfs_open_file___29 *);
	void (*release)(struct kernfs_open_file___29 *);
	u64 (*read_u64)(struct cgroup_subsys_state___22 *, struct cftype___22 *);
	s64 (*read_s64)(struct cgroup_subsys_state___22 *, struct cftype___22 *);
	int (*seq_show)(struct seq_file___29 *, void *);
	void * (*seq_start)(struct seq_file___29 *, loff_t *);
	void * (*seq_next)(struct seq_file___29 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___29 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___22 *, struct cftype___22 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___22 *, struct cftype___22 *, s64);
	ssize_t (*write)(struct kernfs_open_file___29 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___29 *, struct poll_table_struct___23 *);
};

struct perf_cpu_context___20;

struct perf_output_handle___20;

struct pmu___20 {
	struct list_head entry;
	struct module___31 *module;
	struct device___27 *dev;
	const struct attribute_group___29 **attr_groups;
	const struct attribute_group___29 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___20 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___20 *);
	void (*pmu_disable)(struct pmu___20 *);
	int (*event_init)(struct perf_event___20 *);
	void (*event_mapped)(struct perf_event___20 *, struct mm_struct___31 *);
	void (*event_unmapped)(struct perf_event___20 *, struct mm_struct___31 *);
	int (*add)(struct perf_event___20 *, int);
	void (*del)(struct perf_event___20 *, int);
	void (*start)(struct perf_event___20 *, int);
	void (*stop)(struct perf_event___20 *, int);
	void (*read)(struct perf_event___20 *);
	void (*start_txn)(struct pmu___20 *, unsigned int);
	int (*commit_txn)(struct pmu___20 *);
	void (*cancel_txn)(struct pmu___20 *);
	int (*event_idx)(struct perf_event___20 *);
	void (*sched_task)(struct perf_event_context___20 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___20 *, struct perf_event_context___20 *);
	void * (*setup_aux)(struct perf_event___20 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___20 *, struct perf_output_handle___20 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___20 *);
	int (*aux_output_match)(struct perf_event___20 *);
	int (*filter_match)(struct perf_event___20 *);
	int (*check_period)(struct perf_event___20 *, u64);
};

struct perf_cpu_context___20 {
	struct perf_event_context___20 ctx;
	struct perf_event_context___20 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___20 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___20 **heap;
	struct perf_event___20 *heap_default[2];
};

struct perf_output_handle___20 {
	struct perf_event___20 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___20 {
	struct cgroup_subsys_state___22 css;
	struct perf_cgroup_info *info;
};

struct tms {
	__kernel_clock_t tms_utime;
	__kernel_clock_t tms_stime;
	__kernel_clock_t tms_cutime;
	__kernel_clock_t tms_cstime;
};

struct block_device_operations___13;

struct gendisk___13 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___14 *part0;
	const struct block_device_operations___13 *fops;
	struct request_queue___14 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___12 *bdi;
	struct kobject___29 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___29 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___13 {
	struct bio___13 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___15 *bip_vec;
	struct bio_vec___15 bip_inline_vecs[0];
};

struct blkcg___12;

struct blkg_policy_data___12;

struct blkcg_gq___12 {
	struct request_queue___14 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___12 *blkcg;
	struct blkcg_gq___12 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___12 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___13 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___13(struct request___13 *);

typedef void integrity_complete_fn___13(struct request___13 *, unsigned int);

struct blk_integrity_profile___13 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___13 *prepare_fn;
	integrity_complete_fn___13 *complete_fn;
	const char *name;
};

struct block_device_operations___13 {
	blk_qc_t (*submit_bio)(struct bio___13 *);
	int (*open)(struct block_device___14 *, fmode_t);
	void (*release)(struct gendisk___13 *, fmode_t);
	int (*rw_page)(struct block_device___14 *, sector_t, struct page___31 *, unsigned int);
	int (*ioctl)(struct block_device___14 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___14 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___13 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___13 *);
	int (*getgeo)(struct block_device___14 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___14 *, bool);
	void (*swap_slot_free_notify)(struct block_device___14 *, long unsigned int);
	int (*report_zones)(struct gendisk___13 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___13 *, umode_t *);
	struct module___31 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___13 *, sector_t *);
};

typedef void rq_end_io_fn___13(struct request___13 *, blk_status_t);

struct request___13 {
	struct request_queue___14 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___12 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___13 *bio;
	struct bio___13 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___15 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___13 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___13 *saved_end_io;
		} flush;
	};
	struct gendisk___13 *rq_disk;
	struct block_device___14 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___13 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___12 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___14 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___29 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___30 *debugfs_dir;
	struct dentry___30 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___13;

struct elevator_mq_ops___13 {
	int (*init_sched)(struct request_queue___14 *, struct elevator_type___13 *);
	void (*exit_sched)(struct elevator_queue___13 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___12 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___12 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___12 *);
	bool (*allow_merge)(struct request_queue___14 *, struct request___13 *, struct bio___13 *);
	bool (*bio_merge)(struct request_queue___14 *, struct bio___13 *, unsigned int);
	int (*request_merge)(struct request_queue___14 *, struct request___13 **, struct bio___13 *);
	void (*request_merged)(struct request_queue___14 *, struct request___13 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___14 *, struct request___13 *, struct request___13 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___13 *);
	void (*finish_request)(struct request___13 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___12 *, struct list_head *, bool);
	struct request___13 * (*dispatch_request)(struct blk_mq_hw_ctx___12 *);
	bool (*has_work)(struct blk_mq_hw_ctx___12 *);
	void (*completed_request)(struct request___13 *, u64);
	void (*requeue_request)(struct request___13 *);
	struct request___13 * (*former_request)(struct request_queue___14 *, struct request___13 *);
	struct request___13 * (*next_request)(struct request_queue___14 *, struct request___13 *);
	void (*init_icq)(struct io_cq___13 *);
	void (*exit_icq)(struct io_cq___13 *);
};

struct elv_fs_entry___13;

struct elevator_type___13 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___13 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___13 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___31 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___13 {
	struct elevator_type___13 *type;
	void *elevator_data;
	struct kobject___29 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___13 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___13 *, char *);
	ssize_t (*store)(struct elevator_queue___13 *, const char *, size_t);
};

struct blk_mq_queue_data___12;

struct blk_mq_ops___12 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___12 *, const struct blk_mq_queue_data___12 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___12 *);
	int (*get_budget)(struct request_queue___14 *);
	void (*put_budget)(struct request_queue___14 *, int);
	void (*set_rq_budget_token)(struct request___13 *, int);
	int (*get_rq_budget_token)(struct request___13 *);
	enum blk_eh_timer_return (*timeout)(struct request___13 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___12 *);
	void (*complete)(struct request___13 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___12 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___12 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___12 *, struct request___13 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___12 *, struct request___13 *, unsigned int);
	void (*initialize_rq_fn)(struct request___13 *);
	void (*cleanup_rq)(struct request___13 *);
	bool (*busy)(struct request_queue___14 *);
	int (*map_queues)(struct blk_mq_tag_set___12 *);
	void (*show_rq)(struct seq_file___29 *, struct request___13 *);
};

struct blk_mq_tag_set___12 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___12 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___12 {
	struct request___13 *rq;
	bool last;
};

struct blkcg_policy_data___12;

struct blkcg___12 {
	struct cgroup_subsys_state___22 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___12 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___12 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___12 {
	struct blkcg___12 *blkcg;
	int plid;
};

struct blkg_policy_data___12 {
	struct blkcg_gq___12 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___12 {
	struct mem_cgroup___12 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___12 {
	struct lruvec___13 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___12 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___12 *memcg;
};

struct obj_cgroup___12 {
	struct percpu_ref refcnt;
	struct mem_cgroup___12 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct tty_operations___6 {
	struct tty_struct___6 * (*lookup)(struct tty_driver___6 *, struct file___31 *, int);
	int (*install)(struct tty_driver___6 *, struct tty_struct___6 *);
	void (*remove)(struct tty_driver___6 *, struct tty_struct___6 *);
	int (*open)(struct tty_struct___6 *, struct file___31 *);
	void (*close)(struct tty_struct___6 *, struct file___31 *);
	void (*shutdown)(struct tty_struct___6 *);
	void (*cleanup)(struct tty_struct___6 *);
	int (*write)(struct tty_struct___6 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___6 *, unsigned char);
	void (*flush_chars)(struct tty_struct___6 *);
	unsigned int (*write_room)(struct tty_struct___6 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___6 *);
	int (*ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___6 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	void (*throttle)(struct tty_struct___6 *);
	void (*unthrottle)(struct tty_struct___6 *);
	void (*stop)(struct tty_struct___6 *);
	void (*start)(struct tty_struct___6 *);
	void (*hangup)(struct tty_struct___6 *);
	int (*break_ctl)(struct tty_struct___6 *, int);
	void (*flush_buffer)(struct tty_struct___6 *);
	void (*set_ldisc)(struct tty_struct___6 *);
	void (*wait_until_sent)(struct tty_struct___6 *, int);
	void (*send_xchar)(struct tty_struct___6 *, char);
	int (*tiocmget)(struct tty_struct___6 *);
	int (*tiocmset)(struct tty_struct___6 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___6 *, struct winsize *);
	int (*get_icount)(struct tty_struct___6 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___6 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___6 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___6 *, struct seq_file___29 *);
	int (*poll_init)(struct tty_driver___6 *, int, char *);
	int (*poll_get_char)(struct tty_driver___6 *, int);
	void (*poll_put_char)(struct tty_driver___6 *, int, char);
	int (*proc_show)(struct seq_file___29 *, void *);
};

struct tty_driver___6 {
	int magic;
	struct kref kref;
	struct cdev___16 **cdevs;
	struct module___31 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___6 *other;
	struct tty_struct___6 **ttys;
	struct tty_port___6 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___6 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___6;

struct tty_port_client_operations___6;

struct tty_port___6 {
	struct tty_bufhead buf;
	struct tty_struct___6 *tty;
	struct tty_struct___6 *itty;
	const struct tty_port_operations___6 *ops;
	const struct tty_port_client_operations___6 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___6 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___6 *);
	void (*close)(struct tty_struct___6 *);
	void (*flush_buffer)(struct tty_struct___6 *);
	ssize_t (*read)(struct tty_struct___6 *, struct file___31 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___6 *, struct file___31 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___6 *, struct file___31 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___6 *, struct file___31 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___6 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___6 *, struct file___31 *, struct poll_table_struct___23 *);
	int (*hangup)(struct tty_struct___6 *);
	void (*receive_buf)(struct tty_struct___6 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___6 *);
	void (*dcd_change)(struct tty_struct___6 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___6 *, const unsigned char *, const char *, int);
	struct module___31 *owner;
};

struct tty_ldisc___6 {
	struct tty_ldisc_ops___6 *ops;
	struct tty_struct___6 *tty;
};

struct tty_port_operations___6 {
	int (*carrier_raised)(struct tty_port___6 *);
	void (*dtr_rts)(struct tty_port___6 *, int);
	void (*shutdown)(struct tty_port___6 *);
	int (*activate)(struct tty_port___6 *, struct tty_struct___6 *);
	void (*destruct)(struct tty_port___6 *);
};

struct tty_port_client_operations___6 {
	int (*receive_buf)(struct tty_port___6 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___6 *);
};

struct getcpu_cache {
	long unsigned int blob[16];
};

struct trace_event_fields___15 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___15 *);
	};
};

struct trace_event_class___15 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___15 *, enum trace_reg, void *);
	struct trace_event_fields___15 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___15 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___15 *);
};

struct syscall_metadata___6 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___15 *enter_event;
	struct trace_event_call___15 *exit_event;
};

struct linux_binprm___7 {
	struct vm_area_struct___30 *vma;
	long unsigned int vma_pages;
	struct mm_struct___31 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___31 *executable;
	struct file___31 *interpreter;
	struct file___31 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___6 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___31 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct compat_sysinfo {
	s32 uptime;
	u32 loads[3];
	u32 totalram;
	u32 freeram;
	u32 sharedram;
	u32 bufferram;
	u32 totalswap;
	u32 freeswap;
	u16 procs;
	u16 pad;
	u32 totalhigh;
	u32 freehigh;
	u32 mem_unit;
	char _f[8];
};

struct dentry___31;

struct super_block___31;

struct module___32;

struct file_system_type___30 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___31 * (*mount)(struct file_system_type___30 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___31 *);
	struct module___32 *owner;
	struct file_system_type___30 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___32;

struct kiocb___30;

struct iov_iter___16;

struct poll_table_struct___24;

struct vm_area_struct___31;

struct inode___32;

struct file_lock___30;

struct page___32;

struct seq_file___30;

struct file_operations___30 {
	struct module___32 *owner;
	loff_t (*llseek)(struct file___32 *, loff_t, int);
	ssize_t (*read)(struct file___32 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___32 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___30 *, struct iov_iter___16 *);
	ssize_t (*write_iter)(struct kiocb___30 *, struct iov_iter___16 *);
	int (*iopoll)(struct kiocb___30 *, bool);
	int (*iterate)(struct file___32 *, struct dir_context *);
	int (*iterate_shared)(struct file___32 *, struct dir_context *);
	__poll_t (*poll)(struct file___32 *, struct poll_table_struct___24 *);
	long int (*unlocked_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___32 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___32 *, struct vm_area_struct___31 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___32 *, struct file___32 *);
	int (*flush)(struct file___32 *, fl_owner_t);
	int (*release)(struct inode___32 *, struct file___32 *);
	int (*fsync)(struct file___32 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___32 *, int);
	int (*lock)(struct file___32 *, int, struct file_lock___30 *);
	ssize_t (*sendpage)(struct file___32 *, struct page___32 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___32 *, long unsigned int);
	int (*flock)(struct file___32 *, int, struct file_lock___30 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___32 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___32 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___32 *, long int, struct file_lock___30 **, void **);
	long int (*fallocate)(struct file___32 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___30 *, struct file___32 *);
	ssize_t (*copy_file_range)(struct file___32 *, loff_t, struct file___32 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___32 *, loff_t, struct file___32 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___32 *, loff_t, loff_t, int);
};

struct vmacache___31 {
	u64 seqnum;
	struct vm_area_struct___31 *vmas[4];
};

struct page_frag___31 {
	struct page___32 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___21;

struct debug_info___21 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___21 *hbp_break[16];
	struct perf_event___21 *hbp_watch[16];
};

struct thread_struct___21 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___21 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___32;

struct pid___29;

struct fs_struct___5;

struct files_struct___3;

struct nsproxy___30;

struct signal_struct___31;

struct bio_list___14;

struct backing_dev_info___13;

struct io_context___15;

struct css_set___23;

struct perf_event_context___21;

struct mem_cgroup___13;

struct request_queue___15;

struct vm_struct___31;

struct task_struct___33 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___33 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___32 *mm;
	struct mm_struct___32 *active_mm;
	struct vmacache___31 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___33 *real_parent;
	struct task_struct___33 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___33 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___29 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___5 *fs;
	struct files_struct___3 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___30 *nsproxy;
	struct signal_struct___31 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___33 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___14 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___13 *backing_dev_info;
	struct io_context___15 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___23 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___21 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___31 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___13 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___13 *active_memcg;
	struct request_queue___15 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___33 *oom_reaper_list;
	struct vm_struct___31 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___21 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___30;

struct kobj_type___30;

struct kernfs_node___30;

struct kobject___30 {
	const char *name;
	struct list_head entry;
	struct kobject___30 *parent;
	struct kset___30 *kset;
	struct kobj_type___30 *ktype;
	struct kernfs_node___30 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___30 {
	struct kobject___30 kobj;
	struct module___32 *mod;
	struct kobject___30 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___30 {
	struct module___32 *mod;
	struct latch_tree_node node;
};

struct module_layout___30 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___30 mtn;
};

struct module_attribute___30;

struct kernel_param___30;

struct trace_event_call___16;

struct module___32 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___30 mkobj;
	struct module_attribute___30 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___30 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___30 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___30 core_layout;
	struct module_layout___30 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___16 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___21 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___33 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___21)(struct perf_event___21 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___21;

struct fasync_struct___30;

struct pid_namespace___29;

struct perf_cgroup___21;

struct perf_event___21 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___21 *group_leader;
	struct pmu___21 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___21 hw;
	struct perf_event_context___21 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___21 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___33 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___30 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___21 *aux_event;
	void (*destroy)(struct perf_event___21 *);
	struct callback_head callback_head;
	struct pid_namespace___29 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___21 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___21 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___16 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___21 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___29 {
	int nr;
	struct pid_namespace___29 *ns;
};

struct pid_namespace___29 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___33 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___29 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___29 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___29 numbers[1];
};

typedef struct page___32 *pgtable_t___31;

struct address_space___30;

struct dev_pagemap___30;

struct page___32 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___30 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___32 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___31 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___32 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___30 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___30;

struct vm_area_struct___31 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___31 *vm_next;
	struct vm_area_struct___31 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___32 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___30 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___32 *vm_file;
	struct file___32 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___31 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___33 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___33 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___29 *pids[4];
	struct pid___29 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___32 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___7;

struct core_state___31;

struct mm_struct___32 {
	struct {
		struct vm_area_struct___31 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___32 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___7 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___31 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___33 *owner;
		struct user_namespace___2 *user_ns;
		struct file___32 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vfsmount___30;

struct path___30 {
	struct vfsmount___30 *mnt;
	struct dentry___31 *dentry;
};

struct fs_struct___5 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___30 root;
	struct path___30 pwd;
};

struct fdtable___3 {
	unsigned int max_fds;
	struct file___32 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___3 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___3 *fdt;
	struct fdtable___3 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___32 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___23;

struct nsproxy___30 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___29 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___23 *cgroup_ns;
};

struct bio___14;

struct bio_list___14 {
	struct bio___14 *head;
	struct bio___14 *tail;
};

struct cgroup_subsys_state___23;

struct bdi_writeback___13 {
	struct backing_dev_info___13 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___23 *memcg_css;
	struct cgroup_subsys_state___23 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___28;

struct backing_dev_info___13 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___13 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___28 *dev;
	char dev_name[64];
	struct device___28 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___31 *debug_dir;
};

struct io_cq___14;

struct io_context___15 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___14 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___23;

struct css_set___23 {
	struct cgroup_subsys_state___23 *subsys[14];
	refcount_t refcount;
	struct css_set___23 *dom_cset;
	struct cgroup___23 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___23 *mg_src_cgrp;
	struct cgroup___23 *mg_dst_cgrp;
	struct css_set___23 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___21 {
	struct pmu___21 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___33 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___21 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___23;

struct cgroup_subsys_state___23 {
	struct cgroup___23 *cgroup;
	struct cgroup_subsys___23 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___23 *parent;
};

struct cgroup_file___23 {
	struct kernfs_node___30 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___13;

struct mem_cgroup_per_node___13;

struct mem_cgroup___13 {
	struct cgroup_subsys_state___23 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___23 events_file;
	struct cgroup_file___23 events_local_file;
	struct cgroup_file___23 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___13 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___33 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___13 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___14;

struct blk_integrity___14 {
	const struct blk_integrity_profile___14 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___14 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___14 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___14;

struct elevator_queue___14;

struct blk_mq_ops___13;

struct blk_mq_hw_ctx___13;

struct gendisk___14;

struct blkcg_gq___13;

struct blk_mq_tag_set___13;

struct request_queue___15 {
	struct request___14 *last_merge;
	struct elevator_queue___14 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___13 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___13 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___14 *disk;
	struct kobject___30 kobj;
	struct kobject___30 *mq_kobj;
	struct blk_integrity___14 integrity;
	struct device___28 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___13 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___13 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___14 bio_split;
	struct dentry___31 *debugfs_dir;
	struct dentry___31 *sched_debugfs_dir;
	struct dentry___31 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___31 {
	struct vm_struct___31 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___32 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___30;

struct address_space___30 {
	struct inode___32 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___30 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___30;

struct dev_pagemap___30 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___30 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___29 {
	rwlock_t lock;
	struct pid___29 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___32 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___30 f_path;
	struct inode___32 *f_inode;
	const struct file_operations___30 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___29 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___30 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___30;

struct vm_operations_struct___30 {
	void (*open)(struct vm_area_struct___31 *);
	void (*close)(struct vm_area_struct___31 *);
	int (*may_split)(struct vm_area_struct___31 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___31 *);
	int (*mprotect)(struct vm_area_struct___31 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___30 *);
	vm_fault_t (*huge_fault)(struct vm_fault___30 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___30 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___31 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___30 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___30 *);
	int (*access)(struct vm_area_struct___31 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___31 *);
	int (*set_policy)(struct vm_area_struct___31 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___31 *, long unsigned int);
	struct page___32 * (*find_special_page)(struct vm_area_struct___31 *, long unsigned int);
};

struct core_thread___31 {
	struct task_struct___33 *task;
	struct core_thread___31 *next;
};

struct core_state___31 {
	atomic_t nr_threads;
	struct core_thread___31 dumper;
	struct completion startup;
};

struct linux_binprm___8;

struct coredump_params___7;

struct linux_binfmt___7 {
	struct list_head lh;
	struct module___32 *module;
	int (*load_binary)(struct linux_binprm___8 *);
	int (*load_shlib)(struct file___32 *);
	int (*core_dump)(struct coredump_params___7 *);
	long unsigned int min_coredump;
};

struct vm_fault___30 {
	const struct {
		struct vm_area_struct___31 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___32 *cow_page;
	struct page___32 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___31 prealloc_pte;
};

struct pglist_data___14;

struct lruvec___14 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___14 *pgdat;
};

struct zone___14 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___14 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___14 {
	struct zone___14 *zone;
	int zone_idx;
};

struct zonelist___14 {
	struct zoneref___14 _zonerefs[321];
};

struct pglist_data___14 {
	struct zone___14 node_zones[5];
	struct zonelist___14 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___33 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___33 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___14 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___30;

struct dentry___31 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___31 *d_parent;
	struct qstr d_name;
	struct inode___32 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___30 *d_op;
	struct super_block___31 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___30;

struct inode___32 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___30 *i_op;
	struct super_block___31 *i_sb;
	struct address_space___30 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___13 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___30 *i_fop;
		void (*free_inode)(struct inode___32 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___30 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___16 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___30 {
	int (*d_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___31 *, unsigned int);
	int (*d_hash)(const struct dentry___31 *, struct qstr *);
	int (*d_compare)(const struct dentry___31 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___31 *);
	int (*d_init)(struct dentry___31 *);
	void (*d_release)(struct dentry___31 *);
	void (*d_prune)(struct dentry___31 *);
	void (*d_iput)(struct dentry___31 *, struct inode___32 *);
	char * (*d_dname)(struct dentry___31 *, char *, int);
	struct vfsmount___30 * (*d_automount)(struct path___30 *);
	int (*d_manage)(const struct path___30 *, bool);
	struct dentry___31 * (*d_real)(struct dentry___31 *, const struct inode___32 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___30;

struct mem_dqinfo___30 {
	struct quota_format_type___30 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___30;

struct quota_info___30 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___32 *files[3];
	struct mem_dqinfo___30 info[3];
	const struct quota_format_ops___30 *ops[3];
};

struct rcuwait___30 {
	struct task_struct___33 *task;
};

struct percpu_rw_semaphore___30 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___30 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___30 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___30 rw_sem[3];
};

struct shrink_control___13;

struct shrinker___13 {
	long unsigned int (*count_objects)(struct shrinker___13 *, struct shrink_control___13 *);
	long unsigned int (*scan_objects)(struct shrinker___13 *, struct shrink_control___13 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___30;

struct dquot_operations___30;

struct quotactl_ops___30;

struct block_device___15;

struct super_block___31 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___30 *s_type;
	const struct super_operations___30 *s_op;
	const struct dquot_operations___30 *dq_op;
	const struct quotactl_ops___30 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___31 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___15 *s_bdev;
	struct backing_dev_info___13 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___30 s_dquot;
	struct sb_writers___30 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___30 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___30 {
	struct dentry___31 *mnt_root;
	struct super_block___31 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct shrink_control___13 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___13 *memcg;
};

struct psi_group___23 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___33 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___23;

struct cgroup_rstat_cpu___23;

struct cgroup___23 {
	struct cgroup_subsys_state___23 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___30 *kn;
	struct cgroup_file___23 procs_file;
	struct cgroup_file___23 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___23 *subsys[14];
	struct cgroup_root___23 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___23 *dom_cgrp;
	struct cgroup___23 *old_dom_cgrp;
	struct cgroup_rstat_cpu___23 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___23 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___14 {
	struct request_queue___15 *q;
	struct io_context___15 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___15;

struct kiocb___30 {
	struct file___32 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___30 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___15 *ki_waitq;
	};
};

struct iattr___31 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___32 *ia_file;
};

struct dquot___30 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___31 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___30 {
	int qf_fmt_id;
	const struct quota_format_ops___30 *qf_ops;
	struct module___32 *qf_owner;
	struct quota_format_type___30 *qf_next;
};

struct quota_format_ops___30 {
	int (*check_quota_file)(struct super_block___31 *, int);
	int (*read_file_info)(struct super_block___31 *, int);
	int (*write_file_info)(struct super_block___31 *, int);
	int (*free_file_info)(struct super_block___31 *, int);
	int (*read_dqblk)(struct dquot___30 *);
	int (*commit_dqblk)(struct dquot___30 *);
	int (*release_dqblk)(struct dquot___30 *);
	int (*get_next_id)(struct super_block___31 *, struct kqid *);
};

struct dquot_operations___30 {
	int (*write_dquot)(struct dquot___30 *);
	struct dquot___30 * (*alloc_dquot)(struct super_block___31 *, int);
	void (*destroy_dquot)(struct dquot___30 *);
	int (*acquire_dquot)(struct dquot___30 *);
	int (*release_dquot)(struct dquot___30 *);
	int (*mark_dirty)(struct dquot___30 *);
	int (*write_info)(struct super_block___31 *, int);
	qsize_t * (*get_reserved_space)(struct inode___32 *);
	int (*get_projid)(struct inode___32 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___32 *, qsize_t *);
	int (*get_next_id)(struct super_block___31 *, struct kqid *);
};

struct quotactl_ops___30 {
	int (*quota_on)(struct super_block___31 *, int, int, const struct path___30 *);
	int (*quota_off)(struct super_block___31 *, int);
	int (*quota_enable)(struct super_block___31 *, unsigned int);
	int (*quota_disable)(struct super_block___31 *, unsigned int);
	int (*quota_sync)(struct super_block___31 *, int);
	int (*set_info)(struct super_block___31 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___31 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___31 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___31 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___31 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___31 *, unsigned int);
};

struct wait_page_queue___15 {
	struct page___32 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___13;

struct readahead_control___15;

struct swap_info_struct___10;

struct address_space_operations___30 {
	int (*writepage)(struct page___32 *, struct writeback_control___13 *);
	int (*readpage)(struct file___32 *, struct page___32 *);
	int (*writepages)(struct address_space___30 *, struct writeback_control___13 *);
	int (*set_page_dirty)(struct page___32 *);
	int (*readpages)(struct file___32 *, struct address_space___30 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___15 *);
	int (*write_begin)(struct file___32 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___32 **, void **);
	int (*write_end)(struct file___32 *, struct address_space___30 *, loff_t, unsigned int, unsigned int, struct page___32 *, void *);
	sector_t (*bmap)(struct address_space___30 *, sector_t);
	void (*invalidatepage)(struct page___32 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___32 *, gfp_t);
	void (*freepage)(struct page___32 *);
	ssize_t (*direct_IO)(struct kiocb___30 *, struct iov_iter___16 *);
	int (*migratepage)(struct address_space___30 *, struct page___32 *, struct page___32 *, enum migrate_mode);
	bool (*isolate_page)(struct page___32 *, isolate_mode_t);
	void (*putback_page)(struct page___32 *);
	int (*launder_page)(struct page___32 *);
	int (*is_partially_uptodate)(struct page___32 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___32 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___30 *, struct page___32 *);
	int (*swap_activate)(struct swap_info_struct___10 *, struct file___32 *, sector_t *);
	void (*swap_deactivate)(struct file___32 *);
};

struct writeback_control___13 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___13 *wb;
	struct inode___32 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___15 {
	struct file___32 *file;
	struct address_space___30 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___16;

struct iov_iter___16 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___16 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___10 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___15 *bdev;
	struct file___32 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___30 {
	struct dentry___31 * (*lookup)(struct inode___32 *, struct dentry___31 *, unsigned int);
	const char * (*get_link)(struct dentry___31 *, struct inode___32 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___32 *, int);
	struct posix_acl * (*get_acl)(struct inode___32 *, int, bool);
	int (*readlink)(struct dentry___31 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___32 *, struct dentry___31 *, umode_t, bool);
	int (*link)(struct dentry___31 *, struct inode___32 *, struct dentry___31 *);
	int (*unlink)(struct inode___32 *, struct dentry___31 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___32 *, struct dentry___31 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___32 *, struct dentry___31 *, umode_t);
	int (*rmdir)(struct inode___32 *, struct dentry___31 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___32 *, struct dentry___31 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___32 *, struct dentry___31 *, struct inode___32 *, struct dentry___31 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___31 *, struct iattr___31 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___30 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___31 *, char *, size_t);
	int (*fiemap)(struct inode___32 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___32 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___32 *, struct dentry___31 *, struct file___32 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___32 *, struct dentry___31 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___32 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___31 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___31 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___30 {
	void (*fl_copy_lock)(struct file_lock___30 *, struct file_lock___30 *);
	void (*fl_release_private)(struct file_lock___30 *);
};

struct lock_manager_operations___30;

struct file_lock___30 {
	struct file_lock___30 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___32 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___30 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___30 *fl_ops;
	const struct lock_manager_operations___30 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___30 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___30 *);
	int (*lm_grant)(struct file_lock___30 *, int);
	bool (*lm_break)(struct file_lock___30 *);
	int (*lm_change)(struct file_lock___30 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___30 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___30 *);
};

struct fasync_struct___30 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___30 *fa_next;
	struct file___32 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___30 {
	struct inode___32 * (*alloc_inode)(struct super_block___31 *);
	void (*destroy_inode)(struct inode___32 *);
	void (*free_inode)(struct inode___32 *);
	void (*dirty_inode)(struct inode___32 *, int);
	int (*write_inode)(struct inode___32 *, struct writeback_control___13 *);
	int (*drop_inode)(struct inode___32 *);
	void (*evict_inode)(struct inode___32 *);
	void (*put_super)(struct super_block___31 *);
	int (*sync_fs)(struct super_block___31 *, int);
	int (*freeze_super)(struct super_block___31 *);
	int (*freeze_fs)(struct super_block___31 *);
	int (*thaw_super)(struct super_block___31 *);
	int (*unfreeze_fs)(struct super_block___31 *);
	int (*statfs)(struct dentry___31 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___31 *, int *, char *);
	void (*umount_begin)(struct super_block___31 *);
	int (*show_options)(struct seq_file___30 *, struct dentry___31 *);
	int (*show_devname)(struct seq_file___30 *, struct dentry___31 *);
	int (*show_path)(struct seq_file___30 *, struct dentry___31 *);
	int (*show_stats)(struct seq_file___30 *, struct dentry___31 *);
	ssize_t (*quota_read)(struct super_block___31 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___31 *, int, const char *, size_t, loff_t);
	struct dquot___30 ** (*get_dquots)(struct inode___32 *);
	long int (*nr_cached_objects)(struct super_block___31 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___31 *, struct shrink_control___13 *);
	struct file___32 * (*real_loop)(struct file___32 *);
};

struct wakeup_source___28;

struct dev_pm_info___28 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___28 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___28 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___28;

struct bus_type___28;

struct device_driver___28;

struct dev_pm_domain___28;

struct fwnode_handle___28;

struct class___28;

struct attribute_group___30;

struct device___28 {
	struct kobject___30 kobj;
	struct device___28 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___28 *type;
	struct bus_type___28 *bus;
	struct device_driver___28 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___28 power;
	struct dev_pm_domain___28 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___28 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___28 *class;
	const struct attribute_group___30 **groups;
	void (*release)(struct device___28 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___15 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___32 *bd_inode;
	struct super_block___31 *bd_super;
	void *bd_claiming;
	struct device___28 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___30 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___14 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___31 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___24)(struct file___32 *, wait_queue_head_t *, struct poll_table_struct___24 *);

struct poll_table_struct___24 {
	poll_queue_proc___24 _qproc;
	__poll_t _key;
};

struct seq_operations___29;

struct seq_file___30 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___29 *op;
	int poll_event;
	const struct file___32 *file;
	void *private;
};

typedef void bio_end_io_t___14(struct bio___14 *);

struct bio_vec___16 {
	struct page___32 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___14;

struct bio___14 {
	struct bio___14 *bi_next;
	struct block_device___15 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___14 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___13 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___14 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___16 *bi_io_vec;
	struct bio_set___14 *bi_pool;
	struct bio_vec___16 bi_inline_vecs[0];
};

struct kernfs_root___30;

struct kernfs_elem_dir___30 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___30 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___30;

struct kernfs_root___30 {
	struct kernfs_node___30 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___30 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___30 {
	struct kernfs_node___30 *target_kn;
};

struct kernfs_ops___30;

struct kernfs_elem_attr___30 {
	const struct kernfs_ops___30 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___30 *notify_next;
};

struct kernfs_node___30 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___30 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___30 dir;
		struct kernfs_elem_symlink___30 symlink;
		struct kernfs_elem_attr___30 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___30;

struct kernfs_ops___30 {
	int (*open)(struct kernfs_open_file___30 *);
	void (*release)(struct kernfs_open_file___30 *);
	int (*seq_show)(struct seq_file___30 *, void *);
	void * (*seq_start)(struct seq_file___30 *, loff_t *);
	void * (*seq_next)(struct seq_file___30 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___30 *, void *);
	ssize_t (*read)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___30 *, struct poll_table_struct___24 *);
	int (*mmap)(struct kernfs_open_file___30 *, struct vm_area_struct___31 *);
};

struct kernfs_syscall_ops___30 {
	int (*show_options)(struct seq_file___30 *, struct kernfs_root___30 *);
	int (*mkdir)(struct kernfs_node___30 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___30 *);
	int (*rename)(struct kernfs_node___30 *, struct kernfs_node___30 *, const char *);
	int (*show_path)(struct seq_file___30 *, struct kernfs_node___30 *, struct kernfs_root___30 *);
};

struct kernfs_open_file___30 {
	struct kernfs_node___30 *kn;
	struct file___32 *file;
	struct seq_file___30 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___30 *vm_ops;
};

struct bin_attribute___30;

struct attribute_group___30 {
	const char *name;
	umode_t (*is_visible)(struct kobject___30 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___30 *, struct bin_attribute___30 *, int);
	struct attribute **attrs;
	struct bin_attribute___30 **bin_attrs;
};

struct bin_attribute___30 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___30 * (*f_mapping)();
	ssize_t (*read)(struct file___32 *, struct kobject___30 *, struct bin_attribute___30 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___32 *, struct kobject___30 *, struct bin_attribute___30 *, char *, loff_t, size_t);
	int (*mmap)(struct file___32 *, struct kobject___30 *, struct bin_attribute___30 *, struct vm_area_struct___31 *);
};

struct sysfs_ops___30 {
	ssize_t (*show)(struct kobject___30 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___30 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___30;

struct kset___30 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___30 kobj;
	const struct kset_uevent_ops___30 *uevent_ops;
};

struct kobj_type___30 {
	void (*release)(struct kobject___30 *);
	const struct sysfs_ops___30 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___30 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___30 *);
	const void * (*namespace)(struct kobject___30 *);
	void (*get_ownership)(struct kobject___30 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___30 {
	int (* const filter)(struct kset___30 *, struct kobject___30 *);
	const char * (* const name)(struct kset___30 *, struct kobject___30 *);
	int (* const uevent)(struct kset___30 *, struct kobject___30 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___30 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___30 *);
	int (*get)(char *, const struct kernel_param___30 *);
	void (*free)(void *);
};

struct kparam_array___30;

struct kernel_param___30 {
	const char *name;
	struct module___32 *mod;
	const struct kernel_param_ops___30 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___30 *arr;
	};
};

struct kparam_array___30 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___30 *ops;
	void *elem;
};

struct module_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___30 *, struct module_kobject___30 *, char *);
	ssize_t (*store)(struct module_attribute___30 *, struct module_kobject___30 *, const char *, size_t);
	void (*setup)(struct module___32 *, const char *);
	int (*test)(struct module___32 *);
	void (*free)(struct module___32 *);
};

struct trace_event_class___16;

struct trace_event_call___16 {
	struct list_head list;
	struct trace_event_class___16 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___16 *, struct perf_event___21 *);
};

struct linux_binprm___8 {
	struct vm_area_struct___31 *vma;
	long unsigned int vma_pages;
	struct mm_struct___32 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___32 *executable;
	struct file___32 *interpreter;
	struct file___32 *file;
	struct cred *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___7 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___32 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dev_pm_ops___28 {
	int (*prepare)(struct device___28 *);
	void (*complete)(struct device___28 *);
	int (*suspend)(struct device___28 *);
	int (*resume)(struct device___28 *);
	int (*freeze)(struct device___28 *);
	int (*thaw)(struct device___28 *);
	int (*poweroff)(struct device___28 *);
	int (*restore)(struct device___28 *);
	int (*suspend_late)(struct device___28 *);
	int (*resume_early)(struct device___28 *);
	int (*freeze_late)(struct device___28 *);
	int (*thaw_early)(struct device___28 *);
	int (*poweroff_late)(struct device___28 *);
	int (*restore_early)(struct device___28 *);
	int (*suspend_noirq)(struct device___28 *);
	int (*resume_noirq)(struct device___28 *);
	int (*freeze_noirq)(struct device___28 *);
	int (*thaw_noirq)(struct device___28 *);
	int (*poweroff_noirq)(struct device___28 *);
	int (*restore_noirq)(struct device___28 *);
	int (*runtime_suspend)(struct device___28 *);
	int (*runtime_resume)(struct device___28 *);
	int (*runtime_idle)(struct device___28 *);
};

struct wakeup_source___28 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___28 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___28 {
	struct dev_pm_ops___28 ops;
	int (*start)(struct device___28 *);
	void (*detach)(struct device___28 *, bool);
	int (*activate)(struct device___28 *);
	void (*sync)(struct device___28 *);
	void (*dismiss)(struct device___28 *);
};

struct bus_type___28 {
	const char *name;
	const char *dev_name;
	struct device___28 *dev_root;
	const struct attribute_group___30 **bus_groups;
	const struct attribute_group___30 **dev_groups;
	const struct attribute_group___30 **drv_groups;
	int (*match)(struct device___28 *, struct device_driver___28 *);
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	int (*probe)(struct device___28 *);
	void (*sync_state)(struct device___28 *);
	void (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*online)(struct device___28 *);
	int (*offline)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	int (*num_vf)(struct device___28 *);
	int (*dma_configure)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___28 {
	const char *name;
	struct bus_type___28 *bus;
	struct module___32 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___28 *);
	void (*sync_state)(struct device___28 *);
	int (*remove)(struct device___28 *);
	void (*shutdown)(struct device___28 *);
	int (*suspend)(struct device___28 *, pm_message_t);
	int (*resume)(struct device___28 *);
	const struct attribute_group___30 **groups;
	const struct attribute_group___30 **dev_groups;
	const struct dev_pm_ops___28 *pm;
	void (*coredump)(struct device___28 *);
	struct driver_private *p;
};

struct device_type___28 {
	const char *name;
	const struct attribute_group___30 **groups;
	int (*uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___28 *);
	const struct dev_pm_ops___28 *pm;
};

struct class___28 {
	const char *name;
	struct module___32 *owner;
	const struct attribute_group___30 **class_groups;
	const struct attribute_group___30 **dev_groups;
	struct kobject___30 *dev_kobj;
	int (*dev_uevent)(struct device___28 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___28 *, umode_t *);
	void (*class_release)(struct class___28 *);
	void (*dev_release)(struct device___28 *);
	int (*shutdown_pre)(struct device___28 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___28 *);
	void (*get_ownership)(struct device___28 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___28 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___28;

struct fwnode_handle___28 {
	struct fwnode_handle___28 *secondary;
	const struct fwnode_operations___28 *ops;
	struct device___28 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___30 {
	void (*page_free)(struct page___32 *);
	void (*kill)(struct dev_pagemap___30 *);
	void (*cleanup)(struct dev_pagemap___30 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___30 *);
};

struct seq_operations___29 {
	void * (*start)(struct seq_file___30 *, loff_t *);
	void (*stop)(struct seq_file___30 *, void *);
	void * (*next)(struct seq_file___30 *, void *, loff_t *);
	int (*show)(struct seq_file___30 *, void *);
};

struct fwnode_reference_args___28;

struct fwnode_endpoint___28;

struct fwnode_operations___28 {
	struct fwnode_handle___28 * (*get)(struct fwnode_handle___28 *);
	void (*put)(struct fwnode_handle___28 *);
	bool (*device_is_available)(const struct fwnode_handle___28 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___28 *, const struct device___28 *);
	bool (*property_present)(const struct fwnode_handle___28 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___28 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___28 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___28 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_parent)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_next_child_node)(const struct fwnode_handle___28 *, struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*get_named_child_node)(const struct fwnode_handle___28 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___28 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___28 *);
	struct fwnode_handle___28 * (*graph_get_next_endpoint)(const struct fwnode_handle___28 *, struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*graph_get_remote_endpoint)(const struct fwnode_handle___28 *);
	struct fwnode_handle___28 * (*graph_get_port_parent)(struct fwnode_handle___28 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___28 *, struct fwnode_endpoint___28 *);
	int (*add_links)(struct fwnode_handle___28 *);
};

struct fwnode_endpoint___28 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___28 *local_fwnode;
};

struct fwnode_reference_args___28 {
	struct fwnode_handle___28 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___23 {
	struct ns_common___3 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___23 *root_cset;
};

struct cftype___23;

struct cgroup_subsys___23 {
	struct cgroup_subsys_state___23 * (*css_alloc)(struct cgroup_subsys_state___23 *);
	int (*css_online)(struct cgroup_subsys_state___23 *);
	void (*css_offline)(struct cgroup_subsys_state___23 *);
	void (*css_released)(struct cgroup_subsys_state___23 *);
	void (*css_free)(struct cgroup_subsys_state___23 *);
	void (*css_reset)(struct cgroup_subsys_state___23 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___23 *, int);
	int (*css_extra_stat_show)(struct seq_file___30 *, struct cgroup_subsys_state___23 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___33 *, struct css_set___23 *);
	void (*cancel_fork)(struct task_struct___33 *, struct css_set___23 *);
	void (*fork)(struct task_struct___33 *);
	void (*exit)(struct task_struct___33 *);
	void (*release)(struct task_struct___33 *);
	void (*bind)(struct cgroup_subsys_state___23 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___23 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___23 *dfl_cftypes;
	struct cftype___23 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___23 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___23 *updated_children;
	struct cgroup___23 *updated_next;
};

struct cgroup_root___23 {
	struct kernfs_root___30 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___23 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___23 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___23 *ss;
	struct list_head node;
	struct kernfs_ops___30 *kf_ops;
	int (*open)(struct kernfs_open_file___30 *);
	void (*release)(struct kernfs_open_file___30 *);
	u64 (*read_u64)(struct cgroup_subsys_state___23 *, struct cftype___23 *);
	s64 (*read_s64)(struct cgroup_subsys_state___23 *, struct cftype___23 *);
	int (*seq_show)(struct seq_file___30 *, void *);
	void * (*seq_start)(struct seq_file___30 *, loff_t *);
	void * (*seq_next)(struct seq_file___30 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___30 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___23 *, struct cftype___23 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___23 *, struct cftype___23 *, s64);
	ssize_t (*write)(struct kernfs_open_file___30 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___30 *, struct poll_table_struct___24 *);
};

struct perf_cpu_context___21;

struct perf_output_handle___21;

struct pmu___21 {
	struct list_head entry;
	struct module___32 *module;
	struct device___28 *dev;
	const struct attribute_group___30 **attr_groups;
	const struct attribute_group___30 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___21 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___21 *);
	void (*pmu_disable)(struct pmu___21 *);
	int (*event_init)(struct perf_event___21 *);
	void (*event_mapped)(struct perf_event___21 *, struct mm_struct___32 *);
	void (*event_unmapped)(struct perf_event___21 *, struct mm_struct___32 *);
	int (*add)(struct perf_event___21 *, int);
	void (*del)(struct perf_event___21 *, int);
	void (*start)(struct perf_event___21 *, int);
	void (*stop)(struct perf_event___21 *, int);
	void (*read)(struct perf_event___21 *);
	void (*start_txn)(struct pmu___21 *, unsigned int);
	int (*commit_txn)(struct pmu___21 *);
	void (*cancel_txn)(struct pmu___21 *);
	int (*event_idx)(struct perf_event___21 *);
	void (*sched_task)(struct perf_event_context___21 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___21 *, struct perf_event_context___21 *);
	void * (*setup_aux)(struct perf_event___21 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___21 *, struct perf_output_handle___21 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___21 *);
	int (*aux_output_match)(struct perf_event___21 *);
	int (*filter_match)(struct perf_event___21 *);
	int (*check_period)(struct perf_event___21 *, u64);
};

struct perf_cpu_context___21 {
	struct perf_event_context___21 ctx;
	struct perf_event_context___21 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___21 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___21 **heap;
	struct perf_event___21 *heap_default[2];
};

struct perf_output_handle___21 {
	struct perf_event___21 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___21 {
	struct cgroup_subsys_state___23 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___16 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___16 *);
	};
};

struct trace_event_class___16 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___16 *, enum trace_reg, void *);
	struct trace_event_fields___16 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___16 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___16 *);
};

struct block_device_operations___14;

struct gendisk___14 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___15 *part0;
	const struct block_device_operations___14 *fops;
	struct request_queue___15 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___13 *bdi;
	struct kobject___30 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___30 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___14 {
	struct bio___14 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___16 *bip_vec;
	struct bio_vec___16 bip_inline_vecs[0];
};

struct blkcg___13;

struct blkg_policy_data___13;

struct blkcg_gq___13 {
	struct request_queue___15 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___13 *blkcg;
	struct blkcg_gq___13 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___13 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___14 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___14(struct request___14 *);

typedef void integrity_complete_fn___14(struct request___14 *, unsigned int);

struct blk_integrity_profile___14 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___14 *prepare_fn;
	integrity_complete_fn___14 *complete_fn;
	const char *name;
};

struct block_device_operations___14 {
	blk_qc_t (*submit_bio)(struct bio___14 *);
	int (*open)(struct block_device___15 *, fmode_t);
	void (*release)(struct gendisk___14 *, fmode_t);
	int (*rw_page)(struct block_device___15 *, sector_t, struct page___32 *, unsigned int);
	int (*ioctl)(struct block_device___15 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___15 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___14 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___14 *);
	int (*getgeo)(struct block_device___15 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___15 *, bool);
	void (*swap_slot_free_notify)(struct block_device___15 *, long unsigned int);
	int (*report_zones)(struct gendisk___14 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___14 *, umode_t *);
	struct module___32 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___14 *, sector_t *);
};

typedef void rq_end_io_fn___14(struct request___14 *, blk_status_t);

struct request___14 {
	struct request_queue___15 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___13 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___14 *bio;
	struct bio___14 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___16 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___14 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___14 *saved_end_io;
		} flush;
	};
	struct gendisk___14 *rq_disk;
	struct block_device___15 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___14 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___13 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___15 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___30 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___31 *debugfs_dir;
	struct dentry___31 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___14;

struct elevator_mq_ops___14 {
	int (*init_sched)(struct request_queue___15 *, struct elevator_type___14 *);
	void (*exit_sched)(struct elevator_queue___14 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___13 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___13 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___13 *);
	bool (*allow_merge)(struct request_queue___15 *, struct request___14 *, struct bio___14 *);
	bool (*bio_merge)(struct request_queue___15 *, struct bio___14 *, unsigned int);
	int (*request_merge)(struct request_queue___15 *, struct request___14 **, struct bio___14 *);
	void (*request_merged)(struct request_queue___15 *, struct request___14 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___15 *, struct request___14 *, struct request___14 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___14 *);
	void (*finish_request)(struct request___14 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___13 *, struct list_head *, bool);
	struct request___14 * (*dispatch_request)(struct blk_mq_hw_ctx___13 *);
	bool (*has_work)(struct blk_mq_hw_ctx___13 *);
	void (*completed_request)(struct request___14 *, u64);
	void (*requeue_request)(struct request___14 *);
	struct request___14 * (*former_request)(struct request_queue___15 *, struct request___14 *);
	struct request___14 * (*next_request)(struct request_queue___15 *, struct request___14 *);
	void (*init_icq)(struct io_cq___14 *);
	void (*exit_icq)(struct io_cq___14 *);
};

struct elv_fs_entry___14;

struct elevator_type___14 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___14 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___14 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___32 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___14 {
	struct elevator_type___14 *type;
	void *elevator_data;
	struct kobject___30 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___14 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___14 *, char *);
	ssize_t (*store)(struct elevator_queue___14 *, const char *, size_t);
};

struct blk_mq_queue_data___13;

struct blk_mq_ops___13 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___13 *, const struct blk_mq_queue_data___13 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___13 *);
	int (*get_budget)(struct request_queue___15 *);
	void (*put_budget)(struct request_queue___15 *, int);
	void (*set_rq_budget_token)(struct request___14 *, int);
	int (*get_rq_budget_token)(struct request___14 *);
	enum blk_eh_timer_return (*timeout)(struct request___14 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___13 *);
	void (*complete)(struct request___14 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___13 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___13 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___13 *, struct request___14 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___13 *, struct request___14 *, unsigned int);
	void (*initialize_rq_fn)(struct request___14 *);
	void (*cleanup_rq)(struct request___14 *);
	bool (*busy)(struct request_queue___15 *);
	int (*map_queues)(struct blk_mq_tag_set___13 *);
	void (*show_rq)(struct seq_file___30 *, struct request___14 *);
};

struct blk_mq_tag_set___13 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___13 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___13 {
	struct request___14 *rq;
	bool last;
};

struct blkcg_policy_data___13;

struct blkcg___13 {
	struct cgroup_subsys_state___23 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___13 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___13 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___13 {
	struct blkcg___13 *blkcg;
	int plid;
};

struct blkg_policy_data___13 {
	struct blkcg_gq___13 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___13 {
	struct mem_cgroup___13 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___13 {
	struct lruvec___14 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___13 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___13 *memcg;
};

struct obj_cgroup___13 {
	struct percpu_ref refcnt;
	struct mem_cgroup___13 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct dentry___32;

struct super_block___32;

struct module___33;

struct file_system_type___31 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___32 * (*mount)(struct file_system_type___31 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___32 *);
	struct module___33 *owner;
	struct file_system_type___31 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___33;

struct kiocb___31;

struct poll_table_struct___25;

struct vm_area_struct___32;

struct inode___33;

struct file_lock___31;

struct page___33;

struct seq_file___31;

struct file_operations___31 {
	struct module___33 *owner;
	loff_t (*llseek)(struct file___33 *, loff_t, int);
	ssize_t (*read)(struct file___33 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___33 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___31 *, struct iov_iter___16 *);
	ssize_t (*write_iter)(struct kiocb___31 *, struct iov_iter___16 *);
	int (*iopoll)(struct kiocb___31 *, bool);
	int (*iterate)(struct file___33 *, struct dir_context *);
	int (*iterate_shared)(struct file___33 *, struct dir_context *);
	__poll_t (*poll)(struct file___33 *, struct poll_table_struct___25 *);
	long int (*unlocked_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___33 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___33 *, struct vm_area_struct___32 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___33 *, struct file___33 *);
	int (*flush)(struct file___33 *, fl_owner_t);
	int (*release)(struct inode___33 *, struct file___33 *);
	int (*fsync)(struct file___33 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___33 *, int);
	int (*lock)(struct file___33 *, int, struct file_lock___31 *);
	ssize_t (*sendpage)(struct file___33 *, struct page___33 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___33 *, long unsigned int);
	int (*flock)(struct file___33 *, int, struct file_lock___31 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___33 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___33 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___33 *, long int, struct file_lock___31 **, void **);
	long int (*fallocate)(struct file___33 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___31 *, struct file___33 *);
	ssize_t (*copy_file_range)(struct file___33 *, loff_t, struct file___33 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___33 *, loff_t, struct file___33 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___33 *, loff_t, loff_t, int);
};

struct vmacache___32 {
	u64 seqnum;
	struct vm_area_struct___32 *vmas[4];
};

struct page_frag___32 {
	struct page___33 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___22;

struct debug_info___22 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___22 *hbp_break[16];
	struct perf_event___22 *hbp_watch[16];
};

struct thread_struct___22 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___22 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___33;

struct pid___30;

struct nsproxy___31;

struct signal_struct___32;

struct css_set___24;

struct perf_event_context___22;

struct vm_struct___32;

struct task_struct___34 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___34 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___33 *mm;
	struct mm_struct___33 *active_mm;
	struct vmacache___32 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___34 *real_parent;
	struct task_struct___34 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___34 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___30 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___31 *nsproxy;
	struct signal_struct___32 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___34 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___15 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___24 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___22 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___32 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___34 *oom_reaper_list;
	struct vm_struct___32 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___22 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___31;

struct kobj_type___31;

struct kernfs_node___31;

struct kobject___31 {
	const char *name;
	struct list_head entry;
	struct kobject___31 *parent;
	struct kset___31 *kset;
	struct kobj_type___31 *ktype;
	struct kernfs_node___31 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___31 {
	struct kobject___31 kobj;
	struct module___33 *mod;
	struct kobject___31 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___31 {
	struct module___33 *mod;
	struct latch_tree_node node;
};

struct module_layout___31 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___31 mtn;
};

struct module_attribute___31;

struct kernel_param___31;

struct trace_event_call___17;

struct module___33 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___31 mkobj;
	struct module_attribute___31 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___31 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___31 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___31 core_layout;
	struct module_layout___31 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___17 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___22 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___34 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___22)(struct perf_event___22 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___22;

struct fasync_struct___31;

struct pid_namespace___30;

struct perf_cgroup___22;

struct perf_event___22 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___22 *group_leader;
	struct pmu___22 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___22 hw;
	struct perf_event_context___22 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___22 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___34 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___31 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___22 *aux_event;
	void (*destroy)(struct perf_event___22 *);
	struct callback_head callback_head;
	struct pid_namespace___30 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___22 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___22 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___17 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___22 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___30 {
	int nr;
	struct pid_namespace___30 *ns;
};

struct pid_namespace___30 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___34 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___30 *parent;
	struct fs_pin *bacct;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	int reboot;
	struct ns_common___3 ns;
};

struct pid___30 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___30 numbers[1];
};

struct wq_flusher;

struct worker;

struct workqueue_attrs;

struct pool_workqueue;

struct wq_device;

struct workqueue_struct {
	struct list_head pwqs;
	struct list_head list;
	struct mutex mutex;
	int work_color;
	int flush_color;
	atomic_t nr_pwqs_to_flush;
	struct wq_flusher *first_flusher;
	struct list_head flusher_queue;
	struct list_head flusher_overflow;
	struct list_head maydays;
	struct worker *rescuer;
	int nr_drainers;
	int saved_max_active;
	struct workqueue_attrs *unbound_attrs;
	struct pool_workqueue *dfl_pwq;
	struct wq_device *wq_dev;
	char name[24];
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int flags;
	struct pool_workqueue *cpu_pwqs;
	struct pool_workqueue *numa_pwq_tbl[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct workqueue_attrs {
	int nice;
	cpumask_var_t cpumask;
	bool no_numa;
};

struct execute_work {
	struct work_struct work;
};

enum {
	WQ_UNBOUND = 2,
	WQ_FREEZABLE = 4,
	WQ_MEM_RECLAIM = 8,
	WQ_HIGHPRI = 16,
	WQ_CPU_INTENSIVE = 32,
	WQ_SYSFS = 64,
	WQ_POWER_EFFICIENT = 128,
	__WQ_DRAINING = 65536,
	__WQ_ORDERED = 131072,
	__WQ_LEGACY = 262144,
	__WQ_ORDERED_EXPLICIT = 524288,
	WQ_MAX_ACTIVE = 512,
	WQ_MAX_UNBOUND_PER_CPU = 4,
	WQ_DFL_ACTIVE = 256,
};

typedef struct page___33 *pgtable_t___32;

struct address_space___31;

struct dev_pagemap___31;

struct page___33 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___31 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___7 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___33 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___32 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___33 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___31 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___31;

struct vm_area_struct___32 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___32 *vm_next;
	struct vm_area_struct___32 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___33 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___31 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___33 *vm_file;
	struct file___33 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___32 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___34 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___34 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___30 *pids[4];
	struct pid___30 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___33 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___32;

struct mm_struct___33 {
	struct {
		struct vm_area_struct___32 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___33 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___32 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___34 *owner;
		struct user_namespace___2 *user_ns;
		struct file___33 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___24;

struct nsproxy___31 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___30 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___24 *cgroup_ns;
};

struct cgroup_subsys_state___24;

struct cgroup___24;

struct css_set___24 {
	struct cgroup_subsys_state___24 *subsys[14];
	refcount_t refcount;
	struct css_set___24 *dom_cset;
	struct cgroup___24 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___24 *mg_src_cgrp;
	struct cgroup___24 *mg_dst_cgrp;
	struct css_set___24 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___22 {
	struct pmu___22 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___34 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___22 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___32 {
	struct vm_struct___32 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___33 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___31;

struct address_space___31 {
	struct inode___33 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___31 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___31;

struct dev_pagemap___31 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___31 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___31;

struct path___31 {
	struct vfsmount___31 *mnt;
	struct dentry___32 *dentry;
};

struct fown_struct___30 {
	rwlock_t lock;
	struct pid___30 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___33 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___31 f_path;
	struct inode___33 *f_inode;
	const struct file_operations___31 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___30 f_owner;
	const struct cred *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___31 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___31;

struct vm_operations_struct___31 {
	void (*open)(struct vm_area_struct___32 *);
	void (*close)(struct vm_area_struct___32 *);
	int (*may_split)(struct vm_area_struct___32 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___32 *);
	int (*mprotect)(struct vm_area_struct___32 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___31 *);
	vm_fault_t (*huge_fault)(struct vm_fault___31 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___31 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___32 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___31 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___31 *);
	int (*access)(struct vm_area_struct___32 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___32 *);
	int (*set_policy)(struct vm_area_struct___32 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___32 *, long unsigned int);
	struct page___33 * (*find_special_page)(struct vm_area_struct___32 *, long unsigned int);
};

struct core_thread___32 {
	struct task_struct___34 *task;
	struct core_thread___32 *next;
};

struct core_state___32 {
	atomic_t nr_threads;
	struct core_thread___32 dumper;
	struct completion startup;
};

struct vm_fault___31 {
	const struct {
		struct vm_area_struct___32 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___33 *cow_page;
	struct page___33 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___32 prealloc_pte;
};

typedef unsigned int xa_mark_t;

enum xa_lock_type {
	XA_LOCK_IRQ = 1,
	XA_LOCK_BH = 2,
};

struct ida {
	struct xarray xa;
};

struct kernfs_root___31;

struct kernfs_elem_dir___31 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___31 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___31;

struct kernfs_root___31 {
	struct kernfs_node___31 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___31 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___31 {
	struct kernfs_node___31 *target_kn;
};

struct kernfs_ops___31;

struct kernfs_elem_attr___31 {
	const struct kernfs_ops___31 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___31 *notify_next;
};

struct kernfs_node___31 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___31 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___31 dir;
		struct kernfs_elem_symlink___31 symlink;
		struct kernfs_elem_attr___31 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___31;

struct kernfs_ops___31 {
	int (*open)(struct kernfs_open_file___31 *);
	void (*release)(struct kernfs_open_file___31 *);
	int (*seq_show)(struct seq_file___31 *, void *);
	void * (*seq_start)(struct seq_file___31 *, loff_t *);
	void * (*seq_next)(struct seq_file___31 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___31 *, void *);
	ssize_t (*read)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___31 *, struct poll_table_struct___25 *);
	int (*mmap)(struct kernfs_open_file___31 *, struct vm_area_struct___32 *);
};

struct kernfs_syscall_ops___31 {
	int (*show_options)(struct seq_file___31 *, struct kernfs_root___31 *);
	int (*mkdir)(struct kernfs_node___31 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___31 *);
	int (*rename)(struct kernfs_node___31 *, struct kernfs_node___31 *, const char *);
	int (*show_path)(struct seq_file___31 *, struct kernfs_node___31 *, struct kernfs_root___31 *);
};

struct seq_operations___30;

struct seq_file___31 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___30 *op;
	int poll_event;
	const struct file___33 *file;
	void *private;
};

struct kernfs_open_file___31 {
	struct kernfs_node___31 *kn;
	struct file___33 *file;
	struct seq_file___31 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___31 *vm_ops;
};

typedef void (*poll_queue_proc___25)(struct file___33 *, wait_queue_head_t *, struct poll_table_struct___25 *);

struct poll_table_struct___25 {
	poll_queue_proc___25 _qproc;
	__poll_t _key;
};

struct bin_attribute___31;

struct attribute_group___31 {
	const char *name;
	umode_t (*is_visible)(struct kobject___31 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___31 *, struct bin_attribute___31 *, int);
	struct attribute **attrs;
	struct bin_attribute___31 **bin_attrs;
};

struct bin_attribute___31 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___31 * (*f_mapping)();
	ssize_t (*read)(struct file___33 *, struct kobject___31 *, struct bin_attribute___31 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___33 *, struct kobject___31 *, struct bin_attribute___31 *, char *, loff_t, size_t);
	int (*mmap)(struct file___33 *, struct kobject___31 *, struct bin_attribute___31 *, struct vm_area_struct___32 *);
};

struct sysfs_ops___31 {
	ssize_t (*show)(struct kobject___31 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___31 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___31;

struct kset___31 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___31 kobj;
	const struct kset_uevent_ops___31 *uevent_ops;
};

struct kobj_type___31 {
	void (*release)(struct kobject___31 *);
	const struct sysfs_ops___31 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___31 **default_groups;
	const struct kobj_ns_type_operations___2 * (*child_ns_type)(struct kobject___31 *);
	const void * (*namespace)(struct kobject___31 *);
	void (*get_ownership)(struct kobject___31 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___31 {
	int (* const filter)(struct kset___31 *, struct kobject___31 *);
	const char * (* const name)(struct kset___31 *, struct kobject___31 *);
	int (* const uevent)(struct kset___31 *, struct kobject___31 *, struct kobj_uevent_env *);
};

struct wakeup_source___29;

struct device___29;

struct dev_pm_info___29 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___29 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___29 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___29;

struct bus_type___29;

struct device_driver___29;

struct dev_pm_domain___29;

struct device_node___17;

struct fwnode_handle___29;

struct class___29;

struct device___29 {
	struct kobject___31 kobj;
	struct device___29 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___29 *type;
	struct bus_type___29 *bus;
	struct device_driver___29 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___29 power;
	struct dev_pm_domain___29 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___17 *of_node;
	struct fwnode_handle___29 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___29 *class;
	const struct attribute_group___31 **groups;
	void (*release)(struct device___29 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___29 {
	int (*prepare)(struct device___29 *);
	void (*complete)(struct device___29 *);
	int (*suspend)(struct device___29 *);
	int (*resume)(struct device___29 *);
	int (*freeze)(struct device___29 *);
	int (*thaw)(struct device___29 *);
	int (*poweroff)(struct device___29 *);
	int (*restore)(struct device___29 *);
	int (*suspend_late)(struct device___29 *);
	int (*resume_early)(struct device___29 *);
	int (*freeze_late)(struct device___29 *);
	int (*thaw_early)(struct device___29 *);
	int (*poweroff_late)(struct device___29 *);
	int (*restore_early)(struct device___29 *);
	int (*suspend_noirq)(struct device___29 *);
	int (*resume_noirq)(struct device___29 *);
	int (*freeze_noirq)(struct device___29 *);
	int (*thaw_noirq)(struct device___29 *);
	int (*poweroff_noirq)(struct device___29 *);
	int (*restore_noirq)(struct device___29 *);
	int (*runtime_suspend)(struct device___29 *);
	int (*runtime_resume)(struct device___29 *);
	int (*runtime_idle)(struct device___29 *);
};

struct wakeup_source___29 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___29 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___29 {
	struct dev_pm_ops___29 ops;
	int (*start)(struct device___29 *);
	void (*detach)(struct device___29 *, bool);
	int (*activate)(struct device___29 *);
	void (*sync)(struct device___29 *);
	void (*dismiss)(struct device___29 *);
};

struct bus_type___29 {
	const char *name;
	const char *dev_name;
	struct device___29 *dev_root;
	const struct attribute_group___31 **bus_groups;
	const struct attribute_group___31 **dev_groups;
	const struct attribute_group___31 **drv_groups;
	int (*match)(struct device___29 *, struct device_driver___29 *);
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	int (*probe)(struct device___29 *);
	void (*sync_state)(struct device___29 *);
	void (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*online)(struct device___29 *);
	int (*offline)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	int (*num_vf)(struct device___29 *);
	int (*dma_configure)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___29 {
	const char *name;
	struct bus_type___29 *bus;
	struct module___33 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___29 *);
	void (*sync_state)(struct device___29 *);
	int (*remove)(struct device___29 *);
	void (*shutdown)(struct device___29 *);
	int (*suspend)(struct device___29 *, pm_message_t);
	int (*resume)(struct device___29 *);
	const struct attribute_group___31 **groups;
	const struct attribute_group___31 **dev_groups;
	const struct dev_pm_ops___29 *pm;
	void (*coredump)(struct device___29 *);
	struct driver_private *p;
};

struct device_type___29 {
	const char *name;
	const struct attribute_group___31 **groups;
	int (*uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___29 *);
	const struct dev_pm_ops___29 *pm;
};

struct class___29 {
	const char *name;
	struct module___33 *owner;
	const struct attribute_group___31 **class_groups;
	const struct attribute_group___31 **dev_groups;
	struct kobject___31 *dev_kobj;
	int (*dev_uevent)(struct device___29 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___29 *, umode_t *);
	void (*class_release)(struct class___29 *);
	void (*dev_release)(struct device___29 *);
	int (*shutdown_pre)(struct device___29 *);
	const struct kobj_ns_type_operations___2 *ns_type;
	const void * (*namespace)(struct device___29 *);
	void (*get_ownership)(struct device___29 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___29 *pm;
	struct subsys_private *p;
};

struct device_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct device___29 *, struct device_attribute___5 *, char *);
	ssize_t (*store)(struct device___29 *, struct device_attribute___5 *, const char *, size_t);
};

struct fwnode_operations___29;

struct fwnode_handle___29 {
	struct fwnode_handle___29 *secondary;
	const struct fwnode_operations___29 *ops;
	struct device___29 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___14;

struct device_node___17 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___29 fwnode;
	struct property___14 *properties;
	struct property___14 *deadprops;
	struct device_node___17 *parent;
	struct device_node___17 *child;
	struct device_node___17 *sibling;
	struct kobject___31 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___29;

struct fwnode_endpoint___29;

struct fwnode_operations___29 {
	struct fwnode_handle___29 * (*get)(struct fwnode_handle___29 *);
	void (*put)(struct fwnode_handle___29 *);
	bool (*device_is_available)(const struct fwnode_handle___29 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___29 *, const struct device___29 *);
	bool (*property_present)(const struct fwnode_handle___29 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___29 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___29 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___29 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_parent)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_next_child_node)(const struct fwnode_handle___29 *, struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*get_named_child_node)(const struct fwnode_handle___29 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___29 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___29 *);
	struct fwnode_handle___29 * (*graph_get_next_endpoint)(const struct fwnode_handle___29 *, struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*graph_get_remote_endpoint)(const struct fwnode_handle___29 *);
	struct fwnode_handle___29 * (*graph_get_port_parent)(struct fwnode_handle___29 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___29 *, struct fwnode_endpoint___29 *);
	int (*add_links)(struct fwnode_handle___29 *);
};

struct fwnode_endpoint___29 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___29 *local_fwnode;
};

struct fwnode_reference_args___29 {
	struct fwnode_handle___29 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dentry_operations___31;

struct dentry___32 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___32 *d_parent;
	struct qstr d_name;
	struct inode___33 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___31 *d_op;
	struct super_block___32 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___31;

struct inode___33 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___31 *i_op;
	struct super_block___32 *i_sb;
	struct address_space___31 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___31 *i_fop;
		void (*free_inode)(struct inode___33 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___31 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___16 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___31 {
	int (*d_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___32 *, unsigned int);
	int (*d_hash)(const struct dentry___32 *, struct qstr *);
	int (*d_compare)(const struct dentry___32 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___32 *);
	int (*d_init)(struct dentry___32 *);
	void (*d_release)(struct dentry___32 *);
	void (*d_prune)(struct dentry___32 *);
	void (*d_iput)(struct dentry___32 *, struct inode___33 *);
	char * (*d_dname)(struct dentry___32 *, char *, int);
	struct vfsmount___31 * (*d_automount)(struct path___31 *);
	int (*d_manage)(const struct path___31 *, bool);
	struct dentry___32 * (*d_real)(struct dentry___32 *, const struct inode___33 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___31;

struct mem_dqinfo___31 {
	struct quota_format_type___31 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___31;

struct quota_info___31 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___33 *files[3];
	struct mem_dqinfo___31 info[3];
	const struct quota_format_ops___31 *ops[3];
};

struct rcuwait___31 {
	struct task_struct___34 *task;
};

struct percpu_rw_semaphore___31 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___31 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___31 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___31 rw_sem[3];
};

struct super_operations___31;

struct dquot_operations___31;

struct quotactl_ops___31;

struct super_block___32 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___31 *s_type;
	const struct super_operations___31 *s_op;
	const struct dquot_operations___31 *dq_op;
	const struct quotactl_ops___31 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___32 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___31 s_dquot;
	struct sb_writers___31 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___31 *s_d_op;
	int cleancache_poolid;
	struct shrinker___13 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___2 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___31 {
	struct dentry___32 *mnt_root;
	struct super_block___32 *mnt_sb;
	int mnt_flags;
	struct user_namespace___2 *mnt_userns;
};

struct cgroup_subsys___24;

struct cgroup_subsys_state___24 {
	struct cgroup___24 *cgroup;
	struct cgroup_subsys___24 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___24 *parent;
};

struct cgroup_file___24 {
	struct kernfs_node___31 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___24 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___34 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___24;

struct cgroup_rstat_cpu___24;

struct cgroup___24 {
	struct cgroup_subsys_state___24 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___31 *kn;
	struct cgroup_file___24 procs_file;
	struct cgroup_file___24 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___24 *subsys[14];
	struct cgroup_root___24 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___24 *dom_cgrp;
	struct cgroup___24 *old_dom_cgrp;
	struct cgroup_rstat_cpu___24 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___24 psi;
	struct cgroup_bpf___3 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___16;

struct kiocb___31 {
	struct file___33 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___31 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___32 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___33 *ia_file;
};

struct dquot___31 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___32 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___31 {
	int qf_fmt_id;
	const struct quota_format_ops___31 *qf_ops;
	struct module___33 *qf_owner;
	struct quota_format_type___31 *qf_next;
};

struct quota_format_ops___31 {
	int (*check_quota_file)(struct super_block___32 *, int);
	int (*read_file_info)(struct super_block___32 *, int);
	int (*write_file_info)(struct super_block___32 *, int);
	int (*free_file_info)(struct super_block___32 *, int);
	int (*read_dqblk)(struct dquot___31 *);
	int (*commit_dqblk)(struct dquot___31 *);
	int (*release_dqblk)(struct dquot___31 *);
	int (*get_next_id)(struct super_block___32 *, struct kqid *);
};

struct dquot_operations___31 {
	int (*write_dquot)(struct dquot___31 *);
	struct dquot___31 * (*alloc_dquot)(struct super_block___32 *, int);
	void (*destroy_dquot)(struct dquot___31 *);
	int (*acquire_dquot)(struct dquot___31 *);
	int (*release_dquot)(struct dquot___31 *);
	int (*mark_dirty)(struct dquot___31 *);
	int (*write_info)(struct super_block___32 *, int);
	qsize_t * (*get_reserved_space)(struct inode___33 *);
	int (*get_projid)(struct inode___33 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___33 *, qsize_t *);
	int (*get_next_id)(struct super_block___32 *, struct kqid *);
};

struct quotactl_ops___31 {
	int (*quota_on)(struct super_block___32 *, int, int, const struct path___31 *);
	int (*quota_off)(struct super_block___32 *, int);
	int (*quota_enable)(struct super_block___32 *, unsigned int);
	int (*quota_disable)(struct super_block___32 *, unsigned int);
	int (*quota_sync)(struct super_block___32 *, int);
	int (*set_info)(struct super_block___32 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___32 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___32 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___32 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___32 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___32 *, unsigned int);
};

struct wait_page_queue___16 {
	struct page___33 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___16;

struct address_space_operations___31 {
	int (*writepage)(struct page___33 *, struct writeback_control___3 *);
	int (*readpage)(struct file___33 *, struct page___33 *);
	int (*writepages)(struct address_space___31 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___33 *);
	int (*readpages)(struct file___33 *, struct address_space___31 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___16 *);
	int (*write_begin)(struct file___33 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___33 **, void **);
	int (*write_end)(struct file___33 *, struct address_space___31 *, loff_t, unsigned int, unsigned int, struct page___33 *, void *);
	sector_t (*bmap)(struct address_space___31 *, sector_t);
	void (*invalidatepage)(struct page___33 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___33 *, gfp_t);
	void (*freepage)(struct page___33 *);
	ssize_t (*direct_IO)(struct kiocb___31 *, struct iov_iter___16 *);
	int (*migratepage)(struct address_space___31 *, struct page___33 *, struct page___33 *, enum migrate_mode);
	bool (*isolate_page)(struct page___33 *, isolate_mode_t);
	void (*putback_page)(struct page___33 *);
	int (*launder_page)(struct page___33 *);
	int (*is_partially_uptodate)(struct page___33 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___33 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___31 *, struct page___33 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___33 *, sector_t *);
	void (*swap_deactivate)(struct file___33 *);
};

struct readahead_control___16 {
	struct file___33 *file;
	struct address_space___31 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___31 {
	struct dentry___32 * (*lookup)(struct inode___33 *, struct dentry___32 *, unsigned int);
	const char * (*get_link)(struct dentry___32 *, struct inode___33 *, struct delayed_call *);
	int (*permission)(struct user_namespace___2 *, struct inode___33 *, int);
	struct posix_acl * (*get_acl)(struct inode___33 *, int, bool);
	int (*readlink)(struct dentry___32 *, char *, int);
	int (*create)(struct user_namespace___2 *, struct inode___33 *, struct dentry___32 *, umode_t, bool);
	int (*link)(struct dentry___32 *, struct inode___33 *, struct dentry___32 *);
	int (*unlink)(struct inode___33 *, struct dentry___32 *);
	int (*symlink)(struct user_namespace___2 *, struct inode___33 *, struct dentry___32 *, const char *);
	int (*mkdir)(struct user_namespace___2 *, struct inode___33 *, struct dentry___32 *, umode_t);
	int (*rmdir)(struct inode___33 *, struct dentry___32 *);
	int (*mknod)(struct user_namespace___2 *, struct inode___33 *, struct dentry___32 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___2 *, struct inode___33 *, struct dentry___32 *, struct inode___33 *, struct dentry___32 *, unsigned int);
	int (*setattr)(struct user_namespace___2 *, struct dentry___32 *, struct iattr___32 *);
	int (*getattr)(struct user_namespace___2 *, const struct path___31 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___32 *, char *, size_t);
	int (*fiemap)(struct inode___33 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___33 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___33 *, struct dentry___32 *, struct file___33 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___2 *, struct inode___33 *, struct dentry___32 *, umode_t);
	int (*set_acl)(struct user_namespace___2 *, struct inode___33 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___2 *, struct dentry___32 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___32 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___31 {
	void (*fl_copy_lock)(struct file_lock___31 *, struct file_lock___31 *);
	void (*fl_release_private)(struct file_lock___31 *);
};

struct lock_manager_operations___31;

struct file_lock___31 {
	struct file_lock___31 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___33 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___31 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___31 *fl_ops;
	const struct lock_manager_operations___31 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___31 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___31 *);
	int (*lm_grant)(struct file_lock___31 *, int);
	bool (*lm_break)(struct file_lock___31 *);
	int (*lm_change)(struct file_lock___31 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___31 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___31 *);
};

struct fasync_struct___31 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___31 *fa_next;
	struct file___33 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___31 {
	struct inode___33 * (*alloc_inode)(struct super_block___32 *);
	void (*destroy_inode)(struct inode___33 *);
	void (*free_inode)(struct inode___33 *);
	void (*dirty_inode)(struct inode___33 *, int);
	int (*write_inode)(struct inode___33 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___33 *);
	void (*evict_inode)(struct inode___33 *);
	void (*put_super)(struct super_block___32 *);
	int (*sync_fs)(struct super_block___32 *, int);
	int (*freeze_super)(struct super_block___32 *);
	int (*freeze_fs)(struct super_block___32 *);
	int (*thaw_super)(struct super_block___32 *);
	int (*unfreeze_fs)(struct super_block___32 *);
	int (*statfs)(struct dentry___32 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___32 *, int *, char *);
	void (*umount_begin)(struct super_block___32 *);
	int (*show_options)(struct seq_file___31 *, struct dentry___32 *);
	int (*show_devname)(struct seq_file___31 *, struct dentry___32 *);
	int (*show_path)(struct seq_file___31 *, struct dentry___32 *);
	int (*show_stats)(struct seq_file___31 *, struct dentry___32 *);
	ssize_t (*quota_read)(struct super_block___32 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___32 *, int, const char *, size_t, loff_t);
	struct dquot___31 ** (*get_dquots)(struct inode___33 *);
	long int (*nr_cached_objects)(struct super_block___32 *, struct shrink_control___13 *);
	long int (*free_cached_objects)(struct super_block___32 *, struct shrink_control___13 *);
	struct file___33 * (*real_loop)(struct file___33 *);
};

struct dev_pagemap_ops___31 {
	void (*page_free)(struct page___33 *);
	void (*kill)(struct dev_pagemap___31 *);
	void (*cleanup)(struct dev_pagemap___31 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___31 *);
};

struct kernel_param_ops___31 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___31 *);
	int (*get)(char *, const struct kernel_param___31 *);
	void (*free)(void *);
};

struct kparam_array___31;

struct kernel_param___31 {
	const char *name;
	struct module___33 *mod;
	const struct kernel_param_ops___31 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___31 *arr;
	};
};

struct kparam_array___31 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___31 *ops;
	void *elem;
};

struct module_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___31 *, struct module_kobject___31 *, char *);
	ssize_t (*store)(struct module_attribute___31 *, struct module_kobject___31 *, const char *, size_t);
	void (*setup)(struct module___33 *, const char *);
	int (*test)(struct module___33 *);
	void (*free)(struct module___33 *);
};

struct trace_event_class___17;

struct trace_event_call___17 {
	struct list_head list;
	struct trace_event_class___17 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___3 *prog_array;
	int (*perf_perm)(struct trace_event_call___17 *, struct perf_event___22 *);
};

struct cgroup_namespace___24 {
	struct ns_common___3 ns;
	struct user_namespace___2 *user_ns;
	struct ucounts___2 *ucounts;
	struct css_set___24 *root_cset;
};

struct __una_u32 {
	u32 x;
};

struct property___14 {
	char *name;
	int length;
	void *value;
	struct property___14 *next;
	long unsigned int _flags;
	struct bin_attribute___31 attr;
};

struct worker_pool;

struct worker {
	union {
		struct list_head entry;
		struct hlist_node hentry;
	};
	struct work_struct *current_work;
	work_func_t current_func;
	struct pool_workqueue *current_pwq;
	unsigned int current_color;
	struct list_head scheduled;
	struct task_struct___34 *task;
	struct worker_pool *pool;
	struct list_head node;
	long unsigned int last_active;
	unsigned int flags;
	int id;
	int sleeping;
	char desc[24];
	struct workqueue_struct *rescue_wq;
	work_func_t last_func;
};

struct pool_workqueue {
	struct worker_pool *pool;
	struct workqueue_struct *wq;
	int work_color;
	int flush_color;
	int refcnt;
	int nr_in_flight[16];
	int nr_active;
	int max_active;
	struct list_head inactive_works;
	struct list_head pwqs_node;
	struct list_head mayday_node;
	struct work_struct unbound_release_work;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct worker_pool {
	raw_spinlock_t lock;
	int cpu;
	int node;
	int id;
	unsigned int flags;
	long unsigned int watchdog_ts;
	struct list_head worklist;
	int nr_workers;
	int nr_idle;
	struct list_head idle_list;
	struct timer_list idle_timer;
	struct timer_list mayday_timer;
	struct hlist_head busy_hash[64];
	struct worker *manager;
	struct list_head workers;
	struct completion *detach_completion;
	struct ida worker_ida;
	struct workqueue_attrs *attrs;
	struct hlist_node hash_node;
	int refcnt;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_t nr_running;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	POOL_MANAGER_ACTIVE = 1,
	POOL_DISASSOCIATED = 4,
	WORKER_DIE = 2,
	WORKER_IDLE = 4,
	WORKER_PREP = 8,
	WORKER_CPU_INTENSIVE = 64,
	WORKER_UNBOUND = 128,
	WORKER_REBOUND = 256,
	WORKER_NOT_RUNNING = 456,
	NR_STD_WORKER_POOLS = 2,
	UNBOUND_POOL_HASH_ORDER = 6,
	BUSY_WORKER_HASH_ORDER = 6,
	MAX_IDLE_WORKERS_RATIO = 4,
	IDLE_WORKER_TIMEOUT = 75000,
	MAYDAY_INITIAL_TIMEOUT = 2,
	MAYDAY_INTERVAL = 25,
	CREATE_COOLDOWN = 250,
	RESCUER_NICE_LEVEL = 4294967276,
	HIGHPRI_NICE_LEVEL = 4294967276,
	WQ_NAME_LEN = 24,
};

struct wq_flusher {
	struct list_head list;
	int flush_color;
	struct completion done;
};

struct wq_device {
	struct workqueue_struct *wq;
	struct device___29 dev;
};

struct seq_operations___30 {
	void * (*start)(struct seq_file___31 *, loff_t *);
	void (*stop)(struct seq_file___31 *, void *);
	void * (*next)(struct seq_file___31 *, void *, loff_t *);
	int (*show)(struct seq_file___31 *, void *);
};

struct cftype___24;

struct cgroup_subsys___24 {
	struct cgroup_subsys_state___24 * (*css_alloc)(struct cgroup_subsys_state___24 *);
	int (*css_online)(struct cgroup_subsys_state___24 *);
	void (*css_offline)(struct cgroup_subsys_state___24 *);
	void (*css_released)(struct cgroup_subsys_state___24 *);
	void (*css_free)(struct cgroup_subsys_state___24 *);
	void (*css_reset)(struct cgroup_subsys_state___24 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___24 *, int);
	int (*css_extra_stat_show)(struct seq_file___31 *, struct cgroup_subsys_state___24 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___34 *, struct css_set___24 *);
	void (*cancel_fork)(struct task_struct___34 *, struct css_set___24 *);
	void (*fork)(struct task_struct___34 *);
	void (*exit)(struct task_struct___34 *);
	void (*release)(struct task_struct___34 *);
	void (*bind)(struct cgroup_subsys_state___24 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___24 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___24 *dfl_cftypes;
	struct cftype___24 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___24 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___24 *updated_children;
	struct cgroup___24 *updated_next;
};

struct cgroup_root___24 {
	struct kernfs_root___31 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___24 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___24 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___24 *ss;
	struct list_head node;
	struct kernfs_ops___31 *kf_ops;
	int (*open)(struct kernfs_open_file___31 *);
	void (*release)(struct kernfs_open_file___31 *);
	u64 (*read_u64)(struct cgroup_subsys_state___24 *, struct cftype___24 *);
	s64 (*read_s64)(struct cgroup_subsys_state___24 *, struct cftype___24 *);
	int (*seq_show)(struct seq_file___31 *, void *);
	void * (*seq_start)(struct seq_file___31 *, loff_t *);
	void * (*seq_next)(struct seq_file___31 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___31 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___24 *, struct cftype___24 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___24 *, struct cftype___24 *, s64);
	ssize_t (*write)(struct kernfs_open_file___31 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___31 *, struct poll_table_struct___25 *);
};

struct perf_cpu_context___22;

struct perf_output_handle___22;

struct pmu___22 {
	struct list_head entry;
	struct module___33 *module;
	struct device___29 *dev;
	const struct attribute_group___31 **attr_groups;
	const struct attribute_group___31 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___22 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___22 *);
	void (*pmu_disable)(struct pmu___22 *);
	int (*event_init)(struct perf_event___22 *);
	void (*event_mapped)(struct perf_event___22 *, struct mm_struct___33 *);
	void (*event_unmapped)(struct perf_event___22 *, struct mm_struct___33 *);
	int (*add)(struct perf_event___22 *, int);
	void (*del)(struct perf_event___22 *, int);
	void (*start)(struct perf_event___22 *, int);
	void (*stop)(struct perf_event___22 *, int);
	void (*read)(struct perf_event___22 *);
	void (*start_txn)(struct pmu___22 *, unsigned int);
	int (*commit_txn)(struct pmu___22 *);
	void (*cancel_txn)(struct pmu___22 *);
	int (*event_idx)(struct perf_event___22 *);
	void (*sched_task)(struct perf_event_context___22 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___22 *, struct perf_event_context___22 *);
	void * (*setup_aux)(struct perf_event___22 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___22 *, struct perf_output_handle___22 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___22 *);
	int (*aux_output_match)(struct perf_event___22 *);
	int (*filter_match)(struct perf_event___22 *);
	int (*check_period)(struct perf_event___22 *, u64);
};

struct perf_cpu_context___22 {
	struct perf_event_context___22 ctx;
	struct perf_event_context___22 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___22 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___22 **heap;
	struct perf_event___22 *heap_default[2];
};

struct perf_output_handle___22 {
	struct perf_event___22 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___22 {
	struct cgroup_subsys_state___24 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___17 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___17 *);
	};
};

struct trace_event_class___17 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___17 *, enum trace_reg, void *);
	struct trace_event_fields___17 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___17 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___17 *);
};

struct trace_event_file___8;

struct trace_event_buffer___8 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___8 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___8 {
	struct list_head list;
	struct trace_event_call___17 *event_call;
	struct event_filter *filter;
	struct dentry___32 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_workqueue_queue_work {
	struct trace_entry ent;
	void *work;
	void *function;
	u32 __data_loc_workqueue;
	unsigned int req_cpu;
	unsigned int cpu;
	char __data[0];
};

struct trace_event_raw_workqueue_activate_work {
	struct trace_entry ent;
	void *work;
	char __data[0];
};

struct trace_event_raw_workqueue_execute_start {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_raw_workqueue_execute_end {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_data_offsets_workqueue_queue_work {
	u32 workqueue;
};

struct trace_event_data_offsets_workqueue_activate_work {};

struct trace_event_data_offsets_workqueue_execute_start {};

struct trace_event_data_offsets_workqueue_execute_end {};

typedef void (*btf_trace_workqueue_queue_work)(void *, unsigned int, struct pool_workqueue *, struct work_struct *);

typedef void (*btf_trace_workqueue_activate_work)(void *, struct work_struct *);

typedef void (*btf_trace_workqueue_execute_start)(void *, struct work_struct *);

typedef void (*btf_trace_workqueue_execute_end)(void *, struct work_struct *, work_func_t);

struct wq_barrier {
	struct work_struct work;
	struct completion done;
	struct task_struct___34 *task;
};

struct cwt_wait {
	wait_queue_entry_t wait;
	struct work_struct *work;
};

struct apply_wqattrs_ctx {
	struct workqueue_struct *wq;
	struct workqueue_attrs *attrs;
	struct list_head list;
	struct pool_workqueue *dfl_pwq;
	struct pool_workqueue *pwq_tbl[0];
};

struct work_for_cpu {
	struct work_struct work;
	long int (*fn)(void *);
	void *arg;
	long int ret;
};

struct dentry___33;

struct super_block___33;

struct module___34;

struct file_system_type___32 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___33 * (*mount)(struct file_system_type___32 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___33 *);
	struct module___34 *owner;
	struct file_system_type___32 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___34;

struct kiocb___32;

struct iov_iter___17;

struct poll_table_struct___26;

struct vm_area_struct___33;

struct inode___34;

struct file_lock___32;

struct page___34;

struct pipe_inode_info___8;

struct seq_file___32;

struct file_operations___32 {
	struct module___34 *owner;
	loff_t (*llseek)(struct file___34 *, loff_t, int);
	ssize_t (*read)(struct file___34 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___34 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___32 *, struct iov_iter___17 *);
	ssize_t (*write_iter)(struct kiocb___32 *, struct iov_iter___17 *);
	int (*iopoll)(struct kiocb___32 *, bool);
	int (*iterate)(struct file___34 *, struct dir_context *);
	int (*iterate_shared)(struct file___34 *, struct dir_context *);
	__poll_t (*poll)(struct file___34 *, struct poll_table_struct___26 *);
	long int (*unlocked_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___34 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___34 *, struct vm_area_struct___33 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___34 *, struct file___34 *);
	int (*flush)(struct file___34 *, fl_owner_t);
	int (*release)(struct inode___34 *, struct file___34 *);
	int (*fsync)(struct file___34 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___34 *, int);
	int (*lock)(struct file___34 *, int, struct file_lock___32 *);
	ssize_t (*sendpage)(struct file___34 *, struct page___34 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___34 *, long unsigned int);
	int (*flock)(struct file___34 *, int, struct file_lock___32 *);
	ssize_t (*splice_write)(struct pipe_inode_info___8 *, struct file___34 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___34 *, loff_t *, struct pipe_inode_info___8 *, size_t, unsigned int);
	int (*setlease)(struct file___34 *, long int, struct file_lock___32 **, void **);
	long int (*fallocate)(struct file___34 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___32 *, struct file___34 *);
	ssize_t (*copy_file_range)(struct file___34 *, loff_t, struct file___34 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___34 *, loff_t, struct file___34 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___34 *, loff_t, loff_t, int);
};

struct vmacache___33 {
	u64 seqnum;
	struct vm_area_struct___33 *vmas[4];
};

struct page_frag___33 {
	struct page___34 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___23;

struct debug_info___23 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___23 *hbp_break[16];
	struct perf_event___23 *hbp_watch[16];
};

struct thread_struct___23 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___23 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___34;

struct pid___31;

struct cred___2;

struct nsproxy___32;

struct signal_struct___33;

struct bio_list___15;

struct backing_dev_info___14;

struct io_context___16;

struct css_set___25;

struct perf_event_context___23;

struct mem_cgroup___14;

struct request_queue___16;

struct vm_struct___33;

struct task_struct___35 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___35 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___34 *mm;
	struct mm_struct___34 *active_mm;
	struct vmacache___33 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___35 *real_parent;
	struct task_struct___35 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___35 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___31 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___32 *nsproxy;
	struct signal_struct___33 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___35 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___15 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___14 *backing_dev_info;
	struct io_context___16 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___25 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___23 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___8 *splice_pipe;
	struct page_frag___33 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___14 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___14 *active_memcg;
	struct request_queue___16 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___35 *oom_reaper_list;
	struct vm_struct___33 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___23 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___32;

struct kobj_type___32;

struct kernfs_node___32;

struct kobject___32 {
	const char *name;
	struct list_head entry;
	struct kobject___32 *parent;
	struct kset___32 *kset;
	struct kobj_type___32 *ktype;
	struct kernfs_node___32 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___32 {
	struct kobject___32 kobj;
	struct module___34 *mod;
	struct kobject___32 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___32 {
	struct module___34 *mod;
	struct latch_tree_node node;
};

struct module_layout___32 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___32 mtn;
};

struct module_attribute___32;

struct kernel_param___32;

struct trace_event_call___18;

struct module___34 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___32 mkobj;
	struct module_attribute___32 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___32 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___32 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___32 core_layout;
	struct module_layout___32 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___18 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___23 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___35 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___23)(struct perf_event___23 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___23;

struct fasync_struct___32;

struct pid_namespace___31;

struct bpf_prog___4;

struct perf_cgroup___23;

struct perf_event___23 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___23 *group_leader;
	struct pmu___23 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___23 hw;
	struct perf_event_context___23 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___23 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___35 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___32 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___23 *aux_event;
	void (*destroy)(struct perf_event___23 *);
	struct callback_head callback_head;
	struct pid_namespace___31 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___23 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___23 orig_overflow_handler;
	struct bpf_prog___4 *prog;
	u64 bpf_cookie;
	struct trace_event_call___18 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___23 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___34 *pgtable_t___33;

struct address_space___32;

struct page_pool___8;

struct dev_pagemap___32;

struct page___34 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___32 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___8 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___34 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___33 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___34 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___32 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___32;

struct vm_area_struct___33 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___33 *vm_next;
	struct vm_area_struct___33 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___34 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___32 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___34 *vm_file;
	struct file___34 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___33;

struct user_namespace___3;

struct mm_struct___34 {
	struct {
		struct vm_area_struct___33 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___34 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___33 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___35 *owner;
		struct user_namespace___3 *user_ns;
		struct file___34 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___32;

struct address_space___32 {
	struct inode___34 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___32 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___30;

struct page_pool_params___8 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___30 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___8 {
	u32 count;
	struct page___34 *cache[128];
};

struct page_pool___8 {
	struct page_pool_params___8 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___34 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___8 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___32;

struct dev_pagemap___32 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___32 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___32;

struct path___32 {
	struct vfsmount___32 *mnt;
	struct dentry___33 *dentry;
};

struct fown_struct___31 {
	rwlock_t lock;
	struct pid___31 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___34 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___32 f_path;
	struct inode___34 *f_inode;
	const struct file_operations___32 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___31 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___32 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___32;

struct vm_operations_struct___32 {
	void (*open)(struct vm_area_struct___33 *);
	void (*close)(struct vm_area_struct___33 *);
	int (*may_split)(struct vm_area_struct___33 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___33 *);
	int (*mprotect)(struct vm_area_struct___33 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___32 *);
	vm_fault_t (*huge_fault)(struct vm_fault___32 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___32 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___33 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___32 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___32 *);
	int (*access)(struct vm_area_struct___33 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___33 *);
	int (*set_policy)(struct vm_area_struct___33 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___33 *, long unsigned int);
	struct page___34 * (*find_special_page)(struct vm_area_struct___33 *, long unsigned int);
};

struct core_thread___33 {
	struct task_struct___35 *task;
	struct core_thread___33 *next;
};

struct core_state___33 {
	atomic_t nr_threads;
	struct core_thread___33 dumper;
	struct completion startup;
};

struct proc_ns_operations___4;

struct ns_common___4 {
	atomic_long_t stashed;
	const struct proc_ns_operations___4 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___3;

struct user_namespace___3 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___3 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___4 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___3 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___32 {
	const struct {
		struct vm_area_struct___33 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___34 *cow_page;
	struct page___34 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___33 prealloc_pte;
};

struct pglist_data___15;

struct lruvec___15 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___15 *pgdat;
};

struct zone___15 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___15 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___15 {
	struct zone___15 *zone;
	int zone_idx;
};

struct zonelist___15 {
	struct zoneref___15 _zonerefs[321];
};

struct pglist_data___15 {
	struct zone___15 node_zones[5];
	struct zonelist___15 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___35 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___35 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___15 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___14 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___14 *memcg;
};

struct cgroup___25;

struct cgroup_subsys___25;

struct cgroup_subsys_state___25 {
	struct cgroup___25 *cgroup;
	struct cgroup_subsys___25 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___25 *parent;
};

struct cgroup_file___25 {
	struct kernfs_node___32 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___14;

struct mem_cgroup_per_node___14;

struct mem_cgroup___14 {
	struct cgroup_subsys_state___25 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___25 events_file;
	struct cgroup_file___25 events_local_file;
	struct cgroup_file___25 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___14 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___35 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___14 *nodeinfo[0];
	long: 64;
};

struct shrinker___14 {
	long unsigned int (*count_objects)(struct shrinker___14 *, struct shrink_control___14 *);
	long unsigned int (*scan_objects)(struct shrinker___14 *, struct shrink_control___14 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___32 {
	void (*page_free)(struct page___34 *);
	void (*kill)(struct dev_pagemap___32 *);
	void (*cleanup)(struct dev_pagemap___32 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___32 *);
};

struct upid___31 {
	int nr;
	struct pid_namespace___31 *ns;
};

struct pid_namespace___31 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___35 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___31 *parent;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___31 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___31 numbers[1];
};

struct ucounts___3 {
	struct hlist_node node;
	struct user_namespace___3 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___33 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___35 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___35 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___31 *pids[4];
	struct pid___31 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___34 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___2 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct uts_namespace___3;

struct net___6;

struct cgroup_namespace___25;

struct nsproxy___32 {
	atomic_t count;
	struct uts_namespace___3 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___31 *pid_ns_for_children;
	struct net___6 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___25 *cgroup_ns;
};

struct bio___15;

struct bio_list___15 {
	struct bio___15 *head;
	struct bio___15 *tail;
};

struct bdi_writeback___14 {
	struct backing_dev_info___14 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___25 *memcg_css;
	struct cgroup_subsys_state___25 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___14 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___14 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___30 *dev;
	char dev_name[64];
	struct device___30 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___33 *debug_dir;
};

struct io_cq___15;

struct io_context___16 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___15 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___25 {
	struct cgroup_subsys_state___25 *subsys[14];
	refcount_t refcount;
	struct css_set___25 *dom_cset;
	struct cgroup___25 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___25 *mg_src_cgrp;
	struct cgroup___25 *mg_dst_cgrp;
	struct css_set___25 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___23 {
	struct pmu___23 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___35 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___23 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___8;

struct pipe_inode_info___8 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___34 *tmp_page;
	struct fasync_struct___32 *fasync_readers;
	struct fasync_struct___32 *fasync_writers;
	struct pipe_buffer___8 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___15;

struct blk_integrity___15 {
	const struct blk_integrity_profile___15 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___15 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___15 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___15;

struct elevator_queue___15;

struct blk_mq_ops___14;

struct blk_mq_hw_ctx___14;

struct gendisk___15;

struct blkcg_gq___14;

struct blk_mq_tag_set___14;

struct request_queue___16 {
	struct request___15 *last_merge;
	struct elevator_queue___15 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___14 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___14 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___15 *disk;
	struct kobject___32 kobj;
	struct kobject___32 *mq_kobj;
	struct blk_integrity___15 integrity;
	struct device___30 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___14 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___14 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___15 bio_split;
	struct dentry___33 *debugfs_dir;
	struct dentry___33 *sched_debugfs_dir;
	struct dentry___33 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___33 {
	struct vm_struct___33 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___34 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___32;

struct dentry___33 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___33 *d_parent;
	struct qstr d_name;
	struct inode___34 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___32 *d_op;
	struct super_block___33 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___32;

struct inode___34 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___32 *i_op;
	struct super_block___33 *i_sb;
	struct address_space___32 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___14 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___32 *i_fop;
		void (*free_inode)(struct inode___34 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___32 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___8 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___32 {
	int (*d_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___33 *, unsigned int);
	int (*d_hash)(const struct dentry___33 *, struct qstr *);
	int (*d_compare)(const struct dentry___33 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___33 *);
	int (*d_init)(struct dentry___33 *);
	void (*d_release)(struct dentry___33 *);
	void (*d_prune)(struct dentry___33 *);
	void (*d_iput)(struct dentry___33 *, struct inode___34 *);
	char * (*d_dname)(struct dentry___33 *, char *, int);
	struct vfsmount___32 * (*d_automount)(struct path___32 *);
	int (*d_manage)(const struct path___32 *, bool);
	struct dentry___33 * (*d_real)(struct dentry___33 *, const struct inode___34 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___32;

struct mem_dqinfo___32 {
	struct quota_format_type___32 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___32;

struct quota_info___32 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___34 *files[3];
	struct mem_dqinfo___32 info[3];
	const struct quota_format_ops___32 *ops[3];
};

struct rcuwait___32 {
	struct task_struct___35 *task;
};

struct percpu_rw_semaphore___32 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___32 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___32 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___32 rw_sem[3];
};

struct super_operations___32;

struct dquot_operations___32;

struct quotactl_ops___32;

struct block_device___16;

struct super_block___33 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___32 *s_type;
	const struct super_operations___32 *s_op;
	const struct dquot_operations___32 *dq_op;
	const struct quotactl_ops___32 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___33 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___16 *s_bdev;
	struct backing_dev_info___14 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___32 s_dquot;
	struct sb_writers___32 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___32 *s_d_op;
	int cleancache_poolid;
	struct shrinker___14 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___32 {
	struct dentry___33 *mnt_root;
	struct super_block___33 *mnt_sb;
	int mnt_flags;
	struct user_namespace___3 *mnt_userns;
};

struct psi_group___25 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___35 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___4;

struct cgroup_bpf___4 {
	struct bpf_prog_array___4 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___4 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___25;

struct cgroup_rstat_cpu___25;

struct cgroup___25 {
	struct cgroup_subsys_state___25 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___32 *kn;
	struct cgroup_file___25 procs_file;
	struct cgroup_file___25 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___25 *subsys[14];
	struct cgroup_root___25 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___25 *dom_cgrp;
	struct cgroup___25 *old_dom_cgrp;
	struct cgroup_rstat_cpu___25 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___25 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___15 {
	struct request_queue___16 *q;
	struct io_context___16 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___32 {
	struct file___34 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___32 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___33 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___34 *ia_file;
};

struct dquot___32 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___33 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___32 {
	int qf_fmt_id;
	const struct quota_format_ops___32 *qf_ops;
	struct module___34 *qf_owner;
	struct quota_format_type___32 *qf_next;
};

struct quota_format_ops___32 {
	int (*check_quota_file)(struct super_block___33 *, int);
	int (*read_file_info)(struct super_block___33 *, int);
	int (*write_file_info)(struct super_block___33 *, int);
	int (*free_file_info)(struct super_block___33 *, int);
	int (*read_dqblk)(struct dquot___32 *);
	int (*commit_dqblk)(struct dquot___32 *);
	int (*release_dqblk)(struct dquot___32 *);
	int (*get_next_id)(struct super_block___33 *, struct kqid *);
};

struct dquot_operations___32 {
	int (*write_dquot)(struct dquot___32 *);
	struct dquot___32 * (*alloc_dquot)(struct super_block___33 *, int);
	void (*destroy_dquot)(struct dquot___32 *);
	int (*acquire_dquot)(struct dquot___32 *);
	int (*release_dquot)(struct dquot___32 *);
	int (*mark_dirty)(struct dquot___32 *);
	int (*write_info)(struct super_block___33 *, int);
	qsize_t * (*get_reserved_space)(struct inode___34 *);
	int (*get_projid)(struct inode___34 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___34 *, qsize_t *);
	int (*get_next_id)(struct super_block___33 *, struct kqid *);
};

struct quotactl_ops___32 {
	int (*quota_on)(struct super_block___33 *, int, int, const struct path___32 *);
	int (*quota_off)(struct super_block___33 *, int);
	int (*quota_enable)(struct super_block___33 *, unsigned int);
	int (*quota_disable)(struct super_block___33 *, unsigned int);
	int (*quota_sync)(struct super_block___33 *, int);
	int (*set_info)(struct super_block___33 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___33 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___33 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___33 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___33 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___33 *, unsigned int);
};

struct writeback_control___14;

struct address_space_operations___32 {
	int (*writepage)(struct page___34 *, struct writeback_control___14 *);
	int (*readpage)(struct file___34 *, struct page___34 *);
	int (*writepages)(struct address_space___32 *, struct writeback_control___14 *);
	int (*set_page_dirty)(struct page___34 *);
	int (*readpages)(struct file___34 *, struct address_space___32 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___34 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___34 **, void **);
	int (*write_end)(struct file___34 *, struct address_space___32 *, loff_t, unsigned int, unsigned int, struct page___34 *, void *);
	sector_t (*bmap)(struct address_space___32 *, sector_t);
	void (*invalidatepage)(struct page___34 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___34 *, gfp_t);
	void (*freepage)(struct page___34 *);
	ssize_t (*direct_IO)(struct kiocb___32 *, struct iov_iter___17 *);
	int (*migratepage)(struct address_space___32 *, struct page___34 *, struct page___34 *, enum migrate_mode);
	bool (*isolate_page)(struct page___34 *, isolate_mode_t);
	void (*putback_page)(struct page___34 *);
	int (*launder_page)(struct page___34 *);
	int (*is_partially_uptodate)(struct page___34 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___34 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___32 *, struct page___34 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___34 *, sector_t *);
	void (*swap_deactivate)(struct file___34 *);
};

struct writeback_control___14 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___14 *wb;
	struct inode___34 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___17;

struct iov_iter___17 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___17 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___8 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___32 {
	struct dentry___33 * (*lookup)(struct inode___34 *, struct dentry___33 *, unsigned int);
	const char * (*get_link)(struct dentry___33 *, struct inode___34 *, struct delayed_call *);
	int (*permission)(struct user_namespace___3 *, struct inode___34 *, int);
	struct posix_acl * (*get_acl)(struct inode___34 *, int, bool);
	int (*readlink)(struct dentry___33 *, char *, int);
	int (*create)(struct user_namespace___3 *, struct inode___34 *, struct dentry___33 *, umode_t, bool);
	int (*link)(struct dentry___33 *, struct inode___34 *, struct dentry___33 *);
	int (*unlink)(struct inode___34 *, struct dentry___33 *);
	int (*symlink)(struct user_namespace___3 *, struct inode___34 *, struct dentry___33 *, const char *);
	int (*mkdir)(struct user_namespace___3 *, struct inode___34 *, struct dentry___33 *, umode_t);
	int (*rmdir)(struct inode___34 *, struct dentry___33 *);
	int (*mknod)(struct user_namespace___3 *, struct inode___34 *, struct dentry___33 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___3 *, struct inode___34 *, struct dentry___33 *, struct inode___34 *, struct dentry___33 *, unsigned int);
	int (*setattr)(struct user_namespace___3 *, struct dentry___33 *, struct iattr___33 *);
	int (*getattr)(struct user_namespace___3 *, const struct path___32 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___33 *, char *, size_t);
	int (*fiemap)(struct inode___34 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___34 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___34 *, struct dentry___33 *, struct file___34 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___3 *, struct inode___34 *, struct dentry___33 *, umode_t);
	int (*set_acl)(struct user_namespace___3 *, struct inode___34 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___3 *, struct dentry___33 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___33 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___32 {
	void (*fl_copy_lock)(struct file_lock___32 *, struct file_lock___32 *);
	void (*fl_release_private)(struct file_lock___32 *);
};

struct lock_manager_operations___32;

struct file_lock___32 {
	struct file_lock___32 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___34 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___32 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___32 *fl_ops;
	const struct lock_manager_operations___32 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___32 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___32 *);
	int (*lm_grant)(struct file_lock___32 *, int);
	bool (*lm_break)(struct file_lock___32 *);
	int (*lm_change)(struct file_lock___32 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___32 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___32 *);
};

struct fasync_struct___32 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___32 *fa_next;
	struct file___34 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___32 {
	struct inode___34 * (*alloc_inode)(struct super_block___33 *);
	void (*destroy_inode)(struct inode___34 *);
	void (*free_inode)(struct inode___34 *);
	void (*dirty_inode)(struct inode___34 *, int);
	int (*write_inode)(struct inode___34 *, struct writeback_control___14 *);
	int (*drop_inode)(struct inode___34 *);
	void (*evict_inode)(struct inode___34 *);
	void (*put_super)(struct super_block___33 *);
	int (*sync_fs)(struct super_block___33 *, int);
	int (*freeze_super)(struct super_block___33 *);
	int (*freeze_fs)(struct super_block___33 *);
	int (*thaw_super)(struct super_block___33 *);
	int (*unfreeze_fs)(struct super_block___33 *);
	int (*statfs)(struct dentry___33 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___33 *, int *, char *);
	void (*umount_begin)(struct super_block___33 *);
	int (*show_options)(struct seq_file___32 *, struct dentry___33 *);
	int (*show_devname)(struct seq_file___32 *, struct dentry___33 *);
	int (*show_path)(struct seq_file___32 *, struct dentry___33 *);
	int (*show_stats)(struct seq_file___32 *, struct dentry___33 *);
	ssize_t (*quota_read)(struct super_block___33 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___33 *, int, const char *, size_t, loff_t);
	struct dquot___32 ** (*get_dquots)(struct inode___34 *);
	long int (*nr_cached_objects)(struct super_block___33 *, struct shrink_control___14 *);
	long int (*free_cached_objects)(struct super_block___33 *, struct shrink_control___14 *);
	struct file___34 * (*real_loop)(struct file___34 *);
};

struct wakeup_source___30;

struct dev_pm_info___30 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___30 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___30 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___30;

struct bus_type___30;

struct device_driver___30;

struct dev_pm_domain___30;

struct fwnode_handle___30;

struct class___30;

struct attribute_group___32;

struct device___30 {
	struct kobject___32 kobj;
	struct device___30 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___30 *type;
	struct bus_type___30 *bus;
	struct device_driver___30 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___30 power;
	struct dev_pm_domain___30 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___30 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___30 *class;
	const struct attribute_group___32 **groups;
	void (*release)(struct device___30 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___16 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___34 *bd_inode;
	struct super_block___33 *bd_super;
	void *bd_claiming;
	struct device___30 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___32 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___15 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___33 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___26)(struct file___34 *, wait_queue_head_t *, struct poll_table_struct___26 *);

struct poll_table_struct___26 {
	poll_queue_proc___26 _qproc;
	__poll_t _key;
};

struct seq_operations___31;

struct seq_file___32 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___31 *op;
	int poll_event;
	const struct file___34 *file;
	void *private;
};

typedef void bio_end_io_t___15(struct bio___15 *);

struct bio_vec___17 {
	struct page___34 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___15;

struct bio___15 {
	struct bio___15 *bi_next;
	struct block_device___16 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___15 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___14 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___15 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___17 *bi_io_vec;
	struct bio_set___15 *bi_pool;
	struct bio_vec___17 bi_inline_vecs[0];
};

struct uts_namespace___3 {
	struct new_utsname name;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct ns_common___4 ns;
};

struct fib_rules_ops___3;

struct fqdir___5;

struct fib_notifier_ops___3;

struct netns_ipv4___5 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___3 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___4 *fibnl;
	struct sock___4 **icmp_sk;
	struct sock___4 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___4 **tcp_sk;
	struct fqdir___5 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___3 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___3 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___3 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___3;

struct dst_ops___5 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___5 *);
	struct dst_entry___2 * (*check)(struct dst_entry___2 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___2 *);
	unsigned int (*mtu)(const struct dst_entry___2 *);
	u32 * (*cow_metrics)(struct dst_entry___2 *, long unsigned int);
	void (*destroy)(struct dst_entry___2 *);
	void (*ifdown)(struct dst_entry___2 *, struct net_device___8 *, int);
	struct dst_entry___2 * (*negative_advice)(struct dst_entry___2 *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry___2 *, struct sock___4 *, struct sk_buff___4 *, u32, bool);
	void (*redirect)(struct dst_entry___2 *, struct sock___4 *, struct sk_buff___4 *);
	int (*local_out)(struct net___6 *, struct sock___4 *, struct sk_buff___4 *);
	struct neighbour___3 * (*neigh_lookup)(const struct dst_entry___2 *, struct sk_buff___4 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___2 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___5 {
	struct dst_ops___5 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___5 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___3 *fib6_rules_ops;
	struct sock___4 **icmp_sk;
	struct sock___4 *ndisc_sk;
	struct sock___4 *tcp_sk;
	struct sock___4 *igmp_sk;
	struct sock___4 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___3 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___3 *notifier_ops;
	struct fib_notifier_ops___3 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___5 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___5 *fqdir;
};

struct netns_sctp___3 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___4 *ctl_sock;
	struct sock___4 *udp4_sock;
	struct sock___4 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___4 {
	struct sk_buff___4 *next;
	struct sk_buff___4 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___4 {
	struct bpf_prog_array___4 *run_array[2];
	struct bpf_prog___4 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___5 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___4 *nlsk;
	struct sock___4 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___5 xfrm4_dst_ops;
	struct dst_ops___5 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___6 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct idr netns_ids;
	struct ns_common___4 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___4 *rtnl;
	struct sock___4 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___8 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___5 ipv4;
	struct netns_ipv6___5 ipv6;
	struct netns_ieee802154_lowpan___5 ieee802154_lowpan;
	struct netns_sctp___3 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___4 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___5 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___4 *crypto_nlsk;
	struct sock___4 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___25 {
	struct ns_common___4 ns;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct css_set___25 *root_cset;
};

struct nsset___3 {
	unsigned int flags;
	struct nsproxy___32 *nsproxy;
	struct fs_struct *fs;
	const struct cred___2 *cred;
};

struct proc_ns_operations___4 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___4 * (*get)(struct task_struct___35 *);
	void (*put)(struct ns_common___4 *);
	int (*install)(struct nsset___3 *, struct ns_common___4 *);
	struct user_namespace___3 * (*owner)(struct ns_common___4 *);
	struct ns_common___4 * (*get_parent)(struct ns_common___4 *);
};

struct fwnode_operations___30;

struct fwnode_handle___30 {
	struct fwnode_handle___30 *secondary;
	const struct fwnode_operations___30 *ops;
	struct device___30 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___30;

struct fwnode_endpoint___30;

struct fwnode_operations___30 {
	struct fwnode_handle___30 * (*get)(struct fwnode_handle___30 *);
	void (*put)(struct fwnode_handle___30 *);
	bool (*device_is_available)(const struct fwnode_handle___30 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___30 *, const struct device___30 *);
	bool (*property_present)(const struct fwnode_handle___30 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___30 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___30 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___30 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_parent)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_next_child_node)(const struct fwnode_handle___30 *, struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*get_named_child_node)(const struct fwnode_handle___30 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___30 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___30 *);
	struct fwnode_handle___30 * (*graph_get_next_endpoint)(const struct fwnode_handle___30 *, struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*graph_get_remote_endpoint)(const struct fwnode_handle___30 *);
	struct fwnode_handle___30 * (*graph_get_port_parent)(struct fwnode_handle___30 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___30 *, struct fwnode_endpoint___30 *);
	int (*add_links)(struct fwnode_handle___30 *);
};

struct fwnode_endpoint___30 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___30 *local_fwnode;
};

struct fwnode_reference_args___30 {
	struct fwnode_handle___30 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___32;

struct kernfs_elem_dir___32 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___32 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___32;

struct kernfs_root___32 {
	struct kernfs_node___32 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___32 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___32 {
	struct kernfs_node___32 *target_kn;
};

struct kernfs_ops___32;

struct kernfs_elem_attr___32 {
	const struct kernfs_ops___32 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___32 *notify_next;
};

struct kernfs_node___32 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___32 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___32 dir;
		struct kernfs_elem_symlink___32 symlink;
		struct kernfs_elem_attr___32 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___32;

struct kernfs_ops___32 {
	int (*open)(struct kernfs_open_file___32 *);
	void (*release)(struct kernfs_open_file___32 *);
	int (*seq_show)(struct seq_file___32 *, void *);
	void * (*seq_start)(struct seq_file___32 *, loff_t *);
	void * (*seq_next)(struct seq_file___32 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___32 *, void *);
	ssize_t (*read)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___32 *, struct poll_table_struct___26 *);
	int (*mmap)(struct kernfs_open_file___32 *, struct vm_area_struct___33 *);
};

struct kernfs_syscall_ops___32 {
	int (*show_options)(struct seq_file___32 *, struct kernfs_root___32 *);
	int (*mkdir)(struct kernfs_node___32 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___32 *);
	int (*rename)(struct kernfs_node___32 *, struct kernfs_node___32 *, const char *);
	int (*show_path)(struct seq_file___32 *, struct kernfs_node___32 *, struct kernfs_root___32 *);
};

struct kernfs_open_file___32 {
	struct kernfs_node___32 *kn;
	struct file___34 *file;
	struct seq_file___32 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___32 *vm_ops;
};

struct kobj_ns_type_operations___3 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___4 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___6 *net;
} possible_net_t___4;

struct proto___3;

struct sock_common___3 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___3 *skc_prot;
	possible_net_t___4 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___4 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___3 {
	struct cgroup___25 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___3;

struct socket_wq___3;

struct socket___3;

struct sock___4 {
	struct sock_common___3 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___4 sk_error_queue;
	struct sk_buff___4 *sk_rx_skb_cache;
	struct sk_buff_head___4 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___4 *head;
		struct sk_buff___4 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___3 *sk_filter;
	union {
		struct socket_wq___3 *sk_wq;
		struct socket_wq___3 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___2 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___2 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___4 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___4 *sk_tx_skb_cache;
	struct sk_buff_head___4 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___33 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___3 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___31 *sk_peer_pid;
	const struct cred___2 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___3 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___3 sk_cgrp_data;
	struct mem_cgroup___14 *sk_memcg;
	void (*sk_state_change)(struct sock___4 *);
	void (*sk_data_ready)(struct sock___4 *);
	void (*sk_write_space)(struct sock___4 *);
	void (*sk_error_report)(struct sock___4 *);
	int (*sk_backlog_rcv)(struct sock___4 *, struct sk_buff___4 *);
	struct sk_buff___4 * (*sk_validate_xmit_skb)(struct sock___4 *, struct net_device___8 *, struct sk_buff___4 *);
	void (*sk_destruct)(struct sock___4 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___32;

struct attribute_group___32 {
	const char *name;
	umode_t (*is_visible)(struct kobject___32 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___32 *, struct bin_attribute___32 *, int);
	struct attribute **attrs;
	struct bin_attribute___32 **bin_attrs;
};

struct bin_attribute___32 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___32 * (*f_mapping)();
	ssize_t (*read)(struct file___34 *, struct kobject___32 *, struct bin_attribute___32 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___34 *, struct kobject___32 *, struct bin_attribute___32 *, char *, loff_t, size_t);
	int (*mmap)(struct file___34 *, struct kobject___32 *, struct bin_attribute___32 *, struct vm_area_struct___33 *);
};

struct sysfs_ops___32 {
	ssize_t (*show)(struct kobject___32 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___32 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___32;

struct kset___32 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___32 kobj;
	const struct kset_uevent_ops___32 *uevent_ops;
};

struct kobj_type___32 {
	void (*release)(struct kobject___32 *);
	const struct sysfs_ops___32 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___32 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___32 *);
	const void * (*namespace)(struct kobject___32 *);
	void (*get_ownership)(struct kobject___32 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___32 {
	int (* const filter)(struct kset___32 *, struct kobject___32 *);
	const char * (* const name)(struct kset___32 *, struct kobject___32 *);
	int (* const uevent)(struct kset___32 *, struct kobject___32 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___32 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___32 *);
	int (*get)(char *, const struct kernel_param___32 *);
	void (*free)(void *);
};

struct kparam_array___32;

struct kernel_param___32 {
	const char *name;
	struct module___34 *mod;
	const struct kernel_param_ops___32 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___32 *arr;
	};
};

struct kparam_array___32 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___32 *ops;
	void *elem;
};

struct module_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___32 *, struct module_kobject___32 *, char *);
	ssize_t (*store)(struct module_attribute___32 *, struct module_kobject___32 *, const char *, size_t);
	void (*setup)(struct module___34 *, const char *);
	int (*test)(struct module___34 *);
	void (*free)(struct module___34 *);
};

struct trace_event_class___18;

struct trace_event_call___18 {
	struct list_head list;
	struct trace_event_class___18 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___18 *, struct perf_event___23 *);
};

struct msghdr___3 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___17 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___32 *msg_iocb;
};

struct seq_operations___31 {
	void * (*start)(struct seq_file___32 *, loff_t *);
	void (*stop)(struct seq_file___32 *, void *);
	void * (*next)(struct seq_file___32 *, void *, loff_t *);
	int (*show)(struct seq_file___32 *, void *);
};

struct sk_buff___4 {
	union {
		struct {
			struct sk_buff___4 *next;
			struct sk_buff___4 *prev;
			union {
				struct net_device___8 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___4 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___4 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___5;

struct fqdir___5 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___5 *f;
	struct net___6 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___5;

struct inet_frags___5 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___5 *, const void *);
	void (*destructor)(struct inet_frag_queue___5 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___5 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___4 *fragments_tail;
	struct sk_buff___4 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___5 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___3;

struct fib_lookup_arg___3;

struct fib_rules_ops___3 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___3 *, struct flowi *, int, struct fib_lookup_arg___3 *);
	bool (*suppress)(struct fib_rule___3 *, int, struct fib_lookup_arg___3 *);
	int (*match)(struct fib_rule___3 *, struct flowi *, int);
	int (*configure)(struct fib_rule___3 *, struct sk_buff___4 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___3 *);
	int (*compare)(struct fib_rule___3 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___3 *, struct sk_buff___4 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___3 *);
	void (*flush_cache)(struct fib_rules_ops___3 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___34 *owner;
	struct net___6 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___3 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___6 *);
	int (*fib_dump)(struct net___6 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___34 *owner;
	struct callback_head rcu;
};

struct dst_entry___2 {
	struct net_device___8 *dev;
	struct dst_ops___5 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___4 *);
	int (*output)(struct net___6 *, struct sock___4 *, struct sk_buff___4 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___4(struct sk_buff___4 **);

struct bpf_xdp_entity___4 {
	struct bpf_prog___4 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___4;

struct net_device_ops___4;

struct xfrmdev_ops___4;

struct header_ops___4;

struct netdev_rx_queue___4;

struct mini_Qdisc___4;

struct netdev_queue___4;

struct Qdisc___4;

struct rtnl_link_ops___4;

struct dcbnl_rtnl_ops___4;

struct net_device___8 {
	char name[16];
	struct netdev_name_node___4 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___4 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___4 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___4 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___32 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___4 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___4 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___4 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___4 *miniq_ingress;
	struct netdev_queue___4 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___4 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___4 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___4 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___4 = 0,
		NETREG_REGISTERED___4 = 1,
		NETREG_UNREGISTERING___4 = 2,
		NETREG_UNREGISTERED___4 = 3,
		NETREG_RELEASED___4 = 4,
		NETREG_DUMMY___4 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___4 = 0,
		RTNL_LINK_INITIALIZING___4 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___8 *);
	struct netpoll_info *npinfo;
	possible_net_t___4 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___30 dev;
	const struct attribute_group___32 *sysfs_groups[4];
	const struct attribute_group___32 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___4 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___4 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___4 xdp_state[3];
	long: 64;
};

struct neigh_table___3;

struct neigh_ops___3;

struct neighbour___3 {
	struct neighbour___3 *next;
	struct neigh_table___3 *tbl;
	struct neigh_parms___2 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___4 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___3 *, struct sk_buff___4 *);
	const struct neigh_ops___3 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___8 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___4 {
	struct bpf_prog___4 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___4 {
	struct callback_head rcu;
	struct bpf_prog_array_item___4 items[0];
};

struct bpf_prog_aux___4;

struct bpf_prog___4 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___4 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct socket_wq___3 {
	wait_queue_head_t wait;
	struct fasync_struct___32 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___3;

struct socket___3 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___34 *file;
	struct sock___4 *sk;
	const struct proto_ops___3 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___3 wq;
};

typedef int (*sk_read_actor_t___3)(read_descriptor_t *, struct sk_buff___4 *, unsigned int, size_t);

struct proto_ops___3 {
	int family;
	struct module___34 *owner;
	int (*release)(struct socket___3 *);
	int (*bind)(struct socket___3 *, struct sockaddr *, int);
	int (*connect)(struct socket___3 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___3 *, struct socket___3 *);
	int (*accept)(struct socket___3 *, struct socket___3 *, int, bool);
	int (*getname)(struct socket___3 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___34 *, struct socket___3 *, struct poll_table_struct___26 *);
	int (*ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___3 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___3 *, void *, bool, bool);
	int (*listen)(struct socket___3 *, int);
	int (*shutdown)(struct socket___3 *, int);
	int (*setsockopt)(struct socket___3 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___3 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___32 *, struct socket___3 *);
	int (*sendmsg)(struct socket___3 *, struct msghdr___3 *, size_t);
	int (*recvmsg)(struct socket___3 *, struct msghdr___3 *, size_t, int);
	int (*mmap)(struct file___34 *, struct socket___3 *, struct vm_area_struct___33 *);
	ssize_t (*sendpage)(struct socket___3 *, struct page___34 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___3 *, loff_t *, struct pipe_inode_info___8 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___4 *, int);
	int (*peek_len)(struct socket___3 *);
	int (*read_sock)(struct sock___4 *, read_descriptor_t *, sk_read_actor_t___3);
	int (*sendpage_locked)(struct sock___4 *, struct page___34 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___4 *, struct msghdr___3 *, size_t);
	int (*set_rcvlowat)(struct sock___4 *, int);
};

struct dev_pm_ops___30 {
	int (*prepare)(struct device___30 *);
	void (*complete)(struct device___30 *);
	int (*suspend)(struct device___30 *);
	int (*resume)(struct device___30 *);
	int (*freeze)(struct device___30 *);
	int (*thaw)(struct device___30 *);
	int (*poweroff)(struct device___30 *);
	int (*restore)(struct device___30 *);
	int (*suspend_late)(struct device___30 *);
	int (*resume_early)(struct device___30 *);
	int (*freeze_late)(struct device___30 *);
	int (*thaw_early)(struct device___30 *);
	int (*poweroff_late)(struct device___30 *);
	int (*restore_early)(struct device___30 *);
	int (*suspend_noirq)(struct device___30 *);
	int (*resume_noirq)(struct device___30 *);
	int (*freeze_noirq)(struct device___30 *);
	int (*thaw_noirq)(struct device___30 *);
	int (*poweroff_noirq)(struct device___30 *);
	int (*restore_noirq)(struct device___30 *);
	int (*runtime_suspend)(struct device___30 *);
	int (*runtime_resume)(struct device___30 *);
	int (*runtime_idle)(struct device___30 *);
};

struct wakeup_source___30 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___30 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___30 {
	struct dev_pm_ops___30 ops;
	int (*start)(struct device___30 *);
	void (*detach)(struct device___30 *, bool);
	int (*activate)(struct device___30 *);
	void (*sync)(struct device___30 *);
	void (*dismiss)(struct device___30 *);
};

struct bus_type___30 {
	const char *name;
	const char *dev_name;
	struct device___30 *dev_root;
	const struct attribute_group___32 **bus_groups;
	const struct attribute_group___32 **dev_groups;
	const struct attribute_group___32 **drv_groups;
	int (*match)(struct device___30 *, struct device_driver___30 *);
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	int (*probe)(struct device___30 *);
	void (*sync_state)(struct device___30 *);
	void (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*online)(struct device___30 *);
	int (*offline)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	int (*num_vf)(struct device___30 *);
	int (*dma_configure)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___30 {
	const char *name;
	struct bus_type___30 *bus;
	struct module___34 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___30 *);
	void (*sync_state)(struct device___30 *);
	int (*remove)(struct device___30 *);
	void (*shutdown)(struct device___30 *);
	int (*suspend)(struct device___30 *, pm_message_t);
	int (*resume)(struct device___30 *);
	const struct attribute_group___32 **groups;
	const struct attribute_group___32 **dev_groups;
	const struct dev_pm_ops___30 *pm;
	void (*coredump)(struct device___30 *);
	struct driver_private *p;
};

struct device_type___30 {
	const char *name;
	const struct attribute_group___32 **groups;
	int (*uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___30 *);
	const struct dev_pm_ops___30 *pm;
};

struct class___30 {
	const char *name;
	struct module___34 *owner;
	const struct attribute_group___32 **class_groups;
	const struct attribute_group___32 **dev_groups;
	struct kobject___32 *dev_kobj;
	int (*dev_uevent)(struct device___30 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___30 *, umode_t *);
	void (*class_release)(struct class___30 *);
	void (*dev_release)(struct device___30 *);
	int (*shutdown_pre)(struct device___30 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___30 *);
	void (*get_ownership)(struct device___30 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___30 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___8;

struct pipe_buffer___8 {
	struct page___34 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___8 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___8 {
	int (*confirm)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	void (*release)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	bool (*try_steal)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
	bool (*get)(struct pipe_inode_info___8 *, struct pipe_buffer___8 *);
};

struct fd___5 {
	struct file___34 *file;
	unsigned int flags;
};

struct bpf_iter_aux_info___4;

typedef int (*bpf_iter_init_seq_priv_t___4)(void *, struct bpf_iter_aux_info___4 *);

struct bpf_map___4;

struct bpf_iter_aux_info___4 {
	struct bpf_map___4 *map;
};

struct bpf_iter_seq_info___4 {
	const struct seq_operations___31 *seq_ops;
	bpf_iter_init_seq_priv_t___4 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___4 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___4 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___4 *, struct file___34 *);
	void (*map_free)(struct bpf_map___4 *);
	int (*map_get_next_key)(struct bpf_map___4 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___4 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___4 *, void *);
	int (*map_lookup_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___4 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___4 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___4 *, void *);
	int (*map_update_elem)(struct bpf_map___4 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___4 *, void *);
	int (*map_push_elem)(struct bpf_map___4 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___4 *, void *);
	int (*map_peek_elem)(struct bpf_map___4 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___4 *, struct file___34 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___4 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___4 *, void *, struct seq_file___32 *);
	int (*map_check_btf)(const struct bpf_map___4 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___4 *, struct bpf_prog_aux___4 *);
	void (*map_poke_untrack)(struct bpf_map___4 *, struct bpf_prog_aux___4 *);
	void (*map_poke_run)(struct bpf_map___4 *, u32, struct bpf_prog___4 *, struct bpf_prog___4 *);
	int (*map_direct_value_addr)(const struct bpf_map___4 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___4 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___4 *, struct vm_area_struct___33 *);
	__poll_t (*map_poll)(struct bpf_map___4 *, struct file___34 *, struct poll_table_struct___26 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___4 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___4 *, const struct bpf_map___4 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___4 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___4 *iter_seq_info;
};

struct bpf_map___4 {
	const struct bpf_map_ops___4 *ops;
	struct bpf_map___4 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___14 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___4;

struct bpf_jit_poke_descriptor___4;

struct bpf_prog_ops___4;

struct btf_mod_pair___4;

struct bpf_prog_offload___4;

struct bpf_prog_aux___4 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___4 *dst_prog;
	struct bpf_trampoline___4 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___4 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___4 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___4 *ops;
	struct bpf_map___4 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___4 *used_btfs;
	struct bpf_prog___4 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___4 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___4 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___4;

struct bpf_map_dev_ops___4 {
	int (*map_get_next_key)(struct bpf_offloaded_map___4 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___4 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___4 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___4 *, void *);
};

struct bpf_offloaded_map___4 {
	struct bpf_map___4 map;
	struct net_device___8 *netdev;
	const struct bpf_map_dev_ops___4 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___4 {
	int (*test_run)(struct bpf_prog___4 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___4 {
	struct bpf_prog___4 *prog;
	struct net_device___8 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___4 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___4 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___34 *mod;
};

struct bpf_jit_poke_descriptor___4 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___4 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___4 {
	struct btf *btf;
	struct module___34 *module;
};

struct cftype___25;

struct cgroup_subsys___25 {
	struct cgroup_subsys_state___25 * (*css_alloc)(struct cgroup_subsys_state___25 *);
	int (*css_online)(struct cgroup_subsys_state___25 *);
	void (*css_offline)(struct cgroup_subsys_state___25 *);
	void (*css_released)(struct cgroup_subsys_state___25 *);
	void (*css_free)(struct cgroup_subsys_state___25 *);
	void (*css_reset)(struct cgroup_subsys_state___25 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___25 *, int);
	int (*css_extra_stat_show)(struct seq_file___32 *, struct cgroup_subsys_state___25 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___35 *, struct css_set___25 *);
	void (*cancel_fork)(struct task_struct___35 *, struct css_set___25 *);
	void (*fork)(struct task_struct___35 *);
	void (*exit)(struct task_struct___35 *);
	void (*release)(struct task_struct___35 *);
	void (*bind)(struct cgroup_subsys_state___25 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___25 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___25 *dfl_cftypes;
	struct cftype___25 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___25 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___25 *updated_children;
	struct cgroup___25 *updated_next;
};

struct cgroup_root___25 {
	struct kernfs_root___32 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___25 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___25 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___25 *ss;
	struct list_head node;
	struct kernfs_ops___32 *kf_ops;
	int (*open)(struct kernfs_open_file___32 *);
	void (*release)(struct kernfs_open_file___32 *);
	u64 (*read_u64)(struct cgroup_subsys_state___25 *, struct cftype___25 *);
	s64 (*read_s64)(struct cgroup_subsys_state___25 *, struct cftype___25 *);
	int (*seq_show)(struct seq_file___32 *, void *);
	void * (*seq_start)(struct seq_file___32 *, loff_t *);
	void * (*seq_next)(struct seq_file___32 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___32 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___25 *, struct cftype___25 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___25 *, struct cftype___25 *, s64);
	ssize_t (*write)(struct kernfs_open_file___32 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___32 *, struct poll_table_struct___26 *);
};

struct perf_cpu_context___23;

struct perf_output_handle___23;

struct pmu___23 {
	struct list_head entry;
	struct module___34 *module;
	struct device___30 *dev;
	const struct attribute_group___32 **attr_groups;
	const struct attribute_group___32 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___23 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___23 *);
	void (*pmu_disable)(struct pmu___23 *);
	int (*event_init)(struct perf_event___23 *);
	void (*event_mapped)(struct perf_event___23 *, struct mm_struct___34 *);
	void (*event_unmapped)(struct perf_event___23 *, struct mm_struct___34 *);
	int (*add)(struct perf_event___23 *, int);
	void (*del)(struct perf_event___23 *, int);
	void (*start)(struct perf_event___23 *, int);
	void (*stop)(struct perf_event___23 *, int);
	void (*read)(struct perf_event___23 *);
	void (*start_txn)(struct pmu___23 *, unsigned int);
	int (*commit_txn)(struct pmu___23 *);
	void (*cancel_txn)(struct pmu___23 *);
	int (*event_idx)(struct perf_event___23 *);
	void (*sched_task)(struct perf_event_context___23 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___23 *, struct perf_event_context___23 *);
	void * (*setup_aux)(struct perf_event___23 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___23 *, struct perf_output_handle___23 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___23 *);
	int (*aux_output_match)(struct perf_event___23 *);
	int (*filter_match)(struct perf_event___23 *);
	int (*check_period)(struct perf_event___23 *, u64);
};

struct perf_cpu_context___23 {
	struct perf_event_context___23 ctx;
	struct perf_event_context___23 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___23 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___23 **heap;
	struct perf_event___23 *heap_default[2];
};

struct perf_output_handle___23 {
	struct perf_event___23 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___23 {
	struct cgroup_subsys_state___25 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___18 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___18 *);
	};
};

struct trace_event_class___18 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___18 *, enum trace_reg, void *);
	struct trace_event_fields___18 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___18 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___18 *);
};

struct syscall_metadata___7 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___18 *enter_event;
	struct trace_event_call___18 *exit_event;
};

struct dcbnl_rtnl_ops___4 {
	int (*ieee_getets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___8 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___8 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___8 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___8 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___8 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___8 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___8 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___8 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___8 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___8 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___8 *);
	u8 (*setstate)(struct net_device___8 *, u8);
	void (*getpermhwaddr)(struct net_device___8 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___8 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___8 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___8 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___8 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___8 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___8 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___8 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___8 *, int, u8 *);
	void (*setpfccfg)(struct net_device___8 *, int, u8);
	void (*getpfccfg)(struct net_device___8 *, int, u8 *);
	u8 (*setall)(struct net_device___8 *);
	u8 (*getcap)(struct net_device___8 *, int, u8 *);
	int (*getnumtcs)(struct net_device___8 *, int, u8 *);
	int (*setnumtcs)(struct net_device___8 *, int, u8);
	u8 (*getpfcstate)(struct net_device___8 *);
	void (*setpfcstate)(struct net_device___8 *, u8);
	void (*getbcncfg)(struct net_device___8 *, int, u32 *);
	void (*setbcncfg)(struct net_device___8 *, int, u32);
	void (*getbcnrp)(struct net_device___8 *, int, u8 *);
	void (*setbcnrp)(struct net_device___8 *, int, u8);
	int (*setapp)(struct net_device___8 *, u8, u16, u8);
	int (*getapp)(struct net_device___8 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___8 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___8 *, int, u8);
	u8 (*getdcbx)(struct net_device___8 *);
	u8 (*setdcbx)(struct net_device___8 *, u8);
	int (*peer_getappinfo)(struct net_device___8 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___8 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___8 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___8 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___8 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___8 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___4 {
	struct net_device___8 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___4 {
	struct net_device___8 *dev;
};

struct xdp_buff___4 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___4 *rxq;
	struct xdp_txq_info___4 *txq;
	u32 frame_sz;
};

struct xdp_frame___4 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___8 *dev_rx;
};

struct netlink_callback___4 {
	struct sk_buff___4 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___4 *, struct netlink_callback___4 *);
	int (*done)(struct netlink_callback___4 *);
	void *data;
	struct module___34 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___4 {
	int (*create)(struct sk_buff___4 *, struct net_device___8 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___4 *, unsigned char *);
	int (*cache)(const struct neighbour___3 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___8 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___4 *);
};

struct netdev_queue___4 {
	struct net_device___8 *dev;
	struct Qdisc___4 *qdisc;
	struct Qdisc___4 *qdisc_sleeping;
	struct kobject___32 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___8 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___4 {
	struct sk_buff___4 *head;
	struct sk_buff___4 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___4;

struct Qdisc___4 {
	int (*enqueue)(struct sk_buff___4 *, struct Qdisc___4 *, struct sk_buff___4 **);
	struct sk_buff___4 * (*dequeue)(struct Qdisc___4 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___4 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___4 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___4 gso_skb;
	struct qdisc_skb_head___4 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___4 *next_sched;
	struct sk_buff_head___4 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___4 {
	struct xdp_rxq_info___4 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___32 kobj;
	struct net_device___8 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___4 {
	enum net_device_path_type type;
	const struct net_device___8 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___4 = 0,
				DEV_PATH_BR_VLAN_TAG___4 = 1,
				DEV_PATH_BR_VLAN_UNTAG___4 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___4 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___4 {
	const struct net_device___8 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___4 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___4 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___4 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___4 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___4 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___4 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___8 *dev;
	const char *name;
};

struct net_device_ops___4 {
	int (*ndo_init)(struct net_device___8 *);
	void (*ndo_uninit)(struct net_device___8 *);
	int (*ndo_open)(struct net_device___8 *);
	int (*ndo_stop)(struct net_device___8 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___4 *, struct net_device___8 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___4 *, struct net_device___8 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___8 *, struct sk_buff___4 *, struct net_device___8 *);
	void (*ndo_change_rx_flags)(struct net_device___8 *, int);
	void (*ndo_set_rx_mode)(struct net_device___8 *);
	int (*ndo_set_mac_address)(struct net_device___8 *, void *);
	int (*ndo_validate_addr)(struct net_device___8 *);
	int (*ndo_do_ioctl)(struct net_device___8 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___8 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___8 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___8 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___8 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___8 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___8 *, int);
	int (*ndo_neigh_setup)(struct net_device___8 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___8 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___8 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___8 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___8 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___8 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___8 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___8 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___8 *);
	int (*ndo_netpoll_setup)(struct net_device___8 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___8 *);
	int (*ndo_set_vf_mac)(struct net_device___8 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___8 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___8 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___8 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___8 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___8 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___8 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___8 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___8 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___8 *, int, struct sk_buff___4 *);
	int (*ndo_get_vf_guid)(struct net_device___8 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___8 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___8 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___8 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___8 *);
	int (*ndo_fcoe_disable)(struct net_device___8 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___8 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___8 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___8 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___8 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___8 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___8 *, const struct sk_buff___4 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___8 *, struct net_device___8 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___8 *, struct net_device___8 *);
	struct net_device___8 * (*ndo_get_xmit_slave)(struct net_device___8 *, struct sk_buff___4 *, bool);
	struct net_device___8 * (*ndo_sk_get_lower_dev)(struct net_device___8 *, struct sock___4 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___8 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___8 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___8 *, struct neighbour___3 *);
	void (*ndo_neigh_destroy)(struct net_device___8 *, struct neighbour___3 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___4 *, struct netlink_callback___4 *, struct net_device___8 *, struct net_device___8 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___4 *, struct nlattr **, struct net_device___8 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___8 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___4 *, u32, u32, struct net_device___8 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___8 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___8 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___8 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___8 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___8 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___8 *, struct net_device___8 *);
	void (*ndo_dfwd_del_station)(struct net_device___8 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___8 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___8 *);
	int (*ndo_change_proto_down)(struct net_device___8 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___8 *, struct sk_buff___4 *);
	void (*ndo_set_rx_headroom)(struct net_device___8 *, int);
	int (*ndo_bpf)(struct net_device___8 *, struct netdev_bpf___4 *);
	int (*ndo_xdp_xmit)(struct net_device___8 *, int, struct xdp_frame___4 **, u32);
	struct net_device___8 * (*ndo_xdp_get_xmit_slave)(struct net_device___8 *, struct xdp_buff___4 *);
	int (*ndo_xsk_wakeup)(struct net_device___8 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___8 *);
	int (*ndo_tunnel_ctl)(struct net_device___8 *, struct ip_tunnel_parm *, int);
	struct net_device___8 * (*ndo_get_peer_dev)(struct net_device___8 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___4 *, struct net_device_path___4 *);
};

struct neigh_parms___2 {
	possible_net_t___4 net;
	struct net_device___8 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___3 *);
	struct neigh_table___3 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct tcf_proto___4;

struct tcf_block___4;

struct mini_Qdisc___4 {
	struct tcf_proto___4 *filter_list;
	struct tcf_block___4 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___4 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___8 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___8 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___6 *, struct net_device___8 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___8 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___8 *, struct list_head *);
	size_t (*get_size)(const struct net_device___8 *);
	int (*fill_info)(struct sk_buff___4 *, const struct net_device___8 *);
	size_t (*get_xstats_size)(const struct net_device___8 *);
	int (*fill_xstats)(struct sk_buff___4 *, const struct net_device___8 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___8 *, struct net_device___8 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___8 *, const struct net_device___8 *);
	int (*fill_slave_info)(struct sk_buff___4 *, const struct net_device___8 *, const struct net_device___8 *);
	struct net___6 * (*get_link_net)(const struct net_device___8 *);
	size_t (*get_linkxstats_size)(const struct net_device___8 *, int);
	int (*fill_linkxstats)(struct sk_buff___4 *, const struct net_device___8 *, int *, int);
};

struct block_device_operations___15;

struct gendisk___15 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___16 *part0;
	const struct block_device_operations___15 *fops;
	struct request_queue___16 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___14 *bdi;
	struct kobject___32 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___32 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___15 {
	struct bio___15 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___17 *bip_vec;
	struct bio_vec___17 bip_inline_vecs[0];
};

struct blkcg___14;

struct blkg_policy_data___14;

struct blkcg_gq___14 {
	struct request_queue___16 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___14 *blkcg;
	struct blkcg_gq___14 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___14 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___15 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___15(struct request___15 *);

typedef void integrity_complete_fn___15(struct request___15 *, unsigned int);

struct blk_integrity_profile___15 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___15 *prepare_fn;
	integrity_complete_fn___15 *complete_fn;
	const char *name;
};

struct block_device_operations___15 {
	blk_qc_t (*submit_bio)(struct bio___15 *);
	int (*open)(struct block_device___16 *, fmode_t);
	void (*release)(struct gendisk___15 *, fmode_t);
	int (*rw_page)(struct block_device___16 *, sector_t, struct page___34 *, unsigned int);
	int (*ioctl)(struct block_device___16 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___16 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___15 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___15 *);
	int (*getgeo)(struct block_device___16 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___16 *, bool);
	void (*swap_slot_free_notify)(struct block_device___16 *, long unsigned int);
	int (*report_zones)(struct gendisk___15 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___15 *, umode_t *);
	struct module___34 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___15 *, sector_t *);
};

typedef void rq_end_io_fn___15(struct request___15 *, blk_status_t);

struct request___15 {
	struct request_queue___16 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___14 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___15 *bio;
	struct bio___15 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___17 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___15 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___15 *saved_end_io;
		} flush;
	};
	struct gendisk___15 *rq_disk;
	struct block_device___16 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___15 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___14 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___16 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___32 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___33 *debugfs_dir;
	struct dentry___33 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___15;

struct elevator_mq_ops___15 {
	int (*init_sched)(struct request_queue___16 *, struct elevator_type___15 *);
	void (*exit_sched)(struct elevator_queue___15 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___14 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___14 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___14 *);
	bool (*allow_merge)(struct request_queue___16 *, struct request___15 *, struct bio___15 *);
	bool (*bio_merge)(struct request_queue___16 *, struct bio___15 *, unsigned int);
	int (*request_merge)(struct request_queue___16 *, struct request___15 **, struct bio___15 *);
	void (*request_merged)(struct request_queue___16 *, struct request___15 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___16 *, struct request___15 *, struct request___15 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___15 *);
	void (*finish_request)(struct request___15 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___14 *, struct list_head *, bool);
	struct request___15 * (*dispatch_request)(struct blk_mq_hw_ctx___14 *);
	bool (*has_work)(struct blk_mq_hw_ctx___14 *);
	void (*completed_request)(struct request___15 *, u64);
	void (*requeue_request)(struct request___15 *);
	struct request___15 * (*former_request)(struct request_queue___16 *, struct request___15 *);
	struct request___15 * (*next_request)(struct request_queue___16 *, struct request___15 *);
	void (*init_icq)(struct io_cq___15 *);
	void (*exit_icq)(struct io_cq___15 *);
};

struct elv_fs_entry___15;

struct elevator_type___15 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___15 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___15 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___34 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___15 {
	struct elevator_type___15 *type;
	void *elevator_data;
	struct kobject___32 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___15 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___15 *, char *);
	ssize_t (*store)(struct elevator_queue___15 *, const char *, size_t);
};

struct blk_mq_queue_data___14;

struct blk_mq_ops___14 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___14 *, const struct blk_mq_queue_data___14 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___14 *);
	int (*get_budget)(struct request_queue___16 *);
	void (*put_budget)(struct request_queue___16 *, int);
	void (*set_rq_budget_token)(struct request___15 *, int);
	int (*get_rq_budget_token)(struct request___15 *);
	enum blk_eh_timer_return (*timeout)(struct request___15 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___14 *);
	void (*complete)(struct request___15 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___14 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___14 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___14 *, struct request___15 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___14 *, struct request___15 *, unsigned int);
	void (*initialize_rq_fn)(struct request___15 *);
	void (*cleanup_rq)(struct request___15 *);
	bool (*busy)(struct request_queue___16 *);
	int (*map_queues)(struct blk_mq_tag_set___14 *);
	void (*show_rq)(struct seq_file___32 *, struct request___15 *);
};

struct blk_mq_tag_set___14 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___14 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___14 {
	struct request___15 *rq;
	bool last;
};

struct blkcg_policy_data___14;

struct blkcg___14 {
	struct cgroup_subsys_state___25 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___14 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___14 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___14 {
	struct blkcg___14 *blkcg;
	int plid;
};

struct blkg_policy_data___14 {
	struct blkcg_gq___14 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___14 {
	struct mem_cgroup___14 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___14 {
	struct lruvec___15 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___14 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___14 *memcg;
};

struct obj_cgroup___14 {
	struct percpu_ref refcnt;
	struct mem_cgroup___14 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___4 {
	spinlock_t *lock;
	struct sk_buff___4 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___4;

struct Qdisc_ops___4 {
	struct Qdisc_ops___4 *next;
	const struct Qdisc_class_ops___4 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___4 *, struct Qdisc___4 *, struct sk_buff___4 **);
	struct sk_buff___4 * (*dequeue)(struct Qdisc___4 *);
	struct sk_buff___4 * (*peek)(struct Qdisc___4 *);
	int (*init)(struct Qdisc___4 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___4 *);
	void (*destroy)(struct Qdisc___4 *);
	int (*change)(struct Qdisc___4 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___4 *);
	int (*change_tx_queue_len)(struct Qdisc___4 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___4 *, unsigned int);
	int (*dump)(struct Qdisc___4 *, struct sk_buff___4 *);
	int (*dump_stats)(struct Qdisc___4 *, struct gnet_dump___4 *);
	void (*ingress_block_set)(struct Qdisc___4 *, u32);
	void (*egress_block_set)(struct Qdisc___4 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___4 *);
	u32 (*egress_block_get)(struct Qdisc___4 *);
	struct module___34 *owner;
};

struct Qdisc_class_ops___4 {
	unsigned int flags;
	struct netdev_queue___4 * (*select_queue)(struct Qdisc___4 *, struct tcmsg *);
	int (*graft)(struct Qdisc___4 *, long unsigned int, struct Qdisc___4 *, struct Qdisc___4 **, struct netlink_ext_ack *);
	struct Qdisc___4 * (*leaf)(struct Qdisc___4 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___4 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___4 *, u32);
	int (*change)(struct Qdisc___4 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___4 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___4 *, struct qdisc_walker *);
	struct tcf_block___4 * (*tcf_block)(struct Qdisc___4 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___4 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___4 *, long unsigned int);
	int (*dump)(struct Qdisc___4 *, long unsigned int, struct sk_buff___4 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___4 *, long unsigned int, struct gnet_dump___4 *);
};

struct tcf_chain___4;

struct tcf_block___4 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___6 *net;
	struct Qdisc___4 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___4 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___4;

struct tcf_proto_ops___4;

struct tcf_proto___4 {
	struct tcf_proto___4 *next;
	void *root;
	int (*classify)(struct sk_buff___4 *, const struct tcf_proto___4 *, struct tcf_result___4 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___4 *ops;
	struct tcf_chain___4 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___4 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___4 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___4 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___4 *, const struct tcf_proto___4 *, struct tcf_result___4 *);
	int (*init)(struct tcf_proto___4 *);
	void (*destroy)(struct tcf_proto___4 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___4 *, u32);
	void (*put)(struct tcf_proto___4 *, void *);
	int (*change)(struct net___6 *, struct sk_buff___4 *, struct tcf_proto___4 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___4 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___4 *);
	void (*walk)(struct tcf_proto___4 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___4 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___4 *, void *);
	void (*hw_del)(struct tcf_proto___4 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___6 *, struct tcf_chain___4 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___6 *, struct tcf_proto___4 *, void *, struct sk_buff___4 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___6 *, struct tcf_proto___4 *, void *, struct sk_buff___4 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___4 *, struct net___6 *, void *);
	struct module___34 *owner;
	int flags;
};

struct tcf_chain___4 {
	struct mutex filter_chain_lock;
	struct tcf_proto___4 *filter_chain;
	struct list_head list;
	struct tcf_block___4 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___4 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___3 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___4 *prog;
};

struct pneigh_entry___3;

struct neigh_hash_table___3;

struct neigh_table___3 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___8 *, __u32 *);
	bool (*key_eq)(const struct neighbour___3 *, const void *);
	int (*constructor)(struct neighbour___3 *);
	int (*pconstructor)(struct pneigh_entry___3 *);
	void (*pdestructor)(struct pneigh_entry___3 *);
	void (*proxy_redo)(struct sk_buff___4 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___8 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___2 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___4 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___3 *nht;
	struct pneigh_entry___3 **phash_buckets;
};

struct neigh_ops___3 {
	int family;
	void (*solicit)(struct neighbour___3 *, struct sk_buff___4 *);
	void (*error_report)(struct neighbour___3 *, struct sk_buff___4 *);
	int (*output)(struct neighbour___3 *, struct sk_buff___4 *);
	int (*connected_output)(struct neighbour___3 *, struct sk_buff___4 *);
};

struct pneigh_entry___3 {
	struct pneigh_entry___3 *next;
	possible_net_t___4 net;
	struct net_device___8 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___3 {
	struct neighbour___3 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___3 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___3 *ctarget;
	struct net___6 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___3 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___3 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___3;

struct timewait_sock_ops___3;

struct proto___3 {
	void (*close)(struct sock___4 *, long int);
	int (*pre_connect)(struct sock___4 *, struct sockaddr *, int);
	int (*connect)(struct sock___4 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___4 *, int);
	struct sock___4 * (*accept)(struct sock___4 *, int, int *, bool);
	int (*ioctl)(struct sock___4 *, int, long unsigned int);
	int (*init)(struct sock___4 *);
	void (*destroy)(struct sock___4 *);
	void (*shutdown)(struct sock___4 *, int);
	int (*setsockopt)(struct sock___4 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___4 *, int, int, char *, int *);
	void (*keepalive)(struct sock___4 *, int);
	int (*compat_ioctl)(struct sock___4 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___4 *, struct msghdr___3 *, size_t);
	int (*recvmsg)(struct sock___4 *, struct msghdr___3 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___4 *, struct page___34 *, int, size_t, int);
	int (*bind)(struct sock___4 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___4 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___4 *, struct sk_buff___4 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___4 *);
	int (*hash)(struct sock___4 *);
	void (*unhash)(struct sock___4 *);
	void (*rehash)(struct sock___4 *);
	int (*get_port)(struct sock___4 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___4 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___4 *, int);
	bool (*sock_is_readable)(struct sock___4 *);
	void (*enter_memory_pressure)(struct sock___4 *);
	void (*leave_memory_pressure)(struct sock___4 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___34 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___4 *, int);
};

typedef void (*task_work_func_t)(struct callback_head *);

enum task_work_notify_mode {
	TWA_NONE = 0,
	TWA_RESUME = 1,
	TWA_SIGNAL = 2,
};

enum {
	KERNEL_PARAM_OPS_FL_NOARG = 1,
};

enum {
	KERNEL_PARAM_FL_UNSAFE = 1,
	KERNEL_PARAM_FL_HWPARAM = 2,
};

struct param_attribute {
	struct module_attribute___10 mattr;
	const struct kernel_param___10 *param;
};

struct module_param_attrs {
	unsigned int num;
	struct attribute_group___10 grp;
	struct param_attribute attrs[0];
};

struct module_version_attribute {
	struct module_attribute___10 mattr;
	const char *module_name;
	const char *version;
};

enum lockdown_reason {
	LOCKDOWN_NONE = 0,
	LOCKDOWN_MODULE_SIGNATURE = 1,
	LOCKDOWN_DEV_MEM = 2,
	LOCKDOWN_EFI_TEST = 3,
	LOCKDOWN_KEXEC = 4,
	LOCKDOWN_HIBERNATION = 5,
	LOCKDOWN_PCI_ACCESS = 6,
	LOCKDOWN_IOPORT = 7,
	LOCKDOWN_MSR = 8,
	LOCKDOWN_ACPI_TABLES = 9,
	LOCKDOWN_PCMCIA_CIS = 10,
	LOCKDOWN_TIOCSSERIAL = 11,
	LOCKDOWN_MODULE_PARAMETERS = 12,
	LOCKDOWN_MMIOTRACE = 13,
	LOCKDOWN_DEBUGFS = 14,
	LOCKDOWN_XMON_WR = 15,
	LOCKDOWN_BPF_WRITE_USER = 16,
	LOCKDOWN_INTEGRITY_MAX = 17,
	LOCKDOWN_KCORE = 18,
	LOCKDOWN_KPROBES = 19,
	LOCKDOWN_BPF_READ_KERNEL = 20,
	LOCKDOWN_PERF = 21,
	LOCKDOWN_TRACEFS = 22,
	LOCKDOWN_XMON_RW = 23,
	LOCKDOWN_XFRM_SECRET = 24,
	LOCKDOWN_CONFIDENTIALITY_MAX = 25,
};

struct kmalloced_param {
	struct list_head list;
	char val[0];
};

struct sched_param {
	int sched_priority;
};

struct dentry___34;

struct super_block___34;

struct module___35;

struct file_system_type___33 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___34 * (*mount)(struct file_system_type___33 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___34 *);
	struct module___35 *owner;
	struct file_system_type___33 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___35;

struct kiocb___33;

struct vm_area_struct___34;

struct inode___35;

struct file_lock___33;

struct page___35;

struct seq_file___33;

struct file_operations___33 {
	struct module___35 *owner;
	loff_t (*llseek)(struct file___35 *, loff_t, int);
	ssize_t (*read)(struct file___35 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___35 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___33 *, struct iov_iter___17 *);
	ssize_t (*write_iter)(struct kiocb___33 *, struct iov_iter___17 *);
	int (*iopoll)(struct kiocb___33 *, bool);
	int (*iterate)(struct file___35 *, struct dir_context *);
	int (*iterate_shared)(struct file___35 *, struct dir_context *);
	__poll_t (*poll)(struct file___35 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___35 *, struct vm_area_struct___34 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___35 *, struct file___35 *);
	int (*flush)(struct file___35 *, fl_owner_t);
	int (*release)(struct inode___35 *, struct file___35 *);
	int (*fsync)(struct file___35 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___35 *, int);
	int (*lock)(struct file___35 *, int, struct file_lock___33 *);
	ssize_t (*sendpage)(struct file___35 *, struct page___35 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___35 *, long unsigned int);
	int (*flock)(struct file___35 *, int, struct file_lock___33 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___35 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___35 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___35 *, long int, struct file_lock___33 **, void **);
	long int (*fallocate)(struct file___35 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___33 *, struct file___35 *);
	ssize_t (*copy_file_range)(struct file___35 *, loff_t, struct file___35 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___35 *, loff_t, struct file___35 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___35 *, loff_t, loff_t, int);
};

struct vmacache___34 {
	u64 seqnum;
	struct vm_area_struct___34 *vmas[4];
};

struct page_frag___34 {
	struct page___35 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___35;

struct pid___32;

struct nsproxy___33;

struct signal_struct___34;

struct css_set___26;

struct vm_struct___34;

struct task_struct___36 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___36 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___35 *mm;
	struct mm_struct___35 *active_mm;
	struct vmacache___34 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___36 *real_parent;
	struct task_struct___36 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___36 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___32 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___2 *ptracer_cred;
	const struct cred___2 *real_cred;
	const struct cred___2 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___33 *nsproxy;
	struct signal_struct___34 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___36 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___26 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___34 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___36 *oom_reaper_list;
	struct vm_struct___34 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___23 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___33;

struct kobj_type___33;

struct kernfs_node___33;

struct kobject___33 {
	const char *name;
	struct list_head entry;
	struct kobject___33 *parent;
	struct kset___33 *kset;
	struct kobj_type___33 *ktype;
	struct kernfs_node___33 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___33 {
	struct kobject___33 kobj;
	struct module___35 *mod;
	struct kobject___33 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___33 {
	struct module___35 *mod;
	struct latch_tree_node node;
};

struct module_layout___33 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___33 mtn;
};

struct module_attribute___33;

struct kernel_param___33;

struct module___35 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___33 mkobj;
	struct module_attribute___33 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___33 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___33 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___33 core_layout;
	struct module_layout___33 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___35 *pgtable_t___34;

struct address_space___33;

struct dev_pagemap___33;

struct page___35 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___33 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___8 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___35 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___34 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___35 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___33 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___33;

struct vm_area_struct___34 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___34 *vm_next;
	struct vm_area_struct___34 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___35 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___33 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___35 *vm_file;
	struct file___35 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___8;

struct core_state___34;

struct mm_struct___35 {
	struct {
		struct vm_area_struct___34 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___8 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___34 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___36 *owner;
		struct user_namespace___3 *user_ns;
		struct file___35 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___33;

struct address_space___33 {
	struct inode___35 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___33 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___33;

struct dev_pagemap___33 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___33 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___33;

struct path___33 {
	struct vfsmount___33 *mnt;
	struct dentry___34 *dentry;
};

struct fown_struct___32 {
	rwlock_t lock;
	struct pid___32 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___35 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___33 f_path;
	struct inode___35 *f_inode;
	const struct file_operations___33 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___32 f_owner;
	const struct cred___2 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___33 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___33;

struct vm_operations_struct___33 {
	void (*open)(struct vm_area_struct___34 *);
	void (*close)(struct vm_area_struct___34 *);
	int (*may_split)(struct vm_area_struct___34 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___34 *);
	int (*mprotect)(struct vm_area_struct___34 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___33 *);
	vm_fault_t (*huge_fault)(struct vm_fault___33 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___33 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___34 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___33 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___33 *);
	int (*access)(struct vm_area_struct___34 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___34 *);
	int (*set_policy)(struct vm_area_struct___34 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___34 *, long unsigned int);
	struct page___35 * (*find_special_page)(struct vm_area_struct___34 *, long unsigned int);
};

struct core_thread___34 {
	struct task_struct___36 *task;
	struct core_thread___34 *next;
};

struct core_state___34 {
	atomic_t nr_threads;
	struct core_thread___34 dumper;
	struct completion startup;
};

struct linux_binprm___9;

struct coredump_params___8;

struct linux_binfmt___8 {
	struct list_head lh;
	struct module___35 *module;
	int (*load_binary)(struct linux_binprm___9 *);
	int (*load_shlib)(struct file___35 *);
	int (*core_dump)(struct coredump_params___8 *);
	long unsigned int min_coredump;
};

struct vm_fault___33 {
	const struct {
		struct vm_area_struct___34 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___35 *cow_page;
	struct page___35 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___34 prealloc_pte;
};

enum {
	__PERCPU_REF_ATOMIC = 1,
	__PERCPU_REF_DEAD = 2,
	__PERCPU_REF_ATOMIC_DEAD = 3,
	__PERCPU_REF_FLAG_BITS = 2,
};

struct dev_pagemap_ops___33 {
	void (*page_free)(struct page___35 *);
	void (*kill)(struct dev_pagemap___33 *);
	void (*cleanup)(struct dev_pagemap___33 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___33 *);
};

struct pid_namespace___32;

struct upid___32 {
	int nr;
	struct pid_namespace___32 *ns;
};

struct pid_namespace___32 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___36 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___32 *parent;
	struct fs_pin *bacct;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	int reboot;
	struct ns_common___4 ns;
};

struct pid___32 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___32 numbers[1];
};

struct signal_struct___34 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___36 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___36 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___32 *pids[4];
	struct pid___32 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___35 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___26;

struct nsproxy___33 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___32 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___26 *cgroup_ns;
};

struct cgroup_subsys_state___26;

struct cgroup___26;

struct css_set___26 {
	struct cgroup_subsys_state___26 *subsys[14];
	refcount_t refcount;
	struct css_set___26 *dom_cset;
	struct cgroup___26 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___26 *mg_src_cgrp;
	struct cgroup___26 *mg_dst_cgrp;
	struct css_set___26 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___34 {
	struct vm_struct___34 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___35 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___33;

struct dentry___34 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___34 *d_parent;
	struct qstr d_name;
	struct inode___35 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___33 *d_op;
	struct super_block___34 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___33;

struct inode___35 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___33 *i_op;
	struct super_block___34 *i_sb;
	struct address_space___33 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___33 *i_fop;
		void (*free_inode)(struct inode___35 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___33 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___8 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___33 {
	int (*d_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___34 *, unsigned int);
	int (*d_hash)(const struct dentry___34 *, struct qstr *);
	int (*d_compare)(const struct dentry___34 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___34 *);
	int (*d_init)(struct dentry___34 *);
	void (*d_release)(struct dentry___34 *);
	void (*d_prune)(struct dentry___34 *);
	void (*d_iput)(struct dentry___34 *, struct inode___35 *);
	char * (*d_dname)(struct dentry___34 *, char *, int);
	struct vfsmount___33 * (*d_automount)(struct path___33 *);
	int (*d_manage)(const struct path___33 *, bool);
	struct dentry___34 * (*d_real)(struct dentry___34 *, const struct inode___35 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___33;

struct mem_dqinfo___33 {
	struct quota_format_type___33 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___33;

struct quota_info___33 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___35 *files[3];
	struct mem_dqinfo___33 info[3];
	const struct quota_format_ops___33 *ops[3];
};

struct rcuwait___33 {
	struct task_struct___36 *task;
};

struct percpu_rw_semaphore___33 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___33 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___33 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___33 rw_sem[3];
};

struct super_operations___33;

struct dquot_operations___33;

struct quotactl_ops___33;

struct super_block___34 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___33 *s_type;
	const struct super_operations___33 *s_op;
	const struct dquot_operations___33 *dq_op;
	const struct quotactl_ops___33 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___34 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___33 s_dquot;
	struct sb_writers___33 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___33 *s_d_op;
	int cleancache_poolid;
	struct shrinker___14 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___3 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___33 {
	struct dentry___34 *mnt_root;
	struct super_block___34 *mnt_sb;
	int mnt_flags;
	struct user_namespace___3 *mnt_userns;
};

struct cgroup_subsys___26;

struct cgroup_subsys_state___26 {
	struct cgroup___26 *cgroup;
	struct cgroup_subsys___26 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___26 *parent;
};

struct cgroup_file___26 {
	struct kernfs_node___33 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___26 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___36 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___26;

struct cgroup_rstat_cpu___26;

struct cgroup___26 {
	struct cgroup_subsys_state___26 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___33 *kn;
	struct cgroup_file___26 procs_file;
	struct cgroup_file___26 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___26 *subsys[14];
	struct cgroup_root___26 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___26 *dom_cgrp;
	struct cgroup___26 *old_dom_cgrp;
	struct cgroup_rstat_cpu___26 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___26 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___33 {
	struct file___35 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___33 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___34 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___35 *ia_file;
};

struct dquot___33 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___34 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___33 {
	int qf_fmt_id;
	const struct quota_format_ops___33 *qf_ops;
	struct module___35 *qf_owner;
	struct quota_format_type___33 *qf_next;
};

struct quota_format_ops___33 {
	int (*check_quota_file)(struct super_block___34 *, int);
	int (*read_file_info)(struct super_block___34 *, int);
	int (*write_file_info)(struct super_block___34 *, int);
	int (*free_file_info)(struct super_block___34 *, int);
	int (*read_dqblk)(struct dquot___33 *);
	int (*commit_dqblk)(struct dquot___33 *);
	int (*release_dqblk)(struct dquot___33 *);
	int (*get_next_id)(struct super_block___34 *, struct kqid *);
};

struct dquot_operations___33 {
	int (*write_dquot)(struct dquot___33 *);
	struct dquot___33 * (*alloc_dquot)(struct super_block___34 *, int);
	void (*destroy_dquot)(struct dquot___33 *);
	int (*acquire_dquot)(struct dquot___33 *);
	int (*release_dquot)(struct dquot___33 *);
	int (*mark_dirty)(struct dquot___33 *);
	int (*write_info)(struct super_block___34 *, int);
	qsize_t * (*get_reserved_space)(struct inode___35 *);
	int (*get_projid)(struct inode___35 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___35 *, qsize_t *);
	int (*get_next_id)(struct super_block___34 *, struct kqid *);
};

struct quotactl_ops___33 {
	int (*quota_on)(struct super_block___34 *, int, int, const struct path___33 *);
	int (*quota_off)(struct super_block___34 *, int);
	int (*quota_enable)(struct super_block___34 *, unsigned int);
	int (*quota_disable)(struct super_block___34 *, unsigned int);
	int (*quota_sync)(struct super_block___34 *, int);
	int (*set_info)(struct super_block___34 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___34 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___34 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___34 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___34 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___34 *, unsigned int);
};

struct address_space_operations___33 {
	int (*writepage)(struct page___35 *, struct writeback_control___3 *);
	int (*readpage)(struct file___35 *, struct page___35 *);
	int (*writepages)(struct address_space___33 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___35 *);
	int (*readpages)(struct file___35 *, struct address_space___33 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___35 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___35 **, void **);
	int (*write_end)(struct file___35 *, struct address_space___33 *, loff_t, unsigned int, unsigned int, struct page___35 *, void *);
	sector_t (*bmap)(struct address_space___33 *, sector_t);
	void (*invalidatepage)(struct page___35 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___35 *, gfp_t);
	void (*freepage)(struct page___35 *);
	ssize_t (*direct_IO)(struct kiocb___33 *, struct iov_iter___17 *);
	int (*migratepage)(struct address_space___33 *, struct page___35 *, struct page___35 *, enum migrate_mode);
	bool (*isolate_page)(struct page___35 *, isolate_mode_t);
	void (*putback_page)(struct page___35 *);
	int (*launder_page)(struct page___35 *);
	int (*is_partially_uptodate)(struct page___35 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___35 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___33 *, struct page___35 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___35 *, sector_t *);
	void (*swap_deactivate)(struct file___35 *);
};

struct inode_operations___33 {
	struct dentry___34 * (*lookup)(struct inode___35 *, struct dentry___34 *, unsigned int);
	const char * (*get_link)(struct dentry___34 *, struct inode___35 *, struct delayed_call *);
	int (*permission)(struct user_namespace___3 *, struct inode___35 *, int);
	struct posix_acl * (*get_acl)(struct inode___35 *, int, bool);
	int (*readlink)(struct dentry___34 *, char *, int);
	int (*create)(struct user_namespace___3 *, struct inode___35 *, struct dentry___34 *, umode_t, bool);
	int (*link)(struct dentry___34 *, struct inode___35 *, struct dentry___34 *);
	int (*unlink)(struct inode___35 *, struct dentry___34 *);
	int (*symlink)(struct user_namespace___3 *, struct inode___35 *, struct dentry___34 *, const char *);
	int (*mkdir)(struct user_namespace___3 *, struct inode___35 *, struct dentry___34 *, umode_t);
	int (*rmdir)(struct inode___35 *, struct dentry___34 *);
	int (*mknod)(struct user_namespace___3 *, struct inode___35 *, struct dentry___34 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___3 *, struct inode___35 *, struct dentry___34 *, struct inode___35 *, struct dentry___34 *, unsigned int);
	int (*setattr)(struct user_namespace___3 *, struct dentry___34 *, struct iattr___34 *);
	int (*getattr)(struct user_namespace___3 *, const struct path___33 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___34 *, char *, size_t);
	int (*fiemap)(struct inode___35 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___35 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___35 *, struct dentry___34 *, struct file___35 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___3 *, struct inode___35 *, struct dentry___34 *, umode_t);
	int (*set_acl)(struct user_namespace___3 *, struct inode___35 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___3 *, struct dentry___34 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___34 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___33 {
	void (*fl_copy_lock)(struct file_lock___33 *, struct file_lock___33 *);
	void (*fl_release_private)(struct file_lock___33 *);
};

struct fasync_struct___33;

struct lock_manager_operations___33;

struct file_lock___33 {
	struct file_lock___33 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___35 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___33 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___33 *fl_ops;
	const struct lock_manager_operations___33 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___33 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___33 *);
	int (*lm_grant)(struct file_lock___33 *, int);
	bool (*lm_break)(struct file_lock___33 *);
	int (*lm_change)(struct file_lock___33 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___33 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___33 *);
};

struct fasync_struct___33 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___33 *fa_next;
	struct file___35 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___33 {
	struct inode___35 * (*alloc_inode)(struct super_block___34 *);
	void (*destroy_inode)(struct inode___35 *);
	void (*free_inode)(struct inode___35 *);
	void (*dirty_inode)(struct inode___35 *, int);
	int (*write_inode)(struct inode___35 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___35 *);
	void (*evict_inode)(struct inode___35 *);
	void (*put_super)(struct super_block___34 *);
	int (*sync_fs)(struct super_block___34 *, int);
	int (*freeze_super)(struct super_block___34 *);
	int (*freeze_fs)(struct super_block___34 *);
	int (*thaw_super)(struct super_block___34 *);
	int (*unfreeze_fs)(struct super_block___34 *);
	int (*statfs)(struct dentry___34 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___34 *, int *, char *);
	void (*umount_begin)(struct super_block___34 *);
	int (*show_options)(struct seq_file___33 *, struct dentry___34 *);
	int (*show_devname)(struct seq_file___33 *, struct dentry___34 *);
	int (*show_path)(struct seq_file___33 *, struct dentry___34 *);
	int (*show_stats)(struct seq_file___33 *, struct dentry___34 *);
	ssize_t (*quota_read)(struct super_block___34 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___34 *, int, const char *, size_t, loff_t);
	struct dquot___33 ** (*get_dquots)(struct inode___35 *);
	long int (*nr_cached_objects)(struct super_block___34 *, struct shrink_control___14 *);
	long int (*free_cached_objects)(struct super_block___34 *, struct shrink_control___14 *);
	struct file___35 * (*real_loop)(struct file___35 *);
};

struct seq_operations___32;

struct seq_file___33 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___32 *op;
	int poll_event;
	const struct file___35 *file;
	void *private;
};

struct kernfs_root___33;

struct kernfs_elem_dir___33 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___33 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___33;

struct kernfs_root___33 {
	struct kernfs_node___33 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___33 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___33 {
	struct kernfs_node___33 *target_kn;
};

struct kernfs_ops___33;

struct kernfs_elem_attr___33 {
	const struct kernfs_ops___33 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___33 *notify_next;
};

struct kernfs_node___33 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___33 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___33 dir;
		struct kernfs_elem_symlink___33 symlink;
		struct kernfs_elem_attr___33 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___33;

struct kernfs_ops___33 {
	int (*open)(struct kernfs_open_file___33 *);
	void (*release)(struct kernfs_open_file___33 *);
	int (*seq_show)(struct seq_file___33 *, void *);
	void * (*seq_start)(struct seq_file___33 *, loff_t *);
	void * (*seq_next)(struct seq_file___33 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___33 *, void *);
	ssize_t (*read)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___33 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___33 *, struct vm_area_struct___34 *);
};

struct kernfs_syscall_ops___33 {
	int (*show_options)(struct seq_file___33 *, struct kernfs_root___33 *);
	int (*mkdir)(struct kernfs_node___33 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___33 *);
	int (*rename)(struct kernfs_node___33 *, struct kernfs_node___33 *, const char *);
	int (*show_path)(struct seq_file___33 *, struct kernfs_node___33 *, struct kernfs_root___33 *);
};

struct kernfs_open_file___33 {
	struct kernfs_node___33 *kn;
	struct file___35 *file;
	struct seq_file___33 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___33 *vm_ops;
};

struct bin_attribute___33;

struct attribute_group___33 {
	const char *name;
	umode_t (*is_visible)(struct kobject___33 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___33 *, struct bin_attribute___33 *, int);
	struct attribute **attrs;
	struct bin_attribute___33 **bin_attrs;
};

struct bin_attribute___33 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___33 * (*f_mapping)();
	ssize_t (*read)(struct file___35 *, struct kobject___33 *, struct bin_attribute___33 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___35 *, struct kobject___33 *, struct bin_attribute___33 *, char *, loff_t, size_t);
	int (*mmap)(struct file___35 *, struct kobject___33 *, struct bin_attribute___33 *, struct vm_area_struct___34 *);
};

struct sysfs_ops___33 {
	ssize_t (*show)(struct kobject___33 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___33 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___33;

struct kset___33 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___33 kobj;
	const struct kset_uevent_ops___33 *uevent_ops;
};

struct kobj_type___33 {
	void (*release)(struct kobject___33 *);
	const struct sysfs_ops___33 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___33 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___33 *);
	const void * (*namespace)(struct kobject___33 *);
	void (*get_ownership)(struct kobject___33 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___33 {
	int (* const filter)(struct kset___33 *, struct kobject___33 *);
	const char * (* const name)(struct kset___33 *, struct kobject___33 *);
	int (* const uevent)(struct kset___33 *, struct kobject___33 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___33 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___33 *);
	int (*get)(char *, const struct kernel_param___33 *);
	void (*free)(void *);
};

struct kparam_array___33;

struct kernel_param___33 {
	const char *name;
	struct module___35 *mod;
	const struct kernel_param_ops___33 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___33 *arr;
	};
};

struct kparam_array___33 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___33 *ops;
	void *elem;
};

struct module_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___33 *, struct module_kobject___33 *, char *);
	ssize_t (*store)(struct module_attribute___33 *, struct module_kobject___33 *, const char *, size_t);
	void (*setup)(struct module___35 *, const char *);
	int (*test)(struct module___35 *);
	void (*free)(struct module___35 *);
};

struct cgroup_namespace___26 {
	struct ns_common___4 ns;
	struct user_namespace___3 *user_ns;
	struct ucounts___3 *ucounts;
	struct css_set___26 *root_cset;
};

struct kthread_work;

typedef void (*kthread_work_func_t)(struct kthread_work *);

struct kthread_worker;

struct kthread_work {
	struct list_head node;
	kthread_work_func_t func;
	struct kthread_worker *worker;
	int canceling;
};

enum {
	KTW_FREEZABLE = 1,
};

struct kthread_worker {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___36 *task;
	struct kthread_work *current_work;
};

struct kthread_delayed_work {
	struct kthread_work work;
	struct timer_list timer;
};

struct seq_operations___32 {
	void * (*start)(struct seq_file___33 *, loff_t *);
	void (*stop)(struct seq_file___33 *, void *);
	void * (*next)(struct seq_file___33 *, void *, loff_t *);
	int (*show)(struct seq_file___33 *, void *);
};

enum {
	CSS_NO_REF = 1,
	CSS_ONLINE = 2,
	CSS_RELEASED = 4,
	CSS_VISIBLE = 8,
	CSS_DYING = 16,
};

struct cftype___26;

struct cgroup_subsys___26 {
	struct cgroup_subsys_state___26 * (*css_alloc)(struct cgroup_subsys_state___26 *);
	int (*css_online)(struct cgroup_subsys_state___26 *);
	void (*css_offline)(struct cgroup_subsys_state___26 *);
	void (*css_released)(struct cgroup_subsys_state___26 *);
	void (*css_free)(struct cgroup_subsys_state___26 *);
	void (*css_reset)(struct cgroup_subsys_state___26 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___26 *, int);
	int (*css_extra_stat_show)(struct seq_file___33 *, struct cgroup_subsys_state___26 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___36 *, struct css_set___26 *);
	void (*cancel_fork)(struct task_struct___36 *, struct css_set___26 *);
	void (*fork)(struct task_struct___36 *);
	void (*exit)(struct task_struct___36 *);
	void (*release)(struct task_struct___36 *);
	void (*bind)(struct cgroup_subsys_state___26 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___26 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___26 *dfl_cftypes;
	struct cftype___26 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___26 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___26 *updated_children;
	struct cgroup___26 *updated_next;
};

struct cgroup_root___26 {
	struct kernfs_root___33 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___26 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___26 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___26 *ss;
	struct list_head node;
	struct kernfs_ops___33 *kf_ops;
	int (*open)(struct kernfs_open_file___33 *);
	void (*release)(struct kernfs_open_file___33 *);
	u64 (*read_u64)(struct cgroup_subsys_state___26 *, struct cftype___26 *);
	s64 (*read_s64)(struct cgroup_subsys_state___26 *, struct cftype___26 *);
	int (*seq_show)(struct seq_file___33 *, void *);
	void * (*seq_start)(struct seq_file___33 *, loff_t *);
	void * (*seq_next)(struct seq_file___33 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___33 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___26 *, struct cftype___26 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___26 *, struct cftype___26 *, s64);
	ssize_t (*write)(struct kernfs_open_file___33 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___33 *, struct poll_table_struct___5 *);
};

struct linux_binprm___9 {
	struct vm_area_struct___34 *vma;
	long unsigned int vma_pages;
	struct mm_struct___35 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___35 *executable;
	struct file___35 *interpreter;
	struct file___35 *file;
	struct cred___2 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___8 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___35 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct kthread_create_info {
	int (*threadfn)(void *);
	void *data;
	int node;
	struct task_struct___36 *result;
	struct completion *done;
	struct list_head list;
};

struct kthread {
	long unsigned int flags;
	unsigned int cpu;
	int (*threadfn)(void *);
	void *data;
	mm_segment_t oldfs;
	struct completion parked;
	struct completion exited;
	struct cgroup_subsys_state___26 *blkcg_css;
};

enum KTHREAD_BITS {
	KTHREAD_IS_PER_CPU = 0,
	KTHREAD_SHOULD_STOP = 1,
	KTHREAD_SHOULD_PARK = 2,
};

struct kthread_flush_work {
	struct kthread_work work;
	struct completion done;
};

struct pt_regs___3;

struct dentry___35;

struct super_block___35;

struct module___36;

struct file_system_type___34 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___35 * (*mount)(struct file_system_type___34 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___35 *);
	struct module___36 *owner;
	struct file_system_type___34 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___36;

struct kiocb___34;

struct iov_iter___18;

struct poll_table_struct___27;

struct vm_area_struct___35;

struct inode___36;

struct file_lock___34;

struct page___36;

struct pipe_inode_info___9;

struct seq_file___34;

struct file_operations___34 {
	struct module___36 *owner;
	loff_t (*llseek)(struct file___36 *, loff_t, int);
	ssize_t (*read)(struct file___36 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___36 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___34 *, struct iov_iter___18 *);
	ssize_t (*write_iter)(struct kiocb___34 *, struct iov_iter___18 *);
	int (*iopoll)(struct kiocb___34 *, bool);
	int (*iterate)(struct file___36 *, struct dir_context *);
	int (*iterate_shared)(struct file___36 *, struct dir_context *);
	__poll_t (*poll)(struct file___36 *, struct poll_table_struct___27 *);
	long int (*unlocked_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___36 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___36 *, struct vm_area_struct___35 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___36 *, struct file___36 *);
	int (*flush)(struct file___36 *, fl_owner_t);
	int (*release)(struct inode___36 *, struct file___36 *);
	int (*fsync)(struct file___36 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___36 *, int);
	int (*lock)(struct file___36 *, int, struct file_lock___34 *);
	ssize_t (*sendpage)(struct file___36 *, struct page___36 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___36 *, long unsigned int);
	int (*flock)(struct file___36 *, int, struct file_lock___34 *);
	ssize_t (*splice_write)(struct pipe_inode_info___9 *, struct file___36 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___36 *, loff_t *, struct pipe_inode_info___9 *, size_t, unsigned int);
	int (*setlease)(struct file___36 *, long int, struct file_lock___34 **, void **);
	long int (*fallocate)(struct file___36 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___34 *, struct file___36 *);
	ssize_t (*copy_file_range)(struct file___36 *, loff_t, struct file___36 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___36 *, loff_t, struct file___36 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___36 *, loff_t, loff_t, int);
};

struct vmacache___35 {
	u64 seqnum;
	struct vm_area_struct___35 *vmas[4];
};

struct page_frag___35 {
	struct page___36 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___24;

struct debug_info___24 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___24 *hbp_break[16];
	struct perf_event___24 *hbp_watch[16];
};

struct thread_struct___24 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___24 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___36;

struct pid___33;

struct cred___3;

struct fs_struct___6;

struct nsproxy___34;

struct signal_struct___35;

struct css_set___27;

struct perf_event_context___24;

struct vm_struct___35;

struct task_struct___37 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___37 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___36 *mm;
	struct mm_struct___36 *active_mm;
	struct vmacache___35 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___37 *real_parent;
	struct task_struct___37 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___37 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___33 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___6 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___34 *nsproxy;
	struct signal_struct___35 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___37 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___16 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___27 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___24 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___9 *splice_pipe;
	struct page_frag___35 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___37 *oom_reaper_list;
	struct vm_struct___35 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___24 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___34;

struct kobj_type___34;

struct kernfs_node___34;

struct kobject___34 {
	const char *name;
	struct list_head entry;
	struct kobject___34 *parent;
	struct kset___34 *kset;
	struct kobj_type___34 *ktype;
	struct kernfs_node___34 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___34 {
	struct kobject___34 kobj;
	struct module___36 *mod;
	struct kobject___34 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___34 {
	struct module___36 *mod;
	struct latch_tree_node node;
};

struct module_layout___34 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___34 mtn;
};

struct module_attribute___34;

struct kernel_param___34;

struct trace_event_call___19;

struct module___36 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___34 mkobj;
	struct module_attribute___34 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___34 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___34 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___34 core_layout;
	struct module_layout___34 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___19 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___24 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___37 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___24)(struct perf_event___24 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___24;

struct fasync_struct___34;

struct pid_namespace___33;

struct perf_cgroup___24;

struct perf_event___24 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___24 *group_leader;
	struct pmu___24 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___24 hw;
	struct perf_event_context___24 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___24 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___37 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___34 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___24 *aux_event;
	void (*destroy)(struct perf_event___24 *);
	struct callback_head callback_head;
	struct pid_namespace___33 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___24 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___24 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___19 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___24 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___36 *pgtable_t___35;

struct address_space___34;

struct page_pool___9;

struct dev_pagemap___34;

struct page___36 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___34 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___9 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___36 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___35 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___36 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___34 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___34;

struct vm_area_struct___35 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___35 *vm_next;
	struct vm_area_struct___35 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___36 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___34 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___36 *vm_file;
	struct file___36 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___35;

struct user_namespace___4;

struct mm_struct___36 {
	struct {
		struct vm_area_struct___35 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___36 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___35 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___37 *owner;
		struct user_namespace___4 *user_ns;
		struct file___36 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___34;

struct address_space___34 {
	struct inode___36 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___34 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___31;

struct page_pool_params___9 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___31 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___9 {
	u32 count;
	struct page___36 *cache[128];
};

struct page_pool___9 {
	struct page_pool_params___9 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___36 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___9 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___34;

struct dev_pagemap___34 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___34 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___34;

struct path___34 {
	struct vfsmount___34 *mnt;
	struct dentry___35 *dentry;
};

struct fown_struct___33 {
	rwlock_t lock;
	struct pid___33 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___36 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___34 f_path;
	struct inode___36 *f_inode;
	const struct file_operations___34 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___33 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___34 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___34;

struct vm_operations_struct___34 {
	void (*open)(struct vm_area_struct___35 *);
	void (*close)(struct vm_area_struct___35 *);
	int (*may_split)(struct vm_area_struct___35 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___35 *);
	int (*mprotect)(struct vm_area_struct___35 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___34 *);
	vm_fault_t (*huge_fault)(struct vm_fault___34 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___34 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___35 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___34 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___34 *);
	int (*access)(struct vm_area_struct___35 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___35 *);
	int (*set_policy)(struct vm_area_struct___35 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___35 *, long unsigned int);
	struct page___36 * (*find_special_page)(struct vm_area_struct___35 *, long unsigned int);
};

struct core_thread___35 {
	struct task_struct___37 *task;
	struct core_thread___35 *next;
};

struct core_state___35 {
	atomic_t nr_threads;
	struct core_thread___35 dumper;
	struct completion startup;
};

struct proc_ns_operations___5;

struct ns_common___5 {
	atomic_long_t stashed;
	const struct proc_ns_operations___5 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___4;

struct user_namespace___4 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___4 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___5 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___4 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___34 {
	const struct {
		struct vm_area_struct___35 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___36 *cow_page;
	struct page___36 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___35 prealloc_pte;
};

struct upid___33 {
	int nr;
	struct pid_namespace___33 *ns;
};

struct pid_namespace___33 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___37 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___33 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___33 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___33 numbers[1];
};

struct ucounts___4 {
	struct hlist_node node;
	struct user_namespace___4 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___35 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___37 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___37 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___33 *pids[4];
	struct pid___33 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___36 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___3 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct fs_struct___6 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___34 root;
	struct path___34 pwd;
};

struct uts_namespace___4;

struct ipc_namespace___2;

struct net___7;

struct time_namespace___3;

struct cgroup_namespace___27;

struct nsproxy___34 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace___2 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___33 *pid_ns_for_children;
	struct net___7 *net_ns;
	struct time_namespace___3 *time_ns;
	struct time_namespace___3 *time_ns_for_children;
	struct cgroup_namespace___27 *cgroup_ns;
};

struct cgroup_subsys_state___27;

struct cgroup___27;

struct css_set___27 {
	struct cgroup_subsys_state___27 *subsys[14];
	refcount_t refcount;
	struct css_set___27 *dom_cset;
	struct cgroup___27 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___27 *mg_src_cgrp;
	struct cgroup___27 *mg_dst_cgrp;
	struct css_set___27 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___24 {
	struct pmu___24 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___37 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___24 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___9;

struct pipe_inode_info___9 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___36 *tmp_page;
	struct fasync_struct___34 *fasync_readers;
	struct fasync_struct___34 *fasync_writers;
	struct pipe_buffer___9 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___35 {
	struct vm_struct___35 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___36 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct uts_namespace___4 {
	struct new_utsname name;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct ns_common___5 ns;
};

struct ipc_ids {
	int in_use;
	short unsigned int seq;
	struct rw_semaphore rwsem;
	struct idr ipcs_idr;
	int max_idx;
	int last_idx;
	int next_id;
	struct rhashtable key_ht;
};

struct ipc_namespace___2 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___34 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___5 ns;
};

struct fqdir___6;

struct netns_ipv4___6 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___6 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___6 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___6 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___4 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___4 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___4 *);
	int (*local_out)(struct net___7 *, struct sock *, struct sk_buff___4 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___4 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___6 {
	struct dst_ops___6 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___6 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___6 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___6 *fqdir;
};

struct netns_xfrm___6 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___6 xfrm4_dst_ops;
	struct dst_ops___6 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___7 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct idr netns_ids;
	struct ns_common___5 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___6 ipv4;
	struct netns_ipv6___6 ipv6;
	struct netns_ieee802154_lowpan___6 ieee802154_lowpan;
	struct netns_sctp___3 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___4 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___4 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___6 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct time_namespace___3 {
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct ns_common___5 ns;
	struct timens_offsets offsets;
	struct page___36 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___27 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___27 *root_cset;
};

struct nsset___4 {
	unsigned int flags;
	struct nsproxy___34 *nsproxy;
	struct fs_struct___6 *fs;
	const struct cred___3 *cred;
};

struct proc_ns_operations___5 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___5 * (*get)(struct task_struct___37 *);
	void (*put)(struct ns_common___5 *);
	int (*install)(struct nsset___4 *, struct ns_common___5 *);
	struct user_namespace___4 * (*owner)(struct ns_common___5 *);
	struct ns_common___5 * (*get_parent)(struct ns_common___5 *);
};

struct fwnode_operations___31;

struct fwnode_handle___31 {
	struct fwnode_handle___31 *secondary;
	const struct fwnode_operations___31 *ops;
	struct device___31 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___31;

struct fwnode_endpoint___31;

struct fwnode_operations___31 {
	struct fwnode_handle___31 * (*get)(struct fwnode_handle___31 *);
	void (*put)(struct fwnode_handle___31 *);
	bool (*device_is_available)(const struct fwnode_handle___31 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___31 *, const struct device___31 *);
	bool (*property_present)(const struct fwnode_handle___31 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___31 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___31 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___31 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_parent)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_next_child_node)(const struct fwnode_handle___31 *, struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*get_named_child_node)(const struct fwnode_handle___31 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___31 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___31 *);
	struct fwnode_handle___31 * (*graph_get_next_endpoint)(const struct fwnode_handle___31 *, struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*graph_get_remote_endpoint)(const struct fwnode_handle___31 *);
	struct fwnode_handle___31 * (*graph_get_port_parent)(struct fwnode_handle___31 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___31 *, struct fwnode_endpoint___31 *);
	int (*add_links)(struct fwnode_handle___31 *);
};

struct wakeup_source___31;

struct dev_pm_info___31 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___31 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___31 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___31;

struct bus_type___31;

struct device_driver___31;

struct dev_pm_domain___31;

struct class___31;

struct attribute_group___34;

struct device___31 {
	struct kobject___34 kobj;
	struct device___31 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___31 *type;
	struct bus_type___31 *bus;
	struct device_driver___31 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___31 power;
	struct dev_pm_domain___31 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___31 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___31 *class;
	const struct attribute_group___34 **groups;
	void (*release)(struct device___31 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___31 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___31 *local_fwnode;
};

struct fwnode_reference_args___31 {
	struct fwnode_handle___31 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___33;

struct seq_file___34 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___33 *op;
	int poll_event;
	const struct file___36 *file;
	void *private;
};

struct kernfs_root___34;

struct kernfs_elem_dir___34 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___34 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___34;

struct kernfs_root___34 {
	struct kernfs_node___34 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___34 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___34 {
	struct kernfs_node___34 *target_kn;
};

struct kernfs_ops___34;

struct kernfs_elem_attr___34 {
	const struct kernfs_ops___34 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___34 *notify_next;
};

struct kernfs_node___34 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___34 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___34 dir;
		struct kernfs_elem_symlink___34 symlink;
		struct kernfs_elem_attr___34 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___34;

struct kernfs_ops___34 {
	int (*open)(struct kernfs_open_file___34 *);
	void (*release)(struct kernfs_open_file___34 *);
	int (*seq_show)(struct seq_file___34 *, void *);
	void * (*seq_start)(struct seq_file___34 *, loff_t *);
	void * (*seq_next)(struct seq_file___34 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___34 *, void *);
	ssize_t (*read)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___34 *, struct poll_table_struct___27 *);
	int (*mmap)(struct kernfs_open_file___34 *, struct vm_area_struct___35 *);
};

struct kernfs_syscall_ops___34 {
	int (*show_options)(struct seq_file___34 *, struct kernfs_root___34 *);
	int (*mkdir)(struct kernfs_node___34 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___34 *);
	int (*rename)(struct kernfs_node___34 *, struct kernfs_node___34 *, const char *);
	int (*show_path)(struct seq_file___34 *, struct kernfs_node___34 *, struct kernfs_root___34 *);
};

struct kernfs_open_file___34 {
	struct kernfs_node___34 *kn;
	struct file___36 *file;
	struct seq_file___34 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___34 *vm_ops;
};

typedef void (*poll_queue_proc___27)(struct file___36 *, wait_queue_head_t *, struct poll_table_struct___27 *);

struct poll_table_struct___27 {
	poll_queue_proc___27 _qproc;
	__poll_t _key;
};

struct bin_attribute___34;

struct attribute_group___34 {
	const char *name;
	umode_t (*is_visible)(struct kobject___34 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___34 *, struct bin_attribute___34 *, int);
	struct attribute **attrs;
	struct bin_attribute___34 **bin_attrs;
};

struct bin_attribute___34 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___34 * (*f_mapping)();
	ssize_t (*read)(struct file___36 *, struct kobject___34 *, struct bin_attribute___34 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___36 *, struct kobject___34 *, struct bin_attribute___34 *, char *, loff_t, size_t);
	int (*mmap)(struct file___36 *, struct kobject___34 *, struct bin_attribute___34 *, struct vm_area_struct___35 *);
};

struct sysfs_ops___34 {
	ssize_t (*show)(struct kobject___34 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___34 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___34;

struct kset___34 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___34 kobj;
	const struct kset_uevent_ops___34 *uevent_ops;
};

struct kobj_type___34 {
	void (*release)(struct kobject___34 *);
	const struct sysfs_ops___34 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___34 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___34 *);
	const void * (*namespace)(struct kobject___34 *);
	void (*get_ownership)(struct kobject___34 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___34 {
	int (* const filter)(struct kset___34 *, struct kobject___34 *);
	const char * (* const name)(struct kset___34 *, struct kobject___34 *);
	int (* const uevent)(struct kset___34 *, struct kobject___34 *, struct kobj_uevent_env *);
};

struct dev_pagemap_ops___34 {
	void (*page_free)(struct page___36 *);
	void (*kill)(struct dev_pagemap___34 *);
	void (*cleanup)(struct dev_pagemap___34 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___34 *);
};

struct dentry_operations___34;

struct dentry___35 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___35 *d_parent;
	struct qstr d_name;
	struct inode___36 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___34 *d_op;
	struct super_block___35 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___34;

struct inode___36 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___34 *i_op;
	struct super_block___35 *i_sb;
	struct address_space___34 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___34 *i_fop;
		void (*free_inode)(struct inode___36 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___34 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___9 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___34 {
	int (*d_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___35 *, unsigned int);
	int (*d_hash)(const struct dentry___35 *, struct qstr *);
	int (*d_compare)(const struct dentry___35 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___35 *);
	int (*d_init)(struct dentry___35 *);
	void (*d_release)(struct dentry___35 *);
	void (*d_prune)(struct dentry___35 *);
	void (*d_iput)(struct dentry___35 *, struct inode___36 *);
	char * (*d_dname)(struct dentry___35 *, char *, int);
	struct vfsmount___34 * (*d_automount)(struct path___34 *);
	int (*d_manage)(const struct path___34 *, bool);
	struct dentry___35 * (*d_real)(struct dentry___35 *, const struct inode___36 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___34;

struct mem_dqinfo___34 {
	struct quota_format_type___34 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___34;

struct quota_info___34 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___36 *files[3];
	struct mem_dqinfo___34 info[3];
	const struct quota_format_ops___34 *ops[3];
};

struct rcuwait___34 {
	struct task_struct___37 *task;
};

struct percpu_rw_semaphore___34 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___34 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___34 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___34 rw_sem[3];
};

struct super_operations___34;

struct dquot_operations___34;

struct quotactl_ops___34;

struct super_block___35 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___34 *s_type;
	const struct super_operations___34 *s_op;
	const struct dquot_operations___34 *dq_op;
	const struct quotactl_ops___34 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___35 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___34 s_dquot;
	struct sb_writers___34 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___34 *s_d_op;
	int cleancache_poolid;
	struct shrinker___14 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___34 {
	struct dentry___35 *mnt_root;
	struct super_block___35 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct cgroup_subsys___27;

struct cgroup_subsys_state___27 {
	struct cgroup___27 *cgroup;
	struct cgroup_subsys___27 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___27 *parent;
};

struct cgroup_file___27 {
	struct kernfs_node___34 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___27 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___37 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___27;

struct cgroup_rstat_cpu___27;

struct cgroup___27 {
	struct cgroup_subsys_state___27 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___34 *kn;
	struct cgroup_file___27 procs_file;
	struct cgroup_file___27 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___27 *subsys[14];
	struct cgroup_root___27 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___27 *dom_cgrp;
	struct cgroup___27 *old_dom_cgrp;
	struct cgroup_rstat_cpu___27 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___27 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___34 {
	struct file___36 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___34 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___16 *ki_waitq;
	};
};

struct iattr___35 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___36 *ia_file;
};

struct dquot___34 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___35 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___34 {
	int qf_fmt_id;
	const struct quota_format_ops___34 *qf_ops;
	struct module___36 *qf_owner;
	struct quota_format_type___34 *qf_next;
};

struct quota_format_ops___34 {
	int (*check_quota_file)(struct super_block___35 *, int);
	int (*read_file_info)(struct super_block___35 *, int);
	int (*write_file_info)(struct super_block___35 *, int);
	int (*free_file_info)(struct super_block___35 *, int);
	int (*read_dqblk)(struct dquot___34 *);
	int (*commit_dqblk)(struct dquot___34 *);
	int (*release_dqblk)(struct dquot___34 *);
	int (*get_next_id)(struct super_block___35 *, struct kqid *);
};

struct dquot_operations___34 {
	int (*write_dquot)(struct dquot___34 *);
	struct dquot___34 * (*alloc_dquot)(struct super_block___35 *, int);
	void (*destroy_dquot)(struct dquot___34 *);
	int (*acquire_dquot)(struct dquot___34 *);
	int (*release_dquot)(struct dquot___34 *);
	int (*mark_dirty)(struct dquot___34 *);
	int (*write_info)(struct super_block___35 *, int);
	qsize_t * (*get_reserved_space)(struct inode___36 *);
	int (*get_projid)(struct inode___36 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___36 *, qsize_t *);
	int (*get_next_id)(struct super_block___35 *, struct kqid *);
};

struct quotactl_ops___34 {
	int (*quota_on)(struct super_block___35 *, int, int, const struct path___34 *);
	int (*quota_off)(struct super_block___35 *, int);
	int (*quota_enable)(struct super_block___35 *, unsigned int);
	int (*quota_disable)(struct super_block___35 *, unsigned int);
	int (*quota_sync)(struct super_block___35 *, int);
	int (*set_info)(struct super_block___35 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___35 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___35 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___35 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___35 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___35 *, unsigned int);
};

struct address_space_operations___34 {
	int (*writepage)(struct page___36 *, struct writeback_control___3 *);
	int (*readpage)(struct file___36 *, struct page___36 *);
	int (*writepages)(struct address_space___34 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___36 *);
	int (*readpages)(struct file___36 *, struct address_space___34 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___36 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___36 **, void **);
	int (*write_end)(struct file___36 *, struct address_space___34 *, loff_t, unsigned int, unsigned int, struct page___36 *, void *);
	sector_t (*bmap)(struct address_space___34 *, sector_t);
	void (*invalidatepage)(struct page___36 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___36 *, gfp_t);
	void (*freepage)(struct page___36 *);
	ssize_t (*direct_IO)(struct kiocb___34 *, struct iov_iter___18 *);
	int (*migratepage)(struct address_space___34 *, struct page___36 *, struct page___36 *, enum migrate_mode);
	bool (*isolate_page)(struct page___36 *, isolate_mode_t);
	void (*putback_page)(struct page___36 *);
	int (*launder_page)(struct page___36 *);
	int (*is_partially_uptodate)(struct page___36 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___36 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___34 *, struct page___36 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___36 *, sector_t *);
	void (*swap_deactivate)(struct file___36 *);
};

struct bio_vec___18;

struct iov_iter___18 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___18 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___9 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___34 {
	struct dentry___35 * (*lookup)(struct inode___36 *, struct dentry___35 *, unsigned int);
	const char * (*get_link)(struct dentry___35 *, struct inode___36 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___36 *, int);
	struct posix_acl * (*get_acl)(struct inode___36 *, int, bool);
	int (*readlink)(struct dentry___35 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___36 *, struct dentry___35 *, umode_t, bool);
	int (*link)(struct dentry___35 *, struct inode___36 *, struct dentry___35 *);
	int (*unlink)(struct inode___36 *, struct dentry___35 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___36 *, struct dentry___35 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___36 *, struct dentry___35 *, umode_t);
	int (*rmdir)(struct inode___36 *, struct dentry___35 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___36 *, struct dentry___35 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___36 *, struct dentry___35 *, struct inode___36 *, struct dentry___35 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___35 *, struct iattr___35 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___34 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___35 *, char *, size_t);
	int (*fiemap)(struct inode___36 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___36 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___36 *, struct dentry___35 *, struct file___36 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___36 *, struct dentry___35 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___36 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___35 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___35 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___34 {
	void (*fl_copy_lock)(struct file_lock___34 *, struct file_lock___34 *);
	void (*fl_release_private)(struct file_lock___34 *);
};

struct lock_manager_operations___34;

struct file_lock___34 {
	struct file_lock___34 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___36 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___34 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___34 *fl_ops;
	const struct lock_manager_operations___34 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___34 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___34 *);
	int (*lm_grant)(struct file_lock___34 *, int);
	bool (*lm_break)(struct file_lock___34 *);
	int (*lm_change)(struct file_lock___34 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___34 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___34 *);
};

struct fasync_struct___34 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___34 *fa_next;
	struct file___36 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___34 {
	struct inode___36 * (*alloc_inode)(struct super_block___35 *);
	void (*destroy_inode)(struct inode___36 *);
	void (*free_inode)(struct inode___36 *);
	void (*dirty_inode)(struct inode___36 *, int);
	int (*write_inode)(struct inode___36 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___36 *);
	void (*evict_inode)(struct inode___36 *);
	void (*put_super)(struct super_block___35 *);
	int (*sync_fs)(struct super_block___35 *, int);
	int (*freeze_super)(struct super_block___35 *);
	int (*freeze_fs)(struct super_block___35 *);
	int (*thaw_super)(struct super_block___35 *);
	int (*unfreeze_fs)(struct super_block___35 *);
	int (*statfs)(struct dentry___35 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___35 *, int *, char *);
	void (*umount_begin)(struct super_block___35 *);
	int (*show_options)(struct seq_file___34 *, struct dentry___35 *);
	int (*show_devname)(struct seq_file___34 *, struct dentry___35 *);
	int (*show_path)(struct seq_file___34 *, struct dentry___35 *);
	int (*show_stats)(struct seq_file___34 *, struct dentry___35 *);
	ssize_t (*quota_read)(struct super_block___35 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___35 *, int, const char *, size_t, loff_t);
	struct dquot___34 ** (*get_dquots)(struct inode___36 *);
	long int (*nr_cached_objects)(struct super_block___35 *, struct shrink_control___14 *);
	long int (*free_cached_objects)(struct super_block___35 *, struct shrink_control___14 *);
	struct file___36 * (*real_loop)(struct file___36 *);
};

struct kernel_param_ops___34 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___34 *);
	int (*get)(char *, const struct kernel_param___34 *);
	void (*free)(void *);
};

struct kparam_array___34;

struct kernel_param___34 {
	const char *name;
	struct module___36 *mod;
	const struct kernel_param_ops___34 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___34 *arr;
	};
};

struct kparam_array___34 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___34 *ops;
	void *elem;
};

struct module_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___34 *, struct module_kobject___34 *, char *);
	ssize_t (*store)(struct module_attribute___34 *, struct module_kobject___34 *, const char *, size_t);
	void (*setup)(struct module___36 *, const char *);
	int (*test)(struct module___36 *);
	void (*free)(struct module___36 *);
};

struct trace_event_class___19;

struct trace_event_call___19 {
	struct list_head list;
	struct trace_event_class___19 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___19 *, struct perf_event___24 *);
};

struct bio_vec___18 {
	struct page___36 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct seq_operations___33 {
	void * (*start)(struct seq_file___34 *, loff_t *);
	void (*stop)(struct seq_file___34 *, void *);
	void * (*next)(struct seq_file___34 *, void *, loff_t *);
	int (*show)(struct seq_file___34 *, void *);
};

struct inet_frags___6;

struct fqdir___6 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___6 *f;
	struct net___7 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___6;

struct inet_frags___6 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___6 *, const void *);
	void (*destructor)(struct inet_frag_queue___6 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___6 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___4 *fragments_tail;
	struct sk_buff___4 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___6 *fqdir;
	struct callback_head rcu;
};

struct dev_pm_ops___31 {
	int (*prepare)(struct device___31 *);
	void (*complete)(struct device___31 *);
	int (*suspend)(struct device___31 *);
	int (*resume)(struct device___31 *);
	int (*freeze)(struct device___31 *);
	int (*thaw)(struct device___31 *);
	int (*poweroff)(struct device___31 *);
	int (*restore)(struct device___31 *);
	int (*suspend_late)(struct device___31 *);
	int (*resume_early)(struct device___31 *);
	int (*freeze_late)(struct device___31 *);
	int (*thaw_early)(struct device___31 *);
	int (*poweroff_late)(struct device___31 *);
	int (*restore_early)(struct device___31 *);
	int (*suspend_noirq)(struct device___31 *);
	int (*resume_noirq)(struct device___31 *);
	int (*freeze_noirq)(struct device___31 *);
	int (*thaw_noirq)(struct device___31 *);
	int (*poweroff_noirq)(struct device___31 *);
	int (*restore_noirq)(struct device___31 *);
	int (*runtime_suspend)(struct device___31 *);
	int (*runtime_resume)(struct device___31 *);
	int (*runtime_idle)(struct device___31 *);
};

struct wakeup_source___31 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___31 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___31 {
	struct dev_pm_ops___31 ops;
	int (*start)(struct device___31 *);
	void (*detach)(struct device___31 *, bool);
	int (*activate)(struct device___31 *);
	void (*sync)(struct device___31 *);
	void (*dismiss)(struct device___31 *);
};

struct bus_type___31 {
	const char *name;
	const char *dev_name;
	struct device___31 *dev_root;
	const struct attribute_group___34 **bus_groups;
	const struct attribute_group___34 **dev_groups;
	const struct attribute_group___34 **drv_groups;
	int (*match)(struct device___31 *, struct device_driver___31 *);
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	int (*probe)(struct device___31 *);
	void (*sync_state)(struct device___31 *);
	void (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*online)(struct device___31 *);
	int (*offline)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	int (*num_vf)(struct device___31 *);
	int (*dma_configure)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___31 {
	const char *name;
	struct bus_type___31 *bus;
	struct module___36 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___31 *);
	void (*sync_state)(struct device___31 *);
	int (*remove)(struct device___31 *);
	void (*shutdown)(struct device___31 *);
	int (*suspend)(struct device___31 *, pm_message_t);
	int (*resume)(struct device___31 *);
	const struct attribute_group___34 **groups;
	const struct attribute_group___34 **dev_groups;
	const struct dev_pm_ops___31 *pm;
	void (*coredump)(struct device___31 *);
	struct driver_private *p;
};

struct device_type___31 {
	const char *name;
	const struct attribute_group___34 **groups;
	int (*uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___31 *);
	const struct dev_pm_ops___31 *pm;
};

struct class___31 {
	const char *name;
	struct module___36 *owner;
	const struct attribute_group___34 **class_groups;
	const struct attribute_group___34 **dev_groups;
	struct kobject___34 *dev_kobj;
	int (*dev_uevent)(struct device___31 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___31 *, umode_t *);
	void (*class_release)(struct class___31 *);
	void (*dev_release)(struct device___31 *);
	int (*shutdown_pre)(struct device___31 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___31 *);
	void (*get_ownership)(struct device___31 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___31 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___9;

struct pipe_buffer___9 {
	struct page___36 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___9 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___9 {
	int (*confirm)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	void (*release)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	bool (*try_steal)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
	bool (*get)(struct pipe_inode_info___9 *, struct pipe_buffer___9 *);
};

struct cftype___27;

struct cgroup_subsys___27 {
	struct cgroup_subsys_state___27 * (*css_alloc)(struct cgroup_subsys_state___27 *);
	int (*css_online)(struct cgroup_subsys_state___27 *);
	void (*css_offline)(struct cgroup_subsys_state___27 *);
	void (*css_released)(struct cgroup_subsys_state___27 *);
	void (*css_free)(struct cgroup_subsys_state___27 *);
	void (*css_reset)(struct cgroup_subsys_state___27 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___27 *, int);
	int (*css_extra_stat_show)(struct seq_file___34 *, struct cgroup_subsys_state___27 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___37 *, struct css_set___27 *);
	void (*cancel_fork)(struct task_struct___37 *, struct css_set___27 *);
	void (*fork)(struct task_struct___37 *);
	void (*exit)(struct task_struct___37 *);
	void (*release)(struct task_struct___37 *);
	void (*bind)(struct cgroup_subsys_state___27 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___27 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___27 *dfl_cftypes;
	struct cftype___27 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___27 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___27 *updated_children;
	struct cgroup___27 *updated_next;
};

struct cgroup_root___27 {
	struct kernfs_root___34 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___27 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___27 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___27 *ss;
	struct list_head node;
	struct kernfs_ops___34 *kf_ops;
	int (*open)(struct kernfs_open_file___34 *);
	void (*release)(struct kernfs_open_file___34 *);
	u64 (*read_u64)(struct cgroup_subsys_state___27 *, struct cftype___27 *);
	s64 (*read_s64)(struct cgroup_subsys_state___27 *, struct cftype___27 *);
	int (*seq_show)(struct seq_file___34 *, void *);
	void * (*seq_start)(struct seq_file___34 *, loff_t *);
	void * (*seq_next)(struct seq_file___34 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___34 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___27 *, struct cftype___27 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___27 *, struct cftype___27 *, s64);
	ssize_t (*write)(struct kernfs_open_file___34 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___34 *, struct poll_table_struct___27 *);
};

struct perf_cpu_context___24;

struct perf_output_handle___24;

struct pmu___24 {
	struct list_head entry;
	struct module___36 *module;
	struct device___31 *dev;
	const struct attribute_group___34 **attr_groups;
	const struct attribute_group___34 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___24 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___24 *);
	void (*pmu_disable)(struct pmu___24 *);
	int (*event_init)(struct perf_event___24 *);
	void (*event_mapped)(struct perf_event___24 *, struct mm_struct___36 *);
	void (*event_unmapped)(struct perf_event___24 *, struct mm_struct___36 *);
	int (*add)(struct perf_event___24 *, int);
	void (*del)(struct perf_event___24 *, int);
	void (*start)(struct perf_event___24 *, int);
	void (*stop)(struct perf_event___24 *, int);
	void (*read)(struct perf_event___24 *);
	void (*start_txn)(struct pmu___24 *, unsigned int);
	int (*commit_txn)(struct pmu___24 *);
	void (*cancel_txn)(struct pmu___24 *);
	int (*event_idx)(struct perf_event___24 *);
	void (*sched_task)(struct perf_event_context___24 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___24 *, struct perf_event_context___24 *);
	void * (*setup_aux)(struct perf_event___24 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___24 *, struct perf_output_handle___24 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___24 *);
	int (*aux_output_match)(struct perf_event___24 *);
	int (*filter_match)(struct perf_event___24 *);
	int (*check_period)(struct perf_event___24 *, u64);
};

struct perf_cpu_context___24 {
	struct perf_event_context___24 ctx;
	struct perf_event_context___24 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___24 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___24 **heap;
	struct perf_event___24 *heap_default[2];
};

struct perf_output_handle___24 {
	struct perf_event___24 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___24 {
	struct cgroup_subsys_state___27 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___19 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___19 *);
	};
};

struct trace_event_class___19 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___19 *, enum trace_reg, void *);
	struct trace_event_fields___19 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___19 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___19 *);
};

struct syscall_metadata___8 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___19 *enter_event;
	struct trace_event_call___19 *exit_event;
};

struct srcu_notifier_head {
	struct mutex mutex;
	struct srcu_struct srcu;
	struct notifier_block *head;
};

struct kobj_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___33 *, struct kobj_attribute___2 *, char *);
	ssize_t (*store)(struct kobject___33 *, struct kobj_attribute___2 *, const char *, size_t);
};

struct kimage___2;

typedef void *kexec_load_t___2(struct kimage___2 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___2 {
	kexec_probe_t *probe;
	kexec_load_t___2 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct kimage___2 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___35 *control_code_page;
	struct page___35 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type;
	unsigned int preserve_context;
	unsigned int file_mode;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___2 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *ima_buffer;
	phys_addr_t ima_buffer_addr;
	size_t ima_buffer_size;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

struct lsmblob {
	u32 secid[4];
};

enum what {
	PROC_EVENT_NONE = 0,
	PROC_EVENT_FORK = 1,
	PROC_EVENT_EXEC = 2,
	PROC_EVENT_UID = 4,
	PROC_EVENT_GID = 64,
	PROC_EVENT_SID = 128,
	PROC_EVENT_PTRACE = 256,
	PROC_EVENT_COMM = 512,
	PROC_EVENT_COREDUMP = 1073741824,
	PROC_EVENT_EXIT = 2147483648,
};

struct kobj_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___30 *, struct kobj_attribute___3 *, char *);
	ssize_t (*store)(struct kobject___30 *, struct kobj_attribute___3 *, const char *, size_t);
};

enum reboot_type {
	BOOT_TRIPLE = 116,
	BOOT_KBD = 107,
	BOOT_BIOS = 98,
	BOOT_ACPI = 97,
	BOOT_EFI = 101,
	BOOT_CF9_FORCE = 112,
	BOOT_CF9_SAFE = 113,
};

typedef void (*dr_release_t___2)(struct device___28 *, void *);

struct vm_area_struct___36;

struct vmacache___36 {
	u64 seqnum;
	struct vm_area_struct___36 *vmas[4];
};

struct page___37;

struct page_frag___36 {
	struct page___37 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___37;

struct uprobe_task___3;

struct task_struct___38 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___38 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___37 *mm;
	struct mm_struct___37 *active_mm;
	struct vmacache___36 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___38 *real_parent;
	struct task_struct___38 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___38 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___33 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___38 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___36 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task___3 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___38 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___24 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___37 *pgtable_t___36;

struct page___37 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___34 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___9 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___37 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___36 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___37 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___34 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	long: 64;
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___36 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___36 *vm_next;
	struct vm_area_struct___36 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___37 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___36;

struct mm_struct___37 {
	struct {
		struct vm_area_struct___36 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___36 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___38 *owner;
		struct user_namespace *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct uprobe_task___3 {
	enum uprobe_task_state state;
	union {
		struct {
			struct arch_uprobe_task autask;
			long unsigned int vaddr;
		};
		struct {
			struct callback_head dup_xol_work;
			long unsigned int dup_xol_addr;
		};
	};
	long: 64;
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	struct return_instance *return_instances;
	unsigned int depth;
};

struct core_thread___36 {
	struct task_struct___38 *task;
	struct core_thread___36 *next;
};

struct core_state___36 {
	atomic_t nr_threads;
	struct core_thread___36 dumper;
	struct completion startup;
};

struct pool_workqueue___2;

struct worker_pool___2;

struct worker___2 {
	union {
		struct list_head entry;
		struct hlist_node hentry;
	};
	struct work_struct *current_work;
	work_func_t current_func;
	struct pool_workqueue___2 *current_pwq;
	unsigned int current_color;
	struct list_head scheduled;
	struct task_struct___38 *task;
	struct worker_pool___2 *pool;
	struct list_head node;
	long unsigned int last_active;
	unsigned int flags;
	int id;
	int sleeping;
	char desc[24];
	struct workqueue_struct *rescue_wq;
	work_func_t last_func;
};

struct async_entry {
	struct list_head domain_list;
	struct list_head global_list;
	struct work_struct work;
	async_cookie_t cookie;
	async_func_t func;
	void *data;
	struct async_domain *domain;
};

struct smp_hotplug_thread___3 {
	struct task_struct___38 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct smpboot_thread_data {
	unsigned int cpu;
	unsigned int status;
	struct smp_hotplug_thread___3 *ht;
};

enum {
	HP_THREAD_NONE = 0,
	HP_THREAD_ACTIVE = 1,
	HP_THREAD_PARKED = 2,
};

struct user_regset___3;

typedef int user_regset_active_fn___3(struct task_struct___38 *, const struct user_regset___3 *);

typedef int user_regset_get2_fn___3(struct task_struct___38 *, const struct user_regset___3 *, struct membuf);

typedef int user_regset_set_fn___3(struct task_struct___38 *, const struct user_regset___3 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___3(struct task_struct___38 *, const struct user_regset___3 *, int);

struct user_regset___3 {
	user_regset_get2_fn___3 *regset_get;
	user_regset_set_fn___3 *set;
	user_regset_active_fn___3 *active;
	user_regset_writeback_fn___3 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___3 {
	const char *name;
	const struct user_regset___3 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct vfsmount___35;

struct dentry___36;

struct path___35 {
	struct vfsmount___35 *mnt;
	struct dentry___36 *dentry;
};

struct pid___34;

struct fown_struct___34 {
	rwlock_t lock;
	struct pid___34 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file_operations___35;

struct address_space___35;

struct file___2 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___35 f_path;
	struct inode___3 *f_inode;
	const struct file_operations___35 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___34 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___35 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct fs_context___4;

struct fs_parameter_spec___4;

struct super_block___36;

struct module___37;

struct file_system_type___35 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___4 *);
	const struct fs_parameter_spec___4 *parameters;
	struct dentry___36 * (*mount)(struct file_system_type___35 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___36 *);
	struct module___37 *owner;
	struct file_system_type___35 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___35;

struct iov_iter___19;

struct vm_area_struct___37;

struct file_lock___35;

struct pipe_inode_info___10;

struct seq_file___35;

struct file_operations___35 {
	struct module___37 *owner;
	loff_t (*llseek)(struct file___2 *, loff_t, int);
	ssize_t (*read)(struct file___2 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___2 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___35 *, struct iov_iter___19 *);
	ssize_t (*write_iter)(struct kiocb___35 *, struct iov_iter___19 *);
	int (*iopoll)(struct kiocb___35 *, bool);
	int (*iterate)(struct file___2 *, struct dir_context *);
	int (*iterate_shared)(struct file___2 *, struct dir_context *);
	__poll_t (*poll)(struct file___2 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___2 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___2 *, struct vm_area_struct___37 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___3 *, struct file___2 *);
	int (*flush)(struct file___2 *, fl_owner_t);
	int (*release)(struct inode___3 *, struct file___2 *);
	int (*fsync)(struct file___2 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___2 *, int);
	int (*lock)(struct file___2 *, int, struct file_lock___35 *);
	ssize_t (*sendpage)(struct file___2 *, struct page___2 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___2 *, long unsigned int);
	int (*flock)(struct file___2 *, int, struct file_lock___35 *);
	ssize_t (*splice_write)(struct pipe_inode_info___10 *, struct file___2 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___2 *, loff_t *, struct pipe_inode_info___10 *, size_t, unsigned int);
	int (*setlease)(struct file___2 *, long int, struct file_lock___35 **, void **);
	long int (*fallocate)(struct file___2 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___35 *, struct file___2 *);
	ssize_t (*copy_file_range)(struct file___2 *, loff_t, struct file___2 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___2 *, loff_t, struct file___2 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___2 *, loff_t, loff_t, int);
};

struct vmacache___37 {
	u64 seqnum;
	struct vm_area_struct___37 *vmas[4];
};

struct page_frag___37 {
	struct page___2 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___38;

struct fs_struct___7;

struct nsproxy___35;

struct signal_struct___36;

struct bio_list___16;

struct backing_dev_info___15;

struct io_context___17;

struct css_set___28;

struct mem_cgroup___15;

struct request_queue___17;

struct vm_struct___36;

struct task_struct___39 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___39 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___38 *mm;
	struct mm_struct___38 *active_mm;
	struct vmacache___37 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___39 *real_parent;
	struct task_struct___39 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___39 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___34 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___7 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___35 *nsproxy;
	struct signal_struct___36 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___39 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___16 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___15 *backing_dev_info;
	struct io_context___17 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___28 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___10 *splice_pipe;
	struct page_frag___37 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___15 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___15 *active_memcg;
	struct request_queue___17 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___39 *oom_reaper_list;
	struct vm_struct___36 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___24 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___35;

struct kobj_type___35;

struct kernfs_node___35;

struct kobject___35 {
	const char *name;
	struct list_head entry;
	struct kobject___35 *parent;
	struct kset___35 *kset;
	struct kobj_type___35 *ktype;
	struct kernfs_node___35 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___35 {
	struct kobject___35 kobj;
	struct module___37 *mod;
	struct kobject___35 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___35 {
	struct module___37 *mod;
	struct latch_tree_node node;
};

struct module_layout___35 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___35 mtn;
};

struct module_attribute___35;

struct kernel_param___35;

struct module___37 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___35 mkobj;
	struct module_attribute___35 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___35 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___35 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___35 core_layout;
	struct module_layout___35 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___2 *pgtable_t___37;

struct dev_pagemap___35;

struct page___2 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___35 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___9 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___2 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___37 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___38 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___35 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___35;

struct vm_area_struct___37 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___37 *vm_next;
	struct vm_area_struct___37 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___38 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___35 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___2 *vm_file;
	struct file___2 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___37;

struct mm_struct___38 {
	struct {
		struct vm_area_struct___37 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___2 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___37 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___39 *owner;
		struct user_namespace___4 *user_ns;
		struct file___2 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___35;

struct address_space___35 {
	struct inode___3 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___35 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___35;

struct dev_pagemap___35 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___35 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___35;

struct vm_operations_struct___35 {
	void (*open)(struct vm_area_struct___37 *);
	void (*close)(struct vm_area_struct___37 *);
	int (*may_split)(struct vm_area_struct___37 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___37 *);
	int (*mprotect)(struct vm_area_struct___37 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___35 *);
	vm_fault_t (*huge_fault)(struct vm_fault___35 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___35 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___37 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___35 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___35 *);
	int (*access)(struct vm_area_struct___37 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___37 *);
	int (*set_policy)(struct vm_area_struct___37 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___37 *, long unsigned int);
	struct page___2 * (*find_special_page)(struct vm_area_struct___37 *, long unsigned int);
};

struct core_thread___37 {
	struct task_struct___39 *task;
	struct core_thread___37 *next;
};

struct core_state___37 {
	atomic_t nr_threads;
	struct core_thread___37 dumper;
	struct completion startup;
};

struct vm_fault___35 {
	const struct {
		struct vm_area_struct___37 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___2 *cow_page;
	struct page___2 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___37 prealloc_pte;
};

struct pglist_data___16;

struct lruvec___16 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___16 *pgdat;
};

struct zone___16 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___16 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___16 {
	struct zone___16 *zone;
	int zone_idx;
};

struct zonelist___16 {
	struct zoneref___16 _zonerefs[321];
};

struct pglist_data___16 {
	struct zone___16 node_zones[5];
	struct zonelist___16 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___39 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___39 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___16 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___34;

struct upid___34 {
	int nr;
	struct pid_namespace___34 *ns;
};

struct pid_namespace___34 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___39 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___34 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___34 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___34 numbers[1];
};

struct signal_struct___36 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___39 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___39 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___34 *pids[4];
	struct pid___34 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___38 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___7 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___35 root;
	struct path___35 pwd;
};

struct cgroup_namespace___28;

struct nsproxy___35 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___34 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___28 *cgroup_ns;
};

struct bio___16;

struct bio_list___16 {
	struct bio___16 *head;
	struct bio___16 *tail;
};

struct cgroup_subsys_state___28;

struct bdi_writeback___15 {
	struct backing_dev_info___15 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___28 *memcg_css;
	struct cgroup_subsys_state___28 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___32;

struct backing_dev_info___15 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___15 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___32 *dev;
	char dev_name[64];
	struct device___32 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___36 *debug_dir;
};

struct io_cq___16;

struct io_context___17 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___16 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___28;

struct css_set___28 {
	struct cgroup_subsys_state___28 *subsys[14];
	refcount_t refcount;
	struct css_set___28 *dom_cset;
	struct cgroup___28 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___28 *mg_src_cgrp;
	struct cgroup___28 *mg_dst_cgrp;
	struct css_set___28 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___35;

struct pipe_buffer___10;

struct pipe_inode_info___10 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___2 *tmp_page;
	struct fasync_struct___35 *fasync_readers;
	struct fasync_struct___35 *fasync_writers;
	struct pipe_buffer___10 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___28;

struct cgroup_subsys_state___28 {
	struct cgroup___28 *cgroup;
	struct cgroup_subsys___28 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___28 *parent;
};

struct cgroup_file___28 {
	struct kernfs_node___35 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___15;

struct mem_cgroup_per_node___15;

struct mem_cgroup___15 {
	struct cgroup_subsys_state___28 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___28 events_file;
	struct cgroup_file___28 events_local_file;
	struct cgroup_file___28 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___15 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___39 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___15 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___16;

struct blk_integrity___16 {
	const struct blk_integrity_profile___16 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___16 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___16 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___16;

struct elevator_queue___16;

struct blk_mq_ops___15;

struct blk_mq_hw_ctx___15;

struct gendisk___16;

struct blkcg_gq___15;

struct blk_mq_tag_set___15;

struct request_queue___17 {
	struct request___16 *last_merge;
	struct elevator_queue___16 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___15 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___15 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___16 *disk;
	struct kobject___35 kobj;
	struct kobject___35 *mq_kobj;
	struct blk_integrity___16 integrity;
	struct device___32 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___15 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___15 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___16 bio_split;
	struct dentry___36 *debugfs_dir;
	struct dentry___36 *sched_debugfs_dir;
	struct dentry___36 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___36 {
	struct vm_struct___36 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___2 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___35;

struct dentry___36 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___36 *d_parent;
	struct qstr d_name;
	struct inode___3 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___35 *d_op;
	struct super_block___36 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___35;

struct inode___3 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___35 *i_op;
	struct super_block___36 *i_sb;
	struct address_space___35 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___15 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___35 *i_fop;
		void (*free_inode)(struct inode___3 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___35 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___10 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___35 {
	int (*d_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___36 *, unsigned int);
	int (*d_hash)(const struct dentry___36 *, struct qstr *);
	int (*d_compare)(const struct dentry___36 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___36 *);
	int (*d_init)(struct dentry___36 *);
	void (*d_release)(struct dentry___36 *);
	void (*d_prune)(struct dentry___36 *);
	void (*d_iput)(struct dentry___36 *, struct inode___3 *);
	char * (*d_dname)(struct dentry___36 *, char *, int);
	struct vfsmount___35 * (*d_automount)(struct path___35 *);
	int (*d_manage)(const struct path___35 *, bool);
	struct dentry___36 * (*d_real)(struct dentry___36 *, const struct inode___3 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___35;

struct mem_dqinfo___35 {
	struct quota_format_type___35 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___35;

struct quota_info___35 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___3 *files[3];
	struct mem_dqinfo___35 info[3];
	const struct quota_format_ops___35 *ops[3];
};

struct rcuwait___35 {
	struct task_struct___39 *task;
};

struct percpu_rw_semaphore___35 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___35 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___35 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___35 rw_sem[3];
};

struct shrink_control___15;

struct shrinker___15 {
	long unsigned int (*count_objects)(struct shrinker___15 *, struct shrink_control___15 *);
	long unsigned int (*scan_objects)(struct shrinker___15 *, struct shrink_control___15 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___35;

struct dquot_operations___35;

struct quotactl_ops___35;

struct xattr_handler___4;

struct block_device___17;

struct super_block___36 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___35 *s_type;
	const struct super_operations___35 *s_op;
	const struct dquot_operations___35 *dq_op;
	const struct quotactl_ops___35 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___36 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___4 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___17 *s_bdev;
	struct backing_dev_info___15 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___35 s_dquot;
	struct sb_writers___35 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___35 *s_d_op;
	int cleancache_poolid;
	struct shrinker___15 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___35 {
	struct dentry___36 *mnt_root;
	struct super_block___36 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct shrink_control___15 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___15 *memcg;
};

struct psi_group___28 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___39 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___28;

struct cgroup_rstat_cpu___28;

struct cgroup___28 {
	struct cgroup_subsys_state___28 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___35 *kn;
	struct cgroup_file___28 procs_file;
	struct cgroup_file___28 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___28 *subsys[14];
	struct cgroup_root___28 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___28 *dom_cgrp;
	struct cgroup___28 *old_dom_cgrp;
	struct cgroup_rstat_cpu___28 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___28 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___16 {
	struct request_queue___17 *q;
	struct io_context___17 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___17;

struct kiocb___35 {
	struct file___2 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___35 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___17 *ki_waitq;
	};
};

struct iattr___36 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___2 *ia_file;
};

struct dquot___35 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___36 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___35 {
	int qf_fmt_id;
	const struct quota_format_ops___35 *qf_ops;
	struct module___37 *qf_owner;
	struct quota_format_type___35 *qf_next;
};

struct quota_format_ops___35 {
	int (*check_quota_file)(struct super_block___36 *, int);
	int (*read_file_info)(struct super_block___36 *, int);
	int (*write_file_info)(struct super_block___36 *, int);
	int (*free_file_info)(struct super_block___36 *, int);
	int (*read_dqblk)(struct dquot___35 *);
	int (*commit_dqblk)(struct dquot___35 *);
	int (*release_dqblk)(struct dquot___35 *);
	int (*get_next_id)(struct super_block___36 *, struct kqid *);
};

struct dquot_operations___35 {
	int (*write_dquot)(struct dquot___35 *);
	struct dquot___35 * (*alloc_dquot)(struct super_block___36 *, int);
	void (*destroy_dquot)(struct dquot___35 *);
	int (*acquire_dquot)(struct dquot___35 *);
	int (*release_dquot)(struct dquot___35 *);
	int (*mark_dirty)(struct dquot___35 *);
	int (*write_info)(struct super_block___36 *, int);
	qsize_t * (*get_reserved_space)(struct inode___3 *);
	int (*get_projid)(struct inode___3 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___3 *, qsize_t *);
	int (*get_next_id)(struct super_block___36 *, struct kqid *);
};

struct quotactl_ops___35 {
	int (*quota_on)(struct super_block___36 *, int, int, const struct path___35 *);
	int (*quota_off)(struct super_block___36 *, int);
	int (*quota_enable)(struct super_block___36 *, unsigned int);
	int (*quota_disable)(struct super_block___36 *, unsigned int);
	int (*quota_sync)(struct super_block___36 *, int);
	int (*set_info)(struct super_block___36 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___36 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___36 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___36 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___36 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___36 *, unsigned int);
};

struct wait_page_queue___17 {
	struct page___2 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___15;

struct readahead_control___17;

struct swap_info_struct___11;

struct address_space_operations___35 {
	int (*writepage)(struct page___2 *, struct writeback_control___15 *);
	int (*readpage)(struct file___2 *, struct page___2 *);
	int (*writepages)(struct address_space___35 *, struct writeback_control___15 *);
	int (*set_page_dirty)(struct page___2 *);
	int (*readpages)(struct file___2 *, struct address_space___35 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___17 *);
	int (*write_begin)(struct file___2 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___2 **, void **);
	int (*write_end)(struct file___2 *, struct address_space___35 *, loff_t, unsigned int, unsigned int, struct page___2 *, void *);
	sector_t (*bmap)(struct address_space___35 *, sector_t);
	void (*invalidatepage)(struct page___2 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___2 *, gfp_t);
	void (*freepage)(struct page___2 *);
	ssize_t (*direct_IO)(struct kiocb___35 *, struct iov_iter___19 *);
	int (*migratepage)(struct address_space___35 *, struct page___2 *, struct page___2 *, enum migrate_mode);
	bool (*isolate_page)(struct page___2 *, isolate_mode_t);
	void (*putback_page)(struct page___2 *);
	int (*launder_page)(struct page___2 *);
	int (*is_partially_uptodate)(struct page___2 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___2 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___35 *, struct page___2 *);
	int (*swap_activate)(struct swap_info_struct___11 *, struct file___2 *, sector_t *);
	void (*swap_deactivate)(struct file___2 *);
};

struct writeback_control___15 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___15 *wb;
	struct inode___3 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___17 {
	struct file___2 *file;
	struct address_space___35 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___19;

struct iov_iter___19 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___19 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___10 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___11 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___17 *bdev;
	struct file___2 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___35 {
	struct dentry___36 * (*lookup)(struct inode___3 *, struct dentry___36 *, unsigned int);
	const char * (*get_link)(struct dentry___36 *, struct inode___3 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___3 *, int);
	struct posix_acl * (*get_acl)(struct inode___3 *, int, bool);
	int (*readlink)(struct dentry___36 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___3 *, struct dentry___36 *, umode_t, bool);
	int (*link)(struct dentry___36 *, struct inode___3 *, struct dentry___36 *);
	int (*unlink)(struct inode___3 *, struct dentry___36 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___3 *, struct dentry___36 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___3 *, struct dentry___36 *, umode_t);
	int (*rmdir)(struct inode___3 *, struct dentry___36 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___3 *, struct dentry___36 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___3 *, struct dentry___36 *, struct inode___3 *, struct dentry___36 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___36 *, struct iattr___36 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___35 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___36 *, char *, size_t);
	int (*fiemap)(struct inode___3 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___3 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___3 *, struct dentry___36 *, struct file___2 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___3 *, struct dentry___36 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___3 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___36 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___36 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___35 {
	void (*fl_copy_lock)(struct file_lock___35 *, struct file_lock___35 *);
	void (*fl_release_private)(struct file_lock___35 *);
};

struct lock_manager_operations___35;

struct file_lock___35 {
	struct file_lock___35 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___2 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___35 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___35 *fl_ops;
	const struct lock_manager_operations___35 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___35 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___35 *);
	int (*lm_grant)(struct file_lock___35 *, int);
	bool (*lm_break)(struct file_lock___35 *);
	int (*lm_change)(struct file_lock___35 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___35 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___35 *);
};

struct fasync_struct___35 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___35 *fa_next;
	struct file___2 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___35 {
	struct inode___3 * (*alloc_inode)(struct super_block___36 *);
	void (*destroy_inode)(struct inode___3 *);
	void (*free_inode)(struct inode___3 *);
	void (*dirty_inode)(struct inode___3 *, int);
	int (*write_inode)(struct inode___3 *, struct writeback_control___15 *);
	int (*drop_inode)(struct inode___3 *);
	void (*evict_inode)(struct inode___3 *);
	void (*put_super)(struct super_block___36 *);
	int (*sync_fs)(struct super_block___36 *, int);
	int (*freeze_super)(struct super_block___36 *);
	int (*freeze_fs)(struct super_block___36 *);
	int (*thaw_super)(struct super_block___36 *);
	int (*unfreeze_fs)(struct super_block___36 *);
	int (*statfs)(struct dentry___36 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___36 *, int *, char *);
	void (*umount_begin)(struct super_block___36 *);
	int (*show_options)(struct seq_file___35 *, struct dentry___36 *);
	int (*show_devname)(struct seq_file___35 *, struct dentry___36 *);
	int (*show_path)(struct seq_file___35 *, struct dentry___36 *);
	int (*show_stats)(struct seq_file___35 *, struct dentry___36 *);
	ssize_t (*quota_read)(struct super_block___36 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___36 *, int, const char *, size_t, loff_t);
	struct dquot___35 ** (*get_dquots)(struct inode___3 *);
	long int (*nr_cached_objects)(struct super_block___36 *, struct shrink_control___15 *);
	long int (*free_cached_objects)(struct super_block___36 *, struct shrink_control___15 *);
	struct file___2 * (*real_loop)(struct file___2 *);
};

struct xattr_handler___4 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___36 *);
	int (*get)(const struct xattr_handler___4 *, struct dentry___36 *, struct inode___3 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___4 *, struct user_namespace___4 *, struct dentry___36 *, struct inode___3 *, const char *, const void *, size_t, int);
};

struct wakeup_source___32;

struct dev_pm_info___32 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___32 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___32 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___32;

struct bus_type___32;

struct device_driver___32;

struct dev_pm_domain___32;

struct fwnode_handle___32;

struct class___32;

struct attribute_group___35;

struct device___32 {
	struct kobject___35 kobj;
	struct device___32 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___32 *type;
	struct bus_type___32 *bus;
	struct device_driver___32 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___32 power;
	struct dev_pm_domain___32 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___32 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___32 *class;
	const struct attribute_group___35 **groups;
	void (*release)(struct device___32 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___17 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___3 *bd_inode;
	struct super_block___36 *bd_super;
	void *bd_claiming;
	struct device___32 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___35 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___16 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___36 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___34;

struct seq_file___35 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___34 *op;
	int poll_event;
	const struct file___2 *file;
	void *private;
};

struct fc_log___4;

struct p_log___4 {
	const char *prefix;
	struct fc_log___4 *log;
};

struct fs_context_operations___4;

struct fs_context___4 {
	const struct fs_context_operations___4 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___35 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___36 *root;
	struct user_namespace___4 *user_ns;
	struct net *net_ns;
	const struct cred___3 *cred;
	struct p_log___4 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___4;

typedef int fs_param_type___4(struct p_log___4 *, const struct fs_parameter_spec___4 *, struct fs_parameter___4 *, struct fs_parse_result *);

struct fs_parameter_spec___4 {
	const char *name;
	fs_param_type___4 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___16(struct bio___16 *);

struct bio_vec___19 {
	struct page___2 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___16;

struct bio___16 {
	struct bio___16 *bi_next;
	struct block_device___17 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___16 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___15 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___16 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___19 *bi_io_vec;
	struct bio_set___16 *bi_pool;
	struct bio_vec___19 bi_inline_vecs[0];
};

struct seq_operations___34 {
	void * (*start)(struct seq_file___35 *, loff_t *);
	void (*stop)(struct seq_file___35 *, void *);
	void * (*next)(struct seq_file___35 *, void *, loff_t *);
	int (*show)(struct seq_file___35 *, void *);
};

struct kernfs_root___35;

struct kernfs_elem_dir___35 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___35 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___35;

struct kernfs_root___35 {
	struct kernfs_node___35 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___35 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___35 {
	struct kernfs_node___35 *target_kn;
};

struct kernfs_ops___35;

struct kernfs_elem_attr___35 {
	const struct kernfs_ops___35 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___35 *notify_next;
};

struct kernfs_node___35 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___35 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___35 dir;
		struct kernfs_elem_symlink___35 symlink;
		struct kernfs_elem_attr___35 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___35;

struct kernfs_ops___35 {
	int (*open)(struct kernfs_open_file___35 *);
	void (*release)(struct kernfs_open_file___35 *);
	int (*seq_show)(struct seq_file___35 *, void *);
	void * (*seq_start)(struct seq_file___35 *, loff_t *);
	void * (*seq_next)(struct seq_file___35 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___35 *, void *);
	ssize_t (*read)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___35 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___35 *, struct vm_area_struct___37 *);
};

struct kernfs_syscall_ops___35 {
	int (*show_options)(struct seq_file___35 *, struct kernfs_root___35 *);
	int (*mkdir)(struct kernfs_node___35 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___35 *);
	int (*rename)(struct kernfs_node___35 *, struct kernfs_node___35 *, const char *);
	int (*show_path)(struct seq_file___35 *, struct kernfs_node___35 *, struct kernfs_root___35 *);
};

struct kernfs_open_file___35 {
	struct kernfs_node___35 *kn;
	struct file___2 *file;
	struct seq_file___35 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___35 *vm_ops;
};

struct cgroup_namespace___28 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___28 *root_cset;
};

struct fwnode_operations___32;

struct fwnode_handle___32 {
	struct fwnode_handle___32 *secondary;
	const struct fwnode_operations___32 *ops;
	struct device___32 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___32;

struct fwnode_endpoint___32;

struct fwnode_operations___32 {
	struct fwnode_handle___32 * (*get)(struct fwnode_handle___32 *);
	void (*put)(struct fwnode_handle___32 *);
	bool (*device_is_available)(const struct fwnode_handle___32 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___32 *, const struct device___32 *);
	bool (*property_present)(const struct fwnode_handle___32 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___32 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___32 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___32 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_parent)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_next_child_node)(const struct fwnode_handle___32 *, struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*get_named_child_node)(const struct fwnode_handle___32 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___32 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___32 *);
	struct fwnode_handle___32 * (*graph_get_next_endpoint)(const struct fwnode_handle___32 *, struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*graph_get_remote_endpoint)(const struct fwnode_handle___32 *);
	struct fwnode_handle___32 * (*graph_get_port_parent)(struct fwnode_handle___32 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___32 *, struct fwnode_endpoint___32 *);
	int (*add_links)(struct fwnode_handle___32 *);
};

struct fwnode_endpoint___32 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___32 *local_fwnode;
};

struct fwnode_reference_args___32 {
	struct fwnode_handle___32 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___35;

struct attribute_group___35 {
	const char *name;
	umode_t (*is_visible)(struct kobject___35 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___35 *, struct bin_attribute___35 *, int);
	struct attribute **attrs;
	struct bin_attribute___35 **bin_attrs;
};

struct bin_attribute___35 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___35 * (*f_mapping)();
	ssize_t (*read)(struct file___2 *, struct kobject___35 *, struct bin_attribute___35 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___2 *, struct kobject___35 *, struct bin_attribute___35 *, char *, loff_t, size_t);
	int (*mmap)(struct file___2 *, struct kobject___35 *, struct bin_attribute___35 *, struct vm_area_struct___37 *);
};

struct sysfs_ops___35 {
	ssize_t (*show)(struct kobject___35 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___35 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___35;

struct kset___35 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___35 kobj;
	const struct kset_uevent_ops___35 *uevent_ops;
};

struct kobj_type___35 {
	void (*release)(struct kobject___35 *);
	const struct sysfs_ops___35 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___35 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___35 *);
	const void * (*namespace)(struct kobject___35 *);
	void (*get_ownership)(struct kobject___35 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___35 {
	int (* const filter)(struct kset___35 *, struct kobject___35 *);
	const char * (* const name)(struct kset___35 *, struct kobject___35 *);
	int (* const uevent)(struct kset___35 *, struct kobject___35 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___35 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___35 *);
	int (*get)(char *, const struct kernel_param___35 *);
	void (*free)(void *);
};

struct kparam_array___35;

struct kernel_param___35 {
	const char *name;
	struct module___37 *mod;
	const struct kernel_param_ops___35 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___35 *arr;
	};
};

struct kparam_array___35 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___35 *ops;
	void *elem;
};

struct module_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___35 *, struct module_kobject___35 *, char *);
	ssize_t (*store)(struct module_attribute___35 *, struct module_kobject___35 *, const char *, size_t);
	void (*setup)(struct module___37 *, const char *);
	int (*test)(struct module___37 *);
	void (*free)(struct module___37 *);
};

struct dev_pagemap_ops___35 {
	void (*page_free)(struct page___2 *);
	void (*kill)(struct dev_pagemap___35 *);
	void (*cleanup)(struct dev_pagemap___35 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___35 *);
};

struct cftype___28;

struct cgroup_subsys___28 {
	struct cgroup_subsys_state___28 * (*css_alloc)(struct cgroup_subsys_state___28 *);
	int (*css_online)(struct cgroup_subsys_state___28 *);
	void (*css_offline)(struct cgroup_subsys_state___28 *);
	void (*css_released)(struct cgroup_subsys_state___28 *);
	void (*css_free)(struct cgroup_subsys_state___28 *);
	void (*css_reset)(struct cgroup_subsys_state___28 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___28 *, int);
	int (*css_extra_stat_show)(struct seq_file___35 *, struct cgroup_subsys_state___28 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___39 *, struct css_set___28 *);
	void (*cancel_fork)(struct task_struct___39 *, struct css_set___28 *);
	void (*fork)(struct task_struct___39 *);
	void (*exit)(struct task_struct___39 *);
	void (*release)(struct task_struct___39 *);
	void (*bind)(struct cgroup_subsys_state___28 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___28 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___28 *dfl_cftypes;
	struct cftype___28 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___28 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___28 *updated_children;
	struct cgroup___28 *updated_next;
};

struct cgroup_root___28 {
	struct kernfs_root___35 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___28 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___28 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___28 *ss;
	struct list_head node;
	struct kernfs_ops___35 *kf_ops;
	int (*open)(struct kernfs_open_file___35 *);
	void (*release)(struct kernfs_open_file___35 *);
	u64 (*read_u64)(struct cgroup_subsys_state___28 *, struct cftype___28 *);
	s64 (*read_s64)(struct cgroup_subsys_state___28 *, struct cftype___28 *);
	int (*seq_show)(struct seq_file___35 *, void *);
	void * (*seq_start)(struct seq_file___35 *, loff_t *);
	void * (*seq_next)(struct seq_file___35 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___35 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___28 *, struct cftype___28 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___28 *, struct cftype___28 *, s64);
	ssize_t (*write)(struct kernfs_open_file___35 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___35 *, struct poll_table_struct___5 *);
};

struct dev_pm_ops___32 {
	int (*prepare)(struct device___32 *);
	void (*complete)(struct device___32 *);
	int (*suspend)(struct device___32 *);
	int (*resume)(struct device___32 *);
	int (*freeze)(struct device___32 *);
	int (*thaw)(struct device___32 *);
	int (*poweroff)(struct device___32 *);
	int (*restore)(struct device___32 *);
	int (*suspend_late)(struct device___32 *);
	int (*resume_early)(struct device___32 *);
	int (*freeze_late)(struct device___32 *);
	int (*thaw_early)(struct device___32 *);
	int (*poweroff_late)(struct device___32 *);
	int (*restore_early)(struct device___32 *);
	int (*suspend_noirq)(struct device___32 *);
	int (*resume_noirq)(struct device___32 *);
	int (*freeze_noirq)(struct device___32 *);
	int (*thaw_noirq)(struct device___32 *);
	int (*poweroff_noirq)(struct device___32 *);
	int (*restore_noirq)(struct device___32 *);
	int (*runtime_suspend)(struct device___32 *);
	int (*runtime_resume)(struct device___32 *);
	int (*runtime_idle)(struct device___32 *);
};

struct wakeup_source___32 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___32 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___32 {
	struct dev_pm_ops___32 ops;
	int (*start)(struct device___32 *);
	void (*detach)(struct device___32 *, bool);
	int (*activate)(struct device___32 *);
	void (*sync)(struct device___32 *);
	void (*dismiss)(struct device___32 *);
};

struct bus_type___32 {
	const char *name;
	const char *dev_name;
	struct device___32 *dev_root;
	const struct attribute_group___35 **bus_groups;
	const struct attribute_group___35 **dev_groups;
	const struct attribute_group___35 **drv_groups;
	int (*match)(struct device___32 *, struct device_driver___32 *);
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	int (*probe)(struct device___32 *);
	void (*sync_state)(struct device___32 *);
	void (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*online)(struct device___32 *);
	int (*offline)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	int (*num_vf)(struct device___32 *);
	int (*dma_configure)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___32 {
	const char *name;
	struct bus_type___32 *bus;
	struct module___37 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___32 *);
	void (*sync_state)(struct device___32 *);
	int (*remove)(struct device___32 *);
	void (*shutdown)(struct device___32 *);
	int (*suspend)(struct device___32 *, pm_message_t);
	int (*resume)(struct device___32 *);
	const struct attribute_group___35 **groups;
	const struct attribute_group___35 **dev_groups;
	const struct dev_pm_ops___32 *pm;
	void (*coredump)(struct device___32 *);
	struct driver_private *p;
};

struct device_type___32 {
	const char *name;
	const struct attribute_group___35 **groups;
	int (*uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___32 *);
	const struct dev_pm_ops___32 *pm;
};

struct class___32 {
	const char *name;
	struct module___37 *owner;
	const struct attribute_group___35 **class_groups;
	const struct attribute_group___35 **dev_groups;
	struct kobject___35 *dev_kobj;
	int (*dev_uevent)(struct device___32 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___32 *, umode_t *);
	void (*class_release)(struct class___32 *);
	void (*dev_release)(struct device___32 *);
	int (*shutdown_pre)(struct device___32 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___32 *);
	void (*get_ownership)(struct device___32 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___32 *pm;
	struct subsys_private *p;
};

struct block_device_operations___16;

struct gendisk___16 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___17 *part0;
	const struct block_device_operations___16 *fops;
	struct request_queue___17 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___15 *bdi;
	struct kobject___35 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___35 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___16 {
	struct bio___16 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___19 *bip_vec;
	struct bio_vec___19 bip_inline_vecs[0];
};

struct blkcg___15;

struct blkg_policy_data___15;

struct blkcg_gq___15 {
	struct request_queue___17 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___15 *blkcg;
	struct blkcg_gq___15 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___15 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___16 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___16(struct request___16 *);

typedef void integrity_complete_fn___16(struct request___16 *, unsigned int);

struct blk_integrity_profile___16 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___16 *prepare_fn;
	integrity_complete_fn___16 *complete_fn;
	const char *name;
};

struct block_device_operations___16 {
	blk_qc_t (*submit_bio)(struct bio___16 *);
	int (*open)(struct block_device___17 *, fmode_t);
	void (*release)(struct gendisk___16 *, fmode_t);
	int (*rw_page)(struct block_device___17 *, sector_t, struct page___2 *, unsigned int);
	int (*ioctl)(struct block_device___17 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___17 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___16 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___16 *);
	int (*getgeo)(struct block_device___17 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___17 *, bool);
	void (*swap_slot_free_notify)(struct block_device___17 *, long unsigned int);
	int (*report_zones)(struct gendisk___16 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___16 *, umode_t *);
	struct module___37 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___16 *, sector_t *);
};

typedef void rq_end_io_fn___16(struct request___16 *, blk_status_t);

struct request___16 {
	struct request_queue___17 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___15 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___16 *bio;
	struct bio___16 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___19 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___16 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___16 *saved_end_io;
		} flush;
	};
	struct gendisk___16 *rq_disk;
	struct block_device___17 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___16 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___15 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___17 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___35 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___36 *debugfs_dir;
	struct dentry___36 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___16;

struct elevator_mq_ops___16 {
	int (*init_sched)(struct request_queue___17 *, struct elevator_type___16 *);
	void (*exit_sched)(struct elevator_queue___16 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___15 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___15 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___15 *);
	bool (*allow_merge)(struct request_queue___17 *, struct request___16 *, struct bio___16 *);
	bool (*bio_merge)(struct request_queue___17 *, struct bio___16 *, unsigned int);
	int (*request_merge)(struct request_queue___17 *, struct request___16 **, struct bio___16 *);
	void (*request_merged)(struct request_queue___17 *, struct request___16 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___17 *, struct request___16 *, struct request___16 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___16 *);
	void (*finish_request)(struct request___16 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___15 *, struct list_head *, bool);
	struct request___16 * (*dispatch_request)(struct blk_mq_hw_ctx___15 *);
	bool (*has_work)(struct blk_mq_hw_ctx___15 *);
	void (*completed_request)(struct request___16 *, u64);
	void (*requeue_request)(struct request___16 *);
	struct request___16 * (*former_request)(struct request_queue___17 *, struct request___16 *);
	struct request___16 * (*next_request)(struct request_queue___17 *, struct request___16 *);
	void (*init_icq)(struct io_cq___16 *);
	void (*exit_icq)(struct io_cq___16 *);
};

struct elv_fs_entry___16;

struct elevator_type___16 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___16 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___16 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___37 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___16 {
	struct elevator_type___16 *type;
	void *elevator_data;
	struct kobject___35 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___16 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___16 *, char *);
	ssize_t (*store)(struct elevator_queue___16 *, const char *, size_t);
};

struct blk_mq_queue_data___15;

struct blk_mq_ops___15 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___15 *, const struct blk_mq_queue_data___15 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___15 *);
	int (*get_budget)(struct request_queue___17 *);
	void (*put_budget)(struct request_queue___17 *, int);
	void (*set_rq_budget_token)(struct request___16 *, int);
	int (*get_rq_budget_token)(struct request___16 *);
	enum blk_eh_timer_return (*timeout)(struct request___16 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___15 *);
	void (*complete)(struct request___16 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___15 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___15 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___15 *, struct request___16 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___15 *, struct request___16 *, unsigned int);
	void (*initialize_rq_fn)(struct request___16 *);
	void (*cleanup_rq)(struct request___16 *);
	bool (*busy)(struct request_queue___17 *);
	int (*map_queues)(struct blk_mq_tag_set___15 *);
	void (*show_rq)(struct seq_file___35 *, struct request___16 *);
};

struct blk_mq_tag_set___15 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___15 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___15 {
	struct request___16 *rq;
	bool last;
};

struct blkcg_policy_data___15;

struct blkcg___15 {
	struct cgroup_subsys_state___28 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___15 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___15 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___15 {
	struct blkcg___15 *blkcg;
	int plid;
};

struct blkg_policy_data___15 {
	struct blkcg_gq___15 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___15 {
	struct mem_cgroup___15 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___15 {
	struct lruvec___16 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___15 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___15 *memcg;
};

struct obj_cgroup___15 {
	struct percpu_ref refcnt;
	struct mem_cgroup___15 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fs_parameter___4 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___2 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___4 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___37 *owner;
	char *buffer[8];
};

struct fs_context_operations___4 {
	void (*free)(struct fs_context___4 *);
	int (*dup)(struct fs_context___4 *, struct fs_context___4 *);
	int (*parse_param)(struct fs_context___4 *, struct fs_parameter___4 *);
	int (*parse_monolithic)(struct fs_context___4 *, void *);
	int (*get_tree)(struct fs_context___4 *);
	int (*reconfigure)(struct fs_context___4 *);
};

struct pipe_buf_operations___10;

struct pipe_buffer___10 {
	struct page___2 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___10 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___10 {
	int (*confirm)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	void (*release)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	bool (*try_steal)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
	bool (*get)(struct pipe_inode_info___10 *, struct pipe_buffer___10 *);
};

struct umd_info {
	const char *driver_name;
	struct file___2 *pipe_to_umh;
	struct file___2 *pipe_from_umh;
	struct path___35 wd;
	struct pid___34 *tgid;
};

struct dentry___37;

struct super_block___37;

struct module___38;

struct file_system_type___36 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___37 * (*mount)(struct file_system_type___36 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___37 *);
	struct module___38 *owner;
	struct file_system_type___36 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct pin_cookie {};

struct file___37;

struct kiocb___36;

struct iov_iter___20;

struct poll_table_struct___28;

struct vm_area_struct___38;

struct inode___37;

struct file_lock___36;

struct page___38;

struct pipe_inode_info___11;

struct seq_file___36;

struct file_operations___36 {
	struct module___38 *owner;
	loff_t (*llseek)(struct file___37 *, loff_t, int);
	ssize_t (*read)(struct file___37 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___37 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___36 *, struct iov_iter___20 *);
	ssize_t (*write_iter)(struct kiocb___36 *, struct iov_iter___20 *);
	int (*iopoll)(struct kiocb___36 *, bool);
	int (*iterate)(struct file___37 *, struct dir_context *);
	int (*iterate_shared)(struct file___37 *, struct dir_context *);
	__poll_t (*poll)(struct file___37 *, struct poll_table_struct___28 *);
	long int (*unlocked_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___37 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___37 *, struct vm_area_struct___38 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___37 *, struct file___37 *);
	int (*flush)(struct file___37 *, fl_owner_t);
	int (*release)(struct inode___37 *, struct file___37 *);
	int (*fsync)(struct file___37 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___37 *, int);
	int (*lock)(struct file___37 *, int, struct file_lock___36 *);
	ssize_t (*sendpage)(struct file___37 *, struct page___38 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___37 *, long unsigned int);
	int (*flock)(struct file___37 *, int, struct file_lock___36 *);
	ssize_t (*splice_write)(struct pipe_inode_info___11 *, struct file___37 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___37 *, loff_t *, struct pipe_inode_info___11 *, size_t, unsigned int);
	int (*setlease)(struct file___37 *, long int, struct file_lock___36 **, void **);
	long int (*fallocate)(struct file___37 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___36 *, struct file___37 *);
	ssize_t (*copy_file_range)(struct file___37 *, loff_t, struct file___37 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___37 *, loff_t, struct file___37 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___37 *, loff_t, loff_t, int);
};

struct preempt_notifier___6;

struct task_struct___40;

struct preempt_ops___6 {
	void (*sched_in)(struct preempt_notifier___6 *, int);
	void (*sched_out)(struct preempt_notifier___6 *, struct task_struct___40 *);
};

struct preempt_notifier___6 {
	struct hlist_node link;
	struct preempt_ops___6 *ops;
};

struct vmacache___38 {
	u64 seqnum;
	struct vm_area_struct___38 *vmas[4];
};

struct page_frag___38 {
	struct page___38 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___25;

struct debug_info___25 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___25 *hbp_break[16];
	struct perf_event___25 *hbp_watch[16];
};

struct thread_struct___25 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___25 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct sched_class___2;

struct task_group___2;

struct mm_struct___39;

struct pid___35;

struct nsproxy___36;

struct signal_struct___37;

struct bio_list___17;

struct backing_dev_info___16;

struct io_context___18;

struct css_set___29;

struct perf_event_context___25;

struct mem_cgroup___16;

struct request_queue___18;

struct vm_struct___37;

struct task_struct___40 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___40 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___2 *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group___2 *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___39 *mm;
	struct mm_struct___39 *active_mm;
	struct vmacache___38 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___40 *real_parent;
	struct task_struct___40 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___40 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___35 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___36 *nsproxy;
	struct signal_struct___37 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___40 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___17 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___16 *backing_dev_info;
	struct io_context___18 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___29 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___25 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___11 *splice_pipe;
	struct page_frag___38 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___16 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___16 *active_memcg;
	struct request_queue___18 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___40 *oom_reaper_list;
	struct vm_struct___37 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___25 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	CSD_FLAG_LOCK = 1,
	IRQ_WORK_PENDING = 1,
	IRQ_WORK_BUSY = 2,
	IRQ_WORK_LAZY = 4,
	IRQ_WORK_HARD_IRQ = 8,
	IRQ_WORK_CLAIMED = 3,
	CSD_TYPE_ASYNC = 0,
	CSD_TYPE_SYNC = 16,
	CSD_TYPE_IRQ_WORK = 32,
	CSD_TYPE_TTWU = 48,
	CSD_FLAG_TYPE_MASK = 240,
};

typedef struct __call_single_data call_single_data_t;

struct kset___36;

struct kobj_type___36;

struct kernfs_node___36;

struct kobject___36 {
	const char *name;
	struct list_head entry;
	struct kobject___36 *parent;
	struct kset___36 *kset;
	struct kobj_type___36 *ktype;
	struct kernfs_node___36 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___36 {
	struct kobject___36 kobj;
	struct module___38 *mod;
	struct kobject___36 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___36 {
	struct module___38 *mod;
	struct latch_tree_node node;
};

struct module_layout___36 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___36 mtn;
};

struct module_attribute___36;

struct kernel_param___36;

struct trace_event_call___20;

struct module___38 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___36 mkobj;
	struct module_attribute___36 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___36 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___36 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___36 core_layout;
	struct module_layout___36 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___20 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___25 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___40 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___25)(struct perf_event___25 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___25;

struct fasync_struct___36;

struct pid_namespace___35;

struct perf_cgroup___25;

struct perf_event___25 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___25 *group_leader;
	struct pmu___25 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___25 hw;
	struct perf_event_context___25 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___25 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___40 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___36 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___25 *aux_event;
	void (*destroy)(struct perf_event___25 *);
	struct callback_head callback_head;
	struct pid_namespace___35 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___25 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___25 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___20 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___25 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___35 {
	int nr;
	struct pid_namespace___35 *ns;
};

struct pid_namespace___35 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___40 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___35 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___35 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___35 numbers[1];
};

typedef struct page___38 *pgtable_t___38;

struct address_space___36;

struct page_pool___10;

struct dev_pagemap___36;

struct page___38 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___36 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___10 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___38 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___38 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___39 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___36 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___36;

struct vm_area_struct___38 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___38 *vm_next;
	struct vm_area_struct___38 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___39 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___36 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___37 *vm_file;
	struct file___37 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct autogroup___2;

struct signal_struct___37 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___40 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___40 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___35 *pids[4];
	struct pid___35 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___2 *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___39 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct dl_bw {
	raw_spinlock_t lock;
	u64 bw;
	u64 total_bw;
};

struct cpudl_item;

struct cpudl {
	raw_spinlock_t lock;
	int size;
	cpumask_var_t free_cpus;
	struct cpudl_item *elements;
};

struct cpupri_vec {
	atomic_t count;
	cpumask_var_t mask;
};

struct cpupri {
	struct cpupri_vec pri_to_cpu[101];
	int *cpu_to_pri;
};

struct perf_domain;

struct root_domain {
	atomic_t refcount;
	atomic_t rto_count;
	struct callback_head rcu;
	cpumask_var_t span;
	cpumask_var_t online;
	int overload;
	int overutilized;
	cpumask_var_t dlo_mask;
	atomic_t dlo_count;
	struct dl_bw dl_bw;
	struct cpudl cpudl;
	u64 visit_gen;
	struct irq_work rto_push_work;
	raw_spinlock_t rto_lock;
	int rto_loop;
	int rto_cpu;
	atomic_t rto_loop_next;
	atomic_t rto_loop_start;
	cpumask_var_t rto_mask;
	struct cpupri cpupri;
	long unsigned int max_cpu_capacity;
	struct perf_domain *pd;
};

struct rq___2;

struct cfs_rq {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity *curr;
	struct sched_entity *next;
	struct sched_entity *last;
	struct sched_entity *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity *h_load_next;
	struct rq___2 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___2 *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sched_class___2 {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq___2 *, struct task_struct___40 *, int);
	void (*dequeue_task)(struct rq___2 *, struct task_struct___40 *, int);
	void (*yield_task)(struct rq___2 *);
	bool (*yield_to_task)(struct rq___2 *, struct task_struct___40 *);
	void (*check_preempt_curr)(struct rq___2 *, struct task_struct___40 *, int);
	struct task_struct___40 * (*pick_next_task)(struct rq___2 *);
	void (*put_prev_task)(struct rq___2 *, struct task_struct___40 *);
	void (*set_next_task)(struct rq___2 *, struct task_struct___40 *, bool);
	int (*balance)(struct rq___2 *, struct task_struct___40 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___40 *, int, int);
	struct task_struct___40 * (*pick_task)(struct rq___2 *);
	void (*migrate_task_rq)(struct task_struct___40 *, int);
	void (*task_woken)(struct rq___2 *, struct task_struct___40 *);
	void (*set_cpus_allowed)(struct task_struct___40 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq___2 *);
	void (*rq_offline)(struct rq___2 *);
	struct rq___2 * (*find_lock_rq)(struct task_struct___40 *, struct rq___2 *);
	void (*task_tick)(struct rq___2 *, struct task_struct___40 *, int);
	void (*task_fork)(struct task_struct___40 *);
	void (*task_dead)(struct task_struct___40 *);
	void (*switched_from)(struct rq___2 *, struct task_struct___40 *);
	void (*switched_to)(struct rq___2 *, struct task_struct___40 *);
	void (*prio_changed)(struct rq___2 *, struct task_struct___40 *, int);
	unsigned int (*get_rr_interval)(struct rq___2 *, struct task_struct___40 *);
	void (*update_curr)(struct rq___2 *);
	void (*task_change_group)(struct task_struct___40 *, int);
};

struct cgroup___29;

struct cgroup_subsys___29;

struct cgroup_subsys_state___29 {
	struct cgroup___29 *cgroup;
	struct cgroup_subsys___29 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___29 *parent;
};

struct cfs_bandwidth {
	raw_spinlock_t lock;
	ktime_t period;
	u64 quota;
	u64 runtime;
	u64 burst;
	s64 hierarchical_quota;
	u8 idle;
	u8 period_active;
	u8 slack_started;
	struct hrtimer period_timer;
	struct hrtimer slack_timer;
	struct list_head throttled_cfs_rq;
	int nr_periods;
	int nr_throttled;
	u64 throttled_time;
};

struct task_group___2 {
	struct cgroup_subsys_state___29 css;
	struct sched_entity **se;
	struct cfs_rq **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___2 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___2 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binfmt___9;

struct core_state___38;

struct mm_struct___39 {
	struct {
		struct vm_area_struct___38 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___9 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___38 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___40 *owner;
		struct user_namespace___4 *user_ns;
		struct file___37 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___29;

struct nsproxy___36 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___35 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___29 *cgroup_ns;
};

struct bio___17;

struct bio_list___17 {
	struct bio___17 *head;
	struct bio___17 *tail;
};

struct bdi_writeback___16 {
	struct backing_dev_info___16 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___29 *memcg_css;
	struct cgroup_subsys_state___29 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___33;

struct backing_dev_info___16 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___16 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___33 *dev;
	char dev_name[64];
	struct device___33 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___37 *debug_dir;
};

struct io_cq___17;

struct io_context___18 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___17 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___29 {
	struct cgroup_subsys_state___29 *subsys[14];
	refcount_t refcount;
	struct css_set___29 *dom_cset;
	struct cgroup___29 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___29 *mg_src_cgrp;
	struct cgroup___29 *mg_dst_cgrp;
	struct css_set___29 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___25 {
	struct pmu___25 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___40 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___25 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___11;

struct pipe_inode_info___11 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___38 *tmp_page;
	struct fasync_struct___36 *fasync_readers;
	struct fasync_struct___36 *fasync_writers;
	struct pipe_buffer___11 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_file___29 {
	struct kernfs_node___36 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___16;

struct mem_cgroup_per_node___16;

struct mem_cgroup___16 {
	struct cgroup_subsys_state___29 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___29 events_file;
	struct cgroup_file___29 events_local_file;
	struct cgroup_file___29 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___16 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___40 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___16 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___17;

struct blk_integrity___17 {
	const struct blk_integrity_profile___17 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___17 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___17 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___17;

struct elevator_queue___17;

struct blk_mq_ops___16;

struct blk_mq_hw_ctx___16;

struct gendisk___17;

struct blkcg_gq___16;

struct blk_mq_tag_set___16;

struct request_queue___18 {
	struct request___17 *last_merge;
	struct elevator_queue___17 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___16 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___16 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___17 *disk;
	struct kobject___36 kobj;
	struct kobject___36 *mq_kobj;
	struct blk_integrity___17 integrity;
	struct device___33 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___16 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___16 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___17 bio_split;
	struct dentry___37 *debugfs_dir;
	struct dentry___37 *sched_debugfs_dir;
	struct dentry___37 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___37 {
	struct vm_struct___37 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___38 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kthread_work___2;

typedef void (*kthread_work_func_t___2)(struct kthread_work___2 *);

struct kthread_worker___2;

struct kthread_work___2 {
	struct list_head node;
	kthread_work_func_t___2 func;
	struct kthread_worker___2 *worker;
	int canceling;
};

struct kthread_worker___2 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___40 *task;
	struct kthread_work___2 *current_work;
};

struct address_space_operations___36;

struct address_space___36 {
	struct inode___37 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___36 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___10 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___33 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___10 {
	u32 count;
	struct page___38 *cache[128];
};

struct page_pool___10 {
	struct page_pool_params___10 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___38 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___10 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___36;

struct dev_pagemap___36 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___36 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___36;

struct path___36 {
	struct vfsmount___36 *mnt;
	struct dentry___37 *dentry;
};

struct fown_struct___35 {
	rwlock_t lock;
	struct pid___35 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___37 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___36 f_path;
	struct inode___37 *f_inode;
	const struct file_operations___36 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___35 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___36 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___36;

struct vm_operations_struct___36 {
	void (*open)(struct vm_area_struct___38 *);
	void (*close)(struct vm_area_struct___38 *);
	int (*may_split)(struct vm_area_struct___38 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___38 *);
	int (*mprotect)(struct vm_area_struct___38 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___36 *);
	vm_fault_t (*huge_fault)(struct vm_fault___36 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___36 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___38 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___36 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___36 *);
	int (*access)(struct vm_area_struct___38 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___38 *);
	int (*set_policy)(struct vm_area_struct___38 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___38 *, long unsigned int);
	struct page___38 * (*find_special_page)(struct vm_area_struct___38 *, long unsigned int);
};

struct core_thread___38 {
	struct task_struct___40 *task;
	struct core_thread___38 *next;
};

struct core_state___38 {
	atomic_t nr_threads;
	struct core_thread___38 dumper;
	struct completion startup;
};

struct linux_binprm___10;

struct coredump_params___9;

struct linux_binfmt___9 {
	struct list_head lh;
	struct module___38 *module;
	int (*load_binary)(struct linux_binprm___10 *);
	int (*load_shlib)(struct file___37 *);
	int (*core_dump)(struct coredump_params___9 *);
	long unsigned int min_coredump;
};

struct vm_fault___36 {
	const struct {
		struct vm_area_struct___38 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___38 *cow_page;
	struct page___38 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___38 prealloc_pte;
};

struct pglist_data___17;

struct lruvec___17 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___17 *pgdat;
};

struct zone___17 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___17 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___17 {
	struct zone___17 *zone;
	int zone_idx;
};

struct zonelist___17 {
	struct zoneref___17 _zonerefs[321];
};

struct pglist_data___17 {
	struct zone___17 node_zones[5];
	struct zonelist___17 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___40 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___40 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___17 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___36;

struct kernfs_elem_dir___36 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___36 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___36;

struct kernfs_root___36 {
	struct kernfs_node___36 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___36 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___36 {
	struct kernfs_node___36 *target_kn;
};

struct kernfs_ops___36;

struct kernfs_elem_attr___36 {
	const struct kernfs_ops___36 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___36 *notify_next;
};

struct kernfs_node___36 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___36 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___36 dir;
		struct kernfs_elem_symlink___36 symlink;
		struct kernfs_elem_attr___36 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___36;

struct kernfs_ops___36 {
	int (*open)(struct kernfs_open_file___36 *);
	void (*release)(struct kernfs_open_file___36 *);
	int (*seq_show)(struct seq_file___36 *, void *);
	void * (*seq_start)(struct seq_file___36 *, loff_t *);
	void * (*seq_next)(struct seq_file___36 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___36 *, void *);
	ssize_t (*read)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___36 *, struct poll_table_struct___28 *);
	int (*mmap)(struct kernfs_open_file___36 *, struct vm_area_struct___38 *);
};

struct kernfs_syscall_ops___36 {
	int (*show_options)(struct seq_file___36 *, struct kernfs_root___36 *);
	int (*mkdir)(struct kernfs_node___36 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___36 *);
	int (*rename)(struct kernfs_node___36 *, struct kernfs_node___36 *, const char *);
	int (*show_path)(struct seq_file___36 *, struct kernfs_node___36 *, struct kernfs_root___36 *);
};

struct seq_operations___35;

struct seq_file___36 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___35 *op;
	int poll_event;
	const struct file___37 *file;
	void *private;
};

struct kernfs_open_file___36 {
	struct kernfs_node___36 *kn;
	struct file___37 *file;
	struct seq_file___36 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___36 *vm_ops;
};

typedef void (*poll_queue_proc___28)(struct file___37 *, wait_queue_head_t *, struct poll_table_struct___28 *);

struct poll_table_struct___28 {
	poll_queue_proc___28 _qproc;
	__poll_t _key;
};

struct bin_attribute___36;

struct attribute_group___36 {
	const char *name;
	umode_t (*is_visible)(struct kobject___36 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___36 *, struct bin_attribute___36 *, int);
	struct attribute **attrs;
	struct bin_attribute___36 **bin_attrs;
};

struct bin_attribute___36 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___36 * (*f_mapping)();
	ssize_t (*read)(struct file___37 *, struct kobject___36 *, struct bin_attribute___36 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___37 *, struct kobject___36 *, struct bin_attribute___36 *, char *, loff_t, size_t);
	int (*mmap)(struct file___37 *, struct kobject___36 *, struct bin_attribute___36 *, struct vm_area_struct___38 *);
};

struct sysfs_ops___36 {
	ssize_t (*show)(struct kobject___36 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___36 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___36;

struct kset___36 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___36 kobj;
	const struct kset_uevent_ops___36 *uevent_ops;
};

struct kobj_type___36 {
	void (*release)(struct kobject___36 *);
	const struct sysfs_ops___36 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___36 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___36 *);
	const void * (*namespace)(struct kobject___36 *);
	void (*get_ownership)(struct kobject___36 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___36 {
	int (* const filter)(struct kset___36 *, struct kobject___36 *);
	const char * (* const name)(struct kset___36 *, struct kobject___36 *);
	int (* const uevent)(struct kset___36 *, struct kobject___36 *, struct kobj_uevent_env *);
};

struct sched_domain_attr {
	int relax_domain_level;
};

struct sched_domain_shared {
	atomic_t ref;
	atomic_t nr_busy_cpus;
	int has_idle_cores;
};

struct sched_group;

struct sched_domain {
	struct sched_domain *parent;
	struct sched_domain *child;
	struct sched_group *groups;
	long unsigned int min_interval;
	long unsigned int max_interval;
	unsigned int busy_factor;
	unsigned int imbalance_pct;
	unsigned int cache_nice_tries;
	int nohz_idle;
	int flags;
	int level;
	long unsigned int last_balance;
	unsigned int balance_interval;
	unsigned int nr_balance_failed;
	u64 max_newidle_lb_cost;
	long unsigned int next_decay_max_lb_cost;
	u64 avg_scan_cost;
	unsigned int lb_count[3];
	unsigned int lb_failed[3];
	unsigned int lb_balanced[3];
	unsigned int lb_imbalance[3];
	unsigned int lb_gained[3];
	unsigned int lb_hot_gained[3];
	unsigned int lb_nobusyg[3];
	unsigned int lb_nobusyq[3];
	unsigned int alb_count;
	unsigned int alb_failed;
	unsigned int alb_pushed;
	unsigned int sbe_count;
	unsigned int sbe_balanced;
	unsigned int sbe_pushed;
	unsigned int sbf_count;
	unsigned int sbf_balanced;
	unsigned int sbf_pushed;
	unsigned int ttwu_wake_remote;
	unsigned int ttwu_move_affine;
	unsigned int ttwu_move_balance;
	char *name;
	union {
		void *private;
		struct callback_head rcu;
	};
	struct sched_domain_shared *shared;
	unsigned int span_weight;
	long unsigned int span[0];
};

struct sched_group_capacity;

struct sched_group {
	struct sched_group *next;
	atomic_t ref;
	unsigned int group_weight;
	struct sched_group_capacity *sgc;
	int asym_prefer_cpu;
	int flags;
	long unsigned int cpumask[0];
};

struct sched_group_capacity {
	atomic_t ref;
	long unsigned int capacity;
	long unsigned int min_capacity;
	long unsigned int max_capacity;
	long unsigned int next_update;
	int imbalance;
	int id;
	long unsigned int cpumask[0];
};

struct wakeup_source___33;

struct dev_pm_qos___6;

struct dev_pm_info___33 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___33 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___33 *, s32);
	struct dev_pm_qos___6 *qos;
};

struct device_type___33;

struct bus_type___33;

struct device_driver___33;

struct dev_pm_domain___33;

struct device_node___18;

struct fwnode_handle___33;

struct class___33;

struct device___33 {
	struct kobject___36 kobj;
	struct device___33 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___33 *type;
	struct bus_type___33 *bus;
	struct device_driver___33 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___33 power;
	struct dev_pm_domain___33 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___18 *of_node;
	struct fwnode_handle___33 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___33 *class;
	const struct attribute_group___36 **groups;
	void (*release)(struct device___33 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___33 {
	int (*prepare)(struct device___33 *);
	void (*complete)(struct device___33 *);
	int (*suspend)(struct device___33 *);
	int (*resume)(struct device___33 *);
	int (*freeze)(struct device___33 *);
	int (*thaw)(struct device___33 *);
	int (*poweroff)(struct device___33 *);
	int (*restore)(struct device___33 *);
	int (*suspend_late)(struct device___33 *);
	int (*resume_early)(struct device___33 *);
	int (*freeze_late)(struct device___33 *);
	int (*thaw_early)(struct device___33 *);
	int (*poweroff_late)(struct device___33 *);
	int (*restore_early)(struct device___33 *);
	int (*suspend_noirq)(struct device___33 *);
	int (*resume_noirq)(struct device___33 *);
	int (*freeze_noirq)(struct device___33 *);
	int (*thaw_noirq)(struct device___33 *);
	int (*poweroff_noirq)(struct device___33 *);
	int (*restore_noirq)(struct device___33 *);
	int (*runtime_suspend)(struct device___33 *);
	int (*runtime_resume)(struct device___33 *);
	int (*runtime_idle)(struct device___33 *);
};

struct wakeup_source___33 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___33 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___6;

struct dev_pm_qos___6 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___6 *resume_latency_req;
	struct dev_pm_qos_request___6 *latency_tolerance_req;
	struct dev_pm_qos_request___6 *flags_req;
};

struct dev_pm_domain___33 {
	struct dev_pm_ops___33 ops;
	int (*start)(struct device___33 *);
	void (*detach)(struct device___33 *, bool);
	int (*activate)(struct device___33 *);
	void (*sync)(struct device___33 *);
	void (*dismiss)(struct device___33 *);
};

struct bus_type___33 {
	const char *name;
	const char *dev_name;
	struct device___33 *dev_root;
	const struct attribute_group___36 **bus_groups;
	const struct attribute_group___36 **dev_groups;
	const struct attribute_group___36 **drv_groups;
	int (*match)(struct device___33 *, struct device_driver___33 *);
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	int (*probe)(struct device___33 *);
	void (*sync_state)(struct device___33 *);
	void (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*online)(struct device___33 *);
	int (*offline)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	int (*num_vf)(struct device___33 *);
	int (*dma_configure)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___33 {
	const char *name;
	struct bus_type___33 *bus;
	struct module___38 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___33 *);
	void (*sync_state)(struct device___33 *);
	int (*remove)(struct device___33 *);
	void (*shutdown)(struct device___33 *);
	int (*suspend)(struct device___33 *, pm_message_t);
	int (*resume)(struct device___33 *);
	const struct attribute_group___36 **groups;
	const struct attribute_group___36 **dev_groups;
	const struct dev_pm_ops___33 *pm;
	void (*coredump)(struct device___33 *);
	struct driver_private *p;
};

struct device_type___33 {
	const char *name;
	const struct attribute_group___36 **groups;
	int (*uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___33 *);
	const struct dev_pm_ops___33 *pm;
};

struct class___33 {
	const char *name;
	struct module___38 *owner;
	const struct attribute_group___36 **class_groups;
	const struct attribute_group___36 **dev_groups;
	struct kobject___36 *dev_kobj;
	int (*dev_uevent)(struct device___33 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___33 *, umode_t *);
	void (*class_release)(struct class___33 *);
	void (*dev_release)(struct device___33 *);
	int (*shutdown_pre)(struct device___33 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___33 *);
	void (*get_ownership)(struct device___33 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___33 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___33;

struct fwnode_handle___33 {
	struct fwnode_handle___33 *secondary;
	const struct fwnode_operations___33 *ops;
	struct device___33 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___15;

struct device_node___18 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___33 fwnode;
	struct property___15 *properties;
	struct property___15 *deadprops;
	struct device_node___18 *parent;
	struct device_node___18 *child;
	struct device_node___18 *sibling;
	struct kobject___36 kobj;
	long unsigned int _flags;
	void *data;
};

struct linux_binprm___10 {
	struct vm_area_struct___38 *vma;
	long unsigned int vma_pages;
	struct mm_struct___39 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___37 *executable;
	struct file___37 *interpreter;
	struct file___37 *file;
	struct cred___3 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___9 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___37 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct shrink_control___16 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___16 *memcg;
};

struct shrinker___16 {
	long unsigned int (*count_objects)(struct shrinker___16 *, struct shrink_control___16 *);
	long unsigned int (*scan_objects)(struct shrinker___16 *, struct shrink_control___16 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___36 {
	void (*page_free)(struct page___38 *);
	void (*kill)(struct dev_pagemap___36 *);
	void (*cleanup)(struct dev_pagemap___36 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___36 *);
};

struct dentry_operations___36;

struct dentry___37 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___37 *d_parent;
	struct qstr d_name;
	struct inode___37 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___36 *d_op;
	struct super_block___37 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___36;

struct inode___37 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___36 *i_op;
	struct super_block___37 *i_sb;
	struct address_space___36 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___16 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___36 *i_fop;
		void (*free_inode)(struct inode___37 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___36 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___11 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___36 {
	int (*d_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___37 *, unsigned int);
	int (*d_hash)(const struct dentry___37 *, struct qstr *);
	int (*d_compare)(const struct dentry___37 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___37 *);
	int (*d_init)(struct dentry___37 *);
	void (*d_release)(struct dentry___37 *);
	void (*d_prune)(struct dentry___37 *);
	void (*d_iput)(struct dentry___37 *, struct inode___37 *);
	char * (*d_dname)(struct dentry___37 *, char *, int);
	struct vfsmount___36 * (*d_automount)(struct path___36 *);
	int (*d_manage)(const struct path___36 *, bool);
	struct dentry___37 * (*d_real)(struct dentry___37 *, const struct inode___37 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___36;

struct mem_dqinfo___36 {
	struct quota_format_type___36 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___36;

struct quota_info___36 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___37 *files[3];
	struct mem_dqinfo___36 info[3];
	const struct quota_format_ops___36 *ops[3];
};

struct rcuwait___36 {
	struct task_struct___40 *task;
};

struct percpu_rw_semaphore___36 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___36 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___36 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___36 rw_sem[3];
};

struct super_operations___36;

struct dquot_operations___36;

struct quotactl_ops___36;

struct block_device___18;

struct super_block___37 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___36 *s_type;
	const struct super_operations___36 *s_op;
	const struct dquot_operations___36 *dq_op;
	const struct quotactl_ops___36 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___37 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___18 *s_bdev;
	struct backing_dev_info___16 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___36 s_dquot;
	struct sb_writers___36 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___36 *s_d_op;
	int cleancache_poolid;
	struct shrinker___16 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___36 {
	struct dentry___37 *mnt_root;
	struct super_block___37 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct kernel_clone_args___2 {
	u64 flags;
	int *pidfd;
	int *child_tid;
	int *parent_tid;
	int exit_signal;
	long unsigned int stack;
	long unsigned int stack_size;
	long unsigned int tls;
	pid_t *set_tid;
	size_t set_tid_size;
	int cgroup;
	int io_thread;
	struct cgroup___29 *cgrp;
	struct css_set___29 *cset;
};

struct psi_group___29 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___40 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___29;

struct cgroup_rstat_cpu___29;

struct cgroup___29 {
	struct cgroup_subsys_state___29 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___36 *kn;
	struct cgroup_file___29 procs_file;
	struct cgroup_file___29 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___29 *subsys[14];
	struct cgroup_root___29 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___29 *dom_cgrp;
	struct cgroup___29 *old_dom_cgrp;
	struct cgroup_rstat_cpu___29 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___29 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct autogroup___2 {
	struct kref kref;
	struct task_group___2 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct io_cq___17 {
	struct request_queue___18 *q;
	struct io_context___18 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___18;

struct kiocb___36 {
	struct file___37 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___36 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___18 *ki_waitq;
	};
};

struct iattr___37 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___37 *ia_file;
};

struct dquot___36 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___37 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___36 {
	int qf_fmt_id;
	const struct quota_format_ops___36 *qf_ops;
	struct module___38 *qf_owner;
	struct quota_format_type___36 *qf_next;
};

struct quota_format_ops___36 {
	int (*check_quota_file)(struct super_block___37 *, int);
	int (*read_file_info)(struct super_block___37 *, int);
	int (*write_file_info)(struct super_block___37 *, int);
	int (*free_file_info)(struct super_block___37 *, int);
	int (*read_dqblk)(struct dquot___36 *);
	int (*commit_dqblk)(struct dquot___36 *);
	int (*release_dqblk)(struct dquot___36 *);
	int (*get_next_id)(struct super_block___37 *, struct kqid *);
};

struct dquot_operations___36 {
	int (*write_dquot)(struct dquot___36 *);
	struct dquot___36 * (*alloc_dquot)(struct super_block___37 *, int);
	void (*destroy_dquot)(struct dquot___36 *);
	int (*acquire_dquot)(struct dquot___36 *);
	int (*release_dquot)(struct dquot___36 *);
	int (*mark_dirty)(struct dquot___36 *);
	int (*write_info)(struct super_block___37 *, int);
	qsize_t * (*get_reserved_space)(struct inode___37 *);
	int (*get_projid)(struct inode___37 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___37 *, qsize_t *);
	int (*get_next_id)(struct super_block___37 *, struct kqid *);
};

struct quotactl_ops___36 {
	int (*quota_on)(struct super_block___37 *, int, int, const struct path___36 *);
	int (*quota_off)(struct super_block___37 *, int);
	int (*quota_enable)(struct super_block___37 *, unsigned int);
	int (*quota_disable)(struct super_block___37 *, unsigned int);
	int (*quota_sync)(struct super_block___37 *, int);
	int (*set_info)(struct super_block___37 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___37 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___37 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___37 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___37 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___37 *, unsigned int);
};

struct wait_page_queue___18 {
	struct page___38 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___16;

struct readahead_control___18;

struct swap_info_struct___12;

struct address_space_operations___36 {
	int (*writepage)(struct page___38 *, struct writeback_control___16 *);
	int (*readpage)(struct file___37 *, struct page___38 *);
	int (*writepages)(struct address_space___36 *, struct writeback_control___16 *);
	int (*set_page_dirty)(struct page___38 *);
	int (*readpages)(struct file___37 *, struct address_space___36 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___18 *);
	int (*write_begin)(struct file___37 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___38 **, void **);
	int (*write_end)(struct file___37 *, struct address_space___36 *, loff_t, unsigned int, unsigned int, struct page___38 *, void *);
	sector_t (*bmap)(struct address_space___36 *, sector_t);
	void (*invalidatepage)(struct page___38 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___38 *, gfp_t);
	void (*freepage)(struct page___38 *);
	ssize_t (*direct_IO)(struct kiocb___36 *, struct iov_iter___20 *);
	int (*migratepage)(struct address_space___36 *, struct page___38 *, struct page___38 *, enum migrate_mode);
	bool (*isolate_page)(struct page___38 *, isolate_mode_t);
	void (*putback_page)(struct page___38 *);
	int (*launder_page)(struct page___38 *);
	int (*is_partially_uptodate)(struct page___38 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___38 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___36 *, struct page___38 *);
	int (*swap_activate)(struct swap_info_struct___12 *, struct file___37 *, sector_t *);
	void (*swap_deactivate)(struct file___37 *);
};

struct writeback_control___16 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___16 *wb;
	struct inode___37 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___18 {
	struct file___37 *file;
	struct address_space___36 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___20;

struct iov_iter___20 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___20 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___11 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___12 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___18 *bdev;
	struct file___37 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___36 {
	struct dentry___37 * (*lookup)(struct inode___37 *, struct dentry___37 *, unsigned int);
	const char * (*get_link)(struct dentry___37 *, struct inode___37 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___37 *, int);
	struct posix_acl * (*get_acl)(struct inode___37 *, int, bool);
	int (*readlink)(struct dentry___37 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___37 *, struct dentry___37 *, umode_t, bool);
	int (*link)(struct dentry___37 *, struct inode___37 *, struct dentry___37 *);
	int (*unlink)(struct inode___37 *, struct dentry___37 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___37 *, struct dentry___37 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___37 *, struct dentry___37 *, umode_t);
	int (*rmdir)(struct inode___37 *, struct dentry___37 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___37 *, struct dentry___37 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___37 *, struct dentry___37 *, struct inode___37 *, struct dentry___37 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___37 *, struct iattr___37 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___36 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___37 *, char *, size_t);
	int (*fiemap)(struct inode___37 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___37 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___37 *, struct dentry___37 *, struct file___37 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___37 *, struct dentry___37 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___37 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___37 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___37 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___36 {
	void (*fl_copy_lock)(struct file_lock___36 *, struct file_lock___36 *);
	void (*fl_release_private)(struct file_lock___36 *);
};

struct lock_manager_operations___36;

struct file_lock___36 {
	struct file_lock___36 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___37 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___36 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___36 *fl_ops;
	const struct lock_manager_operations___36 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___36 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___36 *);
	int (*lm_grant)(struct file_lock___36 *, int);
	bool (*lm_break)(struct file_lock___36 *);
	int (*lm_change)(struct file_lock___36 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___36 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___36 *);
};

struct fasync_struct___36 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___36 *fa_next;
	struct file___37 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___36 {
	struct inode___37 * (*alloc_inode)(struct super_block___37 *);
	void (*destroy_inode)(struct inode___37 *);
	void (*free_inode)(struct inode___37 *);
	void (*dirty_inode)(struct inode___37 *, int);
	int (*write_inode)(struct inode___37 *, struct writeback_control___16 *);
	int (*drop_inode)(struct inode___37 *);
	void (*evict_inode)(struct inode___37 *);
	void (*put_super)(struct super_block___37 *);
	int (*sync_fs)(struct super_block___37 *, int);
	int (*freeze_super)(struct super_block___37 *);
	int (*freeze_fs)(struct super_block___37 *);
	int (*thaw_super)(struct super_block___37 *);
	int (*unfreeze_fs)(struct super_block___37 *);
	int (*statfs)(struct dentry___37 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___37 *, int *, char *);
	void (*umount_begin)(struct super_block___37 *);
	int (*show_options)(struct seq_file___36 *, struct dentry___37 *);
	int (*show_devname)(struct seq_file___36 *, struct dentry___37 *);
	int (*show_path)(struct seq_file___36 *, struct dentry___37 *);
	int (*show_stats)(struct seq_file___36 *, struct dentry___37 *);
	ssize_t (*quota_read)(struct super_block___37 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___37 *, int, const char *, size_t, loff_t);
	struct dquot___36 ** (*get_dquots)(struct inode___37 *);
	long int (*nr_cached_objects)(struct super_block___37 *, struct shrink_control___16 *);
	long int (*free_cached_objects)(struct super_block___37 *, struct shrink_control___16 *);
	struct file___37 * (*real_loop)(struct file___37 *);
};

struct block_device___18 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___37 *bd_inode;
	struct super_block___37 *bd_super;
	void *bd_claiming;
	struct device___33 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___36 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___17 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___37 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___17(struct bio___17 *);

struct bio_vec___20 {
	struct page___38 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___17;

struct bio___17 {
	struct bio___17 *bi_next;
	struct block_device___18 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___17 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___16 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___17 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___20 *bi_io_vec;
	struct bio_set___17 *bi_pool;
	struct bio_vec___20 bi_inline_vecs[0];
};

struct seq_operations___35 {
	void * (*start)(struct seq_file___36 *, loff_t *);
	void (*stop)(struct seq_file___36 *, void *);
	void * (*next)(struct seq_file___36 *, void *, loff_t *);
	int (*show)(struct seq_file___36 *, void *);
};

enum ctx_state___2 {
	CONTEXT_DISABLED___2 = 4294967295,
	CONTEXT_KERNEL___2 = 0,
	CONTEXT_USER___2 = 1,
	CONTEXT_GUEST___2 = 2,
};

struct fwnode_reference_args___33;

struct fwnode_endpoint___33;

struct fwnode_operations___33 {
	struct fwnode_handle___33 * (*get)(struct fwnode_handle___33 *);
	void (*put)(struct fwnode_handle___33 *);
	bool (*device_is_available)(const struct fwnode_handle___33 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___33 *, const struct device___33 *);
	bool (*property_present)(const struct fwnode_handle___33 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___33 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___33 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___33 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_parent)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_next_child_node)(const struct fwnode_handle___33 *, struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*get_named_child_node)(const struct fwnode_handle___33 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___33 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___33 *);
	struct fwnode_handle___33 * (*graph_get_next_endpoint)(const struct fwnode_handle___33 *, struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*graph_get_remote_endpoint)(const struct fwnode_handle___33 *);
	struct fwnode_handle___33 * (*graph_get_port_parent)(struct fwnode_handle___33 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___33 *, struct fwnode_endpoint___33 *);
	int (*add_links)(struct fwnode_handle___33 *);
};

struct fwnode_endpoint___33 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___33 *local_fwnode;
};

struct fwnode_reference_args___33 {
	struct fwnode_handle___33 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___29 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___29 *root_cset;
};

struct kernel_param_ops___36 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___36 *);
	int (*get)(char *, const struct kernel_param___36 *);
	void (*free)(void *);
};

struct kparam_array___36;

struct kernel_param___36 {
	const char *name;
	struct module___38 *mod;
	const struct kernel_param_ops___36 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___36 *arr;
	};
};

struct kparam_array___36 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___36 *ops;
	void *elem;
};

struct module_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___36 *, struct module_kobject___36 *, char *);
	ssize_t (*store)(struct module_attribute___36 *, struct module_kobject___36 *, const char *, size_t);
	void (*setup)(struct module___38 *, const char *);
	int (*test)(struct module___38 *);
	void (*free)(struct module___38 *);
};

struct trace_event_class___20;

struct trace_event_call___20 {
	struct list_head list;
	struct trace_event_class___20 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___20 *, struct perf_event___25 *);
};

struct kernel_cpustat {
	u64 cpustat[10];
};

enum {
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_READY = 1,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED = 2,
	MEMBARRIER_STATE_GLOBAL_EXPEDITED_READY = 4,
	MEMBARRIER_STATE_GLOBAL_EXPEDITED = 8,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_SYNC_CORE_READY = 16,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_SYNC_CORE = 32,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_RSEQ_READY = 64,
	MEMBARRIER_STATE_PRIVATE_EXPEDITED_RSEQ = 128,
};

enum {
	CFTYPE_ONLY_ON_ROOT = 1,
	CFTYPE_NOT_ON_ROOT = 2,
	CFTYPE_NS_DELEGATABLE = 4,
	CFTYPE_NO_PREFIX = 8,
	CFTYPE_WORLD_WRITABLE = 16,
	CFTYPE_DEBUG = 32,
	CFTYPE_PRESSURE = 64,
	__CFTYPE_ONLY_ON_DFL = 65536,
	__CFTYPE_NOT_ON_DFL = 131072,
};

struct cftype___29;

struct cgroup_subsys___29 {
	struct cgroup_subsys_state___29 * (*css_alloc)(struct cgroup_subsys_state___29 *);
	int (*css_online)(struct cgroup_subsys_state___29 *);
	void (*css_offline)(struct cgroup_subsys_state___29 *);
	void (*css_released)(struct cgroup_subsys_state___29 *);
	void (*css_free)(struct cgroup_subsys_state___29 *);
	void (*css_reset)(struct cgroup_subsys_state___29 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___29 *, int);
	int (*css_extra_stat_show)(struct seq_file___36 *, struct cgroup_subsys_state___29 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___40 *, struct css_set___29 *);
	void (*cancel_fork)(struct task_struct___40 *, struct css_set___29 *);
	void (*fork)(struct task_struct___40 *);
	void (*exit)(struct task_struct___40 *);
	void (*release)(struct task_struct___40 *);
	void (*bind)(struct cgroup_subsys_state___29 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___29 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___29 *dfl_cftypes;
	struct cftype___29 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___29 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___29 *updated_children;
	struct cgroup___29 *updated_next;
};

struct cgroup_root___29 {
	struct kernfs_root___36 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___29 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___29 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___29 *ss;
	struct list_head node;
	struct kernfs_ops___36 *kf_ops;
	int (*open)(struct kernfs_open_file___36 *);
	void (*release)(struct kernfs_open_file___36 *);
	u64 (*read_u64)(struct cgroup_subsys_state___29 *, struct cftype___29 *);
	s64 (*read_s64)(struct cgroup_subsys_state___29 *, struct cftype___29 *);
	int (*seq_show)(struct seq_file___36 *, void *);
	void * (*seq_start)(struct seq_file___36 *, loff_t *);
	void * (*seq_next)(struct seq_file___36 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___36 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___29 *, struct cftype___29 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___29 *, struct cftype___29 *, s64);
	ssize_t (*write)(struct kernfs_open_file___36 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___36 *, struct poll_table_struct___28 *);
};

struct css_task_iter {
	struct cgroup_subsys___29 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___29 *cur_cset;
	struct css_set___29 *cur_dcset;
	struct task_struct___40 *cur_task;
	struct list_head iters_node;
};

struct perf_cpu_context___25;

struct perf_output_handle___25;

struct pmu___25 {
	struct list_head entry;
	struct module___38 *module;
	struct device___33 *dev;
	const struct attribute_group___36 **attr_groups;
	const struct attribute_group___36 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___25 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___25 *);
	void (*pmu_disable)(struct pmu___25 *);
	int (*event_init)(struct perf_event___25 *);
	void (*event_mapped)(struct perf_event___25 *, struct mm_struct___39 *);
	void (*event_unmapped)(struct perf_event___25 *, struct mm_struct___39 *);
	int (*add)(struct perf_event___25 *, int);
	void (*del)(struct perf_event___25 *, int);
	void (*start)(struct perf_event___25 *, int);
	void (*stop)(struct perf_event___25 *, int);
	void (*read)(struct perf_event___25 *);
	void (*start_txn)(struct pmu___25 *, unsigned int);
	int (*commit_txn)(struct pmu___25 *);
	void (*cancel_txn)(struct pmu___25 *);
	int (*event_idx)(struct perf_event___25 *);
	void (*sched_task)(struct perf_event_context___25 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___25 *, struct perf_event_context___25 *);
	void * (*setup_aux)(struct perf_event___25 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___25 *, struct perf_output_handle___25 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___25 *);
	int (*aux_output_match)(struct perf_event___25 *);
	int (*filter_match)(struct perf_event___25 *);
	int (*check_period)(struct perf_event___25 *, u64);
};

struct perf_cpu_context___25 {
	struct perf_event_context___25 ctx;
	struct perf_event_context___25 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___25 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___25 **heap;
	struct perf_event___25 *heap_default[2];
};

struct perf_output_handle___25 {
	struct perf_event___25 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___25 {
	struct cgroup_subsys_state___29 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___20 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___20 *);
	};
};

struct trace_event_class___20 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___20 *, enum trace_reg, void *);
	struct trace_event_fields___20 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___20 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___20 *);
};

struct trace_event_file___9;

struct trace_event_buffer___9 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___9 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___9 {
	struct list_head list;
	struct trace_event_call___20 *event_call;
	struct event_filter *filter;
	struct dentry___37 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_sched_kthread_stop {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct trace_event_raw_sched_kthread_stop_ret {
	struct trace_entry ent;
	int ret;
	char __data[0];
};

struct trace_event_raw_sched_kthread_work_queue_work {
	struct trace_entry ent;
	void *work;
	void *function;
	void *worker;
	char __data[0];
};

struct trace_event_raw_sched_kthread_work_execute_start {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_raw_sched_kthread_work_execute_end {
	struct trace_entry ent;
	void *work;
	void *function;
	char __data[0];
};

struct trace_event_raw_sched_wakeup_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int target_cpu;
	char __data[0];
};

struct trace_event_raw_sched_switch {
	struct trace_entry ent;
	char prev_comm[16];
	pid_t prev_pid;
	int prev_prio;
	long int prev_state;
	char next_comm[16];
	pid_t next_pid;
	int next_prio;
	char __data[0];
};

struct trace_event_raw_sched_migrate_task {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	int orig_cpu;
	int dest_cpu;
	char __data[0];
};

struct trace_event_raw_sched_process_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct trace_event_raw_sched_process_wait {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int prio;
	char __data[0];
};

struct trace_event_raw_sched_process_fork {
	struct trace_entry ent;
	char parent_comm[16];
	pid_t parent_pid;
	char child_comm[16];
	pid_t child_pid;
	char __data[0];
};

struct trace_event_raw_sched_process_exec {
	struct trace_entry ent;
	u32 __data_loc_filename;
	pid_t pid;
	pid_t old_pid;
	char __data[0];
};

struct trace_event_raw_sched_stat_template {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 delay;
	char __data[0];
};

struct trace_event_raw_sched_stat_runtime {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	u64 runtime;
	u64 vruntime;
	char __data[0];
};

struct trace_event_raw_sched_pi_setprio {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	int oldprio;
	int newprio;
	char __data[0];
};

struct trace_event_raw_sched_process_hang {
	struct trace_entry ent;
	char comm[16];
	pid_t pid;
	char __data[0];
};

struct trace_event_raw_sched_move_numa {
	struct trace_entry ent;
	pid_t pid;
	pid_t tgid;
	pid_t ngid;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct trace_event_raw_sched_numa_pair_template {
	struct trace_entry ent;
	pid_t src_pid;
	pid_t src_tgid;
	pid_t src_ngid;
	int src_cpu;
	int src_nid;
	pid_t dst_pid;
	pid_t dst_tgid;
	pid_t dst_ngid;
	int dst_cpu;
	int dst_nid;
	char __data[0];
};

struct trace_event_raw_sched_wake_idle_without_ipi {
	struct trace_entry ent;
	int cpu;
	char __data[0];
};

struct trace_event_data_offsets_sched_kthread_stop {};

struct trace_event_data_offsets_sched_kthread_stop_ret {};

struct trace_event_data_offsets_sched_kthread_work_queue_work {};

struct trace_event_data_offsets_sched_kthread_work_execute_start {};

struct trace_event_data_offsets_sched_kthread_work_execute_end {};

struct trace_event_data_offsets_sched_wakeup_template {};

struct trace_event_data_offsets_sched_switch {};

struct trace_event_data_offsets_sched_migrate_task {};

struct trace_event_data_offsets_sched_process_template {};

struct trace_event_data_offsets_sched_process_wait {};

struct trace_event_data_offsets_sched_process_fork {};

struct trace_event_data_offsets_sched_process_exec {
	u32 filename;
};

struct trace_event_data_offsets_sched_stat_template {};

struct trace_event_data_offsets_sched_stat_runtime {};

struct trace_event_data_offsets_sched_pi_setprio {};

struct trace_event_data_offsets_sched_process_hang {};

struct trace_event_data_offsets_sched_move_numa {};

struct trace_event_data_offsets_sched_numa_pair_template {};

struct trace_event_data_offsets_sched_wake_idle_without_ipi {};

typedef void (*btf_trace_sched_kthread_stop)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_kthread_stop_ret)(void *, int);

typedef void (*btf_trace_sched_kthread_work_queue_work)(void *, struct kthread_worker___2 *, struct kthread_work___2 *);

typedef void (*btf_trace_sched_kthread_work_execute_start)(void *, struct kthread_work___2 *);

typedef void (*btf_trace_sched_kthread_work_execute_end)(void *, struct kthread_work___2 *, kthread_work_func_t___2);

typedef void (*btf_trace_sched_waking)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_wakeup)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_wakeup_new)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_switch)(void *, bool, struct task_struct___40 *, struct task_struct___40 *);

typedef void (*btf_trace_sched_migrate_task)(void *, struct task_struct___40 *, int);

typedef void (*btf_trace_sched_process_free)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_process_exit)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_wait_task)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_process_wait)(void *, struct pid___35 *);

typedef void (*btf_trace_sched_process_fork)(void *, struct task_struct___40 *, struct task_struct___40 *);

typedef void (*btf_trace_sched_process_exec)(void *, struct task_struct___40 *, pid_t, struct linux_binprm___10 *);

typedef void (*btf_trace_sched_stat_wait)(void *, struct task_struct___40 *, u64);

typedef void (*btf_trace_sched_stat_sleep)(void *, struct task_struct___40 *, u64);

typedef void (*btf_trace_sched_stat_iowait)(void *, struct task_struct___40 *, u64);

typedef void (*btf_trace_sched_stat_blocked)(void *, struct task_struct___40 *, u64);

typedef void (*btf_trace_sched_stat_runtime)(void *, struct task_struct___40 *, u64, u64);

typedef void (*btf_trace_sched_pi_setprio)(void *, struct task_struct___40 *, struct task_struct___40 *);

typedef void (*btf_trace_sched_process_hang)(void *, struct task_struct___40 *);

typedef void (*btf_trace_sched_move_numa)(void *, struct task_struct___40 *, int, int);

typedef void (*btf_trace_sched_stick_numa)(void *, struct task_struct___40 *, int, struct task_struct___40 *, int);

typedef void (*btf_trace_sched_swap_numa)(void *, struct task_struct___40 *, int, struct task_struct___40 *, int);

typedef void (*btf_trace_sched_wake_idle_without_ipi)(void *, int);

typedef void (*btf_trace_pelt_cfs_tp)(void *, struct cfs_rq *);

typedef void (*btf_trace_pelt_rt_tp)(void *, struct rq___2 *);

struct uclamp_bucket {
	long unsigned int value: 11;
	long unsigned int tasks: 53;
};

struct uclamp_rq {
	unsigned int value;
	struct uclamp_bucket bucket[5];
};

struct rt_prio_array {
	long unsigned int bitmap[2];
	struct list_head queue[100];
};

struct rt_rq {
	struct rt_prio_array active;
	unsigned int rt_nr_running;
	unsigned int rr_nr_running;
	struct {
		int curr;
		int next;
	} highest_prio;
	unsigned int rt_nr_migratory;
	unsigned int rt_nr_total;
	int overloaded;
	struct plist_head pushable_tasks;
	int rt_queued;
	int rt_throttled;
	u64 rt_time;
	u64 rt_runtime;
	raw_spinlock_t rt_runtime_lock;
};

struct dl_rq {
	struct rb_root_cached root;
	unsigned int dl_nr_running;
	struct {
		u64 curr;
		u64 next;
	} earliest_dl;
	unsigned int dl_nr_migratory;
	int overloaded;
	struct rb_root_cached pushable_dl_tasks_root;
	u64 running_bw;
	u64 this_bw;
	u64 extra_bw;
	u64 bw_ratio;
};

struct cpu_stop_done;

struct cpu_stop_work {
	struct list_head list;
	cpu_stop_fn_t fn;
	long unsigned int caller;
	void *arg;
	struct cpu_stop_done *done;
};

struct cpuidle_state;

struct rq___2 {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___40 *curr;
	struct task_struct___40 *idle;
	struct task_struct___40 *stop;
	long unsigned int next_balance;
	struct mm_struct___39 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	struct sched_avg avg_thermal;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___36 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq___2 *core;
	struct task_struct___40 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

typedef void (*btf_trace_pelt_dl_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_pelt_thermal_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_pelt_irq_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_pelt_se_tp)(void *, struct sched_entity *);

typedef void (*btf_trace_sched_cpu_capacity_tp)(void *, struct rq___2 *);

typedef void (*btf_trace_sched_overutilized_tp)(void *, struct root_domain *, bool);

typedef void (*btf_trace_sched_util_est_cfs_tp)(void *, struct cfs_rq *);

typedef void (*btf_trace_sched_util_est_se_tp)(void *, struct sched_entity *);

typedef void (*btf_trace_sched_update_nr_running_tp)(void *, struct rq___2 *, int);

struct property___15 {
	char *name;
	int length;
	void *value;
	struct property___15 *next;
	long unsigned int _flags;
	struct bin_attribute___36 attr;
};

struct wake_q_head {
	struct wake_q_node *first;
	struct wake_q_node **lastp;
};

struct sched_attr {
	__u32 size;
	__u32 sched_policy;
	__u64 sched_flags;
	__s32 sched_nice;
	__u32 sched_priority;
	__u64 sched_runtime;
	__u64 sched_deadline;
	__u64 sched_period;
	__u32 sched_util_min;
	__u32 sched_util_max;
};

struct block_device_operations___17;

struct gendisk___17 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___18 *part0;
	const struct block_device_operations___17 *fops;
	struct request_queue___18 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___16 *bdi;
	struct kobject___36 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___36 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___17 {
	struct bio___17 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___20 *bip_vec;
	struct bio_vec___20 bip_inline_vecs[0];
};

struct blkcg___16;

struct blkg_policy_data___16;

struct blkcg_gq___16 {
	struct request_queue___18 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___16 *blkcg;
	struct blkcg_gq___16 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___16 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___17 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___17(struct request___17 *);

typedef void integrity_complete_fn___17(struct request___17 *, unsigned int);

struct blk_integrity_profile___17 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___17 *prepare_fn;
	integrity_complete_fn___17 *complete_fn;
	const char *name;
};

struct block_device_operations___17 {
	blk_qc_t (*submit_bio)(struct bio___17 *);
	int (*open)(struct block_device___18 *, fmode_t);
	void (*release)(struct gendisk___17 *, fmode_t);
	int (*rw_page)(struct block_device___18 *, sector_t, struct page___38 *, unsigned int);
	int (*ioctl)(struct block_device___18 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___18 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___17 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___17 *);
	int (*getgeo)(struct block_device___18 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___18 *, bool);
	void (*swap_slot_free_notify)(struct block_device___18 *, long unsigned int);
	int (*report_zones)(struct gendisk___17 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___17 *, umode_t *);
	struct module___38 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___17 *, sector_t *);
};

typedef void rq_end_io_fn___17(struct request___17 *, blk_status_t);

struct request___17 {
	struct request_queue___18 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___16 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___17 *bio;
	struct bio___17 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___20 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___17 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___17 *saved_end_io;
		} flush;
	};
	struct gendisk___17 *rq_disk;
	struct block_device___18 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___17 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___16 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___18 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___36 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___37 *debugfs_dir;
	struct dentry___37 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___17;

struct elevator_mq_ops___17 {
	int (*init_sched)(struct request_queue___18 *, struct elevator_type___17 *);
	void (*exit_sched)(struct elevator_queue___17 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___16 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___16 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___16 *);
	bool (*allow_merge)(struct request_queue___18 *, struct request___17 *, struct bio___17 *);
	bool (*bio_merge)(struct request_queue___18 *, struct bio___17 *, unsigned int);
	int (*request_merge)(struct request_queue___18 *, struct request___17 **, struct bio___17 *);
	void (*request_merged)(struct request_queue___18 *, struct request___17 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___18 *, struct request___17 *, struct request___17 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___17 *);
	void (*finish_request)(struct request___17 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___16 *, struct list_head *, bool);
	struct request___17 * (*dispatch_request)(struct blk_mq_hw_ctx___16 *);
	bool (*has_work)(struct blk_mq_hw_ctx___16 *);
	void (*completed_request)(struct request___17 *, u64);
	void (*requeue_request)(struct request___17 *);
	struct request___17 * (*former_request)(struct request_queue___18 *, struct request___17 *);
	struct request___17 * (*next_request)(struct request_queue___18 *, struct request___17 *);
	void (*init_icq)(struct io_cq___17 *);
	void (*exit_icq)(struct io_cq___17 *);
};

struct elv_fs_entry___17;

struct elevator_type___17 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___17 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___17 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___38 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___17 {
	struct elevator_type___17 *type;
	void *elevator_data;
	struct kobject___36 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___17 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___17 *, char *);
	ssize_t (*store)(struct elevator_queue___17 *, const char *, size_t);
};

struct blk_mq_queue_data___16;

struct blk_mq_ops___16 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___16 *, const struct blk_mq_queue_data___16 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___16 *);
	int (*get_budget)(struct request_queue___18 *);
	void (*put_budget)(struct request_queue___18 *, int);
	void (*set_rq_budget_token)(struct request___17 *, int);
	int (*get_rq_budget_token)(struct request___17 *);
	enum blk_eh_timer_return (*timeout)(struct request___17 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___16 *);
	void (*complete)(struct request___17 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___16 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___16 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___16 *, struct request___17 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___16 *, struct request___17 *, unsigned int);
	void (*initialize_rq_fn)(struct request___17 *);
	void (*cleanup_rq)(struct request___17 *);
	bool (*busy)(struct request_queue___18 *);
	int (*map_queues)(struct blk_mq_tag_set___16 *);
	void (*show_rq)(struct seq_file___36 *, struct request___17 *);
};

struct blk_mq_tag_set___16 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___16 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct dev_pm_qos_request___6 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___33 *dev;
};

struct cpuidle_state_usage {
	long long unsigned int disable;
	long long unsigned int usage;
	u64 time_ns;
	long long unsigned int above;
	long long unsigned int below;
	long long unsigned int rejected;
	long long unsigned int s2idle_usage;
	long long unsigned int s2idle_time;
};

struct cpuidle_device;

struct cpuidle_driver;

struct cpuidle_state {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device *, struct cpuidle_driver *, int);
	int (*enter_dead)(struct cpuidle_device *, int);
	int (*enter_s2idle)(struct cpuidle_device *, struct cpuidle_driver *, int);
};

struct cpuidle_state_kobj;

struct cpuidle_driver_kobj;

struct cpuidle_device_kobj;

struct cpuidle_device {
	unsigned int registered;
	unsigned int enabled;
	unsigned int poll_time_limit;
	unsigned int cpu;
	ktime_t next_hrtimer;
	int last_state_idx;
	u64 last_residency_ns;
	u64 poll_limit_ns;
	u64 forced_idle_latency_limit_ns;
	struct cpuidle_state_usage states_usage[10];
	struct cpuidle_state_kobj *kobjs[10];
	struct cpuidle_driver_kobj *kobj_driver;
	struct cpuidle_device_kobj *kobj_dev;
	struct list_head device_list;
};

struct cpuidle_driver {
	const char *name;
	struct module___38 *owner;
	unsigned int bctimer;
	long: 32;
	long: 64;
	long: 64;
	struct cpuidle_state states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct pipe_buf_operations___11;

struct pipe_buffer___11 {
	struct page___38 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___11 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___11 {
	int (*confirm)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	void (*release)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	bool (*try_steal)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
	bool (*get)(struct pipe_inode_info___11 *, struct pipe_buffer___11 *);
};

struct blk_mq_queue_data___16 {
	struct request___17 *rq;
	bool last;
};

struct blkcg_policy_data___16;

struct blkcg___16 {
	struct cgroup_subsys_state___29 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___16 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___16 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___16 {
	struct blkcg___16 *blkcg;
	int plid;
};

struct blkg_policy_data___16 {
	struct blkcg_gq___16 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___16 {
	struct mem_cgroup___16 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___16 {
	struct lruvec___17 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___16 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___16 *memcg;
};

struct obj_cgroup___16 {
	struct percpu_ref refcnt;
	struct mem_cgroup___16 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct syscall_metadata___9 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___20 *enter_event;
	struct trace_event_call___20 *exit_event;
};

struct cpudl_item {
	u64 dl;
	int cpu;
	int idx;
};

struct rt_bandwidth {
	raw_spinlock_t rt_runtime_lock;
	ktime_t rt_period;
	u64 rt_runtime;
	struct hrtimer rt_period_timer;
	unsigned int rt_period_active;
};

struct dl_bandwidth {
	raw_spinlock_t dl_runtime_lock;
	u64 dl_runtime;
	u64 dl_period;
};

typedef int (*tg_visitor)(struct task_group___2 *, void *);

struct perf_domain {
	struct em_perf_domain *em_pd;
	struct perf_domain *next;
	struct callback_head rcu;
};

struct rq_flags {
	long unsigned int flags;
	struct pin_cookie cookie;
	unsigned int clock_update_flags;
};

enum {
	__SCHED_FEAT_GENTLE_FAIR_SLEEPERS = 0,
	__SCHED_FEAT_START_DEBIT = 1,
	__SCHED_FEAT_NEXT_BUDDY = 2,
	__SCHED_FEAT_LAST_BUDDY = 3,
	__SCHED_FEAT_CACHE_HOT_BUDDY = 4,
	__SCHED_FEAT_WAKEUP_PREEMPTION = 5,
	__SCHED_FEAT_HRTICK = 6,
	__SCHED_FEAT_HRTICK_DL = 7,
	__SCHED_FEAT_DOUBLE_TICK = 8,
	__SCHED_FEAT_NONTASK_CAPACITY = 9,
	__SCHED_FEAT_TTWU_QUEUE = 10,
	__SCHED_FEAT_SIS_PROP = 11,
	__SCHED_FEAT_WARN_DOUBLE_CLOCK = 12,
	__SCHED_FEAT_RT_PUSH_IPI = 13,
	__SCHED_FEAT_RT_RUNTIME_SHARE = 14,
	__SCHED_FEAT_LB_MIN = 15,
	__SCHED_FEAT_ATTACH_AGE_LOAD = 16,
	__SCHED_FEAT_WA_IDLE = 17,
	__SCHED_FEAT_WA_WEIGHT = 18,
	__SCHED_FEAT_WA_BIAS = 19,
	__SCHED_FEAT_UTIL_EST = 20,
	__SCHED_FEAT_UTIL_EST_FASTUP = 21,
	__SCHED_FEAT_LATENCY_WARN = 22,
	__SCHED_FEAT_ALT_PERIOD = 23,
	__SCHED_FEAT_BASE_SLICE = 24,
	__SCHED_FEAT_NR = 25,
};

enum cpu_util_type {
	FREQUENCY_UTIL = 0,
	ENERGY_UTIL = 1,
};

struct set_affinity_pending;

struct migration_arg {
	struct task_struct___40 *task;
	int dest_cpu;
	struct set_affinity_pending *pending;
};

struct set_affinity_pending {
	refcount_t refs;
	unsigned int stop_pending;
	struct completion done;
	struct cpu_stop_work stop_work;
	struct migration_arg arg;
};

struct migration_swap_arg {
	struct task_struct___40 *src_task;
	struct task_struct___40 *dst_task;
	int src_cpu;
	int dst_cpu;
};

struct uclamp_request {
	s64 percent;
	u64 util;
	int ret;
};

struct cfs_schedulable_data {
	struct task_group___2 *tg;
	u64 period;
	u64 quota;
};

enum {
	cpuset = 0,
	possible = 1,
	fail = 2,
};

struct dentry___38;

struct super_block___38;

struct module___39;

struct file_system_type___37 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___38 * (*mount)(struct file_system_type___37 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___38 *);
	struct module___39 *owner;
	struct file_system_type___37 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___38;

struct kiocb___37;

struct iov_iter___21;

struct poll_table_struct___29;

struct vm_area_struct___39;

struct inode___38;

struct file_lock___37;

struct page___39;

struct pipe_inode_info___12;

struct seq_file___37;

struct file_operations___37 {
	struct module___39 *owner;
	loff_t (*llseek)(struct file___38 *, loff_t, int);
	ssize_t (*read)(struct file___38 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___38 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___37 *, struct iov_iter___21 *);
	ssize_t (*write_iter)(struct kiocb___37 *, struct iov_iter___21 *);
	int (*iopoll)(struct kiocb___37 *, bool);
	int (*iterate)(struct file___38 *, struct dir_context *);
	int (*iterate_shared)(struct file___38 *, struct dir_context *);
	__poll_t (*poll)(struct file___38 *, struct poll_table_struct___29 *);
	long int (*unlocked_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___38 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___38 *, struct vm_area_struct___39 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___38 *, struct file___38 *);
	int (*flush)(struct file___38 *, fl_owner_t);
	int (*release)(struct inode___38 *, struct file___38 *);
	int (*fsync)(struct file___38 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___38 *, int);
	int (*lock)(struct file___38 *, int, struct file_lock___37 *);
	ssize_t (*sendpage)(struct file___38 *, struct page___39 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___38 *, long unsigned int);
	int (*flock)(struct file___38 *, int, struct file_lock___37 *);
	ssize_t (*splice_write)(struct pipe_inode_info___12 *, struct file___38 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___38 *, loff_t *, struct pipe_inode_info___12 *, size_t, unsigned int);
	int (*setlease)(struct file___38 *, long int, struct file_lock___37 **, void **);
	long int (*fallocate)(struct file___38 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___37 *, struct file___38 *);
	ssize_t (*copy_file_range)(struct file___38 *, loff_t, struct file___38 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___38 *, loff_t, struct file___38 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___38 *, loff_t, loff_t, int);
};

struct cfs_rq___2;

struct sched_entity___2 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity___2 *parent;
	struct cfs_rq___2 *cfs_rq;
	struct cfs_rq___2 *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct vmacache___39 {
	u64 seqnum;
	struct vm_area_struct___39 *vmas[4];
};

struct page_frag___39 {
	struct page___39 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___26;

struct debug_info___26 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___26 *hbp_break[16];
	struct perf_event___26 *hbp_watch[16];
};

struct thread_struct___26 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___26 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___40;

struct pid___36;

struct nsproxy___37;

struct signal_struct___38;

struct bio_list___18;

struct backing_dev_info___17;

struct io_context___19;

struct css_set___30;

struct perf_event_context___26;

struct mem_cgroup___17;

struct request_queue___19;

struct vm_struct___38;

struct task_struct___2 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___2 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___2 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___40 *mm;
	struct mm_struct___40 *active_mm;
	struct vmacache___39 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___2 *real_parent;
	struct task_struct___2 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___2 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___36 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___37 *nsproxy;
	struct signal_struct___38 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___2 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___18 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___17 *backing_dev_info;
	struct io_context___19 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___30 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___26 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___12 *splice_pipe;
	struct page_frag___39 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___17 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___17 *active_memcg;
	struct request_queue___19 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___2 *oom_reaper_list;
	struct vm_struct___38 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___26 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___37;

struct kobj_type___37;

struct kernfs_node___37;

struct kobject___37 {
	const char *name;
	struct list_head entry;
	struct kobject___37 *parent;
	struct kset___37 *kset;
	struct kobj_type___37 *ktype;
	struct kernfs_node___37 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___37 {
	struct kobject___37 kobj;
	struct module___39 *mod;
	struct kobject___37 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___37 {
	struct module___39 *mod;
	struct latch_tree_node node;
};

struct module_layout___37 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___37 mtn;
};

struct module_attribute___37;

struct kernel_param___37;

struct trace_event_call___21;

struct module___39 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___37 mkobj;
	struct module_attribute___37 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___37 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___37 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___37 core_layout;
	struct module_layout___37 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___21 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___26 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___2 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___26)(struct perf_event___26 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___26;

struct fasync_struct___37;

struct pid_namespace___36;

struct perf_cgroup___26;

struct perf_event___26 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___26 *group_leader;
	struct pmu___26 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___26 hw;
	struct perf_event_context___26 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___26 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___2 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___37 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___26 *aux_event;
	void (*destroy)(struct perf_event___26 *);
	struct callback_head callback_head;
	struct pid_namespace___36 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___26 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___26 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___21 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___26 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___36 {
	int nr;
	struct pid_namespace___36 *ns;
};

struct pid_namespace___36 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___2 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___36 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___36 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___36 numbers[1];
};

typedef struct page___39 *pgtable_t___39;

struct address_space___37;

struct page_pool___11;

struct dev_pagemap___37;

struct page___39 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___37 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___11 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___39 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___39 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___40 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___37 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___37;

struct vm_area_struct___39 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___39 *vm_next;
	struct vm_area_struct___39 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___40 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___37 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___38 *vm_file;
	struct file___38 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___38 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___2 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___2 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___36 *pids[4];
	struct pid___36 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___40 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cfs_rq___2 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity___2 *curr;
	struct sched_entity___2 *next;
	struct sched_entity___2 *last;
	struct sched_entity___2 *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity___2 *h_load_next;
	struct rq *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup___30;

struct cgroup_subsys___30;

struct cgroup_subsys_state___30 {
	struct cgroup___30 *cgroup;
	struct cgroup_subsys___30 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___30 *parent;
};

struct task_group {
	struct cgroup_subsys_state___30 css;
	struct sched_entity___2 **se;
	struct cfs_rq___2 **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binfmt___10;

struct core_state___39;

struct mm_struct___40 {
	struct {
		struct vm_area_struct___39 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___38 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___10 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___39 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___2 *owner;
		struct user_namespace___4 *user_ns;
		struct file___38 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___30;

struct nsproxy___37 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___36 *pid_ns_for_children;
	struct net___7 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___30 *cgroup_ns;
};

struct bio___18;

struct bio_list___18 {
	struct bio___18 *head;
	struct bio___18 *tail;
};

struct bdi_writeback___17 {
	struct backing_dev_info___17 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___30 *memcg_css;
	struct cgroup_subsys_state___30 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___34;

struct backing_dev_info___17 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___17 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___34 *dev;
	char dev_name[64];
	struct device___34 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___38 *debug_dir;
};

struct io_cq___18;

struct io_context___19 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___18 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___30 {
	struct cgroup_subsys_state___30 *subsys[14];
	refcount_t refcount;
	struct css_set___30 *dom_cset;
	struct cgroup___30 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___30 *mg_src_cgrp;
	struct cgroup___30 *mg_dst_cgrp;
	struct css_set___30 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___26 {
	struct pmu___26 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___2 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___26 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___12;

struct pipe_inode_info___12 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___39 *tmp_page;
	struct fasync_struct___37 *fasync_readers;
	struct fasync_struct___37 *fasync_writers;
	struct pipe_buffer___12 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_file___30 {
	struct kernfs_node___37 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___17;

struct mem_cgroup_per_node___17;

struct mem_cgroup___17 {
	struct cgroup_subsys_state___30 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___30 events_file;
	struct cgroup_file___30 events_local_file;
	struct cgroup_file___30 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___17 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___2 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___17 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___18;

struct blk_integrity___18 {
	const struct blk_integrity_profile___18 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___18 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___18 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___18;

struct elevator_queue___18;

struct blk_mq_ops___17;

struct blk_mq_hw_ctx___17;

struct gendisk___18;

struct blkcg_gq___17;

struct blk_mq_tag_set___17;

struct request_queue___19 {
	struct request___18 *last_merge;
	struct elevator_queue___18 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___17 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___17 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___18 *disk;
	struct kobject___37 kobj;
	struct kobject___37 *mq_kobj;
	struct blk_integrity___18 integrity;
	struct device___34 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___17 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___17 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___18 bio_split;
	struct dentry___38 *debugfs_dir;
	struct dentry___38 *sched_debugfs_dir;
	struct dentry___38 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___38 {
	struct vm_struct___38 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___39 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___37;

struct address_space___37 {
	struct inode___38 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___37 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___11 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___34 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___11 {
	u32 count;
	struct page___39 *cache[128];
};

struct page_pool___11 {
	struct page_pool_params___11 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___39 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___11 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___37;

struct dev_pagemap___37 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___37 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___37;

struct path___37 {
	struct vfsmount___37 *mnt;
	struct dentry___38 *dentry;
};

struct fown_struct___36 {
	rwlock_t lock;
	struct pid___36 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___38 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___37 f_path;
	struct inode___38 *f_inode;
	const struct file_operations___37 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___36 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___37 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___37;

struct vm_operations_struct___37 {
	void (*open)(struct vm_area_struct___39 *);
	void (*close)(struct vm_area_struct___39 *);
	int (*may_split)(struct vm_area_struct___39 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___39 *);
	int (*mprotect)(struct vm_area_struct___39 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___37 *);
	vm_fault_t (*huge_fault)(struct vm_fault___37 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___37 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___39 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___37 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___37 *);
	int (*access)(struct vm_area_struct___39 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___39 *);
	int (*set_policy)(struct vm_area_struct___39 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___39 *, long unsigned int);
	struct page___39 * (*find_special_page)(struct vm_area_struct___39 *, long unsigned int);
};

struct core_thread___39 {
	struct task_struct___2 *task;
	struct core_thread___39 *next;
};

struct core_state___39 {
	atomic_t nr_threads;
	struct core_thread___39 dumper;
	struct completion startup;
};

struct linux_binprm___11;

struct coredump_params___10;

struct linux_binfmt___10 {
	struct list_head lh;
	struct module___39 *module;
	int (*load_binary)(struct linux_binprm___11 *);
	int (*load_shlib)(struct file___38 *);
	int (*core_dump)(struct coredump_params___10 *);
	long unsigned int min_coredump;
};

struct vm_fault___37 {
	const struct {
		struct vm_area_struct___39 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___39 *cow_page;
	struct page___39 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___39 prealloc_pte;
};

struct psi_group___30 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___2 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___30;

struct cgroup_rstat_cpu___30;

struct cgroup___30 {
	struct cgroup_subsys_state___30 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___37 *kn;
	struct cgroup_file___30 procs_file;
	struct cgroup_file___30 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___30 *subsys[14];
	struct cgroup_root___30 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___30 *dom_cgrp;
	struct cgroup___30 *old_dom_cgrp;
	struct cgroup_rstat_cpu___30 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___30 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___18;

struct lruvec___18 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___18 *pgdat;
};

struct zone___18 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___18 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___18 {
	struct zone___18 *zone;
	int zone_idx;
};

struct zonelist___18 {
	struct zoneref___18 _zonerefs[321];
};

struct pglist_data___18 {
	struct zone___18 node_zones[5];
	struct zonelist___18 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___2 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___2 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___18 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct autogroup {
	struct kref kref;
	struct task_group *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct kernfs_root___37;

struct kernfs_elem_dir___37 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___37 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___37;

struct kernfs_root___37 {
	struct kernfs_node___37 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___37 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___37 {
	struct kernfs_node___37 *target_kn;
};

struct kernfs_ops___37;

struct kernfs_elem_attr___37 {
	const struct kernfs_ops___37 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___37 *notify_next;
};

struct kernfs_node___37 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___37 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___37 dir;
		struct kernfs_elem_symlink___37 symlink;
		struct kernfs_elem_attr___37 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___37;

struct kernfs_ops___37 {
	int (*open)(struct kernfs_open_file___37 *);
	void (*release)(struct kernfs_open_file___37 *);
	int (*seq_show)(struct seq_file___37 *, void *);
	void * (*seq_start)(struct seq_file___37 *, loff_t *);
	void * (*seq_next)(struct seq_file___37 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___37 *, void *);
	ssize_t (*read)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___37 *, struct poll_table_struct___29 *);
	int (*mmap)(struct kernfs_open_file___37 *, struct vm_area_struct___39 *);
};

struct kernfs_syscall_ops___37 {
	int (*show_options)(struct seq_file___37 *, struct kernfs_root___37 *);
	int (*mkdir)(struct kernfs_node___37 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___37 *);
	int (*rename)(struct kernfs_node___37 *, struct kernfs_node___37 *, const char *);
	int (*show_path)(struct seq_file___37 *, struct kernfs_node___37 *, struct kernfs_root___37 *);
};

struct seq_operations___36;

struct seq_file___37 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___36 *op;
	int poll_event;
	const struct file___38 *file;
	void *private;
};

struct kernfs_open_file___37 {
	struct kernfs_node___37 *kn;
	struct file___38 *file;
	struct seq_file___37 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___37 *vm_ops;
};

typedef void (*poll_queue_proc___29)(struct file___38 *, wait_queue_head_t *, struct poll_table_struct___29 *);

struct poll_table_struct___29 {
	poll_queue_proc___29 _qproc;
	__poll_t _key;
};

struct bin_attribute___37;

struct attribute_group___37 {
	const char *name;
	umode_t (*is_visible)(struct kobject___37 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___37 *, struct bin_attribute___37 *, int);
	struct attribute **attrs;
	struct bin_attribute___37 **bin_attrs;
};

struct bin_attribute___37 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___37 * (*f_mapping)();
	ssize_t (*read)(struct file___38 *, struct kobject___37 *, struct bin_attribute___37 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___38 *, struct kobject___37 *, struct bin_attribute___37 *, char *, loff_t, size_t);
	int (*mmap)(struct file___38 *, struct kobject___37 *, struct bin_attribute___37 *, struct vm_area_struct___39 *);
};

struct sysfs_ops___37 {
	ssize_t (*show)(struct kobject___37 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___37 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___37;

struct kset___37 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___37 kobj;
	const struct kset_uevent_ops___37 *uevent_ops;
};

struct kobj_type___37 {
	void (*release)(struct kobject___37 *);
	const struct sysfs_ops___37 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___37 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___37 *);
	const void * (*namespace)(struct kobject___37 *);
	void (*get_ownership)(struct kobject___37 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___37 {
	int (* const filter)(struct kset___37 *, struct kobject___37 *);
	const char * (* const name)(struct kset___37 *, struct kobject___37 *);
	int (* const uevent)(struct kset___37 *, struct kobject___37 *, struct kobj_uevent_env *);
};

struct fwnode_operations___34;

struct fwnode_handle___34 {
	struct fwnode_handle___34 *secondary;
	const struct fwnode_operations___34 *ops;
	struct device___34 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___34;

struct fwnode_endpoint___34;

struct fwnode_operations___34 {
	struct fwnode_handle___34 * (*get)(struct fwnode_handle___34 *);
	void (*put)(struct fwnode_handle___34 *);
	bool (*device_is_available)(const struct fwnode_handle___34 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___34 *, const struct device___34 *);
	bool (*property_present)(const struct fwnode_handle___34 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___34 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___34 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___34 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_parent)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_next_child_node)(const struct fwnode_handle___34 *, struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*get_named_child_node)(const struct fwnode_handle___34 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___34 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___34 *);
	struct fwnode_handle___34 * (*graph_get_next_endpoint)(const struct fwnode_handle___34 *, struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*graph_get_remote_endpoint)(const struct fwnode_handle___34 *);
	struct fwnode_handle___34 * (*graph_get_port_parent)(struct fwnode_handle___34 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___34 *, struct fwnode_endpoint___34 *);
	int (*add_links)(struct fwnode_handle___34 *);
};

struct wakeup_source___34;

struct dev_pm_qos___7;

struct dev_pm_info___34 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___34 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___34 *, s32);
	struct dev_pm_qos___7 *qos;
};

struct device_type___34;

struct bus_type___34;

struct device_driver___34;

struct dev_pm_domain___34;

struct device_node___19;

struct class___34;

struct device___34 {
	struct kobject___37 kobj;
	struct device___34 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___34 *type;
	struct bus_type___34 *bus;
	struct device_driver___34 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___34 power;
	struct dev_pm_domain___34 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___19 *of_node;
	struct fwnode_handle___34 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___34 *class;
	const struct attribute_group___37 **groups;
	void (*release)(struct device___34 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___34 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___34 *local_fwnode;
};

struct fwnode_reference_args___34 {
	struct fwnode_handle___34 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___16 {
	char *name;
	int length;
	void *value;
	struct property___16 *next;
	long unsigned int _flags;
	struct bin_attribute___37 attr;
};

struct device_node___19 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___34 fwnode;
	struct property___16 *properties;
	struct property___16 *deadprops;
	struct device_node___19 *parent;
	struct device_node___19 *child;
	struct device_node___19 *sibling;
	struct kobject___37 kobj;
	long unsigned int _flags;
	void *data;
};

enum {
	SD_BALANCE_NEWIDLE = 1,
	SD_BALANCE_EXEC = 2,
	SD_BALANCE_FORK = 4,
	SD_BALANCE_WAKE = 8,
	SD_WAKE_AFFINE = 16,
	SD_ASYM_CPUCAPACITY = 32,
	SD_ASYM_CPUCAPACITY_FULL = 64,
	SD_SHARE_CPUCAPACITY = 128,
	SD_SHARE_PKG_RESOURCES = 256,
	SD_SERIALIZE = 512,
	SD_ASYM_PACKING = 1024,
	SD_PREFER_SIBLING = 2048,
	SD_OVERLAP = 4096,
	SD_NUMA = 8192,
};

struct linux_binprm___11 {
	struct vm_area_struct___39 *vma;
	long unsigned int vma_pages;
	struct mm_struct___40 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___38 *executable;
	struct file___38 *interpreter;
	struct file___38 *file;
	struct cred___3 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___10 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___38 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dentry_operations___37;

struct dentry___38 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___38 *d_parent;
	struct qstr d_name;
	struct inode___38 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___37 *d_op;
	struct super_block___38 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___37;

struct inode___38 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___37 *i_op;
	struct super_block___38 *i_sb;
	struct address_space___37 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___17 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___37 *i_fop;
		void (*free_inode)(struct inode___38 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___37 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___12 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___37 {
	int (*d_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___38 *, unsigned int);
	int (*d_hash)(const struct dentry___38 *, struct qstr *);
	int (*d_compare)(const struct dentry___38 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___38 *);
	int (*d_init)(struct dentry___38 *);
	void (*d_release)(struct dentry___38 *);
	void (*d_prune)(struct dentry___38 *);
	void (*d_iput)(struct dentry___38 *, struct inode___38 *);
	char * (*d_dname)(struct dentry___38 *, char *, int);
	struct vfsmount___37 * (*d_automount)(struct path___37 *);
	int (*d_manage)(const struct path___37 *, bool);
	struct dentry___38 * (*d_real)(struct dentry___38 *, const struct inode___38 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___37;

struct mem_dqinfo___37 {
	struct quota_format_type___37 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___37;

struct quota_info___37 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___38 *files[3];
	struct mem_dqinfo___37 info[3];
	const struct quota_format_ops___37 *ops[3];
};

struct rcuwait___37 {
	struct task_struct___2 *task;
};

struct percpu_rw_semaphore___37 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___37 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___37 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___37 rw_sem[3];
};

struct shrink_control___17;

struct shrinker___17 {
	long unsigned int (*count_objects)(struct shrinker___17 *, struct shrink_control___17 *);
	long unsigned int (*scan_objects)(struct shrinker___17 *, struct shrink_control___17 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___37;

struct dquot_operations___37;

struct quotactl_ops___37;

struct block_device___19;

struct super_block___38 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___37 *s_type;
	const struct super_operations___37 *s_op;
	const struct dquot_operations___37 *dq_op;
	const struct quotactl_ops___37 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___38 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___19 *s_bdev;
	struct backing_dev_info___17 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___37 s_dquot;
	struct sb_writers___37 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___37 *s_d_op;
	int cleancache_poolid;
	struct shrinker___17 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___37 {
	struct dentry___38 *mnt_root;
	struct super_block___38 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct shrink_control___17 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___17 *memcg;
};

struct io_cq___18 {
	struct request_queue___19 *q;
	struct io_context___19 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___19;

struct kiocb___37 {
	struct file___38 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___37 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___19 *ki_waitq;
	};
};

struct iattr___38 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___38 *ia_file;
};

struct dquot___37 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___38 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___37 {
	int qf_fmt_id;
	const struct quota_format_ops___37 *qf_ops;
	struct module___39 *qf_owner;
	struct quota_format_type___37 *qf_next;
};

struct quota_format_ops___37 {
	int (*check_quota_file)(struct super_block___38 *, int);
	int (*read_file_info)(struct super_block___38 *, int);
	int (*write_file_info)(struct super_block___38 *, int);
	int (*free_file_info)(struct super_block___38 *, int);
	int (*read_dqblk)(struct dquot___37 *);
	int (*commit_dqblk)(struct dquot___37 *);
	int (*release_dqblk)(struct dquot___37 *);
	int (*get_next_id)(struct super_block___38 *, struct kqid *);
};

struct dquot_operations___37 {
	int (*write_dquot)(struct dquot___37 *);
	struct dquot___37 * (*alloc_dquot)(struct super_block___38 *, int);
	void (*destroy_dquot)(struct dquot___37 *);
	int (*acquire_dquot)(struct dquot___37 *);
	int (*release_dquot)(struct dquot___37 *);
	int (*mark_dirty)(struct dquot___37 *);
	int (*write_info)(struct super_block___38 *, int);
	qsize_t * (*get_reserved_space)(struct inode___38 *);
	int (*get_projid)(struct inode___38 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___38 *, qsize_t *);
	int (*get_next_id)(struct super_block___38 *, struct kqid *);
};

struct quotactl_ops___37 {
	int (*quota_on)(struct super_block___38 *, int, int, const struct path___37 *);
	int (*quota_off)(struct super_block___38 *, int);
	int (*quota_enable)(struct super_block___38 *, unsigned int);
	int (*quota_disable)(struct super_block___38 *, unsigned int);
	int (*quota_sync)(struct super_block___38 *, int);
	int (*set_info)(struct super_block___38 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___38 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___38 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___38 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___38 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___38 *, unsigned int);
};

struct wait_page_queue___19 {
	struct page___39 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___17;

struct readahead_control___19;

struct swap_info_struct___13;

struct address_space_operations___37 {
	int (*writepage)(struct page___39 *, struct writeback_control___17 *);
	int (*readpage)(struct file___38 *, struct page___39 *);
	int (*writepages)(struct address_space___37 *, struct writeback_control___17 *);
	int (*set_page_dirty)(struct page___39 *);
	int (*readpages)(struct file___38 *, struct address_space___37 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___19 *);
	int (*write_begin)(struct file___38 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___39 **, void **);
	int (*write_end)(struct file___38 *, struct address_space___37 *, loff_t, unsigned int, unsigned int, struct page___39 *, void *);
	sector_t (*bmap)(struct address_space___37 *, sector_t);
	void (*invalidatepage)(struct page___39 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___39 *, gfp_t);
	void (*freepage)(struct page___39 *);
	ssize_t (*direct_IO)(struct kiocb___37 *, struct iov_iter___21 *);
	int (*migratepage)(struct address_space___37 *, struct page___39 *, struct page___39 *, enum migrate_mode);
	bool (*isolate_page)(struct page___39 *, isolate_mode_t);
	void (*putback_page)(struct page___39 *);
	int (*launder_page)(struct page___39 *);
	int (*is_partially_uptodate)(struct page___39 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___39 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___37 *, struct page___39 *);
	int (*swap_activate)(struct swap_info_struct___13 *, struct file___38 *, sector_t *);
	void (*swap_deactivate)(struct file___38 *);
};

struct writeback_control___17 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___17 *wb;
	struct inode___38 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___19 {
	struct file___38 *file;
	struct address_space___37 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___21;

struct iov_iter___21 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___21 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___12 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___13 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___19 *bdev;
	struct file___38 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___37 {
	struct dentry___38 * (*lookup)(struct inode___38 *, struct dentry___38 *, unsigned int);
	const char * (*get_link)(struct dentry___38 *, struct inode___38 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___38 *, int);
	struct posix_acl * (*get_acl)(struct inode___38 *, int, bool);
	int (*readlink)(struct dentry___38 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___38 *, struct dentry___38 *, umode_t, bool);
	int (*link)(struct dentry___38 *, struct inode___38 *, struct dentry___38 *);
	int (*unlink)(struct inode___38 *, struct dentry___38 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___38 *, struct dentry___38 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___38 *, struct dentry___38 *, umode_t);
	int (*rmdir)(struct inode___38 *, struct dentry___38 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___38 *, struct dentry___38 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___38 *, struct dentry___38 *, struct inode___38 *, struct dentry___38 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___38 *, struct iattr___38 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___37 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___38 *, char *, size_t);
	int (*fiemap)(struct inode___38 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___38 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___38 *, struct dentry___38 *, struct file___38 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___38 *, struct dentry___38 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___38 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___38 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___38 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___37 {
	void (*fl_copy_lock)(struct file_lock___37 *, struct file_lock___37 *);
	void (*fl_release_private)(struct file_lock___37 *);
};

struct lock_manager_operations___37;

struct file_lock___37 {
	struct file_lock___37 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___38 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___37 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___37 *fl_ops;
	const struct lock_manager_operations___37 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___37 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___37 *);
	int (*lm_grant)(struct file_lock___37 *, int);
	bool (*lm_break)(struct file_lock___37 *);
	int (*lm_change)(struct file_lock___37 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___37 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___37 *);
};

struct fasync_struct___37 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___37 *fa_next;
	struct file___38 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___37 {
	struct inode___38 * (*alloc_inode)(struct super_block___38 *);
	void (*destroy_inode)(struct inode___38 *);
	void (*free_inode)(struct inode___38 *);
	void (*dirty_inode)(struct inode___38 *, int);
	int (*write_inode)(struct inode___38 *, struct writeback_control___17 *);
	int (*drop_inode)(struct inode___38 *);
	void (*evict_inode)(struct inode___38 *);
	void (*put_super)(struct super_block___38 *);
	int (*sync_fs)(struct super_block___38 *, int);
	int (*freeze_super)(struct super_block___38 *);
	int (*freeze_fs)(struct super_block___38 *);
	int (*thaw_super)(struct super_block___38 *);
	int (*unfreeze_fs)(struct super_block___38 *);
	int (*statfs)(struct dentry___38 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___38 *, int *, char *);
	void (*umount_begin)(struct super_block___38 *);
	int (*show_options)(struct seq_file___37 *, struct dentry___38 *);
	int (*show_devname)(struct seq_file___37 *, struct dentry___38 *);
	int (*show_path)(struct seq_file___37 *, struct dentry___38 *);
	int (*show_stats)(struct seq_file___37 *, struct dentry___38 *);
	ssize_t (*quota_read)(struct super_block___38 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___38 *, int, const char *, size_t, loff_t);
	struct dquot___37 ** (*get_dquots)(struct inode___38 *);
	long int (*nr_cached_objects)(struct super_block___38 *, struct shrink_control___17 *);
	long int (*free_cached_objects)(struct super_block___38 *, struct shrink_control___17 *);
	struct file___38 * (*real_loop)(struct file___38 *);
};

struct block_device___19 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___38 *bd_inode;
	struct super_block___38 *bd_super;
	void *bd_claiming;
	struct device___34 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___37 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___18 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___38 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___18(struct bio___18 *);

struct bio_vec___21 {
	struct page___39 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___18;

struct bio___18 {
	struct bio___18 *bi_next;
	struct block_device___19 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___18 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___17 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___18 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___21 *bi_io_vec;
	struct bio_set___18 *bi_pool;
	struct bio_vec___21 bi_inline_vecs[0];
};

struct dev_pagemap_ops___37 {
	void (*page_free)(struct page___39 *);
	void (*kill)(struct dev_pagemap___37 *);
	void (*cleanup)(struct dev_pagemap___37 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___37 *);
};

struct kernel_param_ops___37 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___37 *);
	int (*get)(char *, const struct kernel_param___37 *);
	void (*free)(void *);
};

struct kparam_array___37;

struct kernel_param___37 {
	const char *name;
	struct module___39 *mod;
	const struct kernel_param_ops___37 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___37 *arr;
	};
};

struct kparam_array___37 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___37 *ops;
	void *elem;
};

struct module_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___37 *, struct module_kobject___37 *, char *);
	ssize_t (*store)(struct module_attribute___37 *, struct module_kobject___37 *, const char *, size_t);
	void (*setup)(struct module___39 *, const char *);
	int (*test)(struct module___39 *);
	void (*free)(struct module___39 *);
};

struct trace_event_class___21;

struct trace_event_call___21 {
	struct list_head list;
	struct trace_event_class___21 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___21 *, struct perf_event___26 *);
};

struct cgroup_namespace___30 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___30 *root_cset;
};

struct dev_pm_ops___34 {
	int (*prepare)(struct device___34 *);
	void (*complete)(struct device___34 *);
	int (*suspend)(struct device___34 *);
	int (*resume)(struct device___34 *);
	int (*freeze)(struct device___34 *);
	int (*thaw)(struct device___34 *);
	int (*poweroff)(struct device___34 *);
	int (*restore)(struct device___34 *);
	int (*suspend_late)(struct device___34 *);
	int (*resume_early)(struct device___34 *);
	int (*freeze_late)(struct device___34 *);
	int (*thaw_early)(struct device___34 *);
	int (*poweroff_late)(struct device___34 *);
	int (*restore_early)(struct device___34 *);
	int (*suspend_noirq)(struct device___34 *);
	int (*resume_noirq)(struct device___34 *);
	int (*freeze_noirq)(struct device___34 *);
	int (*thaw_noirq)(struct device___34 *);
	int (*poweroff_noirq)(struct device___34 *);
	int (*restore_noirq)(struct device___34 *);
	int (*runtime_suspend)(struct device___34 *);
	int (*runtime_resume)(struct device___34 *);
	int (*runtime_idle)(struct device___34 *);
};

struct wakeup_source___34 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___34 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___7;

struct dev_pm_qos___7 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___7 *resume_latency_req;
	struct dev_pm_qos_request___7 *latency_tolerance_req;
	struct dev_pm_qos_request___7 *flags_req;
};

struct dev_pm_domain___34 {
	struct dev_pm_ops___34 ops;
	int (*start)(struct device___34 *);
	void (*detach)(struct device___34 *, bool);
	int (*activate)(struct device___34 *);
	void (*sync)(struct device___34 *);
	void (*dismiss)(struct device___34 *);
};

struct bus_type___34 {
	const char *name;
	const char *dev_name;
	struct device___34 *dev_root;
	const struct attribute_group___37 **bus_groups;
	const struct attribute_group___37 **dev_groups;
	const struct attribute_group___37 **drv_groups;
	int (*match)(struct device___34 *, struct device_driver___34 *);
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	int (*probe)(struct device___34 *);
	void (*sync_state)(struct device___34 *);
	void (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*online)(struct device___34 *);
	int (*offline)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	int (*num_vf)(struct device___34 *);
	int (*dma_configure)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___34 {
	const char *name;
	struct bus_type___34 *bus;
	struct module___39 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___34 *);
	void (*sync_state)(struct device___34 *);
	int (*remove)(struct device___34 *);
	void (*shutdown)(struct device___34 *);
	int (*suspend)(struct device___34 *, pm_message_t);
	int (*resume)(struct device___34 *);
	const struct attribute_group___37 **groups;
	const struct attribute_group___37 **dev_groups;
	const struct dev_pm_ops___34 *pm;
	void (*coredump)(struct device___34 *);
	struct driver_private *p;
};

struct device_type___34 {
	const char *name;
	const struct attribute_group___37 **groups;
	int (*uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___34 *);
	const struct dev_pm_ops___34 *pm;
};

struct class___34 {
	const char *name;
	struct module___39 *owner;
	const struct attribute_group___37 **class_groups;
	const struct attribute_group___37 **dev_groups;
	struct kobject___37 *dev_kobj;
	int (*dev_uevent)(struct device___34 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___34 *, umode_t *);
	void (*class_release)(struct class___34 *);
	void (*dev_release)(struct device___34 *);
	int (*shutdown_pre)(struct device___34 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___34 *);
	void (*get_ownership)(struct device___34 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___34 *pm;
	struct subsys_private *p;
};

struct block_device_operations___18;

struct gendisk___18 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___19 *part0;
	const struct block_device_operations___18 *fops;
	struct request_queue___19 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___17 *bdi;
	struct kobject___37 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___37 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___18 {
	struct bio___18 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___21 *bip_vec;
	struct bio_vec___21 bip_inline_vecs[0];
};

struct blkcg___17;

struct blkg_policy_data___17;

struct blkcg_gq___17 {
	struct request_queue___19 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___17 *blkcg;
	struct blkcg_gq___17 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___17 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___18 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___18(struct request___18 *);

typedef void integrity_complete_fn___18(struct request___18 *, unsigned int);

struct blk_integrity_profile___18 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___18 *prepare_fn;
	integrity_complete_fn___18 *complete_fn;
	const char *name;
};

struct block_device_operations___18 {
	blk_qc_t (*submit_bio)(struct bio___18 *);
	int (*open)(struct block_device___19 *, fmode_t);
	void (*release)(struct gendisk___18 *, fmode_t);
	int (*rw_page)(struct block_device___19 *, sector_t, struct page___39 *, unsigned int);
	int (*ioctl)(struct block_device___19 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___19 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___18 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___18 *);
	int (*getgeo)(struct block_device___19 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___19 *, bool);
	void (*swap_slot_free_notify)(struct block_device___19 *, long unsigned int);
	int (*report_zones)(struct gendisk___18 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___18 *, umode_t *);
	struct module___39 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___18 *, sector_t *);
};

typedef void rq_end_io_fn___18(struct request___18 *, blk_status_t);

struct request___18 {
	struct request_queue___19 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___17 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___18 *bio;
	struct bio___18 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___21 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___18 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___18 *saved_end_io;
		} flush;
	};
	struct gendisk___18 *rq_disk;
	struct block_device___19 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___18 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___17 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___19 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___37 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___38 *debugfs_dir;
	struct dentry___38 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___18;

struct elevator_mq_ops___18 {
	int (*init_sched)(struct request_queue___19 *, struct elevator_type___18 *);
	void (*exit_sched)(struct elevator_queue___18 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___17 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___17 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___17 *);
	bool (*allow_merge)(struct request_queue___19 *, struct request___18 *, struct bio___18 *);
	bool (*bio_merge)(struct request_queue___19 *, struct bio___18 *, unsigned int);
	int (*request_merge)(struct request_queue___19 *, struct request___18 **, struct bio___18 *);
	void (*request_merged)(struct request_queue___19 *, struct request___18 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___19 *, struct request___18 *, struct request___18 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___18 *);
	void (*finish_request)(struct request___18 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___17 *, struct list_head *, bool);
	struct request___18 * (*dispatch_request)(struct blk_mq_hw_ctx___17 *);
	bool (*has_work)(struct blk_mq_hw_ctx___17 *);
	void (*completed_request)(struct request___18 *, u64);
	void (*requeue_request)(struct request___18 *);
	struct request___18 * (*former_request)(struct request_queue___19 *, struct request___18 *);
	struct request___18 * (*next_request)(struct request_queue___19 *, struct request___18 *);
	void (*init_icq)(struct io_cq___18 *);
	void (*exit_icq)(struct io_cq___18 *);
};

struct elv_fs_entry___18;

struct elevator_type___18 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___18 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___18 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___39 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___18 {
	struct elevator_type___18 *type;
	void *elevator_data;
	struct kobject___37 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___18 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___18 *, char *);
	ssize_t (*store)(struct elevator_queue___18 *, const char *, size_t);
};

struct blk_mq_queue_data___17;

struct blk_mq_ops___17 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___17 *, const struct blk_mq_queue_data___17 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___17 *);
	int (*get_budget)(struct request_queue___19 *);
	void (*put_budget)(struct request_queue___19 *, int);
	void (*set_rq_budget_token)(struct request___18 *, int);
	int (*get_rq_budget_token)(struct request___18 *);
	enum blk_eh_timer_return (*timeout)(struct request___18 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___17 *);
	void (*complete)(struct request___18 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___17 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___17 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___17 *, struct request___18 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___17 *, struct request___18 *, unsigned int);
	void (*initialize_rq_fn)(struct request___18 *);
	void (*cleanup_rq)(struct request___18 *);
	bool (*busy)(struct request_queue___19 *);
	int (*map_queues)(struct blk_mq_tag_set___17 *);
	void (*show_rq)(struct seq_file___37 *, struct request___18 *);
};

struct blk_mq_tag_set___17 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___17 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct dev_pm_qos_request___7 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___34 *dev;
};

struct cpuidle_device___2;

struct cpuidle_driver___2;

struct cpuidle_state___2 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___2 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___2 *, int);
};

struct cpuidle_device___2 {
	unsigned int registered: 1;
	unsigned int enabled: 1;
	unsigned int poll_time_limit: 1;
	unsigned int cpu;
	ktime_t next_hrtimer;
	int last_state_idx;
	u64 last_residency_ns;
	u64 poll_limit_ns;
	u64 forced_idle_latency_limit_ns;
	struct cpuidle_state_usage states_usage[10];
	struct cpuidle_state_kobj *kobjs[10];
	struct cpuidle_driver_kobj *kobj_driver;
	struct cpuidle_device_kobj *kobj_dev;
	struct list_head device_list;
};

struct cpuidle_driver___2 {
	const char *name;
	struct module___39 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___2 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct seq_operations___36 {
	void * (*start)(struct seq_file___37 *, loff_t *);
	void (*stop)(struct seq_file___37 *, void *);
	void * (*next)(struct seq_file___37 *, void *, loff_t *);
	int (*show)(struct seq_file___37 *, void *);
};

struct pipe_buf_operations___12;

struct pipe_buffer___12 {
	struct page___39 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___12 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___12 {
	int (*confirm)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	void (*release)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	bool (*try_steal)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
	bool (*get)(struct pipe_inode_info___12 *, struct pipe_buffer___12 *);
};

struct cftype___30;

struct cgroup_subsys___30 {
	struct cgroup_subsys_state___30 * (*css_alloc)(struct cgroup_subsys_state___30 *);
	int (*css_online)(struct cgroup_subsys_state___30 *);
	void (*css_offline)(struct cgroup_subsys_state___30 *);
	void (*css_released)(struct cgroup_subsys_state___30 *);
	void (*css_free)(struct cgroup_subsys_state___30 *);
	void (*css_reset)(struct cgroup_subsys_state___30 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___30 *, int);
	int (*css_extra_stat_show)(struct seq_file___37 *, struct cgroup_subsys_state___30 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___2 *, struct css_set___30 *);
	void (*cancel_fork)(struct task_struct___2 *, struct css_set___30 *);
	void (*fork)(struct task_struct___2 *);
	void (*exit)(struct task_struct___2 *);
	void (*release)(struct task_struct___2 *);
	void (*bind)(struct cgroup_subsys_state___30 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___30 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___30 *dfl_cftypes;
	struct cftype___30 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___30 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___30 *updated_children;
	struct cgroup___30 *updated_next;
};

struct cgroup_root___30 {
	struct kernfs_root___37 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___30 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___30 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___30 *ss;
	struct list_head node;
	struct kernfs_ops___37 *kf_ops;
	int (*open)(struct kernfs_open_file___37 *);
	void (*release)(struct kernfs_open_file___37 *);
	u64 (*read_u64)(struct cgroup_subsys_state___30 *, struct cftype___30 *);
	s64 (*read_s64)(struct cgroup_subsys_state___30 *, struct cftype___30 *);
	int (*seq_show)(struct seq_file___37 *, void *);
	void * (*seq_start)(struct seq_file___37 *, loff_t *);
	void * (*seq_next)(struct seq_file___37 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___37 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___30 *, struct cftype___30 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___30 *, struct cftype___30 *, s64);
	ssize_t (*write)(struct kernfs_open_file___37 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___37 *, struct poll_table_struct___29 *);
};

struct blk_mq_queue_data___17 {
	struct request___18 *rq;
	bool last;
};

struct blkcg_policy_data___17;

struct blkcg___17 {
	struct cgroup_subsys_state___30 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___17 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___17 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___17 {
	struct blkcg___17 *blkcg;
	int plid;
};

struct blkg_policy_data___17 {
	struct blkcg_gq___17 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___17 {
	struct mem_cgroup___17 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___17 {
	struct lruvec___18 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___17 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___17 *memcg;
};

struct obj_cgroup___17 {
	struct percpu_ref refcnt;
	struct mem_cgroup___17 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___26;

struct perf_output_handle___26;

struct pmu___26 {
	struct list_head entry;
	struct module___39 *module;
	struct device___34 *dev;
	const struct attribute_group___37 **attr_groups;
	const struct attribute_group___37 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___26 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___26 *);
	void (*pmu_disable)(struct pmu___26 *);
	int (*event_init)(struct perf_event___26 *);
	void (*event_mapped)(struct perf_event___26 *, struct mm_struct___40 *);
	void (*event_unmapped)(struct perf_event___26 *, struct mm_struct___40 *);
	int (*add)(struct perf_event___26 *, int);
	void (*del)(struct perf_event___26 *, int);
	void (*start)(struct perf_event___26 *, int);
	void (*stop)(struct perf_event___26 *, int);
	void (*read)(struct perf_event___26 *);
	void (*start_txn)(struct pmu___26 *, unsigned int);
	int (*commit_txn)(struct pmu___26 *);
	void (*cancel_txn)(struct pmu___26 *);
	int (*event_idx)(struct perf_event___26 *);
	void (*sched_task)(struct perf_event_context___26 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___26 *, struct perf_event_context___26 *);
	void * (*setup_aux)(struct perf_event___26 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___26 *, struct perf_output_handle___26 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___26 *);
	int (*aux_output_match)(struct perf_event___26 *);
	int (*filter_match)(struct perf_event___26 *);
	int (*check_period)(struct perf_event___26 *, u64);
};

struct perf_cpu_context___26 {
	struct perf_event_context___26 ctx;
	struct perf_event_context___26 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___26 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___26 **heap;
	struct perf_event___26 *heap_default[2];
};

struct perf_output_handle___26 {
	struct perf_event___26 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___26 {
	struct cgroup_subsys_state___30 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___21 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___21 *);
	};
};

struct trace_event_class___21 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___21 *, enum trace_reg, void *);
	struct trace_event_fields___21 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___21 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___21 *);
};

struct rq {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq___2 cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___2 *curr;
	struct task_struct___2 *idle;
	struct task_struct___2 *stop;
	long unsigned int next_balance;
	struct mm_struct___40 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	struct sched_avg avg_thermal;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___37 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state___2 *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq *core;
	struct task_struct___2 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

enum s2idle_states {
	S2IDLE_STATE_NONE = 0,
	S2IDLE_STATE_ENTER = 1,
	S2IDLE_STATE_WAKE = 2,
};

struct idle_timer {
	struct hrtimer timer;
	int done;
};

struct dentry___39;

struct super_block___39;

struct module___40;

struct file_system_type___38 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___39 * (*mount)(struct file_system_type___38 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___39 *);
	struct module___40 *owner;
	struct file_system_type___38 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___39;

struct kiocb___38;

struct iov_iter___22;

struct poll_table_struct___30;

struct vm_area_struct___40;

struct inode___39;

struct file_lock___38;

struct page___40;

struct pipe_inode_info___13;

struct seq_file___38;

struct file_operations___38 {
	struct module___40 *owner;
	loff_t (*llseek)(struct file___39 *, loff_t, int);
	ssize_t (*read)(struct file___39 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___39 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___38 *, struct iov_iter___22 *);
	ssize_t (*write_iter)(struct kiocb___38 *, struct iov_iter___22 *);
	int (*iopoll)(struct kiocb___38 *, bool);
	int (*iterate)(struct file___39 *, struct dir_context *);
	int (*iterate_shared)(struct file___39 *, struct dir_context *);
	__poll_t (*poll)(struct file___39 *, struct poll_table_struct___30 *);
	long int (*unlocked_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___39 *, struct vm_area_struct___40 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___39 *, struct file___39 *);
	int (*flush)(struct file___39 *, fl_owner_t);
	int (*release)(struct inode___39 *, struct file___39 *);
	int (*fsync)(struct file___39 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___39 *, int);
	int (*lock)(struct file___39 *, int, struct file_lock___38 *);
	ssize_t (*sendpage)(struct file___39 *, struct page___40 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___39 *, long unsigned int);
	int (*flock)(struct file___39 *, int, struct file_lock___38 *);
	ssize_t (*splice_write)(struct pipe_inode_info___13 *, struct file___39 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___39 *, loff_t *, struct pipe_inode_info___13 *, size_t, unsigned int);
	int (*setlease)(struct file___39 *, long int, struct file_lock___38 **, void **);
	long int (*fallocate)(struct file___39 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___38 *, struct file___39 *);
	ssize_t (*copy_file_range)(struct file___39 *, loff_t, struct file___39 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___39 *, loff_t, struct file___39 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___39 *, loff_t, loff_t, int);
};

struct cfs_rq___3;

struct sched_entity___3 {
	struct load_weight load;
	struct rb_node run_node;
	struct list_head group_node;
	unsigned int on_rq;
	u64 exec_start;
	u64 sum_exec_runtime;
	u64 vruntime;
	u64 prev_sum_exec_runtime;
	u64 nr_migrations;
	struct sched_statistics statistics;
	int depth;
	struct sched_entity___3 *parent;
	struct cfs_rq___3 *cfs_rq;
	struct cfs_rq___3 *my_q;
	long unsigned int runnable_weight;
	long: 64;
	long: 64;
	long: 64;
	struct sched_avg avg;
};

struct vmacache___40 {
	u64 seqnum;
	struct vm_area_struct___40 *vmas[4];
};

struct page_frag___40 {
	struct page___40 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___27;

struct debug_info___27 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___27 *hbp_break[16];
	struct perf_event___27 *hbp_watch[16];
};

struct thread_struct___27 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___27 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct sched_class___3;

struct task_group___3;

struct mm_struct___41;

struct pid___37;

struct nsproxy___38;

struct signal_struct___39;

struct bio_list___19;

struct backing_dev_info___18;

struct io_context___20;

struct css_set___31;

struct perf_event_context___27;

struct mem_cgroup___18;

struct request_queue___20;

struct vm_struct___39;

struct task_struct___41 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___41 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class___3 *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group___3 *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___41 *mm;
	struct mm_struct___41 *active_mm;
	struct vmacache___40 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___41 *real_parent;
	struct task_struct___41 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___41 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___37 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___38 *nsproxy;
	struct signal_struct___39 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___41 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___19 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___18 *backing_dev_info;
	struct io_context___20 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___31 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___27 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___13 *splice_pipe;
	struct page_frag___40 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___18 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___18 *active_memcg;
	struct request_queue___20 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___41 *oom_reaper_list;
	struct vm_struct___39 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___27 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___38;

struct kobj_type___38;

struct kernfs_node___38;

struct kobject___38 {
	const char *name;
	struct list_head entry;
	struct kobject___38 *parent;
	struct kset___38 *kset;
	struct kobj_type___38 *ktype;
	struct kernfs_node___38 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___38 {
	struct kobject___38 kobj;
	struct module___40 *mod;
	struct kobject___38 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___38 {
	struct module___40 *mod;
	struct latch_tree_node node;
};

struct module_layout___38 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___38 mtn;
};

struct module_attribute___38;

struct kernel_param___38;

struct trace_event_call___22;

struct module___40 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___38 mkobj;
	struct module_attribute___38 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___38 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___38 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___38 core_layout;
	struct module_layout___38 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___22 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___27 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___41 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

struct perf_sample_data___3;

typedef void (*perf_overflow_handler_t___27)(struct perf_event___27 *, struct perf_sample_data___3 *, struct pt_regs *);

struct pmu___27;

struct fasync_struct___38;

struct pid_namespace___37;

struct perf_cgroup___27;

struct perf_event___27 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___27 *group_leader;
	struct pmu___27 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___27 hw;
	struct perf_event_context___27 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___27 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___41 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___38 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___27 *aux_event;
	void (*destroy)(struct perf_event___27 *);
	struct callback_head callback_head;
	struct pid_namespace___37 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___27 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___27 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___22 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___27 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___37 {
	int nr;
	struct pid_namespace___37 *ns;
};

struct pid_namespace___37 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___41 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___37 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___37 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___37 numbers[1];
};

typedef struct page___40 *pgtable_t___40;

struct address_space___38;

struct page_pool___12;

struct dev_pagemap___38;

struct page___40 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___38 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___40 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___40 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___41 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___38 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___38;

struct vm_area_struct___40 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___40 *vm_next;
	struct vm_area_struct___40 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___41 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___38 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___39 *vm_file;
	struct file___39 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct autogroup___3;

struct signal_struct___39 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___41 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___41 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___37 *pids[4];
	struct pid___37 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup___3 *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___41 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct rq___3;

struct cfs_rq___3 {
	struct load_weight load;
	unsigned int nr_running;
	unsigned int h_nr_running;
	unsigned int idle_h_nr_running;
	u64 exec_clock;
	u64 min_vruntime;
	unsigned int forceidle_seq;
	u64 min_vruntime_fi;
	struct rb_root_cached tasks_timeline;
	struct sched_entity___3 *curr;
	struct sched_entity___3 *next;
	struct sched_entity___3 *last;
	struct sched_entity___3 *skip;
	unsigned int nr_spread_over;
	long: 32;
	long: 64;
	struct sched_avg avg;
	struct {
		raw_spinlock_t lock;
		int nr;
		long unsigned int load_avg;
		long unsigned int util_avg;
		long unsigned int runnable_avg;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	} removed;
	long unsigned int tg_load_avg_contrib;
	long int propagate;
	long int prop_runnable_sum;
	long unsigned int h_load;
	u64 last_h_load_update;
	struct sched_entity___3 *h_load_next;
	struct rq___3 *rq;
	int on_list;
	struct list_head leaf_cfs_rq_list;
	struct task_group___3 *tg;
	int idle;
	int runtime_enabled;
	s64 runtime_remaining;
	u64 throttled_clock;
	u64 throttled_clock_task;
	u64 throttled_clock_task_time;
	int throttled;
	int throttle_count;
	struct list_head throttled_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sched_class___3 {
	int uclamp_enabled;
	void (*enqueue_task)(struct rq___3 *, struct task_struct___41 *, int);
	void (*dequeue_task)(struct rq___3 *, struct task_struct___41 *, int);
	void (*yield_task)(struct rq___3 *);
	bool (*yield_to_task)(struct rq___3 *, struct task_struct___41 *);
	void (*check_preempt_curr)(struct rq___3 *, struct task_struct___41 *, int);
	struct task_struct___41 * (*pick_next_task)(struct rq___3 *);
	void (*put_prev_task)(struct rq___3 *, struct task_struct___41 *);
	void (*set_next_task)(struct rq___3 *, struct task_struct___41 *, bool);
	int (*balance)(struct rq___3 *, struct task_struct___41 *, struct rq_flags *);
	int (*select_task_rq)(struct task_struct___41 *, int, int);
	struct task_struct___41 * (*pick_task)(struct rq___3 *);
	void (*migrate_task_rq)(struct task_struct___41 *, int);
	void (*task_woken)(struct rq___3 *, struct task_struct___41 *);
	void (*set_cpus_allowed)(struct task_struct___41 *, const struct cpumask *, u32);
	void (*rq_online)(struct rq___3 *);
	void (*rq_offline)(struct rq___3 *);
	struct rq___3 * (*find_lock_rq)(struct task_struct___41 *, struct rq___3 *);
	void (*task_tick)(struct rq___3 *, struct task_struct___41 *, int);
	void (*task_fork)(struct task_struct___41 *);
	void (*task_dead)(struct task_struct___41 *);
	void (*switched_from)(struct rq___3 *, struct task_struct___41 *);
	void (*switched_to)(struct rq___3 *, struct task_struct___41 *);
	void (*prio_changed)(struct rq___3 *, struct task_struct___41 *, int);
	unsigned int (*get_rr_interval)(struct rq___3 *, struct task_struct___41 *);
	void (*update_curr)(struct rq___3 *);
	void (*task_change_group)(struct task_struct___41 *, int);
};

struct cgroup___31;

struct cgroup_subsys___31;

struct cgroup_subsys_state___31 {
	struct cgroup___31 *cgroup;
	struct cgroup_subsys___31 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___31 *parent;
};

struct task_group___3 {
	struct cgroup_subsys_state___31 css;
	struct sched_entity___3 **se;
	struct cfs_rq___3 **cfs_rq;
	long unsigned int shares;
	int idle;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t load_avg;
	struct callback_head rcu;
	struct list_head list;
	struct task_group___3 *parent;
	struct list_head siblings;
	struct list_head children;
	struct autogroup___3 *autogroup;
	struct cfs_bandwidth cfs_bandwidth;
	unsigned int uclamp_pct[2];
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct linux_binfmt___11;

struct core_state___40;

struct mm_struct___41 {
	struct {
		struct vm_area_struct___40 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___11 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___40 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___41 *owner;
		struct user_namespace___4 *user_ns;
		struct file___39 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___31;

struct nsproxy___38 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___37 *pid_ns_for_children;
	struct net___7 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___31 *cgroup_ns;
};

struct bio___19;

struct bio_list___19 {
	struct bio___19 *head;
	struct bio___19 *tail;
};

struct bdi_writeback___18 {
	struct backing_dev_info___18 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___31 *memcg_css;
	struct cgroup_subsys_state___31 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___35;

struct backing_dev_info___18 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___18 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___35 *dev;
	char dev_name[64];
	struct device___35 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___39 *debug_dir;
};

struct io_cq___19;

struct io_context___20 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___19 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___31 {
	struct cgroup_subsys_state___31 *subsys[14];
	refcount_t refcount;
	struct css_set___31 *dom_cset;
	struct cgroup___31 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___31 *mg_src_cgrp;
	struct cgroup___31 *mg_dst_cgrp;
	struct css_set___31 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___27 {
	struct pmu___27 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___41 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___27 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct numa_group {
	refcount_t refcount;
	spinlock_t lock;
	int nr_tasks;
	pid_t gid;
	int active_nodes;
	struct callback_head rcu;
	long unsigned int total_faults;
	long unsigned int max_faults_cpu;
	long unsigned int *faults_cpu;
	long unsigned int faults[0];
};

struct pipe_buffer___13;

struct pipe_inode_info___13 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___40 *tmp_page;
	struct fasync_struct___38 *fasync_readers;
	struct fasync_struct___38 *fasync_writers;
	struct pipe_buffer___13 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_file___31 {
	struct kernfs_node___38 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___18;

struct mem_cgroup_per_node___18;

struct mem_cgroup___18 {
	struct cgroup_subsys_state___31 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___31 events_file;
	struct cgroup_file___31 events_local_file;
	struct cgroup_file___31 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___18 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___41 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___18 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___19;

struct blk_integrity___19 {
	const struct blk_integrity_profile___19 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___19 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___19 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___19;

struct elevator_queue___19;

struct blk_mq_ops___18;

struct blk_mq_hw_ctx___18;

struct gendisk___19;

struct blkcg_gq___18;

struct blk_mq_tag_set___18;

struct request_queue___20 {
	struct request___19 *last_merge;
	struct elevator_queue___19 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___18 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___18 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___19 *disk;
	struct kobject___38 kobj;
	struct kobject___38 *mq_kobj;
	struct blk_integrity___19 integrity;
	struct device___35 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___18 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___18 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___19 bio_split;
	struct dentry___39 *debugfs_dir;
	struct dentry___39 *sched_debugfs_dir;
	struct dentry___39 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___39 {
	struct vm_struct___39 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___40 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___38;

struct address_space___38 {
	struct inode___39 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___38 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___12 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___35 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___12 {
	u32 count;
	struct page___40 *cache[128];
};

struct page_pool___12 {
	struct page_pool_params___12 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___40 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___12 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___38;

struct dev_pagemap___38 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___38 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___38;

struct path___38 {
	struct vfsmount___38 *mnt;
	struct dentry___39 *dentry;
};

struct fown_struct___37 {
	rwlock_t lock;
	struct pid___37 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___39 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___38 f_path;
	struct inode___39 *f_inode;
	const struct file_operations___38 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___37 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___38 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___38;

struct vm_operations_struct___38 {
	void (*open)(struct vm_area_struct___40 *);
	void (*close)(struct vm_area_struct___40 *);
	int (*may_split)(struct vm_area_struct___40 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___40 *);
	int (*mprotect)(struct vm_area_struct___40 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___38 *);
	vm_fault_t (*huge_fault)(struct vm_fault___38 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___38 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___40 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___38 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___38 *);
	int (*access)(struct vm_area_struct___40 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___40 *);
	int (*set_policy)(struct vm_area_struct___40 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___40 *, long unsigned int);
	struct page___40 * (*find_special_page)(struct vm_area_struct___40 *, long unsigned int);
};

struct core_thread___40 {
	struct task_struct___41 *task;
	struct core_thread___40 *next;
};

struct core_state___40 {
	atomic_t nr_threads;
	struct core_thread___40 dumper;
	struct completion startup;
};

struct linux_binprm___12;

struct coredump_params___11;

struct linux_binfmt___11 {
	struct list_head lh;
	struct module___40 *module;
	int (*load_binary)(struct linux_binprm___12 *);
	int (*load_shlib)(struct file___39 *);
	int (*core_dump)(struct coredump_params___11 *);
	long unsigned int min_coredump;
};

struct vm_fault___38 {
	const struct {
		struct vm_area_struct___40 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___40 *cow_page;
	struct page___40 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___40 prealloc_pte;
};

struct update_util_data {
	void (*func)(struct update_util_data *, u64, unsigned int);
};

struct psi_group___31 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___41 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___31;

struct cgroup_rstat_cpu___31;

struct cgroup___31 {
	struct cgroup_subsys_state___31 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___38 *kn;
	struct cgroup_file___31 procs_file;
	struct cgroup_file___31 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___31 *subsys[14];
	struct cgroup_root___31 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___31 *dom_cgrp;
	struct cgroup___31 *old_dom_cgrp;
	struct cgroup_rstat_cpu___31 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___31 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___19;

struct lruvec___19 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___19 *pgdat;
};

struct zone___19 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___19 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___19 {
	struct zone___19 *zone;
	int zone_idx;
};

struct zonelist___19 {
	struct zoneref___19 _zonerefs[321];
};

struct pglist_data___19 {
	struct zone___19 node_zones[5];
	struct zonelist___19 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___41 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___41 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___19 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct autogroup___3 {
	struct kref kref;
	struct task_group___3 *tg;
	struct rw_semaphore lock;
	long unsigned int id;
	int nice;
};

struct kernfs_root___38;

struct kernfs_elem_dir___38 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___38 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___38;

struct kernfs_root___38 {
	struct kernfs_node___38 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___38 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___38 {
	struct kernfs_node___38 *target_kn;
};

struct kernfs_ops___38;

struct kernfs_elem_attr___38 {
	const struct kernfs_ops___38 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___38 *notify_next;
};

struct kernfs_node___38 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___38 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___38 dir;
		struct kernfs_elem_symlink___38 symlink;
		struct kernfs_elem_attr___38 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___38;

struct kernfs_ops___38 {
	int (*open)(struct kernfs_open_file___38 *);
	void (*release)(struct kernfs_open_file___38 *);
	int (*seq_show)(struct seq_file___38 *, void *);
	void * (*seq_start)(struct seq_file___38 *, loff_t *);
	void * (*seq_next)(struct seq_file___38 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___38 *, void *);
	ssize_t (*read)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___38 *, struct poll_table_struct___30 *);
	int (*mmap)(struct kernfs_open_file___38 *, struct vm_area_struct___40 *);
};

struct kernfs_syscall_ops___38 {
	int (*show_options)(struct seq_file___38 *, struct kernfs_root___38 *);
	int (*mkdir)(struct kernfs_node___38 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___38 *);
	int (*rename)(struct kernfs_node___38 *, struct kernfs_node___38 *, const char *);
	int (*show_path)(struct seq_file___38 *, struct kernfs_node___38 *, struct kernfs_root___38 *);
};

struct seq_operations___37;

struct seq_file___38 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___37 *op;
	int poll_event;
	const struct file___39 *file;
	void *private;
};

struct kernfs_open_file___38 {
	struct kernfs_node___38 *kn;
	struct file___39 *file;
	struct seq_file___38 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___38 *vm_ops;
};

typedef void (*poll_queue_proc___30)(struct file___39 *, wait_queue_head_t *, struct poll_table_struct___30 *);

struct poll_table_struct___30 {
	poll_queue_proc___30 _qproc;
	__poll_t _key;
};

struct bin_attribute___38;

struct attribute_group___38 {
	const char *name;
	umode_t (*is_visible)(struct kobject___38 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___38 *, struct bin_attribute___38 *, int);
	struct attribute **attrs;
	struct bin_attribute___38 **bin_attrs;
};

struct bin_attribute___38 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___38 * (*f_mapping)();
	ssize_t (*read)(struct file___39 *, struct kobject___38 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___39 *, struct kobject___38 *, struct bin_attribute___38 *, char *, loff_t, size_t);
	int (*mmap)(struct file___39 *, struct kobject___38 *, struct bin_attribute___38 *, struct vm_area_struct___40 *);
};

struct sysfs_ops___38 {
	ssize_t (*show)(struct kobject___38 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___38 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___38;

struct kset___38 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___38 kobj;
	const struct kset_uevent_ops___38 *uevent_ops;
};

struct kobj_type___38 {
	void (*release)(struct kobject___38 *);
	const struct sysfs_ops___38 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___38 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___38 *);
	const void * (*namespace)(struct kobject___38 *);
	void (*get_ownership)(struct kobject___38 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___38 {
	int (* const filter)(struct kset___38 *, struct kobject___38 *);
	const char * (* const name)(struct kset___38 *, struct kobject___38 *);
	int (* const uevent)(struct kset___38 *, struct kobject___38 *, struct kobj_uevent_env *);
};

struct fwnode_operations___35;

struct fwnode_handle___35 {
	struct fwnode_handle___35 *secondary;
	const struct fwnode_operations___35 *ops;
	struct device___35 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___35;

struct fwnode_endpoint___35;

struct fwnode_operations___35 {
	struct fwnode_handle___35 * (*get)(struct fwnode_handle___35 *);
	void (*put)(struct fwnode_handle___35 *);
	bool (*device_is_available)(const struct fwnode_handle___35 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___35 *, const struct device___35 *);
	bool (*property_present)(const struct fwnode_handle___35 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___35 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___35 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___35 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_parent)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_next_child_node)(const struct fwnode_handle___35 *, struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*get_named_child_node)(const struct fwnode_handle___35 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___35 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___35 *);
	struct fwnode_handle___35 * (*graph_get_next_endpoint)(const struct fwnode_handle___35 *, struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*graph_get_remote_endpoint)(const struct fwnode_handle___35 *);
	struct fwnode_handle___35 * (*graph_get_port_parent)(struct fwnode_handle___35 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___35 *, struct fwnode_endpoint___35 *);
	int (*add_links)(struct fwnode_handle___35 *);
};

struct wakeup_source___35;

struct dev_pm_qos___8;

struct dev_pm_info___35 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___35 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___35 *, s32);
	struct dev_pm_qos___8 *qos;
};

struct device_type___35;

struct bus_type___35;

struct device_driver___35;

struct dev_pm_domain___35;

struct device_node___20;

struct class___35;

struct device___35 {
	struct kobject___38 kobj;
	struct device___35 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___35 *type;
	struct bus_type___35 *bus;
	struct device_driver___35 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___35 power;
	struct dev_pm_domain___35 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___20 *of_node;
	struct fwnode_handle___35 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___35 *class;
	const struct attribute_group___38 **groups;
	void (*release)(struct device___35 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___35 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___35 *local_fwnode;
};

struct fwnode_reference_args___35 {
	struct fwnode_handle___35 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___17 {
	char *name;
	int length;
	void *value;
	struct property___17 *next;
	long unsigned int _flags;
	struct bin_attribute___38 attr;
};

struct device_node___20 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___35 fwnode;
	struct property___17 *properties;
	struct property___17 *deadprops;
	struct device_node___20 *parent;
	struct device_node___20 *child;
	struct device_node___20 *sibling;
	struct kobject___38 kobj;
	long unsigned int _flags;
	void *data;
};

enum sched_tunable_scaling {
	SCHED_TUNABLESCALING_NONE = 0,
	SCHED_TUNABLESCALING_LOG = 1,
	SCHED_TUNABLESCALING_LINEAR = 2,
	SCHED_TUNABLESCALING_END = 3,
};

struct linux_binprm___12 {
	struct vm_area_struct___40 *vma;
	long unsigned int vma_pages;
	struct mm_struct___41 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___39 *executable;
	struct file___39 *interpreter;
	struct file___39 *file;
	struct cred___3 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___11 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___39 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dentry_operations___38;

struct dentry___39 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___39 *d_parent;
	struct qstr d_name;
	struct inode___39 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___38 *d_op;
	struct super_block___39 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___38;

struct inode___39 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___38 *i_op;
	struct super_block___39 *i_sb;
	struct address_space___38 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___18 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___38 *i_fop;
		void (*free_inode)(struct inode___39 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___38 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___13 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___38 {
	int (*d_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___39 *, unsigned int);
	int (*d_hash)(const struct dentry___39 *, struct qstr *);
	int (*d_compare)(const struct dentry___39 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___39 *);
	int (*d_init)(struct dentry___39 *);
	void (*d_release)(struct dentry___39 *);
	void (*d_prune)(struct dentry___39 *);
	void (*d_iput)(struct dentry___39 *, struct inode___39 *);
	char * (*d_dname)(struct dentry___39 *, char *, int);
	struct vfsmount___38 * (*d_automount)(struct path___38 *);
	int (*d_manage)(const struct path___38 *, bool);
	struct dentry___39 * (*d_real)(struct dentry___39 *, const struct inode___39 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___38;

struct mem_dqinfo___38 {
	struct quota_format_type___38 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___38;

struct quota_info___38 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___39 *files[3];
	struct mem_dqinfo___38 info[3];
	const struct quota_format_ops___38 *ops[3];
};

struct rcuwait___38 {
	struct task_struct___41 *task;
};

struct percpu_rw_semaphore___38 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___38 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___38 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___38 rw_sem[3];
};

struct shrink_control___18;

struct shrinker___18 {
	long unsigned int (*count_objects)(struct shrinker___18 *, struct shrink_control___18 *);
	long unsigned int (*scan_objects)(struct shrinker___18 *, struct shrink_control___18 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___38;

struct dquot_operations___38;

struct quotactl_ops___38;

struct block_device___20;

struct super_block___39 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___38 *s_type;
	const struct super_operations___38 *s_op;
	const struct dquot_operations___38 *dq_op;
	const struct quotactl_ops___38 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___39 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___20 *s_bdev;
	struct backing_dev_info___18 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___38 s_dquot;
	struct sb_writers___38 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___38 *s_d_op;
	int cleancache_poolid;
	struct shrinker___18 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___38 {
	struct dentry___39 *mnt_root;
	struct super_block___39 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct shrink_control___18 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___18 *memcg;
};

struct io_cq___19 {
	struct request_queue___20 *q;
	struct io_context___20 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___20;

struct kiocb___38 {
	struct file___39 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___38 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___20 *ki_waitq;
	};
};

struct iattr___39 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___39 *ia_file;
};

struct dquot___38 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___39 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___38 {
	int qf_fmt_id;
	const struct quota_format_ops___38 *qf_ops;
	struct module___40 *qf_owner;
	struct quota_format_type___38 *qf_next;
};

struct quota_format_ops___38 {
	int (*check_quota_file)(struct super_block___39 *, int);
	int (*read_file_info)(struct super_block___39 *, int);
	int (*write_file_info)(struct super_block___39 *, int);
	int (*free_file_info)(struct super_block___39 *, int);
	int (*read_dqblk)(struct dquot___38 *);
	int (*commit_dqblk)(struct dquot___38 *);
	int (*release_dqblk)(struct dquot___38 *);
	int (*get_next_id)(struct super_block___39 *, struct kqid *);
};

struct dquot_operations___38 {
	int (*write_dquot)(struct dquot___38 *);
	struct dquot___38 * (*alloc_dquot)(struct super_block___39 *, int);
	void (*destroy_dquot)(struct dquot___38 *);
	int (*acquire_dquot)(struct dquot___38 *);
	int (*release_dquot)(struct dquot___38 *);
	int (*mark_dirty)(struct dquot___38 *);
	int (*write_info)(struct super_block___39 *, int);
	qsize_t * (*get_reserved_space)(struct inode___39 *);
	int (*get_projid)(struct inode___39 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___39 *, qsize_t *);
	int (*get_next_id)(struct super_block___39 *, struct kqid *);
};

struct quotactl_ops___38 {
	int (*quota_on)(struct super_block___39 *, int, int, const struct path___38 *);
	int (*quota_off)(struct super_block___39 *, int);
	int (*quota_enable)(struct super_block___39 *, unsigned int);
	int (*quota_disable)(struct super_block___39 *, unsigned int);
	int (*quota_sync)(struct super_block___39 *, int);
	int (*set_info)(struct super_block___39 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___39 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___39 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___39 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___39 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___39 *, unsigned int);
};

struct wait_page_queue___20 {
	struct page___40 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___18;

struct readahead_control___20;

struct swap_info_struct___14;

struct address_space_operations___38 {
	int (*writepage)(struct page___40 *, struct writeback_control___18 *);
	int (*readpage)(struct file___39 *, struct page___40 *);
	int (*writepages)(struct address_space___38 *, struct writeback_control___18 *);
	int (*set_page_dirty)(struct page___40 *);
	int (*readpages)(struct file___39 *, struct address_space___38 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___20 *);
	int (*write_begin)(struct file___39 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___40 **, void **);
	int (*write_end)(struct file___39 *, struct address_space___38 *, loff_t, unsigned int, unsigned int, struct page___40 *, void *);
	sector_t (*bmap)(struct address_space___38 *, sector_t);
	void (*invalidatepage)(struct page___40 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___40 *, gfp_t);
	void (*freepage)(struct page___40 *);
	ssize_t (*direct_IO)(struct kiocb___38 *, struct iov_iter___22 *);
	int (*migratepage)(struct address_space___38 *, struct page___40 *, struct page___40 *, enum migrate_mode);
	bool (*isolate_page)(struct page___40 *, isolate_mode_t);
	void (*putback_page)(struct page___40 *);
	int (*launder_page)(struct page___40 *);
	int (*is_partially_uptodate)(struct page___40 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___40 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___38 *, struct page___40 *);
	int (*swap_activate)(struct swap_info_struct___14 *, struct file___39 *, sector_t *);
	void (*swap_deactivate)(struct file___39 *);
};

struct writeback_control___18 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___18 *wb;
	struct inode___39 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___20 {
	struct file___39 *file;
	struct address_space___38 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___22;

struct iov_iter___22 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___22 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___13 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___14 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___20 *bdev;
	struct file___39 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___38 {
	struct dentry___39 * (*lookup)(struct inode___39 *, struct dentry___39 *, unsigned int);
	const char * (*get_link)(struct dentry___39 *, struct inode___39 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___39 *, int);
	struct posix_acl * (*get_acl)(struct inode___39 *, int, bool);
	int (*readlink)(struct dentry___39 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___39 *, struct dentry___39 *, umode_t, bool);
	int (*link)(struct dentry___39 *, struct inode___39 *, struct dentry___39 *);
	int (*unlink)(struct inode___39 *, struct dentry___39 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___39 *, struct dentry___39 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___39 *, struct dentry___39 *, umode_t);
	int (*rmdir)(struct inode___39 *, struct dentry___39 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___39 *, struct dentry___39 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___39 *, struct dentry___39 *, struct inode___39 *, struct dentry___39 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___39 *, struct iattr___39 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___38 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___39 *, char *, size_t);
	int (*fiemap)(struct inode___39 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___39 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___39 *, struct dentry___39 *, struct file___39 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___39 *, struct dentry___39 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___39 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___39 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___39 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___38 {
	void (*fl_copy_lock)(struct file_lock___38 *, struct file_lock___38 *);
	void (*fl_release_private)(struct file_lock___38 *);
};

struct lock_manager_operations___38;

struct file_lock___38 {
	struct file_lock___38 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___39 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___38 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___38 *fl_ops;
	const struct lock_manager_operations___38 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___38 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___38 *);
	int (*lm_grant)(struct file_lock___38 *, int);
	bool (*lm_break)(struct file_lock___38 *);
	int (*lm_change)(struct file_lock___38 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___38 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___38 *);
};

struct fasync_struct___38 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___38 *fa_next;
	struct file___39 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___38 {
	struct inode___39 * (*alloc_inode)(struct super_block___39 *);
	void (*destroy_inode)(struct inode___39 *);
	void (*free_inode)(struct inode___39 *);
	void (*dirty_inode)(struct inode___39 *, int);
	int (*write_inode)(struct inode___39 *, struct writeback_control___18 *);
	int (*drop_inode)(struct inode___39 *);
	void (*evict_inode)(struct inode___39 *);
	void (*put_super)(struct super_block___39 *);
	int (*sync_fs)(struct super_block___39 *, int);
	int (*freeze_super)(struct super_block___39 *);
	int (*freeze_fs)(struct super_block___39 *);
	int (*thaw_super)(struct super_block___39 *);
	int (*unfreeze_fs)(struct super_block___39 *);
	int (*statfs)(struct dentry___39 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___39 *, int *, char *);
	void (*umount_begin)(struct super_block___39 *);
	int (*show_options)(struct seq_file___38 *, struct dentry___39 *);
	int (*show_devname)(struct seq_file___38 *, struct dentry___39 *);
	int (*show_path)(struct seq_file___38 *, struct dentry___39 *);
	int (*show_stats)(struct seq_file___38 *, struct dentry___39 *);
	ssize_t (*quota_read)(struct super_block___39 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___39 *, int, const char *, size_t, loff_t);
	struct dquot___38 ** (*get_dquots)(struct inode___39 *);
	long int (*nr_cached_objects)(struct super_block___39 *, struct shrink_control___18 *);
	long int (*free_cached_objects)(struct super_block___39 *, struct shrink_control___18 *);
	struct file___39 * (*real_loop)(struct file___39 *);
};

struct block_device___20 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___39 *bd_inode;
	struct super_block___39 *bd_super;
	void *bd_claiming;
	struct device___35 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___38 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___19 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___39 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___19(struct bio___19 *);

struct bio_vec___22 {
	struct page___40 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___19;

struct bio___19 {
	struct bio___19 *bi_next;
	struct block_device___20 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___19 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___18 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___19 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___22 *bi_io_vec;
	struct bio_set___19 *bi_pool;
	struct bio_vec___22 bi_inline_vecs[0];
};

struct dev_pagemap_ops___38 {
	void (*page_free)(struct page___40 *);
	void (*kill)(struct dev_pagemap___38 *);
	void (*cleanup)(struct dev_pagemap___38 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___38 *);
};

struct kernel_param_ops___38 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___38 *);
	int (*get)(char *, const struct kernel_param___38 *);
	void (*free)(void *);
};

struct kparam_array___38;

struct kernel_param___38 {
	const char *name;
	struct module___40 *mod;
	const struct kernel_param_ops___38 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___38 *arr;
	};
};

struct kparam_array___38 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___38 *ops;
	void *elem;
};

struct module_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___38 *, struct module_kobject___38 *, char *);
	ssize_t (*store)(struct module_attribute___38 *, struct module_kobject___38 *, const char *, size_t);
	void (*setup)(struct module___40 *, const char *);
	int (*test)(struct module___40 *);
	void (*free)(struct module___40 *);
};

struct trace_event_class___22;

struct trace_event_call___22 {
	struct list_head list;
	struct trace_event_class___22 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___22 *, struct perf_event___27 *);
};

struct cgroup_namespace___31 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___31 *root_cset;
};

struct dev_pm_ops___35 {
	int (*prepare)(struct device___35 *);
	void (*complete)(struct device___35 *);
	int (*suspend)(struct device___35 *);
	int (*resume)(struct device___35 *);
	int (*freeze)(struct device___35 *);
	int (*thaw)(struct device___35 *);
	int (*poweroff)(struct device___35 *);
	int (*restore)(struct device___35 *);
	int (*suspend_late)(struct device___35 *);
	int (*resume_early)(struct device___35 *);
	int (*freeze_late)(struct device___35 *);
	int (*thaw_early)(struct device___35 *);
	int (*poweroff_late)(struct device___35 *);
	int (*restore_early)(struct device___35 *);
	int (*suspend_noirq)(struct device___35 *);
	int (*resume_noirq)(struct device___35 *);
	int (*freeze_noirq)(struct device___35 *);
	int (*thaw_noirq)(struct device___35 *);
	int (*poweroff_noirq)(struct device___35 *);
	int (*restore_noirq)(struct device___35 *);
	int (*runtime_suspend)(struct device___35 *);
	int (*runtime_resume)(struct device___35 *);
	int (*runtime_idle)(struct device___35 *);
};

struct wakeup_source___35 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___35 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___8;

struct dev_pm_qos___8 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___8 *resume_latency_req;
	struct dev_pm_qos_request___8 *latency_tolerance_req;
	struct dev_pm_qos_request___8 *flags_req;
};

struct dev_pm_domain___35 {
	struct dev_pm_ops___35 ops;
	int (*start)(struct device___35 *);
	void (*detach)(struct device___35 *, bool);
	int (*activate)(struct device___35 *);
	void (*sync)(struct device___35 *);
	void (*dismiss)(struct device___35 *);
};

struct bus_type___35 {
	const char *name;
	const char *dev_name;
	struct device___35 *dev_root;
	const struct attribute_group___38 **bus_groups;
	const struct attribute_group___38 **dev_groups;
	const struct attribute_group___38 **drv_groups;
	int (*match)(struct device___35 *, struct device_driver___35 *);
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	int (*probe)(struct device___35 *);
	void (*sync_state)(struct device___35 *);
	void (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*online)(struct device___35 *);
	int (*offline)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	int (*num_vf)(struct device___35 *);
	int (*dma_configure)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___35 {
	const char *name;
	struct bus_type___35 *bus;
	struct module___40 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___35 *);
	void (*sync_state)(struct device___35 *);
	int (*remove)(struct device___35 *);
	void (*shutdown)(struct device___35 *);
	int (*suspend)(struct device___35 *, pm_message_t);
	int (*resume)(struct device___35 *);
	const struct attribute_group___38 **groups;
	const struct attribute_group___38 **dev_groups;
	const struct dev_pm_ops___35 *pm;
	void (*coredump)(struct device___35 *);
	struct driver_private *p;
};

struct device_type___35 {
	const char *name;
	const struct attribute_group___38 **groups;
	int (*uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___35 *);
	const struct dev_pm_ops___35 *pm;
};

struct class___35 {
	const char *name;
	struct module___40 *owner;
	const struct attribute_group___38 **class_groups;
	const struct attribute_group___38 **dev_groups;
	struct kobject___38 *dev_kobj;
	int (*dev_uevent)(struct device___35 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___35 *, umode_t *);
	void (*class_release)(struct class___35 *);
	void (*dev_release)(struct device___35 *);
	int (*shutdown_pre)(struct device___35 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___35 *);
	void (*get_ownership)(struct device___35 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___35 *pm;
	struct subsys_private *p;
};

struct block_device_operations___19;

struct gendisk___19 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___20 *part0;
	const struct block_device_operations___19 *fops;
	struct request_queue___20 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___18 *bdi;
	struct kobject___38 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___38 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___19 {
	struct bio___19 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___22 *bip_vec;
	struct bio_vec___22 bip_inline_vecs[0];
};

struct blkcg___18;

struct blkg_policy_data___18;

struct blkcg_gq___18 {
	struct request_queue___20 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___18 *blkcg;
	struct blkcg_gq___18 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___18 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___19 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___19(struct request___19 *);

typedef void integrity_complete_fn___19(struct request___19 *, unsigned int);

struct blk_integrity_profile___19 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___19 *prepare_fn;
	integrity_complete_fn___19 *complete_fn;
	const char *name;
};

struct block_device_operations___19 {
	blk_qc_t (*submit_bio)(struct bio___19 *);
	int (*open)(struct block_device___20 *, fmode_t);
	void (*release)(struct gendisk___19 *, fmode_t);
	int (*rw_page)(struct block_device___20 *, sector_t, struct page___40 *, unsigned int);
	int (*ioctl)(struct block_device___20 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___20 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___19 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___19 *);
	int (*getgeo)(struct block_device___20 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___20 *, bool);
	void (*swap_slot_free_notify)(struct block_device___20 *, long unsigned int);
	int (*report_zones)(struct gendisk___19 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___19 *, umode_t *);
	struct module___40 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___19 *, sector_t *);
};

typedef void rq_end_io_fn___19(struct request___19 *, blk_status_t);

struct request___19 {
	struct request_queue___20 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___18 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___19 *bio;
	struct bio___19 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___22 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___19 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___19 *saved_end_io;
		} flush;
	};
	struct gendisk___19 *rq_disk;
	struct block_device___20 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___19 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___18 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___20 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___38 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___39 *debugfs_dir;
	struct dentry___39 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___19;

struct elevator_mq_ops___19 {
	int (*init_sched)(struct request_queue___20 *, struct elevator_type___19 *);
	void (*exit_sched)(struct elevator_queue___19 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___18 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___18 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___18 *);
	bool (*allow_merge)(struct request_queue___20 *, struct request___19 *, struct bio___19 *);
	bool (*bio_merge)(struct request_queue___20 *, struct bio___19 *, unsigned int);
	int (*request_merge)(struct request_queue___20 *, struct request___19 **, struct bio___19 *);
	void (*request_merged)(struct request_queue___20 *, struct request___19 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___20 *, struct request___19 *, struct request___19 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___19 *);
	void (*finish_request)(struct request___19 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___18 *, struct list_head *, bool);
	struct request___19 * (*dispatch_request)(struct blk_mq_hw_ctx___18 *);
	bool (*has_work)(struct blk_mq_hw_ctx___18 *);
	void (*completed_request)(struct request___19 *, u64);
	void (*requeue_request)(struct request___19 *);
	struct request___19 * (*former_request)(struct request_queue___20 *, struct request___19 *);
	struct request___19 * (*next_request)(struct request_queue___20 *, struct request___19 *);
	void (*init_icq)(struct io_cq___19 *);
	void (*exit_icq)(struct io_cq___19 *);
};

struct elv_fs_entry___19;

struct elevator_type___19 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___19 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___19 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___40 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___19 {
	struct elevator_type___19 *type;
	void *elevator_data;
	struct kobject___38 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___19 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___19 *, char *);
	ssize_t (*store)(struct elevator_queue___19 *, const char *, size_t);
};

struct blk_mq_queue_data___18;

struct blk_mq_ops___18 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___18 *, const struct blk_mq_queue_data___18 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___18 *);
	int (*get_budget)(struct request_queue___20 *);
	void (*put_budget)(struct request_queue___20 *, int);
	void (*set_rq_budget_token)(struct request___19 *, int);
	int (*get_rq_budget_token)(struct request___19 *);
	enum blk_eh_timer_return (*timeout)(struct request___19 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___18 *);
	void (*complete)(struct request___19 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___18 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___18 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___18 *, struct request___19 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___18 *, struct request___19 *, unsigned int);
	void (*initialize_rq_fn)(struct request___19 *);
	void (*cleanup_rq)(struct request___19 *);
	bool (*busy)(struct request_queue___20 *);
	int (*map_queues)(struct blk_mq_tag_set___18 *);
	void (*show_rq)(struct seq_file___38 *, struct request___19 *);
};

struct blk_mq_tag_set___18 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___18 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct dev_pm_qos_request___8 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___35 *dev;
};

struct cpuidle_driver___3;

struct cpuidle_state___3 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___3 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___3 *, int);
};

struct cpuidle_driver___3 {
	const char *name;
	struct module___40 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___3 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct seq_operations___37 {
	void * (*start)(struct seq_file___38 *, loff_t *);
	void (*stop)(struct seq_file___38 *, void *);
	void * (*next)(struct seq_file___38 *, void *, loff_t *);
	int (*show)(struct seq_file___38 *, void *);
};

struct pipe_buf_operations___13;

struct pipe_buffer___13 {
	struct page___40 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___13 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___13 {
	int (*confirm)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	void (*release)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	bool (*try_steal)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
	bool (*get)(struct pipe_inode_info___13 *, struct pipe_buffer___13 *);
};

struct cftype___31;

struct cgroup_subsys___31 {
	struct cgroup_subsys_state___31 * (*css_alloc)(struct cgroup_subsys_state___31 *);
	int (*css_online)(struct cgroup_subsys_state___31 *);
	void (*css_offline)(struct cgroup_subsys_state___31 *);
	void (*css_released)(struct cgroup_subsys_state___31 *);
	void (*css_free)(struct cgroup_subsys_state___31 *);
	void (*css_reset)(struct cgroup_subsys_state___31 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___31 *, int);
	int (*css_extra_stat_show)(struct seq_file___38 *, struct cgroup_subsys_state___31 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___41 *, struct css_set___31 *);
	void (*cancel_fork)(struct task_struct___41 *, struct css_set___31 *);
	void (*fork)(struct task_struct___41 *);
	void (*exit)(struct task_struct___41 *);
	void (*release)(struct task_struct___41 *);
	void (*bind)(struct cgroup_subsys_state___31 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___31 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___31 *dfl_cftypes;
	struct cftype___31 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___31 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___31 *updated_children;
	struct cgroup___31 *updated_next;
};

struct cgroup_root___31 {
	struct kernfs_root___38 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___31 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___31 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___31 *ss;
	struct list_head node;
	struct kernfs_ops___38 *kf_ops;
	int (*open)(struct kernfs_open_file___38 *);
	void (*release)(struct kernfs_open_file___38 *);
	u64 (*read_u64)(struct cgroup_subsys_state___31 *, struct cftype___31 *);
	s64 (*read_s64)(struct cgroup_subsys_state___31 *, struct cftype___31 *);
	int (*seq_show)(struct seq_file___38 *, void *);
	void * (*seq_start)(struct seq_file___38 *, loff_t *);
	void * (*seq_next)(struct seq_file___38 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___38 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___31 *, struct cftype___31 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___31 *, struct cftype___31 *, s64);
	ssize_t (*write)(struct kernfs_open_file___38 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___38 *, struct poll_table_struct___30 *);
};

struct blk_mq_queue_data___18 {
	struct request___19 *rq;
	bool last;
};

struct blkcg_policy_data___18;

struct blkcg___18 {
	struct cgroup_subsys_state___31 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___18 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___18 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___18 {
	struct blkcg___18 *blkcg;
	int plid;
};

struct blkg_policy_data___18 {
	struct blkcg_gq___18 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___18 {
	struct mem_cgroup___18 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___18 {
	struct lruvec___19 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___18 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___18 *memcg;
};

struct obj_cgroup___18 {
	struct percpu_ref refcnt;
	struct mem_cgroup___18 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

union perf_mem_data_src___3 {
	__u64 val;
	struct {
		__u64 mem_op: 5;
		__u64 mem_lvl: 14;
		__u64 mem_snoop: 5;
		__u64 mem_lock: 2;
		__u64 mem_dtlb: 7;
		__u64 mem_lvl_num: 4;
		__u64 mem_remote: 1;
		__u64 mem_snoopx: 2;
		__u64 mem_blk: 3;
		__u64 mem_rsvd: 21;
	};
};

union perf_sample_weight___3 {
	__u64 full;
	struct {
		__u32 var1_dw;
		__u16 var2_w;
		__u16 var3_w;
	};
};

struct perf_cpu_context___27;

struct perf_output_handle___27;

struct pmu___27 {
	struct list_head entry;
	struct module___40 *module;
	struct device___35 *dev;
	const struct attribute_group___38 **attr_groups;
	const struct attribute_group___38 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___27 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___27 *);
	void (*pmu_disable)(struct pmu___27 *);
	int (*event_init)(struct perf_event___27 *);
	void (*event_mapped)(struct perf_event___27 *, struct mm_struct___41 *);
	void (*event_unmapped)(struct perf_event___27 *, struct mm_struct___41 *);
	int (*add)(struct perf_event___27 *, int);
	void (*del)(struct perf_event___27 *, int);
	void (*start)(struct perf_event___27 *, int);
	void (*stop)(struct perf_event___27 *, int);
	void (*read)(struct perf_event___27 *);
	void (*start_txn)(struct pmu___27 *, unsigned int);
	int (*commit_txn)(struct pmu___27 *);
	void (*cancel_txn)(struct pmu___27 *);
	int (*event_idx)(struct perf_event___27 *);
	void (*sched_task)(struct perf_event_context___27 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___27 *, struct perf_event_context___27 *);
	void * (*setup_aux)(struct perf_event___27 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___27 *, struct perf_output_handle___27 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___27 *);
	int (*aux_output_match)(struct perf_event___27 *);
	int (*filter_match)(struct perf_event___27 *);
	int (*check_period)(struct perf_event___27 *, u64);
};

struct perf_cpu_context___27 {
	struct perf_event_context___27 ctx;
	struct perf_event_context___27 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___27 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___27 **heap;
	struct perf_event___27 *heap_default[2];
};

struct perf_output_handle___27 {
	struct perf_event___27 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_sample_data___3 {
	u64 addr;
	struct perf_raw_record *raw;
	struct perf_branch_stack *br_stack;
	u64 period;
	union perf_sample_weight___3 weight;
	long: 64;
	u64 txn;
	union perf_mem_data_src___3 data_src;
	long: 64;
	u64 type;
	u64 ip;
	struct {
		u32 pid;
		u32 tid;
	} tid_entry;
	u64 time;
	u64 id;
	u64 stream_id;
	struct {
		u32 cpu;
		u32 reserved;
	} cpu_entry;
	struct perf_callchain_entry *callchain;
	u64 aux_size;
	struct perf_regs regs_user;
	struct perf_regs regs_intr;
	u64 stack_user_size;
	u64 phys_addr;
	u64 cgroup;
	u64 data_page_size;
	u64 code_page_size;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct perf_cgroup___27 {
	struct cgroup_subsys_state___31 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___22 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___22 *);
	};
};

struct trace_event_class___22 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___22 *, enum trace_reg, void *);
	struct trace_event_fields___22 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___22 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___22 *);
};

typedef int (*tg_visitor___2)(struct task_group___3 *, void *);

struct rq___3 {
	raw_spinlock_t __lock;
	unsigned int nr_running;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
	unsigned int numa_migrate_on;
	long unsigned int last_blocked_load_update_tick;
	unsigned int has_blocked_load;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t nohz_csd;
	unsigned int nohz_tick_stopped;
	atomic_t nohz_flags;
	unsigned int ttwu_pending;
	u64 nr_switches;
	long: 64;
	struct uclamp_rq uclamp[2];
	unsigned int uclamp_flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	struct cfs_rq___3 cfs;
	struct rt_rq rt;
	struct dl_rq dl;
	struct list_head leaf_cfs_rq_list;
	struct list_head *tmp_alone_branch;
	unsigned int nr_uninterruptible;
	struct task_struct___41 *curr;
	struct task_struct___41 *idle;
	struct task_struct___41 *stop;
	long unsigned int next_balance;
	struct mm_struct___41 *prev_mm;
	unsigned int clock_update_flags;
	u64 clock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 clock_task;
	u64 clock_pelt;
	long unsigned int lost_idle_time;
	atomic_t nr_iowait;
	u64 last_seen_need_resched_ns;
	int ticks_without_resched;
	int membarrier_state;
	struct root_domain *rd;
	struct sched_domain *sd;
	long unsigned int cpu_capacity;
	long unsigned int cpu_capacity_orig;
	struct callback_head *balance_callback;
	unsigned char nohz_idle_balance;
	unsigned char idle_balance;
	long unsigned int misfit_task_load;
	int active_balance;
	int push_cpu;
	struct cpu_stop_work active_balance_work;
	int cpu;
	int online;
	struct list_head cfs_tasks;
	long: 64;
	struct sched_avg avg_rt;
	struct sched_avg avg_dl;
	struct sched_avg avg_thermal;
	u64 idle_stamp;
	u64 avg_idle;
	long unsigned int wake_stamp;
	u64 wake_avg_idle;
	u64 max_idle_balance_cost;
	struct rcuwait___38 hotplug_wait;
	u64 prev_steal_time;
	long unsigned int calc_load_update;
	long int calc_load_active;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t hrtick_csd;
	struct hrtimer hrtick_timer;
	ktime_t hrtick_time;
	struct sched_info rq_sched_info;
	long long unsigned int rq_cpu_time;
	unsigned int yld_count;
	unsigned int sched_count;
	unsigned int sched_goidle;
	unsigned int ttwu_count;
	unsigned int ttwu_local;
	struct cpuidle_state___3 *idle_state;
	unsigned int nr_pinned;
	unsigned int push_busy;
	struct cpu_stop_work push_work;
	struct rq___3 *core;
	struct task_struct___41 *core_pick;
	unsigned int core_enabled;
	unsigned int core_sched_seq;
	struct rb_root core_tree;
	unsigned int core_task_seq;
	unsigned int core_pick_seq;
	long unsigned int core_cookie;
	unsigned char core_forceidle;
	unsigned int core_forceidle_seq;
};

enum numa_topology_type {
	NUMA_DIRECT = 0,
	NUMA_GLUELESS_MESH = 1,
	NUMA_BACKPLANE = 2,
};

enum numa_faults_stats {
	NUMA_MEM = 0,
	NUMA_CPU = 1,
	NUMA_MEMBUF = 2,
	NUMA_CPUBUF = 3,
};

enum numa_type {
	node_has_spare = 0,
	node_fully_busy = 1,
	node_overloaded = 2,
};

struct numa_stats {
	long unsigned int load;
	long unsigned int runnable;
	long unsigned int util;
	long unsigned int compute_capacity;
	unsigned int nr_running;
	unsigned int weight;
	enum numa_type node_type;
	int idle_cpu;
};

struct task_numa_env {
	struct task_struct___41 *p;
	int src_cpu;
	int src_nid;
	int dst_cpu;
	int dst_nid;
	struct numa_stats src_stats;
	struct numa_stats dst_stats;
	int imbalance_pct;
	int dist;
	struct task_struct___41 *best_task;
	long int best_imp;
	int best_cpu;
};

enum fbq_type {
	regular = 0,
	remote = 1,
	all = 2,
};

enum group_type {
	group_has_spare = 0,
	group_fully_busy = 1,
	group_misfit_task = 2,
	group_asym_packing = 3,
	group_imbalanced = 4,
	group_overloaded = 5,
};

enum migration_type {
	migrate_load = 0,
	migrate_util = 1,
	migrate_task = 2,
	migrate_misfit = 3,
};

struct lb_env {
	struct sched_domain *sd;
	struct rq___3 *src_rq;
	int src_cpu;
	int dst_cpu;
	struct rq___3 *dst_rq;
	struct cpumask *dst_grpmask;
	int new_dst_cpu;
	enum cpu_idle_type idle;
	long int imbalance;
	struct cpumask *cpus;
	unsigned int flags;
	unsigned int loop;
	unsigned int loop_break;
	unsigned int loop_max;
	enum fbq_type fbq_type;
	enum migration_type migration_type;
	struct list_head tasks;
};

struct sg_lb_stats {
	long unsigned int avg_load;
	long unsigned int group_load;
	long unsigned int group_capacity;
	long unsigned int group_util;
	long unsigned int group_runnable;
	unsigned int sum_nr_running;
	unsigned int sum_h_nr_running;
	unsigned int idle_cpus;
	unsigned int group_weight;
	enum group_type group_type;
	unsigned int group_asym_packing;
	long unsigned int group_misfit_task_load;
	unsigned int nr_numa_running;
	unsigned int nr_preferred_running;
};

struct sd_lb_stats {
	struct sched_group *busiest;
	struct sched_group *local;
	long unsigned int total_load;
	long unsigned int total_capacity;
	long unsigned int avg_load;
	unsigned int prefer_sibling;
	struct sg_lb_stats busiest_stat;
	struct sg_lb_stats local_stat;
};

typedef struct rt_rq *rt_rq_iter_t;

struct swait_queue {
	struct task_struct___2 *task;
	struct list_head task_list;
};

struct sd_flag_debug {
	unsigned int meta_flags;
	char *name;
};

typedef const struct cpumask * (*sched_domain_mask_f)(int);

typedef int (*sched_domain_flags_f)();

struct sd_data {
	struct sched_domain **sd;
	struct sched_domain_shared **sds;
	struct sched_group **sg;
	struct sched_group_capacity **sgc;
};

struct sched_domain_topology_level {
	sched_domain_mask_f mask;
	sched_domain_flags_f sd_flags;
	int flags;
	int numa_level;
	struct sd_data data;
	char *name;
};

struct cpufreq_governor___2;

struct thermal_cooling_device___3;

struct cpufreq_policy___2 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___2 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___38 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___41 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___3 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___2 {
	char name[16];
	int (*init)(struct cpufreq_policy___2 *);
	void (*exit)(struct cpufreq_policy___2 *);
	int (*start)(struct cpufreq_policy___2 *);
	void (*stop)(struct cpufreq_policy___2 *);
	void (*limits)(struct cpufreq_policy___2 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___2 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___2 *, unsigned int);
	struct list_head governor_list;
	struct module___40 *owner;
	u8 flags;
};

struct s_data {
	struct sched_domain **sd;
	struct root_domain *rd;
};

enum s_alloc {
	sa_rootdomain = 0,
	sa_sd = 1,
	sa_sd_storage = 2,
	sa_none = 3,
};

struct asym_cap_data {
	struct list_head link;
	long unsigned int capacity;
	long unsigned int cpus[0];
};

enum cpuacct_stat_index {
	CPUACCT_STAT_USER = 0,
	CPUACCT_STAT_SYSTEM = 1,
	CPUACCT_STAT_NSTATS = 2,
};

struct cpuacct {
	struct cgroup_subsys_state___30 css;
	u64 *cpuusage;
	struct kernel_cpustat *cpustat;
};

struct cpufreq_governor___3;

struct cpufreq_policy___3 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___3 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___37 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___2 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___3 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___3 {
	char name[16];
	int (*init)(struct cpufreq_policy___3 *);
	void (*exit)(struct cpufreq_policy___3 *);
	int (*start)(struct cpufreq_policy___3 *);
	void (*stop)(struct cpufreq_policy___3 *);
	void (*limits)(struct cpufreq_policy___3 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___3 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___3 *, unsigned int);
	struct list_head governor_list;
	struct module___39 *owner;
	u8 flags;
};

struct gov_attr_set {
	struct kobject___37 kobj;
	struct list_head policy_list;
	struct mutex update_lock;
	int usage_count;
};

struct governor_attr {
	struct attribute attr;
	ssize_t (*show)(struct gov_attr_set *, char *);
	ssize_t (*store)(struct gov_attr_set *, const char *, size_t);
};

struct kthread_work___3;

typedef void (*kthread_work_func_t___3)(struct kthread_work___3 *);

struct kthread_worker___3;

struct kthread_work___3 {
	struct list_head node;
	kthread_work_func_t___3 func;
	struct kthread_worker___3 *worker;
	int canceling;
};

struct kthread_worker___3 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___2 *task;
	struct kthread_work___3 *current_work;
};

struct sugov_tunables {
	struct gov_attr_set attr_set;
	unsigned int rate_limit_us;
};

struct sugov_policy {
	struct cpufreq_policy___3 *policy;
	struct sugov_tunables *tunables;
	struct list_head tunables_hook;
	raw_spinlock_t update_lock;
	u64 last_freq_update_time;
	s64 freq_update_delay_ns;
	unsigned int next_freq;
	unsigned int cached_raw_freq;
	struct irq_work irq_work;
	struct kthread_work___3 work;
	struct mutex work_lock;
	struct kthread_worker___3 worker;
	struct task_struct___2 *thread;
	bool work_in_progress;
	bool limits_changed;
	bool need_freq_update;
};

struct sugov_cpu {
	struct update_util_data update_util;
	struct sugov_policy *sg_policy;
	unsigned int cpu;
	bool iowait_boost_pending;
	unsigned int iowait_boost;
	u64 last_update;
	long unsigned int util;
	long unsigned int bw_dl;
	long unsigned int max;
	long unsigned int saved_idle_calls;
};

enum {
	MEMBARRIER_FLAG_SYNC_CORE = 1,
	MEMBARRIER_FLAG_RSEQ = 2,
};

enum membarrier_cmd {
	MEMBARRIER_CMD_QUERY = 0,
	MEMBARRIER_CMD_GLOBAL = 1,
	MEMBARRIER_CMD_GLOBAL_EXPEDITED = 2,
	MEMBARRIER_CMD_REGISTER_GLOBAL_EXPEDITED = 4,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED = 8,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED = 16,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED_SYNC_CORE = 32,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_SYNC_CORE = 64,
	MEMBARRIER_CMD_PRIVATE_EXPEDITED_RSEQ = 128,
	MEMBARRIER_CMD_REGISTER_PRIVATE_EXPEDITED_RSEQ = 256,
	MEMBARRIER_CMD_SHARED = 1,
};

enum membarrier_cmd_flag {
	MEMBARRIER_CMD_FLAG_CPU = 1,
};

struct syscall_metadata___10 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___21 *enter_event;
	struct trace_event_call___21 *exit_event;
};

struct proc_ops {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___39 *, struct file___39 *);
	ssize_t (*proc_read)(struct file___39 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___38 *, struct iov_iter___22 *);
	ssize_t (*proc_write)(struct file___39 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___39 *, loff_t, int);
	int (*proc_release)(struct inode___39 *, struct file___39 *);
	__poll_t (*proc_poll)(struct file___39 *, struct poll_table_struct___30 *);
	long int (*proc_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___39 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___39 *, struct vm_area_struct___40 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___39 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

enum psi_res {
	PSI_IO = 0,
	PSI_MEM = 1,
	PSI_CPU = 2,
	NR_PSI_RESOURCES = 3,
};

struct psi_window {
	u64 size;
	u64 start_time;
	u64 start_value;
	u64 prev_growth;
};

struct psi_trigger {
	enum psi_states state;
	u64 threshold;
	struct list_head node;
	struct psi_group___31 *group;
	wait_queue_head_t event_wait;
	int event;
	struct psi_window win;
	u64 last_event_time;
};

typedef struct poll_table_struct___30 poll_table___4;

struct sched_core_cookie {
	refcount_t refcnt;
};

struct ww_acquire_ctx;

struct ww_mutex {
	struct mutex base;
	struct ww_acquire_ctx *ctx;
};

struct ww_acquire_ctx {
	struct task_struct___30 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct signal_struct___2 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___30 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___30 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___26 *pids[4];
	struct pid___26 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___29 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct mutex_waiter {
	struct list_head list;
	struct task_struct___30 *task;
	struct ww_acquire_ctx *ww_ctx;
};

struct semaphore {
	raw_spinlock_t lock;
	unsigned int count;
	struct list_head wait_list;
};

struct semaphore_waiter {
	struct list_head list;
	struct task_struct___36 *task;
	bool up;
};

enum rwsem_waiter_type {
	RWSEM_WAITING_FOR_WRITE = 0,
	RWSEM_WAITING_FOR_READ = 1,
};

struct rwsem_waiter {
	struct list_head list;
	struct task_struct___30 *task;
	enum rwsem_waiter_type type;
	long unsigned int timeout;
	bool handoff_set;
};

enum rwsem_wake_type {
	RWSEM_WAKE_ANY = 0,
	RWSEM_WAKE_READERS = 1,
	RWSEM_WAKE_READ_OWNED = 2,
};

enum owner_state {
	OWNER_NULL = 1,
	OWNER_WRITER = 2,
	OWNER_READER = 4,
	OWNER_NONSPINNABLE = 8,
};

struct rcuwait___39 {
	struct task_struct___30 *task;
};

struct percpu_rw_semaphore___39 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___39 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct optimistic_spin_node {
	struct optimistic_spin_node *next;
	struct optimistic_spin_node *prev;
	int locked;
	int cpu;
};

struct mcs_spinlock {
	struct mcs_spinlock *next;
	int locked;
	int count;
};

struct qnode {
	struct mcs_spinlock mcs;
};

struct rt_mutex_base {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___30 *owner;
};

struct rt_mutex {
	struct rt_mutex_base rtmutex;
};

struct hrtimer_sleeper {
	struct hrtimer timer;
	struct task_struct___30 *task;
};

struct rt_mutex_waiter {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___30 *task;
	struct rt_mutex_base *lock;
	unsigned int wake_state;
	int prio;
	u64 deadline;
	struct ww_acquire_ctx *ww_ctx;
};

struct rt_wake_q_head {
	struct wake_q_head head;
	struct task_struct___30 *rtlock_task;
};

enum rtmutex_chainwalk {
	RT_MUTEX_MIN_CHAINWALK = 0,
	RT_MUTEX_FULL_CHAINWALK = 1,
};

struct vm_area_struct___41;

struct vmacache___41 {
	u64 seqnum;
	struct vm_area_struct___41 *vmas[4];
};

struct page___41;

struct page_frag___41 {
	struct page___41 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___42;

struct vm_struct___40;

struct task_struct___42 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___42 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___42 *mm;
	struct mm_struct___42 *active_mm;
	struct vmacache___41 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___42 *real_parent;
	struct task_struct___42 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___42 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___37 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___42 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___41 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task___3 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___42 *oom_reaper_list;
	struct vm_struct___40 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___27 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___41 *pgtable_t___41;

struct page___41 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___38 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___41 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___41 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___42 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___38 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	long: 64;
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___41 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___41 *vm_next;
	struct vm_area_struct___41 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___42 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___41;

struct mm_struct___42 {
	struct {
		struct vm_area_struct___41 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___41 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___42 *owner;
		struct user_namespace *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___40 {
	struct vm_struct___40 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___41 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct core_thread___41 {
	struct task_struct___42 *task;
	struct core_thread___41 *next;
};

struct core_state___41 {
	atomic_t nr_threads;
	struct core_thread___41 dumper;
	struct completion startup;
};

struct pm_qos_request {
	struct plist_node node;
	struct pm_qos_constraints *qos;
};

enum pm_qos_req_action {
	PM_QOS_ADD_REQ = 0,
	PM_QOS_UPDATE_REQ = 1,
	PM_QOS_REMOVE_REQ = 2,
};

struct miscdevice___2 {
	int minor;
	const char *name;
	const struct file_operations___7 *fops;
	struct list_head list;
	struct device___29 *parent;
	struct device___29 *this_device;
	const struct attribute_group___31 **groups;
	const char *nodename;
	umode_t mode;
};

typedef int suspend_state_t;

enum suspend_stat_step {
	SUSPEND_FREEZE = 1,
	SUSPEND_PREPARE = 2,
	SUSPEND_SUSPEND = 3,
	SUSPEND_SUSPEND_LATE = 4,
	SUSPEND_SUSPEND_NOIRQ = 5,
	SUSPEND_RESUME_NOIRQ = 6,
	SUSPEND_RESUME_EARLY = 7,
	SUSPEND_RESUME = 8,
};

struct suspend_stats {
	int success;
	int fail;
	int failed_freeze;
	int failed_prepare;
	int failed_suspend;
	int failed_suspend_late;
	int failed_suspend_noirq;
	int failed_resume;
	int failed_resume_early;
	int failed_resume_noirq;
	int last_failed_dev;
	char failed_devs[80];
	int last_failed_errno;
	int errno[2];
	int last_failed_step;
	enum suspend_stat_step failed_steps[2];
};

enum {
	TEST_NONE = 0,
	TEST_CORE = 1,
	TEST_CPUS = 2,
	TEST_PLATFORM = 3,
	TEST_DEVICES = 4,
	TEST_FREEZER = 5,
	__TEST_AFTER_LAST = 6,
};

struct pm_vt_switch {
	struct list_head head;
	struct device___27 *dev;
	bool required;
};

struct dentry___40;

struct super_block___40;

struct module___41;

struct file_system_type___39 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___40 * (*mount)(struct file_system_type___39 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___40 *);
	struct module___41 *owner;
	struct file_system_type___39 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___40;

struct kiocb___39;

struct iov_iter___23;

struct poll_table_struct___31;

struct vm_area_struct___42;

struct inode___40;

struct file_lock___39;

struct page___42;

struct seq_file___39;

struct file_operations___39 {
	struct module___41 *owner;
	loff_t (*llseek)(struct file___40 *, loff_t, int);
	ssize_t (*read)(struct file___40 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___40 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___39 *, struct iov_iter___23 *);
	ssize_t (*write_iter)(struct kiocb___39 *, struct iov_iter___23 *);
	int (*iopoll)(struct kiocb___39 *, bool);
	int (*iterate)(struct file___40 *, struct dir_context *);
	int (*iterate_shared)(struct file___40 *, struct dir_context *);
	__poll_t (*poll)(struct file___40 *, struct poll_table_struct___31 *);
	long int (*unlocked_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___40 *, struct vm_area_struct___42 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___40 *, struct file___40 *);
	int (*flush)(struct file___40 *, fl_owner_t);
	int (*release)(struct inode___40 *, struct file___40 *);
	int (*fsync)(struct file___40 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___40 *, int);
	int (*lock)(struct file___40 *, int, struct file_lock___39 *);
	ssize_t (*sendpage)(struct file___40 *, struct page___42 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___40 *, long unsigned int);
	int (*flock)(struct file___40 *, int, struct file_lock___39 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___40 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___40 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___40 *, long int, struct file_lock___39 **, void **);
	long int (*fallocate)(struct file___40 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___39 *, struct file___40 *);
	ssize_t (*copy_file_range)(struct file___40 *, loff_t, struct file___40 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___40 *, loff_t, struct file___40 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___40 *, loff_t, loff_t, int);
};

struct vmacache___42 {
	u64 seqnum;
	struct vm_area_struct___42 *vmas[4];
};

struct page_frag___42 {
	struct page___42 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___28;

struct debug_info___28 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___28 *hbp_break[16];
	struct perf_event___28 *hbp_watch[16];
};

struct thread_struct___28 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___28 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___43;

struct pid___38;

struct nsproxy___39;

struct signal_struct___40;

struct bio_list___20;

struct backing_dev_info___19;

struct io_context___21;

struct css_set___32;

struct perf_event_context___28;

struct mem_cgroup___19;

struct request_queue___21;

struct vm_struct___41;

struct task_struct___43 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___43 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___43 *mm;
	struct mm_struct___43 *active_mm;
	struct vmacache___42 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___43 *real_parent;
	struct task_struct___43 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___43 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___38 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___39 *nsproxy;
	struct signal_struct___40 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___43 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___20 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___19 *backing_dev_info;
	struct io_context___21 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___32 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___28 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___42 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___19 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___19 *active_memcg;
	struct request_queue___21 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___43 *oom_reaper_list;
	struct vm_struct___41 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___28 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___39;

struct kobj_type___39;

struct kernfs_node___39;

struct kobject___39 {
	const char *name;
	struct list_head entry;
	struct kobject___39 *parent;
	struct kset___39 *kset;
	struct kobj_type___39 *ktype;
	struct kernfs_node___39 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___39 {
	struct kobject___39 kobj;
	struct module___41 *mod;
	struct kobject___39 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___39 {
	struct module___41 *mod;
	struct latch_tree_node node;
};

struct module_layout___39 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___39 mtn;
};

struct module_attribute___39;

struct kernel_param___39;

struct trace_event_call___23;

struct module___41 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___39 mkobj;
	struct module_attribute___39 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___39 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___39 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___39 core_layout;
	struct module_layout___39 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___23 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___28 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___43 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___28)(struct perf_event___28 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___28;

struct fasync_struct___39;

struct pid_namespace___38;

struct perf_cgroup___28;

struct perf_event___28 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___28 *group_leader;
	struct pmu___28 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___28 hw;
	struct perf_event_context___28 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___28 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___43 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___39 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___28 *aux_event;
	void (*destroy)(struct perf_event___28 *);
	struct callback_head callback_head;
	struct pid_namespace___38 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___28 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___28 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___23 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___28 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___38 {
	int nr;
	struct pid_namespace___38 *ns;
};

struct pid_namespace___38 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___43 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___38 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___38 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___38 numbers[1];
};

typedef struct page___42 *pgtable_t___42;

struct address_space___39;

struct dev_pagemap___39;

struct page___42 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___39 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___42 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___42 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___43 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___39 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___39;

struct vm_area_struct___42 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___42 *vm_next;
	struct vm_area_struct___42 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___43 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___39 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___40 *vm_file;
	struct file___40 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___40 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___43 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___43 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___38 *pids[4];
	struct pid___38 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___43 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___42;

struct mm_struct___43 {
	struct {
		struct vm_area_struct___42 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___42 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___43 *owner;
		struct user_namespace___4 *user_ns;
		struct file___40 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___32;

struct nsproxy___39 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___38 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___32 *cgroup_ns;
};

struct bio___20;

struct bio_list___20 {
	struct bio___20 *head;
	struct bio___20 *tail;
};

struct cgroup_subsys_state___32;

struct bdi_writeback___19 {
	struct backing_dev_info___19 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___32 *memcg_css;
	struct cgroup_subsys_state___32 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___36;

struct backing_dev_info___19 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___19 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___36 *dev;
	char dev_name[64];
	struct device___36 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___40 *debug_dir;
};

struct io_cq___20;

struct io_context___21 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___20 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___32;

struct css_set___32 {
	struct cgroup_subsys_state___32 *subsys[14];
	refcount_t refcount;
	struct css_set___32 *dom_cset;
	struct cgroup___32 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___32 *mg_src_cgrp;
	struct cgroup___32 *mg_dst_cgrp;
	struct css_set___32 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___28 {
	struct pmu___28 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___43 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___28 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___32;

struct cgroup_subsys_state___32 {
	struct cgroup___32 *cgroup;
	struct cgroup_subsys___32 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___32 *parent;
};

struct cgroup_file___32 {
	struct kernfs_node___39 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___19;

struct mem_cgroup_per_node___19;

struct mem_cgroup___19 {
	struct cgroup_subsys_state___32 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___32 events_file;
	struct cgroup_file___32 events_local_file;
	struct cgroup_file___32 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___19 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___43 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___19 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___20;

struct blk_integrity___20 {
	const struct blk_integrity_profile___20 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___20 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___20 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___20;

struct elevator_queue___20;

struct blk_mq_ops___19;

struct blk_mq_hw_ctx___19;

struct gendisk___20;

struct blkcg_gq___19;

struct blk_mq_tag_set___19;

struct request_queue___21 {
	struct request___20 *last_merge;
	struct elevator_queue___20 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___19 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___19 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___20 *disk;
	struct kobject___39 kobj;
	struct kobject___39 *mq_kobj;
	struct blk_integrity___20 integrity;
	struct device___36 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___19 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___19 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___20 bio_split;
	struct dentry___40 *debugfs_dir;
	struct dentry___40 *sched_debugfs_dir;
	struct dentry___40 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___41 {
	struct vm_struct___41 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___42 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___39;

struct address_space___39 {
	struct inode___40 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___39 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___39;

struct dev_pagemap___39 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___39 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___39;

struct path___39 {
	struct vfsmount___39 *mnt;
	struct dentry___40 *dentry;
};

struct fown_struct___38 {
	rwlock_t lock;
	struct pid___38 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___40 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___39 f_path;
	struct inode___40 *f_inode;
	const struct file_operations___39 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___38 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___39 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___39;

struct vm_operations_struct___39 {
	void (*open)(struct vm_area_struct___42 *);
	void (*close)(struct vm_area_struct___42 *);
	int (*may_split)(struct vm_area_struct___42 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___42 *);
	int (*mprotect)(struct vm_area_struct___42 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___39 *);
	vm_fault_t (*huge_fault)(struct vm_fault___39 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___39 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___42 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___39 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___39 *);
	int (*access)(struct vm_area_struct___42 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___42 *);
	int (*set_policy)(struct vm_area_struct___42 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___42 *, long unsigned int);
	struct page___42 * (*find_special_page)(struct vm_area_struct___42 *, long unsigned int);
};

struct core_thread___42 {
	struct task_struct___43 *task;
	struct core_thread___42 *next;
};

struct core_state___42 {
	atomic_t nr_threads;
	struct core_thread___42 dumper;
	struct completion startup;
};

struct vm_fault___39 {
	const struct {
		struct vm_area_struct___42 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___42 *cow_page;
	struct page___42 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___42 prealloc_pte;
};

struct pglist_data___20;

struct lruvec___20 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___20 *pgdat;
};

struct zone___20 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___20 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___20 {
	struct zone___20 *zone;
	int zone_idx;
};

struct zonelist___20 {
	struct zoneref___20 _zonerefs[321];
};

struct pglist_data___20 {
	struct zone___20 node_zones[5];
	struct zonelist___20 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___43 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___43 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___20 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct fwnode_operations___36;

struct fwnode_handle___36 {
	struct fwnode_handle___36 *secondary;
	const struct fwnode_operations___36 *ops;
	struct device___36 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___36;

struct fwnode_endpoint___36;

struct fwnode_operations___36 {
	struct fwnode_handle___36 * (*get)(struct fwnode_handle___36 *);
	void (*put)(struct fwnode_handle___36 *);
	bool (*device_is_available)(const struct fwnode_handle___36 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___36 *, const struct device___36 *);
	bool (*property_present)(const struct fwnode_handle___36 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___36 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___36 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___36 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_parent)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_next_child_node)(const struct fwnode_handle___36 *, struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*get_named_child_node)(const struct fwnode_handle___36 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___36 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___36 *);
	struct fwnode_handle___36 * (*graph_get_next_endpoint)(const struct fwnode_handle___36 *, struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*graph_get_remote_endpoint)(const struct fwnode_handle___36 *);
	struct fwnode_handle___36 * (*graph_get_port_parent)(struct fwnode_handle___36 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___36 *, struct fwnode_endpoint___36 *);
	int (*add_links)(struct fwnode_handle___36 *);
};

struct wakeup_source___36;

struct dev_pm_qos___9;

struct dev_pm_info___36 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___36 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___36 *, s32);
	struct dev_pm_qos___9 *qos;
};

struct device_type___36;

struct bus_type___36;

struct device_driver___36;

struct dev_pm_domain___36;

struct device_node___21;

struct class___36;

struct attribute_group___39;

struct device___36 {
	struct kobject___39 kobj;
	struct device___36 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___36 *type;
	struct bus_type___36 *bus;
	struct device_driver___36 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___36 power;
	struct dev_pm_domain___36 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___21 *of_node;
	struct fwnode_handle___36 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___36 *class;
	const struct attribute_group___39 **groups;
	void (*release)(struct device___36 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___36 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___36 *local_fwnode;
};

struct fwnode_reference_args___36 {
	struct fwnode_handle___36 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___38;

struct seq_file___39 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___38 *op;
	int poll_event;
	const struct file___40 *file;
	void *private;
};

struct kernfs_root___39;

struct kernfs_elem_dir___39 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___39 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___39;

struct kernfs_root___39 {
	struct kernfs_node___39 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___39 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___39 {
	struct kernfs_node___39 *target_kn;
};

struct kernfs_ops___39;

struct kernfs_elem_attr___39 {
	const struct kernfs_ops___39 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___39 *notify_next;
};

struct kernfs_node___39 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___39 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___39 dir;
		struct kernfs_elem_symlink___39 symlink;
		struct kernfs_elem_attr___39 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___39;

struct kernfs_ops___39 {
	int (*open)(struct kernfs_open_file___39 *);
	void (*release)(struct kernfs_open_file___39 *);
	int (*seq_show)(struct seq_file___39 *, void *);
	void * (*seq_start)(struct seq_file___39 *, loff_t *);
	void * (*seq_next)(struct seq_file___39 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___39 *, void *);
	ssize_t (*read)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___39 *, struct poll_table_struct___31 *);
	int (*mmap)(struct kernfs_open_file___39 *, struct vm_area_struct___42 *);
};

struct kernfs_syscall_ops___39 {
	int (*show_options)(struct seq_file___39 *, struct kernfs_root___39 *);
	int (*mkdir)(struct kernfs_node___39 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___39 *);
	int (*rename)(struct kernfs_node___39 *, struct kernfs_node___39 *, const char *);
	int (*show_path)(struct seq_file___39 *, struct kernfs_node___39 *, struct kernfs_root___39 *);
};

struct kernfs_open_file___39 {
	struct kernfs_node___39 *kn;
	struct file___40 *file;
	struct seq_file___39 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___39 *vm_ops;
};

typedef void (*poll_queue_proc___31)(struct file___40 *, wait_queue_head_t *, struct poll_table_struct___31 *);

struct poll_table_struct___31 {
	poll_queue_proc___31 _qproc;
	__poll_t _key;
};

struct bin_attribute___39;

struct attribute_group___39 {
	const char *name;
	umode_t (*is_visible)(struct kobject___39 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___39 *, struct bin_attribute___39 *, int);
	struct attribute **attrs;
	struct bin_attribute___39 **bin_attrs;
};

struct bin_attribute___39 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___39 * (*f_mapping)();
	ssize_t (*read)(struct file___40 *, struct kobject___39 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___40 *, struct kobject___39 *, struct bin_attribute___39 *, char *, loff_t, size_t);
	int (*mmap)(struct file___40 *, struct kobject___39 *, struct bin_attribute___39 *, struct vm_area_struct___42 *);
};

struct sysfs_ops___39 {
	ssize_t (*show)(struct kobject___39 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___39 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___39;

struct kset___39 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___39 kobj;
	const struct kset_uevent_ops___39 *uevent_ops;
};

struct kobj_type___39 {
	void (*release)(struct kobject___39 *);
	const struct sysfs_ops___39 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___39 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___39 *);
	const void * (*namespace)(struct kobject___39 *);
	void (*get_ownership)(struct kobject___39 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___39 {
	int (* const filter)(struct kset___39 *, struct kobject___39 *);
	const char * (* const name)(struct kset___39 *, struct kobject___39 *);
	int (* const uevent)(struct kset___39 *, struct kobject___39 *, struct kobj_uevent_env *);
};

struct psi_group___32 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___43 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___32;

struct cgroup_rstat_cpu___32;

struct cgroup___32 {
	struct cgroup_subsys_state___32 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___39 *kn;
	struct cgroup_file___32 procs_file;
	struct cgroup_file___32 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___32 *subsys[14];
	struct cgroup_root___32 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___32 *dom_cgrp;
	struct cgroup___32 *old_dom_cgrp;
	struct cgroup_rstat_cpu___32 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___32 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct shrink_control___19 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___19 *memcg;
};

struct shrinker___19 {
	long unsigned int (*count_objects)(struct shrinker___19 *, struct shrink_control___19 *);
	long unsigned int (*scan_objects)(struct shrinker___19 *, struct shrink_control___19 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___39 {
	void (*page_free)(struct page___42 *);
	void (*kill)(struct dev_pagemap___39 *);
	void (*cleanup)(struct dev_pagemap___39 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___39 *);
};

struct dentry_operations___39;

struct dentry___40 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___40 *d_parent;
	struct qstr d_name;
	struct inode___40 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___39 *d_op;
	struct super_block___40 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___39;

struct inode___40 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___39 *i_op;
	struct super_block___40 *i_sb;
	struct address_space___39 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___19 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___39 *i_fop;
		void (*free_inode)(struct inode___40 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___39 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___13 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___39 {
	int (*d_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___40 *, unsigned int);
	int (*d_hash)(const struct dentry___40 *, struct qstr *);
	int (*d_compare)(const struct dentry___40 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___40 *);
	int (*d_init)(struct dentry___40 *);
	void (*d_release)(struct dentry___40 *);
	void (*d_prune)(struct dentry___40 *);
	void (*d_iput)(struct dentry___40 *, struct inode___40 *);
	char * (*d_dname)(struct dentry___40 *, char *, int);
	struct vfsmount___39 * (*d_automount)(struct path___39 *);
	int (*d_manage)(const struct path___39 *, bool);
	struct dentry___40 * (*d_real)(struct dentry___40 *, const struct inode___40 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___39;

struct mem_dqinfo___39 {
	struct quota_format_type___39 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___39;

struct quota_info___39 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___40 *files[3];
	struct mem_dqinfo___39 info[3];
	const struct quota_format_ops___39 *ops[3];
};

struct rcuwait___40 {
	struct task_struct___43 *task;
};

struct percpu_rw_semaphore___40 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___40 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___39 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___40 rw_sem[3];
};

struct super_operations___39;

struct dquot_operations___39;

struct quotactl_ops___39;

struct block_device___21;

struct super_block___40 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___39 *s_type;
	const struct super_operations___39 *s_op;
	const struct dquot_operations___39 *dq_op;
	const struct quotactl_ops___39 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___40 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___21 *s_bdev;
	struct backing_dev_info___19 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___39 s_dquot;
	struct sb_writers___39 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___39 *s_d_op;
	int cleancache_poolid;
	struct shrinker___19 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___39 {
	struct dentry___40 *mnt_root;
	struct super_block___40 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct io_cq___20 {
	struct request_queue___21 *q;
	struct io_context___21 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___21;

struct kiocb___39 {
	struct file___40 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___39 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___21 *ki_waitq;
	};
};

struct iattr___40 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___40 *ia_file;
};

struct dquot___39 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___40 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___39 {
	int qf_fmt_id;
	const struct quota_format_ops___39 *qf_ops;
	struct module___41 *qf_owner;
	struct quota_format_type___39 *qf_next;
};

struct quota_format_ops___39 {
	int (*check_quota_file)(struct super_block___40 *, int);
	int (*read_file_info)(struct super_block___40 *, int);
	int (*write_file_info)(struct super_block___40 *, int);
	int (*free_file_info)(struct super_block___40 *, int);
	int (*read_dqblk)(struct dquot___39 *);
	int (*commit_dqblk)(struct dquot___39 *);
	int (*release_dqblk)(struct dquot___39 *);
	int (*get_next_id)(struct super_block___40 *, struct kqid *);
};

struct dquot_operations___39 {
	int (*write_dquot)(struct dquot___39 *);
	struct dquot___39 * (*alloc_dquot)(struct super_block___40 *, int);
	void (*destroy_dquot)(struct dquot___39 *);
	int (*acquire_dquot)(struct dquot___39 *);
	int (*release_dquot)(struct dquot___39 *);
	int (*mark_dirty)(struct dquot___39 *);
	int (*write_info)(struct super_block___40 *, int);
	qsize_t * (*get_reserved_space)(struct inode___40 *);
	int (*get_projid)(struct inode___40 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___40 *, qsize_t *);
	int (*get_next_id)(struct super_block___40 *, struct kqid *);
};

struct quotactl_ops___39 {
	int (*quota_on)(struct super_block___40 *, int, int, const struct path___39 *);
	int (*quota_off)(struct super_block___40 *, int);
	int (*quota_enable)(struct super_block___40 *, unsigned int);
	int (*quota_disable)(struct super_block___40 *, unsigned int);
	int (*quota_sync)(struct super_block___40 *, int);
	int (*set_info)(struct super_block___40 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___40 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___40 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___40 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___40 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___40 *, unsigned int);
};

struct wait_page_queue___21 {
	struct page___42 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___19;

struct readahead_control___21;

struct swap_info_struct___15;

struct address_space_operations___39 {
	int (*writepage)(struct page___42 *, struct writeback_control___19 *);
	int (*readpage)(struct file___40 *, struct page___42 *);
	int (*writepages)(struct address_space___39 *, struct writeback_control___19 *);
	int (*set_page_dirty)(struct page___42 *);
	int (*readpages)(struct file___40 *, struct address_space___39 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___21 *);
	int (*write_begin)(struct file___40 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___42 **, void **);
	int (*write_end)(struct file___40 *, struct address_space___39 *, loff_t, unsigned int, unsigned int, struct page___42 *, void *);
	sector_t (*bmap)(struct address_space___39 *, sector_t);
	void (*invalidatepage)(struct page___42 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___42 *, gfp_t);
	void (*freepage)(struct page___42 *);
	ssize_t (*direct_IO)(struct kiocb___39 *, struct iov_iter___23 *);
	int (*migratepage)(struct address_space___39 *, struct page___42 *, struct page___42 *, enum migrate_mode);
	bool (*isolate_page)(struct page___42 *, isolate_mode_t);
	void (*putback_page)(struct page___42 *);
	int (*launder_page)(struct page___42 *);
	int (*is_partially_uptodate)(struct page___42 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___42 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___39 *, struct page___42 *);
	int (*swap_activate)(struct swap_info_struct___15 *, struct file___40 *, sector_t *);
	void (*swap_deactivate)(struct file___40 *);
};

struct writeback_control___19 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___19 *wb;
	struct inode___40 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___21 {
	struct file___40 *file;
	struct address_space___39 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___23;

struct iov_iter___23 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___23 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___15 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___21 *bdev;
	struct file___40 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___39 {
	struct dentry___40 * (*lookup)(struct inode___40 *, struct dentry___40 *, unsigned int);
	const char * (*get_link)(struct dentry___40 *, struct inode___40 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___40 *, int);
	struct posix_acl * (*get_acl)(struct inode___40 *, int, bool);
	int (*readlink)(struct dentry___40 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___40 *, struct dentry___40 *, umode_t, bool);
	int (*link)(struct dentry___40 *, struct inode___40 *, struct dentry___40 *);
	int (*unlink)(struct inode___40 *, struct dentry___40 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___40 *, struct dentry___40 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___40 *, struct dentry___40 *, umode_t);
	int (*rmdir)(struct inode___40 *, struct dentry___40 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___40 *, struct dentry___40 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___40 *, struct dentry___40 *, struct inode___40 *, struct dentry___40 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___40 *, struct iattr___40 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___39 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___40 *, char *, size_t);
	int (*fiemap)(struct inode___40 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___40 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___40 *, struct dentry___40 *, struct file___40 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___40 *, struct dentry___40 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___40 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___40 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___40 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___39 {
	void (*fl_copy_lock)(struct file_lock___39 *, struct file_lock___39 *);
	void (*fl_release_private)(struct file_lock___39 *);
};

struct lock_manager_operations___39;

struct file_lock___39 {
	struct file_lock___39 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___40 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___39 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___39 *fl_ops;
	const struct lock_manager_operations___39 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___39 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___39 *);
	int (*lm_grant)(struct file_lock___39 *, int);
	bool (*lm_break)(struct file_lock___39 *);
	int (*lm_change)(struct file_lock___39 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___39 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___39 *);
};

struct fasync_struct___39 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___39 *fa_next;
	struct file___40 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___39 {
	struct inode___40 * (*alloc_inode)(struct super_block___40 *);
	void (*destroy_inode)(struct inode___40 *);
	void (*free_inode)(struct inode___40 *);
	void (*dirty_inode)(struct inode___40 *, int);
	int (*write_inode)(struct inode___40 *, struct writeback_control___19 *);
	int (*drop_inode)(struct inode___40 *);
	void (*evict_inode)(struct inode___40 *);
	void (*put_super)(struct super_block___40 *);
	int (*sync_fs)(struct super_block___40 *, int);
	int (*freeze_super)(struct super_block___40 *);
	int (*freeze_fs)(struct super_block___40 *);
	int (*thaw_super)(struct super_block___40 *);
	int (*unfreeze_fs)(struct super_block___40 *);
	int (*statfs)(struct dentry___40 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___40 *, int *, char *);
	void (*umount_begin)(struct super_block___40 *);
	int (*show_options)(struct seq_file___39 *, struct dentry___40 *);
	int (*show_devname)(struct seq_file___39 *, struct dentry___40 *);
	int (*show_path)(struct seq_file___39 *, struct dentry___40 *);
	int (*show_stats)(struct seq_file___39 *, struct dentry___40 *);
	ssize_t (*quota_read)(struct super_block___40 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___40 *, int, const char *, size_t, loff_t);
	struct dquot___39 ** (*get_dquots)(struct inode___40 *);
	long int (*nr_cached_objects)(struct super_block___40 *, struct shrink_control___19 *);
	long int (*free_cached_objects)(struct super_block___40 *, struct shrink_control___19 *);
	struct file___40 * (*real_loop)(struct file___40 *);
};

struct block_device___21 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___40 *bd_inode;
	struct super_block___40 *bd_super;
	void *bd_claiming;
	struct device___36 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___39 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___20 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___40 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___20(struct bio___20 *);

struct bio_vec___23 {
	struct page___42 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___20;

struct bio___20 {
	struct bio___20 *bi_next;
	struct block_device___21 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___20 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___19 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___20 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___23 *bi_io_vec;
	struct bio_set___20 *bi_pool;
	struct bio_vec___23 bi_inline_vecs[0];
};

struct seq_operations___38 {
	void * (*start)(struct seq_file___39 *, loff_t *);
	void (*stop)(struct seq_file___39 *, void *);
	void * (*next)(struct seq_file___39 *, void *, loff_t *);
	int (*show)(struct seq_file___39 *, void *);
};

struct cgroup_namespace___32 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___32 *root_cset;
};

struct kernel_param_ops___39 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___39 *);
	int (*get)(char *, const struct kernel_param___39 *);
	void (*free)(void *);
};

struct kparam_array___39;

struct kernel_param___39 {
	const char *name;
	struct module___41 *mod;
	const struct kernel_param_ops___39 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___39 *arr;
	};
};

struct kparam_array___39 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___39 *ops;
	void *elem;
};

struct module_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___39 *, struct module_kobject___39 *, char *);
	ssize_t (*store)(struct module_attribute___39 *, struct module_kobject___39 *, const char *, size_t);
	void (*setup)(struct module___41 *, const char *);
	int (*test)(struct module___41 *);
	void (*free)(struct module___41 *);
};

struct trace_event_class___23;

struct trace_event_call___23 {
	struct list_head list;
	struct trace_event_class___23 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___23 *, struct perf_event___28 *);
};

struct cftype___32;

struct cgroup_subsys___32 {
	struct cgroup_subsys_state___32 * (*css_alloc)(struct cgroup_subsys_state___32 *);
	int (*css_online)(struct cgroup_subsys_state___32 *);
	void (*css_offline)(struct cgroup_subsys_state___32 *);
	void (*css_released)(struct cgroup_subsys_state___32 *);
	void (*css_free)(struct cgroup_subsys_state___32 *);
	void (*css_reset)(struct cgroup_subsys_state___32 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___32 *, int);
	int (*css_extra_stat_show)(struct seq_file___39 *, struct cgroup_subsys_state___32 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___43 *, struct css_set___32 *);
	void (*cancel_fork)(struct task_struct___43 *, struct css_set___32 *);
	void (*fork)(struct task_struct___43 *);
	void (*exit)(struct task_struct___43 *);
	void (*release)(struct task_struct___43 *);
	void (*bind)(struct cgroup_subsys_state___32 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___32 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___32 *dfl_cftypes;
	struct cftype___32 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___32 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___32 *updated_children;
	struct cgroup___32 *updated_next;
};

struct cgroup_root___32 {
	struct kernfs_root___39 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___32 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___32 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___32 *ss;
	struct list_head node;
	struct kernfs_ops___39 *kf_ops;
	int (*open)(struct kernfs_open_file___39 *);
	void (*release)(struct kernfs_open_file___39 *);
	u64 (*read_u64)(struct cgroup_subsys_state___32 *, struct cftype___32 *);
	s64 (*read_s64)(struct cgroup_subsys_state___32 *, struct cftype___32 *);
	int (*seq_show)(struct seq_file___39 *, void *);
	void * (*seq_start)(struct seq_file___39 *, loff_t *);
	void * (*seq_next)(struct seq_file___39 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___39 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___32 *, struct cftype___32 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___32 *, struct cftype___32 *, s64);
	ssize_t (*write)(struct kernfs_open_file___39 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___39 *, struct poll_table_struct___31 *);
};

struct dev_pm_ops___36 {
	int (*prepare)(struct device___36 *);
	void (*complete)(struct device___36 *);
	int (*suspend)(struct device___36 *);
	int (*resume)(struct device___36 *);
	int (*freeze)(struct device___36 *);
	int (*thaw)(struct device___36 *);
	int (*poweroff)(struct device___36 *);
	int (*restore)(struct device___36 *);
	int (*suspend_late)(struct device___36 *);
	int (*resume_early)(struct device___36 *);
	int (*freeze_late)(struct device___36 *);
	int (*thaw_early)(struct device___36 *);
	int (*poweroff_late)(struct device___36 *);
	int (*restore_early)(struct device___36 *);
	int (*suspend_noirq)(struct device___36 *);
	int (*resume_noirq)(struct device___36 *);
	int (*freeze_noirq)(struct device___36 *);
	int (*thaw_noirq)(struct device___36 *);
	int (*poweroff_noirq)(struct device___36 *);
	int (*restore_noirq)(struct device___36 *);
	int (*runtime_suspend)(struct device___36 *);
	int (*runtime_resume)(struct device___36 *);
	int (*runtime_idle)(struct device___36 *);
};

struct wakeup_source___36 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___36 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___9;

struct dev_pm_qos___9 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___9 *resume_latency_req;
	struct dev_pm_qos_request___9 *latency_tolerance_req;
	struct dev_pm_qos_request___9 *flags_req;
};

struct dev_pm_domain___36 {
	struct dev_pm_ops___36 ops;
	int (*start)(struct device___36 *);
	void (*detach)(struct device___36 *, bool);
	int (*activate)(struct device___36 *);
	void (*sync)(struct device___36 *);
	void (*dismiss)(struct device___36 *);
};

struct bus_type___36 {
	const char *name;
	const char *dev_name;
	struct device___36 *dev_root;
	const struct attribute_group___39 **bus_groups;
	const struct attribute_group___39 **dev_groups;
	const struct attribute_group___39 **drv_groups;
	int (*match)(struct device___36 *, struct device_driver___36 *);
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	int (*probe)(struct device___36 *);
	void (*sync_state)(struct device___36 *);
	void (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*online)(struct device___36 *);
	int (*offline)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	int (*num_vf)(struct device___36 *);
	int (*dma_configure)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___36 {
	const char *name;
	struct bus_type___36 *bus;
	struct module___41 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___36 *);
	void (*sync_state)(struct device___36 *);
	int (*remove)(struct device___36 *);
	void (*shutdown)(struct device___36 *);
	int (*suspend)(struct device___36 *, pm_message_t);
	int (*resume)(struct device___36 *);
	const struct attribute_group___39 **groups;
	const struct attribute_group___39 **dev_groups;
	const struct dev_pm_ops___36 *pm;
	void (*coredump)(struct device___36 *);
	struct driver_private *p;
};

struct device_type___36 {
	const char *name;
	const struct attribute_group___39 **groups;
	int (*uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___36 *);
	const struct dev_pm_ops___36 *pm;
};

struct class___36 {
	const char *name;
	struct module___41 *owner;
	const struct attribute_group___39 **class_groups;
	const struct attribute_group___39 **dev_groups;
	struct kobject___39 *dev_kobj;
	int (*dev_uevent)(struct device___36 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___36 *, umode_t *);
	void (*class_release)(struct class___36 *);
	void (*dev_release)(struct device___36 *);
	int (*shutdown_pre)(struct device___36 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___36 *);
	void (*get_ownership)(struct device___36 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___36 *pm;
	struct subsys_private *p;
};

struct property___18;

struct device_node___21 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___36 fwnode;
	struct property___18 *properties;
	struct property___18 *deadprops;
	struct device_node___21 *parent;
	struct device_node___21 *child;
	struct device_node___21 *sibling;
	struct kobject___39 kobj;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___20;

struct gendisk___20 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___21 *part0;
	const struct block_device_operations___20 *fops;
	struct request_queue___21 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___19 *bdi;
	struct kobject___39 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___39 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___20 {
	struct bio___20 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___23 *bip_vec;
	struct bio_vec___23 bip_inline_vecs[0];
};

struct blkcg___19;

struct blkg_policy_data___19;

struct blkcg_gq___19 {
	struct request_queue___21 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___19 *blkcg;
	struct blkcg_gq___19 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___19 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___20 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___20(struct request___20 *);

typedef void integrity_complete_fn___20(struct request___20 *, unsigned int);

struct blk_integrity_profile___20 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___20 *prepare_fn;
	integrity_complete_fn___20 *complete_fn;
	const char *name;
};

struct block_device_operations___20 {
	blk_qc_t (*submit_bio)(struct bio___20 *);
	int (*open)(struct block_device___21 *, fmode_t);
	void (*release)(struct gendisk___20 *, fmode_t);
	int (*rw_page)(struct block_device___21 *, sector_t, struct page___42 *, unsigned int);
	int (*ioctl)(struct block_device___21 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___21 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___20 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___20 *);
	int (*getgeo)(struct block_device___21 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___21 *, bool);
	void (*swap_slot_free_notify)(struct block_device___21 *, long unsigned int);
	int (*report_zones)(struct gendisk___20 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___20 *, umode_t *);
	struct module___41 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___20 *, sector_t *);
};

typedef void rq_end_io_fn___20(struct request___20 *, blk_status_t);

struct request___20 {
	struct request_queue___21 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___19 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___20 *bio;
	struct bio___20 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___23 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___20 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___20 *saved_end_io;
		} flush;
	};
	struct gendisk___20 *rq_disk;
	struct block_device___21 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___20 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___19 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___21 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___39 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___40 *debugfs_dir;
	struct dentry___40 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___20;

struct elevator_mq_ops___20 {
	int (*init_sched)(struct request_queue___21 *, struct elevator_type___20 *);
	void (*exit_sched)(struct elevator_queue___20 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___19 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___19 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___19 *);
	bool (*allow_merge)(struct request_queue___21 *, struct request___20 *, struct bio___20 *);
	bool (*bio_merge)(struct request_queue___21 *, struct bio___20 *, unsigned int);
	int (*request_merge)(struct request_queue___21 *, struct request___20 **, struct bio___20 *);
	void (*request_merged)(struct request_queue___21 *, struct request___20 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___21 *, struct request___20 *, struct request___20 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___20 *);
	void (*finish_request)(struct request___20 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___19 *, struct list_head *, bool);
	struct request___20 * (*dispatch_request)(struct blk_mq_hw_ctx___19 *);
	bool (*has_work)(struct blk_mq_hw_ctx___19 *);
	void (*completed_request)(struct request___20 *, u64);
	void (*requeue_request)(struct request___20 *);
	struct request___20 * (*former_request)(struct request_queue___21 *, struct request___20 *);
	struct request___20 * (*next_request)(struct request_queue___21 *, struct request___20 *);
	void (*init_icq)(struct io_cq___20 *);
	void (*exit_icq)(struct io_cq___20 *);
};

struct elv_fs_entry___20;

struct elevator_type___20 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___20 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___20 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___41 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___20 {
	struct elevator_type___20 *type;
	void *elevator_data;
	struct kobject___39 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___20 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___20 *, char *);
	ssize_t (*store)(struct elevator_queue___20 *, const char *, size_t);
};

struct blk_mq_queue_data___19;

struct blk_mq_ops___19 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___19 *, const struct blk_mq_queue_data___19 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___19 *);
	int (*get_budget)(struct request_queue___21 *);
	void (*put_budget)(struct request_queue___21 *, int);
	void (*set_rq_budget_token)(struct request___20 *, int);
	int (*get_rq_budget_token)(struct request___20 *);
	enum blk_eh_timer_return (*timeout)(struct request___20 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___19 *);
	void (*complete)(struct request___20 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___19 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___19 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___19 *, struct request___20 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___19 *, struct request___20 *, unsigned int);
	void (*initialize_rq_fn)(struct request___20 *);
	void (*cleanup_rq)(struct request___20 *);
	bool (*busy)(struct request_queue___21 *);
	int (*map_queues)(struct blk_mq_tag_set___19 *);
	void (*show_rq)(struct seq_file___39 *, struct request___20 *);
};

struct blk_mq_tag_set___19 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___19 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___19 {
	struct request___20 *rq;
	bool last;
};

struct blkcg_policy_data___19;

struct blkcg___19 {
	struct cgroup_subsys_state___32 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___19 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___19 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___19 {
	struct blkcg___19 *blkcg;
	int plid;
};

struct blkg_policy_data___19 {
	struct blkcg_gq___19 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___19 {
	struct mem_cgroup___19 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___19 {
	struct lruvec___20 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___19 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___19 *memcg;
};

struct obj_cgroup___19 {
	struct percpu_ref refcnt;
	struct mem_cgroup___19 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___28;

struct perf_output_handle___28;

struct pmu___28 {
	struct list_head entry;
	struct module___41 *module;
	struct device___36 *dev;
	const struct attribute_group___39 **attr_groups;
	const struct attribute_group___39 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___28 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___28 *);
	void (*pmu_disable)(struct pmu___28 *);
	int (*event_init)(struct perf_event___28 *);
	void (*event_mapped)(struct perf_event___28 *, struct mm_struct___43 *);
	void (*event_unmapped)(struct perf_event___28 *, struct mm_struct___43 *);
	int (*add)(struct perf_event___28 *, int);
	void (*del)(struct perf_event___28 *, int);
	void (*start)(struct perf_event___28 *, int);
	void (*stop)(struct perf_event___28 *, int);
	void (*read)(struct perf_event___28 *);
	void (*start_txn)(struct pmu___28 *, unsigned int);
	int (*commit_txn)(struct pmu___28 *);
	void (*cancel_txn)(struct pmu___28 *);
	int (*event_idx)(struct perf_event___28 *);
	void (*sched_task)(struct perf_event_context___28 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___28 *, struct perf_event_context___28 *);
	void * (*setup_aux)(struct perf_event___28 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___28 *, struct perf_output_handle___28 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___28 *);
	int (*aux_output_match)(struct perf_event___28 *);
	int (*filter_match)(struct perf_event___28 *);
	int (*check_period)(struct perf_event___28 *, u64);
};

struct perf_cpu_context___28 {
	struct perf_event_context___28 ctx;
	struct perf_event_context___28 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___28 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___28 **heap;
	struct perf_event___28 *heap_default[2];
};

struct perf_output_handle___28 {
	struct perf_event___28 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___28 {
	struct cgroup_subsys_state___32 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___23 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___23 *);
	};
};

struct trace_event_class___23 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___23 *, enum trace_reg, void *);
	struct trace_event_fields___23 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___23 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___23 *);
};

struct property___18 {
	char *name;
	int length;
	void *value;
	struct property___18 *next;
	long unsigned int _flags;
	struct bin_attribute___39 attr;
};

struct dev_pm_qos_request___9 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___36 *dev;
};

struct swait_queue___2 {
	struct task_struct___43 *task;
	struct list_head task_list;
};

struct platform_suspend_ops {
	int (*valid)(suspend_state_t);
	int (*begin)(suspend_state_t);
	int (*prepare)();
	int (*prepare_late)();
	int (*enter)(suspend_state_t);
	void (*wake)();
	void (*finish)();
	bool (*suspend_again)();
	void (*end)();
	void (*recover)();
};

struct platform_s2idle_ops {
	int (*begin)();
	int (*prepare)();
	int (*prepare_late)();
	bool (*wake)();
	void (*restore_early)();
	void (*restore)();
	void (*end)();
};

struct wakelock {
	char *name;
	struct rb_node node;
	struct wakeup_source___36 *ws;
	struct list_head lru;
};

struct sysrq_key_op {
	void (* const handler)(int);
	const char * const help_msg;
	const char * const action_msg;
	const int enable_mask;
};

struct em_data_callback {
	int (*active_power)(long unsigned int *, long unsigned int *, struct device___32 *);
};

typedef unsigned int uint;

struct dentry___41;

struct super_block___41;

struct module___42;

struct file_system_type___40 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___41 * (*mount)(struct file_system_type___40 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___41 *);
	struct module___42 *owner;
	struct file_system_type___40 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___41;

struct kiocb___40;

struct poll_table_struct___32;

struct vm_area_struct___43;

struct inode___41;

struct file_lock___40;

struct page___43;

struct seq_file___40;

struct file_operations___40 {
	struct module___42 *owner;
	loff_t (*llseek)(struct file___41 *, loff_t, int);
	ssize_t (*read)(struct file___41 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___41 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___40 *, struct iov_iter___23 *);
	ssize_t (*write_iter)(struct kiocb___40 *, struct iov_iter___23 *);
	int (*iopoll)(struct kiocb___40 *, bool);
	int (*iterate)(struct file___41 *, struct dir_context *);
	int (*iterate_shared)(struct file___41 *, struct dir_context *);
	__poll_t (*poll)(struct file___41 *, struct poll_table_struct___32 *);
	long int (*unlocked_ioctl)(struct file___41 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___41 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___41 *, struct vm_area_struct___43 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___41 *, struct file___41 *);
	int (*flush)(struct file___41 *, fl_owner_t);
	int (*release)(struct inode___41 *, struct file___41 *);
	int (*fsync)(struct file___41 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___41 *, int);
	int (*lock)(struct file___41 *, int, struct file_lock___40 *);
	ssize_t (*sendpage)(struct file___41 *, struct page___43 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___41 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___41 *, long unsigned int);
	int (*flock)(struct file___41 *, int, struct file_lock___40 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___41 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___41 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___41 *, long int, struct file_lock___40 **, void **);
	long int (*fallocate)(struct file___41 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___40 *, struct file___41 *);
	ssize_t (*copy_file_range)(struct file___41 *, loff_t, struct file___41 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___41 *, loff_t, struct file___41 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___41 *, loff_t, loff_t, int);
};

struct vmacache___43 {
	u64 seqnum;
	struct vm_area_struct___43 *vmas[4];
};

struct page_frag___43 {
	struct page___43 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___29;

struct debug_info___29 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___29 *hbp_break[16];
	struct perf_event___29 *hbp_watch[16];
};

struct thread_struct___29 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___29 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___44;

struct pid___39;

struct nsproxy___40;

struct signal_struct___41;

struct css_set___33;

struct perf_event_context___29;

struct vm_struct___42;

struct task_struct___44 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___44 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___44 *mm;
	struct mm_struct___44 *active_mm;
	struct vmacache___43 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___44 *real_parent;
	struct task_struct___44 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___44 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___39 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___40 *nsproxy;
	struct signal_struct___41 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___44 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___21 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___33 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___29 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___43 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___44 *oom_reaper_list;
	struct vm_struct___42 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___40;

struct kobj_type___40;

struct kernfs_node___40;

struct kobject___40 {
	const char *name;
	struct list_head entry;
	struct kobject___40 *parent;
	struct kset___40 *kset;
	struct kobj_type___40 *ktype;
	struct kernfs_node___40 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___40 {
	struct kobject___40 kobj;
	struct module___42 *mod;
	struct kobject___40 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___40 {
	struct module___42 *mod;
	struct latch_tree_node node;
};

struct module_layout___40 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___40 mtn;
};

struct module_attribute___40;

struct kernel_param___40;

struct trace_event_call___24;

struct module___42 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___40 mkobj;
	struct module_attribute___40 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___40 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___40 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___40 core_layout;
	struct module_layout___40 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___24 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___29 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___44 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___29)(struct perf_event___29 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___29;

struct fasync_struct___40;

struct pid_namespace___39;

struct perf_cgroup___29;

struct perf_event___29 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___29 *group_leader;
	struct pmu___29 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___29 hw;
	struct perf_event_context___29 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___29 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___44 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___40 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___29 *aux_event;
	void (*destroy)(struct perf_event___29 *);
	struct callback_head callback_head;
	struct pid_namespace___39 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___29 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___29 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___24 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___29 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct {
	seqcount_t seqcount;
} seqcount_latch_t;

typedef struct page___43 *pgtable_t___43;

struct address_space___40;

struct dev_pagemap___40;

struct page___43 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___40 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___43 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___43 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___44 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___40 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___40;

struct vm_area_struct___43 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___43 *vm_next;
	struct vm_area_struct___43 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___44 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___40 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___41 *vm_file;
	struct file___41 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___43;

struct mm_struct___44 {
	struct {
		struct vm_area_struct___43 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___41 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___43 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___44 *owner;
		struct user_namespace___4 *user_ns;
		struct file___41 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___40;

struct address_space___40 {
	struct inode___41 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___40 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___40;

struct dev_pagemap___40 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___40 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___40;

struct path___40 {
	struct vfsmount___40 *mnt;
	struct dentry___41 *dentry;
};

struct fown_struct___39 {
	rwlock_t lock;
	struct pid___39 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___41 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___40 f_path;
	struct inode___41 *f_inode;
	const struct file_operations___40 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___39 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___40 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___40;

struct vm_operations_struct___40 {
	void (*open)(struct vm_area_struct___43 *);
	void (*close)(struct vm_area_struct___43 *);
	int (*may_split)(struct vm_area_struct___43 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___43 *);
	int (*mprotect)(struct vm_area_struct___43 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___40 *);
	vm_fault_t (*huge_fault)(struct vm_fault___40 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___40 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___43 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___40 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___40 *);
	int (*access)(struct vm_area_struct___43 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___43 *);
	int (*set_policy)(struct vm_area_struct___43 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___43 *, long unsigned int);
	struct page___43 * (*find_special_page)(struct vm_area_struct___43 *, long unsigned int);
};

struct core_thread___43 {
	struct task_struct___44 *task;
	struct core_thread___43 *next;
};

struct core_state___43 {
	atomic_t nr_threads;
	struct core_thread___43 dumper;
	struct completion startup;
};

struct vm_fault___40 {
	const struct {
		struct vm_area_struct___43 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___43 *cow_page;
	struct page___43 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___43 prealloc_pte;
};

struct dev_pagemap_ops___40 {
	void (*page_free)(struct page___43 *);
	void (*kill)(struct dev_pagemap___40 *);
	void (*cleanup)(struct dev_pagemap___40 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___40 *);
};

struct upid___39 {
	int nr;
	struct pid_namespace___39 *ns;
};

struct pid_namespace___39 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___44 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___39 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___39 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___39 numbers[1];
};

struct tty_struct___7;

struct signal_struct___41 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___44 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___44 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___39 *pids[4];
	struct pid___39 *tty_old_pgrp;
	int leader;
	struct tty_struct___7 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___44 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___33;

struct nsproxy___40 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___39 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___33 *cgroup_ns;
};

struct cgroup_subsys_state___33;

struct cgroup___33;

struct css_set___33 {
	struct cgroup_subsys_state___33 *subsys[14];
	refcount_t refcount;
	struct css_set___33 *dom_cset;
	struct cgroup___33 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___33 *mg_src_cgrp;
	struct cgroup___33 *mg_dst_cgrp;
	struct css_set___33 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___29 {
	struct pmu___29 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___44 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___29 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___42 {
	struct vm_struct___42 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___43 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___40;

struct dentry___41 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___41 *d_parent;
	struct qstr d_name;
	struct inode___41 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___40 *d_op;
	struct super_block___41 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___40;

struct cdev___17;

struct inode___41 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___40 *i_op;
	struct super_block___41 *i_sb;
	struct address_space___40 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___40 *i_fop;
		void (*free_inode)(struct inode___41 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___40 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___17 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___40 {
	int (*d_revalidate)(struct dentry___41 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___41 *, unsigned int);
	int (*d_hash)(const struct dentry___41 *, struct qstr *);
	int (*d_compare)(const struct dentry___41 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___41 *);
	int (*d_init)(struct dentry___41 *);
	void (*d_release)(struct dentry___41 *);
	void (*d_prune)(struct dentry___41 *);
	void (*d_iput)(struct dentry___41 *, struct inode___41 *);
	char * (*d_dname)(struct dentry___41 *, char *, int);
	struct vfsmount___40 * (*d_automount)(struct path___40 *);
	int (*d_manage)(const struct path___40 *, bool);
	struct dentry___41 * (*d_real)(struct dentry___41 *, const struct inode___41 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___40;

struct mem_dqinfo___40 {
	struct quota_format_type___40 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___40;

struct quota_info___40 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___41 *files[3];
	struct mem_dqinfo___40 info[3];
	const struct quota_format_ops___40 *ops[3];
};

struct rcuwait___41 {
	struct task_struct___44 *task;
};

struct percpu_rw_semaphore___41 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___41 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___40 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___41 rw_sem[3];
};

struct super_operations___40;

struct dquot_operations___40;

struct quotactl_ops___40;

struct super_block___41 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___40 *s_type;
	const struct super_operations___40 *s_op;
	const struct dquot_operations___40 *dq_op;
	const struct quotactl_ops___40 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___41 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___40 s_dquot;
	struct sb_writers___40 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___40 *s_d_op;
	int cleancache_poolid;
	struct shrinker___19 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___40 {
	struct dentry___41 *mnt_root;
	struct super_block___41 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct cgroup_subsys___33;

struct cgroup_subsys_state___33 {
	struct cgroup___33 *cgroup;
	struct cgroup_subsys___33 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___33 *parent;
};

struct cgroup_file___33 {
	struct kernfs_node___40 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___33 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___44 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___33;

struct cgroup_rstat_cpu___33;

struct cgroup___33 {
	struct cgroup_subsys_state___33 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___40 *kn;
	struct cgroup_file___33 procs_file;
	struct cgroup_file___33 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___33 *subsys[14];
	struct cgroup_root___33 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___33 *dom_cgrp;
	struct cgroup___33 *old_dom_cgrp;
	struct cgroup_rstat_cpu___33 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___33 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct device___37;

struct tty_driver___7;

struct tty_operations___7;

struct tty_ldisc___7;

struct tty_port___7;

struct tty_struct___7 {
	int magic;
	struct kref kref;
	struct device___37 *dev;
	struct tty_driver___7 *driver;
	const struct tty_operations___7 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___7 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___39 *pgrp;
		struct pid___39 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___7 *link;
	struct fasync_struct___40 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___7 *port;
};

struct kiocb___40 {
	struct file___41 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___40 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___21 *ki_waitq;
	};
};

struct iattr___41 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___41 *ia_file;
};

struct dquot___40 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___41 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___40 {
	int qf_fmt_id;
	const struct quota_format_ops___40 *qf_ops;
	struct module___42 *qf_owner;
	struct quota_format_type___40 *qf_next;
};

struct quota_format_ops___40 {
	int (*check_quota_file)(struct super_block___41 *, int);
	int (*read_file_info)(struct super_block___41 *, int);
	int (*write_file_info)(struct super_block___41 *, int);
	int (*free_file_info)(struct super_block___41 *, int);
	int (*read_dqblk)(struct dquot___40 *);
	int (*commit_dqblk)(struct dquot___40 *);
	int (*release_dqblk)(struct dquot___40 *);
	int (*get_next_id)(struct super_block___41 *, struct kqid *);
};

struct dquot_operations___40 {
	int (*write_dquot)(struct dquot___40 *);
	struct dquot___40 * (*alloc_dquot)(struct super_block___41 *, int);
	void (*destroy_dquot)(struct dquot___40 *);
	int (*acquire_dquot)(struct dquot___40 *);
	int (*release_dquot)(struct dquot___40 *);
	int (*mark_dirty)(struct dquot___40 *);
	int (*write_info)(struct super_block___41 *, int);
	qsize_t * (*get_reserved_space)(struct inode___41 *);
	int (*get_projid)(struct inode___41 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___41 *, qsize_t *);
	int (*get_next_id)(struct super_block___41 *, struct kqid *);
};

struct quotactl_ops___40 {
	int (*quota_on)(struct super_block___41 *, int, int, const struct path___40 *);
	int (*quota_off)(struct super_block___41 *, int);
	int (*quota_enable)(struct super_block___41 *, unsigned int);
	int (*quota_disable)(struct super_block___41 *, unsigned int);
	int (*quota_sync)(struct super_block___41 *, int);
	int (*set_info)(struct super_block___41 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___41 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___41 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___41 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___41 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___41 *, unsigned int);
};

struct address_space_operations___40 {
	int (*writepage)(struct page___43 *, struct writeback_control___3 *);
	int (*readpage)(struct file___41 *, struct page___43 *);
	int (*writepages)(struct address_space___40 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___43 *);
	int (*readpages)(struct file___41 *, struct address_space___40 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___41 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___43 **, void **);
	int (*write_end)(struct file___41 *, struct address_space___40 *, loff_t, unsigned int, unsigned int, struct page___43 *, void *);
	sector_t (*bmap)(struct address_space___40 *, sector_t);
	void (*invalidatepage)(struct page___43 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___43 *, gfp_t);
	void (*freepage)(struct page___43 *);
	ssize_t (*direct_IO)(struct kiocb___40 *, struct iov_iter___23 *);
	int (*migratepage)(struct address_space___40 *, struct page___43 *, struct page___43 *, enum migrate_mode);
	bool (*isolate_page)(struct page___43 *, isolate_mode_t);
	void (*putback_page)(struct page___43 *);
	int (*launder_page)(struct page___43 *);
	int (*is_partially_uptodate)(struct page___43 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___43 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___40 *, struct page___43 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___41 *, sector_t *);
	void (*swap_deactivate)(struct file___41 *);
};

struct cdev___17 {
	struct kobject___40 kobj;
	struct module___42 *owner;
	const struct file_operations___40 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___40 {
	struct dentry___41 * (*lookup)(struct inode___41 *, struct dentry___41 *, unsigned int);
	const char * (*get_link)(struct dentry___41 *, struct inode___41 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___41 *, int);
	struct posix_acl * (*get_acl)(struct inode___41 *, int, bool);
	int (*readlink)(struct dentry___41 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___41 *, struct dentry___41 *, umode_t, bool);
	int (*link)(struct dentry___41 *, struct inode___41 *, struct dentry___41 *);
	int (*unlink)(struct inode___41 *, struct dentry___41 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___41 *, struct dentry___41 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___41 *, struct dentry___41 *, umode_t);
	int (*rmdir)(struct inode___41 *, struct dentry___41 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___41 *, struct dentry___41 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___41 *, struct dentry___41 *, struct inode___41 *, struct dentry___41 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___41 *, struct iattr___41 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___40 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___41 *, char *, size_t);
	int (*fiemap)(struct inode___41 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___41 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___41 *, struct dentry___41 *, struct file___41 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___41 *, struct dentry___41 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___41 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___41 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___41 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___40 {
	void (*fl_copy_lock)(struct file_lock___40 *, struct file_lock___40 *);
	void (*fl_release_private)(struct file_lock___40 *);
};

struct lock_manager_operations___40;

struct file_lock___40 {
	struct file_lock___40 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___41 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___40 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___40 *fl_ops;
	const struct lock_manager_operations___40 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___40 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___40 *);
	int (*lm_grant)(struct file_lock___40 *, int);
	bool (*lm_break)(struct file_lock___40 *);
	int (*lm_change)(struct file_lock___40 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___40 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___40 *);
};

struct fasync_struct___40 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___40 *fa_next;
	struct file___41 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___40 {
	struct inode___41 * (*alloc_inode)(struct super_block___41 *);
	void (*destroy_inode)(struct inode___41 *);
	void (*free_inode)(struct inode___41 *);
	void (*dirty_inode)(struct inode___41 *, int);
	int (*write_inode)(struct inode___41 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___41 *);
	void (*evict_inode)(struct inode___41 *);
	void (*put_super)(struct super_block___41 *);
	int (*sync_fs)(struct super_block___41 *, int);
	int (*freeze_super)(struct super_block___41 *);
	int (*freeze_fs)(struct super_block___41 *);
	int (*thaw_super)(struct super_block___41 *);
	int (*unfreeze_fs)(struct super_block___41 *);
	int (*statfs)(struct dentry___41 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___41 *, int *, char *);
	void (*umount_begin)(struct super_block___41 *);
	int (*show_options)(struct seq_file___40 *, struct dentry___41 *);
	int (*show_devname)(struct seq_file___40 *, struct dentry___41 *);
	int (*show_path)(struct seq_file___40 *, struct dentry___41 *);
	int (*show_stats)(struct seq_file___40 *, struct dentry___41 *);
	ssize_t (*quota_read)(struct super_block___41 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___41 *, int, const char *, size_t, loff_t);
	struct dquot___40 ** (*get_dquots)(struct inode___41 *);
	long int (*nr_cached_objects)(struct super_block___41 *, struct shrink_control___19 *);
	long int (*free_cached_objects)(struct super_block___41 *, struct shrink_control___19 *);
	struct file___41 * (*real_loop)(struct file___41 *);
};

typedef void (*poll_queue_proc___32)(struct file___41 *, wait_queue_head_t *, struct poll_table_struct___32 *);

struct poll_table_struct___32 {
	poll_queue_proc___32 _qproc;
	__poll_t _key;
};

struct seq_operations___39;

struct seq_file___40 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___39 *op;
	int poll_event;
	const struct file___41 *file;
	void *private;
};

struct kernfs_root___40;

struct kernfs_elem_dir___40 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___40 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___40;

struct kernfs_root___40 {
	struct kernfs_node___40 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___40 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___40 {
	struct kernfs_node___40 *target_kn;
};

struct kernfs_ops___40;

struct kernfs_elem_attr___40 {
	const struct kernfs_ops___40 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___40 *notify_next;
};

struct kernfs_node___40 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___40 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___40 dir;
		struct kernfs_elem_symlink___40 symlink;
		struct kernfs_elem_attr___40 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___40;

struct kernfs_ops___40 {
	int (*open)(struct kernfs_open_file___40 *);
	void (*release)(struct kernfs_open_file___40 *);
	int (*seq_show)(struct seq_file___40 *, void *);
	void * (*seq_start)(struct seq_file___40 *, loff_t *);
	void * (*seq_next)(struct seq_file___40 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___40 *, void *);
	ssize_t (*read)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___40 *, struct poll_table_struct___32 *);
	int (*mmap)(struct kernfs_open_file___40 *, struct vm_area_struct___43 *);
};

struct kernfs_syscall_ops___40 {
	int (*show_options)(struct seq_file___40 *, struct kernfs_root___40 *);
	int (*mkdir)(struct kernfs_node___40 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___40 *);
	int (*rename)(struct kernfs_node___40 *, struct kernfs_node___40 *, const char *);
	int (*show_path)(struct seq_file___40 *, struct kernfs_node___40 *, struct kernfs_root___40 *);
};

struct kernfs_open_file___40 {
	struct kernfs_node___40 *kn;
	struct file___41 *file;
	struct seq_file___40 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___40 *vm_ops;
};

struct bin_attribute___40;

struct attribute_group___40 {
	const char *name;
	umode_t (*is_visible)(struct kobject___40 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___40 *, struct bin_attribute___40 *, int);
	struct attribute **attrs;
	struct bin_attribute___40 **bin_attrs;
};

struct bin_attribute___40 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___40 * (*f_mapping)();
	ssize_t (*read)(struct file___41 *, struct kobject___40 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___41 *, struct kobject___40 *, struct bin_attribute___40 *, char *, loff_t, size_t);
	int (*mmap)(struct file___41 *, struct kobject___40 *, struct bin_attribute___40 *, struct vm_area_struct___43 *);
};

struct sysfs_ops___40 {
	ssize_t (*show)(struct kobject___40 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___40 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___40;

struct kset___40 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___40 kobj;
	const struct kset_uevent_ops___40 *uevent_ops;
};

struct kobj_type___40 {
	void (*release)(struct kobject___40 *);
	const struct sysfs_ops___40 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___40 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___40 *);
	const void * (*namespace)(struct kobject___40 *);
	void (*get_ownership)(struct kobject___40 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___40 {
	int (* const filter)(struct kset___40 *, struct kobject___40 *);
	const char * (* const name)(struct kset___40 *, struct kobject___40 *);
	int (* const uevent)(struct kset___40 *, struct kobject___40 *, struct kobj_uevent_env *);
};

struct dev_printk_info {
	char subsystem[16];
	char device[48];
};

struct wakeup_source___37;

struct dev_pm_info___37 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___37 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___37 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___37;

struct bus_type___37;

struct device_driver___37;

struct dev_pm_domain___37;

struct fwnode_handle___37;

struct class___37;

struct device___37 {
	struct kobject___40 kobj;
	struct device___37 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___37 *type;
	struct bus_type___37 *bus;
	struct device_driver___37 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___37 power;
	struct dev_pm_domain___37 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___37 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___37 *class;
	const struct attribute_group___40 **groups;
	void (*release)(struct device___37 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___37 {
	int (*prepare)(struct device___37 *);
	void (*complete)(struct device___37 *);
	int (*suspend)(struct device___37 *);
	int (*resume)(struct device___37 *);
	int (*freeze)(struct device___37 *);
	int (*thaw)(struct device___37 *);
	int (*poweroff)(struct device___37 *);
	int (*restore)(struct device___37 *);
	int (*suspend_late)(struct device___37 *);
	int (*resume_early)(struct device___37 *);
	int (*freeze_late)(struct device___37 *);
	int (*thaw_early)(struct device___37 *);
	int (*poweroff_late)(struct device___37 *);
	int (*restore_early)(struct device___37 *);
	int (*suspend_noirq)(struct device___37 *);
	int (*resume_noirq)(struct device___37 *);
	int (*freeze_noirq)(struct device___37 *);
	int (*thaw_noirq)(struct device___37 *);
	int (*poweroff_noirq)(struct device___37 *);
	int (*restore_noirq)(struct device___37 *);
	int (*runtime_suspend)(struct device___37 *);
	int (*runtime_resume)(struct device___37 *);
	int (*runtime_idle)(struct device___37 *);
};

struct wakeup_source___37 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___37 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___37 {
	struct dev_pm_ops___37 ops;
	int (*start)(struct device___37 *);
	void (*detach)(struct device___37 *, bool);
	int (*activate)(struct device___37 *);
	void (*sync)(struct device___37 *);
	void (*dismiss)(struct device___37 *);
};

struct bus_type___37 {
	const char *name;
	const char *dev_name;
	struct device___37 *dev_root;
	const struct attribute_group___40 **bus_groups;
	const struct attribute_group___40 **dev_groups;
	const struct attribute_group___40 **drv_groups;
	int (*match)(struct device___37 *, struct device_driver___37 *);
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	int (*probe)(struct device___37 *);
	void (*sync_state)(struct device___37 *);
	void (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*online)(struct device___37 *);
	int (*offline)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	int (*num_vf)(struct device___37 *);
	int (*dma_configure)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___37 {
	const char *name;
	struct bus_type___37 *bus;
	struct module___42 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___37 *);
	void (*sync_state)(struct device___37 *);
	int (*remove)(struct device___37 *);
	void (*shutdown)(struct device___37 *);
	int (*suspend)(struct device___37 *, pm_message_t);
	int (*resume)(struct device___37 *);
	const struct attribute_group___40 **groups;
	const struct attribute_group___40 **dev_groups;
	const struct dev_pm_ops___37 *pm;
	void (*coredump)(struct device___37 *);
	struct driver_private *p;
};

struct device_type___37 {
	const char *name;
	const struct attribute_group___40 **groups;
	int (*uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___37 *);
	const struct dev_pm_ops___37 *pm;
};

struct class___37 {
	const char *name;
	struct module___42 *owner;
	const struct attribute_group___40 **class_groups;
	const struct attribute_group___40 **dev_groups;
	struct kobject___40 *dev_kobj;
	int (*dev_uevent)(struct device___37 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___37 *, umode_t *);
	void (*class_release)(struct class___37 *);
	void (*dev_release)(struct device___37 *);
	int (*shutdown_pre)(struct device___37 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___37 *);
	void (*get_ownership)(struct device___37 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___37 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___37;

struct fwnode_handle___37 {
	struct fwnode_handle___37 *secondary;
	const struct fwnode_operations___37 *ops;
	struct device___37 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___39 {
	void * (*start)(struct seq_file___40 *, loff_t *);
	void (*stop)(struct seq_file___40 *, void *);
	void * (*next)(struct seq_file___40 *, void *, loff_t *);
	int (*show)(struct seq_file___40 *, void *);
};

struct tty_operations___7 {
	struct tty_struct___7 * (*lookup)(struct tty_driver___7 *, struct file___41 *, int);
	int (*install)(struct tty_driver___7 *, struct tty_struct___7 *);
	void (*remove)(struct tty_driver___7 *, struct tty_struct___7 *);
	int (*open)(struct tty_struct___7 *, struct file___41 *);
	void (*close)(struct tty_struct___7 *, struct file___41 *);
	void (*shutdown)(struct tty_struct___7 *);
	void (*cleanup)(struct tty_struct___7 *);
	int (*write)(struct tty_struct___7 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___7 *, unsigned char);
	void (*flush_chars)(struct tty_struct___7 *);
	unsigned int (*write_room)(struct tty_struct___7 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___7 *);
	int (*ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___7 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	void (*throttle)(struct tty_struct___7 *);
	void (*unthrottle)(struct tty_struct___7 *);
	void (*stop)(struct tty_struct___7 *);
	void (*start)(struct tty_struct___7 *);
	void (*hangup)(struct tty_struct___7 *);
	int (*break_ctl)(struct tty_struct___7 *, int);
	void (*flush_buffer)(struct tty_struct___7 *);
	void (*set_ldisc)(struct tty_struct___7 *);
	void (*wait_until_sent)(struct tty_struct___7 *, int);
	void (*send_xchar)(struct tty_struct___7 *, char);
	int (*tiocmget)(struct tty_struct___7 *);
	int (*tiocmset)(struct tty_struct___7 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___7 *, struct winsize *);
	int (*get_icount)(struct tty_struct___7 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___7 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___7 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___7 *, struct seq_file___40 *);
	int (*poll_init)(struct tty_driver___7 *, int, char *);
	int (*poll_get_char)(struct tty_driver___7 *, int);
	void (*poll_put_char)(struct tty_driver___7 *, int, char);
	int (*proc_show)(struct seq_file___40 *, void *);
};

struct tty_driver___7 {
	int magic;
	struct kref kref;
	struct cdev___17 **cdevs;
	struct module___42 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___7 *other;
	struct tty_struct___7 **ttys;
	struct tty_port___7 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___7 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___7;

struct tty_port_client_operations___7;

struct tty_port___7 {
	struct tty_bufhead buf;
	struct tty_struct___7 *tty;
	struct tty_struct___7 *itty;
	const struct tty_port_operations___7 *ops;
	const struct tty_port_client_operations___7 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___7 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___7 *);
	void (*close)(struct tty_struct___7 *);
	void (*flush_buffer)(struct tty_struct___7 *);
	ssize_t (*read)(struct tty_struct___7 *, struct file___41 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___7 *, struct file___41 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___7 *, struct file___41 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___7 *, struct file___41 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___7 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___7 *, struct file___41 *, struct poll_table_struct___32 *);
	int (*hangup)(struct tty_struct___7 *);
	void (*receive_buf)(struct tty_struct___7 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___7 *);
	void (*dcd_change)(struct tty_struct___7 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___7 *, const unsigned char *, const char *, int);
	struct module___42 *owner;
};

struct tty_ldisc___7 {
	struct tty_ldisc_ops___7 *ops;
	struct tty_struct___7 *tty;
};

struct tty_port_operations___7 {
	int (*carrier_raised)(struct tty_port___7 *);
	void (*dtr_rts)(struct tty_port___7 *, int);
	void (*shutdown)(struct tty_port___7 *);
	int (*activate)(struct tty_port___7 *, struct tty_struct___7 *);
	void (*destruct)(struct tty_port___7 *);
};

struct tty_port_client_operations___7 {
	int (*receive_buf)(struct tty_port___7 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___7 *);
};

struct console {
	char name[16];
	void (*write)(struct console *, const char *, unsigned int);
	int (*read)(struct console *, char *, unsigned int);
	struct tty_driver___7 * (*device)(struct console *, int *);
	void (*unblank)();
	int (*setup)(struct console *, char *);
	int (*exit)(struct console *);
	int (*match)(struct console *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console *next;
};

struct kernel_param_ops___40 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___40 *);
	int (*get)(char *, const struct kernel_param___40 *);
	void (*free)(void *);
};

struct kparam_array___40;

struct kernel_param___40 {
	const char *name;
	struct module___42 *mod;
	const struct kernel_param_ops___40 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___40 *arr;
	};
};

struct kparam_array___40 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___40 *ops;
	void *elem;
};

struct module_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___40 *, struct module_kobject___40 *, char *);
	ssize_t (*store)(struct module_attribute___40 *, struct module_kobject___40 *, const char *, size_t);
	void (*setup)(struct module___42 *, const char *);
	int (*test)(struct module___42 *);
	void (*free)(struct module___42 *);
};

struct trace_event_class___24;

struct trace_event_call___24 {
	struct list_head list;
	struct trace_event_class___24 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___24 *, struct perf_event___29 *);
};

typedef struct poll_table_struct___32 poll_table___5;

struct fwnode_reference_args___37;

struct fwnode_endpoint___37;

struct fwnode_operations___37 {
	struct fwnode_handle___37 * (*get)(struct fwnode_handle___37 *);
	void (*put)(struct fwnode_handle___37 *);
	bool (*device_is_available)(const struct fwnode_handle___37 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___37 *, const struct device___37 *);
	bool (*property_present)(const struct fwnode_handle___37 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___37 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___37 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___37 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_parent)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_next_child_node)(const struct fwnode_handle___37 *, struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*get_named_child_node)(const struct fwnode_handle___37 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___37 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___37 *);
	struct fwnode_handle___37 * (*graph_get_next_endpoint)(const struct fwnode_handle___37 *, struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*graph_get_remote_endpoint)(const struct fwnode_handle___37 *);
	struct fwnode_handle___37 * (*graph_get_port_parent)(struct fwnode_handle___37 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___37 *, struct fwnode_endpoint___37 *);
	int (*add_links)(struct fwnode_handle___37 *);
};

struct fwnode_endpoint___37 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___37 *local_fwnode;
};

struct fwnode_reference_args___37 {
	struct fwnode_handle___37 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___33 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___33 *root_cset;
};

struct cftype___33;

struct cgroup_subsys___33 {
	struct cgroup_subsys_state___33 * (*css_alloc)(struct cgroup_subsys_state___33 *);
	int (*css_online)(struct cgroup_subsys_state___33 *);
	void (*css_offline)(struct cgroup_subsys_state___33 *);
	void (*css_released)(struct cgroup_subsys_state___33 *);
	void (*css_free)(struct cgroup_subsys_state___33 *);
	void (*css_reset)(struct cgroup_subsys_state___33 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___33 *, int);
	int (*css_extra_stat_show)(struct seq_file___40 *, struct cgroup_subsys_state___33 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___44 *, struct css_set___33 *);
	void (*cancel_fork)(struct task_struct___44 *, struct css_set___33 *);
	void (*fork)(struct task_struct___44 *);
	void (*exit)(struct task_struct___44 *);
	void (*release)(struct task_struct___44 *);
	void (*bind)(struct cgroup_subsys_state___33 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___33 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___33 *dfl_cftypes;
	struct cftype___33 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___33 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___33 *updated_children;
	struct cgroup___33 *updated_next;
};

struct cgroup_root___33 {
	struct kernfs_root___40 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___33 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___33 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___33 *ss;
	struct list_head node;
	struct kernfs_ops___40 *kf_ops;
	int (*open)(struct kernfs_open_file___40 *);
	void (*release)(struct kernfs_open_file___40 *);
	u64 (*read_u64)(struct cgroup_subsys_state___33 *, struct cftype___33 *);
	s64 (*read_s64)(struct cgroup_subsys_state___33 *, struct cftype___33 *);
	int (*seq_show)(struct seq_file___40 *, void *);
	void * (*seq_start)(struct seq_file___40 *, loff_t *);
	void * (*seq_next)(struct seq_file___40 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___40 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___33 *, struct cftype___33 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___33 *, struct cftype___33 *, s64);
	ssize_t (*write)(struct kernfs_open_file___40 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___40 *, struct poll_table_struct___32 *);
};

struct perf_cpu_context___29;

struct perf_output_handle___29;

struct pmu___29 {
	struct list_head entry;
	struct module___42 *module;
	struct device___37 *dev;
	const struct attribute_group___40 **attr_groups;
	const struct attribute_group___40 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___29 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___29 *);
	void (*pmu_disable)(struct pmu___29 *);
	int (*event_init)(struct perf_event___29 *);
	void (*event_mapped)(struct perf_event___29 *, struct mm_struct___44 *);
	void (*event_unmapped)(struct perf_event___29 *, struct mm_struct___44 *);
	int (*add)(struct perf_event___29 *, int);
	void (*del)(struct perf_event___29 *, int);
	void (*start)(struct perf_event___29 *, int);
	void (*stop)(struct perf_event___29 *, int);
	void (*read)(struct perf_event___29 *);
	void (*start_txn)(struct pmu___29 *, unsigned int);
	int (*commit_txn)(struct pmu___29 *);
	void (*cancel_txn)(struct pmu___29 *);
	int (*event_idx)(struct perf_event___29 *);
	void (*sched_task)(struct perf_event_context___29 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___29 *, struct perf_event_context___29 *);
	void * (*setup_aux)(struct perf_event___29 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___29 *, struct perf_output_handle___29 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___29 *);
	int (*aux_output_match)(struct perf_event___29 *);
	int (*filter_match)(struct perf_event___29 *);
	int (*check_period)(struct perf_event___29 *, u64);
};

struct perf_cpu_context___29 {
	struct perf_event_context___29 ctx;
	struct perf_event_context___29 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___29 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___29 **heap;
	struct perf_event___29 *heap_default[2];
};

struct perf_output_handle___29 {
	struct perf_event___29 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___29 {
	struct cgroup_subsys_state___33 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___24 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___24 *);
	};
};

struct trace_event_class___24 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___24 *, enum trace_reg, void *);
	struct trace_event_fields___24 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___24 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___24 *);
};

struct trace_event_file___10;

struct trace_event_buffer___10 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___10 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___10 {
	struct list_head list;
	struct trace_event_call___24 *event_call;
	struct event_filter *filter;
	struct dentry___41 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___11 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___24 *enter_event;
	struct trace_event_call___24 *exit_event;
};

struct kmsg_dump_iter {
	u64 cur_seq;
	u64 next_seq;
};

struct kmsg_dumper {
	struct list_head list;
	void (*dump)(struct kmsg_dumper *, enum kmsg_dump_reason);
	enum kmsg_dump_reason max_reason;
	bool registered;
};

struct trace_event_raw_console {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_data_offsets_console {
	u32 msg;
};

typedef void (*btf_trace_console)(void *, const char *, size_t);

struct printk_info {
	u64 seq;
	u64 ts_nsec;
	u16 text_len;
	u8 facility;
	u8 flags: 5;
	u8 level: 3;
	long: 29;
	long: 64;
	long: 64;
	u32 caller_id;
	struct dev_printk_info dev_info;
};

struct printk_record {
	struct printk_info *info;
	char *text_buf;
	unsigned int text_buf_size;
};

struct prb_data_blk_lpos {
	long unsigned int begin;
	long unsigned int next;
};

struct prb_desc {
	atomic_long_t state_var;
	struct prb_data_blk_lpos text_blk_lpos;
};

struct prb_data_ring {
	unsigned int size_bits;
	char *data;
	atomic_long_t head_lpos;
	atomic_long_t tail_lpos;
};

struct prb_desc_ring {
	unsigned int count_bits;
	struct prb_desc *descs;
	struct printk_info *infos;
	atomic_long_t head_id;
	atomic_long_t tail_id;
};

struct printk_ringbuffer {
	struct prb_desc_ring desc_ring;
	struct prb_data_ring text_data_ring;
	atomic_long_t fail;
};

struct prb_reserved_entry {
	struct printk_ringbuffer *rb;
	long unsigned int irqflags;
	long unsigned int id;
	unsigned int text_space;
};

enum desc_state {
	desc_miss = 4294967295,
	desc_reserved = 0,
	desc_committed = 1,
	desc_finalized = 2,
	desc_reusable = 3,
};

struct console_cmdline {
	char name[16];
	int index;
	bool user_specified;
	char *options;
};

enum printk_info_flags {
	LOG_NEWLINE = 2,
	LOG_CONT = 8,
};

enum devkmsg_log_bits {
	__DEVKMSG_LOG_BIT_ON = 0,
	__DEVKMSG_LOG_BIT_OFF = 1,
	__DEVKMSG_LOG_BIT_LOCK = 2,
};

enum devkmsg_log_masks {
	DEVKMSG_LOG_MASK_ON = 1,
	DEVKMSG_LOG_MASK_OFF = 2,
	DEVKMSG_LOG_MASK_LOCK = 4,
};

enum con_msg_format_flags {
	MSG_FORMAT_DEFAULT = 0,
	MSG_FORMAT_SYSLOG = 1,
};

struct latched_seq {
	seqcount_latch_t latch;
	u64 val[2];
};

struct devkmsg_user {
	atomic64_t seq;
	struct ratelimit_state rs;
	struct mutex lock;
	char buf[8192];
	struct printk_info info;
	char text_buf[8192];
	struct printk_record record;
};

enum kdb_msgsrc {
	KDB_MSGSRC_INTERNAL = 0,
	KDB_MSGSRC_PRINTK = 1,
};

struct dev_printk_info___2;

struct prb_data_block {
	long unsigned int id;
	char data[0];
};

struct vm_area_struct___44;

struct vmacache___44 {
	u64 seqnum;
	struct vm_area_struct___44 *vmas[4];
};

struct page___44;

struct page_frag___44 {
	struct page___44 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___45;

struct vm_struct___43;

struct task_struct___45 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___45 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___45 *mm;
	struct mm_struct___45 *active_mm;
	struct vmacache___44 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___45 *real_parent;
	struct task_struct___45 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___45 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___39 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred *ptracer_cred;
	const struct cred *real_cred;
	const struct cred *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___45 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___44 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task___3 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___45 *oom_reaper_list;
	struct vm_struct___43 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___29 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___14;

typedef void (*irq_flow_handler_t___14)(struct irq_desc___14 *);

struct irq_chip___13;

struct irq_domain___13;

struct irq_data___13 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___13 *chip;
	struct irq_domain___13 *domain;
	struct irq_data___13 *parent_data;
	void *chip_data;
};

struct kset___41;

struct kobj_type___41;

struct kernfs_node___41;

struct kobject___41 {
	const char *name;
	struct list_head entry;
	struct kobject___41 *parent;
	struct kset___41 *kset;
	struct kobj_type___41 *ktype;
	struct kernfs_node___41 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___11;

struct irq_desc___14 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___13 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___14 handle_irq;
	struct irqaction___11 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___41 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___44 *pgtable_t___44;

struct page___44 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___40 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___44 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___44 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___45 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___40 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	long: 64;
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___44 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___44 *vm_next;
	struct vm_area_struct___44 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___45 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___44;

struct mm_struct___45 {
	struct {
		struct vm_area_struct___44 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___44 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___45 *owner;
		struct user_namespace *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct core_thread___44 {
	struct task_struct___45 *task;
	struct core_thread___44 *next;
};

struct core_state___44 {
	atomic_t nr_threads;
	struct core_thread___44 dumper;
	struct completion startup;
};

struct vm_struct___43 {
	struct vm_struct___43 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___44 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct fwnode_operations___38;

struct device___38;

struct fwnode_handle___38 {
	struct fwnode_handle___38 *secondary;
	const struct fwnode_operations___38 *ops;
	struct device___38 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___38;

struct fwnode_endpoint___38;

struct fwnode_operations___38 {
	struct fwnode_handle___38 * (*get)(struct fwnode_handle___38 *);
	void (*put)(struct fwnode_handle___38 *);
	bool (*device_is_available)(const struct fwnode_handle___38 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___38 *, const struct device___38 *);
	bool (*property_present)(const struct fwnode_handle___38 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___38 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___38 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___38 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_parent)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_next_child_node)(const struct fwnode_handle___38 *, struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*get_named_child_node)(const struct fwnode_handle___38 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___38 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___38 *);
	struct fwnode_handle___38 * (*graph_get_next_endpoint)(const struct fwnode_handle___38 *, struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*graph_get_remote_endpoint)(const struct fwnode_handle___38 *);
	struct fwnode_handle___38 * (*graph_get_port_parent)(struct fwnode_handle___38 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___38 *, struct fwnode_endpoint___38 *);
	int (*add_links)(struct fwnode_handle___38 *);
};

struct wakeup_source___38;

struct dev_pm_info___38 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___38 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___38 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___38;

struct bus_type___38;

struct device_driver___38;

struct dev_pm_domain___38;

struct device_node___22;

struct class___38;

struct attribute_group___41;

struct device___38 {
	struct kobject___41 kobj;
	struct device___38 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___38 *type;
	struct bus_type___38 *bus;
	struct device_driver___38 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___38 power;
	struct dev_pm_domain___38 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___13 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___22 *of_node;
	struct fwnode_handle___38 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___38 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___38 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___38 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___38 *local_fwnode;
};

struct fwnode_reference_args___38 {
	struct fwnode_handle___38 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___13 {
	struct device___38 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___13 *);
	void (*irq_shutdown)(struct irq_data___13 *);
	void (*irq_enable)(struct irq_data___13 *);
	void (*irq_disable)(struct irq_data___13 *);
	void (*irq_ack)(struct irq_data___13 *);
	void (*irq_mask)(struct irq_data___13 *);
	void (*irq_mask_ack)(struct irq_data___13 *);
	void (*irq_unmask)(struct irq_data___13 *);
	void (*irq_eoi)(struct irq_data___13 *);
	int (*irq_set_affinity)(struct irq_data___13 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___13 *);
	int (*irq_set_type)(struct irq_data___13 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___13 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___13 *);
	void (*irq_bus_sync_unlock)(struct irq_data___13 *);
	void (*irq_cpu_online)(struct irq_data___13 *);
	void (*irq_cpu_offline)(struct irq_data___13 *);
	void (*irq_suspend)(struct irq_data___13 *);
	void (*irq_resume)(struct irq_data___13 *);
	void (*irq_pm_shutdown)(struct irq_data___13 *);
	void (*irq_calc_mask)(struct irq_data___13 *);
	void (*irq_print_chip)(struct irq_data___13 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___13 *);
	void (*irq_release_resources)(struct irq_data___13 *);
	void (*irq_compose_msi_msg)(struct irq_data___13 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___13 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___13 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___13 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___13 *, void *);
	void (*ipi_send_single)(struct irq_data___13 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___13 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___13 *);
	void (*irq_nmi_teardown)(struct irq_data___13 *);
	long unsigned int flags;
};

struct irq_domain_ops___13;

struct irq_domain_chip_generic___13;

struct irq_domain___13 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___13 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___38 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___13 *gc;
	struct irq_domain___13 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___13 *revmap[0];
};

struct kernfs_root___41;

struct kernfs_elem_dir___41 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___41 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___41;

struct kernfs_root___41 {
	struct kernfs_node___41 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___41 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___41 {
	struct kernfs_node___41 *target_kn;
};

struct kernfs_ops___41;

struct kernfs_elem_attr___41 {
	const struct kernfs_ops___41 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___41 *notify_next;
};

struct kernfs_node___41 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___41 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___41 dir;
		struct kernfs_elem_symlink___41 symlink;
		struct kernfs_elem_attr___41 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___41;

struct kernfs_ops___41 {
	int (*open)(struct kernfs_open_file___41 *);
	void (*release)(struct kernfs_open_file___41 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___41 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___41 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___41 *, struct vm_area_struct___44 *);
};

struct kernfs_syscall_ops___41 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___41 *);
	int (*mkdir)(struct kernfs_node___41 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___41 *);
	int (*rename)(struct kernfs_node___41 *, struct kernfs_node___41 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___41 *, struct kernfs_root___41 *);
};

struct kernfs_open_file___41 {
	struct kernfs_node___41 *kn;
	struct file___29 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___41;

struct attribute_group___41 {
	const char *name;
	umode_t (*is_visible)(struct kobject___41 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___41 *, struct bin_attribute___41 *, int);
	struct attribute **attrs;
	struct bin_attribute___41 **bin_attrs;
};

struct bin_attribute___41 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___27 * (*f_mapping)();
	ssize_t (*read)(struct file___29 *, struct kobject___41 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___41 *, struct bin_attribute___41 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___41 *, struct bin_attribute___41 *, struct vm_area_struct___44 *);
};

struct sysfs_ops___41 {
	ssize_t (*show)(struct kobject___41 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___41 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___41;

struct kset___41 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___41 kobj;
	const struct kset_uevent_ops___41 *uevent_ops;
};

struct kobj_type___41 {
	void (*release)(struct kobject___41 *);
	const struct sysfs_ops___41 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___41 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___41 *);
	const void * (*namespace)(struct kobject___41 *);
	void (*get_ownership)(struct kobject___41 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___41 {
	int (* const filter)(struct kset___41 *, struct kobject___41 *);
	const char * (* const name)(struct kset___41 *, struct kobject___41 *);
	int (* const uevent)(struct kset___41 *, struct kobject___41 *, struct kobj_uevent_env *);
};

struct kobj_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___41 *, struct kobj_attribute___4 *, char *);
	ssize_t (*store)(struct kobject___41 *, struct kobj_attribute___4 *, const char *, size_t);
};

struct irqaction___11 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___11 *next;
	irq_handler_t thread_fn;
	struct task_struct___45 *thread;
	struct irqaction___11 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___13 {
	struct irq_chip___13 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___14 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___13 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___13 *);
	void (*resume)(struct irq_chip_generic___13 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___13 *domain;
	struct list_head list;
	struct irq_chip_type___13 chip_types[0];
};

struct irq_domain_chip_generic___13 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___13 *gc[0];
};

struct property___19 {
	char *name;
	int length;
	void *value;
	struct property___19 *next;
	long unsigned int _flags;
	struct bin_attribute___41 attr;
};

struct device_node___22 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___38 fwnode;
	struct property___19 *properties;
	struct property___19 *deadprops;
	struct device_node___22 *parent;
	struct device_node___22 *child;
	struct device_node___22 *sibling;
	struct kobject___41 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___13 {
	struct fwnode_handle___38 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___13 {
	int (*match)(struct irq_domain___13 *, struct device_node___22 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___13 *, struct irq_fwspec___13 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___13 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___13 *, unsigned int);
	int (*xlate)(struct irq_domain___13 *, struct device_node___22 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___13 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___13 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___13 *, struct irq_data___13 *, bool);
	void (*deactivate)(struct irq_domain___13 *, struct irq_data___13 *);
	int (*translate)(struct irq_domain___13 *, struct irq_fwspec___13 *, long unsigned int *, unsigned int *);
};

struct dev_pm_ops___38 {
	int (*prepare)(struct device___38 *);
	void (*complete)(struct device___38 *);
	int (*suspend)(struct device___38 *);
	int (*resume)(struct device___38 *);
	int (*freeze)(struct device___38 *);
	int (*thaw)(struct device___38 *);
	int (*poweroff)(struct device___38 *);
	int (*restore)(struct device___38 *);
	int (*suspend_late)(struct device___38 *);
	int (*resume_early)(struct device___38 *);
	int (*freeze_late)(struct device___38 *);
	int (*thaw_early)(struct device___38 *);
	int (*poweroff_late)(struct device___38 *);
	int (*restore_early)(struct device___38 *);
	int (*suspend_noirq)(struct device___38 *);
	int (*resume_noirq)(struct device___38 *);
	int (*freeze_noirq)(struct device___38 *);
	int (*thaw_noirq)(struct device___38 *);
	int (*poweroff_noirq)(struct device___38 *);
	int (*restore_noirq)(struct device___38 *);
	int (*runtime_suspend)(struct device___38 *);
	int (*runtime_resume)(struct device___38 *);
	int (*runtime_idle)(struct device___38 *);
};

struct wakeup_source___38 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___38 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___38 {
	struct dev_pm_ops___38 ops;
	int (*start)(struct device___38 *);
	void (*detach)(struct device___38 *, bool);
	int (*activate)(struct device___38 *);
	void (*sync)(struct device___38 *);
	void (*dismiss)(struct device___38 *);
};

struct bus_type___38 {
	const char *name;
	const char *dev_name;
	struct device___38 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___38 *, struct device_driver___38 *);
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	int (*probe)(struct device___38 *);
	void (*sync_state)(struct device___38 *);
	void (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*online)(struct device___38 *);
	int (*offline)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	int (*num_vf)(struct device___38 *);
	int (*dma_configure)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___38 {
	const char *name;
	struct bus_type___38 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___38 *);
	void (*sync_state)(struct device___38 *);
	int (*remove)(struct device___38 *);
	void (*shutdown)(struct device___38 *);
	int (*suspend)(struct device___38 *, pm_message_t);
	int (*resume)(struct device___38 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___38 *pm;
	void (*coredump)(struct device___38 *);
	struct driver_private *p;
};

struct device_type___38 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___38 *);
	const struct dev_pm_ops___38 *pm;
};

struct class___38 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___38 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___38 *, umode_t *);
	void (*class_release)(struct class___38 *);
	void (*dev_release)(struct device___38 *);
	int (*shutdown_pre)(struct device___38 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___38 *);
	void (*get_ownership)(struct device___38 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___38 *pm;
	struct subsys_private *p;
};

enum {
	IRQS_AUTODETECT = 1,
	IRQS_SPURIOUS_DISABLED = 2,
	IRQS_POLL_INPROGRESS = 8,
	IRQS_ONESHOT = 32,
	IRQS_REPLAY = 64,
	IRQS_WAITING = 128,
	IRQS_PENDING = 512,
	IRQS_SUSPENDED = 2048,
	IRQS_TIMINGS = 4096,
	IRQS_NMI = 8192,
};

enum {
	_IRQ_DEFAULT_INIT_FLAGS = 0,
	_IRQ_PER_CPU = 512,
	_IRQ_LEVEL = 256,
	_IRQ_NOPROBE = 1024,
	_IRQ_NOREQUEST = 2048,
	_IRQ_NOTHREAD = 65536,
	_IRQ_NOAUTOEN = 4096,
	_IRQ_MOVE_PCNTXT = 16384,
	_IRQ_NO_BALANCING = 8192,
	_IRQ_NESTED_THREAD = 32768,
	_IRQ_PER_CPU_DEVID = 131072,
	_IRQ_IS_POLLED = 262144,
	_IRQ_DISABLE_UNLAZY = 524288,
	_IRQ_HIDDEN = 1048576,
	_IRQ_NO_DEBUG = 2097152,
	_IRQF_MODIFY_MASK = 2096911,
};

enum {
	IRQTF_RUNTHREAD = 0,
	IRQTF_WARNED = 1,
	IRQTF_AFFINITY = 2,
	IRQTF_FORCED_THREAD = 3,
};

enum {
	IRQ_SET_MASK_OK = 0,
	IRQ_SET_MASK_OK_NOCOPY = 1,
	IRQ_SET_MASK_OK_DONE = 2,
};

enum {
	IRQCHIP_SET_TYPE_MASKED = 1,
	IRQCHIP_EOI_IF_HANDLED = 2,
	IRQCHIP_MASK_ON_SUSPEND = 4,
	IRQCHIP_ONOFFLINE_ENABLED = 8,
	IRQCHIP_SKIP_SET_WAKE = 16,
	IRQCHIP_ONESHOT_SAFE = 32,
	IRQCHIP_EOI_THREADED = 64,
	IRQCHIP_SUPPORTS_LEVEL_MSI = 128,
	IRQCHIP_SUPPORTS_NMI = 256,
	IRQCHIP_ENABLE_WAKEUP_ON_SUSPEND = 512,
	IRQCHIP_AFFINITY_PRE_STARTUP = 1024,
};

enum {
	IRQC_IS_HARDIRQ = 0,
	IRQC_IS_NESTED = 1,
};

enum {
	IRQ_STARTUP_NORMAL = 0,
	IRQ_STARTUP_MANAGED = 1,
	IRQ_STARTUP_ABORT = 2,
};

typedef void (*dr_release_t___3)(struct device___15 *, void *);

typedef int (*dr_match_t___2)(struct device___15 *, void *, void *);

struct irq_devres {
	unsigned int irq;
	void *dev_id;
};

struct irq_desc_devres {
	unsigned int from;
	unsigned int cnt;
};

struct irq_generic_chip_devres {
	struct irq_chip_generic___9 *gc;
	u32 msk;
	unsigned int clr;
	unsigned int set;
};

struct of_phandle_args___3 {
	struct device_node___13 *np;
	int args_count;
	uint32_t args[16];
};

enum {
	IRQ_DOMAIN_FLAG_HIERARCHY = 1,
	IRQ_DOMAIN_NAME_ALLOCATED = 2,
	IRQ_DOMAIN_FLAG_IPI_PER_CPU = 4,
	IRQ_DOMAIN_FLAG_IPI_SINGLE = 8,
	IRQ_DOMAIN_FLAG_MSI = 16,
	IRQ_DOMAIN_FLAG_MSI_REMAP = 32,
	IRQ_DOMAIN_MSI_NOMASK_QUIRK = 64,
	IRQ_DOMAIN_FLAG_NO_MAP = 128,
	IRQ_DOMAIN_FLAG_NONCORE = 65536,
};

struct irqchip_fwid {
	struct fwnode_handle___19 fwnode;
	unsigned int type;
	char *name;
	phys_addr_t *pa;
};

struct proc_ops___2 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___40 *, struct file___40 *);
	ssize_t (*proc_read)(struct file___40 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___39 *, struct iov_iter___4 *);
	ssize_t (*proc_write)(struct file___40 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___40 *, loff_t, int);
	int (*proc_release)(struct inode___40 *, struct file___40 *);
	__poll_t (*proc_poll)(struct file___40 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___40 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___40 *, struct vm_area_struct___42 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___40 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

enum {
	AFFINITY = 0,
	AFFINITY_LIST = 1,
	EFFECTIVE = 2,
	EFFECTIVE_LIST = 3,
};

struct irq_desc___15;

typedef void (*irq_flow_handler_t___15)(struct irq_desc___15 *);

struct irq_chip___14;

struct irq_data___14 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___14 *chip;
	struct irq_domain___2 *domain;
	struct irq_data___14 *parent_data;
	void *chip_data;
};

struct kset___42;

struct kobj_type___42;

struct kernfs_node___42;

struct kobject___42 {
	const char *name;
	struct list_head entry;
	struct kobject___42 *parent;
	struct kset___42 *kset;
	struct kobj_type___42 *ktype;
	struct kernfs_node___42 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___15 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___14 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___15 handle_irq;
	struct irqaction___11 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___42 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___39;

struct device___39;

struct fwnode_handle___39 {
	struct fwnode_handle___39 *secondary;
	const struct fwnode_operations___39 *ops;
	struct device___39 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___39;

struct fwnode_endpoint___39;

struct fwnode_operations___39 {
	struct fwnode_handle___39 * (*get)(struct fwnode_handle___39 *);
	void (*put)(struct fwnode_handle___39 *);
	bool (*device_is_available)(const struct fwnode_handle___39 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___39 *, const struct device___39 *);
	bool (*property_present)(const struct fwnode_handle___39 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___39 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___39 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___39 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_parent)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_next_child_node)(const struct fwnode_handle___39 *, struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*get_named_child_node)(const struct fwnode_handle___39 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___39 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___39 *);
	struct fwnode_handle___39 * (*graph_get_next_endpoint)(const struct fwnode_handle___39 *, struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*graph_get_remote_endpoint)(const struct fwnode_handle___39 *);
	struct fwnode_handle___39 * (*graph_get_port_parent)(struct fwnode_handle___39 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___39 *, struct fwnode_endpoint___39 *);
	int (*add_links)(struct fwnode_handle___39 *);
};

struct wakeup_source___39;

struct dev_pm_info___39 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___39 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___39 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___39;

struct bus_type___39;

struct device_driver___39;

struct dev_pm_domain___39;

struct device_node___23;

struct class___39;

struct attribute_group___42;

struct device___39 {
	struct kobject___42 kobj;
	struct device___39 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___39 *type;
	struct bus_type___39 *bus;
	struct device_driver___39 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___39 power;
	struct dev_pm_domain___39 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___23 *of_node;
	struct fwnode_handle___39 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___39 *class;
	const struct attribute_group___42 **groups;
	void (*release)(struct device___39 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___39 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___39 *local_fwnode;
};

struct fwnode_reference_args___39 {
	struct fwnode_handle___39 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___14 {
	struct device___39 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___14 *);
	void (*irq_shutdown)(struct irq_data___14 *);
	void (*irq_enable)(struct irq_data___14 *);
	void (*irq_disable)(struct irq_data___14 *);
	void (*irq_ack)(struct irq_data___14 *);
	void (*irq_mask)(struct irq_data___14 *);
	void (*irq_mask_ack)(struct irq_data___14 *);
	void (*irq_unmask)(struct irq_data___14 *);
	void (*irq_eoi)(struct irq_data___14 *);
	int (*irq_set_affinity)(struct irq_data___14 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___14 *);
	int (*irq_set_type)(struct irq_data___14 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___14 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___14 *);
	void (*irq_bus_sync_unlock)(struct irq_data___14 *);
	void (*irq_cpu_online)(struct irq_data___14 *);
	void (*irq_cpu_offline)(struct irq_data___14 *);
	void (*irq_suspend)(struct irq_data___14 *);
	void (*irq_resume)(struct irq_data___14 *);
	void (*irq_pm_shutdown)(struct irq_data___14 *);
	void (*irq_calc_mask)(struct irq_data___14 *);
	void (*irq_print_chip)(struct irq_data___14 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___14 *);
	void (*irq_release_resources)(struct irq_data___14 *);
	void (*irq_compose_msi_msg)(struct irq_data___14 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___14 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___14 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___14 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___14 *, void *);
	void (*ipi_send_single)(struct irq_data___14 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___14 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___14 *);
	void (*irq_nmi_teardown)(struct irq_data___14 *);
	long unsigned int flags;
};

struct kernfs_root___42;

struct kernfs_elem_dir___42 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___42 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___42;

struct kernfs_root___42 {
	struct kernfs_node___42 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___42 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___42 {
	struct kernfs_node___42 *target_kn;
};

struct kernfs_ops___42;

struct kernfs_elem_attr___42 {
	const struct kernfs_ops___42 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___42 *notify_next;
};

struct kernfs_node___42 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___42 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___42 dir;
		struct kernfs_elem_symlink___42 symlink;
		struct kernfs_elem_attr___42 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___42;

struct kernfs_ops___42 {
	int (*open)(struct kernfs_open_file___42 *);
	void (*release)(struct kernfs_open_file___42 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___42 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___42 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___42 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___42 *, struct vm_area_struct___44 *);
};

struct kernfs_syscall_ops___42 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___42 *);
	int (*mkdir)(struct kernfs_node___42 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___42 *);
	int (*rename)(struct kernfs_node___42 *, struct kernfs_node___42 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___42 *, struct kernfs_root___42 *);
};

struct kernfs_open_file___42 {
	struct kernfs_node___42 *kn;
	struct file___29 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___42;

struct attribute_group___42 {
	const char *name;
	umode_t (*is_visible)(struct kobject___42 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___42 *, struct bin_attribute___42 *, int);
	struct attribute **attrs;
	struct bin_attribute___42 **bin_attrs;
};

struct bin_attribute___42 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___27 * (*f_mapping)();
	ssize_t (*read)(struct file___29 *, struct kobject___42 *, struct bin_attribute___42 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___42 *, struct bin_attribute___42 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___42 *, struct bin_attribute___42 *, struct vm_area_struct___44 *);
};

struct sysfs_ops___42 {
	ssize_t (*show)(struct kobject___42 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___42 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___42;

struct kset___42 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___42 kobj;
	const struct kset_uevent_ops___42 *uevent_ops;
};

struct kobj_type___42 {
	void (*release)(struct kobject___42 *);
	const struct sysfs_ops___42 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___42 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___42 *);
	const void * (*namespace)(struct kobject___42 *);
	void (*get_ownership)(struct kobject___42 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___42 {
	int (* const filter)(struct kset___42 *, struct kobject___42 *);
	const char * (* const name)(struct kset___42 *, struct kobject___42 *);
	int (* const uevent)(struct kset___42 *, struct kobject___42 *, struct kobj_uevent_env *);
};

struct property___20 {
	char *name;
	int length;
	void *value;
	struct property___20 *next;
	long unsigned int _flags;
	struct bin_attribute___42 attr;
};

struct device_node___23 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___39 fwnode;
	struct property___20 *properties;
	struct property___20 *deadprops;
	struct device_node___23 *parent;
	struct device_node___23 *child;
	struct device_node___23 *sibling;
	struct kobject___42 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___39 {
	int (*prepare)(struct device___39 *);
	void (*complete)(struct device___39 *);
	int (*suspend)(struct device___39 *);
	int (*resume)(struct device___39 *);
	int (*freeze)(struct device___39 *);
	int (*thaw)(struct device___39 *);
	int (*poweroff)(struct device___39 *);
	int (*restore)(struct device___39 *);
	int (*suspend_late)(struct device___39 *);
	int (*resume_early)(struct device___39 *);
	int (*freeze_late)(struct device___39 *);
	int (*thaw_early)(struct device___39 *);
	int (*poweroff_late)(struct device___39 *);
	int (*restore_early)(struct device___39 *);
	int (*suspend_noirq)(struct device___39 *);
	int (*resume_noirq)(struct device___39 *);
	int (*freeze_noirq)(struct device___39 *);
	int (*thaw_noirq)(struct device___39 *);
	int (*poweroff_noirq)(struct device___39 *);
	int (*restore_noirq)(struct device___39 *);
	int (*runtime_suspend)(struct device___39 *);
	int (*runtime_resume)(struct device___39 *);
	int (*runtime_idle)(struct device___39 *);
};

struct wakeup_source___39 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___39 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___39 {
	struct dev_pm_ops___39 ops;
	int (*start)(struct device___39 *);
	void (*detach)(struct device___39 *, bool);
	int (*activate)(struct device___39 *);
	void (*sync)(struct device___39 *);
	void (*dismiss)(struct device___39 *);
};

struct bus_type___39 {
	const char *name;
	const char *dev_name;
	struct device___39 *dev_root;
	const struct attribute_group___42 **bus_groups;
	const struct attribute_group___42 **dev_groups;
	const struct attribute_group___42 **drv_groups;
	int (*match)(struct device___39 *, struct device_driver___39 *);
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	int (*probe)(struct device___39 *);
	void (*sync_state)(struct device___39 *);
	void (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*online)(struct device___39 *);
	int (*offline)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	int (*num_vf)(struct device___39 *);
	int (*dma_configure)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___39 {
	const char *name;
	struct bus_type___39 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___39 *);
	void (*sync_state)(struct device___39 *);
	int (*remove)(struct device___39 *);
	void (*shutdown)(struct device___39 *);
	int (*suspend)(struct device___39 *, pm_message_t);
	int (*resume)(struct device___39 *);
	const struct attribute_group___42 **groups;
	const struct attribute_group___42 **dev_groups;
	const struct dev_pm_ops___39 *pm;
	void (*coredump)(struct device___39 *);
	struct driver_private *p;
};

struct device_type___39 {
	const char *name;
	const struct attribute_group___42 **groups;
	int (*uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___39 *);
	const struct dev_pm_ops___39 *pm;
};

struct class___39 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___42 **class_groups;
	const struct attribute_group___42 **dev_groups;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___39 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___39 *, umode_t *);
	void (*class_release)(struct class___39 *);
	void (*dev_release)(struct device___39 *);
	int (*shutdown_pre)(struct device___39 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___39 *);
	void (*get_ownership)(struct device___39 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___39 *pm;
	struct subsys_private *p;
};

struct device_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct device___19 *, struct device_attribute___6 *, char *);
	ssize_t (*store)(struct device___19 *, struct device_attribute___6 *, const char *, size_t);
};

struct msi_alloc_info {
	struct msi_desc___3 *desc;
	irq_hw_number_t hwirq;
	long unsigned int flags;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info msi_alloc_info_t;

struct msi_domain_info;

struct msi_domain_ops {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info *, msi_alloc_info_t *);
	int (*msi_init)(struct irq_domain___10 *, struct msi_domain_info *, unsigned int, irq_hw_number_t, msi_alloc_info_t *);
	void (*msi_free)(struct irq_domain___10 *, struct msi_domain_info *, unsigned int);
	int (*msi_check)(struct irq_domain___10 *, struct msi_domain_info *, struct device___19 *);
	int (*msi_prepare)(struct irq_domain___10 *, struct device___19 *, int, msi_alloc_info_t *);
	void (*msi_finish)(msi_alloc_info_t *, int);
	void (*set_desc)(msi_alloc_info_t *, struct msi_desc___3 *);
	int (*handle_error)(struct irq_domain___10 *, struct msi_desc___3 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___10 *, struct device___19 *, int);
	void (*domain_free_irqs)(struct irq_domain___10 *, struct device___19 *);
};

struct msi_domain_info {
	u32 flags;
	struct msi_domain_ops *ops;
	struct irq_chip___10 *chip;
	void *chip_data;
	irq_flow_handler_t___11 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

enum {
	MSI_FLAG_USE_DEF_DOM_OPS = 1,
	MSI_FLAG_USE_DEF_CHIP_OPS = 2,
	MSI_FLAG_MULTI_PCI_MSI = 4,
	MSI_FLAG_PCI_MSIX = 8,
	MSI_FLAG_ACTIVATE_EARLY = 16,
	MSI_FLAG_MUST_REACTIVATE = 32,
	MSI_FLAG_LEVEL_CAPABLE = 64,
};

struct irq_desc___16;

typedef void (*irq_flow_handler_t___16)(struct irq_desc___16 *);

struct irq_chip___15;

struct irq_domain___14;

struct irq_data___15 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___15 *chip;
	struct irq_domain___14 *domain;
	struct irq_data___15 *parent_data;
	void *chip_data;
};

struct kset___43;

struct kobj_type___43;

struct kernfs_node___43;

struct kobject___43 {
	const char *name;
	struct list_head entry;
	struct kobject___43 *parent;
	struct kset___43 *kset;
	struct kobj_type___43 *ktype;
	struct kernfs_node___43 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_desc___16 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___15 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___16 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___43 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___43;

struct kernfs_elem_dir___43 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___43 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___43;

struct kernfs_root___43 {
	struct kernfs_node___43 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___43 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___43 {
	struct kernfs_node___43 *target_kn;
};

struct kernfs_ops___43;

struct kernfs_elem_attr___43 {
	const struct kernfs_ops___43 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___43 *notify_next;
};

struct kernfs_node___43 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___43 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___43 dir;
		struct kernfs_elem_symlink___43 symlink;
		struct kernfs_elem_attr___43 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___43;

struct kernfs_ops___43 {
	int (*open)(struct kernfs_open_file___43 *);
	void (*release)(struct kernfs_open_file___43 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___43 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___43 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___43 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___43 *, struct vm_area_struct___41 *);
};

struct kernfs_syscall_ops___43 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___43 *);
	int (*mkdir)(struct kernfs_node___43 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___43 *);
	int (*rename)(struct kernfs_node___43 *, struct kernfs_node___43 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___43 *, struct kernfs_root___43 *);
};

struct kernfs_open_file___43 {
	struct kernfs_node___43 *kn;
	struct file___29 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___43;

struct attribute_group___43 {
	const char *name;
	umode_t (*is_visible)(struct kobject___43 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___43 *, struct bin_attribute___43 *, int);
	struct attribute **attrs;
	struct bin_attribute___43 **bin_attrs;
};

struct bin_attribute___43 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___27 * (*f_mapping)();
	ssize_t (*read)(struct file___29 *, struct kobject___43 *, struct bin_attribute___43 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___43 *, struct bin_attribute___43 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___43 *, struct bin_attribute___43 *, struct vm_area_struct___41 *);
};

struct sysfs_ops___43 {
	ssize_t (*show)(struct kobject___43 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___43 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___43;

struct kset___43 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___43 kobj;
	const struct kset_uevent_ops___43 *uevent_ops;
};

struct kobj_type___43 {
	void (*release)(struct kobject___43 *);
	const struct sysfs_ops___43 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___43 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___43 *);
	const void * (*namespace)(struct kobject___43 *);
	void (*get_ownership)(struct kobject___43 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___43 {
	int (* const filter)(struct kset___43 *, struct kobject___43 *);
	const char * (* const name)(struct kset___43 *, struct kobject___43 *);
	int (* const uevent)(struct kset___43 *, struct kobject___43 *, struct kobj_uevent_env *);
};

struct property___21 {
	char *name;
	int length;
	void *value;
	struct property___21 *next;
	long unsigned int _flags;
	struct bin_attribute___43 attr;
};

struct device_node___24 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___39 fwnode;
	struct property___21 *properties;
	struct property___21 *deadprops;
	struct device_node___24 *parent;
	struct device_node___24 *child;
	struct device_node___24 *sibling;
	struct kobject___43 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_domain_ops___14 {
	int (*match)(struct irq_domain___14 *, struct device_node___24 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___14 *, struct irq_fwspec___13 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___14 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___14 *, unsigned int);
	int (*xlate)(struct irq_domain___14 *, struct device_node___24 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___14 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___14 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___14 *, struct irq_data___15 *, bool);
	void (*deactivate)(struct irq_domain___14 *, struct irq_data___15 *);
	int (*translate)(struct irq_domain___14 *, struct irq_fwspec___13 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___14;

struct irq_domain___14 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___14 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___39 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___14 *gc;
	struct irq_domain___14 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___15 *revmap[0];
};

struct irq_chip_generic___14;

struct irq_domain_chip_generic___14 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___14 *gc[0];
};

struct irq_chip___15 {
	struct device___9 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___15 *);
	void (*irq_shutdown)(struct irq_data___15 *);
	void (*irq_enable)(struct irq_data___15 *);
	void (*irq_disable)(struct irq_data___15 *);
	void (*irq_ack)(struct irq_data___15 *);
	void (*irq_mask)(struct irq_data___15 *);
	void (*irq_mask_ack)(struct irq_data___15 *);
	void (*irq_unmask)(struct irq_data___15 *);
	void (*irq_eoi)(struct irq_data___15 *);
	int (*irq_set_affinity)(struct irq_data___15 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___15 *);
	int (*irq_set_type)(struct irq_data___15 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___15 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___15 *);
	void (*irq_bus_sync_unlock)(struct irq_data___15 *);
	void (*irq_cpu_online)(struct irq_data___15 *);
	void (*irq_cpu_offline)(struct irq_data___15 *);
	void (*irq_suspend)(struct irq_data___15 *);
	void (*irq_resume)(struct irq_data___15 *);
	void (*irq_pm_shutdown)(struct irq_data___15 *);
	void (*irq_calc_mask)(struct irq_data___15 *);
	void (*irq_print_chip)(struct irq_data___15 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___15 *);
	void (*irq_release_resources)(struct irq_data___15 *);
	void (*irq_compose_msi_msg)(struct irq_data___15 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___15 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___15 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___15 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___15 *, void *);
	void (*ipi_send_single)(struct irq_data___15 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___15 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___15 *);
	void (*irq_nmi_teardown)(struct irq_data___15 *);
	long unsigned int flags;
};

struct irq_chip_type___14 {
	struct irq_chip___15 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___16 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___14 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___14 *);
	void (*resume)(struct irq_chip_generic___14 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___14 *domain;
	struct list_head list;
	struct irq_chip_type___14 chip_types[0];
};

struct irq_affinity {
	unsigned int pre_vectors;
	unsigned int post_vectors;
	unsigned int nr_sets;
	unsigned int set_size[4];
	void (*calc_sets)(struct irq_affinity *, unsigned int);
	void *priv;
};

struct node_vectors {
	unsigned int id;
	union {
		unsigned int nvectors;
		unsigned int ncpus;
	};
};

typedef void (*call_rcu_func_t)(struct callback_head *, rcu_callback_t);

struct rcu_synchronize {
	struct callback_head head;
	struct completion completion;
};

struct trace_event_raw_rcu_utilization {
	struct trace_entry ent;
	const char *s;
	char __data[0];
};

struct trace_event_raw_rcu_stall_warning {
	struct trace_entry ent;
	const char *rcuname;
	const char *msg;
	char __data[0];
};

struct trace_event_data_offsets_rcu_utilization {};

struct trace_event_data_offsets_rcu_stall_warning {};

typedef void (*btf_trace_rcu_utilization)(void *, const char *);

typedef void (*btf_trace_rcu_stall_warning)(void *, const char *, const char *);

struct rcu_tasks;

typedef void (*rcu_tasks_gp_func_t)(struct rcu_tasks *);

typedef void (*pregp_func_t)();

typedef void (*pertask_func_t)(struct task_struct___2 *, struct list_head *);

typedef void (*postscan_func_t)(struct list_head *);

typedef void (*holdouts_func_t)(struct list_head *, bool, bool *);

typedef void (*postgp_func_t)(struct rcu_tasks *);

struct rcu_tasks {
	struct callback_head *cbs_head;
	struct callback_head **cbs_tail;
	struct wait_queue_head cbs_wq;
	raw_spinlock_t cbs_lock;
	int gp_state;
	int gp_sleep;
	int init_fract;
	long unsigned int gp_jiffies;
	long unsigned int gp_start;
	long unsigned int n_gps;
	long unsigned int n_ipis;
	long unsigned int n_ipis_fails;
	struct task_struct___2 *kthread_ptr;
	rcu_tasks_gp_func_t gp_func;
	pregp_func_t pregp_func;
	pertask_func_t pertask_func;
	postscan_func_t postscan_func;
	holdouts_func_t holdouts_func;
	postgp_func_t postgp_func;
	call_rcu_func_t call_func;
	char *name;
	char *kname;
};

enum {
	GP_IDLE = 0,
	GP_ENTER = 1,
	GP_PASSED = 2,
	GP_EXIT = 3,
	GP_REPLAY = 4,
};

typedef long unsigned int ulong;

struct rcu_cblist {
	struct callback_head *head;
	struct callback_head **tail;
	long int len;
};

enum rcutorture_type {
	RCU_FLAVOR = 0,
	RCU_TASKS_FLAVOR = 1,
	RCU_TASKS_RUDE_FLAVOR = 2,
	RCU_TASKS_TRACING_FLAVOR = 3,
	RCU_TRIVIAL_FLAVOR = 4,
	SRCU_FLAVOR = 5,
	INVALID_RCU_FLAVOR = 6,
};

struct dentry___42;

struct super_block___42;

struct module___43;

struct file_system_type___41 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___42 * (*mount)(struct file_system_type___41 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___42 *);
	struct module___43 *owner;
	struct file_system_type___41 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___42;

struct kiocb___41;

struct iov_iter___24;

struct poll_table_struct___33;

struct vm_area_struct___45;

struct inode___42;

struct file_lock___41;

struct page___45;

struct seq_file___41;

struct file_operations___41 {
	struct module___43 *owner;
	loff_t (*llseek)(struct file___42 *, loff_t, int);
	ssize_t (*read)(struct file___42 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___42 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___41 *, struct iov_iter___24 *);
	ssize_t (*write_iter)(struct kiocb___41 *, struct iov_iter___24 *);
	int (*iopoll)(struct kiocb___41 *, bool);
	int (*iterate)(struct file___42 *, struct dir_context *);
	int (*iterate_shared)(struct file___42 *, struct dir_context *);
	__poll_t (*poll)(struct file___42 *, struct poll_table_struct___33 *);
	long int (*unlocked_ioctl)(struct file___42 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___42 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___42 *, struct vm_area_struct___45 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___42 *, struct file___42 *);
	int (*flush)(struct file___42 *, fl_owner_t);
	int (*release)(struct inode___42 *, struct file___42 *);
	int (*fsync)(struct file___42 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___42 *, int);
	int (*lock)(struct file___42 *, int, struct file_lock___41 *);
	ssize_t (*sendpage)(struct file___42 *, struct page___45 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___42 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___42 *, long unsigned int);
	int (*flock)(struct file___42 *, int, struct file_lock___41 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___42 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___42 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___42 *, long int, struct file_lock___41 **, void **);
	long int (*fallocate)(struct file___42 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___41 *, struct file___42 *);
	ssize_t (*copy_file_range)(struct file___42 *, loff_t, struct file___42 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___42 *, loff_t, struct file___42 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___42 *, loff_t, loff_t, int);
};

struct vmacache___45 {
	u64 seqnum;
	struct vm_area_struct___45 *vmas[4];
};

struct page_frag___45 {
	struct page___45 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___30;

struct debug_info___30 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___30 *hbp_break[16];
	struct perf_event___30 *hbp_watch[16];
};

struct thread_struct___30 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___30 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___46;

struct pid___40;

struct nsproxy___41;

struct signal_struct___42;

struct rt_mutex_waiter___2;

struct bio_list___21;

struct backing_dev_info___20;

struct io_context___22;

struct css_set___34;

struct perf_event_context___30;

struct mem_cgroup___20;

struct request_queue___22;

struct vm_struct___44;

struct task_struct___46 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___46 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___46 *mm;
	struct mm_struct___46 *active_mm;
	struct vmacache___45 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___46 *real_parent;
	struct task_struct___46 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___46 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___40 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___41 *nsproxy;
	struct signal_struct___42 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___46 *pi_top_task;
	struct rt_mutex_waiter___2 *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___21 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___20 *backing_dev_info;
	struct io_context___22 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___34 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___30 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___45 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___20 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___20 *active_memcg;
	struct request_queue___22 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___46 *oom_reaper_list;
	struct vm_struct___44 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___30 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___44;

struct kobj_type___44;

struct kernfs_node___44;

struct kobject___44 {
	const char *name;
	struct list_head entry;
	struct kobject___44 *parent;
	struct kset___44 *kset;
	struct kobj_type___44 *ktype;
	struct kernfs_node___44 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___41 {
	struct kobject___44 kobj;
	struct module___43 *mod;
	struct kobject___44 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___41 {
	struct module___43 *mod;
	struct latch_tree_node node;
};

struct module_layout___41 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___41 mtn;
};

struct module_attribute___41;

struct kernel_param___41;

struct trace_event_call___25;

struct module___43 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___41 mkobj;
	struct module_attribute___41 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___44 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___41 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___41 core_layout;
	struct module_layout___41 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___25 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___30 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___46 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___30)(struct perf_event___30 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___30;

struct fasync_struct___41;

struct pid_namespace___40;

struct perf_cgroup___30;

struct perf_event___30 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___30 *group_leader;
	struct pmu___30 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___30 hw;
	struct perf_event_context___30 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___30 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___46 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___41 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___30 *aux_event;
	void (*destroy)(struct perf_event___30 *);
	struct callback_head callback_head;
	struct pid_namespace___40 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___30 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___30 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___25 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___30 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct swait_queue___3 {
	struct task_struct___46 *task;
	struct list_head task_list;
};

struct upid___40 {
	int nr;
	struct pid_namespace___40 *ns;
};

struct pid_namespace___40 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___46 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___40 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___40 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___40 numbers[1];
};

typedef struct page___45 *pgtable_t___45;

struct address_space___41;

struct dev_pagemap___41;

struct page___45 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___41 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___45 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___45 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___46 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___41 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct rt_mutex_base___2 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___46 *owner;
};

struct rt_mutex___2 {
	struct rt_mutex_base___2 rtmutex;
};

struct ww_acquire_ctx___2 {
	struct task_struct___46 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct vm_operations_struct___41;

struct vm_area_struct___45 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___45 *vm_next;
	struct vm_area_struct___45 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___46 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___41 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___42 *vm_file;
	struct file___42 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___42 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___46 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___46 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___40 *pids[4];
	struct pid___40 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___46 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___45;

struct mm_struct___46 {
	struct {
		struct vm_area_struct___45 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___42 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___45 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___46 *owner;
		struct user_namespace___4 *user_ns;
		struct file___42 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___34;

struct nsproxy___41 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___40 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___34 *cgroup_ns;
};

struct rt_mutex_waiter___2 {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___46 *task;
	struct rt_mutex_base___2 *lock;
	unsigned int wake_state;
	int prio;
	u64 deadline;
	struct ww_acquire_ctx___2 *ww_ctx;
};

struct bio___21;

struct bio_list___21 {
	struct bio___21 *head;
	struct bio___21 *tail;
};

struct cgroup_subsys_state___34;

struct bdi_writeback___20 {
	struct backing_dev_info___20 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___34 *memcg_css;
	struct cgroup_subsys_state___34 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___40;

struct backing_dev_info___20 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___20 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___40 *dev;
	char dev_name[64];
	struct device___40 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___42 *debug_dir;
};

struct io_cq___21;

struct io_context___22 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___21 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___34;

struct css_set___34 {
	struct cgroup_subsys_state___34 *subsys[14];
	refcount_t refcount;
	struct css_set___34 *dom_cset;
	struct cgroup___34 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___34 *mg_src_cgrp;
	struct cgroup___34 *mg_dst_cgrp;
	struct css_set___34 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___30 {
	struct pmu___30 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___46 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___30 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___34;

struct cgroup_subsys_state___34 {
	struct cgroup___34 *cgroup;
	struct cgroup_subsys___34 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___34 *parent;
};

struct cgroup_file___34 {
	struct kernfs_node___44 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___20;

struct mem_cgroup_per_node___20;

struct mem_cgroup___20 {
	struct cgroup_subsys_state___34 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___34 events_file;
	struct cgroup_file___34 events_local_file;
	struct cgroup_file___34 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___20 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___46 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___20 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___21;

struct blk_integrity___21 {
	const struct blk_integrity_profile___21 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___21 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___21 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___21;

struct elevator_queue___21;

struct blk_mq_ops___20;

struct blk_mq_hw_ctx___20;

struct gendisk___21;

struct blkcg_gq___20;

struct blk_mq_tag_set___20;

struct request_queue___22 {
	struct request___21 *last_merge;
	struct elevator_queue___21 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___20 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___20 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___21 *disk;
	struct kobject___44 kobj;
	struct kobject___44 *mq_kobj;
	struct blk_integrity___21 integrity;
	struct device___40 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___20 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___20 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___21 bio_split;
	struct dentry___42 *debugfs_dir;
	struct dentry___42 *sched_debugfs_dir;
	struct dentry___42 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___44 {
	struct vm_struct___44 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___45 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___41;

struct address_space___41 {
	struct inode___42 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___41 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___41;

struct dev_pagemap___41 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___41 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___41;

struct path___41 {
	struct vfsmount___41 *mnt;
	struct dentry___42 *dentry;
};

struct fown_struct___40 {
	rwlock_t lock;
	struct pid___40 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___42 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___41 f_path;
	struct inode___42 *f_inode;
	const struct file_operations___41 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___40 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___41 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___41;

struct vm_operations_struct___41 {
	void (*open)(struct vm_area_struct___45 *);
	void (*close)(struct vm_area_struct___45 *);
	int (*may_split)(struct vm_area_struct___45 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___45 *);
	int (*mprotect)(struct vm_area_struct___45 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___41 *);
	vm_fault_t (*huge_fault)(struct vm_fault___41 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___41 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___45 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___41 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___41 *);
	int (*access)(struct vm_area_struct___45 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___45 *);
	int (*set_policy)(struct vm_area_struct___45 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___45 *, long unsigned int);
	struct page___45 * (*find_special_page)(struct vm_area_struct___45 *, long unsigned int);
};

struct core_thread___45 {
	struct task_struct___46 *task;
	struct core_thread___45 *next;
};

struct core_state___45 {
	atomic_t nr_threads;
	struct core_thread___45 dumper;
	struct completion startup;
};

struct vm_fault___41 {
	const struct {
		struct vm_area_struct___45 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___45 *cow_page;
	struct page___45 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___45 prealloc_pte;
};

struct pglist_data___21;

struct lruvec___21 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___21 *pgdat;
};

struct zone___21 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___21 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___21 {
	struct zone___21 *zone;
	int zone_idx;
};

struct zonelist___21 {
	struct zoneref___21 _zonerefs[321];
};

struct pglist_data___21 {
	struct zone___21 node_zones[5];
	struct zonelist___21 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___46 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___46 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___21 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct fwnode_operations___40;

struct fwnode_handle___40 {
	struct fwnode_handle___40 *secondary;
	const struct fwnode_operations___40 *ops;
	struct device___40 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___40;

struct fwnode_endpoint___40;

struct fwnode_operations___40 {
	struct fwnode_handle___40 * (*get)(struct fwnode_handle___40 *);
	void (*put)(struct fwnode_handle___40 *);
	bool (*device_is_available)(const struct fwnode_handle___40 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___40 *, const struct device___40 *);
	bool (*property_present)(const struct fwnode_handle___40 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___40 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___40 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___40 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_parent)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_next_child_node)(const struct fwnode_handle___40 *, struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*get_named_child_node)(const struct fwnode_handle___40 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___40 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___40 *);
	struct fwnode_handle___40 * (*graph_get_next_endpoint)(const struct fwnode_handle___40 *, struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*graph_get_remote_endpoint)(const struct fwnode_handle___40 *);
	struct fwnode_handle___40 * (*graph_get_port_parent)(struct fwnode_handle___40 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___40 *, struct fwnode_endpoint___40 *);
	int (*add_links)(struct fwnode_handle___40 *);
};

struct wakeup_source___40;

struct dev_pm_info___40 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___40 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___40 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___40;

struct bus_type___40;

struct device_driver___40;

struct dev_pm_domain___40;

struct device_node___25;

struct class___40;

struct attribute_group___44;

struct device___40 {
	struct kobject___44 kobj;
	struct device___40 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___40 *type;
	struct bus_type___40 *bus;
	struct device_driver___40 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___40 power;
	struct dev_pm_domain___40 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___25 *of_node;
	struct fwnode_handle___40 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___40 *class;
	const struct attribute_group___44 **groups;
	void (*release)(struct device___40 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___40 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___40 *local_fwnode;
};

struct fwnode_reference_args___40 {
	struct fwnode_handle___40 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___40;

struct seq_file___41 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___40 *op;
	int poll_event;
	const struct file___42 *file;
	void *private;
};

struct kernfs_root___44;

struct kernfs_elem_dir___44 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___44 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___44;

struct kernfs_root___44 {
	struct kernfs_node___44 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___44 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___44 {
	struct kernfs_node___44 *target_kn;
};

struct kernfs_ops___44;

struct kernfs_elem_attr___44 {
	const struct kernfs_ops___44 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___44 *notify_next;
};

struct kernfs_node___44 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___44 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___44 dir;
		struct kernfs_elem_symlink___44 symlink;
		struct kernfs_elem_attr___44 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___44;

struct kernfs_ops___44 {
	int (*open)(struct kernfs_open_file___44 *);
	void (*release)(struct kernfs_open_file___44 *);
	int (*seq_show)(struct seq_file___41 *, void *);
	void * (*seq_start)(struct seq_file___41 *, loff_t *);
	void * (*seq_next)(struct seq_file___41 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___41 *, void *);
	ssize_t (*read)(struct kernfs_open_file___44 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___44 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___44 *, struct poll_table_struct___33 *);
	int (*mmap)(struct kernfs_open_file___44 *, struct vm_area_struct___45 *);
};

struct kernfs_syscall_ops___44 {
	int (*show_options)(struct seq_file___41 *, struct kernfs_root___44 *);
	int (*mkdir)(struct kernfs_node___44 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___44 *);
	int (*rename)(struct kernfs_node___44 *, struct kernfs_node___44 *, const char *);
	int (*show_path)(struct seq_file___41 *, struct kernfs_node___44 *, struct kernfs_root___44 *);
};

struct kernfs_open_file___44 {
	struct kernfs_node___44 *kn;
	struct file___42 *file;
	struct seq_file___41 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___41 *vm_ops;
};

typedef void (*poll_queue_proc___33)(struct file___42 *, wait_queue_head_t *, struct poll_table_struct___33 *);

struct poll_table_struct___33 {
	poll_queue_proc___33 _qproc;
	__poll_t _key;
};

struct bin_attribute___44;

struct attribute_group___44 {
	const char *name;
	umode_t (*is_visible)(struct kobject___44 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___44 *, struct bin_attribute___44 *, int);
	struct attribute **attrs;
	struct bin_attribute___44 **bin_attrs;
};

struct bin_attribute___44 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___41 * (*f_mapping)();
	ssize_t (*read)(struct file___42 *, struct kobject___44 *, struct bin_attribute___44 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___42 *, struct kobject___44 *, struct bin_attribute___44 *, char *, loff_t, size_t);
	int (*mmap)(struct file___42 *, struct kobject___44 *, struct bin_attribute___44 *, struct vm_area_struct___45 *);
};

struct sysfs_ops___44 {
	ssize_t (*show)(struct kobject___44 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___44 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___44;

struct kset___44 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___44 kobj;
	const struct kset_uevent_ops___44 *uevent_ops;
};

struct kobj_type___44 {
	void (*release)(struct kobject___44 *);
	const struct sysfs_ops___44 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___44 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___44 *);
	const void * (*namespace)(struct kobject___44 *);
	void (*get_ownership)(struct kobject___44 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___44 {
	int (* const filter)(struct kset___44 *, struct kobject___44 *);
	const char * (* const name)(struct kset___44 *, struct kobject___44 *);
	int (* const uevent)(struct kset___44 *, struct kobject___44 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___41 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___41 *);
	int (*get)(char *, const struct kernel_param___41 *);
	void (*free)(void *);
};

struct kparam_array___41;

struct kernel_param___41 {
	const char *name;
	struct module___43 *mod;
	const struct kernel_param_ops___41 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___41 *arr;
	};
};

struct kparam_array___41 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___41 *ops;
	void *elem;
};

struct dev_pm_ops___40 {
	int (*prepare)(struct device___40 *);
	void (*complete)(struct device___40 *);
	int (*suspend)(struct device___40 *);
	int (*resume)(struct device___40 *);
	int (*freeze)(struct device___40 *);
	int (*thaw)(struct device___40 *);
	int (*poweroff)(struct device___40 *);
	int (*restore)(struct device___40 *);
	int (*suspend_late)(struct device___40 *);
	int (*resume_early)(struct device___40 *);
	int (*freeze_late)(struct device___40 *);
	int (*thaw_early)(struct device___40 *);
	int (*poweroff_late)(struct device___40 *);
	int (*restore_early)(struct device___40 *);
	int (*suspend_noirq)(struct device___40 *);
	int (*resume_noirq)(struct device___40 *);
	int (*freeze_noirq)(struct device___40 *);
	int (*thaw_noirq)(struct device___40 *);
	int (*poweroff_noirq)(struct device___40 *);
	int (*restore_noirq)(struct device___40 *);
	int (*runtime_suspend)(struct device___40 *);
	int (*runtime_resume)(struct device___40 *);
	int (*runtime_idle)(struct device___40 *);
};

struct wakeup_source___40 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___40 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___40 {
	struct dev_pm_ops___40 ops;
	int (*start)(struct device___40 *);
	void (*detach)(struct device___40 *, bool);
	int (*activate)(struct device___40 *);
	void (*sync)(struct device___40 *);
	void (*dismiss)(struct device___40 *);
};

struct bus_type___40 {
	const char *name;
	const char *dev_name;
	struct device___40 *dev_root;
	const struct attribute_group___44 **bus_groups;
	const struct attribute_group___44 **dev_groups;
	const struct attribute_group___44 **drv_groups;
	int (*match)(struct device___40 *, struct device_driver___40 *);
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	int (*probe)(struct device___40 *);
	void (*sync_state)(struct device___40 *);
	void (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*online)(struct device___40 *);
	int (*offline)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	int (*num_vf)(struct device___40 *);
	int (*dma_configure)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___40 {
	const char *name;
	struct bus_type___40 *bus;
	struct module___43 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___40 *);
	void (*sync_state)(struct device___40 *);
	int (*remove)(struct device___40 *);
	void (*shutdown)(struct device___40 *);
	int (*suspend)(struct device___40 *, pm_message_t);
	int (*resume)(struct device___40 *);
	const struct attribute_group___44 **groups;
	const struct attribute_group___44 **dev_groups;
	const struct dev_pm_ops___40 *pm;
	void (*coredump)(struct device___40 *);
	struct driver_private *p;
};

struct device_type___40 {
	const char *name;
	const struct attribute_group___44 **groups;
	int (*uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___40 *);
	const struct dev_pm_ops___40 *pm;
};

struct class___40 {
	const char *name;
	struct module___43 *owner;
	const struct attribute_group___44 **class_groups;
	const struct attribute_group___44 **dev_groups;
	struct kobject___44 *dev_kobj;
	int (*dev_uevent)(struct device___40 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___40 *, umode_t *);
	void (*class_release)(struct class___40 *);
	void (*dev_release)(struct device___40 *);
	int (*shutdown_pre)(struct device___40 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___40 *);
	void (*get_ownership)(struct device___40 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___40 *pm;
	struct subsys_private *p;
};

struct property___22;

struct device_node___25 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___40 fwnode;
	struct property___22 *properties;
	struct property___22 *deadprops;
	struct device_node___25 *parent;
	struct device_node___25 *child;
	struct device_node___25 *sibling;
	struct kobject___44 kobj;
	long unsigned int _flags;
	void *data;
};

struct shrink_control___20 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___20 *memcg;
};

struct shrinker___20 {
	long unsigned int (*count_objects)(struct shrinker___20 *, struct shrink_control___20 *);
	long unsigned int (*scan_objects)(struct shrinker___20 *, struct shrink_control___20 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___41 {
	void (*page_free)(struct page___45 *);
	void (*kill)(struct dev_pagemap___41 *);
	void (*cleanup)(struct dev_pagemap___41 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___41 *);
};

struct dentry_operations___41;

struct dentry___42 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___42 *d_parent;
	struct qstr d_name;
	struct inode___42 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___41 *d_op;
	struct super_block___42 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___41;

struct inode___42 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___41 *i_op;
	struct super_block___42 *i_sb;
	struct address_space___41 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___20 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___41 *i_fop;
		void (*free_inode)(struct inode___42 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___41 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___17 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___41 {
	int (*d_revalidate)(struct dentry___42 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___42 *, unsigned int);
	int (*d_hash)(const struct dentry___42 *, struct qstr *);
	int (*d_compare)(const struct dentry___42 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___42 *);
	int (*d_init)(struct dentry___42 *);
	void (*d_release)(struct dentry___42 *);
	void (*d_prune)(struct dentry___42 *);
	void (*d_iput)(struct dentry___42 *, struct inode___42 *);
	char * (*d_dname)(struct dentry___42 *, char *, int);
	struct vfsmount___41 * (*d_automount)(struct path___41 *);
	int (*d_manage)(const struct path___41 *, bool);
	struct dentry___42 * (*d_real)(struct dentry___42 *, const struct inode___42 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___41;

struct mem_dqinfo___41 {
	struct quota_format_type___41 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___41;

struct quota_info___41 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___42 *files[3];
	struct mem_dqinfo___41 info[3];
	const struct quota_format_ops___41 *ops[3];
};

struct rcuwait___42 {
	struct task_struct___46 *task;
};

struct percpu_rw_semaphore___42 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___42 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___41 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___42 rw_sem[3];
};

struct super_operations___41;

struct dquot_operations___41;

struct quotactl_ops___41;

struct block_device___22;

struct super_block___42 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___41 *s_type;
	const struct super_operations___41 *s_op;
	const struct dquot_operations___41 *dq_op;
	const struct quotactl_ops___41 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___42 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___22 *s_bdev;
	struct backing_dev_info___20 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___41 s_dquot;
	struct sb_writers___41 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___41 *s_d_op;
	int cleancache_poolid;
	struct shrinker___20 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___41 {
	struct dentry___42 *mnt_root;
	struct super_block___42 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct psi_group___34 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___46 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___34;

struct cgroup_rstat_cpu___34;

struct cgroup___34 {
	struct cgroup_subsys_state___34 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___44 *kn;
	struct cgroup_file___34 procs_file;
	struct cgroup_file___34 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___34 *subsys[14];
	struct cgroup_root___34 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___34 *dom_cgrp;
	struct cgroup___34 *old_dom_cgrp;
	struct cgroup_rstat_cpu___34 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___34 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___21 {
	struct request_queue___22 *q;
	struct io_context___22 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___22;

struct kiocb___41 {
	struct file___42 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___41 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___22 *ki_waitq;
	};
};

struct iattr___42 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___42 *ia_file;
};

struct dquot___41 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___42 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___41 {
	int qf_fmt_id;
	const struct quota_format_ops___41 *qf_ops;
	struct module___43 *qf_owner;
	struct quota_format_type___41 *qf_next;
};

struct quota_format_ops___41 {
	int (*check_quota_file)(struct super_block___42 *, int);
	int (*read_file_info)(struct super_block___42 *, int);
	int (*write_file_info)(struct super_block___42 *, int);
	int (*free_file_info)(struct super_block___42 *, int);
	int (*read_dqblk)(struct dquot___41 *);
	int (*commit_dqblk)(struct dquot___41 *);
	int (*release_dqblk)(struct dquot___41 *);
	int (*get_next_id)(struct super_block___42 *, struct kqid *);
};

struct dquot_operations___41 {
	int (*write_dquot)(struct dquot___41 *);
	struct dquot___41 * (*alloc_dquot)(struct super_block___42 *, int);
	void (*destroy_dquot)(struct dquot___41 *);
	int (*acquire_dquot)(struct dquot___41 *);
	int (*release_dquot)(struct dquot___41 *);
	int (*mark_dirty)(struct dquot___41 *);
	int (*write_info)(struct super_block___42 *, int);
	qsize_t * (*get_reserved_space)(struct inode___42 *);
	int (*get_projid)(struct inode___42 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___42 *, qsize_t *);
	int (*get_next_id)(struct super_block___42 *, struct kqid *);
};

struct quotactl_ops___41 {
	int (*quota_on)(struct super_block___42 *, int, int, const struct path___41 *);
	int (*quota_off)(struct super_block___42 *, int);
	int (*quota_enable)(struct super_block___42 *, unsigned int);
	int (*quota_disable)(struct super_block___42 *, unsigned int);
	int (*quota_sync)(struct super_block___42 *, int);
	int (*set_info)(struct super_block___42 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___42 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___42 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___42 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___42 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___42 *, unsigned int);
};

struct wait_page_queue___22 {
	struct page___45 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___20;

struct readahead_control___22;

struct swap_info_struct___16;

struct address_space_operations___41 {
	int (*writepage)(struct page___45 *, struct writeback_control___20 *);
	int (*readpage)(struct file___42 *, struct page___45 *);
	int (*writepages)(struct address_space___41 *, struct writeback_control___20 *);
	int (*set_page_dirty)(struct page___45 *);
	int (*readpages)(struct file___42 *, struct address_space___41 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___22 *);
	int (*write_begin)(struct file___42 *, struct address_space___41 *, loff_t, unsigned int, unsigned int, struct page___45 **, void **);
	int (*write_end)(struct file___42 *, struct address_space___41 *, loff_t, unsigned int, unsigned int, struct page___45 *, void *);
	sector_t (*bmap)(struct address_space___41 *, sector_t);
	void (*invalidatepage)(struct page___45 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___45 *, gfp_t);
	void (*freepage)(struct page___45 *);
	ssize_t (*direct_IO)(struct kiocb___41 *, struct iov_iter___24 *);
	int (*migratepage)(struct address_space___41 *, struct page___45 *, struct page___45 *, enum migrate_mode);
	bool (*isolate_page)(struct page___45 *, isolate_mode_t);
	void (*putback_page)(struct page___45 *);
	int (*launder_page)(struct page___45 *);
	int (*is_partially_uptodate)(struct page___45 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___45 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___41 *, struct page___45 *);
	int (*swap_activate)(struct swap_info_struct___16 *, struct file___42 *, sector_t *);
	void (*swap_deactivate)(struct file___42 *);
};

struct writeback_control___20 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___20 *wb;
	struct inode___42 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___22 {
	struct file___42 *file;
	struct address_space___41 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___24;

struct iov_iter___24 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___24 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___16 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___22 *bdev;
	struct file___42 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___41 {
	struct dentry___42 * (*lookup)(struct inode___42 *, struct dentry___42 *, unsigned int);
	const char * (*get_link)(struct dentry___42 *, struct inode___42 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___42 *, int);
	struct posix_acl * (*get_acl)(struct inode___42 *, int, bool);
	int (*readlink)(struct dentry___42 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___42 *, struct dentry___42 *, umode_t, bool);
	int (*link)(struct dentry___42 *, struct inode___42 *, struct dentry___42 *);
	int (*unlink)(struct inode___42 *, struct dentry___42 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___42 *, struct dentry___42 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___42 *, struct dentry___42 *, umode_t);
	int (*rmdir)(struct inode___42 *, struct dentry___42 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___42 *, struct dentry___42 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___42 *, struct dentry___42 *, struct inode___42 *, struct dentry___42 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___42 *, struct iattr___42 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___41 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___42 *, char *, size_t);
	int (*fiemap)(struct inode___42 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___42 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___42 *, struct dentry___42 *, struct file___42 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___42 *, struct dentry___42 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___42 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___42 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___42 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___41 {
	void (*fl_copy_lock)(struct file_lock___41 *, struct file_lock___41 *);
	void (*fl_release_private)(struct file_lock___41 *);
};

struct lock_manager_operations___41;

struct file_lock___41 {
	struct file_lock___41 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___42 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___41 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___41 *fl_ops;
	const struct lock_manager_operations___41 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___41 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___41 *);
	int (*lm_grant)(struct file_lock___41 *, int);
	bool (*lm_break)(struct file_lock___41 *);
	int (*lm_change)(struct file_lock___41 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___41 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___41 *);
};

struct fasync_struct___41 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___41 *fa_next;
	struct file___42 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___41 {
	struct inode___42 * (*alloc_inode)(struct super_block___42 *);
	void (*destroy_inode)(struct inode___42 *);
	void (*free_inode)(struct inode___42 *);
	void (*dirty_inode)(struct inode___42 *, int);
	int (*write_inode)(struct inode___42 *, struct writeback_control___20 *);
	int (*drop_inode)(struct inode___42 *);
	void (*evict_inode)(struct inode___42 *);
	void (*put_super)(struct super_block___42 *);
	int (*sync_fs)(struct super_block___42 *, int);
	int (*freeze_super)(struct super_block___42 *);
	int (*freeze_fs)(struct super_block___42 *);
	int (*thaw_super)(struct super_block___42 *);
	int (*unfreeze_fs)(struct super_block___42 *);
	int (*statfs)(struct dentry___42 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___42 *, int *, char *);
	void (*umount_begin)(struct super_block___42 *);
	int (*show_options)(struct seq_file___41 *, struct dentry___42 *);
	int (*show_devname)(struct seq_file___41 *, struct dentry___42 *);
	int (*show_path)(struct seq_file___41 *, struct dentry___42 *);
	int (*show_stats)(struct seq_file___41 *, struct dentry___42 *);
	ssize_t (*quota_read)(struct super_block___42 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___42 *, int, const char *, size_t, loff_t);
	struct dquot___41 ** (*get_dquots)(struct inode___42 *);
	long int (*nr_cached_objects)(struct super_block___42 *, struct shrink_control___20 *);
	long int (*free_cached_objects)(struct super_block___42 *, struct shrink_control___20 *);
	struct file___42 * (*real_loop)(struct file___42 *);
};

struct block_device___22 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___42 *bd_inode;
	struct super_block___42 *bd_super;
	void *bd_claiming;
	struct device___40 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___44 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___21 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___42 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___21(struct bio___21 *);

struct bio_vec___24 {
	struct page___45 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___21;

struct bio___21 {
	struct bio___21 *bi_next;
	struct block_device___22 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___21 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___20 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___21 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___24 *bi_io_vec;
	struct bio_set___21 *bi_pool;
	struct bio_vec___24 bi_inline_vecs[0];
};

struct seq_operations___40 {
	void * (*start)(struct seq_file___41 *, loff_t *);
	void (*stop)(struct seq_file___41 *, void *);
	void * (*next)(struct seq_file___41 *, void *, loff_t *);
	int (*show)(struct seq_file___41 *, void *);
};

struct cgroup_namespace___34 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___34 *root_cset;
};

struct module_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___41 *, struct module_kobject___41 *, char *);
	ssize_t (*store)(struct module_attribute___41 *, struct module_kobject___41 *, const char *, size_t);
	void (*setup)(struct module___43 *, const char *);
	int (*test)(struct module___43 *);
	void (*free)(struct module___43 *);
};

struct trace_event_class___25;

struct trace_event_call___25 {
	struct list_head list;
	struct trace_event_class___25 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___25 *, struct perf_event___30 *);
};

struct cftype___34;

struct cgroup_subsys___34 {
	struct cgroup_subsys_state___34 * (*css_alloc)(struct cgroup_subsys_state___34 *);
	int (*css_online)(struct cgroup_subsys_state___34 *);
	void (*css_offline)(struct cgroup_subsys_state___34 *);
	void (*css_released)(struct cgroup_subsys_state___34 *);
	void (*css_free)(struct cgroup_subsys_state___34 *);
	void (*css_reset)(struct cgroup_subsys_state___34 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___34 *, int);
	int (*css_extra_stat_show)(struct seq_file___41 *, struct cgroup_subsys_state___34 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___46 *, struct css_set___34 *);
	void (*cancel_fork)(struct task_struct___46 *, struct css_set___34 *);
	void (*fork)(struct task_struct___46 *);
	void (*exit)(struct task_struct___46 *);
	void (*release)(struct task_struct___46 *);
	void (*bind)(struct cgroup_subsys_state___34 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___34 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___34 *dfl_cftypes;
	struct cftype___34 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___34 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___34 *updated_children;
	struct cgroup___34 *updated_next;
};

struct cgroup_root___34 {
	struct kernfs_root___44 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___34 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___34 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___34 *ss;
	struct list_head node;
	struct kernfs_ops___44 *kf_ops;
	int (*open)(struct kernfs_open_file___44 *);
	void (*release)(struct kernfs_open_file___44 *);
	u64 (*read_u64)(struct cgroup_subsys_state___34 *, struct cftype___34 *);
	s64 (*read_s64)(struct cgroup_subsys_state___34 *, struct cftype___34 *);
	int (*seq_show)(struct seq_file___41 *, void *);
	void * (*seq_start)(struct seq_file___41 *, loff_t *);
	void * (*seq_next)(struct seq_file___41 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___41 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___34 *, struct cftype___34 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___34 *, struct cftype___34 *, s64);
	ssize_t (*write)(struct kernfs_open_file___44 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___44 *, struct poll_table_struct___33 *);
};

struct perf_cpu_context___30;

struct perf_output_handle___30;

struct pmu___30 {
	struct list_head entry;
	struct module___43 *module;
	struct device___40 *dev;
	const struct attribute_group___44 **attr_groups;
	const struct attribute_group___44 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___30 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___30 *);
	void (*pmu_disable)(struct pmu___30 *);
	int (*event_init)(struct perf_event___30 *);
	void (*event_mapped)(struct perf_event___30 *, struct mm_struct___46 *);
	void (*event_unmapped)(struct perf_event___30 *, struct mm_struct___46 *);
	int (*add)(struct perf_event___30 *, int);
	void (*del)(struct perf_event___30 *, int);
	void (*start)(struct perf_event___30 *, int);
	void (*stop)(struct perf_event___30 *, int);
	void (*read)(struct perf_event___30 *);
	void (*start_txn)(struct pmu___30 *, unsigned int);
	int (*commit_txn)(struct pmu___30 *);
	void (*cancel_txn)(struct pmu___30 *);
	int (*event_idx)(struct perf_event___30 *);
	void (*sched_task)(struct perf_event_context___30 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___30 *, struct perf_event_context___30 *);
	void * (*setup_aux)(struct perf_event___30 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___30 *, struct perf_output_handle___30 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___30 *);
	int (*aux_output_match)(struct perf_event___30 *);
	int (*filter_match)(struct perf_event___30 *);
	int (*check_period)(struct perf_event___30 *, u64);
};

struct perf_cpu_context___30 {
	struct perf_event_context___30 ctx;
	struct perf_event_context___30 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___30 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___30 **heap;
	struct perf_event___30 *heap_default[2];
};

struct perf_output_handle___30 {
	struct perf_event___30 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___30 {
	struct cgroup_subsys_state___34 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___25 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___25 *);
	};
};

struct trace_event_class___25 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___25 *, enum trace_reg, void *);
	struct trace_event_fields___25 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___25 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___25 *);
};

struct block_device_operations___21;

struct gendisk___21 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___22 *part0;
	const struct block_device_operations___21 *fops;
	struct request_queue___22 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___20 *bdi;
	struct kobject___44 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___44 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___21 {
	struct bio___21 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___24 *bip_vec;
	struct bio_vec___24 bip_inline_vecs[0];
};

struct blkcg___20;

struct blkg_policy_data___20;

struct blkcg_gq___20 {
	struct request_queue___22 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___20 *blkcg;
	struct blkcg_gq___20 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___20 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___21 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___21(struct request___21 *);

typedef void integrity_complete_fn___21(struct request___21 *, unsigned int);

struct blk_integrity_profile___21 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___21 *prepare_fn;
	integrity_complete_fn___21 *complete_fn;
	const char *name;
};

struct block_device_operations___21 {
	blk_qc_t (*submit_bio)(struct bio___21 *);
	int (*open)(struct block_device___22 *, fmode_t);
	void (*release)(struct gendisk___21 *, fmode_t);
	int (*rw_page)(struct block_device___22 *, sector_t, struct page___45 *, unsigned int);
	int (*ioctl)(struct block_device___22 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___22 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___21 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___21 *);
	int (*getgeo)(struct block_device___22 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___22 *, bool);
	void (*swap_slot_free_notify)(struct block_device___22 *, long unsigned int);
	int (*report_zones)(struct gendisk___21 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___21 *, umode_t *);
	struct module___43 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___21 *, sector_t *);
};

typedef void rq_end_io_fn___21(struct request___21 *, blk_status_t);

struct request___21 {
	struct request_queue___22 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___20 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___21 *bio;
	struct bio___21 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___24 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___21 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___21 *saved_end_io;
		} flush;
	};
	struct gendisk___21 *rq_disk;
	struct block_device___22 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___21 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___20 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___22 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___44 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___42 *debugfs_dir;
	struct dentry___42 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___21;

struct elevator_mq_ops___21 {
	int (*init_sched)(struct request_queue___22 *, struct elevator_type___21 *);
	void (*exit_sched)(struct elevator_queue___21 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___20 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___20 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___20 *);
	bool (*allow_merge)(struct request_queue___22 *, struct request___21 *, struct bio___21 *);
	bool (*bio_merge)(struct request_queue___22 *, struct bio___21 *, unsigned int);
	int (*request_merge)(struct request_queue___22 *, struct request___21 **, struct bio___21 *);
	void (*request_merged)(struct request_queue___22 *, struct request___21 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___22 *, struct request___21 *, struct request___21 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___21 *);
	void (*finish_request)(struct request___21 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___20 *, struct list_head *, bool);
	struct request___21 * (*dispatch_request)(struct blk_mq_hw_ctx___20 *);
	bool (*has_work)(struct blk_mq_hw_ctx___20 *);
	void (*completed_request)(struct request___21 *, u64);
	void (*requeue_request)(struct request___21 *);
	struct request___21 * (*former_request)(struct request_queue___22 *, struct request___21 *);
	struct request___21 * (*next_request)(struct request_queue___22 *, struct request___21 *);
	void (*init_icq)(struct io_cq___21 *);
	void (*exit_icq)(struct io_cq___21 *);
};

struct elv_fs_entry___21;

struct elevator_type___21 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___21 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___21 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___43 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___21 {
	struct elevator_type___21 *type;
	void *elevator_data;
	struct kobject___44 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___21 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___21 *, char *);
	ssize_t (*store)(struct elevator_queue___21 *, const char *, size_t);
};

struct blk_mq_queue_data___20;

struct blk_mq_ops___20 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___20 *, const struct blk_mq_queue_data___20 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___20 *);
	int (*get_budget)(struct request_queue___22 *);
	void (*put_budget)(struct request_queue___22 *, int);
	void (*set_rq_budget_token)(struct request___21 *, int);
	int (*get_rq_budget_token)(struct request___21 *);
	enum blk_eh_timer_return (*timeout)(struct request___21 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___20 *);
	void (*complete)(struct request___21 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___20 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___20 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___20 *, struct request___21 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___20 *, struct request___21 *, unsigned int);
	void (*initialize_rq_fn)(struct request___21 *);
	void (*cleanup_rq)(struct request___21 *);
	bool (*busy)(struct request_queue___22 *);
	int (*map_queues)(struct blk_mq_tag_set___20 *);
	void (*show_rq)(struct seq_file___41 *, struct request___21 *);
};

struct blk_mq_tag_set___20 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___20 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___20 {
	struct request___21 *rq;
	bool last;
};

struct blkcg_policy_data___20;

struct blkcg___20 {
	struct cgroup_subsys_state___34 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___20 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___20 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___20 {
	struct blkcg___20 *blkcg;
	int plid;
};

struct blkg_policy_data___20 {
	struct blkcg_gq___20 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___20 {
	struct mem_cgroup___20 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___20 {
	struct lruvec___21 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___20 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___20 *memcg;
};

struct obj_cgroup___20 {
	struct percpu_ref refcnt;
	struct mem_cgroup___20 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct property___22 {
	char *name;
	int length;
	void *value;
	struct property___22 *next;
	long unsigned int _flags;
	struct bin_attribute___44 attr;
};

enum tick_dep_bits {
	TICK_DEP_BIT_POSIX_TIMER = 0,
	TICK_DEP_BIT_PERF_EVENTS = 1,
	TICK_DEP_BIT_SCHED = 2,
	TICK_DEP_BIT_CLOCK_UNSTABLE = 3,
	TICK_DEP_BIT_RCU = 4,
	TICK_DEP_BIT_RCU_EXP = 5,
};

struct smp_hotplug_thread___4 {
	struct task_struct___46 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct rcu_exp_work {
	long unsigned int rew_s;
	struct work_struct rew_work;
};

struct rcu_node {
	raw_spinlock_t lock;
	long unsigned int gp_seq;
	long unsigned int gp_seq_needed;
	long unsigned int completedqs;
	long unsigned int qsmask;
	long unsigned int rcu_gp_init_mask;
	long unsigned int qsmaskinit;
	long unsigned int qsmaskinitnext;
	long unsigned int ofl_seq;
	long unsigned int expmask;
	long unsigned int expmaskinit;
	long unsigned int expmaskinitnext;
	long unsigned int cbovldmask;
	long unsigned int ffmask;
	long unsigned int grpmask;
	int grplo;
	int grphi;
	u8 grpnum;
	u8 level;
	bool wait_blkd_tasks;
	struct rcu_node *parent;
	struct list_head blkd_tasks;
	struct list_head *gp_tasks;
	struct list_head *exp_tasks;
	struct list_head *boost_tasks;
	struct rt_mutex___2 boost_mtx;
	long unsigned int boost_time;
	struct task_struct___46 *boost_kthread_task;
	unsigned int boost_kthread_status;
	long unsigned int n_boosts;
	long: 64;
	raw_spinlock_t fqslock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t exp_lock;
	long unsigned int exp_seq_rq;
	wait_queue_head_t exp_wq[4];
	struct rcu_exp_work rew;
	bool exp_need_flush;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union rcu_noqs {
	struct {
		u8 norm;
		u8 exp;
	} b;
	u16 s;
};

struct rcu_data {
	long unsigned int gp_seq;
	long unsigned int gp_seq_needed;
	union rcu_noqs cpu_no_qs;
	bool core_needs_qs;
	bool beenonline;
	bool gpwrap;
	bool exp_deferred_qs;
	bool cpu_started;
	struct rcu_node *mynode;
	long unsigned int grpmask;
	long unsigned int ticks_this_gp;
	struct irq_work defer_qs_iw;
	bool defer_qs_iw_pending;
	struct work_struct strict_work;
	struct rcu_segcblist cblist;
	long int qlen_last_fqs_check;
	long unsigned int n_cbs_invoked;
	long unsigned int n_force_qs_snap;
	long int blimit;
	int dynticks_snap;
	long int dynticks_nesting;
	long int dynticks_nmi_nesting;
	atomic_t dynticks;
	bool rcu_need_heavy_qs;
	bool rcu_urgent_qs;
	bool rcu_forced_tick;
	bool rcu_forced_tick_exp;
	struct callback_head barrier_head;
	int exp_dynticks_snap;
	struct task_struct___46 *rcu_cpu_kthread_task;
	unsigned int rcu_cpu_kthread_status;
	char rcu_cpu_has_work;
	unsigned int softirq_snap;
	struct irq_work rcu_iw;
	bool rcu_iw_pending;
	long unsigned int rcu_iw_gp_seq;
	long unsigned int rcu_ofl_gp_seq;
	short int rcu_ofl_gp_flags;
	long unsigned int rcu_onl_gp_seq;
	short int rcu_onl_gp_flags;
	long unsigned int last_fqs_resched;
	int cpu;
};

struct rcu_state {
	struct rcu_node node[17];
	struct rcu_node *level[3];
	int ncpus;
	int n_online_cpus;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 boost;
	long unsigned int gp_seq;
	long unsigned int gp_max;
	struct task_struct___46 *gp_kthread;
	struct swait_queue_head gp_wq;
	short int gp_flags;
	short int gp_state;
	long unsigned int gp_wake_time;
	long unsigned int gp_wake_seq;
	struct mutex barrier_mutex;
	atomic_t barrier_cpu_count;
	struct completion barrier_completion;
	long unsigned int barrier_sequence;
	struct mutex exp_mutex;
	struct mutex exp_wake_mutex;
	long unsigned int expedited_sequence;
	atomic_t expedited_need_qs;
	struct swait_queue_head expedited_wq;
	int ncpus_snap;
	u8 cbovld;
	u8 cbovldnext;
	long unsigned int jiffies_force_qs;
	long unsigned int jiffies_kick_kthreads;
	long unsigned int n_force_qs;
	long unsigned int gp_start;
	long unsigned int gp_end;
	long unsigned int gp_activity;
	long unsigned int gp_req_activity;
	long unsigned int jiffies_stall;
	long unsigned int jiffies_resched;
	long unsigned int n_force_qs_gpstart;
	const char *name;
	char abbr;
	long: 56;
	long: 64;
	long: 64;
	raw_spinlock_t ofl_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kvfree_rcu_bulk_data {
	long unsigned int nr_records;
	struct kvfree_rcu_bulk_data *next;
	void *records[0];
};

struct kfree_rcu_cpu;

struct kfree_rcu_cpu_work {
	struct rcu_work rcu_work;
	struct callback_head *head_free;
	struct kvfree_rcu_bulk_data *bkvhead_free[2];
	struct kfree_rcu_cpu *krcp;
};

struct kfree_rcu_cpu {
	struct callback_head *head;
	struct kvfree_rcu_bulk_data *bkvhead[2];
	struct kfree_rcu_cpu_work krw_arr[2];
	raw_spinlock_t lock;
	struct delayed_work monitor_work;
	bool monitor_todo;
	bool initialized;
	int count;
	struct delayed_work page_cache_work;
	atomic_t backoff_page_cache_fill;
	atomic_t work_in_progress;
	struct hrtimer hrtimer;
	struct llist_head bkvcache;
	int nr_bkv_objs;
};

struct dma_sgt_handle {
	struct sg_table sgt;
	struct page___31 **pages;
};

struct dma_devres {
	size_t size;
	void *vaddr;
	dma_addr_t dma_handle;
	long unsigned int attrs;
};

struct wakeup_source___41;

struct device___41;

struct dev_pm_info___41 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___41 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___41 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___41;

struct bus_type___41;

struct device_driver___41;

struct dev_pm_domain___41;

struct dma_map_ops___3;

struct device_node___26;

struct fwnode_handle___41;

struct class___41;

struct device___41 {
	struct kobject___40 kobj;
	struct device___41 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___41 *type;
	struct bus_type___41 *bus;
	struct device_driver___41 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___41 power;
	struct dev_pm_domain___41 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___3 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___26 *of_node;
	struct fwnode_handle___41 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___41 *class;
	const struct attribute_group___40 **groups;
	void (*release)(struct device___41 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___41 {
	int (*prepare)(struct device___41 *);
	void (*complete)(struct device___41 *);
	int (*suspend)(struct device___41 *);
	int (*resume)(struct device___41 *);
	int (*freeze)(struct device___41 *);
	int (*thaw)(struct device___41 *);
	int (*poweroff)(struct device___41 *);
	int (*restore)(struct device___41 *);
	int (*suspend_late)(struct device___41 *);
	int (*resume_early)(struct device___41 *);
	int (*freeze_late)(struct device___41 *);
	int (*thaw_early)(struct device___41 *);
	int (*poweroff_late)(struct device___41 *);
	int (*restore_early)(struct device___41 *);
	int (*suspend_noirq)(struct device___41 *);
	int (*resume_noirq)(struct device___41 *);
	int (*freeze_noirq)(struct device___41 *);
	int (*thaw_noirq)(struct device___41 *);
	int (*poweroff_noirq)(struct device___41 *);
	int (*restore_noirq)(struct device___41 *);
	int (*runtime_suspend)(struct device___41 *);
	int (*runtime_resume)(struct device___41 *);
	int (*runtime_idle)(struct device___41 *);
};

struct wakeup_source___41 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___41 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___41 {
	struct dev_pm_ops___41 ops;
	int (*start)(struct device___41 *);
	void (*detach)(struct device___41 *, bool);
	int (*activate)(struct device___41 *);
	void (*sync)(struct device___41 *);
	void (*dismiss)(struct device___41 *);
};

struct bus_type___41 {
	const char *name;
	const char *dev_name;
	struct device___41 *dev_root;
	const struct attribute_group___40 **bus_groups;
	const struct attribute_group___40 **dev_groups;
	const struct attribute_group___40 **drv_groups;
	int (*match)(struct device___41 *, struct device_driver___41 *);
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	int (*probe)(struct device___41 *);
	void (*sync_state)(struct device___41 *);
	void (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*online)(struct device___41 *);
	int (*offline)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	int (*num_vf)(struct device___41 *);
	int (*dma_configure)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___41 {
	const char *name;
	struct bus_type___41 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___41 *);
	void (*sync_state)(struct device___41 *);
	int (*remove)(struct device___41 *);
	void (*shutdown)(struct device___41 *);
	int (*suspend)(struct device___41 *, pm_message_t);
	int (*resume)(struct device___41 *);
	const struct attribute_group___40 **groups;
	const struct attribute_group___40 **dev_groups;
	const struct dev_pm_ops___41 *pm;
	void (*coredump)(struct device___41 *);
	struct driver_private *p;
};

struct device_type___41 {
	const char *name;
	const struct attribute_group___40 **groups;
	int (*uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___41 *);
	const struct dev_pm_ops___41 *pm;
};

struct class___41 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___40 **class_groups;
	const struct attribute_group___40 **dev_groups;
	struct kobject___40 *dev_kobj;
	int (*dev_uevent)(struct device___41 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___41 *, umode_t *);
	void (*class_release)(struct class___41 *);
	void (*dev_release)(struct device___41 *);
	int (*shutdown_pre)(struct device___41 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___41 *);
	void (*get_ownership)(struct device___41 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___41 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___3 {
	void * (*alloc)(struct device___41 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___41 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___43 * (*alloc_pages)(struct device___41 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___41 *, size_t, struct page___43 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___41 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___41 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___41 *, struct vm_area_struct___43 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___41 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___41 *, struct page___43 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___41 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___41 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___41 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___41 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___41 *, u64);
	u64 (*get_required_mask)(struct device___41 *);
	size_t (*max_mapping_size)(struct device___41 *);
	long unsigned int (*get_merge_boundary)(struct device___41 *);
};

struct cma_kobject;

struct cma {
	long unsigned int base_pfn;
	long unsigned int count;
	long unsigned int *bitmap;
	unsigned int order_per_bit;
	spinlock_t lock;
	char name[64];
	atomic64_t nr_pages_succeeded;
	atomic64_t nr_pages_failed;
	struct cma_kobject *cma_kobj;
};

struct fwnode_operations___41;

struct fwnode_handle___41 {
	struct fwnode_handle___41 *secondary;
	const struct fwnode_operations___41 *ops;
	struct device___41 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___26 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___41 fwnode;
	struct property___12 *properties;
	struct property___12 *deadprops;
	struct device_node___26 *parent;
	struct device_node___26 *child;
	struct device_node___26 *sibling;
	struct kobject___40 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___41;

struct fwnode_endpoint___41;

struct fwnode_operations___41 {
	struct fwnode_handle___41 * (*get)(struct fwnode_handle___41 *);
	void (*put)(struct fwnode_handle___41 *);
	bool (*device_is_available)(const struct fwnode_handle___41 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___41 *, const struct device___41 *);
	bool (*property_present)(const struct fwnode_handle___41 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___41 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___41 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___41 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_parent)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_next_child_node)(const struct fwnode_handle___41 *, struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*get_named_child_node)(const struct fwnode_handle___41 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___41 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___41 *);
	struct fwnode_handle___41 * (*graph_get_next_endpoint)(const struct fwnode_handle___41 *, struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*graph_get_remote_endpoint)(const struct fwnode_handle___41 *);
	struct fwnode_handle___41 * (*graph_get_port_parent)(struct fwnode_handle___41 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___41 *, struct fwnode_endpoint___41 *);
	int (*add_links)(struct fwnode_handle___41 *);
};

struct fwnode_endpoint___41 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___41 *local_fwnode;
};

struct fwnode_reference_args___41 {
	struct fwnode_handle___41 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct reserved_mem_ops;

struct reserved_mem {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops {
	int (*device_init)(struct reserved_mem *, struct device___41 *);
	void (*device_release)(struct reserved_mem *, struct device___41 *);
};

typedef int (*reservedmem_of_init_fn)(struct reserved_mem *);

struct dma_coherent_mem {
	void *virt_base;
	dma_addr_t device_base;
	long unsigned int pfn_base;
	int size;
	long unsigned int *bitmap;
	spinlock_t spinlock;
	bool use_dev_dma_pfn_offset;
};

struct reserved_mem_ops___2;

struct reserved_mem___2 {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops___2 *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops___2 {
	int (*device_init)(struct reserved_mem___2 *, struct device___40 *);
	void (*device_release)(struct reserved_mem___2 *, struct device___40 *);
};

typedef int (*reservedmem_of_init_fn___2)(struct reserved_mem___2 *);

struct dentry___43;

struct super_block___43;

struct module___44;

struct file_system_type___42 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___43 * (*mount)(struct file_system_type___42 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___43 *);
	struct module___44 *owner;
	struct file_system_type___42 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___43;

struct kiocb___42;

struct poll_table_struct___34;

struct vm_area_struct___46;

struct inode___43;

struct file_lock___42;

struct page___46;

struct seq_file___42;

struct file_operations___42 {
	struct module___44 *owner;
	loff_t (*llseek)(struct file___43 *, loff_t, int);
	ssize_t (*read)(struct file___43 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___43 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___42 *, struct iov_iter___24 *);
	ssize_t (*write_iter)(struct kiocb___42 *, struct iov_iter___24 *);
	int (*iopoll)(struct kiocb___42 *, bool);
	int (*iterate)(struct file___43 *, struct dir_context *);
	int (*iterate_shared)(struct file___43 *, struct dir_context *);
	__poll_t (*poll)(struct file___43 *, struct poll_table_struct___34 *);
	long int (*unlocked_ioctl)(struct file___43 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___43 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___43 *, struct vm_area_struct___46 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___43 *, struct file___43 *);
	int (*flush)(struct file___43 *, fl_owner_t);
	int (*release)(struct inode___43 *, struct file___43 *);
	int (*fsync)(struct file___43 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___43 *, int);
	int (*lock)(struct file___43 *, int, struct file_lock___42 *);
	ssize_t (*sendpage)(struct file___43 *, struct page___46 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___43 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___43 *, long unsigned int);
	int (*flock)(struct file___43 *, int, struct file_lock___42 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___43 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___43 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___43 *, long int, struct file_lock___42 **, void **);
	long int (*fallocate)(struct file___43 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___42 *, struct file___43 *);
	ssize_t (*copy_file_range)(struct file___43 *, loff_t, struct file___43 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___43 *, loff_t, struct file___43 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___43 *, loff_t, loff_t, int);
};

struct vmacache___46 {
	u64 seqnum;
	struct vm_area_struct___46 *vmas[4];
};

struct page_frag___46 {
	struct page___46 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___31;

struct debug_info___31 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___31 *hbp_break[16];
	struct perf_event___31 *hbp_watch[16];
};

struct thread_struct___31 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___31 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___47;

struct pid___41;

struct nsproxy___42;

struct signal_struct___43;

struct css_set___35;

struct perf_event_context___31;

struct vm_struct___45;

struct task_struct___47 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___47 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___47 *mm;
	struct mm_struct___47 *active_mm;
	struct vmacache___46 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___47 *real_parent;
	struct task_struct___47 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___47 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___41 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___42 *nsproxy;
	struct signal_struct___43 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___47 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___22 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___35 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___31 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___46 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___47 *oom_reaper_list;
	struct vm_struct___45 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___31 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___45;

struct kobj_type___45;

struct kernfs_node___45;

struct kobject___45 {
	const char *name;
	struct list_head entry;
	struct kobject___45 *parent;
	struct kset___45 *kset;
	struct kobj_type___45 *ktype;
	struct kernfs_node___45 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___42 {
	struct kobject___45 kobj;
	struct module___44 *mod;
	struct kobject___45 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___42 {
	struct module___44 *mod;
	struct latch_tree_node node;
};

struct module_layout___42 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___42 mtn;
};

struct module_attribute___42;

struct kernel_param___42;

struct trace_event_call___26;

struct module___44 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___42 mkobj;
	struct module_attribute___42 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___45 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___42 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___42 core_layout;
	struct module_layout___42 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___26 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___31 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___47 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___31)(struct perf_event___31 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___31;

struct fasync_struct___42;

struct pid_namespace___41;

struct perf_cgroup___31;

struct perf_event___31 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___31 *group_leader;
	struct pmu___31 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___31 hw;
	struct perf_event_context___31 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___31 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___47 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___42 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___31 *aux_event;
	void (*destroy)(struct perf_event___31 *);
	struct callback_head callback_head;
	struct pid_namespace___41 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___31 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___31 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___26 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___31 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___41 {
	int nr;
	struct pid_namespace___41 *ns;
};

struct pid_namespace___41 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___47 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___41 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___41 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___41 numbers[1];
};

typedef struct page___46 *pgtable_t___46;

struct address_space___42;

struct dev_pagemap___42;

struct page___46 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___42 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___46 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___46 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___47 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___42 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___42;

struct vm_area_struct___46 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___46 *vm_next;
	struct vm_area_struct___46 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___47 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___42 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___43 *vm_file;
	struct file___43 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___43 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___47 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___47 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___41 *pids[4];
	struct pid___41 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___47 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___46;

struct mm_struct___47 {
	struct {
		struct vm_area_struct___46 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___43 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___46 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___47 *owner;
		struct user_namespace___4 *user_ns;
		struct file___43 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___35;

struct nsproxy___42 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___41 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___35 *cgroup_ns;
};

struct cgroup_subsys_state___35;

struct cgroup___35;

struct css_set___35 {
	struct cgroup_subsys_state___35 *subsys[14];
	refcount_t refcount;
	struct css_set___35 *dom_cset;
	struct cgroup___35 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___35 *mg_src_cgrp;
	struct cgroup___35 *mg_dst_cgrp;
	struct css_set___35 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___31 {
	struct pmu___31 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___47 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___31 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___45 {
	struct vm_struct___45 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___46 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___42;

struct address_space___42 {
	struct inode___43 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___42 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___42;

struct dev_pagemap___42 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___42 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___42;

struct path___42 {
	struct vfsmount___42 *mnt;
	struct dentry___43 *dentry;
};

struct fown_struct___41 {
	rwlock_t lock;
	struct pid___41 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___43 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___42 f_path;
	struct inode___43 *f_inode;
	const struct file_operations___42 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___41 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___42 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___42;

struct vm_operations_struct___42 {
	void (*open)(struct vm_area_struct___46 *);
	void (*close)(struct vm_area_struct___46 *);
	int (*may_split)(struct vm_area_struct___46 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___46 *);
	int (*mprotect)(struct vm_area_struct___46 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___42 *);
	vm_fault_t (*huge_fault)(struct vm_fault___42 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___42 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___46 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___42 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___42 *);
	int (*access)(struct vm_area_struct___46 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___46 *);
	int (*set_policy)(struct vm_area_struct___46 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___46 *, long unsigned int);
	struct page___46 * (*find_special_page)(struct vm_area_struct___46 *, long unsigned int);
};

struct core_thread___46 {
	struct task_struct___47 *task;
	struct core_thread___46 *next;
};

struct core_state___46 {
	atomic_t nr_threads;
	struct core_thread___46 dumper;
	struct completion startup;
};

struct vm_fault___42 {
	const struct {
		struct vm_area_struct___46 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___46 *cow_page;
	struct page___46 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___46 prealloc_pte;
};

struct kernfs_root___45;

struct kernfs_elem_dir___45 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___45 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___45;

struct kernfs_root___45 {
	struct kernfs_node___45 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___45 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___45 {
	struct kernfs_node___45 *target_kn;
};

struct kernfs_ops___45;

struct kernfs_elem_attr___45 {
	const struct kernfs_ops___45 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___45 *notify_next;
};

struct kernfs_node___45 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___45 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___45 dir;
		struct kernfs_elem_symlink___45 symlink;
		struct kernfs_elem_attr___45 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___45;

struct kernfs_ops___45 {
	int (*open)(struct kernfs_open_file___45 *);
	void (*release)(struct kernfs_open_file___45 *);
	int (*seq_show)(struct seq_file___42 *, void *);
	void * (*seq_start)(struct seq_file___42 *, loff_t *);
	void * (*seq_next)(struct seq_file___42 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___42 *, void *);
	ssize_t (*read)(struct kernfs_open_file___45 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___45 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___45 *, struct poll_table_struct___34 *);
	int (*mmap)(struct kernfs_open_file___45 *, struct vm_area_struct___46 *);
};

struct kernfs_syscall_ops___45 {
	int (*show_options)(struct seq_file___42 *, struct kernfs_root___45 *);
	int (*mkdir)(struct kernfs_node___45 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___45 *);
	int (*rename)(struct kernfs_node___45 *, struct kernfs_node___45 *, const char *);
	int (*show_path)(struct seq_file___42 *, struct kernfs_node___45 *, struct kernfs_root___45 *);
};

struct seq_operations___41;

struct seq_file___42 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___41 *op;
	int poll_event;
	const struct file___43 *file;
	void *private;
};

struct kernfs_open_file___45 {
	struct kernfs_node___45 *kn;
	struct file___43 *file;
	struct seq_file___42 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___42 *vm_ops;
};

typedef void (*poll_queue_proc___34)(struct file___43 *, wait_queue_head_t *, struct poll_table_struct___34 *);

struct poll_table_struct___34 {
	poll_queue_proc___34 _qproc;
	__poll_t _key;
};

struct bin_attribute___45;

struct attribute_group___45 {
	const char *name;
	umode_t (*is_visible)(struct kobject___45 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___45 *, struct bin_attribute___45 *, int);
	struct attribute **attrs;
	struct bin_attribute___45 **bin_attrs;
};

struct bin_attribute___45 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___42 * (*f_mapping)();
	ssize_t (*read)(struct file___43 *, struct kobject___45 *, struct bin_attribute___45 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___43 *, struct kobject___45 *, struct bin_attribute___45 *, char *, loff_t, size_t);
	int (*mmap)(struct file___43 *, struct kobject___45 *, struct bin_attribute___45 *, struct vm_area_struct___46 *);
};

struct sysfs_ops___45 {
	ssize_t (*show)(struct kobject___45 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___45 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___45;

struct kset___45 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___45 kobj;
	const struct kset_uevent_ops___45 *uevent_ops;
};

struct kobj_type___45 {
	void (*release)(struct kobject___45 *);
	const struct sysfs_ops___45 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___45 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___45 *);
	const void * (*namespace)(struct kobject___45 *);
	void (*get_ownership)(struct kobject___45 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___45 {
	int (* const filter)(struct kset___45 *, struct kobject___45 *);
	const char * (* const name)(struct kset___45 *, struct kobject___45 *);
	int (* const uevent)(struct kset___45 *, struct kobject___45 *, struct kobj_uevent_env *);
};

struct wakeup_source___42;

struct device___42;

struct dev_pm_info___42 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___42 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___42 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___42;

struct bus_type___42;

struct device_driver___42;

struct dev_pm_domain___42;

struct dma_map_ops___4;

struct io_tlb_mem___3;

struct device_node___27;

struct fwnode_handle___42;

struct class___42;

struct device___42 {
	struct kobject___45 kobj;
	struct device___42 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___42 *type;
	struct bus_type___42 *bus;
	struct device_driver___42 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___42 power;
	struct dev_pm_domain___42 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___4 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem___3 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___27 *of_node;
	struct fwnode_handle___42 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___42 *class;
	const struct attribute_group___45 **groups;
	void (*release)(struct device___42 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___42 {
	int (*prepare)(struct device___42 *);
	void (*complete)(struct device___42 *);
	int (*suspend)(struct device___42 *);
	int (*resume)(struct device___42 *);
	int (*freeze)(struct device___42 *);
	int (*thaw)(struct device___42 *);
	int (*poweroff)(struct device___42 *);
	int (*restore)(struct device___42 *);
	int (*suspend_late)(struct device___42 *);
	int (*resume_early)(struct device___42 *);
	int (*freeze_late)(struct device___42 *);
	int (*thaw_early)(struct device___42 *);
	int (*poweroff_late)(struct device___42 *);
	int (*restore_early)(struct device___42 *);
	int (*suspend_noirq)(struct device___42 *);
	int (*resume_noirq)(struct device___42 *);
	int (*freeze_noirq)(struct device___42 *);
	int (*thaw_noirq)(struct device___42 *);
	int (*poweroff_noirq)(struct device___42 *);
	int (*restore_noirq)(struct device___42 *);
	int (*runtime_suspend)(struct device___42 *);
	int (*runtime_resume)(struct device___42 *);
	int (*runtime_idle)(struct device___42 *);
};

struct wakeup_source___42 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___42 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___42 {
	struct dev_pm_ops___42 ops;
	int (*start)(struct device___42 *);
	void (*detach)(struct device___42 *, bool);
	int (*activate)(struct device___42 *);
	void (*sync)(struct device___42 *);
	void (*dismiss)(struct device___42 *);
};

struct bus_type___42 {
	const char *name;
	const char *dev_name;
	struct device___42 *dev_root;
	const struct attribute_group___45 **bus_groups;
	const struct attribute_group___45 **dev_groups;
	const struct attribute_group___45 **drv_groups;
	int (*match)(struct device___42 *, struct device_driver___42 *);
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	int (*probe)(struct device___42 *);
	void (*sync_state)(struct device___42 *);
	void (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*online)(struct device___42 *);
	int (*offline)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	int (*num_vf)(struct device___42 *);
	int (*dma_configure)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___42 {
	const char *name;
	struct bus_type___42 *bus;
	struct module___44 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___42 *);
	void (*sync_state)(struct device___42 *);
	int (*remove)(struct device___42 *);
	void (*shutdown)(struct device___42 *);
	int (*suspend)(struct device___42 *, pm_message_t);
	int (*resume)(struct device___42 *);
	const struct attribute_group___45 **groups;
	const struct attribute_group___45 **dev_groups;
	const struct dev_pm_ops___42 *pm;
	void (*coredump)(struct device___42 *);
	struct driver_private *p;
};

struct device_type___42 {
	const char *name;
	const struct attribute_group___45 **groups;
	int (*uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___42 *);
	const struct dev_pm_ops___42 *pm;
};

struct class___42 {
	const char *name;
	struct module___44 *owner;
	const struct attribute_group___45 **class_groups;
	const struct attribute_group___45 **dev_groups;
	struct kobject___45 *dev_kobj;
	int (*dev_uevent)(struct device___42 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___42 *, umode_t *);
	void (*class_release)(struct class___42 *);
	void (*dev_release)(struct device___42 *);
	int (*shutdown_pre)(struct device___42 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___42 *);
	void (*get_ownership)(struct device___42 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___42 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___4 {
	void * (*alloc)(struct device___42 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___42 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___46 * (*alloc_pages)(struct device___42 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___42 *, size_t, struct page___46 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___42 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___42 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___42 *, struct vm_area_struct___46 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___42 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___42 *, struct page___46 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___42 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___42 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___42 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___42 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___42 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___42 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___42 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___42 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___42 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___42 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___42 *, u64);
	u64 (*get_required_mask)(struct device___42 *);
	size_t (*max_mapping_size)(struct device___42 *);
	long unsigned int (*get_merge_boundary)(struct device___42 *);
};

struct io_tlb_mem___3 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___43 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct fwnode_operations___42;

struct fwnode_handle___42 {
	struct fwnode_handle___42 *secondary;
	const struct fwnode_operations___42 *ops;
	struct device___42 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___23;

struct device_node___27 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___42 fwnode;
	struct property___23 *properties;
	struct property___23 *deadprops;
	struct device_node___27 *parent;
	struct device_node___27 *child;
	struct device_node___27 *sibling;
	struct kobject___45 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___42 {
	void (*page_free)(struct page___46 *);
	void (*kill)(struct dev_pagemap___42 *);
	void (*cleanup)(struct dev_pagemap___42 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___42 *);
};

struct dentry_operations___42;

struct dentry___43 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___43 *d_parent;
	struct qstr d_name;
	struct inode___43 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___42 *d_op;
	struct super_block___43 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___42;

struct inode___43 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___42 *i_op;
	struct super_block___43 *i_sb;
	struct address_space___42 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___42 *i_fop;
		void (*free_inode)(struct inode___43 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___42 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___17 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___42 {
	int (*d_revalidate)(struct dentry___43 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___43 *, unsigned int);
	int (*d_hash)(const struct dentry___43 *, struct qstr *);
	int (*d_compare)(const struct dentry___43 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___43 *);
	int (*d_init)(struct dentry___43 *);
	void (*d_release)(struct dentry___43 *);
	void (*d_prune)(struct dentry___43 *);
	void (*d_iput)(struct dentry___43 *, struct inode___43 *);
	char * (*d_dname)(struct dentry___43 *, char *, int);
	struct vfsmount___42 * (*d_automount)(struct path___42 *);
	int (*d_manage)(const struct path___42 *, bool);
	struct dentry___43 * (*d_real)(struct dentry___43 *, const struct inode___43 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___42;

struct mem_dqinfo___42 {
	struct quota_format_type___42 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___42;

struct quota_info___42 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___43 *files[3];
	struct mem_dqinfo___42 info[3];
	const struct quota_format_ops___42 *ops[3];
};

struct rcuwait___43 {
	struct task_struct___47 *task;
};

struct percpu_rw_semaphore___43 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___43 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___42 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___43 rw_sem[3];
};

struct super_operations___42;

struct dquot_operations___42;

struct quotactl_ops___42;

struct super_block___43 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___42 *s_type;
	const struct super_operations___42 *s_op;
	const struct dquot_operations___42 *dq_op;
	const struct quotactl_ops___42 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___43 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___42 s_dquot;
	struct sb_writers___42 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___42 *s_d_op;
	int cleancache_poolid;
	struct shrinker___20 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___42 {
	struct dentry___43 *mnt_root;
	struct super_block___43 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct cgroup_subsys___35;

struct cgroup_subsys_state___35 {
	struct cgroup___35 *cgroup;
	struct cgroup_subsys___35 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___35 *parent;
};

struct cgroup_file___35 {
	struct kernfs_node___45 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___35 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___47 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___35;

struct cgroup_rstat_cpu___35;

struct cgroup___35 {
	struct cgroup_subsys_state___35 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___45 *kn;
	struct cgroup_file___35 procs_file;
	struct cgroup_file___35 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___35 *subsys[14];
	struct cgroup_root___35 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___35 *dom_cgrp;
	struct cgroup___35 *old_dom_cgrp;
	struct cgroup_rstat_cpu___35 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___35 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___42 {
	struct file___43 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___42 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___22 *ki_waitq;
	};
};

struct iattr___43 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___43 *ia_file;
};

struct dquot___42 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___43 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___42 {
	int qf_fmt_id;
	const struct quota_format_ops___42 *qf_ops;
	struct module___44 *qf_owner;
	struct quota_format_type___42 *qf_next;
};

struct quota_format_ops___42 {
	int (*check_quota_file)(struct super_block___43 *, int);
	int (*read_file_info)(struct super_block___43 *, int);
	int (*write_file_info)(struct super_block___43 *, int);
	int (*free_file_info)(struct super_block___43 *, int);
	int (*read_dqblk)(struct dquot___42 *);
	int (*commit_dqblk)(struct dquot___42 *);
	int (*release_dqblk)(struct dquot___42 *);
	int (*get_next_id)(struct super_block___43 *, struct kqid *);
};

struct dquot_operations___42 {
	int (*write_dquot)(struct dquot___42 *);
	struct dquot___42 * (*alloc_dquot)(struct super_block___43 *, int);
	void (*destroy_dquot)(struct dquot___42 *);
	int (*acquire_dquot)(struct dquot___42 *);
	int (*release_dquot)(struct dquot___42 *);
	int (*mark_dirty)(struct dquot___42 *);
	int (*write_info)(struct super_block___43 *, int);
	qsize_t * (*get_reserved_space)(struct inode___43 *);
	int (*get_projid)(struct inode___43 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___43 *, qsize_t *);
	int (*get_next_id)(struct super_block___43 *, struct kqid *);
};

struct quotactl_ops___42 {
	int (*quota_on)(struct super_block___43 *, int, int, const struct path___42 *);
	int (*quota_off)(struct super_block___43 *, int);
	int (*quota_enable)(struct super_block___43 *, unsigned int);
	int (*quota_disable)(struct super_block___43 *, unsigned int);
	int (*quota_sync)(struct super_block___43 *, int);
	int (*set_info)(struct super_block___43 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___43 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___43 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___43 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___43 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___43 *, unsigned int);
};

struct address_space_operations___42 {
	int (*writepage)(struct page___46 *, struct writeback_control___3 *);
	int (*readpage)(struct file___43 *, struct page___46 *);
	int (*writepages)(struct address_space___42 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___46 *);
	int (*readpages)(struct file___43 *, struct address_space___42 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___43 *, struct address_space___42 *, loff_t, unsigned int, unsigned int, struct page___46 **, void **);
	int (*write_end)(struct file___43 *, struct address_space___42 *, loff_t, unsigned int, unsigned int, struct page___46 *, void *);
	sector_t (*bmap)(struct address_space___42 *, sector_t);
	void (*invalidatepage)(struct page___46 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___46 *, gfp_t);
	void (*freepage)(struct page___46 *);
	ssize_t (*direct_IO)(struct kiocb___42 *, struct iov_iter___24 *);
	int (*migratepage)(struct address_space___42 *, struct page___46 *, struct page___46 *, enum migrate_mode);
	bool (*isolate_page)(struct page___46 *, isolate_mode_t);
	void (*putback_page)(struct page___46 *);
	int (*launder_page)(struct page___46 *);
	int (*is_partially_uptodate)(struct page___46 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___46 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___42 *, struct page___46 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___43 *, sector_t *);
	void (*swap_deactivate)(struct file___43 *);
};

struct inode_operations___42 {
	struct dentry___43 * (*lookup)(struct inode___43 *, struct dentry___43 *, unsigned int);
	const char * (*get_link)(struct dentry___43 *, struct inode___43 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___43 *, int);
	struct posix_acl * (*get_acl)(struct inode___43 *, int, bool);
	int (*readlink)(struct dentry___43 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___43 *, struct dentry___43 *, umode_t, bool);
	int (*link)(struct dentry___43 *, struct inode___43 *, struct dentry___43 *);
	int (*unlink)(struct inode___43 *, struct dentry___43 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___43 *, struct dentry___43 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___43 *, struct dentry___43 *, umode_t);
	int (*rmdir)(struct inode___43 *, struct dentry___43 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___43 *, struct dentry___43 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___43 *, struct dentry___43 *, struct inode___43 *, struct dentry___43 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___43 *, struct iattr___43 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___42 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___43 *, char *, size_t);
	int (*fiemap)(struct inode___43 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___43 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___43 *, struct dentry___43 *, struct file___43 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___43 *, struct dentry___43 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___43 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___43 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___43 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___42 {
	void (*fl_copy_lock)(struct file_lock___42 *, struct file_lock___42 *);
	void (*fl_release_private)(struct file_lock___42 *);
};

struct lock_manager_operations___42;

struct file_lock___42 {
	struct file_lock___42 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___43 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___42 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___42 *fl_ops;
	const struct lock_manager_operations___42 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___42 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___42 *);
	int (*lm_grant)(struct file_lock___42 *, int);
	bool (*lm_break)(struct file_lock___42 *);
	int (*lm_change)(struct file_lock___42 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___42 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___42 *);
};

struct fasync_struct___42 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___42 *fa_next;
	struct file___43 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___42 {
	struct inode___43 * (*alloc_inode)(struct super_block___43 *);
	void (*destroy_inode)(struct inode___43 *);
	void (*free_inode)(struct inode___43 *);
	void (*dirty_inode)(struct inode___43 *, int);
	int (*write_inode)(struct inode___43 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___43 *);
	void (*evict_inode)(struct inode___43 *);
	void (*put_super)(struct super_block___43 *);
	int (*sync_fs)(struct super_block___43 *, int);
	int (*freeze_super)(struct super_block___43 *);
	int (*freeze_fs)(struct super_block___43 *);
	int (*thaw_super)(struct super_block___43 *);
	int (*unfreeze_fs)(struct super_block___43 *);
	int (*statfs)(struct dentry___43 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___43 *, int *, char *);
	void (*umount_begin)(struct super_block___43 *);
	int (*show_options)(struct seq_file___42 *, struct dentry___43 *);
	int (*show_devname)(struct seq_file___42 *, struct dentry___43 *);
	int (*show_path)(struct seq_file___42 *, struct dentry___43 *);
	int (*show_stats)(struct seq_file___42 *, struct dentry___43 *);
	ssize_t (*quota_read)(struct super_block___43 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___43 *, int, const char *, size_t, loff_t);
	struct dquot___42 ** (*get_dquots)(struct inode___43 *);
	long int (*nr_cached_objects)(struct super_block___43 *, struct shrink_control___20 *);
	long int (*free_cached_objects)(struct super_block___43 *, struct shrink_control___20 *);
	struct file___43 * (*real_loop)(struct file___43 *);
};

struct fwnode_reference_args___42;

struct fwnode_endpoint___42;

struct fwnode_operations___42 {
	struct fwnode_handle___42 * (*get)(struct fwnode_handle___42 *);
	void (*put)(struct fwnode_handle___42 *);
	bool (*device_is_available)(const struct fwnode_handle___42 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___42 *, const struct device___42 *);
	bool (*property_present)(const struct fwnode_handle___42 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___42 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___42 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___42 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*get_parent)(const struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*get_next_child_node)(const struct fwnode_handle___42 *, struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*get_named_child_node)(const struct fwnode_handle___42 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___42 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___42 *);
	struct fwnode_handle___42 * (*graph_get_next_endpoint)(const struct fwnode_handle___42 *, struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*graph_get_remote_endpoint)(const struct fwnode_handle___42 *);
	struct fwnode_handle___42 * (*graph_get_port_parent)(struct fwnode_handle___42 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___42 *, struct fwnode_endpoint___42 *);
	int (*add_links)(struct fwnode_handle___42 *);
};

struct fwnode_endpoint___42 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___42 *local_fwnode;
};

struct fwnode_reference_args___42 {
	struct fwnode_handle___42 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___42 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___42 *);
	int (*get)(char *, const struct kernel_param___42 *);
	void (*free)(void *);
};

struct kparam_array___42;

struct kernel_param___42 {
	const char *name;
	struct module___44 *mod;
	const struct kernel_param_ops___42 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___42 *arr;
	};
};

struct kparam_array___42 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___42 *ops;
	void *elem;
};

struct module_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___42 *, struct module_kobject___42 *, char *);
	ssize_t (*store)(struct module_attribute___42 *, struct module_kobject___42 *, const char *, size_t);
	void (*setup)(struct module___44 *, const char *);
	int (*test)(struct module___44 *);
	void (*free)(struct module___44 *);
};

struct trace_event_class___26;

struct trace_event_call___26 {
	struct list_head list;
	struct trace_event_class___26 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___26 *, struct perf_event___31 *);
};

struct cgroup_namespace___35 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___35 *root_cset;
};

struct seq_operations___41 {
	void * (*start)(struct seq_file___42 *, loff_t *);
	void (*stop)(struct seq_file___42 *, void *);
	void * (*next)(struct seq_file___42 *, void *, loff_t *);
	int (*show)(struct seq_file___42 *, void *);
};

struct property___23 {
	char *name;
	int length;
	void *value;
	struct property___23 *next;
	long unsigned int _flags;
	struct bin_attribute___45 attr;
};

struct reserved_mem_ops___3;

struct reserved_mem___3 {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops___3 *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops___3 {
	int (*device_init)(struct reserved_mem___3 *, struct device___42 *);
	void (*device_release)(struct reserved_mem___3 *, struct device___42 *);
};

typedef int (*reservedmem_of_init_fn___3)(struct reserved_mem___3 *);

struct cftype___35;

struct cgroup_subsys___35 {
	struct cgroup_subsys_state___35 * (*css_alloc)(struct cgroup_subsys_state___35 *);
	int (*css_online)(struct cgroup_subsys_state___35 *);
	void (*css_offline)(struct cgroup_subsys_state___35 *);
	void (*css_released)(struct cgroup_subsys_state___35 *);
	void (*css_free)(struct cgroup_subsys_state___35 *);
	void (*css_reset)(struct cgroup_subsys_state___35 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___35 *, int);
	int (*css_extra_stat_show)(struct seq_file___42 *, struct cgroup_subsys_state___35 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___47 *, struct css_set___35 *);
	void (*cancel_fork)(struct task_struct___47 *, struct css_set___35 *);
	void (*fork)(struct task_struct___47 *);
	void (*exit)(struct task_struct___47 *);
	void (*release)(struct task_struct___47 *);
	void (*bind)(struct cgroup_subsys_state___35 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___35 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___35 *dfl_cftypes;
	struct cftype___35 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___35 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___35 *updated_children;
	struct cgroup___35 *updated_next;
};

struct cgroup_root___35 {
	struct kernfs_root___45 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___35 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___35 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___35 *ss;
	struct list_head node;
	struct kernfs_ops___45 *kf_ops;
	int (*open)(struct kernfs_open_file___45 *);
	void (*release)(struct kernfs_open_file___45 *);
	u64 (*read_u64)(struct cgroup_subsys_state___35 *, struct cftype___35 *);
	s64 (*read_s64)(struct cgroup_subsys_state___35 *, struct cftype___35 *);
	int (*seq_show)(struct seq_file___42 *, void *);
	void * (*seq_start)(struct seq_file___42 *, loff_t *);
	void * (*seq_next)(struct seq_file___42 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___42 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___35 *, struct cftype___35 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___35 *, struct cftype___35 *, s64);
	ssize_t (*write)(struct kernfs_open_file___45 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___45 *, struct poll_table_struct___34 *);
};

struct perf_cpu_context___31;

struct perf_output_handle___31;

struct pmu___31 {
	struct list_head entry;
	struct module___44 *module;
	struct device___42 *dev;
	const struct attribute_group___45 **attr_groups;
	const struct attribute_group___45 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___31 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___31 *);
	void (*pmu_disable)(struct pmu___31 *);
	int (*event_init)(struct perf_event___31 *);
	void (*event_mapped)(struct perf_event___31 *, struct mm_struct___47 *);
	void (*event_unmapped)(struct perf_event___31 *, struct mm_struct___47 *);
	int (*add)(struct perf_event___31 *, int);
	void (*del)(struct perf_event___31 *, int);
	void (*start)(struct perf_event___31 *, int);
	void (*stop)(struct perf_event___31 *, int);
	void (*read)(struct perf_event___31 *);
	void (*start_txn)(struct pmu___31 *, unsigned int);
	int (*commit_txn)(struct pmu___31 *);
	void (*cancel_txn)(struct pmu___31 *);
	int (*event_idx)(struct perf_event___31 *);
	void (*sched_task)(struct perf_event_context___31 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___31 *, struct perf_event_context___31 *);
	void * (*setup_aux)(struct perf_event___31 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___31 *, struct perf_output_handle___31 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___31 *);
	int (*aux_output_match)(struct perf_event___31 *);
	int (*filter_match)(struct perf_event___31 *);
	int (*check_period)(struct perf_event___31 *, u64);
};

struct perf_cpu_context___31 {
	struct perf_event_context___31 ctx;
	struct perf_event_context___31 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___31 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___31 **heap;
	struct perf_event___31 *heap_default[2];
};

struct perf_output_handle___31 {
	struct perf_event___31 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___31 {
	struct cgroup_subsys_state___35 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___26 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___26 *);
	};
};

struct trace_event_class___26 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___26 *, enum trace_reg, void *);
	struct trace_event_fields___26 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___26 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___26 *);
};

struct trace_event_file___11;

struct trace_event_buffer___11 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___11 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___11 {
	struct list_head list;
	struct trace_event_call___26 *event_call;
	struct event_filter *filter;
	struct dentry___43 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_swiotlb_bounced {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	u64 dma_mask;
	dma_addr_t dev_addr;
	size_t size;
	enum swiotlb_force swiotlb_force;
	char __data[0];
};

struct trace_event_data_offsets_swiotlb_bounced {
	u32 dev_name;
};

typedef void (*btf_trace_swiotlb_bounced)(void *, struct device___42 *, dma_addr_t, size_t, enum swiotlb_force);

struct gen_pool;

typedef long unsigned int (*genpool_algo_t)(long unsigned int *, long unsigned int, long unsigned int, unsigned int, void *, struct gen_pool *, long unsigned int);

struct gen_pool {
	spinlock_t lock;
	struct list_head chunks;
	int min_alloc_order;
	genpool_algo_t algo;
	void *data;
	const char *name;
};

struct preempt_notifier___7;

struct preempt_ops___7 {
	void (*sched_in)(struct preempt_notifier___7 *, int);
	void (*sched_out)(struct preempt_notifier___7 *, struct task_struct___46 *);
};

struct preempt_notifier___7 {
	struct hlist_node link;
	struct preempt_ops___7 *ops;
};

struct mmu_notifier___6;

struct mmu_notifier_range___6;

struct mmu_notifier_ops___6 {
	void (*release)(struct mmu_notifier___6 *, struct mm_struct___46 *);
	int (*clear_flush_young)(struct mmu_notifier___6 *, struct mm_struct___46 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___6 *, struct mm_struct___46 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___6 *, struct mm_struct___46 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___6 *, struct mm_struct___46 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___6 *, const struct mmu_notifier_range___6 *);
	void (*invalidate_range_end)(struct mmu_notifier___6 *, const struct mmu_notifier_range___6 *);
	void (*invalidate_range)(struct mmu_notifier___6 *, struct mm_struct___46 *, long unsigned int, long unsigned int);
	struct mmu_notifier___6 * (*alloc_notifier)(struct mm_struct___46 *);
	void (*free_notifier)(struct mmu_notifier___6 *);
};

struct mmu_notifier___6 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___6 *ops;
	struct mm_struct___46 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___6 {
	struct vm_area_struct___45 *vma;
	struct mm_struct___46 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct kvm_vcpu___10;

struct kvm_io_device___10;

struct kvm_io_device_ops___10 {
	int (*read)(struct kvm_vcpu___10 *, struct kvm_io_device___10 *, gpa_t, int, void *);
	int (*write)(struct kvm_vcpu___10 *, struct kvm_io_device___10 *, gpa_t, int, const void *);
	void (*destructor)(struct kvm_io_device___10 *);
};

struct kvm_cpu_context___10 {
	struct user_pt_regs regs;
	u64 spsr_abt;
	u64 spsr_und;
	u64 spsr_irq;
	u64 spsr_fiq;
	struct user_fpsimd_state fp_regs;
	u64 sys_regs[122];
	struct kvm_vcpu___10 *__hyp_running_vcpu;
	long: 64;
};

struct its_vm___6;

struct its_vpe___6 {
	struct page___45 *vpt_page;
	struct its_vm___6 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___40 *fwnode;
			struct irq_domain___2 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct vgic_v3_cpu_if___6 {
	u32 vgic_hcr;
	u32 vgic_vmcr;
	u32 vgic_sre;
	u32 vgic_ap0r[4];
	u32 vgic_ap1r[4];
	u64 vgic_lr[16];
	struct its_vpe___6 its_vpe;
	unsigned int used_lrs;
};

struct vgic_irq___10 {
	raw_spinlock_t irq_lock;
	struct list_head lpi_list;
	struct list_head ap_list;
	struct kvm_vcpu___10 *vcpu;
	struct kvm_vcpu___10 *target_vcpu;
	u32 intid;
	bool line_level;
	bool pending_latch;
	bool active;
	bool enabled;
	bool hw;
	struct kref refcount;
	u32 hwintid;
	unsigned int host_irq;
	union {
		u8 targets;
		u32 mpidr;
	};
	u8 source;
	u8 active_source;
	u8 priority;
	u8 group;
	enum vgic_irq_config config;
	struct irq_ops *ops;
	void *owner;
};

struct kvm_io_device___10 {
	const struct kvm_io_device_ops___10 *ops;
};

struct vgic_its___10;

struct vgic_io_device___10 {
	gpa_t base_addr;
	union {
		struct kvm_vcpu___10 *redist_vcpu;
		struct vgic_its___10 *its;
	};
	const struct vgic_register_region *regions;
	enum iodev_type iodev_type;
	int nr_regions;
	struct kvm_io_device___10 dev;
};

struct vgic_cpu___10 {
	union {
		struct vgic_v2_cpu_if vgic_v2;
		struct vgic_v3_cpu_if___6 vgic_v3;
	};
	struct vgic_irq___10 private_irqs[32];
	raw_spinlock_t ap_list_lock;
	struct list_head ap_list_head;
	struct vgic_io_device___10 rd_iodev;
	struct vgic_redist_region *rdreg;
	u32 rdreg_index;
	u64 pendbaser;
	bool lpis_enabled;
	u32 num_pri_bits;
	u32 num_id_bits;
};

struct arch_timer_context___10 {
	struct kvm_vcpu___10 *vcpu;
	struct kvm_irq_level irq;
	struct hrtimer hrtimer;
	bool loaded;
	u32 host_timer_irq;
	u32 host_timer_irq_flags;
};

struct arch_timer_cpu___10 {
	struct arch_timer_context___10 timers[2];
	struct hrtimer bg_timer;
	bool enabled;
};

struct kvm_pmc___6 {
	u8 idx;
	struct perf_event___30 *perf_event;
};

struct kvm_pmu___6 {
	int irq_num;
	struct kvm_pmc___6 pmc[32];
	long unsigned int chained[1];
	bool created;
	bool irq_level;
	struct irq_work overflow_work;
};

struct kvm_s2_mmu___10;

struct kvm_vcpu_arch___10 {
	struct kvm_cpu_context___10 ctxt;
	void *sve_state;
	unsigned int sve_max_vl;
	struct kvm_s2_mmu___10 *hw_mmu;
	u64 hcr_el2;
	u64 mdcr_el2;
	u64 cptr_el2;
	u64 mdcr_el2_host;
	struct kvm_vcpu_fault_info fault;
	u64 workaround_flags;
	u64 flags;
	struct kvm_guest_debug_arch *debug_ptr;
	struct kvm_guest_debug_arch vcpu_debug_state;
	struct kvm_guest_debug_arch external_debug_state;
	struct thread_info *host_thread_info;
	struct user_fpsimd_state *host_fpsimd_state;
	struct {
		struct kvm_guest_debug_arch regs;
		u64 pmscr_el1;
		u64 trfcr_el1;
	} host_debug_state;
	struct vgic_cpu___10 vgic_cpu;
	struct arch_timer_cpu___10 timer_cpu;
	struct kvm_pmu___6 pmu;
	struct {
		u32 mdscr_el1;
	} guest_debug_preserved;
	bool power_off;
	bool pause;
	struct kvm_mmu_memory_cache mmu_page_cache;
	int target;
	long unsigned int features[1];
	bool has_run_once;
	u64 vsesr_el2;
	struct vcpu_reset_state reset_state;
	bool sysregs_loaded_on_cpu;
	struct {
		u64 last_steal;
		gpa_t base;
	} steal;
};

struct kvm___10;

struct kvm_vcpu___10 {
	struct kvm___10 *kvm;
	struct preempt_notifier___7 preempt_notifier;
	int cpu;
	int vcpu_id;
	int vcpu_idx;
	int srcu_idx;
	int mode;
	u64 requests;
	long unsigned int guest_debug;
	int pre_pcpu;
	struct list_head blocked_vcpu_list;
	struct mutex mutex;
	struct kvm_run *run;
	struct rcuwait___42 wait;
	struct pid___40 *pid;
	int sigset_active;
	sigset_t sigset;
	unsigned int halt_poll_ns;
	bool valid_wakeup;
	int mmio_needed;
	int mmio_read_completed;
	int mmio_is_write;
	int mmio_cur_fragment;
	int mmio_nr_fragments;
	struct kvm_mmio_fragment mmio_fragments[2];
	struct {
		bool in_spin_loop;
		bool dy_eligible;
	} spin_loop;
	bool preempted;
	bool ready;
	struct kvm_vcpu_arch___10 arch;
	struct kvm_vcpu_stat stat;
	char stats_id[48];
	struct kvm_dirty_ring dirty_ring;
	int last_used_slot;
	long: 32;
	long: 64;
};

struct its_vm___6 {
	struct fwnode_handle___40 *fwnode;
	struct irq_domain___2 *domain;
	struct page___45 *vprop_page;
	struct its_vpe___6 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct kvm_device___10;

struct vgic_its___10 {
	gpa_t vgic_its_base;
	bool enabled;
	struct vgic_io_device___10 iodev;
	struct kvm_device___10 *dev;
	u64 baser_device_table;
	u64 baser_coll_table;
	struct mutex cmd_lock;
	u64 cbaser;
	u32 creadr;
	u32 cwriter;
	u32 abi_rev;
	struct mutex its_lock;
	struct list_head device_list;
	struct list_head collection_list;
};

struct kvm_device_ops___10;

struct kvm_device___10 {
	const struct kvm_device_ops___10 *ops;
	struct kvm___10 *kvm;
	void *private;
	struct list_head vm_node;
};

struct vgic_dist___10 {
	bool in_kernel;
	bool ready;
	bool initialized;
	u32 vgic_model;
	u32 implementation_rev;
	bool v2_groups_user_writable;
	bool msis_require_devid;
	int nr_spis;
	gpa_t vgic_dist_base;
	union {
		gpa_t vgic_cpu_base;
		struct list_head rd_regions;
	};
	bool enabled;
	bool nassgireq;
	struct vgic_irq___10 *spis;
	struct vgic_io_device___10 dist_iodev;
	bool has_its;
	u64 propbaser;
	raw_spinlock_t lpi_list_lock;
	struct list_head lpi_list_head;
	int lpi_list_count;
	struct list_head lpi_translation_cache;
	struct vgic_state_iter *iter;
	struct its_vm___6 its_vm;
};

struct kvm_arch___10;

struct kvm_s2_mmu___10 {
	struct kvm_vmid vmid;
	phys_addr_t pgd_phys;
	struct kvm_pgtable *pgt;
	int *last_vcpu_ran;
	struct kvm_arch___10 *arch;
};

struct kvm_arch___10 {
	struct kvm_s2_mmu___10 mmu;
	u64 vtcr;
	int max_vcpus;
	struct vgic_dist___10 vgic;
	u32 psci_version;
	bool return_nisv_io_abort_to_user;
	long unsigned int *pmu_filter;
	unsigned int pmuver;
	u8 pfr0_csv2;
	u8 pfr0_csv3;
	bool mte_enabled;
};

struct kvm_io_range___10 {
	gpa_t addr;
	int len;
	struct kvm_io_device___10 *dev;
};

struct kvm_io_bus___10 {
	int dev_count;
	int ioeventfd_count;
	struct kvm_io_range___10 range[0];
};

struct kvm_stat_data___10;

struct kvm___10 {
	spinlock_t mmu_lock;
	struct mutex slots_lock;
	struct mutex slots_arch_lock;
	struct mm_struct___46 *mm;
	struct kvm_memslots *memslots[1];
	struct kvm_vcpu___10 *vcpus[512];
	spinlock_t mn_invalidate_lock;
	long unsigned int mn_active_invalidate_count;
	struct rcuwait___42 mn_memslots_update_rcuwait;
	atomic_t online_vcpus;
	int created_vcpus;
	int last_boosted_vcpu;
	struct list_head vm_list;
	struct mutex lock;
	struct kvm_io_bus___10 *buses[4];
	struct {
		spinlock_t lock;
		struct list_head items;
		struct list_head resampler_list;
		struct mutex resampler_lock;
	} irqfds;
	struct list_head ioeventfds;
	struct kvm_vm_stat stat;
	struct kvm_arch___10 arch;
	refcount_t users_count;
	struct kvm_coalesced_mmio_ring *coalesced_mmio_ring;
	spinlock_t ring_lock;
	struct list_head coalesced_zones;
	struct mutex irq_lock;
	struct kvm_irq_routing_table *irq_routing;
	struct hlist_head irq_ack_notifier_list;
	struct mmu_notifier___6 mmu_notifier;
	long unsigned int mmu_notifier_seq;
	long int mmu_notifier_count;
	long unsigned int mmu_notifier_range_start;
	long unsigned int mmu_notifier_range_end;
	struct list_head devices;
	u64 manual_dirty_log_protect;
	struct dentry___42 *debugfs_dentry;
	struct kvm_stat_data___10 **debugfs_stat_data;
	struct srcu_struct srcu;
	struct srcu_struct irq_srcu;
	pid_t userspace_pid;
	unsigned int max_halt_poll_ns;
	u32 dirty_ring_size;
	bool vm_bugged;
	char stats_id[48];
};

struct kvm_stat_data___10 {
	struct kvm___10 *kvm;
	const struct _kvm_stats_desc *desc;
	enum kvm_stat_kind kind;
};

struct kvm_device_ops___10 {
	const char *name;
	int (*create)(struct kvm_device___10 *, u32);
	void (*init)(struct kvm_device___10 *);
	void (*destroy)(struct kvm_device___10 *);
	void (*release)(struct kvm_device___10 *);
	int (*set_attr)(struct kvm_device___10 *, struct kvm_device_attr *);
	int (*get_attr)(struct kvm_device___10 *, struct kvm_device_attr *);
	int (*has_attr)(struct kvm_device___10 *, struct kvm_device_attr *);
	long int (*ioctl)(struct kvm_device___10 *, unsigned int, long unsigned int);
	int (*mmap)(struct kvm_device___10 *, struct vm_area_struct___45 *);
};

struct syscall_metadata___12 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___16 *enter_event;
	struct trace_event_call___16 *exit_event;
};

enum kcmp_type {
	KCMP_FILE = 0,
	KCMP_VM = 1,
	KCMP_FILES = 2,
	KCMP_FS = 3,
	KCMP_SIGHAND = 4,
	KCMP_IO = 5,
	KCMP_SYSVSEM = 6,
	KCMP_EPOLL_TFD = 7,
	KCMP_TYPES = 8,
};

struct kcmp_epoll_slot {
	__u32 efd;
	__u32 tfd;
	__u32 toff;
};

enum profile_type {
	PROFILE_TASK_EXIT = 0,
	PROFILE_MUNMAP = 1,
};

struct profile_hit {
	u32 pc;
	u32 hits;
};

struct proc_ops___3 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___35 *, struct file___35 *);
	ssize_t (*proc_read)(struct file___35 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___33 *, struct iov_iter___17 *);
	ssize_t (*proc_write)(struct file___35 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___35 *, loff_t, int);
	int (*proc_release)(struct inode___35 *, struct file___35 *);
	__poll_t (*proc_poll)(struct file___35 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___35 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___35 *, struct vm_area_struct___34 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___35 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct stacktrace_cookie {
	long unsigned int *store;
	unsigned int size;
	unsigned int skip;
	unsigned int len;
};

typedef __kernel_long_t __kernel_suseconds_t;

typedef __kernel_suseconds_t suseconds_t;

typedef __u64 timeu64_t;

struct __kernel_itimerspec {
	struct __kernel_timespec it_interval;
	struct __kernel_timespec it_value;
};

struct timezone {
	int tz_minuteswest;
	int tz_dsttime;
};

struct itimerspec64 {
	struct timespec64 it_interval;
	struct timespec64 it_value;
};

struct old_itimerspec32 {
	struct old_timespec32 it_interval;
	struct old_timespec32 it_value;
};

struct old_timex32 {
	u32 modes;
	s32 offset;
	s32 freq;
	s32 maxerror;
	s32 esterror;
	s32 status;
	s32 constant;
	s32 precision;
	s32 tolerance;
	struct old_timeval32 time;
	s32 tick;
	s32 ppsfreq;
	s32 jitter;
	s32 shift;
	s32 stabil;
	s32 jitcnt;
	s32 calcnt;
	s32 errcnt;
	s32 stbcnt;
	s32 tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct __kernel_timex_timeval {
	__kernel_time64_t tv_sec;
	long long int tv_usec;
};

struct __kernel_timex {
	unsigned int modes;
	long long int offset;
	long long int freq;
	long long int maxerror;
	long long int esterror;
	int status;
	long long int constant;
	long long int precision;
	long long int tolerance;
	struct __kernel_timex_timeval time;
	long long int tick;
	long long int ppsfreq;
	long long int jitter;
	int shift;
	long long int stabil;
	long long int jitcnt;
	long long int calcnt;
	long long int errcnt;
	long long int stbcnt;
	int tai;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_raw_timer_class {
	struct trace_entry ent;
	void *timer;
	char __data[0];
};

struct trace_event_raw_timer_start {
	struct trace_entry ent;
	void *timer;
	void *function;
	long unsigned int expires;
	long unsigned int now;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_timer_expire_entry {
	struct trace_entry ent;
	void *timer;
	long unsigned int now;
	void *function;
	long unsigned int baseclk;
	char __data[0];
};

struct trace_event_raw_hrtimer_init {
	struct trace_entry ent;
	void *hrtimer;
	clockid_t clockid;
	enum hrtimer_mode mode;
	char __data[0];
};

struct trace_event_raw_hrtimer_start {
	struct trace_entry ent;
	void *hrtimer;
	void *function;
	s64 expires;
	s64 softexpires;
	enum hrtimer_mode mode;
	char __data[0];
};

struct trace_event_raw_hrtimer_expire_entry {
	struct trace_entry ent;
	void *hrtimer;
	s64 now;
	void *function;
	char __data[0];
};

struct trace_event_raw_hrtimer_class {
	struct trace_entry ent;
	void *hrtimer;
	char __data[0];
};

struct trace_event_raw_itimer_state {
	struct trace_entry ent;
	int which;
	long long unsigned int expires;
	long int value_sec;
	long int value_nsec;
	long int interval_sec;
	long int interval_nsec;
	char __data[0];
};

struct trace_event_raw_itimer_expire {
	struct trace_entry ent;
	int which;
	pid_t pid;
	long long unsigned int now;
	char __data[0];
};

struct trace_event_raw_tick_stop {
	struct trace_entry ent;
	int success;
	int dependency;
	char __data[0];
};

struct trace_event_data_offsets_timer_class {};

struct trace_event_data_offsets_timer_start {};

struct trace_event_data_offsets_timer_expire_entry {};

struct trace_event_data_offsets_hrtimer_init {};

struct trace_event_data_offsets_hrtimer_start {};

struct trace_event_data_offsets_hrtimer_expire_entry {};

struct trace_event_data_offsets_hrtimer_class {};

struct trace_event_data_offsets_itimer_state {};

struct trace_event_data_offsets_itimer_expire {};

struct trace_event_data_offsets_tick_stop {};

typedef void (*btf_trace_timer_init)(void *, struct timer_list *);

typedef void (*btf_trace_timer_start)(void *, struct timer_list *, long unsigned int, unsigned int);

typedef void (*btf_trace_timer_expire_entry)(void *, struct timer_list *, long unsigned int);

typedef void (*btf_trace_timer_expire_exit)(void *, struct timer_list *);

typedef void (*btf_trace_timer_cancel)(void *, struct timer_list *);

typedef void (*btf_trace_hrtimer_init)(void *, struct hrtimer *, clockid_t, enum hrtimer_mode);

typedef void (*btf_trace_hrtimer_start)(void *, struct hrtimer *, enum hrtimer_mode);

typedef void (*btf_trace_hrtimer_expire_entry)(void *, struct hrtimer *, ktime_t *);

typedef void (*btf_trace_hrtimer_expire_exit)(void *, struct hrtimer *);

typedef void (*btf_trace_hrtimer_cancel)(void *, struct hrtimer *);

typedef void (*btf_trace_itimer_state)(void *, int, const struct itimerspec64 * const, long long unsigned int);

typedef void (*btf_trace_itimer_expire)(void *, int, struct pid___19 *, long long unsigned int);

typedef void (*btf_trace_tick_stop)(void *, int, int);

struct timer_base {
	raw_spinlock_t lock;
	struct timer_list *running_timer;
	long unsigned int clk;
	long unsigned int next_expiry;
	unsigned int cpu;
	bool next_expiry_recalc;
	bool is_idle;
	bool timers_pending;
	long unsigned int pending_map[9];
	struct hlist_head vectors[576];
	long: 64;
	long: 64;
};

struct process_timer {
	struct timer_list timer;
	struct task_struct___22 *task;
};

enum clock_event_state {
	CLOCK_EVT_STATE_DETACHED = 0,
	CLOCK_EVT_STATE_SHUTDOWN = 1,
	CLOCK_EVT_STATE_PERIODIC = 2,
	CLOCK_EVT_STATE_ONESHOT = 3,
	CLOCK_EVT_STATE_ONESHOT_STOPPED = 4,
};

struct clock_event_device {
	void (*event_handler)(struct clock_event_device *);
	int (*set_next_event)(long unsigned int, struct clock_event_device *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device *);
	int (*set_state_oneshot)(struct clock_event_device *);
	int (*set_state_oneshot_stopped)(struct clock_event_device *);
	int (*set_state_shutdown)(struct clock_event_device *);
	int (*tick_resume)(struct clock_event_device *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device *);
	void (*resume)(struct clock_event_device *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___15 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hrtimer_sleeper___2 {
	struct hrtimer timer;
	struct task_struct___15 *task;
};

enum tick_device_mode {
	TICKDEV_MODE_PERIODIC = 0,
	TICKDEV_MODE_ONESHOT = 1,
};

struct tick_device {
	struct clock_event_device *evtdev;
	enum tick_device_mode mode;
};

struct ktime_timestamps {
	u64 mono;
	u64 boot;
	u64 real;
};

struct system_device_crosststamp {
	ktime_t device;
	ktime_t sys_realtime;
	ktime_t sys_monoraw;
};

struct clocksource___2;

struct system_counterval_t {
	u64 cycles;
	struct clocksource___2 *cs;
};

struct clocksource___2 {
	u64 (*read)(struct clocksource___2 *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	u32 uncertainty_margin;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	enum clocksource_ids id;
	enum vdso_clock_mode vdso_clock_mode;
	long unsigned int flags;
	int (*enable)(struct clocksource___2 *);
	void (*disable)(struct clocksource___2 *);
	void (*suspend)(struct clocksource___2 *);
	void (*resume)(struct clocksource___2 *);
	void (*mark_unstable)(struct clocksource___2 *);
	void (*tick_stable)(struct clocksource___2 *);
	struct module___16 *owner;
};

struct tk_read_base___2 {
	struct clocksource___2 *clock;
	u64 mask;
	u64 cycle_last;
	u32 mult;
	u32 shift;
	u64 xtime_nsec;
	ktime_t base;
	u64 base_real;
};

struct timekeeper___2 {
	struct tk_read_base___2 tkr_mono;
	struct tk_read_base___2 tkr_raw;
	u64 xtime_sec;
	long unsigned int ktime_sec;
	struct timespec64 wall_to_monotonic;
	ktime_t offs_real;
	ktime_t offs_boot;
	ktime_t offs_tai;
	s32 tai_offset;
	unsigned int clock_was_set_seq;
	u8 cs_was_changed_seq;
	ktime_t next_leap_ktime;
	u64 raw_sec;
	struct timespec64 monotonic_to_boot;
	u64 cycle_interval;
	u64 xtime_interval;
	s64 xtime_remainder;
	u64 raw_interval;
	u64 ntp_tick;
	s64 ntp_error;
	u32 ntp_error_shift;
	u32 ntp_err_mult;
	u32 skip_second_overflow;
};

struct audit_ntp_val {
	long long int oldval;
	long long int newval;
};

struct audit_ntp_data {
	struct audit_ntp_val vals[6];
};

enum timekeeping_adv_mode {
	TK_ADV_TICK = 0,
	TK_ADV_FREQ = 1,
};

struct tk_fast {
	seqcount_latch_t seq;
	struct tk_read_base___2 base[2];
};

struct rtc_time {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	int tm_year;
	int tm_wday;
	int tm_yday;
	int tm_isdst;
};

struct rtc_wkalrm {
	unsigned char enabled;
	unsigned char pending;
	struct rtc_time time;
};

struct rtc_class_ops {
	int (*ioctl)(struct device___12 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___12 *, struct rtc_time *);
	int (*set_time)(struct device___12 *, struct rtc_time *);
	int (*read_alarm)(struct device___12 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___12 *, struct rtc_wkalrm *);
	int (*proc)(struct device___12 *, struct seq_file___15 *);
	int (*alarm_irq_enable)(struct device___12 *, unsigned int);
	int (*read_offset)(struct device___12 *, long int *);
	int (*set_offset)(struct device___12 *, long int);
};

struct rtc_device;

struct rtc_timer {
	struct timerqueue_node node;
	ktime_t period;
	void (*func)(struct rtc_device *);
	struct rtc_device *rtc;
	int enabled;
};

struct rtc_device {
	struct device___12 dev;
	struct module___15 *owner;
	int id;
	const struct rtc_class_ops *ops;
	struct mutex ops_lock;
	struct cdev___7 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___13 *async_queue;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer aie_timer;
	struct rtc_timer uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long unsigned int set_offset_nsec;
	long unsigned int features[1];
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct clocksource___3 {
	u64 (*read)(struct clocksource___3 *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	u32 uncertainty_margin;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	enum clocksource_ids id;
	enum vdso_clock_mode vdso_clock_mode;
	long unsigned int flags;
	int (*enable)(struct clocksource___3 *);
	void (*disable)(struct clocksource___3 *);
	void (*suspend)(struct clocksource___3 *);
	void (*resume)(struct clocksource___3 *);
	void (*mark_unstable)(struct clocksource___3 *);
	void (*tick_stable)(struct clocksource___3 *);
	struct module___17 *owner;
};

struct clock_event_device___2 {
	void (*event_handler)(struct clock_event_device___2 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___2 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___2 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___2 *);
	int (*set_state_oneshot)(struct clock_event_device___2 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___2 *);
	int (*set_state_shutdown)(struct clock_event_device___2 *);
	int (*tick_resume)(struct clock_event_device___2 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___2 *);
	void (*resume)(struct clock_event_device___2 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___16 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tick_device___2 {
	struct clock_event_device___2 *evtdev;
	enum tick_device_mode mode;
};

enum tick_nohz_mode {
	NOHZ_MODE_INACTIVE = 0,
	NOHZ_MODE_LOWRES = 1,
	NOHZ_MODE_HIGHRES = 2,
};

struct tick_sched {
	struct hrtimer sched_timer;
	long unsigned int check_clocks;
	enum tick_nohz_mode nohz_mode;
	unsigned int inidle;
	unsigned int tick_stopped;
	unsigned int idle_active;
	unsigned int do_timer_last;
	unsigned int got_idle_tick;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	ktime_t last_tick;
	ktime_t next_tick;
	long unsigned int idle_jiffies;
	long unsigned int idle_calls;
	long unsigned int idle_sleeps;
	ktime_t idle_entrytime;
	ktime_t idle_waketime;
	ktime_t idle_exittime;
	ktime_t idle_sleeptime;
	ktime_t iowait_sleeptime;
	long unsigned int last_jiffies;
	u64 timer_expires;
	u64 timer_expires_base;
	u64 next_timer;
	ktime_t idle_expires;
	atomic_t tick_dep_mask;
};

struct timer_list_iter {
	int cpu;
	bool second_pass;
	u64 now;
};

struct tm {
	int tm_sec;
	int tm_min;
	int tm_hour;
	int tm_mday;
	int tm_mon;
	long int tm_year;
	int tm_wday;
	int tm_yday;
};

typedef __kernel_timer_t timer_t;

enum alarmtimer_type {
	ALARM_REALTIME = 0,
	ALARM_BOOTTIME = 1,
	ALARM_NUMTYPE = 2,
	ALARM_REALTIME_FREEZER = 3,
	ALARM_BOOTTIME_FREEZER = 4,
};

enum alarmtimer_restart {
	ALARMTIMER_NORESTART = 0,
	ALARMTIMER_RESTART = 1,
};

struct alarm {
	struct timerqueue_node node;
	struct hrtimer timer;
	enum alarmtimer_restart (*function)(struct alarm *, ktime_t);
	enum alarmtimer_type type;
	int state;
	void *data;
};

struct cpu_timer {
	struct timerqueue_node node;
	struct timerqueue_head *head;
	struct pid___28 *pid;
	struct list_head elist;
	int firing;
};

struct k_clock;

struct k_itimer {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___30 *it_signal;
	union {
		struct pid___28 *it_pid;
		struct task_struct___32 *it_process;
	};
	struct sigqueue *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
	} it;
	struct callback_head rcu;
};

struct k_clock {
	int (*clock_getres)(const clockid_t, struct timespec64 *);
	int (*clock_set)(const clockid_t, const struct timespec64 *);
	int (*clock_get_timespec)(const clockid_t, struct timespec64 *);
	ktime_t (*clock_get_ktime)(const clockid_t);
	int (*clock_adj)(const clockid_t, struct __kernel_timex *);
	int (*timer_create)(struct k_itimer *);
	int (*nsleep)(const clockid_t, int, const struct timespec64 *);
	int (*timer_set)(struct k_itimer *, int, struct itimerspec64 *, struct itimerspec64 *);
	int (*timer_del)(struct k_itimer *);
	void (*timer_get)(struct k_itimer *, struct itimerspec64 *);
	void (*timer_rearm)(struct k_itimer *);
	s64 (*timer_forward)(struct k_itimer *, ktime_t);
	ktime_t (*timer_remaining)(struct k_itimer *, ktime_t);
	int (*timer_try_to_cancel)(struct k_itimer *);
	void (*timer_arm)(struct k_itimer *, ktime_t, bool, bool);
	void (*timer_wait_running)(struct k_itimer *);
};

struct class_interface {
	struct list_head node;
	struct class___27 *class;
	int (*add_dev)(struct device___27 *, struct class_interface *);
	void (*remove_dev)(struct device___27 *, struct class_interface *);
};

struct rtc_class_ops___2 {
	int (*ioctl)(struct device___27 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___27 *, struct rtc_time *);
	int (*set_time)(struct device___27 *, struct rtc_time *);
	int (*read_alarm)(struct device___27 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___27 *, struct rtc_wkalrm *);
	int (*proc)(struct device___27 *, struct seq_file___29 *);
	int (*alarm_irq_enable)(struct device___27 *, unsigned int);
	int (*read_offset)(struct device___27 *, long int *);
	int (*set_offset)(struct device___27 *, long int);
};

struct rtc_device___2;

struct rtc_timer___2 {
	struct timerqueue_node node;
	ktime_t period;
	void (*func)(struct rtc_device___2 *);
	struct rtc_device___2 *rtc;
	int enabled;
};

struct rtc_device___2 {
	struct device___27 dev;
	struct module___31 *owner;
	int id;
	const struct rtc_class_ops___2 *ops;
	struct mutex ops_lock;
	struct cdev___16 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___29 *async_queue;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer___2 aie_timer;
	struct rtc_timer___2 uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long unsigned int set_offset_nsec;
	long unsigned int features[1];
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct platform_device___3 {
	const char *name;
	int id;
	bool id_auto;
	struct device___27 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct property_entry;

struct platform_device_info {
	struct device___27 *parent;
	struct fwnode_handle___27 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

enum dev_prop_type {
	DEV_PROP_U8 = 0,
	DEV_PROP_U16 = 1,
	DEV_PROP_U32 = 2,
	DEV_PROP_U64 = 3,
	DEV_PROP_STRING = 4,
	DEV_PROP_REF = 5,
};

struct property_entry {
	const char *name;
	size_t length;
	bool is_inline;
	enum dev_prop_type type;
	union {
		const void *pointer;
		union {
			u8 u8_data[8];
			u16 u16_data[4];
			u32 u32_data[2];
			u64 u64_data[1];
			const char *str[1];
		} value;
	};
};

struct platform_driver___2 {
	int (*probe)(struct platform_device___3 *);
	int (*remove)(struct platform_device___3 *);
	void (*shutdown)(struct platform_device___3 *);
	int (*suspend)(struct platform_device___3 *, pm_message_t);
	int (*resume)(struct platform_device___3 *);
	struct device_driver___27 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct trace_event_file___12;

struct trace_event_buffer___12 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___12 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___12 {
	struct list_head list;
	struct trace_event_call___15 *event_call;
	struct event_filter *filter;
	struct dentry___30 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_alarmtimer_suspend {
	struct trace_entry ent;
	s64 expires;
	unsigned char alarm_type;
	char __data[0];
};

struct trace_event_raw_alarm_class {
	struct trace_entry ent;
	void *alarm;
	unsigned char alarm_type;
	s64 expires;
	s64 now;
	char __data[0];
};

struct trace_event_data_offsets_alarmtimer_suspend {};

struct trace_event_data_offsets_alarm_class {};

typedef void (*btf_trace_alarmtimer_suspend)(void *, ktime_t, int);

typedef void (*btf_trace_alarmtimer_fired)(void *, struct alarm *, ktime_t);

typedef void (*btf_trace_alarmtimer_start)(void *, struct alarm *, ktime_t);

typedef void (*btf_trace_alarmtimer_cancel)(void *, struct alarm *, ktime_t);

struct alarm_base {
	spinlock_t lock;
	struct timerqueue_head timerqueue;
	ktime_t (*get_ktime)();
	void (*get_timespec)(struct timespec64 *);
	clockid_t base_clockid;
};

struct sigevent {
	sigval_t sigev_value;
	int sigev_signo;
	int sigev_notify;
	union {
		int _pad[12];
		int _tid;
		struct {
			void (*_function)(sigval_t);
			void *_attribute;
		} _sigev_thread;
	} _sigev_un;
};

typedef struct sigevent sigevent_t;

struct compat_sigevent {
	compat_sigval_t sigev_value;
	compat_int_t sigev_signo;
	compat_int_t sigev_notify;
	union {
		compat_int_t _pad[13];
		compat_int_t _tid;
		struct {
			compat_uptr_t _function;
			compat_uptr_t _attribute;
		} _sigev_thread;
	} _sigev_un;
};

struct k_clock___2;

struct k_itimer___2 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock___2 *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___15 *it_signal;
	union {
		struct pid___13 *it_pid;
		struct task_struct___16 *it_process;
	};
	struct sigqueue *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
	} it;
	struct callback_head rcu;
};

struct k_clock___2 {
	int (*clock_getres)(const clockid_t, struct timespec64 *);
	int (*clock_set)(const clockid_t, const struct timespec64 *);
	int (*clock_get_timespec)(const clockid_t, struct timespec64 *);
	ktime_t (*clock_get_ktime)(const clockid_t);
	int (*clock_adj)(const clockid_t, struct __kernel_timex *);
	int (*timer_create)(struct k_itimer___2 *);
	int (*nsleep)(const clockid_t, int, const struct timespec64 *);
	int (*timer_set)(struct k_itimer___2 *, int, struct itimerspec64 *, struct itimerspec64 *);
	int (*timer_del)(struct k_itimer___2 *);
	void (*timer_get)(struct k_itimer___2 *, struct itimerspec64 *);
	void (*timer_rearm)(struct k_itimer___2 *);
	s64 (*timer_forward)(struct k_itimer___2 *, ktime_t);
	ktime_t (*timer_remaining)(struct k_itimer___2 *, ktime_t);
	int (*timer_try_to_cancel)(struct k_itimer___2 *);
	void (*timer_arm)(struct k_itimer___2 *, ktime_t, bool, bool);
	void (*timer_wait_running)(struct k_itimer___2 *);
};

typedef struct poll_table_struct___10 poll_table___6;

struct posix_clock;

struct posix_clock_operations {
	struct module___15 *owner;
	int (*clock_adjtime)(struct posix_clock *, struct __kernel_timex *);
	int (*clock_gettime)(struct posix_clock *, struct timespec64 *);
	int (*clock_getres)(struct posix_clock *, struct timespec64 *);
	int (*clock_settime)(struct posix_clock *, const struct timespec64 *);
	long int (*ioctl)(struct posix_clock *, unsigned int, long unsigned int);
	int (*open)(struct posix_clock *, fmode_t);
	__poll_t (*poll)(struct posix_clock *, struct file___14 *, poll_table___6 *);
	int (*release)(struct posix_clock *);
	ssize_t (*read)(struct posix_clock *, uint, char *, size_t);
};

struct posix_clock {
	struct posix_clock_operations ops;
	struct cdev___3 cdev;
	struct device___11 *dev;
	struct rw_semaphore rwsem;
	bool zombie;
};

struct posix_clock_desc {
	struct file___14 *fp;
	struct posix_clock *clk;
};

struct __kernel_old_itimerval {
	struct __kernel_old_timeval it_interval;
	struct __kernel_old_timeval it_value;
};

struct old_itimerval32 {
	struct old_timeval32 it_interval;
	struct old_timeval32 it_value;
};

struct ce_unbind {
	struct clock_event_device *ce;
	int res;
};

enum tick_broadcast_state {
	TICK_BROADCAST_EXIT = 0,
	TICK_BROADCAST_ENTER = 1,
};

enum tick_broadcast_mode {
	TICK_BROADCAST_OFF = 0,
	TICK_BROADCAST_ON = 1,
	TICK_BROADCAST_FORCE = 2,
};

struct clock_data {
	seqcount_latch_t seq;
	struct clock_read_data read_data[2];
	ktime_t wrap_kt;
	long unsigned int rate;
	u64 (*actual_read_sched_clock)();
};

struct dentry___44;

struct super_block___44;

struct file_system_type___43 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___44 * (*mount)(struct file_system_type___43 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___44 *);
	struct module___8 *owner;
	struct file_system_type___43 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___44;

struct kiocb___43;

struct vm_area_struct___47;

struct inode___44;

struct file_lock___43;

struct page___47;

struct seq_file___43;

struct file_operations___43 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___44 *, loff_t, int);
	ssize_t (*read)(struct file___44 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___44 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___43 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___43 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___43 *, bool);
	int (*iterate)(struct file___44 *, struct dir_context *);
	int (*iterate_shared)(struct file___44 *, struct dir_context *);
	__poll_t (*poll)(struct file___44 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___44 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___44 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___44 *, struct vm_area_struct___47 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___44 *, struct file___44 *);
	int (*flush)(struct file___44 *, fl_owner_t);
	int (*release)(struct inode___44 *, struct file___44 *);
	int (*fsync)(struct file___44 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___44 *, int);
	int (*lock)(struct file___44 *, int, struct file_lock___43 *);
	ssize_t (*sendpage)(struct file___44 *, struct page___47 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___44 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___44 *, long unsigned int);
	int (*flock)(struct file___44 *, int, struct file_lock___43 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___44 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___44 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___44 *, long int, struct file_lock___43 **, void **);
	long int (*fallocate)(struct file___44 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___43 *, struct file___44 *);
	ssize_t (*copy_file_range)(struct file___44 *, loff_t, struct file___44 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___44 *, loff_t, struct file___44 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___44 *, loff_t, loff_t, int);
};

struct vmacache___47 {
	u64 seqnum;
	struct vm_area_struct___47 *vmas[4];
};

struct page_frag___47 {
	struct page___47 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___48;

struct cred___4;

struct nsproxy___43;

struct signal_struct___44;

struct vm_struct___46;

struct task_struct___48 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___48 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___48 *mm;
	struct mm_struct___48 *active_mm;
	struct vmacache___47 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___48 *real_parent;
	struct task_struct___48 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___48 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___14 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___4 *ptracer_cred;
	const struct cred___4 *real_cred;
	const struct cred___4 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___43 *nsproxy;
	struct signal_struct___44 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___48 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___6 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___47 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___48 *oom_reaper_list;
	struct vm_struct___46 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___8 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___6;

struct ns_common___6 {
	atomic_long_t stashed;
	const struct proc_ns_operations___6 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___5;

struct user_namespace___5 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___5 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___6 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___5 *ucounts;
	long int ucount_max[16];
};

typedef struct page___47 *pgtable_t___47;

struct address_space___43;

struct dev_pagemap___43;

struct page___47 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___43 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___47 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___47 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___48 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___43 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___5 {
	struct hlist_node node;
	struct user_namespace___5 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___43;

struct vm_area_struct___47 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___47 *vm_next;
	struct vm_area_struct___47 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___48 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___43 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___44 *vm_file;
	struct file___44 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___44 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___48 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___48 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___14 *pids[4];
	struct pid___14 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___48 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___47;

struct mm_struct___48 {
	struct {
		struct vm_area_struct___47 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___44 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___47 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___48 *owner;
		struct user_namespace___5 *user_ns;
		struct file___44 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___4 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___5 *user_ns;
	struct ucounts___5 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct time_namespace___4;

struct nsproxy___43 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace___4 *time_ns;
	struct time_namespace___4 *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___46 {
	struct vm_struct___46 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___47 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct time_namespace___4 {
	struct user_namespace___5 *user_ns;
	struct ucounts___5 *ucounts;
	struct ns_common___6 ns;
	struct timens_offsets offsets;
	struct page___47 *vvar_page;
	bool frozen_offsets;
};

struct nsset___5 {
	unsigned int flags;
	struct nsproxy___43 *nsproxy;
	struct fs_struct *fs;
	const struct cred___4 *cred;
};

struct proc_ns_operations___6 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___6 * (*get)(struct task_struct___48 *);
	void (*put)(struct ns_common___6 *);
	int (*install)(struct nsset___5 *, struct ns_common___6 *);
	struct user_namespace___5 * (*owner)(struct ns_common___6 *);
	struct ns_common___6 * (*get_parent)(struct ns_common___6 *);
};

struct proc_timens_offset {
	int clockid;
	struct timespec64 val;
};

struct seq_operations___42 {
	void * (*start)(struct seq_file___43 *, loff_t *);
	void (*stop)(struct seq_file___43 *, void *);
	void * (*next)(struct seq_file___43 *, void *, loff_t *);
	int (*show)(struct seq_file___43 *, void *);
};

struct address_space_operations___43;

struct address_space___43 {
	struct inode___44 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___43 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___43;

struct dev_pagemap___43 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___43 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___43;

struct path___43 {
	struct vfsmount___43 *mnt;
	struct dentry___44 *dentry;
};

struct file___44 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___43 f_path;
	struct inode___44 *f_inode;
	const struct file_operations___43 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___14 f_owner;
	const struct cred___4 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___43 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___43;

struct vm_operations_struct___43 {
	void (*open)(struct vm_area_struct___47 *);
	void (*close)(struct vm_area_struct___47 *);
	int (*may_split)(struct vm_area_struct___47 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___47 *);
	int (*mprotect)(struct vm_area_struct___47 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___43 *);
	vm_fault_t (*huge_fault)(struct vm_fault___43 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___43 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___47 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___43 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___43 *);
	int (*access)(struct vm_area_struct___47 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___47 *);
	int (*set_policy)(struct vm_area_struct___47 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___47 *, long unsigned int);
	struct page___47 * (*find_special_page)(struct vm_area_struct___47 *, long unsigned int);
};

struct core_thread___47 {
	struct task_struct___48 *task;
	struct core_thread___47 *next;
};

struct core_state___47 {
	atomic_t nr_threads;
	struct core_thread___47 dumper;
	struct completion startup;
};

struct vm_fault___43 {
	const struct {
		struct vm_area_struct___47 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___47 *cow_page;
	struct page___47 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___47 prealloc_pte;
};

struct seq_file___43 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___42 *op;
	int poll_event;
	const struct file___44 *file;
	void *private;
};

struct dentry_operations___43;

struct dentry___44 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___44 *d_parent;
	struct qstr d_name;
	struct inode___44 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___43 *d_op;
	struct super_block___44 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___43;

struct inode___44 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___43 *i_op;
	struct super_block___44 *i_sb;
	struct address_space___43 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___43 *i_fop;
		void (*free_inode)(struct inode___44 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___43 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___8 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___43 {
	int (*d_revalidate)(struct dentry___44 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___44 *, unsigned int);
	int (*d_hash)(const struct dentry___44 *, struct qstr *);
	int (*d_compare)(const struct dentry___44 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___44 *);
	int (*d_init)(struct dentry___44 *);
	void (*d_release)(struct dentry___44 *);
	void (*d_prune)(struct dentry___44 *);
	void (*d_iput)(struct dentry___44 *, struct inode___44 *);
	char * (*d_dname)(struct dentry___44 *, char *, int);
	struct vfsmount___43 * (*d_automount)(struct path___43 *);
	int (*d_manage)(const struct path___43 *, bool);
	struct dentry___44 * (*d_real)(struct dentry___44 *, const struct inode___44 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___43;

struct mem_dqinfo___43 {
	struct quota_format_type___43 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___43;

struct quota_info___43 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___44 *files[3];
	struct mem_dqinfo___43 info[3];
	const struct quota_format_ops___43 *ops[3];
};

struct rcuwait___44 {
	struct task_struct___48 *task;
};

struct percpu_rw_semaphore___44 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___44 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___43 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___44 rw_sem[3];
};

struct super_operations___43;

struct dquot_operations___43;

struct quotactl_ops___43;

struct super_block___44 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___43 *s_type;
	const struct super_operations___43 *s_op;
	const struct dquot_operations___43 *dq_op;
	const struct quotactl_ops___43 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___44 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___43 s_dquot;
	struct sb_writers___43 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___43 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___5 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___43 {
	struct dentry___44 *mnt_root;
	struct super_block___44 *mnt_sb;
	int mnt_flags;
	struct user_namespace___5 *mnt_userns;
};

struct kiocb___43 {
	struct file___44 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___43 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___3 *ki_waitq;
	};
};

struct iattr___44 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___44 *ia_file;
};

struct dquot___43 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___44 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___43 {
	int qf_fmt_id;
	const struct quota_format_ops___43 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___43 *qf_next;
};

struct quota_format_ops___43 {
	int (*check_quota_file)(struct super_block___44 *, int);
	int (*read_file_info)(struct super_block___44 *, int);
	int (*write_file_info)(struct super_block___44 *, int);
	int (*free_file_info)(struct super_block___44 *, int);
	int (*read_dqblk)(struct dquot___43 *);
	int (*commit_dqblk)(struct dquot___43 *);
	int (*release_dqblk)(struct dquot___43 *);
	int (*get_next_id)(struct super_block___44 *, struct kqid *);
};

struct dquot_operations___43 {
	int (*write_dquot)(struct dquot___43 *);
	struct dquot___43 * (*alloc_dquot)(struct super_block___44 *, int);
	void (*destroy_dquot)(struct dquot___43 *);
	int (*acquire_dquot)(struct dquot___43 *);
	int (*release_dquot)(struct dquot___43 *);
	int (*mark_dirty)(struct dquot___43 *);
	int (*write_info)(struct super_block___44 *, int);
	qsize_t * (*get_reserved_space)(struct inode___44 *);
	int (*get_projid)(struct inode___44 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___44 *, qsize_t *);
	int (*get_next_id)(struct super_block___44 *, struct kqid *);
};

struct quotactl_ops___43 {
	int (*quota_on)(struct super_block___44 *, int, int, const struct path___43 *);
	int (*quota_off)(struct super_block___44 *, int);
	int (*quota_enable)(struct super_block___44 *, unsigned int);
	int (*quota_disable)(struct super_block___44 *, unsigned int);
	int (*quota_sync)(struct super_block___44 *, int);
	int (*set_info)(struct super_block___44 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___44 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___44 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___44 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___44 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___44 *, unsigned int);
};

struct address_space_operations___43 {
	int (*writepage)(struct page___47 *, struct writeback_control___3 *);
	int (*readpage)(struct file___44 *, struct page___47 *);
	int (*writepages)(struct address_space___43 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___47 *);
	int (*readpages)(struct file___44 *, struct address_space___43 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___44 *, struct address_space___43 *, loff_t, unsigned int, unsigned int, struct page___47 **, void **);
	int (*write_end)(struct file___44 *, struct address_space___43 *, loff_t, unsigned int, unsigned int, struct page___47 *, void *);
	sector_t (*bmap)(struct address_space___43 *, sector_t);
	void (*invalidatepage)(struct page___47 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___47 *, gfp_t);
	void (*freepage)(struct page___47 *);
	ssize_t (*direct_IO)(struct kiocb___43 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___43 *, struct page___47 *, struct page___47 *, enum migrate_mode);
	bool (*isolate_page)(struct page___47 *, isolate_mode_t);
	void (*putback_page)(struct page___47 *);
	int (*launder_page)(struct page___47 *);
	int (*is_partially_uptodate)(struct page___47 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___47 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___43 *, struct page___47 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___44 *, sector_t *);
	void (*swap_deactivate)(struct file___44 *);
};

struct inode_operations___43 {
	struct dentry___44 * (*lookup)(struct inode___44 *, struct dentry___44 *, unsigned int);
	const char * (*get_link)(struct dentry___44 *, struct inode___44 *, struct delayed_call *);
	int (*permission)(struct user_namespace___5 *, struct inode___44 *, int);
	struct posix_acl * (*get_acl)(struct inode___44 *, int, bool);
	int (*readlink)(struct dentry___44 *, char *, int);
	int (*create)(struct user_namespace___5 *, struct inode___44 *, struct dentry___44 *, umode_t, bool);
	int (*link)(struct dentry___44 *, struct inode___44 *, struct dentry___44 *);
	int (*unlink)(struct inode___44 *, struct dentry___44 *);
	int (*symlink)(struct user_namespace___5 *, struct inode___44 *, struct dentry___44 *, const char *);
	int (*mkdir)(struct user_namespace___5 *, struct inode___44 *, struct dentry___44 *, umode_t);
	int (*rmdir)(struct inode___44 *, struct dentry___44 *);
	int (*mknod)(struct user_namespace___5 *, struct inode___44 *, struct dentry___44 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___5 *, struct inode___44 *, struct dentry___44 *, struct inode___44 *, struct dentry___44 *, unsigned int);
	int (*setattr)(struct user_namespace___5 *, struct dentry___44 *, struct iattr___44 *);
	int (*getattr)(struct user_namespace___5 *, const struct path___43 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___44 *, char *, size_t);
	int (*fiemap)(struct inode___44 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___44 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___44 *, struct dentry___44 *, struct file___44 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___5 *, struct inode___44 *, struct dentry___44 *, umode_t);
	int (*set_acl)(struct user_namespace___5 *, struct inode___44 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___5 *, struct dentry___44 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___44 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___43 {
	void (*fl_copy_lock)(struct file_lock___43 *, struct file_lock___43 *);
	void (*fl_release_private)(struct file_lock___43 *);
};

struct fasync_struct___43;

struct lock_manager_operations___43;

struct file_lock___43 {
	struct file_lock___43 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___44 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___43 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___43 *fl_ops;
	const struct lock_manager_operations___43 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___43 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___43 *);
	int (*lm_grant)(struct file_lock___43 *, int);
	bool (*lm_break)(struct file_lock___43 *);
	int (*lm_change)(struct file_lock___43 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___43 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___43 *);
};

struct fasync_struct___43 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___43 *fa_next;
	struct file___44 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___43 {
	struct inode___44 * (*alloc_inode)(struct super_block___44 *);
	void (*destroy_inode)(struct inode___44 *);
	void (*free_inode)(struct inode___44 *);
	void (*dirty_inode)(struct inode___44 *, int);
	int (*write_inode)(struct inode___44 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___44 *);
	void (*evict_inode)(struct inode___44 *);
	void (*put_super)(struct super_block___44 *);
	int (*sync_fs)(struct super_block___44 *, int);
	int (*freeze_super)(struct super_block___44 *);
	int (*freeze_fs)(struct super_block___44 *);
	int (*thaw_super)(struct super_block___44 *);
	int (*unfreeze_fs)(struct super_block___44 *);
	int (*statfs)(struct dentry___44 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___44 *, int *, char *);
	void (*umount_begin)(struct super_block___44 *);
	int (*show_options)(struct seq_file___43 *, struct dentry___44 *);
	int (*show_devname)(struct seq_file___43 *, struct dentry___44 *);
	int (*show_path)(struct seq_file___43 *, struct dentry___44 *);
	int (*show_stats)(struct seq_file___43 *, struct dentry___44 *);
	ssize_t (*quota_read)(struct super_block___44 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___44 *, int, const char *, size_t, loff_t);
	struct dquot___43 ** (*get_dquots)(struct inode___44 *);
	long int (*nr_cached_objects)(struct super_block___44 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___44 *, struct shrink_control___4 *);
	struct file___44 * (*real_loop)(struct file___44 *);
};

struct dev_pagemap_ops___43 {
	void (*page_free)(struct page___47 *);
	void (*kill)(struct dev_pagemap___43 *);
	void (*cleanup)(struct dev_pagemap___43 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___43 *);
};

struct dentry___45;

struct super_block___45;

struct module___45;

struct file_system_type___44 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___45 * (*mount)(struct file_system_type___44 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___45 *);
	struct module___45 *owner;
	struct file_system_type___44 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___45;

struct kiocb___44;

struct poll_table_struct___35;

struct vm_area_struct___48;

struct inode___45;

struct file_lock___44;

struct page___48;

struct seq_file___44;

struct file_operations___44 {
	struct module___45 *owner;
	loff_t (*llseek)(struct file___45 *, loff_t, int);
	ssize_t (*read)(struct file___45 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___45 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___44 *, struct iov_iter___6 *);
	ssize_t (*write_iter)(struct kiocb___44 *, struct iov_iter___6 *);
	int (*iopoll)(struct kiocb___44 *, bool);
	int (*iterate)(struct file___45 *, struct dir_context *);
	int (*iterate_shared)(struct file___45 *, struct dir_context *);
	__poll_t (*poll)(struct file___45 *, struct poll_table_struct___35 *);
	long int (*unlocked_ioctl)(struct file___45 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___45 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___45 *, struct vm_area_struct___48 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___45 *, struct file___45 *);
	int (*flush)(struct file___45 *, fl_owner_t);
	int (*release)(struct inode___45 *, struct file___45 *);
	int (*fsync)(struct file___45 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___45 *, int);
	int (*lock)(struct file___45 *, int, struct file_lock___44 *);
	ssize_t (*sendpage)(struct file___45 *, struct page___48 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___45 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___45 *, long unsigned int);
	int (*flock)(struct file___45 *, int, struct file_lock___44 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___45 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___45 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___45 *, long int, struct file_lock___44 **, void **);
	long int (*fallocate)(struct file___45 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___44 *, struct file___45 *);
	ssize_t (*copy_file_range)(struct file___45 *, loff_t, struct file___45 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___45 *, loff_t, struct file___45 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___45 *, loff_t, loff_t, int);
};

struct vmacache___48 {
	u64 seqnum;
	struct vm_area_struct___48 *vmas[4];
};

struct page_frag___48 {
	struct page___48 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___32;

struct debug_info___32 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___32 *hbp_break[16];
	struct perf_event___32 *hbp_watch[16];
};

struct thread_struct___32 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___32 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___49;

struct pid___42;

struct nsproxy___44;

struct signal_struct___45;

struct rt_mutex_waiter___3;

struct css_set___36;

struct perf_event_context___32;

struct vm_struct___47;

struct task_struct___49 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___49 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___49 *mm;
	struct mm_struct___49 *active_mm;
	struct vmacache___48 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___49 *real_parent;
	struct task_struct___49 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___49 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___42 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___4 *ptracer_cred;
	const struct cred___4 *real_cred;
	const struct cred___4 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___44 *nsproxy;
	struct signal_struct___45 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___49 *pi_top_task;
	struct rt_mutex_waiter___3 *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___6 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___36 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___32 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___48 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___49 *oom_reaper_list;
	struct vm_struct___47 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___32 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___46;

struct kobj_type___46;

struct kernfs_node___46;

struct kobject___46 {
	const char *name;
	struct list_head entry;
	struct kobject___46 *parent;
	struct kset___46 *kset;
	struct kobj_type___46 *ktype;
	struct kernfs_node___46 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___43 {
	struct kobject___46 kobj;
	struct module___45 *mod;
	struct kobject___46 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___43 {
	struct module___45 *mod;
	struct latch_tree_node node;
};

struct module_layout___43 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___43 mtn;
};

struct module_attribute___43;

struct kernel_param___43;

struct trace_event_call___27;

struct module___45 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___43 mkobj;
	struct module_attribute___43 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___46 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___43 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___43 core_layout;
	struct module_layout___43 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___27 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___32 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___49 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___32)(struct perf_event___32 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___32;

struct fasync_struct___44;

struct pid_namespace___42;

struct perf_cgroup___32;

struct perf_event___32 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___32 *group_leader;
	struct pmu___32 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___32 hw;
	struct perf_event_context___32 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___32 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___49 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___44 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___32 *aux_event;
	void (*destroy)(struct perf_event___32 *);
	struct callback_head callback_head;
	struct pid_namespace___42 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___32 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___32 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___27 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___32 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___42 {
	int nr;
	struct pid_namespace___42 *ns;
};

struct pid_namespace___42 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___49 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___42 *parent;
	struct fs_pin *bacct;
	struct user_namespace___5 *user_ns;
	struct ucounts___5 *ucounts;
	int reboot;
	struct ns_common___6 ns;
};

struct pid___42 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___42 numbers[1];
};

typedef struct page___48 *pgtable_t___48;

struct address_space___44;

struct dev_pagemap___44;

struct page___48 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___44 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___3 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___48 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___48 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___49 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___44 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct rt_mutex_base___3 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___49 *owner;
};

struct ww_acquire_ctx___3 {
	struct task_struct___49 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct hrtimer_sleeper___3 {
	struct hrtimer timer;
	struct task_struct___49 *task;
};

struct vm_operations_struct___44;

struct vm_area_struct___48 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___48 *vm_next;
	struct vm_area_struct___48 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___49 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___44 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___45 *vm_file;
	struct file___45 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___45 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___49 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___49 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___42 *pids[4];
	struct pid___42 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___49 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___48;

struct mm_struct___49 {
	struct {
		struct vm_area_struct___48 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___45 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___48 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___49 *owner;
		struct user_namespace___5 *user_ns;
		struct file___45 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct time_namespace___5;

struct cgroup_namespace___36;

struct nsproxy___44 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___42 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace___5 *time_ns;
	struct time_namespace___5 *time_ns_for_children;
	struct cgroup_namespace___36 *cgroup_ns;
};

struct rt_mutex_waiter___3 {
	struct rb_node tree_entry;
	struct rb_node pi_tree_entry;
	struct task_struct___49 *task;
	struct rt_mutex_base___3 *lock;
	unsigned int wake_state;
	int prio;
	u64 deadline;
	struct ww_acquire_ctx___3 *ww_ctx;
};

struct cgroup_subsys_state___36;

struct cgroup___36;

struct css_set___36 {
	struct cgroup_subsys_state___36 *subsys[14];
	refcount_t refcount;
	struct css_set___36 *dom_cset;
	struct cgroup___36 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___36 *mg_src_cgrp;
	struct cgroup___36 *mg_dst_cgrp;
	struct css_set___36 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

union futex_key {
	struct {
		u64 i_seq;
		long unsigned int pgoff;
		unsigned int offset;
	} shared;
	struct {
		union {
			struct mm_struct___49 *mm;
			u64 __tmp;
		};
		long unsigned int address;
		unsigned int offset;
	} private;
	struct {
		u64 ptr;
		long unsigned int word;
		unsigned int offset;
	} both;
};

struct futex_pi_state {
	struct list_head list;
	struct rt_mutex_base___3 pi_mutex;
	struct task_struct___49 *owner;
	refcount_t refcount;
	union futex_key key;
};

struct perf_event_context___32 {
	struct pmu___32 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___49 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___32 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___47 {
	struct vm_struct___47 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___48 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct wait_page_queue___23;

struct kiocb___44 {
	struct file___45 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___44 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___23 *ki_waitq;
	};
};

struct dentry_operations___44;

struct dentry___45 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___45 *d_parent;
	struct qstr d_name;
	struct inode___45 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___44 *d_op;
	struct super_block___45 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___44;

struct address_space___44 {
	struct inode___45 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___44 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___44;

struct inode___45 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___44 *i_op;
	struct super_block___45 *i_sb;
	struct address_space___44 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___44 *i_fop;
		void (*free_inode)(struct inode___45 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___44 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___8 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___44;

struct path___44;

struct dentry_operations___44 {
	int (*d_revalidate)(struct dentry___45 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___45 *, unsigned int);
	int (*d_hash)(const struct dentry___45 *, struct qstr *);
	int (*d_compare)(const struct dentry___45 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___45 *);
	int (*d_init)(struct dentry___45 *);
	void (*d_release)(struct dentry___45 *);
	void (*d_prune)(struct dentry___45 *);
	void (*d_iput)(struct dentry___45 *, struct inode___45 *);
	char * (*d_dname)(struct dentry___45 *, char *, int);
	struct vfsmount___44 * (*d_automount)(struct path___44 *);
	int (*d_manage)(const struct path___44 *, bool);
	struct dentry___45 * (*d_real)(struct dentry___45 *, const struct inode___45 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___44;

struct mem_dqinfo___44 {
	struct quota_format_type___44 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___44;

struct quota_info___44 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___45 *files[3];
	struct mem_dqinfo___44 info[3];
	const struct quota_format_ops___44 *ops[3];
};

struct rcuwait___45 {
	struct task_struct___49 *task;
};

struct percpu_rw_semaphore___45 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___45 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___44 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___45 rw_sem[3];
};

struct super_operations___44;

struct dquot_operations___44;

struct quotactl_ops___44;

struct super_block___45 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___44 *s_type;
	const struct super_operations___44 *s_op;
	const struct dquot_operations___44 *dq_op;
	const struct quotactl_ops___44 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___45 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___44 s_dquot;
	struct sb_writers___44 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___44 *s_d_op;
	int cleancache_poolid;
	struct shrinker___4 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___5 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___44 {
	struct dentry___45 *mnt_root;
	struct super_block___45 *mnt_sb;
	int mnt_flags;
	struct user_namespace___5 *mnt_userns;
};

struct path___44 {
	struct vfsmount___44 *mnt;
	struct dentry___45 *dentry;
};

struct dev_pagemap_ops___44;

struct dev_pagemap___44 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___44 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___42 {
	rwlock_t lock;
	struct pid___42 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___45 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___44 f_path;
	struct inode___45 *f_inode;
	const struct file_operations___44 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___42 f_owner;
	const struct cred___4 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___44 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___44;

struct vm_operations_struct___44 {
	void (*open)(struct vm_area_struct___48 *);
	void (*close)(struct vm_area_struct___48 *);
	int (*may_split)(struct vm_area_struct___48 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___48 *);
	int (*mprotect)(struct vm_area_struct___48 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___44 *);
	vm_fault_t (*huge_fault)(struct vm_fault___44 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___44 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___48 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___44 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___44 *);
	int (*access)(struct vm_area_struct___48 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___48 *);
	int (*set_policy)(struct vm_area_struct___48 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___48 *, long unsigned int);
	struct page___48 * (*find_special_page)(struct vm_area_struct___48 *, long unsigned int);
};

struct core_thread___48 {
	struct task_struct___49 *task;
	struct core_thread___48 *next;
};

struct core_state___48 {
	atomic_t nr_threads;
	struct core_thread___48 dumper;
	struct completion startup;
};

struct vm_fault___44 {
	const struct {
		struct vm_area_struct___48 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___48 *cow_page;
	struct page___48 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___48 prealloc_pte;
};

struct cgroup_subsys___36;

struct cgroup_subsys_state___36 {
	struct cgroup___36 *cgroup;
	struct cgroup_subsys___36 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___36 *parent;
};

struct cgroup_file___36 {
	struct kernfs_node___46 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___36 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___49 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___36;

struct cgroup_rstat_cpu___36;

struct cgroup___36 {
	struct cgroup_subsys_state___36 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___46 *kn;
	struct cgroup_file___36 procs_file;
	struct cgroup_file___36 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___36 *subsys[14];
	struct cgroup_root___36 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___36 *dom_cgrp;
	struct cgroup___36 *old_dom_cgrp;
	struct cgroup_rstat_cpu___36 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___36 psi;
	struct cgroup_bpf bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___45 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___45 *ia_file;
};

struct dquot___44 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___45 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___44 {
	int qf_fmt_id;
	const struct quota_format_ops___44 *qf_ops;
	struct module___45 *qf_owner;
	struct quota_format_type___44 *qf_next;
};

struct quota_format_ops___44 {
	int (*check_quota_file)(struct super_block___45 *, int);
	int (*read_file_info)(struct super_block___45 *, int);
	int (*write_file_info)(struct super_block___45 *, int);
	int (*free_file_info)(struct super_block___45 *, int);
	int (*read_dqblk)(struct dquot___44 *);
	int (*commit_dqblk)(struct dquot___44 *);
	int (*release_dqblk)(struct dquot___44 *);
	int (*get_next_id)(struct super_block___45 *, struct kqid *);
};

struct dquot_operations___44 {
	int (*write_dquot)(struct dquot___44 *);
	struct dquot___44 * (*alloc_dquot)(struct super_block___45 *, int);
	void (*destroy_dquot)(struct dquot___44 *);
	int (*acquire_dquot)(struct dquot___44 *);
	int (*release_dquot)(struct dquot___44 *);
	int (*mark_dirty)(struct dquot___44 *);
	int (*write_info)(struct super_block___45 *, int);
	qsize_t * (*get_reserved_space)(struct inode___45 *);
	int (*get_projid)(struct inode___45 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___45 *, qsize_t *);
	int (*get_next_id)(struct super_block___45 *, struct kqid *);
};

struct quotactl_ops___44 {
	int (*quota_on)(struct super_block___45 *, int, int, const struct path___44 *);
	int (*quota_off)(struct super_block___45 *, int);
	int (*quota_enable)(struct super_block___45 *, unsigned int);
	int (*quota_disable)(struct super_block___45 *, unsigned int);
	int (*quota_sync)(struct super_block___45 *, int);
	int (*set_info)(struct super_block___45 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___45 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___45 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___45 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___45 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___45 *, unsigned int);
};

struct wait_page_queue___23 {
	struct page___48 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___23;

struct address_space_operations___44 {
	int (*writepage)(struct page___48 *, struct writeback_control___3 *);
	int (*readpage)(struct file___45 *, struct page___48 *);
	int (*writepages)(struct address_space___44 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___48 *);
	int (*readpages)(struct file___45 *, struct address_space___44 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___23 *);
	int (*write_begin)(struct file___45 *, struct address_space___44 *, loff_t, unsigned int, unsigned int, struct page___48 **, void **);
	int (*write_end)(struct file___45 *, struct address_space___44 *, loff_t, unsigned int, unsigned int, struct page___48 *, void *);
	sector_t (*bmap)(struct address_space___44 *, sector_t);
	void (*invalidatepage)(struct page___48 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___48 *, gfp_t);
	void (*freepage)(struct page___48 *);
	ssize_t (*direct_IO)(struct kiocb___44 *, struct iov_iter___6 *);
	int (*migratepage)(struct address_space___44 *, struct page___48 *, struct page___48 *, enum migrate_mode);
	bool (*isolate_page)(struct page___48 *, isolate_mode_t);
	void (*putback_page)(struct page___48 *);
	int (*launder_page)(struct page___48 *);
	int (*is_partially_uptodate)(struct page___48 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___48 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___44 *, struct page___48 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___45 *, sector_t *);
	void (*swap_deactivate)(struct file___45 *);
};

struct readahead_control___23 {
	struct file___45 *file;
	struct address_space___44 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___44 {
	struct dentry___45 * (*lookup)(struct inode___45 *, struct dentry___45 *, unsigned int);
	const char * (*get_link)(struct dentry___45 *, struct inode___45 *, struct delayed_call *);
	int (*permission)(struct user_namespace___5 *, struct inode___45 *, int);
	struct posix_acl * (*get_acl)(struct inode___45 *, int, bool);
	int (*readlink)(struct dentry___45 *, char *, int);
	int (*create)(struct user_namespace___5 *, struct inode___45 *, struct dentry___45 *, umode_t, bool);
	int (*link)(struct dentry___45 *, struct inode___45 *, struct dentry___45 *);
	int (*unlink)(struct inode___45 *, struct dentry___45 *);
	int (*symlink)(struct user_namespace___5 *, struct inode___45 *, struct dentry___45 *, const char *);
	int (*mkdir)(struct user_namespace___5 *, struct inode___45 *, struct dentry___45 *, umode_t);
	int (*rmdir)(struct inode___45 *, struct dentry___45 *);
	int (*mknod)(struct user_namespace___5 *, struct inode___45 *, struct dentry___45 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___5 *, struct inode___45 *, struct dentry___45 *, struct inode___45 *, struct dentry___45 *, unsigned int);
	int (*setattr)(struct user_namespace___5 *, struct dentry___45 *, struct iattr___45 *);
	int (*getattr)(struct user_namespace___5 *, const struct path___44 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___45 *, char *, size_t);
	int (*fiemap)(struct inode___45 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___45 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___45 *, struct dentry___45 *, struct file___45 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___5 *, struct inode___45 *, struct dentry___45 *, umode_t);
	int (*set_acl)(struct user_namespace___5 *, struct inode___45 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___5 *, struct dentry___45 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___45 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___44 {
	void (*fl_copy_lock)(struct file_lock___44 *, struct file_lock___44 *);
	void (*fl_release_private)(struct file_lock___44 *);
};

struct lock_manager_operations___44;

struct file_lock___44 {
	struct file_lock___44 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___45 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___44 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___44 *fl_ops;
	const struct lock_manager_operations___44 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___44 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___44 *);
	int (*lm_grant)(struct file_lock___44 *, int);
	bool (*lm_break)(struct file_lock___44 *);
	int (*lm_change)(struct file_lock___44 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___44 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___44 *);
};

struct fasync_struct___44 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___44 *fa_next;
	struct file___45 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___44 {
	struct inode___45 * (*alloc_inode)(struct super_block___45 *);
	void (*destroy_inode)(struct inode___45 *);
	void (*free_inode)(struct inode___45 *);
	void (*dirty_inode)(struct inode___45 *, int);
	int (*write_inode)(struct inode___45 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___45 *);
	void (*evict_inode)(struct inode___45 *);
	void (*put_super)(struct super_block___45 *);
	int (*sync_fs)(struct super_block___45 *, int);
	int (*freeze_super)(struct super_block___45 *);
	int (*freeze_fs)(struct super_block___45 *);
	int (*thaw_super)(struct super_block___45 *);
	int (*unfreeze_fs)(struct super_block___45 *);
	int (*statfs)(struct dentry___45 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___45 *, int *, char *);
	void (*umount_begin)(struct super_block___45 *);
	int (*show_options)(struct seq_file___44 *, struct dentry___45 *);
	int (*show_devname)(struct seq_file___44 *, struct dentry___45 *);
	int (*show_path)(struct seq_file___44 *, struct dentry___45 *);
	int (*show_stats)(struct seq_file___44 *, struct dentry___45 *);
	ssize_t (*quota_read)(struct super_block___45 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___45 *, int, const char *, size_t, loff_t);
	struct dquot___44 ** (*get_dquots)(struct inode___45 *);
	long int (*nr_cached_objects)(struct super_block___45 *, struct shrink_control___4 *);
	long int (*free_cached_objects)(struct super_block___45 *, struct shrink_control___4 *);
	struct file___45 * (*real_loop)(struct file___45 *);
};

typedef void (*poll_queue_proc___35)(struct file___45 *, wait_queue_head_t *, struct poll_table_struct___35 *);

struct poll_table_struct___35 {
	poll_queue_proc___35 _qproc;
	__poll_t _key;
};

struct seq_operations___43;

struct seq_file___44 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___43 *op;
	int poll_event;
	const struct file___45 *file;
	void *private;
};

struct dev_pagemap_ops___44 {
	void (*page_free)(struct page___48 *);
	void (*kill)(struct dev_pagemap___44 *);
	void (*cleanup)(struct dev_pagemap___44 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___44 *);
};

struct fwnode_operations___43;

struct device___43;

struct fwnode_handle___43 {
	struct fwnode_handle___43 *secondary;
	const struct fwnode_operations___43 *ops;
	struct device___43 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___43;

struct fwnode_endpoint___43;

struct fwnode_operations___43 {
	struct fwnode_handle___43 * (*get)(struct fwnode_handle___43 *);
	void (*put)(struct fwnode_handle___43 *);
	bool (*device_is_available)(const struct fwnode_handle___43 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___43 *, const struct device___43 *);
	bool (*property_present)(const struct fwnode_handle___43 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___43 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___43 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___43 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*get_parent)(const struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*get_next_child_node)(const struct fwnode_handle___43 *, struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*get_named_child_node)(const struct fwnode_handle___43 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___43 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___43 *);
	struct fwnode_handle___43 * (*graph_get_next_endpoint)(const struct fwnode_handle___43 *, struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*graph_get_remote_endpoint)(const struct fwnode_handle___43 *);
	struct fwnode_handle___43 * (*graph_get_port_parent)(struct fwnode_handle___43 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___43 *, struct fwnode_endpoint___43 *);
	int (*add_links)(struct fwnode_handle___43 *);
};

struct wakeup_source___43;

struct dev_pm_info___43 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___43 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___43 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___43;

struct bus_type___43;

struct device_driver___43;

struct dev_pm_domain___43;

struct class___43;

struct attribute_group___46;

struct device___43 {
	struct kobject___46 kobj;
	struct device___43 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___43 *type;
	struct bus_type___43 *bus;
	struct device_driver___43 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___43 power;
	struct dev_pm_domain___43 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___43 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___43 *class;
	const struct attribute_group___46 **groups;
	void (*release)(struct device___43 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___43 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___43 *local_fwnode;
};

struct fwnode_reference_args___43 {
	struct fwnode_handle___43 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___46;

struct kernfs_elem_dir___46 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___46 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___46;

struct kernfs_root___46 {
	struct kernfs_node___46 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___46 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___46 {
	struct kernfs_node___46 *target_kn;
};

struct kernfs_ops___46;

struct kernfs_elem_attr___46 {
	const struct kernfs_ops___46 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___46 *notify_next;
};

struct kernfs_node___46 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___46 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___46 dir;
		struct kernfs_elem_symlink___46 symlink;
		struct kernfs_elem_attr___46 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___46;

struct kernfs_ops___46 {
	int (*open)(struct kernfs_open_file___46 *);
	void (*release)(struct kernfs_open_file___46 *);
	int (*seq_show)(struct seq_file___44 *, void *);
	void * (*seq_start)(struct seq_file___44 *, loff_t *);
	void * (*seq_next)(struct seq_file___44 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___44 *, void *);
	ssize_t (*read)(struct kernfs_open_file___46 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___46 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___46 *, struct poll_table_struct___35 *);
	int (*mmap)(struct kernfs_open_file___46 *, struct vm_area_struct___48 *);
};

struct kernfs_syscall_ops___46 {
	int (*show_options)(struct seq_file___44 *, struct kernfs_root___46 *);
	int (*mkdir)(struct kernfs_node___46 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___46 *);
	int (*rename)(struct kernfs_node___46 *, struct kernfs_node___46 *, const char *);
	int (*show_path)(struct seq_file___44 *, struct kernfs_node___46 *, struct kernfs_root___46 *);
};

struct kernfs_open_file___46 {
	struct kernfs_node___46 *kn;
	struct file___45 *file;
	struct seq_file___44 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___44 *vm_ops;
};

struct bin_attribute___46;

struct attribute_group___46 {
	const char *name;
	umode_t (*is_visible)(struct kobject___46 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___46 *, struct bin_attribute___46 *, int);
	struct attribute **attrs;
	struct bin_attribute___46 **bin_attrs;
};

struct bin_attribute___46 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___44 * (*f_mapping)();
	ssize_t (*read)(struct file___45 *, struct kobject___46 *, struct bin_attribute___46 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___45 *, struct kobject___46 *, struct bin_attribute___46 *, char *, loff_t, size_t);
	int (*mmap)(struct file___45 *, struct kobject___46 *, struct bin_attribute___46 *, struct vm_area_struct___48 *);
};

struct sysfs_ops___46 {
	ssize_t (*show)(struct kobject___46 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___46 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___46;

struct kset___46 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___46 kobj;
	const struct kset_uevent_ops___46 *uevent_ops;
};

struct kobj_type___46 {
	void (*release)(struct kobject___46 *);
	const struct sysfs_ops___46 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___46 **default_groups;
	const struct kobj_ns_type_operations * (*child_ns_type)(struct kobject___46 *);
	const void * (*namespace)(struct kobject___46 *);
	void (*get_ownership)(struct kobject___46 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___46 {
	int (* const filter)(struct kset___46 *, struct kobject___46 *);
	const char * (* const name)(struct kset___46 *, struct kobject___46 *);
	int (* const uevent)(struct kset___46 *, struct kobject___46 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___43 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___43 *);
	int (*get)(char *, const struct kernel_param___43 *);
	void (*free)(void *);
};

struct kparam_array___43;

struct kernel_param___43 {
	const char *name;
	struct module___45 *mod;
	const struct kernel_param_ops___43 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___43 *arr;
	};
};

struct kparam_array___43 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___43 *ops;
	void *elem;
};

struct module_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___43 *, struct module_kobject___43 *, char *);
	ssize_t (*store)(struct module_attribute___43 *, struct module_kobject___43 *, const char *, size_t);
	void (*setup)(struct module___45 *, const char *);
	int (*test)(struct module___45 *);
	void (*free)(struct module___45 *);
};

struct trace_event_class___27;

struct trace_event_call___27 {
	struct list_head list;
	struct trace_event_class___27 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array *prog_array;
	int (*perf_perm)(struct trace_event_call___27 *, struct perf_event___32 *);
};

struct time_namespace___5 {
	struct user_namespace___5 *user_ns;
	struct ucounts___5 *ucounts;
	struct ns_common___6 ns;
	struct timens_offsets offsets;
	struct page___48 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___36 {
	struct ns_common___6 ns;
	struct user_namespace___5 *user_ns;
	struct ucounts___5 *ucounts;
	struct css_set___36 *root_cset;
};

struct dev_pm_ops___43 {
	int (*prepare)(struct device___43 *);
	void (*complete)(struct device___43 *);
	int (*suspend)(struct device___43 *);
	int (*resume)(struct device___43 *);
	int (*freeze)(struct device___43 *);
	int (*thaw)(struct device___43 *);
	int (*poweroff)(struct device___43 *);
	int (*restore)(struct device___43 *);
	int (*suspend_late)(struct device___43 *);
	int (*resume_early)(struct device___43 *);
	int (*freeze_late)(struct device___43 *);
	int (*thaw_early)(struct device___43 *);
	int (*poweroff_late)(struct device___43 *);
	int (*restore_early)(struct device___43 *);
	int (*suspend_noirq)(struct device___43 *);
	int (*resume_noirq)(struct device___43 *);
	int (*freeze_noirq)(struct device___43 *);
	int (*thaw_noirq)(struct device___43 *);
	int (*poweroff_noirq)(struct device___43 *);
	int (*restore_noirq)(struct device___43 *);
	int (*runtime_suspend)(struct device___43 *);
	int (*runtime_resume)(struct device___43 *);
	int (*runtime_idle)(struct device___43 *);
};

struct wakeup_source___43 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___43 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___43 {
	struct dev_pm_ops___43 ops;
	int (*start)(struct device___43 *);
	void (*detach)(struct device___43 *, bool);
	int (*activate)(struct device___43 *);
	void (*sync)(struct device___43 *);
	void (*dismiss)(struct device___43 *);
};

struct bus_type___43 {
	const char *name;
	const char *dev_name;
	struct device___43 *dev_root;
	const struct attribute_group___46 **bus_groups;
	const struct attribute_group___46 **dev_groups;
	const struct attribute_group___46 **drv_groups;
	int (*match)(struct device___43 *, struct device_driver___43 *);
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	int (*probe)(struct device___43 *);
	void (*sync_state)(struct device___43 *);
	void (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*online)(struct device___43 *);
	int (*offline)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	int (*num_vf)(struct device___43 *);
	int (*dma_configure)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___43 {
	const char *name;
	struct bus_type___43 *bus;
	struct module___45 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___43 *);
	void (*sync_state)(struct device___43 *);
	int (*remove)(struct device___43 *);
	void (*shutdown)(struct device___43 *);
	int (*suspend)(struct device___43 *, pm_message_t);
	int (*resume)(struct device___43 *);
	const struct attribute_group___46 **groups;
	const struct attribute_group___46 **dev_groups;
	const struct dev_pm_ops___43 *pm;
	void (*coredump)(struct device___43 *);
	struct driver_private *p;
};

struct device_type___43 {
	const char *name;
	const struct attribute_group___46 **groups;
	int (*uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___43 *);
	const struct dev_pm_ops___43 *pm;
};

struct class___43 {
	const char *name;
	struct module___45 *owner;
	const struct attribute_group___46 **class_groups;
	const struct attribute_group___46 **dev_groups;
	struct kobject___46 *dev_kobj;
	int (*dev_uevent)(struct device___43 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___43 *, umode_t *);
	void (*class_release)(struct class___43 *);
	void (*dev_release)(struct device___43 *);
	int (*shutdown_pre)(struct device___43 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___43 *);
	void (*get_ownership)(struct device___43 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___43 *pm;
	struct subsys_private *p;
};

struct seq_operations___43 {
	void * (*start)(struct seq_file___44 *, loff_t *);
	void (*stop)(struct seq_file___44 *, void *);
	void * (*next)(struct seq_file___44 *, void *, loff_t *);
	int (*show)(struct seq_file___44 *, void *);
};

struct cftype___36;

struct cgroup_subsys___36 {
	struct cgroup_subsys_state___36 * (*css_alloc)(struct cgroup_subsys_state___36 *);
	int (*css_online)(struct cgroup_subsys_state___36 *);
	void (*css_offline)(struct cgroup_subsys_state___36 *);
	void (*css_released)(struct cgroup_subsys_state___36 *);
	void (*css_free)(struct cgroup_subsys_state___36 *);
	void (*css_reset)(struct cgroup_subsys_state___36 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___36 *, int);
	int (*css_extra_stat_show)(struct seq_file___44 *, struct cgroup_subsys_state___36 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___49 *, struct css_set___36 *);
	void (*cancel_fork)(struct task_struct___49 *, struct css_set___36 *);
	void (*fork)(struct task_struct___49 *);
	void (*exit)(struct task_struct___49 *);
	void (*release)(struct task_struct___49 *);
	void (*bind)(struct cgroup_subsys_state___36 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___36 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___36 *dfl_cftypes;
	struct cftype___36 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___36 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___36 *updated_children;
	struct cgroup___36 *updated_next;
};

struct cgroup_root___36 {
	struct kernfs_root___46 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___36 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___36 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___36 *ss;
	struct list_head node;
	struct kernfs_ops___46 *kf_ops;
	int (*open)(struct kernfs_open_file___46 *);
	void (*release)(struct kernfs_open_file___46 *);
	u64 (*read_u64)(struct cgroup_subsys_state___36 *, struct cftype___36 *);
	s64 (*read_s64)(struct cgroup_subsys_state___36 *, struct cftype___36 *);
	int (*seq_show)(struct seq_file___44 *, void *);
	void * (*seq_start)(struct seq_file___44 *, loff_t *);
	void * (*seq_next)(struct seq_file___44 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___44 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___36 *, struct cftype___36 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___36 *, struct cftype___36 *, s64);
	ssize_t (*write)(struct kernfs_open_file___46 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___46 *, struct poll_table_struct___35 *);
};

struct perf_cpu_context___32;

struct perf_output_handle___32;

struct pmu___32 {
	struct list_head entry;
	struct module___45 *module;
	struct device___43 *dev;
	const struct attribute_group___46 **attr_groups;
	const struct attribute_group___46 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___32 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___32 *);
	void (*pmu_disable)(struct pmu___32 *);
	int (*event_init)(struct perf_event___32 *);
	void (*event_mapped)(struct perf_event___32 *, struct mm_struct___49 *);
	void (*event_unmapped)(struct perf_event___32 *, struct mm_struct___49 *);
	int (*add)(struct perf_event___32 *, int);
	void (*del)(struct perf_event___32 *, int);
	void (*start)(struct perf_event___32 *, int);
	void (*stop)(struct perf_event___32 *, int);
	void (*read)(struct perf_event___32 *);
	void (*start_txn)(struct pmu___32 *, unsigned int);
	int (*commit_txn)(struct pmu___32 *);
	void (*cancel_txn)(struct pmu___32 *);
	int (*event_idx)(struct perf_event___32 *);
	void (*sched_task)(struct perf_event_context___32 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___32 *, struct perf_event_context___32 *);
	void * (*setup_aux)(struct perf_event___32 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___32 *, struct perf_output_handle___32 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___32 *);
	int (*aux_output_match)(struct perf_event___32 *);
	int (*filter_match)(struct perf_event___32 *);
	int (*check_period)(struct perf_event___32 *, u64);
};

struct perf_cpu_context___32 {
	struct perf_event_context___32 ctx;
	struct perf_event_context___32 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___32 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___32 **heap;
	struct perf_event___32 *heap_default[2];
};

struct perf_output_handle___32 {
	struct perf_event___32 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___32 {
	struct cgroup_subsys_state___36 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___27 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___27 *);
	};
};

struct trace_event_class___27 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___27 *, enum trace_reg, void *);
	struct trace_event_fields___27 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___27 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___27 *);
};

struct syscall_metadata___13 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___27 *enter_event;
	struct trace_event_call___27 *exit_event;
};

struct rt_wake_q_head___2 {
	struct wake_q_head head;
	struct task_struct___49 *rtlock_task;
};

struct futex_q {
	struct plist_node list;
	struct task_struct___49 *task;
	spinlock_t *lock_ptr;
	union futex_key key;
	struct futex_pi_state *pi_state;
	struct rt_mutex_waiter___3 *rt_waiter;
	union futex_key *requeue_pi_key;
	u32 bitset;
	atomic_t requeue_state;
};

enum {
	Q_REQUEUE_PI_NONE = 0,
	Q_REQUEUE_PI_IGNORE = 1,
	Q_REQUEUE_PI_IN_PROGRESS = 2,
	Q_REQUEUE_PI_WAIT = 3,
	Q_REQUEUE_PI_DONE = 4,
	Q_REQUEUE_PI_LOCKED = 5,
};

struct futex_hash_bucket {
	atomic_t waiters;
	spinlock_t lock;
	struct plist_head chain;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum futex_access {
	FUTEX_READ = 0,
	FUTEX_WRITE = 1,
};

struct cfd_percpu {
	call_single_data_t csd;
};

struct call_function_data {
	struct cfd_percpu *pcpu;
	cpumask_var_t cpumask;
	cpumask_var_t cpumask_ipi;
};

struct smp_call_on_cpu_struct {
	struct work_struct work;
	struct completion done;
	int (*func)(void *);
	void *data;
	int ret;
	int cpu;
};

typedef short unsigned int __kernel_old_uid_t;

typedef short unsigned int __kernel_old_gid_t;

typedef __kernel_old_uid_t old_uid_t;

typedef __kernel_old_gid_t old_gid_t;

struct latch_tree_root {
	seqcount_latch_t seq;
	struct rb_root tree[2];
};

struct latch_tree_ops {
	bool (*less)(struct latch_tree_node *, struct latch_tree_node *);
	int (*comp)(void *, struct latch_tree_node *);
};

struct modversion_info {
	long unsigned int crc;
	char name[56];
};

struct module_use {
	struct list_head source_list;
	struct list_head target_list;
	struct module___14 *source;
	struct module___14 *target;
};

struct module_sect_attr {
	struct bin_attribute___12 battr;
	long unsigned int address;
};

struct module_sect_attrs {
	struct attribute_group___12 grp;
	unsigned int nsections;
	struct module_sect_attr attrs[0];
};

struct module_notes_attrs {
	struct kobject___12 *dir;
	unsigned int notes;
	struct bin_attribute___12 attrs[0];
};

enum kernel_read_file_id {
	READING_UNKNOWN = 0,
	READING_FIRMWARE = 1,
	READING_MODULE = 2,
	READING_KEXEC_IMAGE = 3,
	READING_KEXEC_INITRAMFS = 4,
	READING_POLICY = 5,
	READING_X509_CERTIFICATE = 6,
	READING_MAX_ID = 7,
};

enum kernel_load_data_id {
	LOADING_UNKNOWN = 0,
	LOADING_FIRMWARE = 1,
	LOADING_MODULE = 2,
	LOADING_KEXEC_IMAGE = 3,
	LOADING_KEXEC_INITRAMFS = 4,
	LOADING_POLICY = 5,
	LOADING_X509_CERTIFICATE = 6,
	LOADING_MAX_ID = 7,
};

enum {
	PROC_ENTRY_PERMANENT = 1,
};

struct proc_ops___4 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___14 *, struct file___13 *);
	ssize_t (*proc_read)(struct file___13 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___12 *, struct iov_iter___5 *);
	ssize_t (*proc_write)(struct file___13 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___13 *, loff_t, int);
	int (*proc_release)(struct inode___14 *, struct file___13 *);
	__poll_t (*proc_poll)(struct file___13 *, struct poll_table_struct___9 *);
	long int (*proc_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___13 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___13 *, struct vm_area_struct___12 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___13 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct load_info {
	const char *name;
	struct module___14 *mod;
	Elf64_Ehdr *hdr;
	long unsigned int len;
	Elf64_Shdr *sechdrs;
	char *secstrings;
	char *strtab;
	long unsigned int symoffs;
	long unsigned int stroffs;
	long unsigned int init_typeoffs;
	long unsigned int core_typeoffs;
	struct _ddebug *debug;
	unsigned int num_debug;
	bool sig_ok;
	long unsigned int mod_kallsyms_init_off;
	struct {
		unsigned int sym;
		unsigned int str;
		unsigned int mod;
		unsigned int vers;
		unsigned int info;
		unsigned int pcpu;
	} index;
};

struct trace_event_raw_module_load {
	struct trace_entry ent;
	unsigned int taints;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_module_free {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_module_refcnt {
	struct trace_entry ent;
	long unsigned int ip;
	int refcnt;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_module_request {
	struct trace_entry ent;
	long unsigned int ip;
	bool wait;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_data_offsets_module_load {
	u32 name;
};

struct trace_event_data_offsets_module_free {
	u32 name;
};

struct trace_event_data_offsets_module_refcnt {
	u32 name;
};

struct trace_event_data_offsets_module_request {
	u32 name;
};

typedef void (*btf_trace_module_load)(void *, struct module___14 *);

typedef void (*btf_trace_module_free)(void *, struct module___14 *);

typedef void (*btf_trace_module_get)(void *, struct module___14 *, long unsigned int);

typedef void (*btf_trace_module_put)(void *, struct module___14 *, long unsigned int);

typedef void (*btf_trace_module_request)(void *, char *, bool, long unsigned int);

struct mod_tree_root {
	struct latch_tree_root root;
	long unsigned int addr_min;
	long unsigned int addr_max;
};

enum mod_license {
	NOT_GPL_ONLY = 0,
	GPL_ONLY = 1,
};

struct symsearch {
	const struct kernel_symbol *start;
	const struct kernel_symbol *stop;
	const s32 *crcs;
	enum mod_license license;
};

struct find_symbol_arg {
	const char *name;
	bool gplok;
	bool warn;
	struct module___14 *owner;
	const s32 *crc;
	const struct kernel_symbol *sym;
	enum mod_license license;
};

struct mod_initfree {
	struct llist_node node;
	void *module_init;
};

struct module_signature {
	u8 algo;
	u8 hash;
	u8 id_type;
	u8 signer_len;
	u8 key_id_len;
	u8 __pad[3];
	__be32 sig_len;
};

struct load_info___2 {
	const char *name;
	struct module___12 *mod;
	Elf64_Ehdr *hdr;
	long unsigned int len;
	Elf64_Shdr *sechdrs;
	char *secstrings;
	char *strtab;
	long unsigned int symoffs;
	long unsigned int stroffs;
	long unsigned int init_typeoffs;
	long unsigned int core_typeoffs;
	struct _ddebug *debug;
	unsigned int num_debug;
	bool sig_ok;
	long unsigned int mod_kallsyms_init_off;
	struct {
		unsigned int sym;
		unsigned int str;
		unsigned int mod;
		unsigned int vers;
		unsigned int info;
		unsigned int pcpu;
	} index;
};

enum pkey_id_type {
	PKEY_ID_PGP = 0,
	PKEY_ID_X509 = 1,
	PKEY_ID_PKCS7 = 2,
};

struct proc_ops___5 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___21 *, struct file___20 *);
	ssize_t (*proc_read)(struct file___20 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___19 *, struct iov_iter___8 *);
	ssize_t (*proc_write)(struct file___20 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___20 *, loff_t, int);
	int (*proc_release)(struct inode___21 *, struct file___20 *);
	__poll_t (*proc_poll)(struct file___20 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___20 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___20 *, struct vm_area_struct___19 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___20 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct kallsym_iter {
	loff_t pos;
	loff_t pos_arch_end;
	loff_t pos_mod_end;
	loff_t pos_ftrace_mod_end;
	loff_t pos_bpf_end;
	long unsigned int value;
	unsigned int nameoff;
	char type;
	char name[128];
	char module_name[56];
	int exported;
	int show_value;
};

typedef struct {
	int val[2];
} __kernel_fsid_t;

struct kstatfs {
	long int f_type;
	long int f_bsize;
	u64 f_blocks;
	u64 f_bfree;
	u64 f_bavail;
	u64 f_files;
	u64 f_ffree;
	__kernel_fsid_t f_fsid;
	long int f_namelen;
	long int f_frsize;
	long int f_flags;
	long int f_spare[4];
};

typedef __u16 comp_t;

struct acct_v3 {
	char ac_flag;
	char ac_version;
	__u16 ac_tty;
	__u32 ac_exitcode;
	__u32 ac_uid;
	__u32 ac_gid;
	__u32 ac_pid;
	__u32 ac_ppid;
	__u32 ac_btime;
	__u32 ac_etime;
	comp_t ac_utime;
	comp_t ac_stime;
	comp_t ac_mem;
	comp_t ac_io;
	comp_t ac_rw;
	comp_t ac_minflt;
	comp_t ac_majflt;
	comp_t ac_swaps;
	char ac_comm[16];
};

typedef struct acct_v3 acct_t;

struct fs_pin {
	wait_queue_head_t wait;
	int done;
	struct hlist_node s_list;
	struct hlist_node m_list;
	void (*kill)(struct fs_pin *);
};

struct bsd_acct_struct {
	struct fs_pin pin;
	atomic_long_t count;
	struct callback_head rcu;
	struct mutex lock;
	int active;
	long unsigned int needcheck;
	struct file___30 *file;
	struct pid_namespace___27 *ns;
	struct work_struct work;
	struct completion done;
};

struct elf64_note {
	Elf64_Word n_namesz;
	Elf64_Word n_descsz;
	Elf64_Word n_type;
};

typedef long unsigned int elf_greg_t;

typedef elf_greg_t elf_gregset_t[34];

struct elf_siginfo {
	int si_signo;
	int si_code;
	int si_errno;
};

struct elf_prstatus_common {
	struct elf_siginfo pr_info;
	short int pr_cursig;
	long unsigned int pr_sigpend;
	long unsigned int pr_sighold;
	pid_t pr_pid;
	pid_t pr_ppid;
	pid_t pr_pgrp;
	pid_t pr_sid;
	struct __kernel_old_timeval pr_utime;
	struct __kernel_old_timeval pr_stime;
	struct __kernel_old_timeval pr_cutime;
	struct __kernel_old_timeval pr_cstime;
};

struct elf_prstatus {
	struct elf_prstatus_common common;
	elf_gregset_t pr_reg;
	int pr_fpvalid;
};

typedef u32 note_buf_t[106];

struct kimage___3;

typedef void *kexec_load_t___3(struct kimage___3 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___3 {
	kexec_probe_t *probe;
	kexec_load_t___3 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct kimage___3 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___31 *control_code_page;
	struct page___31 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___3 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *ima_buffer;
	phys_addr_t ima_buffer_addr;
	size_t ima_buffer_size;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

struct compat_kexec_segment {
	compat_uptr_t buf;
	compat_size_t bufsz;
	compat_ulong_t mem;
	compat_size_t memsz;
};

struct elf64_phdr {
	Elf64_Word p_type;
	Elf64_Word p_flags;
	Elf64_Off p_offset;
	Elf64_Addr p_vaddr;
	Elf64_Addr p_paddr;
	Elf64_Xword p_filesz;
	Elf64_Xword p_memsz;
	Elf64_Xword p_align;
};

typedef struct elf64_phdr Elf64_Phdr;

struct kimage___4;

typedef void *kexec_load_t___4(struct kimage___4 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___4 {
	kexec_probe_t *probe;
	kexec_load_t___4 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct kimage___4 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___13 *control_code_page;
	struct page___13 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type: 1;
	unsigned int preserve_context: 1;
	unsigned int file_mode: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___4 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *ima_buffer;
	phys_addr_t ima_buffer_addr;
	size_t ima_buffer_size;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

struct kexec_buf___2 {
	struct kimage___4 *image;
	void *buffer;
	long unsigned int bufsz;
	long unsigned int mem;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

enum hash_algo {
	HASH_ALGO_MD4 = 0,
	HASH_ALGO_MD5 = 1,
	HASH_ALGO_SHA1 = 2,
	HASH_ALGO_RIPE_MD_160 = 3,
	HASH_ALGO_SHA256 = 4,
	HASH_ALGO_SHA384 = 5,
	HASH_ALGO_SHA512 = 6,
	HASH_ALGO_SHA224 = 7,
	HASH_ALGO_RIPE_MD_128 = 8,
	HASH_ALGO_RIPE_MD_256 = 9,
	HASH_ALGO_RIPE_MD_320 = 10,
	HASH_ALGO_WP_256 = 11,
	HASH_ALGO_WP_384 = 12,
	HASH_ALGO_WP_512 = 13,
	HASH_ALGO_TGR_128 = 14,
	HASH_ALGO_TGR_160 = 15,
	HASH_ALGO_TGR_192 = 16,
	HASH_ALGO_SM3_256 = 17,
	HASH_ALGO_STREEBOG_256 = 18,
	HASH_ALGO_STREEBOG_512 = 19,
	HASH_ALGO__LAST = 20,
};

struct crypto_alg;

struct crypto_tfm {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm *);
	struct crypto_alg *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm *, u8 *, const u8 *);
};

struct compress_alg {
	int (*coa_compress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_istat_aead {
	atomic64_t encrypt_cnt;
	atomic64_t encrypt_tlen;
	atomic64_t decrypt_cnt;
	atomic64_t decrypt_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_akcipher {
	atomic64_t encrypt_cnt;
	atomic64_t encrypt_tlen;
	atomic64_t decrypt_cnt;
	atomic64_t decrypt_tlen;
	atomic64_t verify_cnt;
	atomic64_t sign_cnt;
	atomic64_t err_cnt;
};

struct crypto_istat_cipher {
	atomic64_t encrypt_cnt;
	atomic64_t encrypt_tlen;
	atomic64_t decrypt_cnt;
	atomic64_t decrypt_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_compress {
	atomic64_t compress_cnt;
	atomic64_t compress_tlen;
	atomic64_t decompress_cnt;
	atomic64_t decompress_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_hash {
	atomic64_t hash_cnt;
	atomic64_t hash_tlen;
	atomic64_t err_cnt;
};

struct crypto_istat_kpp {
	atomic64_t setsecret_cnt;
	atomic64_t generate_public_key_cnt;
	atomic64_t compute_shared_secret_cnt;
	atomic64_t err_cnt;
};

struct crypto_istat_rng {
	atomic64_t generate_cnt;
	atomic64_t generate_tlen;
	atomic64_t seed_cnt;
	atomic64_t err_cnt;
};

struct crypto_type;

struct crypto_alg {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg cipher;
		struct compress_alg compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm *);
	void (*cra_exit)(struct crypto_tfm *);
	void (*cra_destroy)(struct crypto_alg *);
	struct module___14 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___6;

struct crypto_alg___2;

struct crypto_tfm___2;

struct crypto_instance;

struct crypto_type {
	unsigned int (*ctxsize)(struct crypto_alg___2 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___2 *);
	int (*init)(struct crypto_tfm___2 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___2 *);
	void (*show)(struct seq_file___9 *, struct crypto_alg___2 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___2 *);
	void (*free)(struct crypto_instance *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_shash;

struct shash_desc {
	struct crypto_shash *tfm;
	void *__ctx[0];
};

struct crypto_shash {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm base;
};

struct kexec_sha_region {
	long unsigned int start;
	long unsigned int len;
};

enum migrate_reason {
	MR_COMPACTION = 0,
	MR_MEMORY_FAILURE = 1,
	MR_MEMORY_HOTPLUG = 2,
	MR_SYSCALL = 3,
	MR_MEMPOLICY_MBIND = 4,
	MR_NUMA_MISPLACED = 5,
	MR_CONTIG_RANGE = 6,
	MR_LONGTERM_PIN = 7,
	MR_DEMOTION = 8,
	MR_TYPES = 9,
};

typedef __kernel_ulong_t ino_t;

struct fs_context___5;

struct fs_parameter_spec___5;

struct dentry___46;

struct super_block___46;

struct module___46;

struct file_system_type___45 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___5 *);
	const struct fs_parameter_spec___5 *parameters;
	struct dentry___46 * (*mount)(struct file_system_type___45 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___46 *);
	struct module___46 *owner;
	struct file_system_type___45 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___46;

struct kiocb___45;

struct iov_iter___25;

struct poll_table_struct___36;

struct vm_area_struct___49;

struct inode___46;

struct file_lock___45;

struct page___49;

struct pipe_inode_info___14;

struct seq_file___45;

struct file_operations___45 {
	struct module___46 *owner;
	loff_t (*llseek)(struct file___46 *, loff_t, int);
	ssize_t (*read)(struct file___46 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___46 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___45 *, struct iov_iter___25 *);
	ssize_t (*write_iter)(struct kiocb___45 *, struct iov_iter___25 *);
	int (*iopoll)(struct kiocb___45 *, bool);
	int (*iterate)(struct file___46 *, struct dir_context *);
	int (*iterate_shared)(struct file___46 *, struct dir_context *);
	__poll_t (*poll)(struct file___46 *, struct poll_table_struct___36 *);
	long int (*unlocked_ioctl)(struct file___46 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___46 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___46 *, struct vm_area_struct___49 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___46 *, struct file___46 *);
	int (*flush)(struct file___46 *, fl_owner_t);
	int (*release)(struct inode___46 *, struct file___46 *);
	int (*fsync)(struct file___46 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___46 *, int);
	int (*lock)(struct file___46 *, int, struct file_lock___45 *);
	ssize_t (*sendpage)(struct file___46 *, struct page___49 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___46 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___46 *, long unsigned int);
	int (*flock)(struct file___46 *, int, struct file_lock___45 *);
	ssize_t (*splice_write)(struct pipe_inode_info___14 *, struct file___46 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___46 *, loff_t *, struct pipe_inode_info___14 *, size_t, unsigned int);
	int (*setlease)(struct file___46 *, long int, struct file_lock___45 **, void **);
	long int (*fallocate)(struct file___46 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___45 *, struct file___46 *);
	ssize_t (*copy_file_range)(struct file___46 *, loff_t, struct file___46 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___46 *, loff_t, struct file___46 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___46 *, loff_t, loff_t, int);
};

struct vmacache___49 {
	u64 seqnum;
	struct vm_area_struct___49 *vmas[4];
};

struct page_frag___49 {
	struct page___49 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___33;

struct debug_info___33 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___33 *hbp_break[16];
	struct perf_event___33 *hbp_watch[16];
};

struct thread_struct___33 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___33 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___50;

struct pid___43;

struct cred___5;

struct nsproxy___45;

struct signal_struct___46;

struct bio_list___22;

struct backing_dev_info___21;

struct io_context___23;

struct css_set___37;

struct perf_event_context___33;

struct mem_cgroup___21;

struct request_queue___23;

struct vm_struct___48;

struct task_struct___50 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___50 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___50 *mm;
	struct mm_struct___50 *active_mm;
	struct vmacache___49 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___50 *real_parent;
	struct task_struct___50 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___50 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___43 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___5 *ptracer_cred;
	const struct cred___5 *real_cred;
	const struct cred___5 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___45 *nsproxy;
	struct signal_struct___46 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___50 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___22 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___21 *backing_dev_info;
	struct io_context___23 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___37 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___33 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___14 *splice_pipe;
	struct page_frag___49 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___21 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___21 *active_memcg;
	struct request_queue___23 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___50 *oom_reaper_list;
	struct vm_struct___48 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___47;

struct kobj_type___47;

struct kernfs_node___47;

struct kobject___47 {
	const char *name;
	struct list_head entry;
	struct kobject___47 *parent;
	struct kset___47 *kset;
	struct kobj_type___47 *ktype;
	struct kernfs_node___47 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___44 {
	struct kobject___47 kobj;
	struct module___46 *mod;
	struct kobject___47 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___44 {
	struct module___46 *mod;
	struct latch_tree_node node;
};

struct module_layout___44 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___44 mtn;
};

struct module_attribute___44;

struct kernel_param___44;

struct trace_event_call___28;

struct module___46 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___44 mkobj;
	struct module_attribute___44 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___47 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___44 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___44 core_layout;
	struct module_layout___44 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___28 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___33 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___50 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___33)(struct perf_event___33 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___33;

struct fasync_struct___45;

struct pid_namespace___43;

struct bpf_prog___5;

struct perf_cgroup___33;

struct perf_event___33 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___33 *group_leader;
	struct pmu___33 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___33 hw;
	struct perf_event_context___33 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___33 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___50 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___45 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___33 *aux_event;
	void (*destroy)(struct perf_event___33 *);
	struct callback_head callback_head;
	struct pid_namespace___43 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___33 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___33 orig_overflow_handler;
	struct bpf_prog___5 *prog;
	u64 bpf_cookie;
	struct trace_event_call___28 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___33 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___43 {
	int nr;
	struct pid_namespace___43 *ns;
};

struct proc_ns_operations___7;

struct ns_common___7 {
	atomic_long_t stashed;
	const struct proc_ns_operations___7 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___6;

struct ucounts___6;

struct pid_namespace___43 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___50 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___43 *parent;
	struct fs_pin *bacct;
	struct user_namespace___6 *user_ns;
	struct ucounts___6 *ucounts;
	int reboot;
	struct ns_common___7 ns;
};

struct pid___43 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___43 numbers[1];
};

struct user_namespace___6 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___6 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___7 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___6 *ucounts;
	long int ucount_max[16];
};

typedef struct page___49 *pgtable_t___49;

struct address_space___45;

struct page_pool___13;

struct dev_pagemap___45;

struct page___49 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___45 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___49 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___49 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___50 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___45 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___6 {
	struct hlist_node node;
	struct user_namespace___6 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___45;

struct vm_area_struct___49 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___49 *vm_next;
	struct vm_area_struct___49 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___50 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___45 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___46 *vm_file;
	struct file___46 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___46 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___50 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___50 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___43 *pids[4];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___50 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___49;

struct mm_struct___50 {
	struct {
		struct vm_area_struct___49 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___46 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___49 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___50 *owner;
		struct user_namespace___6 *user_ns;
		struct file___46 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___5 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___6 *user_ns;
	struct ucounts___6 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct uts_namespace___5;

struct net___8;

struct cgroup_namespace___37;

struct nsproxy___45 {
	atomic_t count;
	struct uts_namespace___5 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___43 *pid_ns_for_children;
	struct net___8 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___37 *cgroup_ns;
};

struct bio___22;

struct bio_list___22 {
	struct bio___22 *head;
	struct bio___22 *tail;
};

struct cgroup_subsys_state___37;

struct bdi_writeback___21 {
	struct backing_dev_info___21 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___37 *memcg_css;
	struct cgroup_subsys_state___37 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___44;

struct backing_dev_info___21 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___21 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___44 *dev;
	char dev_name[64];
	struct device___44 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___46 *debug_dir;
};

struct io_cq___22;

struct io_context___23 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___22 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___37;

struct css_set___37 {
	struct cgroup_subsys_state___37 *subsys[14];
	refcount_t refcount;
	struct css_set___37 *dom_cset;
	struct cgroup___37 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___37 *mg_src_cgrp;
	struct cgroup___37 *mg_dst_cgrp;
	struct css_set___37 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___33 {
	struct pmu___33 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___50 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___33 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___14;

struct pipe_inode_info___14 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___49 *tmp_page;
	struct fasync_struct___45 *fasync_readers;
	struct fasync_struct___45 *fasync_writers;
	struct pipe_buffer___14 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___37;

struct cgroup_subsys_state___37 {
	struct cgroup___37 *cgroup;
	struct cgroup_subsys___37 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___37 *parent;
};

struct cgroup_file___37 {
	struct kernfs_node___47 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___21;

struct mem_cgroup_per_node___21;

struct mem_cgroup___21 {
	struct cgroup_subsys_state___37 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___37 events_file;
	struct cgroup_file___37 events_local_file;
	struct cgroup_file___37 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___21 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___50 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___21 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___22;

struct blk_integrity___22 {
	const struct blk_integrity_profile___22 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___22 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___22 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___22;

struct elevator_queue___22;

struct blk_mq_ops___21;

struct blk_mq_hw_ctx___21;

struct gendisk___22;

struct blkcg_gq___21;

struct blk_mq_tag_set___21;

struct request_queue___23 {
	struct request___22 *last_merge;
	struct elevator_queue___22 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___21 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___21 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___22 *disk;
	struct kobject___47 kobj;
	struct kobject___47 *mq_kobj;
	struct blk_integrity___22 integrity;
	struct device___44 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___21 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___21 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___22 bio_split;
	struct dentry___46 *debugfs_dir;
	struct dentry___46 *sched_debugfs_dir;
	struct dentry___46 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___48 {
	struct vm_struct___48 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___49 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___45;

struct dentry___46 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___46 *d_parent;
	struct qstr d_name;
	struct inode___46 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___45 *d_op;
	struct super_block___46 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___45;

struct address_space___45 {
	struct inode___46 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___45 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___45;

struct inode___46 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___45 *i_op;
	struct super_block___46 *i_sb;
	struct address_space___45 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___21 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___45 *i_fop;
		void (*free_inode)(struct inode___46 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___45 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___45;

struct path___45;

struct dentry_operations___45 {
	int (*d_revalidate)(struct dentry___46 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___46 *, unsigned int);
	int (*d_hash)(const struct dentry___46 *, struct qstr *);
	int (*d_compare)(const struct dentry___46 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___46 *);
	int (*d_init)(struct dentry___46 *);
	void (*d_release)(struct dentry___46 *);
	void (*d_prune)(struct dentry___46 *);
	void (*d_iput)(struct dentry___46 *, struct inode___46 *);
	char * (*d_dname)(struct dentry___46 *, char *, int);
	struct vfsmount___45 * (*d_automount)(struct path___45 *);
	int (*d_manage)(const struct path___45 *, bool);
	struct dentry___46 * (*d_real)(struct dentry___46 *, const struct inode___46 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___45;

struct mem_dqinfo___45 {
	struct quota_format_type___45 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___45;

struct quota_info___45 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___46 *files[3];
	struct mem_dqinfo___45 info[3];
	const struct quota_format_ops___45 *ops[3];
};

struct rcuwait___46 {
	struct task_struct___50 *task;
};

struct percpu_rw_semaphore___46 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___46 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___45 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___46 rw_sem[3];
};

struct shrink_control___21;

struct shrinker___21 {
	long unsigned int (*count_objects)(struct shrinker___21 *, struct shrink_control___21 *);
	long unsigned int (*scan_objects)(struct shrinker___21 *, struct shrink_control___21 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___45;

struct dquot_operations___45;

struct quotactl_ops___45;

struct block_device___23;

struct super_block___46 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___45 *s_type;
	const struct super_operations___45 *s_op;
	const struct dquot_operations___45 *dq_op;
	const struct quotactl_ops___45 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___46 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___23 *s_bdev;
	struct backing_dev_info___21 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___45 s_dquot;
	struct sb_writers___45 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___45 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___6 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___45 {
	struct dentry___46 *mnt_root;
	struct super_block___46 *mnt_sb;
	int mnt_flags;
	struct user_namespace___6 *mnt_userns;
};

struct path___45 {
	struct vfsmount___45 *mnt;
	struct dentry___46 *dentry;
};

struct shrink_control___21 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___21 *memcg;
};

struct page_pool_params___13 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___44 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___13 {
	u32 count;
	struct page___49 *cache[128];
};

struct page_pool___13 {
	struct page_pool_params___13 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___49 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___13 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___45;

struct dev_pagemap___45 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___45 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___43 {
	rwlock_t lock;
	struct pid___43 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___46 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___45 f_path;
	struct inode___46 *f_inode;
	const struct file_operations___45 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___5 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___45 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___45;

struct vm_operations_struct___45 {
	void (*open)(struct vm_area_struct___49 *);
	void (*close)(struct vm_area_struct___49 *);
	int (*may_split)(struct vm_area_struct___49 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___49 *);
	int (*mprotect)(struct vm_area_struct___49 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___45 *);
	vm_fault_t (*huge_fault)(struct vm_fault___45 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___45 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___49 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___45 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___45 *);
	int (*access)(struct vm_area_struct___49 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___49 *);
	int (*set_policy)(struct vm_area_struct___49 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___49 *, long unsigned int);
	struct page___49 * (*find_special_page)(struct vm_area_struct___49 *, long unsigned int);
};

struct core_thread___49 {
	struct task_struct___50 *task;
	struct core_thread___49 *next;
};

struct core_state___49 {
	atomic_t nr_threads;
	struct core_thread___49 dumper;
	struct completion startup;
};

struct vm_fault___45 {
	const struct {
		struct vm_area_struct___49 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___49 *cow_page;
	struct page___49 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___49 prealloc_pte;
};

struct pglist_data___22;

struct lruvec___22 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___22 *pgdat;
};

struct zone___22 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___22 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___22 {
	struct zone___22 *zone;
	int zone_idx;
};

struct zonelist___22 {
	struct zoneref___22 _zonerefs[321];
};

struct pglist_data___22 {
	struct zone___22 node_zones[5];
	struct zonelist___22 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___50 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___50 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___22 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernel_clone_args___3 {
	u64 flags;
	int *pidfd;
	int *child_tid;
	int *parent_tid;
	int exit_signal;
	long unsigned int stack;
	long unsigned int stack_size;
	long unsigned int tls;
	pid_t *set_tid;
	size_t set_tid_size;
	int cgroup;
	int io_thread;
	struct cgroup___37 *cgrp;
	struct css_set___37 *cset;
};

struct psi_group___37 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___50 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___5;

struct cgroup_bpf___5 {
	struct bpf_prog_array___5 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___5 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___37;

struct cgroup_rstat_cpu___37;

struct cgroup___37 {
	struct cgroup_subsys_state___37 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___47 *kn;
	struct cgroup_file___37 procs_file;
	struct cgroup_file___37 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___37 *subsys[14];
	struct cgroup_root___37 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___37 *dom_cgrp;
	struct cgroup___37 *old_dom_cgrp;
	struct cgroup_rstat_cpu___37 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___37 psi;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___22 {
	struct request_queue___23 *q;
	struct io_context___23 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___24;

struct kiocb___45 {
	struct file___46 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___45 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___24 *ki_waitq;
	};
};

struct iattr___46 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___46 *ia_file;
};

struct dquot___45 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___46 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___45 {
	int qf_fmt_id;
	const struct quota_format_ops___45 *qf_ops;
	struct module___46 *qf_owner;
	struct quota_format_type___45 *qf_next;
};

struct quota_format_ops___45 {
	int (*check_quota_file)(struct super_block___46 *, int);
	int (*read_file_info)(struct super_block___46 *, int);
	int (*write_file_info)(struct super_block___46 *, int);
	int (*free_file_info)(struct super_block___46 *, int);
	int (*read_dqblk)(struct dquot___45 *);
	int (*commit_dqblk)(struct dquot___45 *);
	int (*release_dqblk)(struct dquot___45 *);
	int (*get_next_id)(struct super_block___46 *, struct kqid *);
};

struct dquot_operations___45 {
	int (*write_dquot)(struct dquot___45 *);
	struct dquot___45 * (*alloc_dquot)(struct super_block___46 *, int);
	void (*destroy_dquot)(struct dquot___45 *);
	int (*acquire_dquot)(struct dquot___45 *);
	int (*release_dquot)(struct dquot___45 *);
	int (*mark_dirty)(struct dquot___45 *);
	int (*write_info)(struct super_block___46 *, int);
	qsize_t * (*get_reserved_space)(struct inode___46 *);
	int (*get_projid)(struct inode___46 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___46 *, qsize_t *);
	int (*get_next_id)(struct super_block___46 *, struct kqid *);
};

struct quotactl_ops___45 {
	int (*quota_on)(struct super_block___46 *, int, int, const struct path___45 *);
	int (*quota_off)(struct super_block___46 *, int);
	int (*quota_enable)(struct super_block___46 *, unsigned int);
	int (*quota_disable)(struct super_block___46 *, unsigned int);
	int (*quota_sync)(struct super_block___46 *, int);
	int (*set_info)(struct super_block___46 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___46 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___46 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___46 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___46 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___46 *, unsigned int);
};

struct wait_page_queue___24 {
	struct page___49 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___21;

struct readahead_control___24;

struct address_space_operations___45 {
	int (*writepage)(struct page___49 *, struct writeback_control___21 *);
	int (*readpage)(struct file___46 *, struct page___49 *);
	int (*writepages)(struct address_space___45 *, struct writeback_control___21 *);
	int (*set_page_dirty)(struct page___49 *);
	int (*readpages)(struct file___46 *, struct address_space___45 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___24 *);
	int (*write_begin)(struct file___46 *, struct address_space___45 *, loff_t, unsigned int, unsigned int, struct page___49 **, void **);
	int (*write_end)(struct file___46 *, struct address_space___45 *, loff_t, unsigned int, unsigned int, struct page___49 *, void *);
	sector_t (*bmap)(struct address_space___45 *, sector_t);
	void (*invalidatepage)(struct page___49 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___49 *, gfp_t);
	void (*freepage)(struct page___49 *);
	ssize_t (*direct_IO)(struct kiocb___45 *, struct iov_iter___25 *);
	int (*migratepage)(struct address_space___45 *, struct page___49 *, struct page___49 *, enum migrate_mode);
	bool (*isolate_page)(struct page___49 *, isolate_mode_t);
	void (*putback_page)(struct page___49 *);
	int (*launder_page)(struct page___49 *);
	int (*is_partially_uptodate)(struct page___49 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___49 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___45 *, struct page___49 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___46 *, sector_t *);
	void (*swap_deactivate)(struct file___46 *);
};

struct writeback_control___21 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___21 *wb;
	struct inode___46 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___24 {
	struct file___46 *file;
	struct address_space___45 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___25;

struct iov_iter___25 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___25 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___14 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___45 {
	struct dentry___46 * (*lookup)(struct inode___46 *, struct dentry___46 *, unsigned int);
	const char * (*get_link)(struct dentry___46 *, struct inode___46 *, struct delayed_call *);
	int (*permission)(struct user_namespace___6 *, struct inode___46 *, int);
	struct posix_acl * (*get_acl)(struct inode___46 *, int, bool);
	int (*readlink)(struct dentry___46 *, char *, int);
	int (*create)(struct user_namespace___6 *, struct inode___46 *, struct dentry___46 *, umode_t, bool);
	int (*link)(struct dentry___46 *, struct inode___46 *, struct dentry___46 *);
	int (*unlink)(struct inode___46 *, struct dentry___46 *);
	int (*symlink)(struct user_namespace___6 *, struct inode___46 *, struct dentry___46 *, const char *);
	int (*mkdir)(struct user_namespace___6 *, struct inode___46 *, struct dentry___46 *, umode_t);
	int (*rmdir)(struct inode___46 *, struct dentry___46 *);
	int (*mknod)(struct user_namespace___6 *, struct inode___46 *, struct dentry___46 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___6 *, struct inode___46 *, struct dentry___46 *, struct inode___46 *, struct dentry___46 *, unsigned int);
	int (*setattr)(struct user_namespace___6 *, struct dentry___46 *, struct iattr___46 *);
	int (*getattr)(struct user_namespace___6 *, const struct path___45 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___46 *, char *, size_t);
	int (*fiemap)(struct inode___46 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___46 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___46 *, struct dentry___46 *, struct file___46 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___6 *, struct inode___46 *, struct dentry___46 *, umode_t);
	int (*set_acl)(struct user_namespace___6 *, struct inode___46 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___6 *, struct dentry___46 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___46 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___45 {
	void (*fl_copy_lock)(struct file_lock___45 *, struct file_lock___45 *);
	void (*fl_release_private)(struct file_lock___45 *);
};

struct lock_manager_operations___45;

struct file_lock___45 {
	struct file_lock___45 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___46 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___45 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___45 *fl_ops;
	const struct lock_manager_operations___45 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___45 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___45 *);
	int (*lm_grant)(struct file_lock___45 *, int);
	bool (*lm_break)(struct file_lock___45 *);
	int (*lm_change)(struct file_lock___45 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___45 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___45 *);
};

struct fasync_struct___45 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___45 *fa_next;
	struct file___46 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___45 {
	struct inode___46 * (*alloc_inode)(struct super_block___46 *);
	void (*destroy_inode)(struct inode___46 *);
	void (*free_inode)(struct inode___46 *);
	void (*dirty_inode)(struct inode___46 *, int);
	int (*write_inode)(struct inode___46 *, struct writeback_control___21 *);
	int (*drop_inode)(struct inode___46 *);
	void (*evict_inode)(struct inode___46 *);
	void (*put_super)(struct super_block___46 *);
	int (*sync_fs)(struct super_block___46 *, int);
	int (*freeze_super)(struct super_block___46 *);
	int (*freeze_fs)(struct super_block___46 *);
	int (*thaw_super)(struct super_block___46 *);
	int (*unfreeze_fs)(struct super_block___46 *);
	int (*statfs)(struct dentry___46 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___46 *, int *, char *);
	void (*umount_begin)(struct super_block___46 *);
	int (*show_options)(struct seq_file___45 *, struct dentry___46 *);
	int (*show_devname)(struct seq_file___45 *, struct dentry___46 *);
	int (*show_path)(struct seq_file___45 *, struct dentry___46 *);
	int (*show_stats)(struct seq_file___45 *, struct dentry___46 *);
	ssize_t (*quota_read)(struct super_block___46 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___46 *, int, const char *, size_t, loff_t);
	struct dquot___45 ** (*get_dquots)(struct inode___46 *);
	long int (*nr_cached_objects)(struct super_block___46 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___46 *, struct shrink_control___21 *);
	struct file___46 * (*real_loop)(struct file___46 *);
};

struct wakeup_source___44;

struct dev_pm_info___44 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___44 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___44 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___44;

struct bus_type___44;

struct device_driver___44;

struct dev_pm_domain___44;

struct fwnode_handle___44;

struct class___44;

struct attribute_group___47;

struct device___44 {
	struct kobject___47 kobj;
	struct device___44 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___44 *type;
	struct bus_type___44 *bus;
	struct device_driver___44 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___44 power;
	struct dev_pm_domain___44 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___44 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___44 *class;
	const struct attribute_group___47 **groups;
	void (*release)(struct device___44 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___23 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___46 *bd_inode;
	struct super_block___46 *bd_super;
	void *bd_claiming;
	struct device___44 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___47 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___22 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___46 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___36)(struct file___46 *, wait_queue_head_t *, struct poll_table_struct___36 *);

struct poll_table_struct___36 {
	poll_queue_proc___36 _qproc;
	__poll_t _key;
};

struct seq_operations___44;

struct seq_file___45 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___44 *op;
	int poll_event;
	const struct file___46 *file;
	void *private;
};

struct fc_log___5;

struct p_log___5 {
	const char *prefix;
	struct fc_log___5 *log;
};

struct fs_context_operations___5;

struct fs_context___5 {
	const struct fs_context_operations___5 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___45 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___46 *root;
	struct user_namespace___6 *user_ns;
	struct net___8 *net_ns;
	const struct cred___5 *cred;
	struct p_log___5 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___5;

typedef int fs_param_type___5(struct p_log___5 *, const struct fs_parameter_spec___5 *, struct fs_parameter___5 *, struct fs_parse_result *);

struct fs_parameter_spec___5 {
	const char *name;
	fs_param_type___5 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___22(struct bio___22 *);

struct bio_vec___25 {
	struct page___49 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___22;

struct bio___22 {
	struct bio___22 *bi_next;
	struct block_device___23 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___22 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___21 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___22 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___25 *bi_io_vec;
	struct bio_set___22 *bi_pool;
	struct bio_vec___25 bi_inline_vecs[0];
};

struct seq_operations___44 {
	void * (*start)(struct seq_file___45 *, loff_t *);
	void (*stop)(struct seq_file___45 *, void *);
	void * (*next)(struct seq_file___45 *, void *, loff_t *);
	int (*show)(struct seq_file___45 *, void *);
};

enum kernfs_node_type {
	KERNFS_DIR = 1,
	KERNFS_FILE = 2,
	KERNFS_LINK = 4,
};

enum kernfs_root_flag {
	KERNFS_ROOT_CREATE_DEACTIVATED = 1,
	KERNFS_ROOT_EXTRA_OPEN_PERM_CHECK = 2,
	KERNFS_ROOT_SUPPORT_EXPORTOP = 4,
	KERNFS_ROOT_SUPPORT_USER_XATTR = 8,
};

struct kernfs_root___47;

struct kernfs_elem_dir___47 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___47 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___47;

struct kernfs_root___47 {
	struct kernfs_node___47 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___47 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___47 {
	struct kernfs_node___47 *target_kn;
};

struct kernfs_ops___47;

struct kernfs_elem_attr___47 {
	const struct kernfs_ops___47 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___47 *notify_next;
};

struct kernfs_node___47 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___47 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___47 dir;
		struct kernfs_elem_symlink___47 symlink;
		struct kernfs_elem_attr___47 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___47;

struct kernfs_ops___47 {
	int (*open)(struct kernfs_open_file___47 *);
	void (*release)(struct kernfs_open_file___47 *);
	int (*seq_show)(struct seq_file___45 *, void *);
	void * (*seq_start)(struct seq_file___45 *, loff_t *);
	void * (*seq_next)(struct seq_file___45 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___45 *, void *);
	ssize_t (*read)(struct kernfs_open_file___47 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___47 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___47 *, struct poll_table_struct___36 *);
	int (*mmap)(struct kernfs_open_file___47 *, struct vm_area_struct___49 *);
};

struct kernfs_syscall_ops___47 {
	int (*show_options)(struct seq_file___45 *, struct kernfs_root___47 *);
	int (*mkdir)(struct kernfs_node___47 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___47 *);
	int (*rename)(struct kernfs_node___47 *, struct kernfs_node___47 *, const char *);
	int (*show_path)(struct seq_file___45 *, struct kernfs_node___47 *, struct kernfs_root___47 *);
};

struct kernfs_open_file___47 {
	struct kernfs_node___47 *kn;
	struct file___46 *file;
	struct seq_file___45 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___45 *vm_ops;
};

struct kernfs_fs_context {
	struct kernfs_root___47 *root;
	void *ns_tag;
	long unsigned int magic;
	bool new_sb_created;
};

struct nsset___6;

struct proc_ns_operations___7 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___7 * (*get)(struct task_struct___50 *);
	void (*put)(struct ns_common___7 *);
	int (*install)(struct nsset___6 *, struct ns_common___7 *);
	struct user_namespace___6 * (*owner)(struct ns_common___7 *);
	struct ns_common___7 * (*get_parent)(struct ns_common___7 *);
};

struct uts_namespace___5 {
	struct new_utsname name;
	struct user_namespace___6 *user_ns;
	struct ucounts___6 *ucounts;
	struct ns_common___7 ns;
};

struct fib_rules_ops___4;

struct sock___6;

struct fqdir___7;

struct fib_notifier_ops___4;

struct netns_ipv4___7 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___4 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___6 *fibnl;
	struct sock___6 **icmp_sk;
	struct sock___6 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___6 **tcp_sk;
	struct fqdir___7 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___4 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___4 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___4 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___4;

struct net_device___10;

struct sk_buff___7;

struct neighbour___4;

struct dst_ops___7 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___7 *);
	struct dst_entry___4 * (*check)(struct dst_entry___4 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___4 *);
	unsigned int (*mtu)(const struct dst_entry___4 *);
	u32 * (*cow_metrics)(struct dst_entry___4 *, long unsigned int);
	void (*destroy)(struct dst_entry___4 *);
	void (*ifdown)(struct dst_entry___4 *, struct net_device___10 *, int);
	struct dst_entry___4 * (*negative_advice)(struct dst_entry___4 *);
	void (*link_failure)(struct sk_buff___7 *);
	void (*update_pmtu)(struct dst_entry___4 *, struct sock___6 *, struct sk_buff___7 *, u32, bool);
	void (*redirect)(struct dst_entry___4 *, struct sock___6 *, struct sk_buff___7 *);
	int (*local_out)(struct net___8 *, struct sock___6 *, struct sk_buff___7 *);
	struct neighbour___4 * (*neigh_lookup)(const struct dst_entry___4 *, struct sk_buff___7 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___4 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___7 {
	struct dst_ops___7 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___7 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___4 *fib6_rules_ops;
	struct sock___6 **icmp_sk;
	struct sock___6 *ndisc_sk;
	struct sock___6 *tcp_sk;
	struct sock___6 *igmp_sk;
	struct sock___6 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___4 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___4 *notifier_ops;
	struct fib_notifier_ops___4 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___7 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___7 *fqdir;
};

struct netns_sctp___4 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___6 *ctl_sock;
	struct sock___6 *udp4_sock;
	struct sock___6 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___5 {
	struct sk_buff___7 *next;
	struct sk_buff___7 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___5 {
	struct bpf_prog_array___5 *run_array[2];
	struct bpf_prog___5 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___7 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___6 *nlsk;
	struct sock___6 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___7 xfrm4_dst_ops;
	struct dst_ops___7 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___8 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___6 *user_ns;
	struct ucounts___6 *ucounts;
	struct idr netns_ids;
	struct ns_common___7 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___6 *rtnl;
	struct sock___6 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___10 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___7 ipv4;
	struct netns_ipv6___7 ipv6;
	struct netns_ieee802154_lowpan___7 ieee802154_lowpan;
	struct netns_sctp___4 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___5 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___5 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___7 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___6 *crypto_nlsk;
	struct sock___6 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___37 {
	struct ns_common___7 ns;
	struct user_namespace___6 *user_ns;
	struct ucounts___6 *ucounts;
	struct css_set___37 *root_cset;
};

struct nsset___6 {
	unsigned int flags;
	struct nsproxy___45 *nsproxy;
	struct fs_struct *fs;
	const struct cred___5 *cred;
};

struct fwnode_operations___44;

struct fwnode_handle___44 {
	struct fwnode_handle___44 *secondary;
	const struct fwnode_operations___44 *ops;
	struct device___44 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___44;

struct fwnode_endpoint___44;

struct fwnode_operations___44 {
	struct fwnode_handle___44 * (*get)(struct fwnode_handle___44 *);
	void (*put)(struct fwnode_handle___44 *);
	bool (*device_is_available)(const struct fwnode_handle___44 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___44 *, const struct device___44 *);
	bool (*property_present)(const struct fwnode_handle___44 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___44 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___44 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___44 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*get_parent)(const struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*get_next_child_node)(const struct fwnode_handle___44 *, struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*get_named_child_node)(const struct fwnode_handle___44 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___44 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___44 *);
	struct fwnode_handle___44 * (*graph_get_next_endpoint)(const struct fwnode_handle___44 *, struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*graph_get_remote_endpoint)(const struct fwnode_handle___44 *);
	struct fwnode_handle___44 * (*graph_get_port_parent)(struct fwnode_handle___44 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___44 *, struct fwnode_endpoint___44 *);
	int (*add_links)(struct fwnode_handle___44 *);
};

struct fwnode_endpoint___44 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___44 *local_fwnode;
};

struct fwnode_reference_args___44 {
	struct fwnode_handle___44 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kobj_ns_type_operations___4 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___6 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___8 *net;
} possible_net_t___5;

struct proto___4;

struct sock_common___4 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___4 *skc_prot;
	possible_net_t___5 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___6 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___4 {
	struct cgroup___37 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___4;

struct socket_wq___4;

struct socket___4;

struct sock___6 {
	struct sock_common___4 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___5 sk_error_queue;
	struct sk_buff___7 *sk_rx_skb_cache;
	struct sk_buff_head___5 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___7 *head;
		struct sk_buff___7 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___4 *sk_filter;
	union {
		struct socket_wq___4 *sk_wq;
		struct socket_wq___4 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___4 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___4 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___7 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___7 *sk_tx_skb_cache;
	struct sk_buff_head___5 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___49 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___4 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___43 *sk_peer_pid;
	const struct cred___5 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___4 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___4 sk_cgrp_data;
	struct mem_cgroup___21 *sk_memcg;
	void (*sk_state_change)(struct sock___6 *);
	void (*sk_data_ready)(struct sock___6 *);
	void (*sk_write_space)(struct sock___6 *);
	void (*sk_error_report)(struct sock___6 *);
	int (*sk_backlog_rcv)(struct sock___6 *, struct sk_buff___7 *);
	struct sk_buff___7 * (*sk_validate_xmit_skb)(struct sock___6 *, struct net_device___10 *, struct sk_buff___7 *);
	void (*sk_destruct)(struct sock___6 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___47;

struct attribute_group___47 {
	const char *name;
	umode_t (*is_visible)(struct kobject___47 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___47 *, struct bin_attribute___47 *, int);
	struct attribute **attrs;
	struct bin_attribute___47 **bin_attrs;
};

struct bin_attribute___47 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___45 * (*f_mapping)();
	ssize_t (*read)(struct file___46 *, struct kobject___47 *, struct bin_attribute___47 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___46 *, struct kobject___47 *, struct bin_attribute___47 *, char *, loff_t, size_t);
	int (*mmap)(struct file___46 *, struct kobject___47 *, struct bin_attribute___47 *, struct vm_area_struct___49 *);
};

struct sysfs_ops___47 {
	ssize_t (*show)(struct kobject___47 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___47 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___47;

struct kset___47 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___47 kobj;
	const struct kset_uevent_ops___47 *uevent_ops;
};

struct kobj_type___47 {
	void (*release)(struct kobject___47 *);
	const struct sysfs_ops___47 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___47 **default_groups;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___47 *);
	const void * (*namespace)(struct kobject___47 *);
	void (*get_ownership)(struct kobject___47 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___47 {
	int (* const filter)(struct kset___47 *, struct kobject___47 *);
	const char * (* const name)(struct kset___47 *, struct kobject___47 *);
	int (* const uevent)(struct kset___47 *, struct kobject___47 *, struct kobj_uevent_env *);
};

struct kobj_attribute___5 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___47 *, struct kobj_attribute___5 *, char *);
	ssize_t (*store)(struct kobject___47 *, struct kobj_attribute___5 *, const char *, size_t);
};

enum bpf_link_type {
	BPF_LINK_TYPE_UNSPEC = 0,
	BPF_LINK_TYPE_RAW_TRACEPOINT = 1,
	BPF_LINK_TYPE_TRACING = 2,
	BPF_LINK_TYPE_CGROUP = 3,
	BPF_LINK_TYPE_ITER = 4,
	BPF_LINK_TYPE_NETNS = 5,
	BPF_LINK_TYPE_XDP = 6,
	BPF_LINK_TYPE_PERF_EVENT = 7,
	MAX_BPF_LINK_TYPE = 8,
};

struct bpf_link_info {
	__u32 type;
	__u32 id;
	__u32 prog_id;
	union {
		struct {
			__u64 tp_name;
			__u32 tp_name_len;
		} raw_tracepoint;
		struct {
			__u32 attach_type;
			__u32 target_obj_id;
			__u32 target_btf_id;
		} tracing;
		struct {
			__u64 cgroup_id;
			__u32 attach_type;
		} cgroup;
		struct {
			__u64 target_name;
			__u32 target_name_len;
			union {
				struct {
					__u32 map_id;
				} map;
			};
		} iter;
		struct {
			__u32 netns_ino;
			__u32 attach_type;
		} netns;
		struct {
			__u32 ifindex;
		} xdp;
	};
};

struct kernel_param_ops___44 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___44 *);
	int (*get)(char *, const struct kernel_param___44 *);
	void (*free)(void *);
};

struct kparam_array___44;

struct kernel_param___44 {
	const char *name;
	struct module___46 *mod;
	const struct kernel_param_ops___44 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___44 *arr;
	};
};

struct kparam_array___44 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___44 *ops;
	void *elem;
};

struct module_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___44 *, struct module_kobject___44 *, char *);
	ssize_t (*store)(struct module_attribute___44 *, struct module_kobject___44 *, const char *, size_t);
	void (*setup)(struct module___46 *, const char *);
	int (*test)(struct module___46 *);
	void (*free)(struct module___46 *);
};

struct trace_event_class___28;

struct trace_event_call___28 {
	struct list_head list;
	struct trace_event_class___28 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___5 *prog_array;
	int (*perf_perm)(struct trace_event_call___28 *, struct perf_event___33 *);
};

struct dev_pagemap_ops___45 {
	void (*page_free)(struct page___49 *);
	void (*kill)(struct dev_pagemap___45 *);
	void (*cleanup)(struct dev_pagemap___45 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___45 *);
};

struct bpf_iter_aux_info___5;

typedef int (*bpf_iter_init_seq_priv_t___5)(void *, struct bpf_iter_aux_info___5 *);

struct bpf_map___5;

struct bpf_iter_aux_info___5 {
	struct bpf_map___5 *map;
};

struct bpf_iter_seq_info___5 {
	const struct seq_operations___44 *seq_ops;
	bpf_iter_init_seq_priv_t___5 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___5;

struct bpf_map_ops___5 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___5 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___5 *, struct file___46 *);
	void (*map_free)(struct bpf_map___5 *);
	int (*map_get_next_key)(struct bpf_map___5 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___5 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___5 *, void *);
	int (*map_lookup_batch)(struct bpf_map___5 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___5 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___5 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___5 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___5 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___5 *, void *);
	int (*map_update_elem)(struct bpf_map___5 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___5 *, void *);
	int (*map_push_elem)(struct bpf_map___5 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___5 *, void *);
	int (*map_peek_elem)(struct bpf_map___5 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___5 *, struct file___46 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___5 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___5 *, void *, struct seq_file___45 *);
	int (*map_check_btf)(const struct bpf_map___5 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___5 *, struct bpf_prog_aux___5 *);
	void (*map_poke_untrack)(struct bpf_map___5 *, struct bpf_prog_aux___5 *);
	void (*map_poke_run)(struct bpf_map___5 *, u32, struct bpf_prog___5 *, struct bpf_prog___5 *);
	int (*map_direct_value_addr)(const struct bpf_map___5 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___5 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___5 *, struct vm_area_struct___49 *);
	__poll_t (*map_poll)(struct bpf_map___5 *, struct file___46 *, struct poll_table_struct___36 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___5 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___5 *, const struct bpf_map___5 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___5 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___5 *iter_seq_info;
};

struct bpf_map___5 {
	const struct bpf_map_ops___5 *ops;
	struct bpf_map___5 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___21 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___5;

struct bpf_jit_poke_descriptor___5;

struct bpf_prog_ops___5;

struct btf_mod_pair___5;

struct bpf_prog_offload___5;

struct bpf_prog_aux___5 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___5 *dst_prog;
	struct bpf_trampoline___5 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___5 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___5 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___5 *ops;
	struct bpf_map___5 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___5 *used_btfs;
	struct bpf_prog___5 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___5 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___5 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___5 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___5 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___5;

struct bpf_map_dev_ops___5 {
	int (*map_get_next_key)(struct bpf_offloaded_map___5 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___5 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___5 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___5 *, void *);
};

struct bpf_offloaded_map___5 {
	struct bpf_map___5 map;
	struct net_device___10 *netdev;
	const struct bpf_map_dev_ops___5 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___5(struct sk_buff___7 **);

struct bpf_xdp_entity___5 {
	struct bpf_prog___5 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___5;

struct net_device_ops___5;

struct l3mdev_ops___4;

struct xfrmdev_ops___5;

struct header_ops___5;

struct netdev_rx_queue___5;

struct mini_Qdisc___5;

struct netdev_queue___5;

struct Qdisc___5;

struct rtnl_link_ops___5;

struct dcbnl_rtnl_ops___5;

struct net_device___10 {
	char name[16];
	struct netdev_name_node___5 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___5 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___4 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___5 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___5 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___47 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___5 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___5 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___5 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___5 *miniq_ingress;
	struct netdev_queue___5 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___5 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___5 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___5 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___5 = 0,
		NETREG_REGISTERED___5 = 1,
		NETREG_UNREGISTERING___5 = 2,
		NETREG_UNREGISTERED___5 = 3,
		NETREG_RELEASED___5 = 4,
		NETREG_DUMMY___5 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___5 = 0,
		RTNL_LINK_INITIALIZING___5 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___10 *);
	struct netpoll_info *npinfo;
	possible_net_t___5 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___44 dev;
	const struct attribute_group___47 *sysfs_groups[4];
	const struct attribute_group___47 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___5 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___5 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___5 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___5 {
	int (*test_run)(struct bpf_prog___5 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___5 {
	struct bpf_prog___5 *prog;
	struct net_device___10 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___5 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___5 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___46 *mod;
};

struct bpf_jit_poke_descriptor___5 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___5 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___5 {
	struct btf *btf;
	struct module___46 *module;
};

struct bpf_link_ops;

struct bpf_link {
	atomic64_t refcnt;
	u32 id;
	enum bpf_link_type type;
	const struct bpf_link_ops *ops;
	struct bpf_prog___5 *prog;
	struct work_struct work;
};

struct bpf_link_ops {
	void (*release)(struct bpf_link *);
	void (*dealloc)(struct bpf_link *);
	int (*detach)(struct bpf_link *);
	int (*update_prog)(struct bpf_link *, struct bpf_prog___5 *, struct bpf_prog___5 *);
	void (*show_fdinfo)(const struct bpf_link *, struct seq_file___45 *);
	int (*fill_link_info)(const struct bpf_link *, struct bpf_link_info *);
};

struct bpf_prog_array_item___5 {
	struct bpf_prog___5 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___5 {
	struct callback_head rcu;
	struct bpf_prog_array_item___5 items[0];
};

struct sk_buff___7 {
	union {
		struct {
			struct sk_buff___7 *next;
			struct sk_buff___7 *prev;
			union {
				struct net_device___10 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___6 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___7 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bpf_cgroup_link {
	struct bpf_link link;
	struct cgroup___37 *cgroup;
	enum bpf_attach_type type;
};

struct psi_trigger___2 {
	enum psi_states state;
	u64 threshold;
	struct list_head node;
	struct psi_group___37 *group;
	wait_queue_head_t event_wait;
	int event;
	struct psi_window win;
	u64 last_event_time;
};

enum {
	CGRP_NOTIFY_ON_RELEASE = 0,
	CGRP_CPUSET_CLONE_CHILDREN = 1,
	CGRP_FREEZE = 2,
	CGRP_FROZEN = 3,
	CGRP_KILL = 4,
};

enum {
	CGRP_ROOT_NOPREFIX = 2,
	CGRP_ROOT_XATTR = 4,
	CGRP_ROOT_NS_DELEGATE = 8,
	CGRP_ROOT_CPUSET_V2_MODE = 16,
	CGRP_ROOT_MEMORY_LOCAL_EVENTS = 32,
	CGRP_ROOT_MEMORY_RECURSIVE_PROT = 64,
};

struct cgroup_taskset___2;

struct cftype___37;

struct cgroup_subsys___37 {
	struct cgroup_subsys_state___37 * (*css_alloc)(struct cgroup_subsys_state___37 *);
	int (*css_online)(struct cgroup_subsys_state___37 *);
	void (*css_offline)(struct cgroup_subsys_state___37 *);
	void (*css_released)(struct cgroup_subsys_state___37 *);
	void (*css_free)(struct cgroup_subsys_state___37 *);
	void (*css_reset)(struct cgroup_subsys_state___37 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___37 *, int);
	int (*css_extra_stat_show)(struct seq_file___45 *, struct cgroup_subsys_state___37 *);
	int (*can_attach)(struct cgroup_taskset___2 *);
	void (*cancel_attach)(struct cgroup_taskset___2 *);
	void (*attach)(struct cgroup_taskset___2 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___50 *, struct css_set___37 *);
	void (*cancel_fork)(struct task_struct___50 *, struct css_set___37 *);
	void (*fork)(struct task_struct___50 *);
	void (*exit)(struct task_struct___50 *);
	void (*release)(struct task_struct___50 *);
	void (*bind)(struct cgroup_subsys_state___37 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___37 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___37 *dfl_cftypes;
	struct cftype___37 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___37 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___37 *updated_children;
	struct cgroup___37 *updated_next;
};

struct cgroup_root___37 {
	struct kernfs_root___47 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___37 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___37 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___37 *ss;
	struct list_head node;
	struct kernfs_ops___47 *kf_ops;
	int (*open)(struct kernfs_open_file___47 *);
	void (*release)(struct kernfs_open_file___47 *);
	u64 (*read_u64)(struct cgroup_subsys_state___37 *, struct cftype___37 *);
	s64 (*read_s64)(struct cgroup_subsys_state___37 *, struct cftype___37 *);
	int (*seq_show)(struct seq_file___45 *, void *);
	void * (*seq_start)(struct seq_file___45 *, loff_t *);
	void * (*seq_next)(struct seq_file___45 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___45 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___37 *, struct cftype___37 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___37 *, struct cftype___37 *, s64);
	ssize_t (*write)(struct kernfs_open_file___47 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___47 *, struct poll_table_struct___36 *);
};

struct cgroup_taskset___2 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___37 *cur_cset;
	struct task_struct___50 *cur_task;
};

struct css_task_iter___2 {
	struct cgroup_subsys___37 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___37 *cur_cset;
	struct css_set___37 *cur_dcset;
	struct task_struct___50 *cur_task;
	struct list_head iters_node;
};

struct fs_parameter___5 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___46 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___5 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___46 *owner;
	char *buffer[8];
};

struct fs_context_operations___5 {
	void (*free)(struct fs_context___5 *);
	int (*dup)(struct fs_context___5 *, struct fs_context___5 *);
	int (*parse_param)(struct fs_context___5 *, struct fs_parameter___5 *);
	int (*parse_monolithic)(struct fs_context___5 *, void *);
	int (*get_tree)(struct fs_context___5 *);
	int (*reconfigure)(struct fs_context___5 *);
};

struct cgroup_fs_context {
	struct kernfs_fs_context kfc;
	struct cgroup_root___37 *root;
	struct cgroup_namespace___37 *ns;
	unsigned int flags;
	bool cpuset_clone_children;
	bool none;
	bool all_ss;
	u16 subsys_mask;
	char *name;
	char *release_agent;
};

struct cgroup_pidlist;

struct cgroup_file_ctx {
	struct cgroup_namespace___37 *ns;
	struct {
		void *trigger;
	} psi;
	struct {
		bool started;
		struct css_task_iter___2 iter;
	} procs;
	struct {
		struct cgroup_pidlist *pidlist;
	} procs1;
};

struct cgrp_cset_link {
	struct cgroup___37 *cgrp;
	struct css_set___37 *cset;
	struct list_head cset_link;
	struct list_head cgrp_link;
};

struct cgroup_mgctx {
	struct list_head preloaded_src_csets;
	struct list_head preloaded_dst_csets;
	struct cgroup_taskset___2 tset;
	u16 ss_mask;
};

struct msghdr___4 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___25 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___45 *msg_iocb;
};

struct inet_frags___7;

struct fqdir___7 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___7 *f;
	struct net___8 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___7;

struct inet_frags___7 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___7 *, const void *);
	void (*destructor)(struct inet_frag_queue___7 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___7 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___7 *fragments_tail;
	struct sk_buff___7 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___7 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___4;

struct fib_lookup_arg___4;

struct fib_rules_ops___4 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___4 *, struct flowi *, int, struct fib_lookup_arg___4 *);
	bool (*suppress)(struct fib_rule___4 *, int, struct fib_lookup_arg___4 *);
	int (*match)(struct fib_rule___4 *, struct flowi *, int);
	int (*configure)(struct fib_rule___4 *, struct sk_buff___7 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___4 *);
	int (*compare)(struct fib_rule___4 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___4 *, struct sk_buff___7 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___4 *);
	void (*flush_cache)(struct fib_rules_ops___4 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___46 *owner;
	struct net___8 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___4 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___8 *);
	int (*fib_dump)(struct net___8 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___46 *owner;
	struct callback_head rcu;
};

struct dst_entry___4 {
	struct net_device___10 *dev;
	struct dst_ops___7 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___7 *);
	int (*output)(struct net___8 *, struct sock___6 *, struct sk_buff___7 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___4;

struct neigh_parms___4;

struct neigh_ops___4;

struct neighbour___4 {
	struct neighbour___4 *next;
	struct neigh_table___4 *tbl;
	struct neigh_parms___4 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___5 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___4 *, struct sk_buff___7 *);
	const struct neigh_ops___4 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___10 *dev;
	u8 primary_key[0];
};

struct socket_wq___4 {
	wait_queue_head_t wait;
	struct fasync_struct___45 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___4;

struct socket___4 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___46 *file;
	struct sock___6 *sk;
	const struct proto_ops___4 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___4 wq;
};

typedef int (*sk_read_actor_t___4)(read_descriptor_t *, struct sk_buff___7 *, unsigned int, size_t);

struct proto_ops___4 {
	int family;
	struct module___46 *owner;
	int (*release)(struct socket___4 *);
	int (*bind)(struct socket___4 *, struct sockaddr *, int);
	int (*connect)(struct socket___4 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___4 *, struct socket___4 *);
	int (*accept)(struct socket___4 *, struct socket___4 *, int, bool);
	int (*getname)(struct socket___4 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___46 *, struct socket___4 *, struct poll_table_struct___36 *);
	int (*ioctl)(struct socket___4 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___4 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___4 *, void *, bool, bool);
	int (*listen)(struct socket___4 *, int);
	int (*shutdown)(struct socket___4 *, int);
	int (*setsockopt)(struct socket___4 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___4 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___45 *, struct socket___4 *);
	int (*sendmsg)(struct socket___4 *, struct msghdr___4 *, size_t);
	int (*recvmsg)(struct socket___4 *, struct msghdr___4 *, size_t, int);
	int (*mmap)(struct file___46 *, struct socket___4 *, struct vm_area_struct___49 *);
	ssize_t (*sendpage)(struct socket___4 *, struct page___49 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___4 *, loff_t *, struct pipe_inode_info___14 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___6 *, int);
	int (*peek_len)(struct socket___4 *);
	int (*read_sock)(struct sock___6 *, read_descriptor_t *, sk_read_actor_t___4);
	int (*sendpage_locked)(struct sock___6 *, struct page___49 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___6 *, struct msghdr___4 *, size_t);
	int (*set_rcvlowat)(struct sock___6 *, int);
};

struct dev_pm_ops___44 {
	int (*prepare)(struct device___44 *);
	void (*complete)(struct device___44 *);
	int (*suspend)(struct device___44 *);
	int (*resume)(struct device___44 *);
	int (*freeze)(struct device___44 *);
	int (*thaw)(struct device___44 *);
	int (*poweroff)(struct device___44 *);
	int (*restore)(struct device___44 *);
	int (*suspend_late)(struct device___44 *);
	int (*resume_early)(struct device___44 *);
	int (*freeze_late)(struct device___44 *);
	int (*thaw_early)(struct device___44 *);
	int (*poweroff_late)(struct device___44 *);
	int (*restore_early)(struct device___44 *);
	int (*suspend_noirq)(struct device___44 *);
	int (*resume_noirq)(struct device___44 *);
	int (*freeze_noirq)(struct device___44 *);
	int (*thaw_noirq)(struct device___44 *);
	int (*poweroff_noirq)(struct device___44 *);
	int (*restore_noirq)(struct device___44 *);
	int (*runtime_suspend)(struct device___44 *);
	int (*runtime_resume)(struct device___44 *);
	int (*runtime_idle)(struct device___44 *);
};

struct wakeup_source___44 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___44 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___44 {
	struct dev_pm_ops___44 ops;
	int (*start)(struct device___44 *);
	void (*detach)(struct device___44 *, bool);
	int (*activate)(struct device___44 *);
	void (*sync)(struct device___44 *);
	void (*dismiss)(struct device___44 *);
};

struct bus_type___44 {
	const char *name;
	const char *dev_name;
	struct device___44 *dev_root;
	const struct attribute_group___47 **bus_groups;
	const struct attribute_group___47 **dev_groups;
	const struct attribute_group___47 **drv_groups;
	int (*match)(struct device___44 *, struct device_driver___44 *);
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	int (*probe)(struct device___44 *);
	void (*sync_state)(struct device___44 *);
	void (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*online)(struct device___44 *);
	int (*offline)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	int (*num_vf)(struct device___44 *);
	int (*dma_configure)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___44 {
	const char *name;
	struct bus_type___44 *bus;
	struct module___46 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___44 *);
	void (*sync_state)(struct device___44 *);
	int (*remove)(struct device___44 *);
	void (*shutdown)(struct device___44 *);
	int (*suspend)(struct device___44 *, pm_message_t);
	int (*resume)(struct device___44 *);
	const struct attribute_group___47 **groups;
	const struct attribute_group___47 **dev_groups;
	const struct dev_pm_ops___44 *pm;
	void (*coredump)(struct device___44 *);
	struct driver_private *p;
};

struct device_type___44 {
	const char *name;
	const struct attribute_group___47 **groups;
	int (*uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___44 *);
	const struct dev_pm_ops___44 *pm;
};

struct class___44 {
	const char *name;
	struct module___46 *owner;
	const struct attribute_group___47 **class_groups;
	const struct attribute_group___47 **dev_groups;
	struct kobject___47 *dev_kobj;
	int (*dev_uevent)(struct device___44 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___44 *, umode_t *);
	void (*class_release)(struct class___44 *);
	void (*dev_release)(struct device___44 *);
	int (*shutdown_pre)(struct device___44 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___44 *);
	void (*get_ownership)(struct device___44 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___44 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___14;

struct pipe_buffer___14 {
	struct page___49 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___14 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___14 {
	int (*confirm)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	void (*release)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	bool (*try_steal)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
	bool (*get)(struct pipe_inode_info___14 *, struct pipe_buffer___14 *);
};

typedef struct poll_table_struct___36 poll_table___7;

struct dcbnl_rtnl_ops___5 {
	int (*ieee_getets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___10 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___10 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___10 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___10 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___10 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___10 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___10 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___10 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___10 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___10 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___10 *);
	u8 (*setstate)(struct net_device___10 *, u8);
	void (*getpermhwaddr)(struct net_device___10 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___10 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___10 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___10 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___10 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___10 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___10 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___10 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___10 *, int, u8 *);
	void (*setpfccfg)(struct net_device___10 *, int, u8);
	void (*getpfccfg)(struct net_device___10 *, int, u8 *);
	u8 (*setall)(struct net_device___10 *);
	u8 (*getcap)(struct net_device___10 *, int, u8 *);
	int (*getnumtcs)(struct net_device___10 *, int, u8 *);
	int (*setnumtcs)(struct net_device___10 *, int, u8);
	u8 (*getpfcstate)(struct net_device___10 *);
	void (*setpfcstate)(struct net_device___10 *, u8);
	void (*getbcncfg)(struct net_device___10 *, int, u32 *);
	void (*setbcncfg)(struct net_device___10 *, int, u32);
	void (*getbcnrp)(struct net_device___10 *, int, u8 *);
	void (*setbcnrp)(struct net_device___10 *, int, u8);
	int (*setapp)(struct net_device___10 *, u8, u16, u8);
	int (*getapp)(struct net_device___10 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___10 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___10 *, int, u8);
	u8 (*getdcbx)(struct net_device___10 *);
	u8 (*setdcbx)(struct net_device___10 *, u8);
	int (*peer_getappinfo)(struct net_device___10 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___10 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___10 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___10 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___10 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___10 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___5 {
	struct net_device___10 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___5 {
	struct net_device___10 *dev;
};

struct xdp_buff___5 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___5 *rxq;
	struct xdp_txq_info___5 *txq;
	u32 frame_sz;
};

struct xdp_frame___5 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___10 *dev_rx;
};

struct netlink_callback___5 {
	struct sk_buff___7 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___7 *, struct netlink_callback___5 *);
	int (*done)(struct netlink_callback___5 *);
	void *data;
	struct module___46 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___5 {
	int (*create)(struct sk_buff___7 *, struct net_device___10 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___7 *, unsigned char *);
	int (*cache)(const struct neighbour___4 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___10 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___7 *);
};

struct netdev_queue___5 {
	struct net_device___10 *dev;
	struct Qdisc___5 *qdisc;
	struct Qdisc___5 *qdisc_sleeping;
	struct kobject___47 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___10 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___5 {
	struct sk_buff___7 *head;
	struct sk_buff___7 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___5;

struct Qdisc___5 {
	int (*enqueue)(struct sk_buff___7 *, struct Qdisc___5 *, struct sk_buff___7 **);
	struct sk_buff___7 * (*dequeue)(struct Qdisc___5 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___5 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___5 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___5 gso_skb;
	struct qdisc_skb_head___5 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___5 *next_sched;
	struct sk_buff_head___5 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___5 {
	struct xdp_rxq_info___5 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___47 kobj;
	struct net_device___10 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___5 {
	enum net_device_path_type type;
	const struct net_device___10 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___5 = 0,
				DEV_PATH_BR_VLAN_TAG___5 = 1,
				DEV_PATH_BR_VLAN_UNTAG___5 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___5 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___5 {
	const struct net_device___10 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___5 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___5 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___5 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___5 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___7 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___5 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___10 *dev;
	const char *name;
};

struct net_device_ops___5 {
	int (*ndo_init)(struct net_device___10 *);
	void (*ndo_uninit)(struct net_device___10 *);
	int (*ndo_open)(struct net_device___10 *);
	int (*ndo_stop)(struct net_device___10 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___7 *, struct net_device___10 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___7 *, struct net_device___10 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___10 *, struct sk_buff___7 *, struct net_device___10 *);
	void (*ndo_change_rx_flags)(struct net_device___10 *, int);
	void (*ndo_set_rx_mode)(struct net_device___10 *);
	int (*ndo_set_mac_address)(struct net_device___10 *, void *);
	int (*ndo_validate_addr)(struct net_device___10 *);
	int (*ndo_do_ioctl)(struct net_device___10 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___10 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___10 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___10 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___10 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___10 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___10 *, int);
	int (*ndo_neigh_setup)(struct net_device___10 *, struct neigh_parms___4 *);
	void (*ndo_tx_timeout)(struct net_device___10 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___10 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___10 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___10 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___10 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___10 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___10 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___10 *);
	int (*ndo_netpoll_setup)(struct net_device___10 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___10 *);
	int (*ndo_set_vf_mac)(struct net_device___10 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___10 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___10 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___10 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___10 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___10 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___10 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___10 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___10 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___10 *, int, struct sk_buff___7 *);
	int (*ndo_get_vf_guid)(struct net_device___10 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___10 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___10 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___10 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___10 *);
	int (*ndo_fcoe_disable)(struct net_device___10 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___10 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___10 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___10 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___10 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___10 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___10 *, const struct sk_buff___7 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___10 *, struct net_device___10 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___10 *, struct net_device___10 *);
	struct net_device___10 * (*ndo_get_xmit_slave)(struct net_device___10 *, struct sk_buff___7 *, bool);
	struct net_device___10 * (*ndo_sk_get_lower_dev)(struct net_device___10 *, struct sock___6 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___10 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___10 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___10 *, struct neighbour___4 *);
	void (*ndo_neigh_destroy)(struct net_device___10 *, struct neighbour___4 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___7 *, struct netlink_callback___5 *, struct net_device___10 *, struct net_device___10 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___7 *, struct nlattr **, struct net_device___10 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___10 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___7 *, u32, u32, struct net_device___10 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___10 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___10 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___10 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___10 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___10 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___10 *, struct net_device___10 *);
	void (*ndo_dfwd_del_station)(struct net_device___10 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___10 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___10 *);
	int (*ndo_change_proto_down)(struct net_device___10 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___10 *, struct sk_buff___7 *);
	void (*ndo_set_rx_headroom)(struct net_device___10 *, int);
	int (*ndo_bpf)(struct net_device___10 *, struct netdev_bpf___5 *);
	int (*ndo_xdp_xmit)(struct net_device___10 *, int, struct xdp_frame___5 **, u32);
	struct net_device___10 * (*ndo_xdp_get_xmit_slave)(struct net_device___10 *, struct xdp_buff___5 *);
	int (*ndo_xsk_wakeup)(struct net_device___10 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___10 *);
	int (*ndo_tunnel_ctl)(struct net_device___10 *, struct ip_tunnel_parm *, int);
	struct net_device___10 * (*ndo_get_peer_dev)(struct net_device___10 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___5 *, struct net_device_path___5 *);
};

struct neigh_parms___4 {
	possible_net_t___5 net;
	struct net_device___10 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___4 *);
	struct neigh_table___4 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___4 {
	u32 (*l3mdev_fib_table)(const struct net_device___10 *);
	struct sk_buff___7 * (*l3mdev_l3_rcv)(struct net_device___10 *, struct sk_buff___7 *, u16);
	struct sk_buff___7 * (*l3mdev_l3_out)(struct net_device___10 *, struct sock___6 *, struct sk_buff___7 *, u16);
	struct dst_entry___4 * (*l3mdev_link_scope_lookup)(const struct net_device___10 *, struct flowi6 *);
};

struct tcf_proto___5;

struct tcf_block___5;

struct mini_Qdisc___5 {
	struct tcf_proto___5 *filter_list;
	struct tcf_block___5 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___5 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___10 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___10 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___8 *, struct net_device___10 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___10 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___10 *, struct list_head *);
	size_t (*get_size)(const struct net_device___10 *);
	int (*fill_info)(struct sk_buff___7 *, const struct net_device___10 *);
	size_t (*get_xstats_size)(const struct net_device___10 *);
	int (*fill_xstats)(struct sk_buff___7 *, const struct net_device___10 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___10 *, struct net_device___10 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___10 *, const struct net_device___10 *);
	int (*fill_slave_info)(struct sk_buff___7 *, const struct net_device___10 *, const struct net_device___10 *);
	struct net___8 * (*get_link_net)(const struct net_device___10 *);
	size_t (*get_linkxstats_size)(const struct net_device___10 *, int);
	int (*fill_linkxstats)(struct sk_buff___7 *, const struct net_device___10 *, int *, int);
};

struct block_device_operations___22;

struct gendisk___22 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___23 *part0;
	const struct block_device_operations___22 *fops;
	struct request_queue___23 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___21 *bdi;
	struct kobject___47 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___47 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___22 {
	struct bio___22 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___25 *bip_vec;
	struct bio_vec___25 bip_inline_vecs[0];
};

struct blkcg___21;

struct blkg_policy_data___21;

struct blkcg_gq___21 {
	struct request_queue___23 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___21 *blkcg;
	struct blkcg_gq___21 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___21 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___22 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___22(struct request___22 *);

typedef void integrity_complete_fn___22(struct request___22 *, unsigned int);

struct blk_integrity_profile___22 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___22 *prepare_fn;
	integrity_complete_fn___22 *complete_fn;
	const char *name;
};

struct block_device_operations___22 {
	blk_qc_t (*submit_bio)(struct bio___22 *);
	int (*open)(struct block_device___23 *, fmode_t);
	void (*release)(struct gendisk___22 *, fmode_t);
	int (*rw_page)(struct block_device___23 *, sector_t, struct page___49 *, unsigned int);
	int (*ioctl)(struct block_device___23 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___23 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___22 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___22 *);
	int (*getgeo)(struct block_device___23 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___23 *, bool);
	void (*swap_slot_free_notify)(struct block_device___23 *, long unsigned int);
	int (*report_zones)(struct gendisk___22 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___22 *, umode_t *);
	struct module___46 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___22 *, sector_t *);
};

typedef void rq_end_io_fn___22(struct request___22 *, blk_status_t);

struct request___22 {
	struct request_queue___23 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___21 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___22 *bio;
	struct bio___22 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___25 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___22 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___22 *saved_end_io;
		} flush;
	};
	struct gendisk___22 *rq_disk;
	struct block_device___23 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___22 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___21 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___23 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___47 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___46 *debugfs_dir;
	struct dentry___46 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___22;

struct elevator_mq_ops___22 {
	int (*init_sched)(struct request_queue___23 *, struct elevator_type___22 *);
	void (*exit_sched)(struct elevator_queue___22 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___21 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___21 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___21 *);
	bool (*allow_merge)(struct request_queue___23 *, struct request___22 *, struct bio___22 *);
	bool (*bio_merge)(struct request_queue___23 *, struct bio___22 *, unsigned int);
	int (*request_merge)(struct request_queue___23 *, struct request___22 **, struct bio___22 *);
	void (*request_merged)(struct request_queue___23 *, struct request___22 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___23 *, struct request___22 *, struct request___22 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___22 *);
	void (*finish_request)(struct request___22 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___21 *, struct list_head *, bool);
	struct request___22 * (*dispatch_request)(struct blk_mq_hw_ctx___21 *);
	bool (*has_work)(struct blk_mq_hw_ctx___21 *);
	void (*completed_request)(struct request___22 *, u64);
	void (*requeue_request)(struct request___22 *);
	struct request___22 * (*former_request)(struct request_queue___23 *, struct request___22 *);
	struct request___22 * (*next_request)(struct request_queue___23 *, struct request___22 *);
	void (*init_icq)(struct io_cq___22 *);
	void (*exit_icq)(struct io_cq___22 *);
};

struct elv_fs_entry___22;

struct elevator_type___22 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___22 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___22 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___46 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___22 {
	struct elevator_type___22 *type;
	void *elevator_data;
	struct kobject___47 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___22 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___22 *, char *);
	ssize_t (*store)(struct elevator_queue___22 *, const char *, size_t);
};

struct blk_mq_queue_data___21;

struct blk_mq_ops___21 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___21 *, const struct blk_mq_queue_data___21 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___21 *);
	int (*get_budget)(struct request_queue___23 *);
	void (*put_budget)(struct request_queue___23 *, int);
	void (*set_rq_budget_token)(struct request___22 *, int);
	int (*get_rq_budget_token)(struct request___22 *);
	enum blk_eh_timer_return (*timeout)(struct request___22 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___21 *);
	void (*complete)(struct request___22 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___21 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___21 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___21 *, struct request___22 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___21 *, struct request___22 *, unsigned int);
	void (*initialize_rq_fn)(struct request___22 *);
	void (*cleanup_rq)(struct request___22 *);
	bool (*busy)(struct request_queue___23 *);
	int (*map_queues)(struct blk_mq_tag_set___21 *);
	void (*show_rq)(struct seq_file___45 *, struct request___22 *);
};

struct blk_mq_tag_set___21 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___21 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___21 {
	struct request___22 *rq;
	bool last;
};

struct blkcg_policy_data___21;

struct blkcg___21 {
	struct cgroup_subsys_state___37 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___21 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___21 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___21 {
	struct blkcg___21 *blkcg;
	int plid;
};

struct blkg_policy_data___21 {
	struct blkcg_gq___21 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___21 {
	struct mem_cgroup___21 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___21 {
	struct lruvec___22 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___21 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___21 *memcg;
};

struct obj_cgroup___21 {
	struct percpu_ref refcnt;
	struct mem_cgroup___21 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___5 {
	spinlock_t *lock;
	struct sk_buff___7 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___5;

struct Qdisc_ops___5 {
	struct Qdisc_ops___5 *next;
	const struct Qdisc_class_ops___5 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___7 *, struct Qdisc___5 *, struct sk_buff___7 **);
	struct sk_buff___7 * (*dequeue)(struct Qdisc___5 *);
	struct sk_buff___7 * (*peek)(struct Qdisc___5 *);
	int (*init)(struct Qdisc___5 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___5 *);
	void (*destroy)(struct Qdisc___5 *);
	int (*change)(struct Qdisc___5 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___5 *);
	int (*change_tx_queue_len)(struct Qdisc___5 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___5 *, unsigned int);
	int (*dump)(struct Qdisc___5 *, struct sk_buff___7 *);
	int (*dump_stats)(struct Qdisc___5 *, struct gnet_dump___5 *);
	void (*ingress_block_set)(struct Qdisc___5 *, u32);
	void (*egress_block_set)(struct Qdisc___5 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___5 *);
	u32 (*egress_block_get)(struct Qdisc___5 *);
	struct module___46 *owner;
};

struct Qdisc_class_ops___5 {
	unsigned int flags;
	struct netdev_queue___5 * (*select_queue)(struct Qdisc___5 *, struct tcmsg *);
	int (*graft)(struct Qdisc___5 *, long unsigned int, struct Qdisc___5 *, struct Qdisc___5 **, struct netlink_ext_ack *);
	struct Qdisc___5 * (*leaf)(struct Qdisc___5 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___5 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___5 *, u32);
	int (*change)(struct Qdisc___5 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___5 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___5 *, struct qdisc_walker *);
	struct tcf_block___5 * (*tcf_block)(struct Qdisc___5 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___5 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___5 *, long unsigned int);
	int (*dump)(struct Qdisc___5 *, long unsigned int, struct sk_buff___7 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___5 *, long unsigned int, struct gnet_dump___5 *);
};

struct tcf_chain___5;

struct tcf_block___5 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___8 *net;
	struct Qdisc___5 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___5 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___5;

struct tcf_proto_ops___5;

struct tcf_proto___5 {
	struct tcf_proto___5 *next;
	void *root;
	int (*classify)(struct sk_buff___7 *, const struct tcf_proto___5 *, struct tcf_result___5 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___5 *ops;
	struct tcf_chain___5 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___5 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___5 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___5 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___7 *, const struct tcf_proto___5 *, struct tcf_result___5 *);
	int (*init)(struct tcf_proto___5 *);
	void (*destroy)(struct tcf_proto___5 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___5 *, u32);
	void (*put)(struct tcf_proto___5 *, void *);
	int (*change)(struct net___8 *, struct sk_buff___7 *, struct tcf_proto___5 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___5 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___5 *);
	void (*walk)(struct tcf_proto___5 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___5 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___5 *, void *);
	void (*hw_del)(struct tcf_proto___5 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___8 *, struct tcf_chain___5 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___8 *, struct tcf_proto___5 *, void *, struct sk_buff___7 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___8 *, struct tcf_proto___5 *, void *, struct sk_buff___7 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___7 *, struct net___8 *, void *);
	struct module___46 *owner;
	int flags;
};

struct tcf_chain___5 {
	struct mutex filter_chain_lock;
	struct tcf_proto___5 *filter_chain;
	struct list_head list;
	struct tcf_block___5 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___5 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___4 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___5 *prog;
};

struct pneigh_entry___4;

struct neigh_hash_table___4;

struct neigh_table___4 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___10 *, __u32 *);
	bool (*key_eq)(const struct neighbour___4 *, const void *);
	int (*constructor)(struct neighbour___4 *);
	int (*pconstructor)(struct pneigh_entry___4 *);
	void (*pdestructor)(struct pneigh_entry___4 *);
	void (*proxy_redo)(struct sk_buff___7 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___10 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___4 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___5 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___4 *nht;
	struct pneigh_entry___4 **phash_buckets;
};

struct neigh_ops___4 {
	int family;
	void (*solicit)(struct neighbour___4 *, struct sk_buff___7 *);
	void (*error_report)(struct neighbour___4 *, struct sk_buff___7 *);
	int (*output)(struct neighbour___4 *, struct sk_buff___7 *);
	int (*connected_output)(struct neighbour___4 *, struct sk_buff___7 *);
};

struct pneigh_entry___4 {
	struct pneigh_entry___4 *next;
	possible_net_t___5 net;
	struct net_device___10 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___4 {
	struct neighbour___4 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___4 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___4 *ctarget;
	struct net___8 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___4 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___4 *rule;
	u32 table;
	int flags;
};

struct proto___4 {
	void (*close)(struct sock___6 *, long int);
	int (*pre_connect)(struct sock___6 *, struct sockaddr *, int);
	int (*connect)(struct sock___6 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___6 *, int);
	struct sock___6 * (*accept)(struct sock___6 *, int, int *, bool);
	int (*ioctl)(struct sock___6 *, int, long unsigned int);
	int (*init)(struct sock___6 *);
	void (*destroy)(struct sock___6 *);
	void (*shutdown)(struct sock___6 *, int);
	int (*setsockopt)(struct sock___6 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___6 *, int, int, char *, int *);
	void (*keepalive)(struct sock___6 *, int);
	int (*compat_ioctl)(struct sock___6 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___6 *, struct msghdr___4 *, size_t);
	int (*recvmsg)(struct sock___6 *, struct msghdr___4 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___6 *, struct page___49 *, int, size_t, int);
	int (*bind)(struct sock___6 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___6 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___6 *, struct sk_buff___7 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___6 *);
	int (*hash)(struct sock___6 *);
	void (*unhash)(struct sock___6 *);
	void (*rehash)(struct sock___6 *);
	int (*get_port)(struct sock___6 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___6 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___6 *, int);
	bool (*sock_is_readable)(struct sock___6 *);
	void (*enter_memory_pressure)(struct sock___6 *);
	void (*leave_memory_pressure)(struct sock___6 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___46 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___6 *, int);
};

struct perf_cpu_context___33;

struct perf_output_handle___33;

struct pmu___33 {
	struct list_head entry;
	struct module___46 *module;
	struct device___44 *dev;
	const struct attribute_group___47 **attr_groups;
	const struct attribute_group___47 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___33 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___33 *);
	void (*pmu_disable)(struct pmu___33 *);
	int (*event_init)(struct perf_event___33 *);
	void (*event_mapped)(struct perf_event___33 *, struct mm_struct___50 *);
	void (*event_unmapped)(struct perf_event___33 *, struct mm_struct___50 *);
	int (*add)(struct perf_event___33 *, int);
	void (*del)(struct perf_event___33 *, int);
	void (*start)(struct perf_event___33 *, int);
	void (*stop)(struct perf_event___33 *, int);
	void (*read)(struct perf_event___33 *);
	void (*start_txn)(struct pmu___33 *, unsigned int);
	int (*commit_txn)(struct pmu___33 *);
	void (*cancel_txn)(struct pmu___33 *);
	int (*event_idx)(struct perf_event___33 *);
	void (*sched_task)(struct perf_event_context___33 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___33 *, struct perf_event_context___33 *);
	void * (*setup_aux)(struct perf_event___33 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___33 *, struct perf_output_handle___33 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___33 *);
	int (*aux_output_match)(struct perf_event___33 *);
	int (*filter_match)(struct perf_event___33 *);
	int (*check_period)(struct perf_event___33 *, u64);
};

struct perf_cpu_context___33 {
	struct perf_event_context___33 ctx;
	struct perf_event_context___33 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___33 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___33 **heap;
	struct perf_event___33 *heap_default[2];
};

struct perf_output_handle___33 {
	struct perf_event___33 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___33 {
	struct cgroup_subsys_state___37 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___28 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___28 *);
	};
};

struct trace_event_class___28 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___28 *, enum trace_reg, void *);
	struct trace_event_fields___28 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___28 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___28 *);
};

struct trace_event_file___13;

struct trace_event_buffer___13 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___13 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___13 {
	struct list_head list;
	struct trace_event_call___28 *event_call;
	struct event_filter *filter;
	struct dentry___46 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_cgroup_root {
	struct trace_entry ent;
	int root;
	u16 ss_mask;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_cgroup {
	struct trace_entry ent;
	int root;
	int level;
	u64 id;
	u32 __data_loc_path;
	char __data[0];
};

struct trace_event_raw_cgroup_migrate {
	struct trace_entry ent;
	int dst_root;
	int dst_level;
	u64 dst_id;
	int pid;
	u32 __data_loc_dst_path;
	u32 __data_loc_comm;
	char __data[0];
};

struct trace_event_raw_cgroup_event {
	struct trace_entry ent;
	int root;
	int level;
	u64 id;
	u32 __data_loc_path;
	int val;
	char __data[0];
};

struct trace_event_data_offsets_cgroup_root {
	u32 name;
};

struct trace_event_data_offsets_cgroup {
	u32 path;
};

struct trace_event_data_offsets_cgroup_migrate {
	u32 dst_path;
	u32 comm;
};

struct trace_event_data_offsets_cgroup_event {
	u32 path;
};

typedef void (*btf_trace_cgroup_setup_root)(void *, struct cgroup_root___37 *);

typedef void (*btf_trace_cgroup_destroy_root)(void *, struct cgroup_root___37 *);

typedef void (*btf_trace_cgroup_remount)(void *, struct cgroup_root___37 *);

typedef void (*btf_trace_cgroup_mkdir)(void *, struct cgroup___37 *, const char *);

typedef void (*btf_trace_cgroup_rmdir)(void *, struct cgroup___37 *, const char *);

typedef void (*btf_trace_cgroup_release)(void *, struct cgroup___37 *, const char *);

typedef void (*btf_trace_cgroup_rename)(void *, struct cgroup___37 *, const char *);

typedef void (*btf_trace_cgroup_freeze)(void *, struct cgroup___37 *, const char *);

typedef void (*btf_trace_cgroup_unfreeze)(void *, struct cgroup___37 *, const char *);

typedef void (*btf_trace_cgroup_attach_task)(void *, struct cgroup___37 *, const char *, struct task_struct___50 *, bool);

typedef void (*btf_trace_cgroup_transfer_tasks)(void *, struct cgroup___37 *, const char *, struct task_struct___50 *, bool);

typedef void (*btf_trace_cgroup_notify_populated)(void *, struct cgroup___37 *, const char *, int);

typedef void (*btf_trace_cgroup_notify_frozen)(void *, struct cgroup___37 *, const char *, int);

enum cgroup_opt_features {
	OPT_FEATURE_PRESSURE = 0,
	OPT_FEATURE_COUNT = 1,
};

enum cgroup2_param {
	Opt_nsdelegate = 0,
	Opt_memory_localevents = 1,
	Opt_memory_recursiveprot = 2,
	nr__cgroup2_params = 3,
};

struct fs_context___6;

struct fs_parameter_spec___6;

struct dentry___47;

struct super_block___47;

struct module___47;

struct file_system_type___46 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___6 *);
	const struct fs_parameter_spec___6 *parameters;
	struct dentry___47 * (*mount)(struct file_system_type___46 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___47 *);
	struct module___47 *owner;
	struct file_system_type___46 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___47;

struct kiocb___46;

struct vm_area_struct___50;

struct inode___47;

struct file_lock___46;

struct page___50;

struct seq_file___46;

struct file_operations___46 {
	struct module___47 *owner;
	loff_t (*llseek)(struct file___47 *, loff_t, int);
	ssize_t (*read)(struct file___47 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___47 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___46 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___46 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___46 *, bool);
	int (*iterate)(struct file___47 *, struct dir_context *);
	int (*iterate_shared)(struct file___47 *, struct dir_context *);
	__poll_t (*poll)(struct file___47 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___47 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___47 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___47 *, struct vm_area_struct___50 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___47 *, struct file___47 *);
	int (*flush)(struct file___47 *, fl_owner_t);
	int (*release)(struct inode___47 *, struct file___47 *);
	int (*fsync)(struct file___47 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___47 *, int);
	int (*lock)(struct file___47 *, int, struct file_lock___46 *);
	ssize_t (*sendpage)(struct file___47 *, struct page___50 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___47 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___47 *, long unsigned int);
	int (*flock)(struct file___47 *, int, struct file_lock___46 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___47 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___47 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___47 *, long int, struct file_lock___46 **, void **);
	long int (*fallocate)(struct file___47 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___46 *, struct file___47 *);
	ssize_t (*copy_file_range)(struct file___47 *, loff_t, struct file___47 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___47 *, loff_t, struct file___47 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___47 *, loff_t, loff_t, int);
};

struct vmacache___50 {
	u64 seqnum;
	struct vm_area_struct___50 *vmas[4];
};

struct page_frag___50 {
	struct page___50 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___51;

struct nsproxy___46;

struct signal_struct___47;

struct css_set___38;

struct vm_struct___49;

struct task_struct___51 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___51 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___51 *mm;
	struct mm_struct___51 *active_mm;
	struct vmacache___50 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___51 *real_parent;
	struct task_struct___51 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___51 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___43 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___5 *ptracer_cred;
	const struct cred___5 *real_cred;
	const struct cred___5 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___46 *nsproxy;
	struct signal_struct___47 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___51 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___23 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___38 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___50 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___51 *oom_reaper_list;
	struct vm_struct___49 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___48;

struct kobj_type___48;

struct kernfs_node___48;

struct kobject___48 {
	const char *name;
	struct list_head entry;
	struct kobject___48 *parent;
	struct kset___48 *kset;
	struct kobj_type___48 *ktype;
	struct kernfs_node___48 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___45 {
	struct kobject___48 kobj;
	struct module___47 *mod;
	struct kobject___48 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___45 {
	struct module___47 *mod;
	struct latch_tree_node node;
};

struct module_layout___45 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___45 mtn;
};

struct module_attribute___45;

struct kernel_param___45;

struct module___47 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___45 mkobj;
	struct module_attribute___45 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___48 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___45 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___45 core_layout;
	struct module_layout___45 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___50 *pgtable_t___50;

struct address_space___46;

struct dev_pagemap___46;

struct page___50 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___46 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___50 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___50 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___51 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___46 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___46;

struct vm_area_struct___50 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___50 *vm_next;
	struct vm_area_struct___50 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___51 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___46 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___47 *vm_file;
	struct file___47 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___47 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___51 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___51 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___43 *pids[4];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___51 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___50;

struct mm_struct___51 {
	struct {
		struct vm_area_struct___50 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___47 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___50 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___51 *owner;
		struct user_namespace___6 *user_ns;
		struct file___47 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___38;

struct nsproxy___46 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___38 *cgroup_ns;
};

struct cgroup_subsys_state___38;

struct cgroup___38;

struct css_set___38 {
	struct cgroup_subsys_state___38 *subsys[14];
	refcount_t refcount;
	struct css_set___38 *dom_cset;
	struct cgroup___38 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___38 *mg_src_cgrp;
	struct cgroup___38 *mg_dst_cgrp;
	struct css_set___38 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___49 {
	struct vm_struct___49 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___50 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___46;

struct dentry___47 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___47 *d_parent;
	struct qstr d_name;
	struct inode___47 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___46 *d_op;
	struct super_block___47 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___46;

struct address_space___46 {
	struct inode___47 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___46 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___46;

struct inode___47 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___46 *i_op;
	struct super_block___47 *i_sb;
	struct address_space___46 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___46 *i_fop;
		void (*free_inode)(struct inode___47 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___46 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___46;

struct path___46;

struct dentry_operations___46 {
	int (*d_revalidate)(struct dentry___47 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___47 *, unsigned int);
	int (*d_hash)(const struct dentry___47 *, struct qstr *);
	int (*d_compare)(const struct dentry___47 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___47 *);
	int (*d_init)(struct dentry___47 *);
	void (*d_release)(struct dentry___47 *);
	void (*d_prune)(struct dentry___47 *);
	void (*d_iput)(struct dentry___47 *, struct inode___47 *);
	char * (*d_dname)(struct dentry___47 *, char *, int);
	struct vfsmount___46 * (*d_automount)(struct path___46 *);
	int (*d_manage)(const struct path___46 *, bool);
	struct dentry___47 * (*d_real)(struct dentry___47 *, const struct inode___47 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___46;

struct mem_dqinfo___46 {
	struct quota_format_type___46 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___46;

struct quota_info___46 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___47 *files[3];
	struct mem_dqinfo___46 info[3];
	const struct quota_format_ops___46 *ops[3];
};

struct rcuwait___47 {
	struct task_struct___51 *task;
};

struct percpu_rw_semaphore___47 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___47 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___46 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___47 rw_sem[3];
};

struct super_operations___46;

struct dquot_operations___46;

struct quotactl_ops___46;

struct super_block___47 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___46 *s_type;
	const struct super_operations___46 *s_op;
	const struct dquot_operations___46 *dq_op;
	const struct quotactl_ops___46 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___47 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___46 s_dquot;
	struct sb_writers___46 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___46 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___6 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___46 {
	struct dentry___47 *mnt_root;
	struct super_block___47 *mnt_sb;
	int mnt_flags;
	struct user_namespace___6 *mnt_userns;
};

struct path___46 {
	struct vfsmount___46 *mnt;
	struct dentry___47 *dentry;
};

struct dev_pagemap_ops___46;

struct dev_pagemap___46 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___46 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___47 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___46 f_path;
	struct inode___47 *f_inode;
	const struct file_operations___46 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___5 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___46 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___46;

struct vm_operations_struct___46 {
	void (*open)(struct vm_area_struct___50 *);
	void (*close)(struct vm_area_struct___50 *);
	int (*may_split)(struct vm_area_struct___50 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___50 *);
	int (*mprotect)(struct vm_area_struct___50 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___46 *);
	vm_fault_t (*huge_fault)(struct vm_fault___46 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___46 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___50 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___46 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___46 *);
	int (*access)(struct vm_area_struct___50 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___50 *);
	int (*set_policy)(struct vm_area_struct___50 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___50 *, long unsigned int);
	struct page___50 * (*find_special_page)(struct vm_area_struct___50 *, long unsigned int);
};

struct core_thread___50 {
	struct task_struct___51 *task;
	struct core_thread___50 *next;
};

struct core_state___50 {
	atomic_t nr_threads;
	struct core_thread___50 dumper;
	struct completion startup;
};

struct vm_fault___46 {
	const struct {
		struct vm_area_struct___50 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___50 *cow_page;
	struct page___50 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___50 prealloc_pte;
};

struct cgroup_subsys___38;

struct cgroup_subsys_state___38 {
	struct cgroup___38 *cgroup;
	struct cgroup_subsys___38 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___38 *parent;
};

struct cgroup_file___38 {
	struct kernfs_node___48 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___38 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___51 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___38;

struct cgroup_rstat_cpu___38;

struct cgroup___38 {
	struct cgroup_subsys_state___38 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___48 *kn;
	struct cgroup_file___38 procs_file;
	struct cgroup_file___38 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___38 *subsys[14];
	struct cgroup_root___38 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___38 *dom_cgrp;
	struct cgroup___38 *old_dom_cgrp;
	struct cgroup_rstat_cpu___38 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___38 psi;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___46 {
	struct file___47 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___46 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___24 *ki_waitq;
	};
};

struct iattr___47 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___47 *ia_file;
};

struct dquot___46 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___47 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___46 {
	int qf_fmt_id;
	const struct quota_format_ops___46 *qf_ops;
	struct module___47 *qf_owner;
	struct quota_format_type___46 *qf_next;
};

struct quota_format_ops___46 {
	int (*check_quota_file)(struct super_block___47 *, int);
	int (*read_file_info)(struct super_block___47 *, int);
	int (*write_file_info)(struct super_block___47 *, int);
	int (*free_file_info)(struct super_block___47 *, int);
	int (*read_dqblk)(struct dquot___46 *);
	int (*commit_dqblk)(struct dquot___46 *);
	int (*release_dqblk)(struct dquot___46 *);
	int (*get_next_id)(struct super_block___47 *, struct kqid *);
};

struct dquot_operations___46 {
	int (*write_dquot)(struct dquot___46 *);
	struct dquot___46 * (*alloc_dquot)(struct super_block___47 *, int);
	void (*destroy_dquot)(struct dquot___46 *);
	int (*acquire_dquot)(struct dquot___46 *);
	int (*release_dquot)(struct dquot___46 *);
	int (*mark_dirty)(struct dquot___46 *);
	int (*write_info)(struct super_block___47 *, int);
	qsize_t * (*get_reserved_space)(struct inode___47 *);
	int (*get_projid)(struct inode___47 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___47 *, qsize_t *);
	int (*get_next_id)(struct super_block___47 *, struct kqid *);
};

struct quotactl_ops___46 {
	int (*quota_on)(struct super_block___47 *, int, int, const struct path___46 *);
	int (*quota_off)(struct super_block___47 *, int);
	int (*quota_enable)(struct super_block___47 *, unsigned int);
	int (*quota_disable)(struct super_block___47 *, unsigned int);
	int (*quota_sync)(struct super_block___47 *, int);
	int (*set_info)(struct super_block___47 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___47 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___47 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___47 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___47 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___47 *, unsigned int);
};

struct address_space_operations___46 {
	int (*writepage)(struct page___50 *, struct writeback_control___3 *);
	int (*readpage)(struct file___47 *, struct page___50 *);
	int (*writepages)(struct address_space___46 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___50 *);
	int (*readpages)(struct file___47 *, struct address_space___46 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___47 *, struct address_space___46 *, loff_t, unsigned int, unsigned int, struct page___50 **, void **);
	int (*write_end)(struct file___47 *, struct address_space___46 *, loff_t, unsigned int, unsigned int, struct page___50 *, void *);
	sector_t (*bmap)(struct address_space___46 *, sector_t);
	void (*invalidatepage)(struct page___50 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___50 *, gfp_t);
	void (*freepage)(struct page___50 *);
	ssize_t (*direct_IO)(struct kiocb___46 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___46 *, struct page___50 *, struct page___50 *, enum migrate_mode);
	bool (*isolate_page)(struct page___50 *, isolate_mode_t);
	void (*putback_page)(struct page___50 *);
	int (*launder_page)(struct page___50 *);
	int (*is_partially_uptodate)(struct page___50 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___50 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___46 *, struct page___50 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___47 *, sector_t *);
	void (*swap_deactivate)(struct file___47 *);
};

struct inode_operations___46 {
	struct dentry___47 * (*lookup)(struct inode___47 *, struct dentry___47 *, unsigned int);
	const char * (*get_link)(struct dentry___47 *, struct inode___47 *, struct delayed_call *);
	int (*permission)(struct user_namespace___6 *, struct inode___47 *, int);
	struct posix_acl * (*get_acl)(struct inode___47 *, int, bool);
	int (*readlink)(struct dentry___47 *, char *, int);
	int (*create)(struct user_namespace___6 *, struct inode___47 *, struct dentry___47 *, umode_t, bool);
	int (*link)(struct dentry___47 *, struct inode___47 *, struct dentry___47 *);
	int (*unlink)(struct inode___47 *, struct dentry___47 *);
	int (*symlink)(struct user_namespace___6 *, struct inode___47 *, struct dentry___47 *, const char *);
	int (*mkdir)(struct user_namespace___6 *, struct inode___47 *, struct dentry___47 *, umode_t);
	int (*rmdir)(struct inode___47 *, struct dentry___47 *);
	int (*mknod)(struct user_namespace___6 *, struct inode___47 *, struct dentry___47 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___6 *, struct inode___47 *, struct dentry___47 *, struct inode___47 *, struct dentry___47 *, unsigned int);
	int (*setattr)(struct user_namespace___6 *, struct dentry___47 *, struct iattr___47 *);
	int (*getattr)(struct user_namespace___6 *, const struct path___46 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___47 *, char *, size_t);
	int (*fiemap)(struct inode___47 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___47 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___47 *, struct dentry___47 *, struct file___47 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___6 *, struct inode___47 *, struct dentry___47 *, umode_t);
	int (*set_acl)(struct user_namespace___6 *, struct inode___47 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___6 *, struct dentry___47 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___47 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___46 {
	void (*fl_copy_lock)(struct file_lock___46 *, struct file_lock___46 *);
	void (*fl_release_private)(struct file_lock___46 *);
};

struct fasync_struct___46;

struct lock_manager_operations___46;

struct file_lock___46 {
	struct file_lock___46 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___47 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___46 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___46 *fl_ops;
	const struct lock_manager_operations___46 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___46 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___46 *);
	int (*lm_grant)(struct file_lock___46 *, int);
	bool (*lm_break)(struct file_lock___46 *);
	int (*lm_change)(struct file_lock___46 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___46 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___46 *);
};

struct fasync_struct___46 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___46 *fa_next;
	struct file___47 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___46 {
	struct inode___47 * (*alloc_inode)(struct super_block___47 *);
	void (*destroy_inode)(struct inode___47 *);
	void (*free_inode)(struct inode___47 *);
	void (*dirty_inode)(struct inode___47 *, int);
	int (*write_inode)(struct inode___47 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___47 *);
	void (*evict_inode)(struct inode___47 *);
	void (*put_super)(struct super_block___47 *);
	int (*sync_fs)(struct super_block___47 *, int);
	int (*freeze_super)(struct super_block___47 *);
	int (*freeze_fs)(struct super_block___47 *);
	int (*thaw_super)(struct super_block___47 *);
	int (*unfreeze_fs)(struct super_block___47 *);
	int (*statfs)(struct dentry___47 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___47 *, int *, char *);
	void (*umount_begin)(struct super_block___47 *);
	int (*show_options)(struct seq_file___46 *, struct dentry___47 *);
	int (*show_devname)(struct seq_file___46 *, struct dentry___47 *);
	int (*show_path)(struct seq_file___46 *, struct dentry___47 *);
	int (*show_stats)(struct seq_file___46 *, struct dentry___47 *);
	ssize_t (*quota_read)(struct super_block___47 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___47 *, int, const char *, size_t, loff_t);
	struct dquot___46 ** (*get_dquots)(struct inode___47 *);
	long int (*nr_cached_objects)(struct super_block___47 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___47 *, struct shrink_control___21 *);
	struct file___47 * (*real_loop)(struct file___47 *);
};

struct seq_operations___45;

struct seq_file___46 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___45 *op;
	int poll_event;
	const struct file___47 *file;
	void *private;
};

struct fc_log___6;

struct p_log___6 {
	const char *prefix;
	struct fc_log___6 *log;
};

struct fs_context_operations___6;

struct fs_context___6 {
	const struct fs_context_operations___6 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___46 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___47 *root;
	struct user_namespace___6 *user_ns;
	struct net *net_ns;
	const struct cred___5 *cred;
	struct p_log___6 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___6;

typedef int fs_param_type___6(struct p_log___6 *, const struct fs_parameter_spec___6 *, struct fs_parameter___6 *, struct fs_parse_result *);

struct fs_parameter_spec___6 {
	const char *name;
	fs_param_type___6 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct seq_operations___45 {
	void * (*start)(struct seq_file___46 *, loff_t *);
	void (*stop)(struct seq_file___46 *, void *);
	void * (*next)(struct seq_file___46 *, void *, loff_t *);
	int (*show)(struct seq_file___46 *, void *);
};

struct kernfs_root___48;

struct kernfs_elem_dir___48 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___48 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___48;

struct kernfs_root___48 {
	struct kernfs_node___48 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___48 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___48 {
	struct kernfs_node___48 *target_kn;
};

struct kernfs_ops___48;

struct kernfs_elem_attr___48 {
	const struct kernfs_ops___48 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___48 *notify_next;
};

struct kernfs_node___48 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___48 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___48 dir;
		struct kernfs_elem_symlink___48 symlink;
		struct kernfs_elem_attr___48 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___48;

struct kernfs_ops___48 {
	int (*open)(struct kernfs_open_file___48 *);
	void (*release)(struct kernfs_open_file___48 *);
	int (*seq_show)(struct seq_file___46 *, void *);
	void * (*seq_start)(struct seq_file___46 *, loff_t *);
	void * (*seq_next)(struct seq_file___46 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___46 *, void *);
	ssize_t (*read)(struct kernfs_open_file___48 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___48 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___48 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___48 *, struct vm_area_struct___50 *);
};

struct kernfs_syscall_ops___48 {
	int (*show_options)(struct seq_file___46 *, struct kernfs_root___48 *);
	int (*mkdir)(struct kernfs_node___48 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___48 *);
	int (*rename)(struct kernfs_node___48 *, struct kernfs_node___48 *, const char *);
	int (*show_path)(struct seq_file___46 *, struct kernfs_node___48 *, struct kernfs_root___48 *);
};

struct kernfs_open_file___48 {
	struct kernfs_node___48 *kn;
	struct file___47 *file;
	struct seq_file___46 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___46 *vm_ops;
};

struct cgroup_namespace___38 {
	struct ns_common___7 ns;
	struct user_namespace___6 *user_ns;
	struct ucounts___6 *ucounts;
	struct css_set___38 *root_cset;
};

struct bin_attribute___48;

struct attribute_group___48 {
	const char *name;
	umode_t (*is_visible)(struct kobject___48 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___48 *, struct bin_attribute___48 *, int);
	struct attribute **attrs;
	struct bin_attribute___48 **bin_attrs;
};

struct bin_attribute___48 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___46 * (*f_mapping)();
	ssize_t (*read)(struct file___47 *, struct kobject___48 *, struct bin_attribute___48 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___47 *, struct kobject___48 *, struct bin_attribute___48 *, char *, loff_t, size_t);
	int (*mmap)(struct file___47 *, struct kobject___48 *, struct bin_attribute___48 *, struct vm_area_struct___50 *);
};

struct sysfs_ops___48 {
	ssize_t (*show)(struct kobject___48 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___48 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___48;

struct kset___48 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___48 kobj;
	const struct kset_uevent_ops___48 *uevent_ops;
};

struct kobj_type___48 {
	void (*release)(struct kobject___48 *);
	const struct sysfs_ops___48 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___48 **default_groups;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___48 *);
	const void * (*namespace)(struct kobject___48 *);
	void (*get_ownership)(struct kobject___48 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___48 {
	int (* const filter)(struct kset___48 *, struct kobject___48 *);
	const char * (* const name)(struct kset___48 *, struct kobject___48 *);
	int (* const uevent)(struct kset___48 *, struct kobject___48 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___45 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___45 *);
	int (*get)(char *, const struct kernel_param___45 *);
	void (*free)(void *);
};

struct kparam_array___45;

struct kernel_param___45 {
	const char *name;
	struct module___47 *mod;
	const struct kernel_param_ops___45 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___45 *arr;
	};
};

struct kparam_array___45 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___45 *ops;
	void *elem;
};

struct module_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___45 *, struct module_kobject___45 *, char *);
	ssize_t (*store)(struct module_attribute___45 *, struct module_kobject___45 *, const char *, size_t);
	void (*setup)(struct module___47 *, const char *);
	int (*test)(struct module___47 *);
	void (*free)(struct module___47 *);
};

struct dev_pagemap_ops___46 {
	void (*page_free)(struct page___50 *);
	void (*kill)(struct dev_pagemap___46 *);
	void (*cleanup)(struct dev_pagemap___46 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___46 *);
};

struct cgroup_taskset___3;

struct cftype___38;

struct cgroup_subsys___38 {
	struct cgroup_subsys_state___38 * (*css_alloc)(struct cgroup_subsys_state___38 *);
	int (*css_online)(struct cgroup_subsys_state___38 *);
	void (*css_offline)(struct cgroup_subsys_state___38 *);
	void (*css_released)(struct cgroup_subsys_state___38 *);
	void (*css_free)(struct cgroup_subsys_state___38 *);
	void (*css_reset)(struct cgroup_subsys_state___38 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___38 *, int);
	int (*css_extra_stat_show)(struct seq_file___46 *, struct cgroup_subsys_state___38 *);
	int (*can_attach)(struct cgroup_taskset___3 *);
	void (*cancel_attach)(struct cgroup_taskset___3 *);
	void (*attach)(struct cgroup_taskset___3 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___51 *, struct css_set___38 *);
	void (*cancel_fork)(struct task_struct___51 *, struct css_set___38 *);
	void (*fork)(struct task_struct___51 *);
	void (*exit)(struct task_struct___51 *);
	void (*release)(struct task_struct___51 *);
	void (*bind)(struct cgroup_subsys_state___38 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___38 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___38 *dfl_cftypes;
	struct cftype___38 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___38 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___38 *updated_children;
	struct cgroup___38 *updated_next;
};

struct cgroup_root___38 {
	struct kernfs_root___48 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___38 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___38 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___38 *ss;
	struct list_head node;
	struct kernfs_ops___48 *kf_ops;
	int (*open)(struct kernfs_open_file___48 *);
	void (*release)(struct kernfs_open_file___48 *);
	u64 (*read_u64)(struct cgroup_subsys_state___38 *, struct cftype___38 *);
	s64 (*read_s64)(struct cgroup_subsys_state___38 *, struct cftype___38 *);
	int (*seq_show)(struct seq_file___46 *, void *);
	void * (*seq_start)(struct seq_file___46 *, loff_t *);
	void * (*seq_next)(struct seq_file___46 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___46 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___38 *, struct cftype___38 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___38 *, struct cftype___38 *, s64);
	ssize_t (*write)(struct kernfs_open_file___48 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___48 *, struct poll_table_struct___5 *);
};

struct cgroup_taskset___3 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___38 *cur_cset;
	struct task_struct___51 *cur_task;
};

struct fs_parameter___6 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___47 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___6 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___47 *owner;
	char *buffer[8];
};

struct fs_context_operations___6 {
	void (*free)(struct fs_context___6 *);
	int (*dup)(struct fs_context___6 *, struct fs_context___6 *);
	int (*parse_param)(struct fs_context___6 *, struct fs_parameter___6 *);
	int (*parse_monolithic)(struct fs_context___6 *, void *);
	int (*get_tree)(struct fs_context___6 *);
	int (*reconfigure)(struct fs_context___6 *);
};

struct fs_context___7;

struct fs_parameter_spec___7;

struct dentry___48;

struct super_block___48;

struct module___48;

struct file_system_type___47 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___7 *);
	const struct fs_parameter_spec___7 *parameters;
	struct dentry___48 * (*mount)(struct file_system_type___47 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___48 *);
	struct module___48 *owner;
	struct file_system_type___47 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___48;

struct kiocb___47;

struct vm_area_struct___51;

struct inode___48;

struct file_lock___47;

struct page___51;

struct seq_file___47;

struct file_operations___47 {
	struct module___48 *owner;
	loff_t (*llseek)(struct file___48 *, loff_t, int);
	ssize_t (*read)(struct file___48 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___48 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___47 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___47 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___47 *, bool);
	int (*iterate)(struct file___48 *, struct dir_context *);
	int (*iterate_shared)(struct file___48 *, struct dir_context *);
	__poll_t (*poll)(struct file___48 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___48 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___48 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___48 *, struct vm_area_struct___51 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___48 *, struct file___48 *);
	int (*flush)(struct file___48 *, fl_owner_t);
	int (*release)(struct inode___48 *, struct file___48 *);
	int (*fsync)(struct file___48 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___48 *, int);
	int (*lock)(struct file___48 *, int, struct file_lock___47 *);
	ssize_t (*sendpage)(struct file___48 *, struct page___51 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___48 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___48 *, long unsigned int);
	int (*flock)(struct file___48 *, int, struct file_lock___47 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___48 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___48 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___48 *, long int, struct file_lock___47 **, void **);
	long int (*fallocate)(struct file___48 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___47 *, struct file___48 *);
	ssize_t (*copy_file_range)(struct file___48 *, loff_t, struct file___48 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___48 *, loff_t, struct file___48 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___48 *, loff_t, loff_t, int);
};

struct vmacache___51 {
	u64 seqnum;
	struct vm_area_struct___51 *vmas[4];
};

struct page_frag___51 {
	struct page___51 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___52;

struct cred___6;

struct nsproxy___47;

struct signal_struct___48;

struct css_set___39;

struct vm_struct___50;

struct task_struct___52 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___52 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___52 *mm;
	struct mm_struct___52 *active_mm;
	struct vmacache___51 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___52 *real_parent;
	struct task_struct___52 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___52 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___43 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___6 *ptracer_cred;
	const struct cred___6 *real_cred;
	const struct cred___6 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___47 *nsproxy;
	struct signal_struct___48 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___52 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___23 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___39 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___51 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___52 *oom_reaper_list;
	struct vm_struct___50 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___49;

struct kobj_type___49;

struct kernfs_node___49;

struct kobject___49 {
	const char *name;
	struct list_head entry;
	struct kobject___49 *parent;
	struct kset___49 *kset;
	struct kobj_type___49 *ktype;
	struct kernfs_node___49 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___46 {
	struct kobject___49 kobj;
	struct module___48 *mod;
	struct kobject___49 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___46 {
	struct module___48 *mod;
	struct latch_tree_node node;
};

struct module_layout___46 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___46 mtn;
};

struct module_attribute___46;

struct kernel_param___46;

struct module___48 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___46 mkobj;
	struct module_attribute___46 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___49 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___46 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___46 core_layout;
	struct module_layout___46 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___8;

struct ns_common___8 {
	atomic_long_t stashed;
	const struct proc_ns_operations___8 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___7;

struct user_namespace___7 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___7 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___8 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___7 *ucounts;
	long int ucount_max[16];
};

typedef struct page___51 *pgtable_t___51;

struct address_space___47;

struct dev_pagemap___47;

struct page___51 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___47 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___51 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___51 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___52 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___47 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___7 {
	struct hlist_node node;
	struct user_namespace___7 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___47;

struct vm_area_struct___51 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___51 *vm_next;
	struct vm_area_struct___51 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___52 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___47 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___48 *vm_file;
	struct file___48 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___48 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___52 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___52 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___43 *pids[4];
	struct pid___43 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___52 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___51;

struct mm_struct___52 {
	struct {
		struct vm_area_struct___51 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___48 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___51 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___52 *owner;
		struct user_namespace___7 *user_ns;
		struct file___48 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___6 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___7 *user_ns;
	struct ucounts___7 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct cgroup_namespace___39;

struct nsproxy___47 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___39 *cgroup_ns;
};

struct cgroup_subsys_state___39;

struct cgroup___39;

struct css_set___39 {
	struct cgroup_subsys_state___39 *subsys[14];
	refcount_t refcount;
	struct css_set___39 *dom_cset;
	struct cgroup___39 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___39 *mg_src_cgrp;
	struct cgroup___39 *mg_dst_cgrp;
	struct css_set___39 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___50 {
	struct vm_struct___50 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___51 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___47;

struct dentry___48 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___48 *d_parent;
	struct qstr d_name;
	struct inode___48 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___47 *d_op;
	struct super_block___48 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___47;

struct address_space___47 {
	struct inode___48 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___47 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___47;

struct inode___48 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___47 *i_op;
	struct super_block___48 *i_sb;
	struct address_space___47 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___47 *i_fop;
		void (*free_inode)(struct inode___48 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___47 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___47;

struct path___47;

struct dentry_operations___47 {
	int (*d_revalidate)(struct dentry___48 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___48 *, unsigned int);
	int (*d_hash)(const struct dentry___48 *, struct qstr *);
	int (*d_compare)(const struct dentry___48 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___48 *);
	int (*d_init)(struct dentry___48 *);
	void (*d_release)(struct dentry___48 *);
	void (*d_prune)(struct dentry___48 *);
	void (*d_iput)(struct dentry___48 *, struct inode___48 *);
	char * (*d_dname)(struct dentry___48 *, char *, int);
	struct vfsmount___47 * (*d_automount)(struct path___47 *);
	int (*d_manage)(const struct path___47 *, bool);
	struct dentry___48 * (*d_real)(struct dentry___48 *, const struct inode___48 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___47;

struct mem_dqinfo___47 {
	struct quota_format_type___47 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___47;

struct quota_info___47 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___48 *files[3];
	struct mem_dqinfo___47 info[3];
	const struct quota_format_ops___47 *ops[3];
};

struct rcuwait___48 {
	struct task_struct___52 *task;
};

struct percpu_rw_semaphore___48 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___48 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___47 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___48 rw_sem[3];
};

struct super_operations___47;

struct dquot_operations___47;

struct quotactl_ops___47;

struct super_block___48 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___47 *s_type;
	const struct super_operations___47 *s_op;
	const struct dquot_operations___47 *dq_op;
	const struct quotactl_ops___47 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___48 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___47 s_dquot;
	struct sb_writers___47 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___47 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___7 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___47 {
	struct dentry___48 *mnt_root;
	struct super_block___48 *mnt_sb;
	int mnt_flags;
	struct user_namespace___7 *mnt_userns;
};

struct path___47 {
	struct vfsmount___47 *mnt;
	struct dentry___48 *dentry;
};

struct dev_pagemap_ops___47;

struct dev_pagemap___47 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___47 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___48 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___47 f_path;
	struct inode___48 *f_inode;
	const struct file_operations___47 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___43 f_owner;
	const struct cred___6 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___47 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___47;

struct vm_operations_struct___47 {
	void (*open)(struct vm_area_struct___51 *);
	void (*close)(struct vm_area_struct___51 *);
	int (*may_split)(struct vm_area_struct___51 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___51 *);
	int (*mprotect)(struct vm_area_struct___51 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___47 *);
	vm_fault_t (*huge_fault)(struct vm_fault___47 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___47 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___51 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___47 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___47 *);
	int (*access)(struct vm_area_struct___51 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___51 *);
	int (*set_policy)(struct vm_area_struct___51 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___51 *, long unsigned int);
	struct page___51 * (*find_special_page)(struct vm_area_struct___51 *, long unsigned int);
};

struct core_thread___51 {
	struct task_struct___52 *task;
	struct core_thread___51 *next;
};

struct core_state___51 {
	atomic_t nr_threads;
	struct core_thread___51 dumper;
	struct completion startup;
};

struct vm_fault___47 {
	const struct {
		struct vm_area_struct___51 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___51 *cow_page;
	struct page___51 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___51 prealloc_pte;
};

struct cgroup_subsys___39;

struct cgroup_subsys_state___39 {
	struct cgroup___39 *cgroup;
	struct cgroup_subsys___39 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___39 *parent;
};

struct cgroup_file___39 {
	struct kernfs_node___49 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___39 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___52 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___39;

struct cgroup_rstat_cpu___39;

struct cgroup___39 {
	struct cgroup_subsys_state___39 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___49 *kn;
	struct cgroup_file___39 procs_file;
	struct cgroup_file___39 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___39 *subsys[14];
	struct cgroup_root___39 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___39 *dom_cgrp;
	struct cgroup___39 *old_dom_cgrp;
	struct cgroup_rstat_cpu___39 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___39 psi;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___47 {
	struct file___48 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___47 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___24 *ki_waitq;
	};
};

struct iattr___48 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___48 *ia_file;
};

struct dquot___47 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___48 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___47 {
	int qf_fmt_id;
	const struct quota_format_ops___47 *qf_ops;
	struct module___48 *qf_owner;
	struct quota_format_type___47 *qf_next;
};

struct quota_format_ops___47 {
	int (*check_quota_file)(struct super_block___48 *, int);
	int (*read_file_info)(struct super_block___48 *, int);
	int (*write_file_info)(struct super_block___48 *, int);
	int (*free_file_info)(struct super_block___48 *, int);
	int (*read_dqblk)(struct dquot___47 *);
	int (*commit_dqblk)(struct dquot___47 *);
	int (*release_dqblk)(struct dquot___47 *);
	int (*get_next_id)(struct super_block___48 *, struct kqid *);
};

struct dquot_operations___47 {
	int (*write_dquot)(struct dquot___47 *);
	struct dquot___47 * (*alloc_dquot)(struct super_block___48 *, int);
	void (*destroy_dquot)(struct dquot___47 *);
	int (*acquire_dquot)(struct dquot___47 *);
	int (*release_dquot)(struct dquot___47 *);
	int (*mark_dirty)(struct dquot___47 *);
	int (*write_info)(struct super_block___48 *, int);
	qsize_t * (*get_reserved_space)(struct inode___48 *);
	int (*get_projid)(struct inode___48 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___48 *, qsize_t *);
	int (*get_next_id)(struct super_block___48 *, struct kqid *);
};

struct quotactl_ops___47 {
	int (*quota_on)(struct super_block___48 *, int, int, const struct path___47 *);
	int (*quota_off)(struct super_block___48 *, int);
	int (*quota_enable)(struct super_block___48 *, unsigned int);
	int (*quota_disable)(struct super_block___48 *, unsigned int);
	int (*quota_sync)(struct super_block___48 *, int);
	int (*set_info)(struct super_block___48 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___48 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___48 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___48 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___48 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___48 *, unsigned int);
};

struct address_space_operations___47 {
	int (*writepage)(struct page___51 *, struct writeback_control___3 *);
	int (*readpage)(struct file___48 *, struct page___51 *);
	int (*writepages)(struct address_space___47 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___51 *);
	int (*readpages)(struct file___48 *, struct address_space___47 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___48 *, struct address_space___47 *, loff_t, unsigned int, unsigned int, struct page___51 **, void **);
	int (*write_end)(struct file___48 *, struct address_space___47 *, loff_t, unsigned int, unsigned int, struct page___51 *, void *);
	sector_t (*bmap)(struct address_space___47 *, sector_t);
	void (*invalidatepage)(struct page___51 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___51 *, gfp_t);
	void (*freepage)(struct page___51 *);
	ssize_t (*direct_IO)(struct kiocb___47 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___47 *, struct page___51 *, struct page___51 *, enum migrate_mode);
	bool (*isolate_page)(struct page___51 *, isolate_mode_t);
	void (*putback_page)(struct page___51 *);
	int (*launder_page)(struct page___51 *);
	int (*is_partially_uptodate)(struct page___51 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___51 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___47 *, struct page___51 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___48 *, sector_t *);
	void (*swap_deactivate)(struct file___48 *);
};

struct inode_operations___47 {
	struct dentry___48 * (*lookup)(struct inode___48 *, struct dentry___48 *, unsigned int);
	const char * (*get_link)(struct dentry___48 *, struct inode___48 *, struct delayed_call *);
	int (*permission)(struct user_namespace___7 *, struct inode___48 *, int);
	struct posix_acl * (*get_acl)(struct inode___48 *, int, bool);
	int (*readlink)(struct dentry___48 *, char *, int);
	int (*create)(struct user_namespace___7 *, struct inode___48 *, struct dentry___48 *, umode_t, bool);
	int (*link)(struct dentry___48 *, struct inode___48 *, struct dentry___48 *);
	int (*unlink)(struct inode___48 *, struct dentry___48 *);
	int (*symlink)(struct user_namespace___7 *, struct inode___48 *, struct dentry___48 *, const char *);
	int (*mkdir)(struct user_namespace___7 *, struct inode___48 *, struct dentry___48 *, umode_t);
	int (*rmdir)(struct inode___48 *, struct dentry___48 *);
	int (*mknod)(struct user_namespace___7 *, struct inode___48 *, struct dentry___48 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___7 *, struct inode___48 *, struct dentry___48 *, struct inode___48 *, struct dentry___48 *, unsigned int);
	int (*setattr)(struct user_namespace___7 *, struct dentry___48 *, struct iattr___48 *);
	int (*getattr)(struct user_namespace___7 *, const struct path___47 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___48 *, char *, size_t);
	int (*fiemap)(struct inode___48 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___48 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___48 *, struct dentry___48 *, struct file___48 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___7 *, struct inode___48 *, struct dentry___48 *, umode_t);
	int (*set_acl)(struct user_namespace___7 *, struct inode___48 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___7 *, struct dentry___48 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___48 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___47 {
	void (*fl_copy_lock)(struct file_lock___47 *, struct file_lock___47 *);
	void (*fl_release_private)(struct file_lock___47 *);
};

struct fasync_struct___47;

struct lock_manager_operations___47;

struct file_lock___47 {
	struct file_lock___47 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___48 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___47 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___47 *fl_ops;
	const struct lock_manager_operations___47 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___47 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___47 *);
	int (*lm_grant)(struct file_lock___47 *, int);
	bool (*lm_break)(struct file_lock___47 *);
	int (*lm_change)(struct file_lock___47 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___47 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___47 *);
};

struct fasync_struct___47 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___47 *fa_next;
	struct file___48 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___47 {
	struct inode___48 * (*alloc_inode)(struct super_block___48 *);
	void (*destroy_inode)(struct inode___48 *);
	void (*free_inode)(struct inode___48 *);
	void (*dirty_inode)(struct inode___48 *, int);
	int (*write_inode)(struct inode___48 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___48 *);
	void (*evict_inode)(struct inode___48 *);
	void (*put_super)(struct super_block___48 *);
	int (*sync_fs)(struct super_block___48 *, int);
	int (*freeze_super)(struct super_block___48 *);
	int (*freeze_fs)(struct super_block___48 *);
	int (*thaw_super)(struct super_block___48 *);
	int (*unfreeze_fs)(struct super_block___48 *);
	int (*statfs)(struct dentry___48 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___48 *, int *, char *);
	void (*umount_begin)(struct super_block___48 *);
	int (*show_options)(struct seq_file___47 *, struct dentry___48 *);
	int (*show_devname)(struct seq_file___47 *, struct dentry___48 *);
	int (*show_path)(struct seq_file___47 *, struct dentry___48 *);
	int (*show_stats)(struct seq_file___47 *, struct dentry___48 *);
	ssize_t (*quota_read)(struct super_block___48 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___48 *, int, const char *, size_t, loff_t);
	struct dquot___47 ** (*get_dquots)(struct inode___48 *);
	long int (*nr_cached_objects)(struct super_block___48 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___48 *, struct shrink_control___21 *);
	struct file___48 * (*real_loop)(struct file___48 *);
};

struct seq_operations___46;

struct seq_file___47 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___46 *op;
	int poll_event;
	const struct file___48 *file;
	void *private;
};

struct fc_log___7;

struct p_log___7 {
	const char *prefix;
	struct fc_log___7 *log;
};

struct fs_context_operations___7;

struct fs_context___7 {
	const struct fs_context_operations___7 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___47 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___48 *root;
	struct user_namespace___7 *user_ns;
	struct net *net_ns;
	const struct cred___6 *cred;
	struct p_log___7 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___7;

typedef int fs_param_type___7(struct p_log___7 *, const struct fs_parameter_spec___7 *, struct fs_parameter___7 *, struct fs_parse_result *);

struct fs_parameter_spec___7 {
	const char *name;
	fs_param_type___7 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct seq_operations___46 {
	void * (*start)(struct seq_file___47 *, loff_t *);
	void (*stop)(struct seq_file___47 *, void *);
	void * (*next)(struct seq_file___47 *, void *, loff_t *);
	int (*show)(struct seq_file___47 *, void *);
};

struct kernfs_root___49;

struct kernfs_elem_dir___49 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___49 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___49;

struct kernfs_root___49 {
	struct kernfs_node___49 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___49 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___49 {
	struct kernfs_node___49 *target_kn;
};

struct kernfs_ops___49;

struct kernfs_elem_attr___49 {
	const struct kernfs_ops___49 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___49 *notify_next;
};

struct kernfs_node___49 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___49 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___49 dir;
		struct kernfs_elem_symlink___49 symlink;
		struct kernfs_elem_attr___49 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___49;

struct kernfs_ops___49 {
	int (*open)(struct kernfs_open_file___49 *);
	void (*release)(struct kernfs_open_file___49 *);
	int (*seq_show)(struct seq_file___47 *, void *);
	void * (*seq_start)(struct seq_file___47 *, loff_t *);
	void * (*seq_next)(struct seq_file___47 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___47 *, void *);
	ssize_t (*read)(struct kernfs_open_file___49 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___49 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___49 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___49 *, struct vm_area_struct___51 *);
};

struct kernfs_syscall_ops___49 {
	int (*show_options)(struct seq_file___47 *, struct kernfs_root___49 *);
	int (*mkdir)(struct kernfs_node___49 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___49 *);
	int (*rename)(struct kernfs_node___49 *, struct kernfs_node___49 *, const char *);
	int (*show_path)(struct seq_file___47 *, struct kernfs_node___49 *, struct kernfs_root___49 *);
};

struct kernfs_open_file___49 {
	struct kernfs_node___49 *kn;
	struct file___48 *file;
	struct seq_file___47 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___47 *vm_ops;
};

struct nsset___7;

struct proc_ns_operations___8 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___8 * (*get)(struct task_struct___52 *);
	void (*put)(struct ns_common___8 *);
	int (*install)(struct nsset___7 *, struct ns_common___8 *);
	struct user_namespace___7 * (*owner)(struct ns_common___8 *);
	struct ns_common___8 * (*get_parent)(struct ns_common___8 *);
};

struct cgroup_namespace___39 {
	struct ns_common___8 ns;
	struct user_namespace___7 *user_ns;
	struct ucounts___7 *ucounts;
	struct css_set___39 *root_cset;
};

struct nsset___7 {
	unsigned int flags;
	struct nsproxy___47 *nsproxy;
	struct fs_struct *fs;
	const struct cred___6 *cred;
};

struct bin_attribute___49;

struct attribute_group___49 {
	const char *name;
	umode_t (*is_visible)(struct kobject___49 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___49 *, struct bin_attribute___49 *, int);
	struct attribute **attrs;
	struct bin_attribute___49 **bin_attrs;
};

struct bin_attribute___49 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___47 * (*f_mapping)();
	ssize_t (*read)(struct file___48 *, struct kobject___49 *, struct bin_attribute___49 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___48 *, struct kobject___49 *, struct bin_attribute___49 *, char *, loff_t, size_t);
	int (*mmap)(struct file___48 *, struct kobject___49 *, struct bin_attribute___49 *, struct vm_area_struct___51 *);
};

struct sysfs_ops___49 {
	ssize_t (*show)(struct kobject___49 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___49 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___49;

struct kset___49 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___49 kobj;
	const struct kset_uevent_ops___49 *uevent_ops;
};

struct kobj_type___49 {
	void (*release)(struct kobject___49 *);
	const struct sysfs_ops___49 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___49 **default_groups;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___49 *);
	const void * (*namespace)(struct kobject___49 *);
	void (*get_ownership)(struct kobject___49 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___49 {
	int (* const filter)(struct kset___49 *, struct kobject___49 *);
	const char * (* const name)(struct kset___49 *, struct kobject___49 *);
	int (* const uevent)(struct kset___49 *, struct kobject___49 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___46 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___46 *);
	int (*get)(char *, const struct kernel_param___46 *);
	void (*free)(void *);
};

struct kparam_array___46;

struct kernel_param___46 {
	const char *name;
	struct module___48 *mod;
	const struct kernel_param_ops___46 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___46 *arr;
	};
};

struct kparam_array___46 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___46 *ops;
	void *elem;
};

struct module_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___46 *, struct module_kobject___46 *, char *);
	ssize_t (*store)(struct module_attribute___46 *, struct module_kobject___46 *, const char *, size_t);
	void (*setup)(struct module___48 *, const char *);
	int (*test)(struct module___48 *);
	void (*free)(struct module___48 *);
};

struct dev_pagemap_ops___47 {
	void (*page_free)(struct page___51 *);
	void (*kill)(struct dev_pagemap___47 *);
	void (*cleanup)(struct dev_pagemap___47 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___47 *);
};

struct cgroup_taskset___4;

struct cftype___39;

struct cgroup_subsys___39 {
	struct cgroup_subsys_state___39 * (*css_alloc)(struct cgroup_subsys_state___39 *);
	int (*css_online)(struct cgroup_subsys_state___39 *);
	void (*css_offline)(struct cgroup_subsys_state___39 *);
	void (*css_released)(struct cgroup_subsys_state___39 *);
	void (*css_free)(struct cgroup_subsys_state___39 *);
	void (*css_reset)(struct cgroup_subsys_state___39 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___39 *, int);
	int (*css_extra_stat_show)(struct seq_file___47 *, struct cgroup_subsys_state___39 *);
	int (*can_attach)(struct cgroup_taskset___4 *);
	void (*cancel_attach)(struct cgroup_taskset___4 *);
	void (*attach)(struct cgroup_taskset___4 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___52 *, struct css_set___39 *);
	void (*cancel_fork)(struct task_struct___52 *, struct css_set___39 *);
	void (*fork)(struct task_struct___52 *);
	void (*exit)(struct task_struct___52 *);
	void (*release)(struct task_struct___52 *);
	void (*bind)(struct cgroup_subsys_state___39 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___39 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___39 *dfl_cftypes;
	struct cftype___39 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___39 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___39 *updated_children;
	struct cgroup___39 *updated_next;
};

struct cgroup_root___39 {
	struct kernfs_root___49 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___39 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___39 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___39 *ss;
	struct list_head node;
	struct kernfs_ops___49 *kf_ops;
	int (*open)(struct kernfs_open_file___49 *);
	void (*release)(struct kernfs_open_file___49 *);
	u64 (*read_u64)(struct cgroup_subsys_state___39 *, struct cftype___39 *);
	s64 (*read_s64)(struct cgroup_subsys_state___39 *, struct cftype___39 *);
	int (*seq_show)(struct seq_file___47 *, void *);
	void * (*seq_start)(struct seq_file___47 *, loff_t *);
	void * (*seq_next)(struct seq_file___47 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___47 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___39 *, struct cftype___39 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___39 *, struct cftype___39 *, s64);
	ssize_t (*write)(struct kernfs_open_file___49 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___49 *, struct poll_table_struct___5 *);
};

struct cgroup_taskset___4 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___39 *cur_cset;
	struct task_struct___52 *cur_task;
};

struct fs_parameter___7 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___48 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___7 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___48 *owner;
	char *buffer[8];
};

struct fs_context_operations___7 {
	void (*free)(struct fs_context___7 *);
	int (*dup)(struct fs_context___7 *, struct fs_context___7 *);
	int (*parse_param)(struct fs_context___7 *, struct fs_parameter___7 *);
	int (*parse_monolithic)(struct fs_context___7 *, void *);
	int (*get_tree)(struct fs_context___7 *);
	int (*reconfigure)(struct fs_context___7 *);
};

struct fs_context___8;

struct fs_parameter_spec___8;

struct dentry___49;

struct super_block___49;

struct module___49;

struct file_system_type___48 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___8 *);
	const struct fs_parameter_spec___8 *parameters;
	struct dentry___49 * (*mount)(struct file_system_type___48 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___49 *);
	struct module___49 *owner;
	struct file_system_type___48 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___49;

struct kiocb___48;

struct vm_area_struct___52;

struct inode___49;

struct file_lock___48;

struct page___52;

struct seq_file___48;

struct file_operations___48 {
	struct module___49 *owner;
	loff_t (*llseek)(struct file___49 *, loff_t, int);
	ssize_t (*read)(struct file___49 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___49 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___48 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___48 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___48 *, bool);
	int (*iterate)(struct file___49 *, struct dir_context *);
	int (*iterate_shared)(struct file___49 *, struct dir_context *);
	__poll_t (*poll)(struct file___49 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___49 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___49 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___49 *, struct vm_area_struct___52 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___49 *, struct file___49 *);
	int (*flush)(struct file___49 *, fl_owner_t);
	int (*release)(struct inode___49 *, struct file___49 *);
	int (*fsync)(struct file___49 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___49 *, int);
	int (*lock)(struct file___49 *, int, struct file_lock___48 *);
	ssize_t (*sendpage)(struct file___49 *, struct page___52 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___49 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___49 *, long unsigned int);
	int (*flock)(struct file___49 *, int, struct file_lock___48 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___49 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___49 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___49 *, long int, struct file_lock___48 **, void **);
	long int (*fallocate)(struct file___49 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___48 *, struct file___49 *);
	ssize_t (*copy_file_range)(struct file___49 *, loff_t, struct file___49 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___49 *, loff_t, struct file___49 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___49 *, loff_t, loff_t, int);
};

struct vmacache___52 {
	u64 seqnum;
	struct vm_area_struct___52 *vmas[4];
};

struct page_frag___52 {
	struct page___52 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___53;

struct pid___44;

struct nsproxy___48;

struct signal_struct___49;

struct css_set___40;

struct vm_struct___51;

struct task_struct___53 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___53 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___53 *mm;
	struct mm_struct___53 *active_mm;
	struct vmacache___52 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___53 *real_parent;
	struct task_struct___53 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___53 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___44 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___6 *ptracer_cred;
	const struct cred___6 *real_cred;
	const struct cred___6 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___48 *nsproxy;
	struct signal_struct___49 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___53 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___23 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___40 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___52 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___53 *oom_reaper_list;
	struct vm_struct___51 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___50;

struct kobj_type___50;

struct kernfs_node___50;

struct kobject___50 {
	const char *name;
	struct list_head entry;
	struct kobject___50 *parent;
	struct kset___50 *kset;
	struct kobj_type___50 *ktype;
	struct kernfs_node___50 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___47 {
	struct kobject___50 kobj;
	struct module___49 *mod;
	struct kobject___50 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___47 {
	struct module___49 *mod;
	struct latch_tree_node node;
};

struct module_layout___47 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___47 mtn;
};

struct module_attribute___47;

struct kernel_param___47;

struct module___49 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___47 mkobj;
	struct module_attribute___47 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___50 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___47 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___47 core_layout;
	struct module_layout___47 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___44;

struct upid___44 {
	int nr;
	struct pid_namespace___44 *ns;
};

struct pid_namespace___44 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___53 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___44 *parent;
	struct fs_pin *bacct;
	struct user_namespace___7 *user_ns;
	struct ucounts___7 *ucounts;
	int reboot;
	struct ns_common___8 ns;
};

struct pid___44 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___44 numbers[1];
};

typedef struct page___52 *pgtable_t___52;

struct address_space___48;

struct dev_pagemap___48;

struct page___52 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___48 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___52 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___52 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___53 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___48 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___48;

struct vm_area_struct___52 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___52 *vm_next;
	struct vm_area_struct___52 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___53 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___48 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___49 *vm_file;
	struct file___49 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___49 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___53 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___53 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___44 *pids[4];
	struct pid___44 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___53 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___52;

struct mm_struct___53 {
	struct {
		struct vm_area_struct___52 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___49 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___52 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___53 *owner;
		struct user_namespace___7 *user_ns;
		struct file___49 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___40;

struct nsproxy___48 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___44 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___40 *cgroup_ns;
};

struct cgroup_subsys_state___40;

struct cgroup___40;

struct css_set___40 {
	struct cgroup_subsys_state___40 *subsys[14];
	refcount_t refcount;
	struct css_set___40 *dom_cset;
	struct cgroup___40 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___40 *mg_src_cgrp;
	struct cgroup___40 *mg_dst_cgrp;
	struct css_set___40 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___51 {
	struct vm_struct___51 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___52 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct cgroupstats {
	__u64 nr_sleeping;
	__u64 nr_running;
	__u64 nr_stopped;
	__u64 nr_uninterruptible;
	__u64 nr_io_wait;
};

struct dentry_operations___48;

struct dentry___49 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___49 *d_parent;
	struct qstr d_name;
	struct inode___49 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___48 *d_op;
	struct super_block___49 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___48;

struct address_space___48 {
	struct inode___49 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___48 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___48;

struct inode___49 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___48 *i_op;
	struct super_block___49 *i_sb;
	struct address_space___48 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___48 *i_fop;
		void (*free_inode)(struct inode___49 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___48 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___48;

struct path___48;

struct dentry_operations___48 {
	int (*d_revalidate)(struct dentry___49 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___49 *, unsigned int);
	int (*d_hash)(const struct dentry___49 *, struct qstr *);
	int (*d_compare)(const struct dentry___49 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___49 *);
	int (*d_init)(struct dentry___49 *);
	void (*d_release)(struct dentry___49 *);
	void (*d_prune)(struct dentry___49 *);
	void (*d_iput)(struct dentry___49 *, struct inode___49 *);
	char * (*d_dname)(struct dentry___49 *, char *, int);
	struct vfsmount___48 * (*d_automount)(struct path___48 *);
	int (*d_manage)(const struct path___48 *, bool);
	struct dentry___49 * (*d_real)(struct dentry___49 *, const struct inode___49 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___48;

struct mem_dqinfo___48 {
	struct quota_format_type___48 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___48;

struct quota_info___48 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___49 *files[3];
	struct mem_dqinfo___48 info[3];
	const struct quota_format_ops___48 *ops[3];
};

struct rcuwait___49 {
	struct task_struct___53 *task;
};

struct percpu_rw_semaphore___49 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___49 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___48 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___49 rw_sem[3];
};

struct super_operations___48;

struct dquot_operations___48;

struct quotactl_ops___48;

struct super_block___49 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___48 *s_type;
	const struct super_operations___48 *s_op;
	const struct dquot_operations___48 *dq_op;
	const struct quotactl_ops___48 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___49 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___48 s_dquot;
	struct sb_writers___48 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___48 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___7 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___48 {
	struct dentry___49 *mnt_root;
	struct super_block___49 *mnt_sb;
	int mnt_flags;
	struct user_namespace___7 *mnt_userns;
};

struct path___48 {
	struct vfsmount___48 *mnt;
	struct dentry___49 *dentry;
};

struct dev_pagemap_ops___48;

struct dev_pagemap___48 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___48 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___44 {
	rwlock_t lock;
	struct pid___44 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___49 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___48 f_path;
	struct inode___49 *f_inode;
	const struct file_operations___48 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___44 f_owner;
	const struct cred___6 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___48 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___48;

struct vm_operations_struct___48 {
	void (*open)(struct vm_area_struct___52 *);
	void (*close)(struct vm_area_struct___52 *);
	int (*may_split)(struct vm_area_struct___52 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___52 *);
	int (*mprotect)(struct vm_area_struct___52 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___48 *);
	vm_fault_t (*huge_fault)(struct vm_fault___48 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___48 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___52 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___48 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___48 *);
	int (*access)(struct vm_area_struct___52 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___52 *);
	int (*set_policy)(struct vm_area_struct___52 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___52 *, long unsigned int);
	struct page___52 * (*find_special_page)(struct vm_area_struct___52 *, long unsigned int);
};

struct core_thread___52 {
	struct task_struct___53 *task;
	struct core_thread___52 *next;
};

struct core_state___52 {
	atomic_t nr_threads;
	struct core_thread___52 dumper;
	struct completion startup;
};

struct vm_fault___48 {
	const struct {
		struct vm_area_struct___52 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___52 *cow_page;
	struct page___52 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___52 prealloc_pte;
};

struct cgroup_subsys___40;

struct cgroup_subsys_state___40 {
	struct cgroup___40 *cgroup;
	struct cgroup_subsys___40 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___40 *parent;
};

struct cgroup_file___40 {
	struct kernfs_node___50 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___40 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___53 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___40;

struct cgroup_rstat_cpu___40;

struct cgroup___40 {
	struct cgroup_subsys_state___40 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___50 *kn;
	struct cgroup_file___40 procs_file;
	struct cgroup_file___40 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___40 *subsys[14];
	struct cgroup_root___40 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___40 *dom_cgrp;
	struct cgroup___40 *old_dom_cgrp;
	struct cgroup_rstat_cpu___40 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___40 psi;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___48 {
	struct file___49 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___48 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___24 *ki_waitq;
	};
};

struct iattr___49 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___49 *ia_file;
};

struct dquot___48 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___49 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___48 {
	int qf_fmt_id;
	const struct quota_format_ops___48 *qf_ops;
	struct module___49 *qf_owner;
	struct quota_format_type___48 *qf_next;
};

struct quota_format_ops___48 {
	int (*check_quota_file)(struct super_block___49 *, int);
	int (*read_file_info)(struct super_block___49 *, int);
	int (*write_file_info)(struct super_block___49 *, int);
	int (*free_file_info)(struct super_block___49 *, int);
	int (*read_dqblk)(struct dquot___48 *);
	int (*commit_dqblk)(struct dquot___48 *);
	int (*release_dqblk)(struct dquot___48 *);
	int (*get_next_id)(struct super_block___49 *, struct kqid *);
};

struct dquot_operations___48 {
	int (*write_dquot)(struct dquot___48 *);
	struct dquot___48 * (*alloc_dquot)(struct super_block___49 *, int);
	void (*destroy_dquot)(struct dquot___48 *);
	int (*acquire_dquot)(struct dquot___48 *);
	int (*release_dquot)(struct dquot___48 *);
	int (*mark_dirty)(struct dquot___48 *);
	int (*write_info)(struct super_block___49 *, int);
	qsize_t * (*get_reserved_space)(struct inode___49 *);
	int (*get_projid)(struct inode___49 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___49 *, qsize_t *);
	int (*get_next_id)(struct super_block___49 *, struct kqid *);
};

struct quotactl_ops___48 {
	int (*quota_on)(struct super_block___49 *, int, int, const struct path___48 *);
	int (*quota_off)(struct super_block___49 *, int);
	int (*quota_enable)(struct super_block___49 *, unsigned int);
	int (*quota_disable)(struct super_block___49 *, unsigned int);
	int (*quota_sync)(struct super_block___49 *, int);
	int (*set_info)(struct super_block___49 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___49 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___49 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___49 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___49 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___49 *, unsigned int);
};

struct address_space_operations___48 {
	int (*writepage)(struct page___52 *, struct writeback_control___3 *);
	int (*readpage)(struct file___49 *, struct page___52 *);
	int (*writepages)(struct address_space___48 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___52 *);
	int (*readpages)(struct file___49 *, struct address_space___48 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___49 *, struct address_space___48 *, loff_t, unsigned int, unsigned int, struct page___52 **, void **);
	int (*write_end)(struct file___49 *, struct address_space___48 *, loff_t, unsigned int, unsigned int, struct page___52 *, void *);
	sector_t (*bmap)(struct address_space___48 *, sector_t);
	void (*invalidatepage)(struct page___52 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___52 *, gfp_t);
	void (*freepage)(struct page___52 *);
	ssize_t (*direct_IO)(struct kiocb___48 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___48 *, struct page___52 *, struct page___52 *, enum migrate_mode);
	bool (*isolate_page)(struct page___52 *, isolate_mode_t);
	void (*putback_page)(struct page___52 *);
	int (*launder_page)(struct page___52 *);
	int (*is_partially_uptodate)(struct page___52 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___52 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___48 *, struct page___52 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___49 *, sector_t *);
	void (*swap_deactivate)(struct file___49 *);
};

struct inode_operations___48 {
	struct dentry___49 * (*lookup)(struct inode___49 *, struct dentry___49 *, unsigned int);
	const char * (*get_link)(struct dentry___49 *, struct inode___49 *, struct delayed_call *);
	int (*permission)(struct user_namespace___7 *, struct inode___49 *, int);
	struct posix_acl * (*get_acl)(struct inode___49 *, int, bool);
	int (*readlink)(struct dentry___49 *, char *, int);
	int (*create)(struct user_namespace___7 *, struct inode___49 *, struct dentry___49 *, umode_t, bool);
	int (*link)(struct dentry___49 *, struct inode___49 *, struct dentry___49 *);
	int (*unlink)(struct inode___49 *, struct dentry___49 *);
	int (*symlink)(struct user_namespace___7 *, struct inode___49 *, struct dentry___49 *, const char *);
	int (*mkdir)(struct user_namespace___7 *, struct inode___49 *, struct dentry___49 *, umode_t);
	int (*rmdir)(struct inode___49 *, struct dentry___49 *);
	int (*mknod)(struct user_namespace___7 *, struct inode___49 *, struct dentry___49 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___7 *, struct inode___49 *, struct dentry___49 *, struct inode___49 *, struct dentry___49 *, unsigned int);
	int (*setattr)(struct user_namespace___7 *, struct dentry___49 *, struct iattr___49 *);
	int (*getattr)(struct user_namespace___7 *, const struct path___48 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___49 *, char *, size_t);
	int (*fiemap)(struct inode___49 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___49 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___49 *, struct dentry___49 *, struct file___49 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___7 *, struct inode___49 *, struct dentry___49 *, umode_t);
	int (*set_acl)(struct user_namespace___7 *, struct inode___49 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___7 *, struct dentry___49 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___49 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___48 {
	void (*fl_copy_lock)(struct file_lock___48 *, struct file_lock___48 *);
	void (*fl_release_private)(struct file_lock___48 *);
};

struct fasync_struct___48;

struct lock_manager_operations___48;

struct file_lock___48 {
	struct file_lock___48 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___49 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___48 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___48 *fl_ops;
	const struct lock_manager_operations___48 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___48 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___48 *);
	int (*lm_grant)(struct file_lock___48 *, int);
	bool (*lm_break)(struct file_lock___48 *);
	int (*lm_change)(struct file_lock___48 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___48 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___48 *);
};

struct fasync_struct___48 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___48 *fa_next;
	struct file___49 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___48 {
	struct inode___49 * (*alloc_inode)(struct super_block___49 *);
	void (*destroy_inode)(struct inode___49 *);
	void (*free_inode)(struct inode___49 *);
	void (*dirty_inode)(struct inode___49 *, int);
	int (*write_inode)(struct inode___49 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___49 *);
	void (*evict_inode)(struct inode___49 *);
	void (*put_super)(struct super_block___49 *);
	int (*sync_fs)(struct super_block___49 *, int);
	int (*freeze_super)(struct super_block___49 *);
	int (*freeze_fs)(struct super_block___49 *);
	int (*thaw_super)(struct super_block___49 *);
	int (*unfreeze_fs)(struct super_block___49 *);
	int (*statfs)(struct dentry___49 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___49 *, int *, char *);
	void (*umount_begin)(struct super_block___49 *);
	int (*show_options)(struct seq_file___48 *, struct dentry___49 *);
	int (*show_devname)(struct seq_file___48 *, struct dentry___49 *);
	int (*show_path)(struct seq_file___48 *, struct dentry___49 *);
	int (*show_stats)(struct seq_file___48 *, struct dentry___49 *);
	ssize_t (*quota_read)(struct super_block___49 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___49 *, int, const char *, size_t, loff_t);
	struct dquot___48 ** (*get_dquots)(struct inode___49 *);
	long int (*nr_cached_objects)(struct super_block___49 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___49 *, struct shrink_control___21 *);
	struct file___49 * (*real_loop)(struct file___49 *);
};

struct seq_operations___47;

struct seq_file___48 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___47 *op;
	int poll_event;
	const struct file___49 *file;
	void *private;
};

struct fc_log___8;

struct p_log___8 {
	const char *prefix;
	struct fc_log___8 *log;
};

struct fs_context_operations___8;

struct fs_context___8 {
	const struct fs_context_operations___8 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___48 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___49 *root;
	struct user_namespace___7 *user_ns;
	struct net *net_ns;
	const struct cred___6 *cred;
	struct p_log___8 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___8;

typedef int fs_param_type___8(struct p_log___8 *, const struct fs_parameter_spec___8 *, struct fs_parameter___8 *, struct fs_parse_result *);

struct fs_parameter_spec___8 {
	const char *name;
	fs_param_type___8 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct seq_operations___47 {
	void * (*start)(struct seq_file___48 *, loff_t *);
	void (*stop)(struct seq_file___48 *, void *);
	void * (*next)(struct seq_file___48 *, void *, loff_t *);
	int (*show)(struct seq_file___48 *, void *);
};

struct kernfs_root___50;

struct kernfs_elem_dir___50 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___50 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___50;

struct kernfs_root___50 {
	struct kernfs_node___50 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___50 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___50 {
	struct kernfs_node___50 *target_kn;
};

struct kernfs_ops___50;

struct kernfs_elem_attr___50 {
	const struct kernfs_ops___50 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___50 *notify_next;
};

struct kernfs_node___50 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___50 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___50 dir;
		struct kernfs_elem_symlink___50 symlink;
		struct kernfs_elem_attr___50 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___50;

struct kernfs_ops___50 {
	int (*open)(struct kernfs_open_file___50 *);
	void (*release)(struct kernfs_open_file___50 *);
	int (*seq_show)(struct seq_file___48 *, void *);
	void * (*seq_start)(struct seq_file___48 *, loff_t *);
	void * (*seq_next)(struct seq_file___48 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___48 *, void *);
	ssize_t (*read)(struct kernfs_open_file___50 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___50 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___50 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___50 *, struct vm_area_struct___52 *);
};

struct kernfs_syscall_ops___50 {
	int (*show_options)(struct seq_file___48 *, struct kernfs_root___50 *);
	int (*mkdir)(struct kernfs_node___50 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___50 *);
	int (*rename)(struct kernfs_node___50 *, struct kernfs_node___50 *, const char *);
	int (*show_path)(struct seq_file___48 *, struct kernfs_node___50 *, struct kernfs_root___50 *);
};

struct kernfs_open_file___50 {
	struct kernfs_node___50 *kn;
	struct file___49 *file;
	struct seq_file___48 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___48 *vm_ops;
};

struct kernfs_fs_context___2 {
	struct kernfs_root___50 *root;
	void *ns_tag;
	long unsigned int magic;
	bool new_sb_created;
};

struct cgroup_namespace___40 {
	struct ns_common___8 ns;
	struct user_namespace___7 *user_ns;
	struct ucounts___7 *ucounts;
	struct css_set___40 *root_cset;
};

struct bin_attribute___50;

struct attribute_group___50 {
	const char *name;
	umode_t (*is_visible)(struct kobject___50 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___50 *, struct bin_attribute___50 *, int);
	struct attribute **attrs;
	struct bin_attribute___50 **bin_attrs;
};

struct bin_attribute___50 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___48 * (*f_mapping)();
	ssize_t (*read)(struct file___49 *, struct kobject___50 *, struct bin_attribute___50 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___49 *, struct kobject___50 *, struct bin_attribute___50 *, char *, loff_t, size_t);
	int (*mmap)(struct file___49 *, struct kobject___50 *, struct bin_attribute___50 *, struct vm_area_struct___52 *);
};

struct sysfs_ops___50 {
	ssize_t (*show)(struct kobject___50 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___50 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___50;

struct kset___50 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___50 kobj;
	const struct kset_uevent_ops___50 *uevent_ops;
};

struct kobj_type___50 {
	void (*release)(struct kobject___50 *);
	const struct sysfs_ops___50 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___50 **default_groups;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___50 *);
	const void * (*namespace)(struct kobject___50 *);
	void (*get_ownership)(struct kobject___50 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___50 {
	int (* const filter)(struct kset___50 *, struct kobject___50 *);
	const char * (* const name)(struct kset___50 *, struct kobject___50 *);
	int (* const uevent)(struct kset___50 *, struct kobject___50 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___47 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___47 *);
	int (*get)(char *, const struct kernel_param___47 *);
	void (*free)(void *);
};

struct kparam_array___47;

struct kernel_param___47 {
	const char *name;
	struct module___49 *mod;
	const struct kernel_param_ops___47 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___47 *arr;
	};
};

struct kparam_array___47 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___47 *ops;
	void *elem;
};

struct module_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___47 *, struct module_kobject___47 *, char *);
	ssize_t (*store)(struct module_attribute___47 *, struct module_kobject___47 *, const char *, size_t);
	void (*setup)(struct module___49 *, const char *);
	int (*test)(struct module___49 *);
	void (*free)(struct module___49 *);
};

struct dev_pagemap_ops___48 {
	void (*page_free)(struct page___52 *);
	void (*kill)(struct dev_pagemap___48 *);
	void (*cleanup)(struct dev_pagemap___48 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___48 *);
};

struct cgroup_taskset___5;

struct cftype___40;

struct cgroup_subsys___40 {
	struct cgroup_subsys_state___40 * (*css_alloc)(struct cgroup_subsys_state___40 *);
	int (*css_online)(struct cgroup_subsys_state___40 *);
	void (*css_offline)(struct cgroup_subsys_state___40 *);
	void (*css_released)(struct cgroup_subsys_state___40 *);
	void (*css_free)(struct cgroup_subsys_state___40 *);
	void (*css_reset)(struct cgroup_subsys_state___40 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___40 *, int);
	int (*css_extra_stat_show)(struct seq_file___48 *, struct cgroup_subsys_state___40 *);
	int (*can_attach)(struct cgroup_taskset___5 *);
	void (*cancel_attach)(struct cgroup_taskset___5 *);
	void (*attach)(struct cgroup_taskset___5 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___53 *, struct css_set___40 *);
	void (*cancel_fork)(struct task_struct___53 *, struct css_set___40 *);
	void (*fork)(struct task_struct___53 *);
	void (*exit)(struct task_struct___53 *);
	void (*release)(struct task_struct___53 *);
	void (*bind)(struct cgroup_subsys_state___40 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___40 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___40 *dfl_cftypes;
	struct cftype___40 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___40 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___40 *updated_children;
	struct cgroup___40 *updated_next;
};

struct cgroup_root___40 {
	struct kernfs_root___50 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___40 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___40 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___40 *ss;
	struct list_head node;
	struct kernfs_ops___50 *kf_ops;
	int (*open)(struct kernfs_open_file___50 *);
	void (*release)(struct kernfs_open_file___50 *);
	u64 (*read_u64)(struct cgroup_subsys_state___40 *, struct cftype___40 *);
	s64 (*read_s64)(struct cgroup_subsys_state___40 *, struct cftype___40 *);
	int (*seq_show)(struct seq_file___48 *, void *);
	void * (*seq_start)(struct seq_file___48 *, loff_t *);
	void * (*seq_next)(struct seq_file___48 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___48 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___40 *, struct cftype___40 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___40 *, struct cftype___40 *, s64);
	ssize_t (*write)(struct kernfs_open_file___50 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___50 *, struct poll_table_struct___5 *);
};

struct cgroup_taskset___5 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___40 *cur_cset;
	struct task_struct___53 *cur_task;
};

struct css_task_iter___3 {
	struct cgroup_subsys___40 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___40 *cur_cset;
	struct css_set___40 *cur_dcset;
	struct task_struct___53 *cur_task;
	struct list_head iters_node;
};

struct fs_parameter___8 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___49 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___8 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___49 *owner;
	char *buffer[8];
};

struct fs_context_operations___8 {
	void (*free)(struct fs_context___8 *);
	int (*dup)(struct fs_context___8 *, struct fs_context___8 *);
	int (*parse_param)(struct fs_context___8 *, struct fs_parameter___8 *);
	int (*parse_monolithic)(struct fs_context___8 *, void *);
	int (*get_tree)(struct fs_context___8 *);
	int (*reconfigure)(struct fs_context___8 *);
};

struct cgroup_fs_context___2 {
	struct kernfs_fs_context___2 kfc;
	struct cgroup_root___40 *root;
	struct cgroup_namespace___40 *ns;
	unsigned int flags;
	bool cpuset_clone_children;
	bool none;
	bool all_ss;
	u16 subsys_mask;
	char *name;
	char *release_agent;
};

enum cgroup_filetype {
	CGROUP_FILE_PROCS = 0,
	CGROUP_FILE_TASKS = 1,
};

struct cgroup_pidlist {
	struct {
		enum cgroup_filetype type;
		struct pid_namespace___44 *ns;
	} key;
	pid_t *list;
	int length;
	struct list_head links;
	struct cgroup___40 *owner;
	struct delayed_work destroy_dwork;
};

struct cgroup_file_ctx___2 {
	struct cgroup_namespace___40 *ns;
	struct {
		void *trigger;
	} psi;
	struct {
		bool started;
		struct css_task_iter___3 iter;
	} procs;
	struct {
		struct cgroup_pidlist *pidlist;
	} procs1;
};

struct cgrp_cset_link___2 {
	struct cgroup___40 *cgrp;
	struct css_set___40 *cset;
	struct list_head cset_link;
	struct list_head cgrp_link;
};

struct cgroup_mgctx___2 {
	struct list_head preloaded_src_csets;
	struct list_head preloaded_dst_csets;
	struct cgroup_taskset___5 tset;
	u16 ss_mask;
};

enum cgroup1_param {
	Opt_all = 0,
	Opt_clone_children = 1,
	Opt_cpuset_v2_mode = 2,
	Opt_name = 3,
	Opt_none = 4,
	Opt_noprefix = 5,
	Opt_release_agent = 6,
	Opt_xattr = 7,
};

struct css_task_iter___4 {
	struct cgroup_subsys___26 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___26 *cur_cset;
	struct css_set___26 *cur_dcset;
	struct task_struct___36 *cur_task;
	struct list_head iters_node;
};

enum freezer_state_flags {
	CGROUP_FREEZER_ONLINE = 1,
	CGROUP_FREEZING_SELF = 2,
	CGROUP_FREEZING_PARENT = 4,
	CGROUP_FROZEN = 8,
	CGROUP_FREEZING = 6,
};

struct freezer {
	struct cgroup_subsys_state___26 css;
	unsigned int state;
};

struct pids_cgroup {
	struct cgroup_subsys_state___26 css;
	atomic64_t counter;
	atomic64_t limit;
	struct cgroup_file___26 events_file;
	atomic64_t events_limit;
};

typedef struct {
	char *from;
	char *to;
} substring_t;

enum rdmacg_resource_type {
	RDMACG_RESOURCE_HCA_HANDLE = 0,
	RDMACG_RESOURCE_HCA_OBJECT = 1,
	RDMACG_RESOURCE_MAX = 2,
};

struct rdma_cgroup {
	struct cgroup_subsys_state___26 css;
	struct list_head rpools;
};

struct rdmacg_device {
	struct list_head dev_node;
	struct list_head rpools;
	char *name;
};

enum rdmacg_file_type {
	RDMACG_RESOURCE_TYPE_MAX = 0,
	RDMACG_RESOURCE_TYPE_STAT = 1,
};

struct rdmacg_resource {
	int max;
	int usage;
};

struct rdmacg_resource_pool {
	struct rdmacg_device *device;
	struct rdmacg_resource resources[2];
	struct list_head cg_node;
	struct list_head dev_node;
	u64 usage_sum;
	int num_max_cnt;
};

struct fs_context___9;

struct dentry___50;

struct super_block___50;

struct module___50;

struct file_system_type___49 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___9 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___50 * (*mount)(struct file_system_type___49 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___50 *);
	struct module___50 *owner;
	struct file_system_type___49 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___50;

struct kiocb___49;

struct iov_iter___26;

struct vm_area_struct___53;

struct inode___50;

struct file_lock___49;

struct page___53;

struct seq_file___49;

struct file_operations___49 {
	struct module___50 *owner;
	loff_t (*llseek)(struct file___50 *, loff_t, int);
	ssize_t (*read)(struct file___50 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___50 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___49 *, struct iov_iter___26 *);
	ssize_t (*write_iter)(struct kiocb___49 *, struct iov_iter___26 *);
	int (*iopoll)(struct kiocb___49 *, bool);
	int (*iterate)(struct file___50 *, struct dir_context *);
	int (*iterate_shared)(struct file___50 *, struct dir_context *);
	__poll_t (*poll)(struct file___50 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___50 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___50 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___50 *, struct vm_area_struct___53 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___50 *, struct file___50 *);
	int (*flush)(struct file___50 *, fl_owner_t);
	int (*release)(struct inode___50 *, struct file___50 *);
	int (*fsync)(struct file___50 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___50 *, int);
	int (*lock)(struct file___50 *, int, struct file_lock___49 *);
	ssize_t (*sendpage)(struct file___50 *, struct page___53 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___50 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___50 *, long unsigned int);
	int (*flock)(struct file___50 *, int, struct file_lock___49 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___50 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___50 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___50 *, long int, struct file_lock___49 **, void **);
	long int (*fallocate)(struct file___50 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___49 *, struct file___50 *);
	ssize_t (*copy_file_range)(struct file___50 *, loff_t, struct file___50 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___50 *, loff_t, struct file___50 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___50 *, loff_t, loff_t, int);
};

struct vmacache___53 {
	u64 seqnum;
	struct vm_area_struct___53 *vmas[4];
};

struct page_frag___53 {
	struct page___53 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___54;

struct pid___45;

struct nsproxy___49;

struct signal_struct___50;

struct bio_list___23;

struct backing_dev_info___22;

struct io_context___24;

struct css_set___41;

struct request_queue___24;

struct vm_struct___52;

struct task_struct___54 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___54 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___54 *mm;
	struct mm_struct___54 *active_mm;
	struct vmacache___53 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___54 *real_parent;
	struct task_struct___54 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___54 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___45 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___6 *ptracer_cred;
	const struct cred___6 *real_cred;
	const struct cred___6 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___49 *nsproxy;
	struct signal_struct___50 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___54 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___23 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___22 *backing_dev_info;
	struct io_context___24 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___41 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___53 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___24 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___54 *oom_reaper_list;
	struct vm_struct___52 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___51;

struct kobj_type___51;

struct kernfs_node___51;

struct kobject___51 {
	const char *name;
	struct list_head entry;
	struct kobject___51 *parent;
	struct kset___51 *kset;
	struct kobj_type___51 *ktype;
	struct kernfs_node___51 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___48 {
	struct kobject___51 kobj;
	struct module___50 *mod;
	struct kobject___51 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___48 {
	struct module___50 *mod;
	struct latch_tree_node node;
};

struct module_layout___48 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___48 mtn;
};

struct module_attribute___48;

struct kernel_param___48;

struct module___50 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___48 mkobj;
	struct module_attribute___48 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___51 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___48 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___48 core_layout;
	struct module_layout___48 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___45;

struct upid___45 {
	int nr;
	struct pid_namespace___45 *ns;
};

struct pid_namespace___45 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___54 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___45 *parent;
	struct fs_pin *bacct;
	struct user_namespace___7 *user_ns;
	struct ucounts___7 *ucounts;
	int reboot;
	struct ns_common___8 ns;
};

struct pid___45 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___45 numbers[1];
};

typedef struct page___53 *pgtable_t___53;

struct address_space___49;

struct dev_pagemap___49;

struct page___53 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___49 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___53 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___53 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___54 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___49 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___49;

struct vm_area_struct___53 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___53 *vm_next;
	struct vm_area_struct___53 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___54 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___49 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___50 *vm_file;
	struct file___50 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___50 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___54 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___54 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___45 *pids[4];
	struct pid___45 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___54 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct root_domain___2;

struct core_state___53;

struct mm_struct___54 {
	struct {
		struct vm_area_struct___53 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___50 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___53 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___54 *owner;
		struct user_namespace___7 *user_ns;
		struct file___50 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___41;

struct nsproxy___49 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___45 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___41 *cgroup_ns;
};

struct bio___23;

struct bio_list___23 {
	struct bio___23 *head;
	struct bio___23 *tail;
};

struct cgroup_subsys_state___41;

struct bdi_writeback___22 {
	struct backing_dev_info___22 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___41 *memcg_css;
	struct cgroup_subsys_state___41 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___45;

struct backing_dev_info___22 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___22 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___45 *dev;
	char dev_name[64];
	struct device___45 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___50 *debug_dir;
};

struct io_cq___23;

struct io_context___24 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___23 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___41;

struct css_set___41 {
	struct cgroup_subsys_state___41 *subsys[14];
	refcount_t refcount;
	struct css_set___41 *dom_cset;
	struct cgroup___41 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___41 *mg_src_cgrp;
	struct cgroup___41 *mg_dst_cgrp;
	struct css_set___41 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___23;

struct blk_integrity___23 {
	const struct blk_integrity_profile___23 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___23 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___23 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___23;

struct elevator_queue___23;

struct blk_mq_ops___22;

struct blk_mq_hw_ctx___22;

struct gendisk___23;

struct blkcg_gq___22;

struct blk_mq_tag_set___22;

struct request_queue___24 {
	struct request___23 *last_merge;
	struct elevator_queue___23 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___22 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___22 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___23 *disk;
	struct kobject___51 kobj;
	struct kobject___51 *mq_kobj;
	struct blk_integrity___23 integrity;
	struct device___45 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___22 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___22 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___23 bio_split;
	struct dentry___50 *debugfs_dir;
	struct dentry___50 *sched_debugfs_dir;
	struct dentry___50 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___52 {
	struct vm_struct___52 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___53 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___49;

struct address_space___49 {
	struct inode___50 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___49 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___49;

struct dev_pagemap___49 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___49 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___49;

struct path___49 {
	struct vfsmount___49 *mnt;
	struct dentry___50 *dentry;
};

struct fown_struct___45 {
	rwlock_t lock;
	struct pid___45 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___50 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___49 f_path;
	struct inode___50 *f_inode;
	const struct file_operations___49 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___45 f_owner;
	const struct cred___6 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___49 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___49;

struct vm_operations_struct___49 {
	void (*open)(struct vm_area_struct___53 *);
	void (*close)(struct vm_area_struct___53 *);
	int (*may_split)(struct vm_area_struct___53 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___53 *);
	int (*mprotect)(struct vm_area_struct___53 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___49 *);
	vm_fault_t (*huge_fault)(struct vm_fault___49 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___49 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___53 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___49 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___49 *);
	int (*access)(struct vm_area_struct___53 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___53 *);
	int (*set_policy)(struct vm_area_struct___53 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___53 *, long unsigned int);
	struct page___53 * (*find_special_page)(struct vm_area_struct___53 *, long unsigned int);
};

struct core_thread___53 {
	struct task_struct___54 *task;
	struct core_thread___53 *next;
};

struct core_state___53 {
	atomic_t nr_threads;
	struct core_thread___53 dumper;
	struct completion startup;
};

struct vm_fault___49 {
	const struct {
		struct vm_area_struct___53 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___53 *cow_page;
	struct page___53 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___53 prealloc_pte;
};

struct kernfs_root___51;

struct kernfs_elem_dir___51 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___51 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___51;

struct kernfs_root___51 {
	struct kernfs_node___51 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___51 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___51 {
	struct kernfs_node___51 *target_kn;
};

struct kernfs_ops___51;

struct kernfs_elem_attr___51 {
	const struct kernfs_ops___51 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___51 *notify_next;
};

struct kernfs_node___51 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___51 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___51 dir;
		struct kernfs_elem_symlink___51 symlink;
		struct kernfs_elem_attr___51 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___51;

struct kernfs_ops___51 {
	int (*open)(struct kernfs_open_file___51 *);
	void (*release)(struct kernfs_open_file___51 *);
	int (*seq_show)(struct seq_file___49 *, void *);
	void * (*seq_start)(struct seq_file___49 *, loff_t *);
	void * (*seq_next)(struct seq_file___49 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___49 *, void *);
	ssize_t (*read)(struct kernfs_open_file___51 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___51 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___51 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___51 *, struct vm_area_struct___53 *);
};

struct kernfs_syscall_ops___51 {
	int (*show_options)(struct seq_file___49 *, struct kernfs_root___51 *);
	int (*mkdir)(struct kernfs_node___51 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___51 *);
	int (*rename)(struct kernfs_node___51 *, struct kernfs_node___51 *, const char *);
	int (*show_path)(struct seq_file___49 *, struct kernfs_node___51 *, struct kernfs_root___51 *);
};

struct seq_operations___48;

struct seq_file___49 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___48 *op;
	int poll_event;
	const struct file___50 *file;
	void *private;
};

struct kernfs_open_file___51 {
	struct kernfs_node___51 *kn;
	struct file___50 *file;
	struct seq_file___49 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___49 *vm_ops;
};

struct bin_attribute___51;

struct attribute_group___51 {
	const char *name;
	umode_t (*is_visible)(struct kobject___51 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___51 *, struct bin_attribute___51 *, int);
	struct attribute **attrs;
	struct bin_attribute___51 **bin_attrs;
};

struct bin_attribute___51 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___49 * (*f_mapping)();
	ssize_t (*read)(struct file___50 *, struct kobject___51 *, struct bin_attribute___51 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___50 *, struct kobject___51 *, struct bin_attribute___51 *, char *, loff_t, size_t);
	int (*mmap)(struct file___50 *, struct kobject___51 *, struct bin_attribute___51 *, struct vm_area_struct___53 *);
};

struct sysfs_ops___51 {
	ssize_t (*show)(struct kobject___51 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___51 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___51;

struct kset___51 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___51 kobj;
	const struct kset_uevent_ops___51 *uevent_ops;
};

struct kobj_type___51 {
	void (*release)(struct kobject___51 *);
	const struct sysfs_ops___51 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___51 **default_groups;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___51 *);
	const void * (*namespace)(struct kobject___51 *);
	void (*get_ownership)(struct kobject___51 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___51 {
	int (* const filter)(struct kset___51 *, struct kobject___51 *);
	const char * (* const name)(struct kset___51 *, struct kobject___51 *);
	int (* const uevent)(struct kset___51 *, struct kobject___51 *, struct kobj_uevent_env *);
};

struct wakeup_source___45;

struct dev_pm_info___45 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___45 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___45 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___45;

struct bus_type___45;

struct device_driver___45;

struct dev_pm_domain___45;

struct device_node___28;

struct fwnode_handle___45;

struct class___45;

struct device___45 {
	struct kobject___51 kobj;
	struct device___45 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___45 *type;
	struct bus_type___45 *bus;
	struct device_driver___45 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___45 power;
	struct dev_pm_domain___45 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___28 *of_node;
	struct fwnode_handle___45 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___45 *class;
	const struct attribute_group___51 **groups;
	void (*release)(struct device___45 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___45 {
	int (*prepare)(struct device___45 *);
	void (*complete)(struct device___45 *);
	int (*suspend)(struct device___45 *);
	int (*resume)(struct device___45 *);
	int (*freeze)(struct device___45 *);
	int (*thaw)(struct device___45 *);
	int (*poweroff)(struct device___45 *);
	int (*restore)(struct device___45 *);
	int (*suspend_late)(struct device___45 *);
	int (*resume_early)(struct device___45 *);
	int (*freeze_late)(struct device___45 *);
	int (*thaw_early)(struct device___45 *);
	int (*poweroff_late)(struct device___45 *);
	int (*restore_early)(struct device___45 *);
	int (*suspend_noirq)(struct device___45 *);
	int (*resume_noirq)(struct device___45 *);
	int (*freeze_noirq)(struct device___45 *);
	int (*thaw_noirq)(struct device___45 *);
	int (*poweroff_noirq)(struct device___45 *);
	int (*restore_noirq)(struct device___45 *);
	int (*runtime_suspend)(struct device___45 *);
	int (*runtime_resume)(struct device___45 *);
	int (*runtime_idle)(struct device___45 *);
};

struct wakeup_source___45 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___45 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___45 {
	struct dev_pm_ops___45 ops;
	int (*start)(struct device___45 *);
	void (*detach)(struct device___45 *, bool);
	int (*activate)(struct device___45 *);
	void (*sync)(struct device___45 *);
	void (*dismiss)(struct device___45 *);
};

struct bus_type___45 {
	const char *name;
	const char *dev_name;
	struct device___45 *dev_root;
	const struct attribute_group___51 **bus_groups;
	const struct attribute_group___51 **dev_groups;
	const struct attribute_group___51 **drv_groups;
	int (*match)(struct device___45 *, struct device_driver___45 *);
	int (*uevent)(struct device___45 *, struct kobj_uevent_env *);
	int (*probe)(struct device___45 *);
	void (*sync_state)(struct device___45 *);
	void (*remove)(struct device___45 *);
	void (*shutdown)(struct device___45 *);
	int (*online)(struct device___45 *);
	int (*offline)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	int (*num_vf)(struct device___45 *);
	int (*dma_configure)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___45 {
	const char *name;
	struct bus_type___45 *bus;
	struct module___50 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___45 *);
	void (*sync_state)(struct device___45 *);
	int (*remove)(struct device___45 *);
	void (*shutdown)(struct device___45 *);
	int (*suspend)(struct device___45 *, pm_message_t);
	int (*resume)(struct device___45 *);
	const struct attribute_group___51 **groups;
	const struct attribute_group___51 **dev_groups;
	const struct dev_pm_ops___45 *pm;
	void (*coredump)(struct device___45 *);
	struct driver_private *p;
};

struct device_type___45 {
	const char *name;
	const struct attribute_group___51 **groups;
	int (*uevent)(struct device___45 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___45 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___45 *);
	const struct dev_pm_ops___45 *pm;
};

struct class___45 {
	const char *name;
	struct module___50 *owner;
	const struct attribute_group___51 **class_groups;
	const struct attribute_group___51 **dev_groups;
	struct kobject___51 *dev_kobj;
	int (*dev_uevent)(struct device___45 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___45 *, umode_t *);
	void (*class_release)(struct class___45 *);
	void (*dev_release)(struct device___45 *);
	int (*shutdown_pre)(struct device___45 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___45 *);
	void (*get_ownership)(struct device___45 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___45 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___45;

struct fwnode_handle___45 {
	struct fwnode_handle___45 *secondary;
	const struct fwnode_operations___45 *ops;
	struct device___45 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___24;

struct device_node___28 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___45 fwnode;
	struct property___24 *properties;
	struct property___24 *deadprops;
	struct device_node___28 *parent;
	struct device_node___28 *child;
	struct device_node___28 *sibling;
	struct kobject___51 kobj;
	long unsigned int _flags;
	void *data;
};

struct cgroup_subsys___41;

struct cgroup_subsys_state___41 {
	struct cgroup___41 *cgroup;
	struct cgroup_subsys___41 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___41 *parent;
};

struct cgroup_file___41 {
	struct kernfs_node___51 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___41 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___54 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___41;

struct cgroup_rstat_cpu___41;

struct cgroup___41 {
	struct cgroup_subsys_state___41 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___51 *kn;
	struct cgroup_file___41 procs_file;
	struct cgroup_file___41 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___41 *subsys[14];
	struct cgroup_root___41 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___41 *dom_cgrp;
	struct cgroup___41 *old_dom_cgrp;
	struct cgroup_rstat_cpu___41 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___41 psi;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct dev_pagemap_ops___49 {
	void (*page_free)(struct page___53 *);
	void (*kill)(struct dev_pagemap___49 *);
	void (*cleanup)(struct dev_pagemap___49 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___49 *);
};

struct dentry_operations___49;

struct dentry___50 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___50 *d_parent;
	struct qstr d_name;
	struct inode___50 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___49 *d_op;
	struct super_block___50 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___49;

struct inode___50 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___49 *i_op;
	struct super_block___50 *i_sb;
	struct address_space___49 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___22 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___49 *i_fop;
		void (*free_inode)(struct inode___50 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___49 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___49 {
	int (*d_revalidate)(struct dentry___50 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___50 *, unsigned int);
	int (*d_hash)(const struct dentry___50 *, struct qstr *);
	int (*d_compare)(const struct dentry___50 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___50 *);
	int (*d_init)(struct dentry___50 *);
	void (*d_release)(struct dentry___50 *);
	void (*d_prune)(struct dentry___50 *);
	void (*d_iput)(struct dentry___50 *, struct inode___50 *);
	char * (*d_dname)(struct dentry___50 *, char *, int);
	struct vfsmount___49 * (*d_automount)(struct path___49 *);
	int (*d_manage)(const struct path___49 *, bool);
	struct dentry___50 * (*d_real)(struct dentry___50 *, const struct inode___50 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___49;

struct mem_dqinfo___49 {
	struct quota_format_type___49 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___49;

struct quota_info___49 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___50 *files[3];
	struct mem_dqinfo___49 info[3];
	const struct quota_format_ops___49 *ops[3];
};

struct rcuwait___50 {
	struct task_struct___54 *task;
};

struct percpu_rw_semaphore___50 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___50 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___49 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___50 rw_sem[3];
};

struct super_operations___49;

struct dquot_operations___49;

struct quotactl_ops___49;

struct block_device___24;

struct super_block___50 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___49 *s_type;
	const struct super_operations___49 *s_op;
	const struct dquot_operations___49 *dq_op;
	const struct quotactl_ops___49 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___50 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___24 *s_bdev;
	struct backing_dev_info___22 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___49 s_dquot;
	struct sb_writers___49 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___49 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___7 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___49 {
	struct dentry___50 *mnt_root;
	struct super_block___50 *mnt_sb;
	int mnt_flags;
	struct user_namespace___7 *mnt_userns;
};

struct io_cq___23 {
	struct request_queue___24 *q;
	struct io_context___24 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___25;

struct kiocb___49 {
	struct file___50 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___49 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___50 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___50 *ia_file;
};

struct dquot___49 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___50 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___49 {
	int qf_fmt_id;
	const struct quota_format_ops___49 *qf_ops;
	struct module___50 *qf_owner;
	struct quota_format_type___49 *qf_next;
};

struct quota_format_ops___49 {
	int (*check_quota_file)(struct super_block___50 *, int);
	int (*read_file_info)(struct super_block___50 *, int);
	int (*write_file_info)(struct super_block___50 *, int);
	int (*free_file_info)(struct super_block___50 *, int);
	int (*read_dqblk)(struct dquot___49 *);
	int (*commit_dqblk)(struct dquot___49 *);
	int (*release_dqblk)(struct dquot___49 *);
	int (*get_next_id)(struct super_block___50 *, struct kqid *);
};

struct dquot_operations___49 {
	int (*write_dquot)(struct dquot___49 *);
	struct dquot___49 * (*alloc_dquot)(struct super_block___50 *, int);
	void (*destroy_dquot)(struct dquot___49 *);
	int (*acquire_dquot)(struct dquot___49 *);
	int (*release_dquot)(struct dquot___49 *);
	int (*mark_dirty)(struct dquot___49 *);
	int (*write_info)(struct super_block___50 *, int);
	qsize_t * (*get_reserved_space)(struct inode___50 *);
	int (*get_projid)(struct inode___50 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___50 *, qsize_t *);
	int (*get_next_id)(struct super_block___50 *, struct kqid *);
};

struct quotactl_ops___49 {
	int (*quota_on)(struct super_block___50 *, int, int, const struct path___49 *);
	int (*quota_off)(struct super_block___50 *, int);
	int (*quota_enable)(struct super_block___50 *, unsigned int);
	int (*quota_disable)(struct super_block___50 *, unsigned int);
	int (*quota_sync)(struct super_block___50 *, int);
	int (*set_info)(struct super_block___50 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___50 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___50 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___50 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___50 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___50 *, unsigned int);
};

struct wait_page_queue___25 {
	struct page___53 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___22;

struct readahead_control___25;

struct address_space_operations___49 {
	int (*writepage)(struct page___53 *, struct writeback_control___22 *);
	int (*readpage)(struct file___50 *, struct page___53 *);
	int (*writepages)(struct address_space___49 *, struct writeback_control___22 *);
	int (*set_page_dirty)(struct page___53 *);
	int (*readpages)(struct file___50 *, struct address_space___49 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___25 *);
	int (*write_begin)(struct file___50 *, struct address_space___49 *, loff_t, unsigned int, unsigned int, struct page___53 **, void **);
	int (*write_end)(struct file___50 *, struct address_space___49 *, loff_t, unsigned int, unsigned int, struct page___53 *, void *);
	sector_t (*bmap)(struct address_space___49 *, sector_t);
	void (*invalidatepage)(struct page___53 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___53 *, gfp_t);
	void (*freepage)(struct page___53 *);
	ssize_t (*direct_IO)(struct kiocb___49 *, struct iov_iter___26 *);
	int (*migratepage)(struct address_space___49 *, struct page___53 *, struct page___53 *, enum migrate_mode);
	bool (*isolate_page)(struct page___53 *, isolate_mode_t);
	void (*putback_page)(struct page___53 *);
	int (*launder_page)(struct page___53 *);
	int (*is_partially_uptodate)(struct page___53 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___53 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___49 *, struct page___53 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___50 *, sector_t *);
	void (*swap_deactivate)(struct file___50 *);
};

struct writeback_control___22 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___22 *wb;
	struct inode___50 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___25 {
	struct file___50 *file;
	struct address_space___49 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___26;

struct iov_iter___26 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___26 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___49 {
	struct dentry___50 * (*lookup)(struct inode___50 *, struct dentry___50 *, unsigned int);
	const char * (*get_link)(struct dentry___50 *, struct inode___50 *, struct delayed_call *);
	int (*permission)(struct user_namespace___7 *, struct inode___50 *, int);
	struct posix_acl * (*get_acl)(struct inode___50 *, int, bool);
	int (*readlink)(struct dentry___50 *, char *, int);
	int (*create)(struct user_namespace___7 *, struct inode___50 *, struct dentry___50 *, umode_t, bool);
	int (*link)(struct dentry___50 *, struct inode___50 *, struct dentry___50 *);
	int (*unlink)(struct inode___50 *, struct dentry___50 *);
	int (*symlink)(struct user_namespace___7 *, struct inode___50 *, struct dentry___50 *, const char *);
	int (*mkdir)(struct user_namespace___7 *, struct inode___50 *, struct dentry___50 *, umode_t);
	int (*rmdir)(struct inode___50 *, struct dentry___50 *);
	int (*mknod)(struct user_namespace___7 *, struct inode___50 *, struct dentry___50 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___7 *, struct inode___50 *, struct dentry___50 *, struct inode___50 *, struct dentry___50 *, unsigned int);
	int (*setattr)(struct user_namespace___7 *, struct dentry___50 *, struct iattr___50 *);
	int (*getattr)(struct user_namespace___7 *, const struct path___49 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___50 *, char *, size_t);
	int (*fiemap)(struct inode___50 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___50 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___50 *, struct dentry___50 *, struct file___50 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___7 *, struct inode___50 *, struct dentry___50 *, umode_t);
	int (*set_acl)(struct user_namespace___7 *, struct inode___50 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___7 *, struct dentry___50 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___50 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___49 {
	void (*fl_copy_lock)(struct file_lock___49 *, struct file_lock___49 *);
	void (*fl_release_private)(struct file_lock___49 *);
};

struct fasync_struct___49;

struct lock_manager_operations___49;

struct file_lock___49 {
	struct file_lock___49 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___50 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___49 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___49 *fl_ops;
	const struct lock_manager_operations___49 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___49 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___49 *);
	int (*lm_grant)(struct file_lock___49 *, int);
	bool (*lm_break)(struct file_lock___49 *);
	int (*lm_change)(struct file_lock___49 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___49 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___49 *);
};

struct fasync_struct___49 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___49 *fa_next;
	struct file___50 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___49 {
	struct inode___50 * (*alloc_inode)(struct super_block___50 *);
	void (*destroy_inode)(struct inode___50 *);
	void (*free_inode)(struct inode___50 *);
	void (*dirty_inode)(struct inode___50 *, int);
	int (*write_inode)(struct inode___50 *, struct writeback_control___22 *);
	int (*drop_inode)(struct inode___50 *);
	void (*evict_inode)(struct inode___50 *);
	void (*put_super)(struct super_block___50 *);
	int (*sync_fs)(struct super_block___50 *, int);
	int (*freeze_super)(struct super_block___50 *);
	int (*freeze_fs)(struct super_block___50 *);
	int (*thaw_super)(struct super_block___50 *);
	int (*unfreeze_fs)(struct super_block___50 *);
	int (*statfs)(struct dentry___50 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___50 *, int *, char *);
	void (*umount_begin)(struct super_block___50 *);
	int (*show_options)(struct seq_file___49 *, struct dentry___50 *);
	int (*show_devname)(struct seq_file___49 *, struct dentry___50 *);
	int (*show_path)(struct seq_file___49 *, struct dentry___50 *);
	int (*show_stats)(struct seq_file___49 *, struct dentry___50 *);
	ssize_t (*quota_read)(struct super_block___50 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___50 *, int, const char *, size_t, loff_t);
	struct dquot___49 ** (*get_dquots)(struct inode___50 *);
	long int (*nr_cached_objects)(struct super_block___50 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___50 *, struct shrink_control___21 *);
	struct file___50 * (*real_loop)(struct file___50 *);
};

struct block_device___24 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___50 *bd_inode;
	struct super_block___50 *bd_super;
	void *bd_claiming;
	struct device___45 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___51 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___23 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___50 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct fc_log___9;

struct p_log___9 {
	const char *prefix;
	struct fc_log___9 *log;
};

struct fs_context_operations___9;

struct fs_context___9 {
	const struct fs_context_operations___9 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___49 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___50 *root;
	struct user_namespace___7 *user_ns;
	struct net *net_ns;
	const struct cred___6 *cred;
	struct p_log___9 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___23(struct bio___23 *);

struct bio_vec___26 {
	struct page___53 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___23;

struct bio___23 {
	struct bio___23 *bi_next;
	struct block_device___24 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___23 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___22 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___23 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___26 *bi_io_vec;
	struct bio_set___23 *bi_pool;
	struct bio_vec___26 bi_inline_vecs[0];
};

struct fwnode_reference_args___45;

struct fwnode_endpoint___45;

struct fwnode_operations___45 {
	struct fwnode_handle___45 * (*get)(struct fwnode_handle___45 *);
	void (*put)(struct fwnode_handle___45 *);
	bool (*device_is_available)(const struct fwnode_handle___45 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___45 *, const struct device___45 *);
	bool (*property_present)(const struct fwnode_handle___45 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___45 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___45 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___45 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*get_parent)(const struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*get_next_child_node)(const struct fwnode_handle___45 *, struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*get_named_child_node)(const struct fwnode_handle___45 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___45 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___45 *);
	struct fwnode_handle___45 * (*graph_get_next_endpoint)(const struct fwnode_handle___45 *, struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*graph_get_remote_endpoint)(const struct fwnode_handle___45 *);
	struct fwnode_handle___45 * (*graph_get_port_parent)(struct fwnode_handle___45 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___45 *, struct fwnode_endpoint___45 *);
	int (*add_links)(struct fwnode_handle___45 *);
};

struct fwnode_endpoint___45 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___45 *local_fwnode;
};

struct fwnode_reference_args___45 {
	struct fwnode_handle___45 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___48 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___48 *);
	int (*get)(char *, const struct kernel_param___48 *);
	void (*free)(void *);
};

struct kparam_array___48;

struct kernel_param___48 {
	const char *name;
	struct module___50 *mod;
	const struct kernel_param_ops___48 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___48 *arr;
	};
};

struct kparam_array___48 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___48 *ops;
	void *elem;
};

struct module_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___48 *, struct module_kobject___48 *, char *);
	ssize_t (*store)(struct module_attribute___48 *, struct module_kobject___48 *, const char *, size_t);
	void (*setup)(struct module___50 *, const char *);
	int (*test)(struct module___50 *);
	void (*free)(struct module___50 *);
};

struct cgroup_namespace___41 {
	struct ns_common___8 ns;
	struct user_namespace___7 *user_ns;
	struct ucounts___7 *ucounts;
	struct css_set___41 *root_cset;
};

struct fs_parameter___9 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___50 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___9 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___50 *owner;
	char *buffer[8];
};

struct fs_context_operations___9 {
	void (*free)(struct fs_context___9 *);
	int (*dup)(struct fs_context___9 *, struct fs_context___9 *);
	int (*parse_param)(struct fs_context___9 *, struct fs_parameter___9 *);
	int (*parse_monolithic)(struct fs_context___9 *, void *);
	int (*get_tree)(struct fs_context___9 *);
	int (*reconfigure)(struct fs_context___9 *);
};

struct seq_operations___48 {
	void * (*start)(struct seq_file___49 *, loff_t *);
	void (*stop)(struct seq_file___49 *, void *);
	void * (*next)(struct seq_file___49 *, void *, loff_t *);
	int (*show)(struct seq_file___49 *, void *);
};

struct block_device_operations___23;

struct gendisk___23 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___24 *part0;
	const struct block_device_operations___23 *fops;
	struct request_queue___24 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___22 *bdi;
	struct kobject___51 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___51 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___23 {
	struct bio___23 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___26 *bip_vec;
	struct bio_vec___26 bip_inline_vecs[0];
};

struct blkcg___22;

struct blkg_policy_data___22;

struct blkcg_gq___22 {
	struct request_queue___24 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___22 *blkcg;
	struct blkcg_gq___22 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___22 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___23 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___23(struct request___23 *);

typedef void integrity_complete_fn___23(struct request___23 *, unsigned int);

struct blk_integrity_profile___23 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___23 *prepare_fn;
	integrity_complete_fn___23 *complete_fn;
	const char *name;
};

struct block_device_operations___23 {
	blk_qc_t (*submit_bio)(struct bio___23 *);
	int (*open)(struct block_device___24 *, fmode_t);
	void (*release)(struct gendisk___23 *, fmode_t);
	int (*rw_page)(struct block_device___24 *, sector_t, struct page___53 *, unsigned int);
	int (*ioctl)(struct block_device___24 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___24 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___23 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___23 *);
	int (*getgeo)(struct block_device___24 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___24 *, bool);
	void (*swap_slot_free_notify)(struct block_device___24 *, long unsigned int);
	int (*report_zones)(struct gendisk___23 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___23 *, umode_t *);
	struct module___50 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___23 *, sector_t *);
};

typedef void rq_end_io_fn___23(struct request___23 *, blk_status_t);

struct request___23 {
	struct request_queue___24 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___22 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___23 *bio;
	struct bio___23 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___26 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___23 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___23 *saved_end_io;
		} flush;
	};
	struct gendisk___23 *rq_disk;
	struct block_device___24 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___23 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___22 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___24 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___51 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___50 *debugfs_dir;
	struct dentry___50 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___23;

struct elevator_mq_ops___23 {
	int (*init_sched)(struct request_queue___24 *, struct elevator_type___23 *);
	void (*exit_sched)(struct elevator_queue___23 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___22 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___22 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___22 *);
	bool (*allow_merge)(struct request_queue___24 *, struct request___23 *, struct bio___23 *);
	bool (*bio_merge)(struct request_queue___24 *, struct bio___23 *, unsigned int);
	int (*request_merge)(struct request_queue___24 *, struct request___23 **, struct bio___23 *);
	void (*request_merged)(struct request_queue___24 *, struct request___23 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___24 *, struct request___23 *, struct request___23 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___23 *);
	void (*finish_request)(struct request___23 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___22 *, struct list_head *, bool);
	struct request___23 * (*dispatch_request)(struct blk_mq_hw_ctx___22 *);
	bool (*has_work)(struct blk_mq_hw_ctx___22 *);
	void (*completed_request)(struct request___23 *, u64);
	void (*requeue_request)(struct request___23 *);
	struct request___23 * (*former_request)(struct request_queue___24 *, struct request___23 *);
	struct request___23 * (*next_request)(struct request_queue___24 *, struct request___23 *);
	void (*init_icq)(struct io_cq___23 *);
	void (*exit_icq)(struct io_cq___23 *);
};

struct elv_fs_entry___23;

struct elevator_type___23 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___23 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___23 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___50 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___23 {
	struct elevator_type___23 *type;
	void *elevator_data;
	struct kobject___51 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___23 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___23 *, char *);
	ssize_t (*store)(struct elevator_queue___23 *, const char *, size_t);
};

struct blk_mq_queue_data___22;

struct blk_mq_ops___22 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___22 *, const struct blk_mq_queue_data___22 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___22 *);
	int (*get_budget)(struct request_queue___24 *);
	void (*put_budget)(struct request_queue___24 *, int);
	void (*set_rq_budget_token)(struct request___23 *, int);
	int (*get_rq_budget_token)(struct request___23 *);
	enum blk_eh_timer_return (*timeout)(struct request___23 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___22 *);
	void (*complete)(struct request___23 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___22 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___22 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___22 *, struct request___23 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___22 *, struct request___23 *, unsigned int);
	void (*initialize_rq_fn)(struct request___23 *);
	void (*cleanup_rq)(struct request___23 *);
	bool (*busy)(struct request_queue___24 *);
	int (*map_queues)(struct blk_mq_tag_set___22 *);
	void (*show_rq)(struct seq_file___49 *, struct request___23 *);
};

struct blk_mq_tag_set___22 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___22 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct cftype___41;

struct cgroup_subsys___41 {
	struct cgroup_subsys_state___41 * (*css_alloc)(struct cgroup_subsys_state___41 *);
	int (*css_online)(struct cgroup_subsys_state___41 *);
	void (*css_offline)(struct cgroup_subsys_state___41 *);
	void (*css_released)(struct cgroup_subsys_state___41 *);
	void (*css_free)(struct cgroup_subsys_state___41 *);
	void (*css_reset)(struct cgroup_subsys_state___41 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___41 *, int);
	int (*css_extra_stat_show)(struct seq_file___49 *, struct cgroup_subsys_state___41 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___54 *, struct css_set___41 *);
	void (*cancel_fork)(struct task_struct___54 *, struct css_set___41 *);
	void (*fork)(struct task_struct___54 *);
	void (*exit)(struct task_struct___54 *);
	void (*release)(struct task_struct___54 *);
	void (*bind)(struct cgroup_subsys_state___41 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___41 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___41 *dfl_cftypes;
	struct cftype___41 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___41 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___41 *updated_children;
	struct cgroup___41 *updated_next;
};

struct cgroup_root___41 {
	struct kernfs_root___51 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___41 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___41 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___41 *ss;
	struct list_head node;
	struct kernfs_ops___51 *kf_ops;
	int (*open)(struct kernfs_open_file___51 *);
	void (*release)(struct kernfs_open_file___51 *);
	u64 (*read_u64)(struct cgroup_subsys_state___41 *, struct cftype___41 *);
	s64 (*read_s64)(struct cgroup_subsys_state___41 *, struct cftype___41 *);
	int (*seq_show)(struct seq_file___49 *, void *);
	void * (*seq_start)(struct seq_file___49 *, loff_t *);
	void * (*seq_next)(struct seq_file___49 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___49 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___41 *, struct cftype___41 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___41 *, struct cftype___41 *, s64);
	ssize_t (*write)(struct kernfs_open_file___51 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___51 *, struct poll_table_struct___5 *);
};

struct css_task_iter___5 {
	struct cgroup_subsys___41 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___41 *cur_cset;
	struct css_set___41 *cur_dcset;
	struct task_struct___54 *cur_task;
	struct list_head iters_node;
};

struct blk_mq_queue_data___22 {
	struct request___23 *rq;
	bool last;
};

struct blkcg_policy_data___22;

struct blkcg___22 {
	struct cgroup_subsys_state___41 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___22 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___22 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___22 {
	struct blkcg___22 *blkcg;
	int plid;
};

struct blkg_policy_data___22 {
	struct blkcg_gq___22 *blkg;
	int plid;
};

struct property___24 {
	char *name;
	int length;
	void *value;
	struct property___24 *next;
	long unsigned int _flags;
	struct bin_attribute___51 attr;
};

struct fmeter {
	int cnt;
	int val;
	time64_t time;
	spinlock_t lock;
};

struct cpuset {
	struct cgroup_subsys_state___41 css;
	long unsigned int flags;
	cpumask_var_t cpus_allowed;
	nodemask_t mems_allowed;
	cpumask_var_t effective_cpus;
	nodemask_t effective_mems;
	cpumask_var_t subparts_cpus;
	nodemask_t old_mems_allowed;
	struct fmeter fmeter;
	int attach_in_progress;
	int pn;
	int relax_domain_level;
	int nr_subparts_cpus;
	int partition_root_state;
	int use_parent_ecpus;
	int child_ecpus_count;
	struct cgroup_file___41 partition_file;
};

struct tmpmasks {
	cpumask_var_t addmask;
	cpumask_var_t delmask;
	cpumask_var_t new_cpus;
};

typedef enum {
	CS_ONLINE = 0,
	CS_CPU_EXCLUSIVE = 1,
	CS_MEM_EXCLUSIVE = 2,
	CS_MEM_HARDWALL = 3,
	CS_MEMORY_MIGRATE = 4,
	CS_SCHED_LOAD_BALANCE = 5,
	CS_SPREAD_PAGE = 6,
	CS_SPREAD_SLAB = 7,
} cpuset_flagbits_t;

enum subparts_cmd {
	partcmd_enable = 0,
	partcmd_disable = 1,
	partcmd_update = 2,
};

struct cpuset_migrate_mm_work {
	struct work_struct work;
	struct mm_struct___54 *mm;
	nodemask_t from;
	nodemask_t to;
};

typedef enum {
	FILE_MEMORY_MIGRATE = 0,
	FILE_CPULIST = 1,
	FILE_MEMLIST = 2,
	FILE_EFFECTIVE_CPULIST = 3,
	FILE_EFFECTIVE_MEMLIST = 4,
	FILE_SUBPARTS_CPULIST = 5,
	FILE_CPU_EXCLUSIVE = 6,
	FILE_MEM_EXCLUSIVE = 7,
	FILE_MEM_HARDWALL = 8,
	FILE_SCHED_LOAD_BALANCE = 9,
	FILE_PARTITION_ROOT = 10,
	FILE_SCHED_RELAX_DOMAIN_LEVEL = 11,
	FILE_MEMORY_PRESSURE_ENABLED = 12,
	FILE_MEMORY_PRESSURE = 13,
	FILE_SPREAD_PAGE = 14,
	FILE_SPREAD_SLAB = 15,
} cpuset_filetype_t;

enum misc_res_type {
	MISC_CG_RES_TYPES = 0,
};

struct misc_res {
	long unsigned int max;
	atomic_long_t usage;
	bool failed;
};

struct misc_cg {
	struct cgroup_subsys_state___26 css;
	struct misc_res res[0];
};

struct vm_area_struct___54;

struct vmacache___54 {
	u64 seqnum;
	struct vm_area_struct___54 *vmas[4];
};

struct page___54;

struct page_frag___54 {
	struct page___54 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___55;

struct cred___7;

struct nsproxy___50;

struct task_struct___55 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___55 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___55 *mm;
	struct mm_struct___55 *active_mm;
	struct vmacache___54 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___55 *real_parent;
	struct task_struct___55 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___55 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___45 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___7 *ptracer_cred;
	const struct cred___7 *real_cred;
	const struct cred___7 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___50 *nsproxy;
	struct signal_struct___2 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___55 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___54 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___55 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___9;

struct ns_common___9 {
	atomic_long_t stashed;
	const struct proc_ns_operations___9 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___8;

struct user_namespace___8 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___8 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___9 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___8 *ucounts;
	long int ucount_max[16];
};

typedef struct page___54 *pgtable_t___54;

struct page___54 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___49 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___54 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___54 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___55 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___49 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___8 {
	struct hlist_node node;
	struct user_namespace___8 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_area_struct___54 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___54 *vm_next;
	struct vm_area_struct___54 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___55 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___54;

struct mm_struct___55 {
	struct {
		struct vm_area_struct___54 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___54 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___55 *owner;
		struct user_namespace___8 *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___7 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___8 *user_ns;
	struct ucounts___8 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct uts_namespace___6;

struct nsproxy___50 {
	atomic_t count;
	struct uts_namespace___6 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct uts_namespace___6 {
	struct new_utsname name;
	struct user_namespace___8 *user_ns;
	struct ucounts___8 *ucounts;
	struct ns_common___9 ns;
};

struct nsset___8 {
	unsigned int flags;
	struct nsproxy___50 *nsproxy;
	struct fs_struct *fs;
	const struct cred___7 *cred;
};

struct proc_ns_operations___9 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___9 * (*get)(struct task_struct___55 *);
	void (*put)(struct ns_common___9 *);
	int (*install)(struct nsset___8 *, struct ns_common___9 *);
	struct user_namespace___8 * (*owner)(struct ns_common___9 *);
	struct ns_common___9 * (*get_parent)(struct ns_common___9 *);
};

struct core_thread___54 {
	struct task_struct___55 *task;
	struct core_thread___54 *next;
};

struct core_state___54 {
	atomic_t nr_threads;
	struct core_thread___54 dumper;
	struct completion startup;
};

struct dentry___51;

struct super_block___51;

struct file_system_type___50 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___51 * (*mount)(struct file_system_type___50 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___51 *);
	struct module___8 *owner;
	struct file_system_type___50 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___51;

struct kiocb___50;

struct vm_area_struct___55;

struct inode___51;

struct file_lock___50;

struct page___55;

struct file_operations___50 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___51 *, loff_t, int);
	ssize_t (*read)(struct file___51 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___51 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___50 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___50 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___50 *, bool);
	int (*iterate)(struct file___51 *, struct dir_context *);
	int (*iterate_shared)(struct file___51 *, struct dir_context *);
	__poll_t (*poll)(struct file___51 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___51 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___51 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___51 *, struct vm_area_struct___55 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___51 *, struct file___51 *);
	int (*flush)(struct file___51 *, fl_owner_t);
	int (*release)(struct inode___51 *, struct file___51 *);
	int (*fsync)(struct file___51 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___51 *, int);
	int (*lock)(struct file___51 *, int, struct file_lock___50 *);
	ssize_t (*sendpage)(struct file___51 *, struct page___55 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___51 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___51 *, long unsigned int);
	int (*flock)(struct file___51 *, int, struct file_lock___50 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___51 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___51 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___51 *, long int, struct file_lock___50 **, void **);
	long int (*fallocate)(struct file___51 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___2 *, struct file___51 *);
	ssize_t (*copy_file_range)(struct file___51 *, loff_t, struct file___51 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___51 *, loff_t, struct file___51 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___51 *, loff_t, loff_t, int);
};

struct vmacache___55 {
	u64 seqnum;
	struct vm_area_struct___55 *vmas[4];
};

struct page_frag___55 {
	struct page___55 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___56;

struct cred___8;

struct fs_struct___8;

struct signal_struct___51;

struct task_struct___56 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___56 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___56 *mm;
	struct mm_struct___56 *active_mm;
	struct vmacache___55 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___56 *real_parent;
	struct task_struct___56 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___56 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___45 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___8 *ptracer_cred;
	const struct cred___8 *real_cred;
	const struct cred___8 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___8 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___50 *nsproxy;
	struct signal_struct___51 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___56 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___24 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___55 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___56 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___33 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___10;

struct ns_common___10 {
	atomic_long_t stashed;
	const struct proc_ns_operations___10 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___9;

struct user_namespace___9 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___9 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___10 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___9 *ucounts;
	long int ucount_max[16];
};

typedef struct page___55 *pgtable_t___55;

struct address_space___50;

struct page___55 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___50 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___55 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___55 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___56 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___49 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___9 {
	struct hlist_node node;
	struct user_namespace___9 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_area_struct___55 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___55 *vm_next;
	struct vm_area_struct___55 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___56 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___51 *vm_file;
	struct file___51 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___51 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___56 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___56 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___45 *pids[4];
	struct pid___45 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___56 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___55;

struct mm_struct___56 {
	struct {
		struct vm_area_struct___55 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___51 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___55 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___56 *owner;
		struct user_namespace___9 *user_ns;
		struct file___51 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___8 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___9 *user_ns;
	struct ucounts___9 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct vfsmount___50;

struct path___50 {
	struct vfsmount___50 *mnt;
	struct dentry___51 *dentry;
};

struct fs_struct___8 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___50 root;
	struct path___50 pwd;
};

struct nsset___9 {
	unsigned int flags;
	struct nsproxy___50 *nsproxy;
	struct fs_struct___8 *fs;
	const struct cred___8 *cred;
};

struct address_space_operations___50;

struct address_space___50 {
	struct inode___51 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___50 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct file___51 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___50 f_path;
	struct inode___51 *f_inode;
	const struct file_operations___50 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___45 f_owner;
	const struct cred___8 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___50 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct core_thread___55 {
	struct task_struct___56 *task;
	struct core_thread___55 *next;
};

struct core_state___55 {
	atomic_t nr_threads;
	struct core_thread___55 dumper;
	struct completion startup;
};

struct proc_ns_operations___10 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___10 * (*get)(struct task_struct___56 *);
	void (*put)(struct ns_common___10 *);
	int (*install)(struct nsset___9 *, struct ns_common___10 *);
	struct user_namespace___9 * (*owner)(struct ns_common___10 *);
	struct ns_common___10 * (*get_parent)(struct ns_common___10 *);
};

struct seq_operations___49 {
	void * (*start)(struct seq_file___2 *, loff_t *);
	void (*stop)(struct seq_file___2 *, void *);
	void * (*next)(struct seq_file___2 *, void *, loff_t *);
	int (*show)(struct seq_file___2 *, void *);
};

struct kernel_pkey_query {
	__u32 supported_ops;
	__u32 key_size;
	__u16 max_data_size;
	__u16 max_sig_size;
	__u16 max_enc_size;
	__u16 max_dec_size;
};

enum kernel_pkey_operation {
	kernel_pkey_encrypt = 0,
	kernel_pkey_decrypt = 1,
	kernel_pkey_sign = 2,
	kernel_pkey_verify = 3,
};

struct kernel_pkey_params {
	struct key *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key_preparsed_payload {
	const char *orig_description;
	char *description;
	union key_payload payload;
	const void *data;
	size_t datalen;
	size_t quotalen;
	time64_t expiry;
};

struct key_match_data {
	bool (*cmp)(const struct key *, const struct key_match_data *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct seq_file___2 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___49 *op;
	int poll_event;
	const struct file___51 *file;
	void *private;
};

struct dentry_operations___50;

struct dentry___51 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___51 *d_parent;
	struct qstr d_name;
	struct inode___51 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___50 *d_op;
	struct super_block___51 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___50;

struct inode___51 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___50 *i_op;
	struct super_block___51 *i_sb;
	struct address_space___50 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___50 *i_fop;
		void (*free_inode)(struct inode___51 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___50 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___50 {
	int (*d_revalidate)(struct dentry___51 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___51 *, unsigned int);
	int (*d_hash)(const struct dentry___51 *, struct qstr *);
	int (*d_compare)(const struct dentry___51 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___51 *);
	int (*d_init)(struct dentry___51 *);
	void (*d_release)(struct dentry___51 *);
	void (*d_prune)(struct dentry___51 *);
	void (*d_iput)(struct dentry___51 *, struct inode___51 *);
	char * (*d_dname)(struct dentry___51 *, char *, int);
	struct vfsmount___50 * (*d_automount)(struct path___50 *);
	int (*d_manage)(const struct path___50 *, bool);
	struct dentry___51 * (*d_real)(struct dentry___51 *, const struct inode___51 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___50;

struct mem_dqinfo___50 {
	struct quota_format_type___50 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___50;

struct quota_info___50 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___51 *files[3];
	struct mem_dqinfo___50 info[3];
	const struct quota_format_ops___50 *ops[3];
};

struct rcuwait___51 {
	struct task_struct___56 *task;
};

struct percpu_rw_semaphore___51 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___51 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___50 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___51 rw_sem[3];
};

struct super_operations___50;

struct dquot_operations___50;

struct quotactl_ops___50;

struct super_block___51 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___50 *s_type;
	const struct super_operations___50 *s_op;
	const struct dquot_operations___50 *dq_op;
	const struct quotactl_ops___50 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___51 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___50 s_dquot;
	struct sb_writers___50 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___50 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___9 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___50 {
	struct dentry___51 *mnt_root;
	struct super_block___51 *mnt_sb;
	int mnt_flags;
	struct user_namespace___9 *mnt_userns;
};

struct kiocb___50 {
	struct file___51 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___50 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___51 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___51 *ia_file;
};

struct dquot___50 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___51 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___50 {
	int qf_fmt_id;
	const struct quota_format_ops___50 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___50 *qf_next;
};

struct quota_format_ops___50 {
	int (*check_quota_file)(struct super_block___51 *, int);
	int (*read_file_info)(struct super_block___51 *, int);
	int (*write_file_info)(struct super_block___51 *, int);
	int (*free_file_info)(struct super_block___51 *, int);
	int (*read_dqblk)(struct dquot___50 *);
	int (*commit_dqblk)(struct dquot___50 *);
	int (*release_dqblk)(struct dquot___50 *);
	int (*get_next_id)(struct super_block___51 *, struct kqid *);
};

struct dquot_operations___50 {
	int (*write_dquot)(struct dquot___50 *);
	struct dquot___50 * (*alloc_dquot)(struct super_block___51 *, int);
	void (*destroy_dquot)(struct dquot___50 *);
	int (*acquire_dquot)(struct dquot___50 *);
	int (*release_dquot)(struct dquot___50 *);
	int (*mark_dirty)(struct dquot___50 *);
	int (*write_info)(struct super_block___51 *, int);
	qsize_t * (*get_reserved_space)(struct inode___51 *);
	int (*get_projid)(struct inode___51 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___51 *, qsize_t *);
	int (*get_next_id)(struct super_block___51 *, struct kqid *);
};

struct quotactl_ops___50 {
	int (*quota_on)(struct super_block___51 *, int, int, const struct path___50 *);
	int (*quota_off)(struct super_block___51 *, int);
	int (*quota_enable)(struct super_block___51 *, unsigned int);
	int (*quota_disable)(struct super_block___51 *, unsigned int);
	int (*quota_sync)(struct super_block___51 *, int);
	int (*set_info)(struct super_block___51 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___51 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___51 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___51 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___51 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___51 *, unsigned int);
};

struct address_space_operations___50 {
	int (*writepage)(struct page___55 *, struct writeback_control___3 *);
	int (*readpage)(struct file___51 *, struct page___55 *);
	int (*writepages)(struct address_space___50 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___55 *);
	int (*readpages)(struct file___51 *, struct address_space___50 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___51 *, struct address_space___50 *, loff_t, unsigned int, unsigned int, struct page___55 **, void **);
	int (*write_end)(struct file___51 *, struct address_space___50 *, loff_t, unsigned int, unsigned int, struct page___55 *, void *);
	sector_t (*bmap)(struct address_space___50 *, sector_t);
	void (*invalidatepage)(struct page___55 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___55 *, gfp_t);
	void (*freepage)(struct page___55 *);
	ssize_t (*direct_IO)(struct kiocb___50 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___50 *, struct page___55 *, struct page___55 *, enum migrate_mode);
	bool (*isolate_page)(struct page___55 *, isolate_mode_t);
	void (*putback_page)(struct page___55 *);
	int (*launder_page)(struct page___55 *);
	int (*is_partially_uptodate)(struct page___55 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___55 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___50 *, struct page___55 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___51 *, sector_t *);
	void (*swap_deactivate)(struct file___51 *);
};

struct inode_operations___50 {
	struct dentry___51 * (*lookup)(struct inode___51 *, struct dentry___51 *, unsigned int);
	const char * (*get_link)(struct dentry___51 *, struct inode___51 *, struct delayed_call *);
	int (*permission)(struct user_namespace___9 *, struct inode___51 *, int);
	struct posix_acl * (*get_acl)(struct inode___51 *, int, bool);
	int (*readlink)(struct dentry___51 *, char *, int);
	int (*create)(struct user_namespace___9 *, struct inode___51 *, struct dentry___51 *, umode_t, bool);
	int (*link)(struct dentry___51 *, struct inode___51 *, struct dentry___51 *);
	int (*unlink)(struct inode___51 *, struct dentry___51 *);
	int (*symlink)(struct user_namespace___9 *, struct inode___51 *, struct dentry___51 *, const char *);
	int (*mkdir)(struct user_namespace___9 *, struct inode___51 *, struct dentry___51 *, umode_t);
	int (*rmdir)(struct inode___51 *, struct dentry___51 *);
	int (*mknod)(struct user_namespace___9 *, struct inode___51 *, struct dentry___51 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___9 *, struct inode___51 *, struct dentry___51 *, struct inode___51 *, struct dentry___51 *, unsigned int);
	int (*setattr)(struct user_namespace___9 *, struct dentry___51 *, struct iattr___51 *);
	int (*getattr)(struct user_namespace___9 *, const struct path___50 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___51 *, char *, size_t);
	int (*fiemap)(struct inode___51 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___51 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___51 *, struct dentry___51 *, struct file___51 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___9 *, struct inode___51 *, struct dentry___51 *, umode_t);
	int (*set_acl)(struct user_namespace___9 *, struct inode___51 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___9 *, struct dentry___51 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___51 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___50 {
	void (*fl_copy_lock)(struct file_lock___50 *, struct file_lock___50 *);
	void (*fl_release_private)(struct file_lock___50 *);
};

struct fasync_struct___50;

struct lock_manager_operations___50;

struct file_lock___50 {
	struct file_lock___50 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___51 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___50 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___50 *fl_ops;
	const struct lock_manager_operations___50 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___50 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___50 *);
	int (*lm_grant)(struct file_lock___50 *, int);
	bool (*lm_break)(struct file_lock___50 *);
	int (*lm_change)(struct file_lock___50 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___50 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___50 *);
};

struct fasync_struct___50 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___50 *fa_next;
	struct file___51 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___50 {
	struct inode___51 * (*alloc_inode)(struct super_block___51 *);
	void (*destroy_inode)(struct inode___51 *);
	void (*free_inode)(struct inode___51 *);
	void (*dirty_inode)(struct inode___51 *, int);
	int (*write_inode)(struct inode___51 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___51 *);
	void (*evict_inode)(struct inode___51 *);
	void (*put_super)(struct super_block___51 *);
	int (*sync_fs)(struct super_block___51 *, int);
	int (*freeze_super)(struct super_block___51 *);
	int (*freeze_fs)(struct super_block___51 *);
	int (*thaw_super)(struct super_block___51 *);
	int (*unfreeze_fs)(struct super_block___51 *);
	int (*statfs)(struct dentry___51 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___51 *, int *, char *);
	void (*umount_begin)(struct super_block___51 *);
	int (*show_options)(struct seq_file___2 *, struct dentry___51 *);
	int (*show_devname)(struct seq_file___2 *, struct dentry___51 *);
	int (*show_path)(struct seq_file___2 *, struct dentry___51 *);
	int (*show_stats)(struct seq_file___2 *, struct dentry___51 *);
	ssize_t (*quota_read)(struct super_block___51 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___51 *, int, const char *, size_t, loff_t);
	struct dquot___50 ** (*get_dquots)(struct inode___51 *);
	long int (*nr_cached_objects)(struct super_block___51 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___51 *, struct shrink_control___21 *);
	struct file___51 * (*real_loop)(struct file___51 *);
};

struct idmap_key {
	bool map_up;
	u32 id;
	u32 count;
};

struct dentry___52;

struct super_block___52;

struct module___51;

struct file_system_type___51 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___52 * (*mount)(struct file_system_type___51 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___52 *);
	struct module___51 *owner;
	struct file_system_type___51 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___52;

struct kiocb___51;

struct poll_table_struct___37;

struct vm_area_struct___56;

struct inode___52;

struct file_lock___51;

struct page___56;

struct seq_file___50;

struct file_operations___51 {
	struct module___51 *owner;
	loff_t (*llseek)(struct file___52 *, loff_t, int);
	ssize_t (*read)(struct file___52 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___52 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___51 *, struct iov_iter___26 *);
	ssize_t (*write_iter)(struct kiocb___51 *, struct iov_iter___26 *);
	int (*iopoll)(struct kiocb___51 *, bool);
	int (*iterate)(struct file___52 *, struct dir_context *);
	int (*iterate_shared)(struct file___52 *, struct dir_context *);
	__poll_t (*poll)(struct file___52 *, struct poll_table_struct___37 *);
	long int (*unlocked_ioctl)(struct file___52 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___52 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___52 *, struct vm_area_struct___56 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___52 *, struct file___52 *);
	int (*flush)(struct file___52 *, fl_owner_t);
	int (*release)(struct inode___52 *, struct file___52 *);
	int (*fsync)(struct file___52 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___52 *, int);
	int (*lock)(struct file___52 *, int, struct file_lock___51 *);
	ssize_t (*sendpage)(struct file___52 *, struct page___56 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___52 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___52 *, long unsigned int);
	int (*flock)(struct file___52 *, int, struct file_lock___51 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___52 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___52 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___52 *, long int, struct file_lock___51 **, void **);
	long int (*fallocate)(struct file___52 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___50 *, struct file___52 *);
	ssize_t (*copy_file_range)(struct file___52 *, loff_t, struct file___52 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___52 *, loff_t, struct file___52 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___52 *, loff_t, loff_t, int);
};

struct vmacache___56 {
	u64 seqnum;
	struct vm_area_struct___56 *vmas[4];
};

struct page_frag___56 {
	struct page___56 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___34;

struct debug_info___34 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___34 *hbp_break[16];
	struct perf_event___34 *hbp_watch[16];
};

struct thread_struct___34 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___34 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___57;

struct pid___46;

struct cred___9;

struct nsproxy___51;

struct signal_struct___52;

struct css_set___42;

struct perf_event_context___34;

struct vm_struct___53;

struct task_struct___57 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___57 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___57 *mm;
	struct mm_struct___57 *active_mm;
	struct vmacache___56 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___57 *real_parent;
	struct task_struct___57 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___57 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___46 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___51 *nsproxy;
	struct signal_struct___52 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___57 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___24 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___42 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___34 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___56 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___57 *oom_reaper_list;
	struct vm_struct___53 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___34 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___52;

struct kobj_type___52;

struct kernfs_node___52;

struct kobject___52 {
	const char *name;
	struct list_head entry;
	struct kobject___52 *parent;
	struct kset___52 *kset;
	struct kobj_type___52 *ktype;
	struct kernfs_node___52 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___49 {
	struct kobject___52 kobj;
	struct module___51 *mod;
	struct kobject___52 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___49 {
	struct module___51 *mod;
	struct latch_tree_node node;
};

struct module_layout___49 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___49 mtn;
};

struct module_attribute___49;

struct kernel_param___49;

struct trace_event_call___29;

struct module___51 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___49 mkobj;
	struct module_attribute___49 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___52 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___49 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___49 core_layout;
	struct module_layout___49 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___29 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___34 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___57 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___34)(struct perf_event___34 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___34;

struct fasync_struct___51;

struct pid_namespace___46;

struct perf_cgroup___34;

struct perf_event___34 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___34 *group_leader;
	struct pmu___34 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___34 hw;
	struct perf_event_context___34 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___34 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___57 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___51 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___34 *aux_event;
	void (*destroy)(struct perf_event___34 *);
	struct callback_head callback_head;
	struct pid_namespace___46 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___34 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___34 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___29 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___34 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___46 {
	int nr;
	struct pid_namespace___46 *ns;
};

struct proc_ns_operations___11;

struct ns_common___11 {
	atomic_long_t stashed;
	const struct proc_ns_operations___11 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___10;

struct ucounts___10;

struct pid_namespace___46 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___57 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___46 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___46 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___46 numbers[1];
};

struct user_namespace___10 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___10 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___11 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___10 *ucounts;
	long int ucount_max[16];
};

typedef struct page___56 *pgtable_t___56;

struct address_space___51;

struct dev_pagemap___50;

struct page___56 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___51 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___13 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___56 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___56 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___57 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___50 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___10 {
	struct hlist_node node;
	struct user_namespace___10 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___50;

struct vm_area_struct___56 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___56 *vm_next;
	struct vm_area_struct___56 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___57 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___50 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___52 *vm_file;
	struct file___52 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___52 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___57 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___57 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___46 *pids[4];
	struct pid___46 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___57 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___56;

struct mm_struct___57 {
	struct {
		struct vm_area_struct___56 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___52 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___56 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___57 *owner;
		struct user_namespace___10 *user_ns;
		struct file___52 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___9 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct cgroup_namespace___42;

struct nsproxy___51 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___46 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___42 *cgroup_ns;
};

struct cgroup_subsys_state___42;

struct cgroup___42;

struct css_set___42 {
	struct cgroup_subsys_state___42 *subsys[14];
	refcount_t refcount;
	struct css_set___42 *dom_cset;
	struct cgroup___42 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___42 *mg_src_cgrp;
	struct cgroup___42 *mg_dst_cgrp;
	struct css_set___42 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___34 {
	struct pmu___34 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___57 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___34 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___53 {
	struct vm_struct___53 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___56 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___51;

struct address_space___51 {
	struct inode___52 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___51 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___50;

struct dev_pagemap___50 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___50 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___51;

struct path___51 {
	struct vfsmount___51 *mnt;
	struct dentry___52 *dentry;
};

struct fown_struct___46 {
	rwlock_t lock;
	struct pid___46 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___52 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___51 f_path;
	struct inode___52 *f_inode;
	const struct file_operations___51 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___46 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___51 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___50;

struct vm_operations_struct___50 {
	void (*open)(struct vm_area_struct___56 *);
	void (*close)(struct vm_area_struct___56 *);
	int (*may_split)(struct vm_area_struct___56 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___56 *);
	int (*mprotect)(struct vm_area_struct___56 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___50 *);
	vm_fault_t (*huge_fault)(struct vm_fault___50 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___50 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___56 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___50 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___50 *);
	int (*access)(struct vm_area_struct___56 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___56 *);
	int (*set_policy)(struct vm_area_struct___56 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___56 *, long unsigned int);
	struct page___56 * (*find_special_page)(struct vm_area_struct___56 *, long unsigned int);
};

struct core_thread___56 {
	struct task_struct___57 *task;
	struct core_thread___56 *next;
};

struct core_state___56 {
	atomic_t nr_threads;
	struct core_thread___56 dumper;
	struct completion startup;
};

struct vm_fault___50 {
	const struct {
		struct vm_area_struct___56 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___56 *cow_page;
	struct page___56 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___56 prealloc_pte;
};

struct dev_pagemap_ops___50 {
	void (*page_free)(struct page___56 *);
	void (*kill)(struct dev_pagemap___50 *);
	void (*cleanup)(struct dev_pagemap___50 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___50 *);
};

struct dentry_operations___51;

struct dentry___52 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___52 *d_parent;
	struct qstr d_name;
	struct inode___52 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___51 *d_op;
	struct super_block___52 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___51;

struct inode___52 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___51 *i_op;
	struct super_block___52 *i_sb;
	struct address_space___51 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___51 *i_fop;
		void (*free_inode)(struct inode___52 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___51 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___14 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___51 {
	int (*d_revalidate)(struct dentry___52 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___52 *, unsigned int);
	int (*d_hash)(const struct dentry___52 *, struct qstr *);
	int (*d_compare)(const struct dentry___52 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___52 *);
	int (*d_init)(struct dentry___52 *);
	void (*d_release)(struct dentry___52 *);
	void (*d_prune)(struct dentry___52 *);
	void (*d_iput)(struct dentry___52 *, struct inode___52 *);
	char * (*d_dname)(struct dentry___52 *, char *, int);
	struct vfsmount___51 * (*d_automount)(struct path___51 *);
	int (*d_manage)(const struct path___51 *, bool);
	struct dentry___52 * (*d_real)(struct dentry___52 *, const struct inode___52 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___51;

struct mem_dqinfo___51 {
	struct quota_format_type___51 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___51;

struct quota_info___51 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___52 *files[3];
	struct mem_dqinfo___51 info[3];
	const struct quota_format_ops___51 *ops[3];
};

struct rcuwait___52 {
	struct task_struct___57 *task;
};

struct percpu_rw_semaphore___52 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___52 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___51 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___52 rw_sem[3];
};

struct super_operations___51;

struct dquot_operations___51;

struct quotactl_ops___51;

struct super_block___52 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___51 *s_type;
	const struct super_operations___51 *s_op;
	const struct dquot_operations___51 *dq_op;
	const struct quotactl_ops___51 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___52 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___51 s_dquot;
	struct sb_writers___51 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___51 *s_d_op;
	int cleancache_poolid;
	struct shrinker___21 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___51 {
	struct dentry___52 *mnt_root;
	struct super_block___52 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct cgroup_subsys___42;

struct cgroup_subsys_state___42 {
	struct cgroup___42 *cgroup;
	struct cgroup_subsys___42 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___42 *parent;
};

struct cgroup_file___42 {
	struct kernfs_node___52 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___42 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___57 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___42;

struct cgroup_rstat_cpu___42;

struct cgroup___42 {
	struct cgroup_subsys_state___42 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___52 *kn;
	struct cgroup_file___42 procs_file;
	struct cgroup_file___42 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___42 *subsys[14];
	struct cgroup_root___42 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___42 *dom_cgrp;
	struct cgroup___42 *old_dom_cgrp;
	struct cgroup_rstat_cpu___42 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___42 psi;
	struct cgroup_bpf___5 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct ctl_path {
	const char *procname;
};

struct kiocb___51 {
	struct file___52 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___51 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___52 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___52 *ia_file;
};

struct dquot___51 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___52 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___51 {
	int qf_fmt_id;
	const struct quota_format_ops___51 *qf_ops;
	struct module___51 *qf_owner;
	struct quota_format_type___51 *qf_next;
};

struct quota_format_ops___51 {
	int (*check_quota_file)(struct super_block___52 *, int);
	int (*read_file_info)(struct super_block___52 *, int);
	int (*write_file_info)(struct super_block___52 *, int);
	int (*free_file_info)(struct super_block___52 *, int);
	int (*read_dqblk)(struct dquot___51 *);
	int (*commit_dqblk)(struct dquot___51 *);
	int (*release_dqblk)(struct dquot___51 *);
	int (*get_next_id)(struct super_block___52 *, struct kqid *);
};

struct dquot_operations___51 {
	int (*write_dquot)(struct dquot___51 *);
	struct dquot___51 * (*alloc_dquot)(struct super_block___52 *, int);
	void (*destroy_dquot)(struct dquot___51 *);
	int (*acquire_dquot)(struct dquot___51 *);
	int (*release_dquot)(struct dquot___51 *);
	int (*mark_dirty)(struct dquot___51 *);
	int (*write_info)(struct super_block___52 *, int);
	qsize_t * (*get_reserved_space)(struct inode___52 *);
	int (*get_projid)(struct inode___52 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___52 *, qsize_t *);
	int (*get_next_id)(struct super_block___52 *, struct kqid *);
};

struct quotactl_ops___51 {
	int (*quota_on)(struct super_block___52 *, int, int, const struct path___51 *);
	int (*quota_off)(struct super_block___52 *, int);
	int (*quota_enable)(struct super_block___52 *, unsigned int);
	int (*quota_disable)(struct super_block___52 *, unsigned int);
	int (*quota_sync)(struct super_block___52 *, int);
	int (*set_info)(struct super_block___52 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___52 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___52 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___52 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___52 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___52 *, unsigned int);
};

struct address_space_operations___51 {
	int (*writepage)(struct page___56 *, struct writeback_control___3 *);
	int (*readpage)(struct file___52 *, struct page___56 *);
	int (*writepages)(struct address_space___51 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___56 *);
	int (*readpages)(struct file___52 *, struct address_space___51 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___52 *, struct address_space___51 *, loff_t, unsigned int, unsigned int, struct page___56 **, void **);
	int (*write_end)(struct file___52 *, struct address_space___51 *, loff_t, unsigned int, unsigned int, struct page___56 *, void *);
	sector_t (*bmap)(struct address_space___51 *, sector_t);
	void (*invalidatepage)(struct page___56 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___56 *, gfp_t);
	void (*freepage)(struct page___56 *);
	ssize_t (*direct_IO)(struct kiocb___51 *, struct iov_iter___26 *);
	int (*migratepage)(struct address_space___51 *, struct page___56 *, struct page___56 *, enum migrate_mode);
	bool (*isolate_page)(struct page___56 *, isolate_mode_t);
	void (*putback_page)(struct page___56 *);
	int (*launder_page)(struct page___56 *);
	int (*is_partially_uptodate)(struct page___56 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___56 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___51 *, struct page___56 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___52 *, sector_t *);
	void (*swap_deactivate)(struct file___52 *);
};

struct inode_operations___51 {
	struct dentry___52 * (*lookup)(struct inode___52 *, struct dentry___52 *, unsigned int);
	const char * (*get_link)(struct dentry___52 *, struct inode___52 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___52 *, int);
	struct posix_acl * (*get_acl)(struct inode___52 *, int, bool);
	int (*readlink)(struct dentry___52 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___52 *, struct dentry___52 *, umode_t, bool);
	int (*link)(struct dentry___52 *, struct inode___52 *, struct dentry___52 *);
	int (*unlink)(struct inode___52 *, struct dentry___52 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___52 *, struct dentry___52 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___52 *, struct dentry___52 *, umode_t);
	int (*rmdir)(struct inode___52 *, struct dentry___52 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___52 *, struct dentry___52 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___52 *, struct dentry___52 *, struct inode___52 *, struct dentry___52 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___52 *, struct iattr___52 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___51 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___52 *, char *, size_t);
	int (*fiemap)(struct inode___52 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___52 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___52 *, struct dentry___52 *, struct file___52 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___52 *, struct dentry___52 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___52 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___52 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___52 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___51 {
	void (*fl_copy_lock)(struct file_lock___51 *, struct file_lock___51 *);
	void (*fl_release_private)(struct file_lock___51 *);
};

struct lock_manager_operations___51;

struct file_lock___51 {
	struct file_lock___51 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___52 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___51 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___51 *fl_ops;
	const struct lock_manager_operations___51 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___51 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___51 *);
	int (*lm_grant)(struct file_lock___51 *, int);
	bool (*lm_break)(struct file_lock___51 *);
	int (*lm_change)(struct file_lock___51 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___51 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___51 *);
};

struct fasync_struct___51 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___51 *fa_next;
	struct file___52 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___51 {
	struct inode___52 * (*alloc_inode)(struct super_block___52 *);
	void (*destroy_inode)(struct inode___52 *);
	void (*free_inode)(struct inode___52 *);
	void (*dirty_inode)(struct inode___52 *, int);
	int (*write_inode)(struct inode___52 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___52 *);
	void (*evict_inode)(struct inode___52 *);
	void (*put_super)(struct super_block___52 *);
	int (*sync_fs)(struct super_block___52 *, int);
	int (*freeze_super)(struct super_block___52 *);
	int (*freeze_fs)(struct super_block___52 *);
	int (*thaw_super)(struct super_block___52 *);
	int (*unfreeze_fs)(struct super_block___52 *);
	int (*statfs)(struct dentry___52 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___52 *, int *, char *);
	void (*umount_begin)(struct super_block___52 *);
	int (*show_options)(struct seq_file___50 *, struct dentry___52 *);
	int (*show_devname)(struct seq_file___50 *, struct dentry___52 *);
	int (*show_path)(struct seq_file___50 *, struct dentry___52 *);
	int (*show_stats)(struct seq_file___50 *, struct dentry___52 *);
	ssize_t (*quota_read)(struct super_block___52 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___52 *, int, const char *, size_t, loff_t);
	struct dquot___51 ** (*get_dquots)(struct inode___52 *);
	long int (*nr_cached_objects)(struct super_block___52 *, struct shrink_control___21 *);
	long int (*free_cached_objects)(struct super_block___52 *, struct shrink_control___21 *);
	struct file___52 * (*real_loop)(struct file___52 *);
};

typedef void (*poll_queue_proc___37)(struct file___52 *, wait_queue_head_t *, struct poll_table_struct___37 *);

struct poll_table_struct___37 {
	poll_queue_proc___37 _qproc;
	__poll_t _key;
};

struct seq_operations___50;

struct seq_file___50 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___50 *op;
	int poll_event;
	const struct file___52 *file;
	void *private;
};

struct cgroup_namespace___42 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___42 *root_cset;
};

struct nsset___10 {
	unsigned int flags;
	struct nsproxy___51 *nsproxy;
	struct fs_struct *fs;
	const struct cred___9 *cred;
};

struct proc_ns_operations___11 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___11 * (*get)(struct task_struct___57 *);
	void (*put)(struct ns_common___11 *);
	int (*install)(struct nsset___10 *, struct ns_common___11 *);
	struct user_namespace___10 * (*owner)(struct ns_common___11 *);
	struct ns_common___11 * (*get_parent)(struct ns_common___11 *);
};

struct seq_operations___50 {
	void * (*start)(struct seq_file___50 *, loff_t *);
	void (*stop)(struct seq_file___50 *, void *);
	void * (*next)(struct seq_file___50 *, void *, loff_t *);
	int (*show)(struct seq_file___50 *, void *);
};

struct kernfs_root___52;

struct kernfs_elem_dir___52 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___52 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___52;

struct kernfs_root___52 {
	struct kernfs_node___52 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___52 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___52 {
	struct kernfs_node___52 *target_kn;
};

struct kernfs_ops___52;

struct kernfs_elem_attr___52 {
	const struct kernfs_ops___52 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___52 *notify_next;
};

struct kernfs_node___52 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___52 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___52 dir;
		struct kernfs_elem_symlink___52 symlink;
		struct kernfs_elem_attr___52 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___52;

struct kernfs_ops___52 {
	int (*open)(struct kernfs_open_file___52 *);
	void (*release)(struct kernfs_open_file___52 *);
	int (*seq_show)(struct seq_file___50 *, void *);
	void * (*seq_start)(struct seq_file___50 *, loff_t *);
	void * (*seq_next)(struct seq_file___50 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___50 *, void *);
	ssize_t (*read)(struct kernfs_open_file___52 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___52 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___52 *, struct poll_table_struct___37 *);
	int (*mmap)(struct kernfs_open_file___52 *, struct vm_area_struct___56 *);
};

struct kernfs_syscall_ops___52 {
	int (*show_options)(struct seq_file___50 *, struct kernfs_root___52 *);
	int (*mkdir)(struct kernfs_node___52 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___52 *);
	int (*rename)(struct kernfs_node___52 *, struct kernfs_node___52 *, const char *);
	int (*show_path)(struct seq_file___50 *, struct kernfs_node___52 *, struct kernfs_root___52 *);
};

struct kernfs_open_file___52 {
	struct kernfs_node___52 *kn;
	struct file___52 *file;
	struct seq_file___50 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___50 *vm_ops;
};

struct bin_attribute___52;

struct attribute_group___52 {
	const char *name;
	umode_t (*is_visible)(struct kobject___52 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___52 *, struct bin_attribute___52 *, int);
	struct attribute **attrs;
	struct bin_attribute___52 **bin_attrs;
};

struct bin_attribute___52 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___51 * (*f_mapping)();
	ssize_t (*read)(struct file___52 *, struct kobject___52 *, struct bin_attribute___52 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___52 *, struct kobject___52 *, struct bin_attribute___52 *, char *, loff_t, size_t);
	int (*mmap)(struct file___52 *, struct kobject___52 *, struct bin_attribute___52 *, struct vm_area_struct___56 *);
};

struct sysfs_ops___52 {
	ssize_t (*show)(struct kobject___52 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___52 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___52;

struct kset___52 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___52 kobj;
	const struct kset_uevent_ops___52 *uevent_ops;
};

struct kobj_type___52 {
	void (*release)(struct kobject___52 *);
	const struct sysfs_ops___52 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___52 **default_groups;
	const struct kobj_ns_type_operations___4 * (*child_ns_type)(struct kobject___52 *);
	const void * (*namespace)(struct kobject___52 *);
	void (*get_ownership)(struct kobject___52 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___52 {
	int (* const filter)(struct kset___52 *, struct kobject___52 *);
	const char * (* const name)(struct kset___52 *, struct kobject___52 *);
	int (* const uevent)(struct kset___52 *, struct kobject___52 *, struct kobj_uevent_env *);
};

struct wakeup_source___46;

struct device___46;

struct dev_pm_info___46 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___46 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___46 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___46;

struct bus_type___46;

struct device_driver___46;

struct dev_pm_domain___46;

struct fwnode_handle___46;

struct class___46;

struct device___46 {
	struct kobject___52 kobj;
	struct device___46 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___46 *type;
	struct bus_type___46 *bus;
	struct device_driver___46 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___46 power;
	struct dev_pm_domain___46 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___46 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___46 *class;
	const struct attribute_group___52 **groups;
	void (*release)(struct device___46 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___46 {
	int (*prepare)(struct device___46 *);
	void (*complete)(struct device___46 *);
	int (*suspend)(struct device___46 *);
	int (*resume)(struct device___46 *);
	int (*freeze)(struct device___46 *);
	int (*thaw)(struct device___46 *);
	int (*poweroff)(struct device___46 *);
	int (*restore)(struct device___46 *);
	int (*suspend_late)(struct device___46 *);
	int (*resume_early)(struct device___46 *);
	int (*freeze_late)(struct device___46 *);
	int (*thaw_early)(struct device___46 *);
	int (*poweroff_late)(struct device___46 *);
	int (*restore_early)(struct device___46 *);
	int (*suspend_noirq)(struct device___46 *);
	int (*resume_noirq)(struct device___46 *);
	int (*freeze_noirq)(struct device___46 *);
	int (*thaw_noirq)(struct device___46 *);
	int (*poweroff_noirq)(struct device___46 *);
	int (*restore_noirq)(struct device___46 *);
	int (*runtime_suspend)(struct device___46 *);
	int (*runtime_resume)(struct device___46 *);
	int (*runtime_idle)(struct device___46 *);
};

struct wakeup_source___46 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___46 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___46 {
	struct dev_pm_ops___46 ops;
	int (*start)(struct device___46 *);
	void (*detach)(struct device___46 *, bool);
	int (*activate)(struct device___46 *);
	void (*sync)(struct device___46 *);
	void (*dismiss)(struct device___46 *);
};

struct bus_type___46 {
	const char *name;
	const char *dev_name;
	struct device___46 *dev_root;
	const struct attribute_group___52 **bus_groups;
	const struct attribute_group___52 **dev_groups;
	const struct attribute_group___52 **drv_groups;
	int (*match)(struct device___46 *, struct device_driver___46 *);
	int (*uevent)(struct device___46 *, struct kobj_uevent_env *);
	int (*probe)(struct device___46 *);
	void (*sync_state)(struct device___46 *);
	void (*remove)(struct device___46 *);
	void (*shutdown)(struct device___46 *);
	int (*online)(struct device___46 *);
	int (*offline)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	int (*num_vf)(struct device___46 *);
	int (*dma_configure)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___46 {
	const char *name;
	struct bus_type___46 *bus;
	struct module___51 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___46 *);
	void (*sync_state)(struct device___46 *);
	int (*remove)(struct device___46 *);
	void (*shutdown)(struct device___46 *);
	int (*suspend)(struct device___46 *, pm_message_t);
	int (*resume)(struct device___46 *);
	const struct attribute_group___52 **groups;
	const struct attribute_group___52 **dev_groups;
	const struct dev_pm_ops___46 *pm;
	void (*coredump)(struct device___46 *);
	struct driver_private *p;
};

struct device_type___46 {
	const char *name;
	const struct attribute_group___52 **groups;
	int (*uevent)(struct device___46 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___46 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___46 *);
	const struct dev_pm_ops___46 *pm;
};

struct class___46 {
	const char *name;
	struct module___51 *owner;
	const struct attribute_group___52 **class_groups;
	const struct attribute_group___52 **dev_groups;
	struct kobject___52 *dev_kobj;
	int (*dev_uevent)(struct device___46 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___46 *, umode_t *);
	void (*class_release)(struct class___46 *);
	void (*dev_release)(struct device___46 *);
	int (*shutdown_pre)(struct device___46 *);
	const struct kobj_ns_type_operations___4 *ns_type;
	const void * (*namespace)(struct device___46 *);
	void (*get_ownership)(struct device___46 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___46 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___46;

struct fwnode_handle___46 {
	struct fwnode_handle___46 *secondary;
	const struct fwnode_operations___46 *ops;
	struct device___46 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___46;

struct fwnode_endpoint___46;

struct fwnode_operations___46 {
	struct fwnode_handle___46 * (*get)(struct fwnode_handle___46 *);
	void (*put)(struct fwnode_handle___46 *);
	bool (*device_is_available)(const struct fwnode_handle___46 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___46 *, const struct device___46 *);
	bool (*property_present)(const struct fwnode_handle___46 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___46 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___46 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___46 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*get_parent)(const struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*get_next_child_node)(const struct fwnode_handle___46 *, struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*get_named_child_node)(const struct fwnode_handle___46 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___46 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___46 *);
	struct fwnode_handle___46 * (*graph_get_next_endpoint)(const struct fwnode_handle___46 *, struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*graph_get_remote_endpoint)(const struct fwnode_handle___46 *);
	struct fwnode_handle___46 * (*graph_get_port_parent)(struct fwnode_handle___46 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___46 *, struct fwnode_endpoint___46 *);
	int (*add_links)(struct fwnode_handle___46 *);
};

struct fwnode_endpoint___46 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___46 *local_fwnode;
};

struct fwnode_reference_args___46 {
	struct fwnode_handle___46 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___49 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___49 *);
	int (*get)(char *, const struct kernel_param___49 *);
	void (*free)(void *);
};

struct kparam_array___49;

struct kernel_param___49 {
	const char *name;
	struct module___51 *mod;
	const struct kernel_param_ops___49 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___49 *arr;
	};
};

struct kparam_array___49 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___49 *ops;
	void *elem;
};

struct module_attribute___49 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___49 *, struct module_kobject___49 *, char *);
	ssize_t (*store)(struct module_attribute___49 *, struct module_kobject___49 *, const char *, size_t);
	void (*setup)(struct module___51 *, const char *);
	int (*test)(struct module___51 *);
	void (*free)(struct module___51 *);
};

struct trace_event_class___29;

struct trace_event_call___29 {
	struct list_head list;
	struct trace_event_class___29 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___5 *prog_array;
	int (*perf_perm)(struct trace_event_call___29 *, struct perf_event___34 *);
};

struct cftype___42;

struct cgroup_subsys___42 {
	struct cgroup_subsys_state___42 * (*css_alloc)(struct cgroup_subsys_state___42 *);
	int (*css_online)(struct cgroup_subsys_state___42 *);
	void (*css_offline)(struct cgroup_subsys_state___42 *);
	void (*css_released)(struct cgroup_subsys_state___42 *);
	void (*css_free)(struct cgroup_subsys_state___42 *);
	void (*css_reset)(struct cgroup_subsys_state___42 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___42 *, int);
	int (*css_extra_stat_show)(struct seq_file___50 *, struct cgroup_subsys_state___42 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___57 *, struct css_set___42 *);
	void (*cancel_fork)(struct task_struct___57 *, struct css_set___42 *);
	void (*fork)(struct task_struct___57 *);
	void (*exit)(struct task_struct___57 *);
	void (*release)(struct task_struct___57 *);
	void (*bind)(struct cgroup_subsys_state___42 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___42 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___42 *dfl_cftypes;
	struct cftype___42 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___42 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___42 *updated_children;
	struct cgroup___42 *updated_next;
};

struct cgroup_root___42 {
	struct kernfs_root___52 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___42 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___42 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___42 *ss;
	struct list_head node;
	struct kernfs_ops___52 *kf_ops;
	int (*open)(struct kernfs_open_file___52 *);
	void (*release)(struct kernfs_open_file___52 *);
	u64 (*read_u64)(struct cgroup_subsys_state___42 *, struct cftype___42 *);
	s64 (*read_s64)(struct cgroup_subsys_state___42 *, struct cftype___42 *);
	int (*seq_show)(struct seq_file___50 *, void *);
	void * (*seq_start)(struct seq_file___50 *, loff_t *);
	void * (*seq_next)(struct seq_file___50 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___50 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___42 *, struct cftype___42 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___42 *, struct cftype___42 *, s64);
	ssize_t (*write)(struct kernfs_open_file___52 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___52 *, struct poll_table_struct___37 *);
};

struct perf_cpu_context___34;

struct perf_output_handle___34;

struct pmu___34 {
	struct list_head entry;
	struct module___51 *module;
	struct device___46 *dev;
	const struct attribute_group___52 **attr_groups;
	const struct attribute_group___52 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___34 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___34 *);
	void (*pmu_disable)(struct pmu___34 *);
	int (*event_init)(struct perf_event___34 *);
	void (*event_mapped)(struct perf_event___34 *, struct mm_struct___57 *);
	void (*event_unmapped)(struct perf_event___34 *, struct mm_struct___57 *);
	int (*add)(struct perf_event___34 *, int);
	void (*del)(struct perf_event___34 *, int);
	void (*start)(struct perf_event___34 *, int);
	void (*stop)(struct perf_event___34 *, int);
	void (*read)(struct perf_event___34 *);
	void (*start_txn)(struct pmu___34 *, unsigned int);
	int (*commit_txn)(struct pmu___34 *);
	void (*cancel_txn)(struct pmu___34 *);
	int (*event_idx)(struct perf_event___34 *);
	void (*sched_task)(struct perf_event_context___34 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___34 *, struct perf_event_context___34 *);
	void * (*setup_aux)(struct perf_event___34 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___34 *, struct perf_output_handle___34 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___34 *);
	int (*aux_output_match)(struct perf_event___34 *);
	int (*filter_match)(struct perf_event___34 *);
	int (*check_period)(struct perf_event___34 *, u64);
};

struct perf_cpu_context___34 {
	struct perf_event_context___34 ctx;
	struct perf_event_context___34 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___34 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___34 **heap;
	struct perf_event___34 *heap_default[2];
};

struct perf_output_handle___34 {
	struct perf_event___34 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___34 {
	struct cgroup_subsys_state___42 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___29 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___29 *);
	};
};

struct trace_event_class___29 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___29 *, enum trace_reg, void *);
	struct trace_event_fields___29 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___29 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___29 *);
};

struct cpu_stop_done {
	atomic_t nr_todo;
	int ret;
	struct completion completion;
};

struct smp_hotplug_thread___5 {
	struct task_struct___8 **store;
	struct list_head list;
	int (*thread_should_run)(unsigned int);
	void (*thread_fn)(unsigned int);
	void (*create)(unsigned int);
	void (*setup)(unsigned int);
	void (*cleanup)(unsigned int, bool);
	void (*park)(unsigned int);
	void (*unpark)(unsigned int);
	bool selfparking;
	const char *thread_comm;
};

struct cpu_stopper {
	struct task_struct___8 *thread;
	raw_spinlock_t lock;
	bool enabled;
	struct list_head works;
	struct cpu_stop_work stop_work;
	long unsigned int caller;
	cpu_stop_fn_t fn;
};

enum multi_stop_state {
	MULTI_STOP_NONE = 0,
	MULTI_STOP_PREPARE = 1,
	MULTI_STOP_DISABLE_IRQ = 2,
	MULTI_STOP_RUN = 3,
	MULTI_STOP_EXIT = 4,
};

struct multi_stop_data {
	cpu_stop_fn_t fn;
	void *data;
	unsigned int num_threads;
	const struct cpumask *active_cpus;
	enum multi_stop_state state;
	atomic_t thread_ack;
};

typedef int __kernel_mqd_t;

typedef __kernel_mqd_t mqd_t;

struct vfsmount___52;

struct dentry___53;

struct path___52 {
	struct vfsmount___52 *mnt;
	struct dentry___53 *dentry;
};

struct pid___47;

struct fown_struct___47 {
	rwlock_t lock;
	struct pid___47 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___53;

struct file_operations___52;

struct address_space___52;

struct file___53 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___52 f_path;
	struct inode___53 *f_inode;
	const struct file_operations___52 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___47 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___52 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct super_block___53;

struct module___52;

struct file_system_type___52 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___53 * (*mount)(struct file_system_type___52 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___53 *);
	struct module___52 *owner;
	struct file_system_type___52 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___52;

struct iov_iter___27;

struct poll_table_struct___38;

struct vm_area_struct___57;

struct file_lock___52;

struct page___57;

struct pipe_inode_info___15;

struct seq_file___51;

struct file_operations___52 {
	struct module___52 *owner;
	loff_t (*llseek)(struct file___53 *, loff_t, int);
	ssize_t (*read)(struct file___53 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___53 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___52 *, struct iov_iter___27 *);
	ssize_t (*write_iter)(struct kiocb___52 *, struct iov_iter___27 *);
	int (*iopoll)(struct kiocb___52 *, bool);
	int (*iterate)(struct file___53 *, struct dir_context *);
	int (*iterate_shared)(struct file___53 *, struct dir_context *);
	__poll_t (*poll)(struct file___53 *, struct poll_table_struct___38 *);
	long int (*unlocked_ioctl)(struct file___53 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___53 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___53 *, struct vm_area_struct___57 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___53 *, struct file___53 *);
	int (*flush)(struct file___53 *, fl_owner_t);
	int (*release)(struct inode___53 *, struct file___53 *);
	int (*fsync)(struct file___53 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___53 *, int);
	int (*lock)(struct file___53 *, int, struct file_lock___52 *);
	ssize_t (*sendpage)(struct file___53 *, struct page___57 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___53 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___53 *, long unsigned int);
	int (*flock)(struct file___53 *, int, struct file_lock___52 *);
	ssize_t (*splice_write)(struct pipe_inode_info___15 *, struct file___53 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___53 *, loff_t *, struct pipe_inode_info___15 *, size_t, unsigned int);
	int (*setlease)(struct file___53 *, long int, struct file_lock___52 **, void **);
	long int (*fallocate)(struct file___53 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___51 *, struct file___53 *);
	ssize_t (*copy_file_range)(struct file___53 *, loff_t, struct file___53 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___53 *, loff_t, struct file___53 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___53 *, loff_t, loff_t, int);
};

struct vmacache___57 {
	u64 seqnum;
	struct vm_area_struct___57 *vmas[4];
};

struct page_frag___57 {
	struct page___57 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___35;

struct debug_info___35 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___35 *hbp_break[16];
	struct perf_event___35 *hbp_watch[16];
};

struct thread_struct___35 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___35 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___58;

struct nsproxy___52;

struct signal_struct___53;

struct audit_context___2;

struct bio_list___24;

struct backing_dev_info___23;

struct io_context___25;

struct css_set___43;

struct perf_event_context___35;

struct mem_cgroup___22;

struct request_queue___25;

struct vm_struct___54;

struct task_struct___58 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___58 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___58 *mm;
	struct mm_struct___58 *active_mm;
	struct vmacache___57 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___58 *real_parent;
	struct task_struct___58 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___58 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___47 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___52 *nsproxy;
	struct signal_struct___53 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context___2 *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___58 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___24 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___23 *backing_dev_info;
	struct io_context___25 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___43 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___35 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___15 *splice_pipe;
	struct page_frag___57 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___22 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___22 *active_memcg;
	struct request_queue___25 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___58 *oom_reaper_list;
	struct vm_struct___54 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___35 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___53;

struct kobj_type___53;

struct kernfs_node___53;

struct kobject___53 {
	const char *name;
	struct list_head entry;
	struct kobject___53 *parent;
	struct kset___53 *kset;
	struct kobj_type___53 *ktype;
	struct kernfs_node___53 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___50 {
	struct kobject___53 kobj;
	struct module___52 *mod;
	struct kobject___53 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___50 {
	struct module___52 *mod;
	struct latch_tree_node node;
};

struct module_layout___50 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___50 mtn;
};

struct module_attribute___50;

struct kernel_param___50;

struct trace_event_call___30;

struct module___52 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___50 mkobj;
	struct module_attribute___50 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___53 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___50 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___50 core_layout;
	struct module_layout___50 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___30 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___35 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___58 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___35)(struct perf_event___35 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___35;

struct fasync_struct___52;

struct pid_namespace___47;

struct bpf_prog___6;

struct perf_cgroup___35;

struct perf_event___35 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___35 *group_leader;
	struct pmu___35 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___35 hw;
	struct perf_event_context___35 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___35 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___58 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___52 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___35 *aux_event;
	void (*destroy)(struct perf_event___35 *);
	struct callback_head callback_head;
	struct pid_namespace___47 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___35 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___35 orig_overflow_handler;
	struct bpf_prog___6 *prog;
	u64 bpf_cookie;
	struct trace_event_call___30 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___35 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___57 *pgtable_t___57;

struct page_pool___14;

struct dev_pagemap___51;

struct page___57 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___52 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___14 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___57 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___57 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___58 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___51 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___51;

struct vm_area_struct___57 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___57 *vm_next;
	struct vm_area_struct___57 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___58 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___51 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___53 *vm_file;
	struct file___53 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___57;

struct mm_struct___58 {
	struct {
		struct vm_area_struct___57 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___53 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___57 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___58 *owner;
		struct user_namespace___10 *user_ns;
		struct file___53 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___52;

struct address_space___52 {
	struct inode___53 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___52 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___47;

struct page_pool_params___14 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___47 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___14 {
	u32 count;
	struct page___57 *cache[128];
};

struct page_pool___14 {
	struct page_pool_params___14 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___57 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___14 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___51;

struct dev_pagemap___51 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___51 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___51;

struct vm_operations_struct___51 {
	void (*open)(struct vm_area_struct___57 *);
	void (*close)(struct vm_area_struct___57 *);
	int (*may_split)(struct vm_area_struct___57 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___57 *);
	int (*mprotect)(struct vm_area_struct___57 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___51 *);
	vm_fault_t (*huge_fault)(struct vm_fault___51 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___51 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___57 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___51 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___51 *);
	int (*access)(struct vm_area_struct___57 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___57 *);
	int (*set_policy)(struct vm_area_struct___57 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___57 *, long unsigned int);
	struct page___57 * (*find_special_page)(struct vm_area_struct___57 *, long unsigned int);
};

struct core_thread___57 {
	struct task_struct___58 *task;
	struct core_thread___57 *next;
};

struct core_state___57 {
	atomic_t nr_threads;
	struct core_thread___57 dumper;
	struct completion startup;
};

struct vm_fault___51 {
	const struct {
		struct vm_area_struct___57 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___57 *cow_page;
	struct page___57 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___57 prealloc_pte;
};

struct pglist_data___23;

struct lruvec___23 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___23 *pgdat;
};

struct zone___23 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___23 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___23 {
	struct zone___23 *zone;
	int zone_idx;
};

struct zonelist___23 {
	struct zoneref___23 _zonerefs[321];
};

struct pglist_data___23 {
	struct zone___23 node_zones[5];
	struct zonelist___23 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___58 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___58 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___23 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___22 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___22 *memcg;
};

struct cgroup___43;

struct cgroup_subsys___43;

struct cgroup_subsys_state___43 {
	struct cgroup___43 *cgroup;
	struct cgroup_subsys___43 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___43 *parent;
};

struct cgroup_file___43 {
	struct kernfs_node___53 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___22;

struct mem_cgroup_per_node___22;

struct mem_cgroup___22 {
	struct cgroup_subsys_state___43 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___43 events_file;
	struct cgroup_file___43 events_local_file;
	struct cgroup_file___43 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___22 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___58 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___22 *nodeinfo[0];
	long: 64;
};

struct shrinker___22 {
	long unsigned int (*count_objects)(struct shrinker___22 *, struct shrink_control___22 *);
	long unsigned int (*scan_objects)(struct shrinker___22 *, struct shrink_control___22 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___51 {
	void (*page_free)(struct page___57 *);
	void (*kill)(struct dev_pagemap___51 *);
	void (*cleanup)(struct dev_pagemap___51 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___51 *);
};

struct upid___47 {
	int nr;
	struct pid_namespace___47 *ns;
};

struct pid_namespace___47 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___58 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___47 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___47 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___47 numbers[1];
};

struct tty_struct___8;

struct signal_struct___53 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___58 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___58 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___47 *pids[4];
	struct pid___47 *tty_old_pgrp;
	int leader;
	struct tty_struct___8 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___58 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___9;

struct cgroup_namespace___43;

struct nsproxy___52 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___47 *pid_ns_for_children;
	struct net___9 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___43 *cgroup_ns;
};

enum audit_state {
	AUDIT_STATE_DISABLED = 0,
	AUDIT_STATE_BUILD = 1,
	AUDIT_STATE_RECORD = 2,
};

struct audit_cap_data {
	kernel_cap_t permitted;
	kernel_cap_t inheritable;
	union {
		unsigned int fE;
		kernel_cap_t effective;
	};
	kernel_cap_t ambient;
	kuid_t rootid;
};

struct audit_names {
	struct list_head list;
	struct filename *name;
	int name_len;
	bool hidden;
	long unsigned int ino;
	dev_t dev;
	umode_t mode;
	kuid_t uid;
	kgid_t gid;
	dev_t rdev;
	struct lsmblob oblob;
	struct audit_cap_data fcap;
	unsigned int fcap_ver;
	unsigned char type;
	bool should_free;
};

struct mq_attr {
	__kernel_long_t mq_flags;
	__kernel_long_t mq_maxmsg;
	__kernel_long_t mq_msgsize;
	__kernel_long_t mq_curmsgs;
	__kernel_long_t __reserved[4];
};

struct audit_proctitle {
	int len;
	char *value;
};

struct audit_aux_data;

struct __kernel_sockaddr_storage;

struct audit_tree_refs;

struct audit_context___2 {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___52 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	struct lsmblob target_lsm;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			struct lsmblob oblob;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
		struct {
			struct audit_ntp_data ntp_data;
			struct timespec64 tk_injoffset;
		} time;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct bio___24;

struct bio_list___24 {
	struct bio___24 *head;
	struct bio___24 *tail;
};

struct bdi_writeback___23 {
	struct backing_dev_info___23 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___43 *memcg_css;
	struct cgroup_subsys_state___43 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___23 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___23 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___47 *dev;
	char dev_name[64];
	struct device___47 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___53 *debug_dir;
};

struct io_cq___24;

struct io_context___25 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___24 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___43 {
	struct cgroup_subsys_state___43 *subsys[14];
	refcount_t refcount;
	struct css_set___43 *dom_cset;
	struct cgroup___43 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___43 *mg_src_cgrp;
	struct cgroup___43 *mg_dst_cgrp;
	struct css_set___43 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___35 {
	struct pmu___35 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___58 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___35 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___15;

struct pipe_inode_info___15 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___57 *tmp_page;
	struct fasync_struct___52 *fasync_readers;
	struct fasync_struct___52 *fasync_writers;
	struct pipe_buffer___15 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___24;

struct blk_integrity___24 {
	const struct blk_integrity_profile___24 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___24 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___24 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___24;

struct elevator_queue___24;

struct blk_mq_ops___23;

struct blk_mq_hw_ctx___23;

struct gendisk___24;

struct blkcg_gq___23;

struct blk_mq_tag_set___23;

struct request_queue___25 {
	struct request___24 *last_merge;
	struct elevator_queue___24 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___23 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___23 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___24 *disk;
	struct kobject___53 kobj;
	struct kobject___53 *mq_kobj;
	struct blk_integrity___24 integrity;
	struct device___47 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___23 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___23 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___24 bio_split;
	struct dentry___53 *debugfs_dir;
	struct dentry___53 *sched_debugfs_dir;
	struct dentry___53 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___54 {
	struct vm_struct___54 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___57 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___52;

struct dentry___53 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___53 *d_parent;
	struct qstr d_name;
	struct inode___53 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___52 *d_op;
	struct super_block___53 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___52;

struct cdev___18;

struct inode___53 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___52 *i_op;
	struct super_block___53 *i_sb;
	struct address_space___52 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___23 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___52 *i_fop;
		void (*free_inode)(struct inode___53 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___52 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___15 *i_pipe;
		struct cdev___18 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___52 {
	int (*d_revalidate)(struct dentry___53 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___53 *, unsigned int);
	int (*d_hash)(const struct dentry___53 *, struct qstr *);
	int (*d_compare)(const struct dentry___53 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___53 *);
	int (*d_init)(struct dentry___53 *);
	void (*d_release)(struct dentry___53 *);
	void (*d_prune)(struct dentry___53 *);
	void (*d_iput)(struct dentry___53 *, struct inode___53 *);
	char * (*d_dname)(struct dentry___53 *, char *, int);
	struct vfsmount___52 * (*d_automount)(struct path___52 *);
	int (*d_manage)(const struct path___52 *, bool);
	struct dentry___53 * (*d_real)(struct dentry___53 *, const struct inode___53 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___52;

struct mem_dqinfo___52 {
	struct quota_format_type___52 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___52;

struct quota_info___52 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___53 *files[3];
	struct mem_dqinfo___52 info[3];
	const struct quota_format_ops___52 *ops[3];
};

struct rcuwait___53 {
	struct task_struct___58 *task;
};

struct percpu_rw_semaphore___53 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___53 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___52 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___53 rw_sem[3];
};

struct super_operations___52;

struct dquot_operations___52;

struct quotactl_ops___52;

struct block_device___25;

struct super_block___53 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___52 *s_type;
	const struct super_operations___52 *s_op;
	const struct dquot_operations___52 *dq_op;
	const struct quotactl_ops___52 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___53 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___25 *s_bdev;
	struct backing_dev_info___23 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___52 s_dquot;
	struct sb_writers___52 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___52 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___52 {
	struct dentry___53 *mnt_root;
	struct super_block___53 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct psi_group___43 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___58 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___6;

struct cgroup_bpf___6 {
	struct bpf_prog_array___6 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___6 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___43;

struct cgroup_rstat_cpu___43;

struct cgroup___43 {
	struct cgroup_subsys_state___43 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___53 *kn;
	struct cgroup_file___43 procs_file;
	struct cgroup_file___43 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___43 *subsys[14];
	struct cgroup_root___43 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___43 *dom_cgrp;
	struct cgroup___43 *old_dom_cgrp;
	struct cgroup_rstat_cpu___43 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___43 psi;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___8;

struct tty_operations___8;

struct tty_ldisc___8;

struct tty_port___8;

struct tty_struct___8 {
	int magic;
	struct kref kref;
	struct device___47 *dev;
	struct tty_driver___8 *driver;
	const struct tty_operations___8 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___8 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___47 *pgrp;
		struct pid___47 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___8 *link;
	struct fasync_struct___52 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___8 *port;
};

struct io_cq___24 {
	struct request_queue___25 *q;
	struct io_context___25 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___52 {
	struct file___53 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___52 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___53 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___53 *ia_file;
};

struct dquot___52 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___53 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___52 {
	int qf_fmt_id;
	const struct quota_format_ops___52 *qf_ops;
	struct module___52 *qf_owner;
	struct quota_format_type___52 *qf_next;
};

struct quota_format_ops___52 {
	int (*check_quota_file)(struct super_block___53 *, int);
	int (*read_file_info)(struct super_block___53 *, int);
	int (*write_file_info)(struct super_block___53 *, int);
	int (*free_file_info)(struct super_block___53 *, int);
	int (*read_dqblk)(struct dquot___52 *);
	int (*commit_dqblk)(struct dquot___52 *);
	int (*release_dqblk)(struct dquot___52 *);
	int (*get_next_id)(struct super_block___53 *, struct kqid *);
};

struct dquot_operations___52 {
	int (*write_dquot)(struct dquot___52 *);
	struct dquot___52 * (*alloc_dquot)(struct super_block___53 *, int);
	void (*destroy_dquot)(struct dquot___52 *);
	int (*acquire_dquot)(struct dquot___52 *);
	int (*release_dquot)(struct dquot___52 *);
	int (*mark_dirty)(struct dquot___52 *);
	int (*write_info)(struct super_block___53 *, int);
	qsize_t * (*get_reserved_space)(struct inode___53 *);
	int (*get_projid)(struct inode___53 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___53 *, qsize_t *);
	int (*get_next_id)(struct super_block___53 *, struct kqid *);
};

struct quotactl_ops___52 {
	int (*quota_on)(struct super_block___53 *, int, int, const struct path___52 *);
	int (*quota_off)(struct super_block___53 *, int);
	int (*quota_enable)(struct super_block___53 *, unsigned int);
	int (*quota_disable)(struct super_block___53 *, unsigned int);
	int (*quota_sync)(struct super_block___53 *, int);
	int (*set_info)(struct super_block___53 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___53 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___53 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___53 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___53 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___53 *, unsigned int);
};

struct writeback_control___23;

struct address_space_operations___52 {
	int (*writepage)(struct page___57 *, struct writeback_control___23 *);
	int (*readpage)(struct file___53 *, struct page___57 *);
	int (*writepages)(struct address_space___52 *, struct writeback_control___23 *);
	int (*set_page_dirty)(struct page___57 *);
	int (*readpages)(struct file___53 *, struct address_space___52 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___53 *, struct address_space___52 *, loff_t, unsigned int, unsigned int, struct page___57 **, void **);
	int (*write_end)(struct file___53 *, struct address_space___52 *, loff_t, unsigned int, unsigned int, struct page___57 *, void *);
	sector_t (*bmap)(struct address_space___52 *, sector_t);
	void (*invalidatepage)(struct page___57 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___57 *, gfp_t);
	void (*freepage)(struct page___57 *);
	ssize_t (*direct_IO)(struct kiocb___52 *, struct iov_iter___27 *);
	int (*migratepage)(struct address_space___52 *, struct page___57 *, struct page___57 *, enum migrate_mode);
	bool (*isolate_page)(struct page___57 *, isolate_mode_t);
	void (*putback_page)(struct page___57 *);
	int (*launder_page)(struct page___57 *);
	int (*is_partially_uptodate)(struct page___57 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___57 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___52 *, struct page___57 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___53 *, sector_t *);
	void (*swap_deactivate)(struct file___53 *);
};

struct writeback_control___23 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___23 *wb;
	struct inode___53 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___27;

struct iov_iter___27 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___27 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___15 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___18 {
	struct kobject___53 kobj;
	struct module___52 *owner;
	const struct file_operations___52 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___52 {
	struct dentry___53 * (*lookup)(struct inode___53 *, struct dentry___53 *, unsigned int);
	const char * (*get_link)(struct dentry___53 *, struct inode___53 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___53 *, int);
	struct posix_acl * (*get_acl)(struct inode___53 *, int, bool);
	int (*readlink)(struct dentry___53 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___53 *, struct dentry___53 *, umode_t, bool);
	int (*link)(struct dentry___53 *, struct inode___53 *, struct dentry___53 *);
	int (*unlink)(struct inode___53 *, struct dentry___53 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___53 *, struct dentry___53 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___53 *, struct dentry___53 *, umode_t);
	int (*rmdir)(struct inode___53 *, struct dentry___53 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___53 *, struct dentry___53 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___53 *, struct dentry___53 *, struct inode___53 *, struct dentry___53 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___53 *, struct iattr___53 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___52 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___53 *, char *, size_t);
	int (*fiemap)(struct inode___53 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___53 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___53 *, struct dentry___53 *, struct file___53 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___53 *, struct dentry___53 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___53 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___53 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___53 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___52 {
	void (*fl_copy_lock)(struct file_lock___52 *, struct file_lock___52 *);
	void (*fl_release_private)(struct file_lock___52 *);
};

struct lock_manager_operations___52;

struct file_lock___52 {
	struct file_lock___52 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___53 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___52 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___52 *fl_ops;
	const struct lock_manager_operations___52 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___52 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___52 *);
	int (*lm_grant)(struct file_lock___52 *, int);
	bool (*lm_break)(struct file_lock___52 *);
	int (*lm_change)(struct file_lock___52 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___52 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___52 *);
};

struct fasync_struct___52 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___52 *fa_next;
	struct file___53 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___52 {
	struct inode___53 * (*alloc_inode)(struct super_block___53 *);
	void (*destroy_inode)(struct inode___53 *);
	void (*free_inode)(struct inode___53 *);
	void (*dirty_inode)(struct inode___53 *, int);
	int (*write_inode)(struct inode___53 *, struct writeback_control___23 *);
	int (*drop_inode)(struct inode___53 *);
	void (*evict_inode)(struct inode___53 *);
	void (*put_super)(struct super_block___53 *);
	int (*sync_fs)(struct super_block___53 *, int);
	int (*freeze_super)(struct super_block___53 *);
	int (*freeze_fs)(struct super_block___53 *);
	int (*thaw_super)(struct super_block___53 *);
	int (*unfreeze_fs)(struct super_block___53 *);
	int (*statfs)(struct dentry___53 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___53 *, int *, char *);
	void (*umount_begin)(struct super_block___53 *);
	int (*show_options)(struct seq_file___51 *, struct dentry___53 *);
	int (*show_devname)(struct seq_file___51 *, struct dentry___53 *);
	int (*show_path)(struct seq_file___51 *, struct dentry___53 *);
	int (*show_stats)(struct seq_file___51 *, struct dentry___53 *);
	ssize_t (*quota_read)(struct super_block___53 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___53 *, int, const char *, size_t, loff_t);
	struct dquot___52 ** (*get_dquots)(struct inode___53 *);
	long int (*nr_cached_objects)(struct super_block___53 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___53 *, struct shrink_control___22 *);
	struct file___53 * (*real_loop)(struct file___53 *);
};

struct wakeup_source___47;

struct dev_pm_info___47 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___47 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___47 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___47;

struct bus_type___47;

struct device_driver___47;

struct dev_pm_domain___47;

struct fwnode_handle___47;

struct class___47;

struct attribute_group___53;

struct device___47 {
	struct kobject___53 kobj;
	struct device___47 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___47 *type;
	struct bus_type___47 *bus;
	struct device_driver___47 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___47 power;
	struct dev_pm_domain___47 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___47 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___47 *class;
	const struct attribute_group___53 **groups;
	void (*release)(struct device___47 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___25 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___53 *bd_inode;
	struct super_block___53 *bd_super;
	void *bd_claiming;
	struct device___47 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___53 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___24 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___53 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___38)(struct file___53 *, wait_queue_head_t *, struct poll_table_struct___38 *);

struct poll_table_struct___38 {
	poll_queue_proc___38 _qproc;
	__poll_t _key;
};

struct seq_operations___51;

struct seq_file___51 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___51 *op;
	int poll_event;
	const struct file___53 *file;
	void *private;
};

typedef void bio_end_io_t___24(struct bio___24 *);

struct bio_vec___27 {
	struct page___57 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___24;

struct bio___24 {
	struct bio___24 *bi_next;
	struct block_device___25 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___24 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___23 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___24 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___27 *bi_io_vec;
	struct bio_set___24 *bi_pool;
	struct bio_vec___27 bi_inline_vecs[0];
};

struct kernfs_root___53;

struct kernfs_elem_dir___53 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___53 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___53;

struct kernfs_root___53 {
	struct kernfs_node___53 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___53 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___53 {
	struct kernfs_node___53 *target_kn;
};

struct kernfs_ops___53;

struct kernfs_elem_attr___53 {
	const struct kernfs_ops___53 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___53 *notify_next;
};

struct kernfs_node___53 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___53 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___53 dir;
		struct kernfs_elem_symlink___53 symlink;
		struct kernfs_elem_attr___53 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___53;

struct kernfs_ops___53 {
	int (*open)(struct kernfs_open_file___53 *);
	void (*release)(struct kernfs_open_file___53 *);
	int (*seq_show)(struct seq_file___51 *, void *);
	void * (*seq_start)(struct seq_file___51 *, loff_t *);
	void * (*seq_next)(struct seq_file___51 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___51 *, void *);
	ssize_t (*read)(struct kernfs_open_file___53 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___53 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___53 *, struct poll_table_struct___38 *);
	int (*mmap)(struct kernfs_open_file___53 *, struct vm_area_struct___57 *);
};

struct kernfs_syscall_ops___53 {
	int (*show_options)(struct seq_file___51 *, struct kernfs_root___53 *);
	int (*mkdir)(struct kernfs_node___53 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___53 *);
	int (*rename)(struct kernfs_node___53 *, struct kernfs_node___53 *, const char *);
	int (*show_path)(struct seq_file___51 *, struct kernfs_node___53 *, struct kernfs_root___53 *);
};

struct kernfs_open_file___53 {
	struct kernfs_node___53 *kn;
	struct file___53 *file;
	struct seq_file___51 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___51 *vm_ops;
};

struct sock___7;

struct kobj_ns_type_operations___5 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___7 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___9 *net;
} possible_net_t___6;

struct proto___5;

struct sock_common___5 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___5 *skc_prot;
	possible_net_t___6 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___7 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___8;

struct sk_buff_head___6 {
	struct sk_buff___8 *next;
	struct sk_buff___8 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___5 {
	struct cgroup___43 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___5;

struct socket_wq___5;

struct dst_entry___5;

struct socket___5;

struct net_device___11;

struct sock___7 {
	struct sock_common___5 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___6 sk_error_queue;
	struct sk_buff___8 *sk_rx_skb_cache;
	struct sk_buff_head___6 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___8 *head;
		struct sk_buff___8 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___5 *sk_filter;
	union {
		struct socket_wq___5 *sk_wq;
		struct socket_wq___5 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___5 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___5 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___8 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___8 *sk_tx_skb_cache;
	struct sk_buff_head___6 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___57 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___5 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___47 *sk_peer_pid;
	const struct cred___9 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___5 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___5 sk_cgrp_data;
	struct mem_cgroup___22 *sk_memcg;
	void (*sk_state_change)(struct sock___7 *);
	void (*sk_data_ready)(struct sock___7 *);
	void (*sk_write_space)(struct sock___7 *);
	void (*sk_error_report)(struct sock___7 *);
	int (*sk_backlog_rcv)(struct sock___7 *, struct sk_buff___8 *);
	struct sk_buff___8 * (*sk_validate_xmit_skb)(struct sock___7 *, struct net_device___11 *, struct sk_buff___8 *);
	void (*sk_destruct)(struct sock___7 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___53;

struct attribute_group___53 {
	const char *name;
	umode_t (*is_visible)(struct kobject___53 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___53 *, struct bin_attribute___53 *, int);
	struct attribute **attrs;
	struct bin_attribute___53 **bin_attrs;
};

struct bin_attribute___53 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___52 * (*f_mapping)();
	ssize_t (*read)(struct file___53 *, struct kobject___53 *, struct bin_attribute___53 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___53 *, struct kobject___53 *, struct bin_attribute___53 *, char *, loff_t, size_t);
	int (*mmap)(struct file___53 *, struct kobject___53 *, struct bin_attribute___53 *, struct vm_area_struct___57 *);
};

struct sysfs_ops___53 {
	ssize_t (*show)(struct kobject___53 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___53 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___53;

struct kset___53 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___53 kobj;
	const struct kset_uevent_ops___53 *uevent_ops;
};

struct kobj_type___53 {
	void (*release)(struct kobject___53 *);
	const struct sysfs_ops___53 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___53 **default_groups;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___53 *);
	const void * (*namespace)(struct kobject___53 *);
	void (*get_ownership)(struct kobject___53 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___53 {
	int (* const filter)(struct kset___53 *, struct kobject___53 *);
	const char * (* const name)(struct kset___53 *, struct kobject___53 *);
	int (* const uevent)(struct kset___53 *, struct kobject___53 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___47 {
	int (*prepare)(struct device___47 *);
	void (*complete)(struct device___47 *);
	int (*suspend)(struct device___47 *);
	int (*resume)(struct device___47 *);
	int (*freeze)(struct device___47 *);
	int (*thaw)(struct device___47 *);
	int (*poweroff)(struct device___47 *);
	int (*restore)(struct device___47 *);
	int (*suspend_late)(struct device___47 *);
	int (*resume_early)(struct device___47 *);
	int (*freeze_late)(struct device___47 *);
	int (*thaw_early)(struct device___47 *);
	int (*poweroff_late)(struct device___47 *);
	int (*restore_early)(struct device___47 *);
	int (*suspend_noirq)(struct device___47 *);
	int (*resume_noirq)(struct device___47 *);
	int (*freeze_noirq)(struct device___47 *);
	int (*thaw_noirq)(struct device___47 *);
	int (*poweroff_noirq)(struct device___47 *);
	int (*restore_noirq)(struct device___47 *);
	int (*runtime_suspend)(struct device___47 *);
	int (*runtime_resume)(struct device___47 *);
	int (*runtime_idle)(struct device___47 *);
};

struct wakeup_source___47 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___47 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___47 {
	struct dev_pm_ops___47 ops;
	int (*start)(struct device___47 *);
	void (*detach)(struct device___47 *, bool);
	int (*activate)(struct device___47 *);
	void (*sync)(struct device___47 *);
	void (*dismiss)(struct device___47 *);
};

struct bus_type___47 {
	const char *name;
	const char *dev_name;
	struct device___47 *dev_root;
	const struct attribute_group___53 **bus_groups;
	const struct attribute_group___53 **dev_groups;
	const struct attribute_group___53 **drv_groups;
	int (*match)(struct device___47 *, struct device_driver___47 *);
	int (*uevent)(struct device___47 *, struct kobj_uevent_env *);
	int (*probe)(struct device___47 *);
	void (*sync_state)(struct device___47 *);
	void (*remove)(struct device___47 *);
	void (*shutdown)(struct device___47 *);
	int (*online)(struct device___47 *);
	int (*offline)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	int (*num_vf)(struct device___47 *);
	int (*dma_configure)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___47 {
	const char *name;
	struct bus_type___47 *bus;
	struct module___52 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___47 *);
	void (*sync_state)(struct device___47 *);
	int (*remove)(struct device___47 *);
	void (*shutdown)(struct device___47 *);
	int (*suspend)(struct device___47 *, pm_message_t);
	int (*resume)(struct device___47 *);
	const struct attribute_group___53 **groups;
	const struct attribute_group___53 **dev_groups;
	const struct dev_pm_ops___47 *pm;
	void (*coredump)(struct device___47 *);
	struct driver_private *p;
};

struct device_type___47 {
	const char *name;
	const struct attribute_group___53 **groups;
	int (*uevent)(struct device___47 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___47 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___47 *);
	const struct dev_pm_ops___47 *pm;
};

struct class___47 {
	const char *name;
	struct module___52 *owner;
	const struct attribute_group___53 **class_groups;
	const struct attribute_group___53 **dev_groups;
	struct kobject___53 *dev_kobj;
	int (*dev_uevent)(struct device___47 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___47 *, umode_t *);
	void (*class_release)(struct class___47 *);
	void (*dev_release)(struct device___47 *);
	int (*shutdown_pre)(struct device___47 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___47 *);
	void (*get_ownership)(struct device___47 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___47 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___47;

struct fwnode_handle___47 {
	struct fwnode_handle___47 *secondary;
	const struct fwnode_operations___47 *ops;
	struct device___47 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___51 {
	void * (*start)(struct seq_file___51 *, loff_t *);
	void (*stop)(struct seq_file___51 *, void *);
	void * (*next)(struct seq_file___51 *, void *, loff_t *);
	int (*show)(struct seq_file___51 *, void *);
};

struct fwnode_reference_args___47;

struct fwnode_endpoint___47;

struct fwnode_operations___47 {
	struct fwnode_handle___47 * (*get)(struct fwnode_handle___47 *);
	void (*put)(struct fwnode_handle___47 *);
	bool (*device_is_available)(const struct fwnode_handle___47 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___47 *, const struct device___47 *);
	bool (*property_present)(const struct fwnode_handle___47 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___47 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___47 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___47 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*get_parent)(const struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*get_next_child_node)(const struct fwnode_handle___47 *, struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*get_named_child_node)(const struct fwnode_handle___47 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___47 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___47 *);
	struct fwnode_handle___47 * (*graph_get_next_endpoint)(const struct fwnode_handle___47 *, struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*graph_get_remote_endpoint)(const struct fwnode_handle___47 *);
	struct fwnode_handle___47 * (*graph_get_port_parent)(struct fwnode_handle___47 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___47 *, struct fwnode_endpoint___47 *);
	int (*add_links)(struct fwnode_handle___47 *);
};

struct fwnode_endpoint___47 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___47 *local_fwnode;
};

struct fwnode_reference_args___47 {
	struct fwnode_handle___47 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___5;

struct fqdir___8;

struct fib_notifier_ops___5;

struct netns_ipv4___8 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___5 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___7 *fibnl;
	struct sock___7 **icmp_sk;
	struct sock___7 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___7 **tcp_sk;
	struct fqdir___8 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___5 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___5 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___5 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___5;

struct dst_ops___8 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___8 *);
	struct dst_entry___5 * (*check)(struct dst_entry___5 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___5 *);
	unsigned int (*mtu)(const struct dst_entry___5 *);
	u32 * (*cow_metrics)(struct dst_entry___5 *, long unsigned int);
	void (*destroy)(struct dst_entry___5 *);
	void (*ifdown)(struct dst_entry___5 *, struct net_device___11 *, int);
	struct dst_entry___5 * (*negative_advice)(struct dst_entry___5 *);
	void (*link_failure)(struct sk_buff___8 *);
	void (*update_pmtu)(struct dst_entry___5 *, struct sock___7 *, struct sk_buff___8 *, u32, bool);
	void (*redirect)(struct dst_entry___5 *, struct sock___7 *, struct sk_buff___8 *);
	int (*local_out)(struct net___9 *, struct sock___7 *, struct sk_buff___8 *);
	struct neighbour___5 * (*neigh_lookup)(const struct dst_entry___5 *, struct sk_buff___8 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___5 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___8 {
	struct dst_ops___8 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___8 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___5 *fib6_rules_ops;
	struct sock___7 **icmp_sk;
	struct sock___7 *ndisc_sk;
	struct sock___7 *tcp_sk;
	struct sock___7 *igmp_sk;
	struct sock___7 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___5 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___5 *notifier_ops;
	struct fib_notifier_ops___5 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___8 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___8 *fqdir;
};

struct netns_sctp___5 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___7 *ctl_sock;
	struct sock___7 *udp4_sock;
	struct sock___7 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___6 {
	struct bpf_prog_array___6 *run_array[2];
	struct bpf_prog___6 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___8 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___7 *nlsk;
	struct sock___7 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___8 xfrm4_dst_ops;
	struct dst_ops___8 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___9 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___7 *rtnl;
	struct sock___7 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___11 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___8 ipv4;
	struct netns_ipv6___8 ipv6;
	struct netns_ieee802154_lowpan___8 ieee802154_lowpan;
	struct netns_sctp___5 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___6 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___6 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___8 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___7 *crypto_nlsk;
	struct sock___7 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___43 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___43 *root_cset;
};

struct kernel_param_ops___50 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___50 *);
	int (*get)(char *, const struct kernel_param___50 *);
	void (*free)(void *);
};

struct kparam_array___50;

struct kernel_param___50 {
	const char *name;
	struct module___52 *mod;
	const struct kernel_param_ops___50 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___50 *arr;
	};
};

struct kparam_array___50 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___50 *ops;
	void *elem;
};

struct module_attribute___50 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___50 *, struct module_kobject___50 *, char *);
	ssize_t (*store)(struct module_attribute___50 *, struct module_kobject___50 *, const char *, size_t);
	void (*setup)(struct module___52 *, const char *);
	int (*test)(struct module___52 *);
	void (*free)(struct module___52 *);
};

struct trace_event_class___30;

struct trace_event_call___30 {
	struct list_head list;
	struct trace_event_class___30 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___30 *, struct perf_event___35 *);
};

struct __kernel_sockaddr_storage {
	union {
		struct {
			__kernel_sa_family_t ss_family;
			char __data[126];
		};
		void *__align;
	};
};

struct msghdr___5 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___27 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___52 *msg_iocb;
};

struct bpf_iter_aux_info___6;

typedef int (*bpf_iter_init_seq_priv_t___6)(void *, struct bpf_iter_aux_info___6 *);

struct bpf_map___6;

struct bpf_iter_aux_info___6 {
	struct bpf_map___6 *map;
};

struct bpf_iter_seq_info___6 {
	const struct seq_operations___51 *seq_ops;
	bpf_iter_init_seq_priv_t___6 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___6;

struct bpf_map_ops___6 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___6 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___6 *, struct file___53 *);
	void (*map_free)(struct bpf_map___6 *);
	int (*map_get_next_key)(struct bpf_map___6 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___6 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___6 *, void *);
	int (*map_lookup_batch)(struct bpf_map___6 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___6 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___6 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___6 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___6 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___6 *, void *);
	int (*map_update_elem)(struct bpf_map___6 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___6 *, void *);
	int (*map_push_elem)(struct bpf_map___6 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___6 *, void *);
	int (*map_peek_elem)(struct bpf_map___6 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___6 *, struct file___53 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___6 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___6 *, void *, struct seq_file___51 *);
	int (*map_check_btf)(const struct bpf_map___6 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___6 *, struct bpf_prog_aux___6 *);
	void (*map_poke_untrack)(struct bpf_map___6 *, struct bpf_prog_aux___6 *);
	void (*map_poke_run)(struct bpf_map___6 *, u32, struct bpf_prog___6 *, struct bpf_prog___6 *);
	int (*map_direct_value_addr)(const struct bpf_map___6 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___6 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___6 *, struct vm_area_struct___57 *);
	__poll_t (*map_poll)(struct bpf_map___6 *, struct file___53 *, struct poll_table_struct___38 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___6 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___6 *, const struct bpf_map___6 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___6 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___6 *iter_seq_info;
};

struct bpf_map___6 {
	const struct bpf_map_ops___6 *ops;
	struct bpf_map___6 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___22 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___6;

struct bpf_jit_poke_descriptor___6;

struct bpf_prog_ops___6;

struct btf_mod_pair___6;

struct bpf_prog_offload___6;

struct bpf_prog_aux___6 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___6 *dst_prog;
	struct bpf_trampoline___6 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___6 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___6 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___6 *ops;
	struct bpf_map___6 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___6 *used_btfs;
	struct bpf_prog___6 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___6 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___6 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___6 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___6 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___6;

struct bpf_map_dev_ops___6 {
	int (*map_get_next_key)(struct bpf_offloaded_map___6 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___6 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___6 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___6 *, void *);
};

struct bpf_offloaded_map___6 {
	struct bpf_map___6 map;
	struct net_device___11 *netdev;
	const struct bpf_map_dev_ops___6 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___6(struct sk_buff___8 **);

struct bpf_xdp_entity___6 {
	struct bpf_prog___6 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___6;

struct net_device_ops___6;

struct l3mdev_ops___5;

struct xfrmdev_ops___6;

struct header_ops___6;

struct netdev_rx_queue___6;

struct mini_Qdisc___6;

struct netdev_queue___6;

struct Qdisc___6;

struct rtnl_link_ops___6;

struct dcbnl_rtnl_ops___6;

struct net_device___11 {
	char name[16];
	struct netdev_name_node___6 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___6 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___5 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___6 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___6 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___53 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___6 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___6 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___6 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___6 *miniq_ingress;
	struct netdev_queue___6 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___6 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___6 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___6 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___6 = 0,
		NETREG_REGISTERED___6 = 1,
		NETREG_UNREGISTERING___6 = 2,
		NETREG_UNREGISTERED___6 = 3,
		NETREG_RELEASED___6 = 4,
		NETREG_DUMMY___6 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___6 = 0,
		RTNL_LINK_INITIALIZING___6 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___11 *);
	struct netpoll_info *npinfo;
	possible_net_t___6 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___47 dev;
	const struct attribute_group___53 *sysfs_groups[4];
	const struct attribute_group___53 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___6 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___6 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___6 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___6 {
	int (*test_run)(struct bpf_prog___6 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___6 {
	struct bpf_prog___6 *prog;
	struct net_device___11 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___6 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___6 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___52 *mod;
};

struct bpf_jit_poke_descriptor___6 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___6 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___6 {
	struct btf *btf;
	struct module___52 *module;
};

struct bpf_prog_array_item___6 {
	struct bpf_prog___6 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___6 {
	struct callback_head rcu;
	struct bpf_prog_array_item___6 items[0];
};

struct sk_buff___8 {
	union {
		struct {
			struct sk_buff___8 *next;
			struct sk_buff___8 *prev;
			union {
				struct net_device___11 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___7 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___8 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___43;

struct cgroup_subsys___43 {
	struct cgroup_subsys_state___43 * (*css_alloc)(struct cgroup_subsys_state___43 *);
	int (*css_online)(struct cgroup_subsys_state___43 *);
	void (*css_offline)(struct cgroup_subsys_state___43 *);
	void (*css_released)(struct cgroup_subsys_state___43 *);
	void (*css_free)(struct cgroup_subsys_state___43 *);
	void (*css_reset)(struct cgroup_subsys_state___43 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___43 *, int);
	int (*css_extra_stat_show)(struct seq_file___51 *, struct cgroup_subsys_state___43 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___58 *, struct css_set___43 *);
	void (*cancel_fork)(struct task_struct___58 *, struct css_set___43 *);
	void (*fork)(struct task_struct___58 *);
	void (*exit)(struct task_struct___58 *);
	void (*release)(struct task_struct___58 *);
	void (*bind)(struct cgroup_subsys_state___43 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___43 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___43 *dfl_cftypes;
	struct cftype___43 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___43 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___43 *updated_children;
	struct cgroup___43 *updated_next;
};

struct cgroup_root___43 {
	struct kernfs_root___53 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___43 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___43 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___43 *ss;
	struct list_head node;
	struct kernfs_ops___53 *kf_ops;
	int (*open)(struct kernfs_open_file___53 *);
	void (*release)(struct kernfs_open_file___53 *);
	u64 (*read_u64)(struct cgroup_subsys_state___43 *, struct cftype___43 *);
	s64 (*read_s64)(struct cgroup_subsys_state___43 *, struct cftype___43 *);
	int (*seq_show)(struct seq_file___51 *, void *);
	void * (*seq_start)(struct seq_file___51 *, loff_t *);
	void * (*seq_next)(struct seq_file___51 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___51 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___43 *, struct cftype___43 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___43 *, struct cftype___43 *, s64);
	ssize_t (*write)(struct kernfs_open_file___53 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___53 *, struct poll_table_struct___38 *);
};

struct lsmcontext {
	char *context;
	u32 len;
	int slot;
};

struct perf_cpu_context___35;

struct perf_output_handle___35;

struct pmu___35 {
	struct list_head entry;
	struct module___52 *module;
	struct device___47 *dev;
	const struct attribute_group___53 **attr_groups;
	const struct attribute_group___53 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___35 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___35 *);
	void (*pmu_disable)(struct pmu___35 *);
	int (*event_init)(struct perf_event___35 *);
	void (*event_mapped)(struct perf_event___35 *, struct mm_struct___58 *);
	void (*event_unmapped)(struct perf_event___35 *, struct mm_struct___58 *);
	int (*add)(struct perf_event___35 *, int);
	void (*del)(struct perf_event___35 *, int);
	void (*start)(struct perf_event___35 *, int);
	void (*stop)(struct perf_event___35 *, int);
	void (*read)(struct perf_event___35 *);
	void (*start_txn)(struct pmu___35 *, unsigned int);
	int (*commit_txn)(struct pmu___35 *);
	void (*cancel_txn)(struct pmu___35 *);
	int (*event_idx)(struct perf_event___35 *);
	void (*sched_task)(struct perf_event_context___35 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___35 *, struct perf_event_context___35 *);
	void * (*setup_aux)(struct perf_event___35 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___35 *, struct perf_output_handle___35 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___35 *);
	int (*aux_output_match)(struct perf_event___35 *);
	int (*filter_match)(struct perf_event___35 *);
	int (*check_period)(struct perf_event___35 *, u64);
};

struct perf_cpu_context___35 {
	struct perf_event_context___35 ctx;
	struct perf_event_context___35 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___35 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___35 **heap;
	struct perf_event___35 *heap_default[2];
};

struct perf_output_handle___35 {
	struct perf_event___35 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___35 {
	struct cgroup_subsys_state___43 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___30 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___30 *);
	};
};

struct trace_event_class___30 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___30 *, enum trace_reg, void *);
	struct trace_event_fields___30 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___30 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___30 *);
};

enum audit_nlgrps {
	AUDIT_NLGRP_NONE = 0,
	AUDIT_NLGRP_READLOG = 1,
	__AUDIT_NLGRP_MAX = 2,
};

struct audit_status {
	__u32 mask;
	__u32 enabled;
	__u32 failure;
	__u32 pid;
	__u32 rate_limit;
	__u32 backlog_limit;
	__u32 lost;
	__u32 backlog;
	union {
		__u32 version;
		__u32 feature_bitmap;
	};
	__u32 backlog_wait_time;
	__u32 backlog_wait_time_actual;
};

struct audit_features {
	__u32 vers;
	__u32 mask;
	__u32 features;
	__u32 lock;
};

struct audit_tty_status {
	__u32 enabled;
	__u32 log_passwd;
};

struct audit_sig_info {
	uid_t uid;
	pid_t pid;
	char ctx[0];
};

struct inet_frags___8;

struct fqdir___8 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___8 *f;
	struct net___9 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___8;

struct inet_frags___8 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___8 *, const void *);
	void (*destructor)(struct inet_frag_queue___8 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___8 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___8 *fragments_tail;
	struct sk_buff___8 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___8 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___5;

struct fib_lookup_arg___5;

struct fib_rules_ops___5 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___5 *, struct flowi *, int, struct fib_lookup_arg___5 *);
	bool (*suppress)(struct fib_rule___5 *, int, struct fib_lookup_arg___5 *);
	int (*match)(struct fib_rule___5 *, struct flowi *, int);
	int (*configure)(struct fib_rule___5 *, struct sk_buff___8 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___5 *);
	int (*compare)(struct fib_rule___5 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___5 *, struct sk_buff___8 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___5 *);
	void (*flush_cache)(struct fib_rules_ops___5 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___52 *owner;
	struct net___9 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___5 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___9 *);
	int (*fib_dump)(struct net___9 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___52 *owner;
	struct callback_head rcu;
};

struct dst_entry___5 {
	struct net_device___11 *dev;
	struct dst_ops___8 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___8 *);
	int (*output)(struct net___9 *, struct sock___7 *, struct sk_buff___8 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___5;

struct neigh_parms___5;

struct neigh_ops___5;

struct neighbour___5 {
	struct neighbour___5 *next;
	struct neigh_table___5 *tbl;
	struct neigh_parms___5 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___6 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___5 *, struct sk_buff___8 *);
	const struct neigh_ops___5 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___11 *dev;
	u8 primary_key[0];
};

struct socket_wq___5 {
	wait_queue_head_t wait;
	struct fasync_struct___52 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___5;

struct socket___5 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___53 *file;
	struct sock___7 *sk;
	const struct proto_ops___5 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___5 wq;
};

typedef int (*sk_read_actor_t___5)(read_descriptor_t *, struct sk_buff___8 *, unsigned int, size_t);

struct proto_ops___5 {
	int family;
	struct module___52 *owner;
	int (*release)(struct socket___5 *);
	int (*bind)(struct socket___5 *, struct sockaddr *, int);
	int (*connect)(struct socket___5 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___5 *, struct socket___5 *);
	int (*accept)(struct socket___5 *, struct socket___5 *, int, bool);
	int (*getname)(struct socket___5 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___53 *, struct socket___5 *, struct poll_table_struct___38 *);
	int (*ioctl)(struct socket___5 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___5 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___5 *, void *, bool, bool);
	int (*listen)(struct socket___5 *, int);
	int (*shutdown)(struct socket___5 *, int);
	int (*setsockopt)(struct socket___5 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___5 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___51 *, struct socket___5 *);
	int (*sendmsg)(struct socket___5 *, struct msghdr___5 *, size_t);
	int (*recvmsg)(struct socket___5 *, struct msghdr___5 *, size_t, int);
	int (*mmap)(struct file___53 *, struct socket___5 *, struct vm_area_struct___57 *);
	ssize_t (*sendpage)(struct socket___5 *, struct page___57 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___5 *, loff_t *, struct pipe_inode_info___15 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___7 *, int);
	int (*peek_len)(struct socket___5 *);
	int (*read_sock)(struct sock___7 *, read_descriptor_t *, sk_read_actor_t___5);
	int (*sendpage_locked)(struct sock___7 *, struct page___57 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___7 *, struct msghdr___5 *, size_t);
	int (*set_rcvlowat)(struct sock___7 *, int);
};

struct pipe_buf_operations___15;

struct pipe_buffer___15 {
	struct page___57 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___15 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___15 {
	int (*confirm)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	void (*release)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	bool (*try_steal)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
	bool (*get)(struct pipe_inode_info___15 *, struct pipe_buffer___15 *);
};

struct net_generic {
	union {
		struct {
			unsigned int len;
			struct callback_head rcu;
		} s;
		void *ptr[0];
	};
};

struct pernet_operations {
	struct list_head list;
	int (*init)(struct net___9 *);
	void (*pre_exit)(struct net___9 *);
	void (*exit)(struct net___9 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___6 {
	int (*ieee_getets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___11 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___11 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___11 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___11 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___11 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___11 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___11 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___11 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___11 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___11 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___11 *);
	u8 (*setstate)(struct net_device___11 *, u8);
	void (*getpermhwaddr)(struct net_device___11 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___11 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___11 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___11 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___11 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___11 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___11 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___11 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___11 *, int, u8 *);
	void (*setpfccfg)(struct net_device___11 *, int, u8);
	void (*getpfccfg)(struct net_device___11 *, int, u8 *);
	u8 (*setall)(struct net_device___11 *);
	u8 (*getcap)(struct net_device___11 *, int, u8 *);
	int (*getnumtcs)(struct net_device___11 *, int, u8 *);
	int (*setnumtcs)(struct net_device___11 *, int, u8);
	u8 (*getpfcstate)(struct net_device___11 *);
	void (*setpfcstate)(struct net_device___11 *, u8);
	void (*getbcncfg)(struct net_device___11 *, int, u32 *);
	void (*setbcncfg)(struct net_device___11 *, int, u32);
	void (*getbcnrp)(struct net_device___11 *, int, u8 *);
	void (*setbcnrp)(struct net_device___11 *, int, u8);
	int (*setapp)(struct net_device___11 *, u8, u16, u8);
	int (*getapp)(struct net_device___11 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___11 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___11 *, int, u8);
	u8 (*getdcbx)(struct net_device___11 *);
	u8 (*setdcbx)(struct net_device___11 *, u8);
	int (*peer_getappinfo)(struct net_device___11 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___11 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___11 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___11 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___11 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___11 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___6 {
	struct net_device___11 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___6 {
	struct net_device___11 *dev;
};

struct xdp_buff___6 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___6 *rxq;
	struct xdp_txq_info___6 *txq;
	u32 frame_sz;
};

struct xdp_frame___6 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___11 *dev_rx;
};

struct scm_creds {
	u32 pid;
	kuid_t uid;
	kgid_t gid;
};

struct netlink_skb_parms {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___7 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___8 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___9 *, int);
	void (*unbind)(struct net___9 *, int);
	bool (*compare)(struct net___9 *, struct sock___7 *);
};

struct netlink_callback___6 {
	struct sk_buff___8 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___8 *, struct netlink_callback___6 *);
	int (*done)(struct netlink_callback___6 *);
	void *data;
	struct module___52 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___6 {
	int (*create)(struct sk_buff___8 *, struct net_device___11 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___8 *, unsigned char *);
	int (*cache)(const struct neighbour___5 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___11 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___8 *);
};

struct netdev_queue___6 {
	struct net_device___11 *dev;
	struct Qdisc___6 *qdisc;
	struct Qdisc___6 *qdisc_sleeping;
	struct kobject___53 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___11 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___6 {
	struct sk_buff___8 *head;
	struct sk_buff___8 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___6;

struct Qdisc___6 {
	int (*enqueue)(struct sk_buff___8 *, struct Qdisc___6 *, struct sk_buff___8 **);
	struct sk_buff___8 * (*dequeue)(struct Qdisc___6 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___6 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___6 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___6 gso_skb;
	struct qdisc_skb_head___6 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___6 *next_sched;
	struct sk_buff_head___6 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___6 {
	struct xdp_rxq_info___6 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___53 kobj;
	struct net_device___11 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___6 {
	enum net_device_path_type type;
	const struct net_device___11 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___6 = 0,
				DEV_PATH_BR_VLAN_TAG___6 = 1,
				DEV_PATH_BR_VLAN_UNTAG___6 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___6 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___6 {
	const struct net_device___11 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___6 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___6 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___6 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___6 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___8 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___6 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___11 *dev;
	const char *name;
};

struct net_device_ops___6 {
	int (*ndo_init)(struct net_device___11 *);
	void (*ndo_uninit)(struct net_device___11 *);
	int (*ndo_open)(struct net_device___11 *);
	int (*ndo_stop)(struct net_device___11 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___8 *, struct net_device___11 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___8 *, struct net_device___11 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___11 *, struct sk_buff___8 *, struct net_device___11 *);
	void (*ndo_change_rx_flags)(struct net_device___11 *, int);
	void (*ndo_set_rx_mode)(struct net_device___11 *);
	int (*ndo_set_mac_address)(struct net_device___11 *, void *);
	int (*ndo_validate_addr)(struct net_device___11 *);
	int (*ndo_do_ioctl)(struct net_device___11 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___11 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___11 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___11 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___11 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___11 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___11 *, int);
	int (*ndo_neigh_setup)(struct net_device___11 *, struct neigh_parms___5 *);
	void (*ndo_tx_timeout)(struct net_device___11 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___11 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___11 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___11 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___11 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___11 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___11 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___11 *);
	int (*ndo_netpoll_setup)(struct net_device___11 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___11 *);
	int (*ndo_set_vf_mac)(struct net_device___11 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___11 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___11 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___11 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___11 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___11 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___11 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___11 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___11 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___11 *, int, struct sk_buff___8 *);
	int (*ndo_get_vf_guid)(struct net_device___11 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___11 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___11 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___11 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___11 *);
	int (*ndo_fcoe_disable)(struct net_device___11 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___11 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___11 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___11 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___11 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___11 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___11 *, const struct sk_buff___8 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___11 *, struct net_device___11 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___11 *, struct net_device___11 *);
	struct net_device___11 * (*ndo_get_xmit_slave)(struct net_device___11 *, struct sk_buff___8 *, bool);
	struct net_device___11 * (*ndo_sk_get_lower_dev)(struct net_device___11 *, struct sock___7 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___11 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___11 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___11 *, struct neighbour___5 *);
	void (*ndo_neigh_destroy)(struct net_device___11 *, struct neighbour___5 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___8 *, struct netlink_callback___6 *, struct net_device___11 *, struct net_device___11 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___8 *, struct nlattr **, struct net_device___11 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___11 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___8 *, u32, u32, struct net_device___11 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___11 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___11 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___11 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___11 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___11 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___11 *, struct net_device___11 *);
	void (*ndo_dfwd_del_station)(struct net_device___11 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___11 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___11 *);
	int (*ndo_change_proto_down)(struct net_device___11 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___11 *, struct sk_buff___8 *);
	void (*ndo_set_rx_headroom)(struct net_device___11 *, int);
	int (*ndo_bpf)(struct net_device___11 *, struct netdev_bpf___6 *);
	int (*ndo_xdp_xmit)(struct net_device___11 *, int, struct xdp_frame___6 **, u32);
	struct net_device___11 * (*ndo_xdp_get_xmit_slave)(struct net_device___11 *, struct xdp_buff___6 *);
	int (*ndo_xsk_wakeup)(struct net_device___11 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___11 *);
	int (*ndo_tunnel_ctl)(struct net_device___11 *, struct ip_tunnel_parm *, int);
	struct net_device___11 * (*ndo_get_peer_dev)(struct net_device___11 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___6 *, struct net_device_path___6 *);
};

struct neigh_parms___5 {
	possible_net_t___6 net;
	struct net_device___11 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___5 *);
	struct neigh_table___5 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___5 {
	u32 (*l3mdev_fib_table)(const struct net_device___11 *);
	struct sk_buff___8 * (*l3mdev_l3_rcv)(struct net_device___11 *, struct sk_buff___8 *, u16);
	struct sk_buff___8 * (*l3mdev_l3_out)(struct net_device___11 *, struct sock___7 *, struct sk_buff___8 *, u16);
	struct dst_entry___5 * (*l3mdev_link_scope_lookup)(const struct net_device___11 *, struct flowi6 *);
};

struct tcf_proto___6;

struct tcf_block___6;

struct mini_Qdisc___6 {
	struct tcf_proto___6 *filter_list;
	struct tcf_block___6 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___6 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___11 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___11 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___9 *, struct net_device___11 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___11 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___11 *, struct list_head *);
	size_t (*get_size)(const struct net_device___11 *);
	int (*fill_info)(struct sk_buff___8 *, const struct net_device___11 *);
	size_t (*get_xstats_size)(const struct net_device___11 *);
	int (*fill_xstats)(struct sk_buff___8 *, const struct net_device___11 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___11 *, struct net_device___11 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___11 *, const struct net_device___11 *);
	int (*fill_slave_info)(struct sk_buff___8 *, const struct net_device___11 *, const struct net_device___11 *);
	struct net___9 * (*get_link_net)(const struct net_device___11 *);
	size_t (*get_linkxstats_size)(const struct net_device___11 *, int);
	int (*fill_linkxstats)(struct sk_buff___8 *, const struct net_device___11 *, int *, int);
};

struct block_device_operations___24;

struct gendisk___24 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___25 *part0;
	const struct block_device_operations___24 *fops;
	struct request_queue___25 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___23 *bdi;
	struct kobject___53 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___53 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___24 {
	struct bio___24 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___27 *bip_vec;
	struct bio_vec___27 bip_inline_vecs[0];
};

struct blkcg___23;

struct blkg_policy_data___23;

struct blkcg_gq___23 {
	struct request_queue___25 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___23 *blkcg;
	struct blkcg_gq___23 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___23 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___24 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___24(struct request___24 *);

typedef void integrity_complete_fn___24(struct request___24 *, unsigned int);

struct blk_integrity_profile___24 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___24 *prepare_fn;
	integrity_complete_fn___24 *complete_fn;
	const char *name;
};

struct block_device_operations___24 {
	blk_qc_t (*submit_bio)(struct bio___24 *);
	int (*open)(struct block_device___25 *, fmode_t);
	void (*release)(struct gendisk___24 *, fmode_t);
	int (*rw_page)(struct block_device___25 *, sector_t, struct page___57 *, unsigned int);
	int (*ioctl)(struct block_device___25 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___25 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___24 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___24 *);
	int (*getgeo)(struct block_device___25 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___25 *, bool);
	void (*swap_slot_free_notify)(struct block_device___25 *, long unsigned int);
	int (*report_zones)(struct gendisk___24 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___24 *, umode_t *);
	struct module___52 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___24 *, sector_t *);
};

typedef void rq_end_io_fn___24(struct request___24 *, blk_status_t);

struct request___24 {
	struct request_queue___25 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___23 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___24 *bio;
	struct bio___24 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___27 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___24 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___24 *saved_end_io;
		} flush;
	};
	struct gendisk___24 *rq_disk;
	struct block_device___25 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___24 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___23 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___25 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___53 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___53 *debugfs_dir;
	struct dentry___53 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___24;

struct elevator_mq_ops___24 {
	int (*init_sched)(struct request_queue___25 *, struct elevator_type___24 *);
	void (*exit_sched)(struct elevator_queue___24 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___23 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___23 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___23 *);
	bool (*allow_merge)(struct request_queue___25 *, struct request___24 *, struct bio___24 *);
	bool (*bio_merge)(struct request_queue___25 *, struct bio___24 *, unsigned int);
	int (*request_merge)(struct request_queue___25 *, struct request___24 **, struct bio___24 *);
	void (*request_merged)(struct request_queue___25 *, struct request___24 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___25 *, struct request___24 *, struct request___24 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___24 *);
	void (*finish_request)(struct request___24 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___23 *, struct list_head *, bool);
	struct request___24 * (*dispatch_request)(struct blk_mq_hw_ctx___23 *);
	bool (*has_work)(struct blk_mq_hw_ctx___23 *);
	void (*completed_request)(struct request___24 *, u64);
	void (*requeue_request)(struct request___24 *);
	struct request___24 * (*former_request)(struct request_queue___25 *, struct request___24 *);
	struct request___24 * (*next_request)(struct request_queue___25 *, struct request___24 *);
	void (*init_icq)(struct io_cq___24 *);
	void (*exit_icq)(struct io_cq___24 *);
};

struct elv_fs_entry___24;

struct elevator_type___24 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___24 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___24 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___52 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___24 {
	struct elevator_type___24 *type;
	void *elevator_data;
	struct kobject___53 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___24 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___24 *, char *);
	ssize_t (*store)(struct elevator_queue___24 *, const char *, size_t);
};

struct blk_mq_queue_data___23;

struct blk_mq_ops___23 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___23 *, const struct blk_mq_queue_data___23 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___23 *);
	int (*get_budget)(struct request_queue___25 *);
	void (*put_budget)(struct request_queue___25 *, int);
	void (*set_rq_budget_token)(struct request___24 *, int);
	int (*get_rq_budget_token)(struct request___24 *);
	enum blk_eh_timer_return (*timeout)(struct request___24 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___23 *);
	void (*complete)(struct request___24 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___23 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___23 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___23 *, struct request___24 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___23 *, struct request___24 *, unsigned int);
	void (*initialize_rq_fn)(struct request___24 *);
	void (*cleanup_rq)(struct request___24 *);
	bool (*busy)(struct request_queue___25 *);
	int (*map_queues)(struct blk_mq_tag_set___23 *);
	void (*show_rq)(struct seq_file___51 *, struct request___24 *);
};

struct blk_mq_tag_set___23 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___23 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___23 {
	struct request___24 *rq;
	bool last;
};

struct blkcg_policy_data___23;

struct blkcg___23 {
	struct cgroup_subsys_state___43 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___23 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___23 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___23 {
	struct blkcg___23 *blkcg;
	int plid;
};

struct blkg_policy_data___23 {
	struct blkcg_gq___23 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___22 {
	struct mem_cgroup___22 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___22 {
	struct lruvec___23 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___22 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___22 *memcg;
};

struct obj_cgroup___22 {
	struct percpu_ref refcnt;
	struct mem_cgroup___22 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___6 {
	spinlock_t *lock;
	struct sk_buff___8 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___6;

struct Qdisc_ops___6 {
	struct Qdisc_ops___6 *next;
	const struct Qdisc_class_ops___6 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___8 *, struct Qdisc___6 *, struct sk_buff___8 **);
	struct sk_buff___8 * (*dequeue)(struct Qdisc___6 *);
	struct sk_buff___8 * (*peek)(struct Qdisc___6 *);
	int (*init)(struct Qdisc___6 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___6 *);
	void (*destroy)(struct Qdisc___6 *);
	int (*change)(struct Qdisc___6 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___6 *);
	int (*change_tx_queue_len)(struct Qdisc___6 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___6 *, unsigned int);
	int (*dump)(struct Qdisc___6 *, struct sk_buff___8 *);
	int (*dump_stats)(struct Qdisc___6 *, struct gnet_dump___6 *);
	void (*ingress_block_set)(struct Qdisc___6 *, u32);
	void (*egress_block_set)(struct Qdisc___6 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___6 *);
	u32 (*egress_block_get)(struct Qdisc___6 *);
	struct module___52 *owner;
};

struct Qdisc_class_ops___6 {
	unsigned int flags;
	struct netdev_queue___6 * (*select_queue)(struct Qdisc___6 *, struct tcmsg *);
	int (*graft)(struct Qdisc___6 *, long unsigned int, struct Qdisc___6 *, struct Qdisc___6 **, struct netlink_ext_ack *);
	struct Qdisc___6 * (*leaf)(struct Qdisc___6 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___6 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___6 *, u32);
	int (*change)(struct Qdisc___6 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___6 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___6 *, struct qdisc_walker *);
	struct tcf_block___6 * (*tcf_block)(struct Qdisc___6 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___6 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___6 *, long unsigned int);
	int (*dump)(struct Qdisc___6 *, long unsigned int, struct sk_buff___8 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___6 *, long unsigned int, struct gnet_dump___6 *);
};

struct tcf_chain___6;

struct tcf_block___6 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___9 *net;
	struct Qdisc___6 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___6 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___6;

struct tcf_proto_ops___6;

struct tcf_proto___6 {
	struct tcf_proto___6 *next;
	void *root;
	int (*classify)(struct sk_buff___8 *, const struct tcf_proto___6 *, struct tcf_result___6 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___6 *ops;
	struct tcf_chain___6 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___6 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___6 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___6 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___8 *, const struct tcf_proto___6 *, struct tcf_result___6 *);
	int (*init)(struct tcf_proto___6 *);
	void (*destroy)(struct tcf_proto___6 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___6 *, u32);
	void (*put)(struct tcf_proto___6 *, void *);
	int (*change)(struct net___9 *, struct sk_buff___8 *, struct tcf_proto___6 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___6 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___6 *);
	void (*walk)(struct tcf_proto___6 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___6 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___6 *, void *);
	void (*hw_del)(struct tcf_proto___6 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___9 *, struct tcf_chain___6 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___9 *, struct tcf_proto___6 *, void *, struct sk_buff___8 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___9 *, struct tcf_proto___6 *, void *, struct sk_buff___8 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___8 *, struct net___9 *, void *);
	struct module___52 *owner;
	int flags;
};

struct tcf_chain___6 {
	struct mutex filter_chain_lock;
	struct tcf_proto___6 *filter_chain;
	struct list_head list;
	struct tcf_block___6 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___6 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___5 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___6 *prog;
};

struct pneigh_entry___5;

struct neigh_hash_table___5;

struct neigh_table___5 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___11 *, __u32 *);
	bool (*key_eq)(const struct neighbour___5 *, const void *);
	int (*constructor)(struct neighbour___5 *);
	int (*pconstructor)(struct pneigh_entry___5 *);
	void (*pdestructor)(struct pneigh_entry___5 *);
	void (*proxy_redo)(struct sk_buff___8 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___11 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___5 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___6 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___5 *nht;
	struct pneigh_entry___5 **phash_buckets;
};

struct neigh_ops___5 {
	int family;
	void (*solicit)(struct neighbour___5 *, struct sk_buff___8 *);
	void (*error_report)(struct neighbour___5 *, struct sk_buff___8 *);
	int (*output)(struct neighbour___5 *, struct sk_buff___8 *);
	int (*connected_output)(struct neighbour___5 *, struct sk_buff___8 *);
};

struct pneigh_entry___5 {
	struct pneigh_entry___5 *next;
	possible_net_t___6 net;
	struct net_device___11 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___5 {
	struct neighbour___5 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___5 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___5 *ctarget;
	struct net___9 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___5 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___5 *rule;
	u32 table;
	int flags;
};

struct proto___5 {
	void (*close)(struct sock___7 *, long int);
	int (*pre_connect)(struct sock___7 *, struct sockaddr *, int);
	int (*connect)(struct sock___7 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___7 *, int);
	struct sock___7 * (*accept)(struct sock___7 *, int, int *, bool);
	int (*ioctl)(struct sock___7 *, int, long unsigned int);
	int (*init)(struct sock___7 *);
	void (*destroy)(struct sock___7 *);
	void (*shutdown)(struct sock___7 *, int);
	int (*setsockopt)(struct sock___7 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___7 *, int, int, char *, int *);
	void (*keepalive)(struct sock___7 *, int);
	int (*compat_ioctl)(struct sock___7 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___7 *, struct msghdr___5 *, size_t);
	int (*recvmsg)(struct sock___7 *, struct msghdr___5 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___7 *, struct page___57 *, int, size_t, int);
	int (*bind)(struct sock___7 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___7 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___7 *, struct sk_buff___8 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___7 *);
	int (*hash)(struct sock___7 *);
	void (*unhash)(struct sock___7 *);
	void (*rehash)(struct sock___7 *);
	int (*get_port)(struct sock___7 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___7 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___7 *, int);
	bool (*sock_is_readable)(struct sock___7 *);
	void (*enter_memory_pressure)(struct sock___7 *);
	void (*leave_memory_pressure)(struct sock___7 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___52 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___7 *, int);
};

struct tty_operations___8 {
	struct tty_struct___8 * (*lookup)(struct tty_driver___8 *, struct file___53 *, int);
	int (*install)(struct tty_driver___8 *, struct tty_struct___8 *);
	void (*remove)(struct tty_driver___8 *, struct tty_struct___8 *);
	int (*open)(struct tty_struct___8 *, struct file___53 *);
	void (*close)(struct tty_struct___8 *, struct file___53 *);
	void (*shutdown)(struct tty_struct___8 *);
	void (*cleanup)(struct tty_struct___8 *);
	int (*write)(struct tty_struct___8 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___8 *, unsigned char);
	void (*flush_chars)(struct tty_struct___8 *);
	unsigned int (*write_room)(struct tty_struct___8 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___8 *);
	int (*ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___8 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	void (*throttle)(struct tty_struct___8 *);
	void (*unthrottle)(struct tty_struct___8 *);
	void (*stop)(struct tty_struct___8 *);
	void (*start)(struct tty_struct___8 *);
	void (*hangup)(struct tty_struct___8 *);
	int (*break_ctl)(struct tty_struct___8 *, int);
	void (*flush_buffer)(struct tty_struct___8 *);
	void (*set_ldisc)(struct tty_struct___8 *);
	void (*wait_until_sent)(struct tty_struct___8 *, int);
	void (*send_xchar)(struct tty_struct___8 *, char);
	int (*tiocmget)(struct tty_struct___8 *);
	int (*tiocmset)(struct tty_struct___8 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___8 *, struct winsize *);
	int (*get_icount)(struct tty_struct___8 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___8 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___8 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___8 *, struct seq_file___51 *);
	int (*poll_init)(struct tty_driver___8 *, int, char *);
	int (*poll_get_char)(struct tty_driver___8 *, int);
	void (*poll_put_char)(struct tty_driver___8 *, int, char);
	int (*proc_show)(struct seq_file___51 *, void *);
};

struct tty_driver___8 {
	int magic;
	struct kref kref;
	struct cdev___18 **cdevs;
	struct module___52 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___8 *other;
	struct tty_struct___8 **ttys;
	struct tty_port___8 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___8 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___8;

struct tty_port_client_operations___8;

struct tty_port___8 {
	struct tty_bufhead buf;
	struct tty_struct___8 *tty;
	struct tty_struct___8 *itty;
	const struct tty_port_operations___8 *ops;
	const struct tty_port_client_operations___8 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___8 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___8 *);
	void (*close)(struct tty_struct___8 *);
	void (*flush_buffer)(struct tty_struct___8 *);
	ssize_t (*read)(struct tty_struct___8 *, struct file___53 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___8 *, struct file___53 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___8 *, struct file___53 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___8 *, struct file___53 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___8 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___8 *, struct file___53 *, struct poll_table_struct___38 *);
	int (*hangup)(struct tty_struct___8 *);
	void (*receive_buf)(struct tty_struct___8 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___8 *);
	void (*dcd_change)(struct tty_struct___8 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___8 *, const unsigned char *, const char *, int);
	struct module___52 *owner;
};

struct tty_ldisc___8 {
	struct tty_ldisc_ops___8 *ops;
	struct tty_struct___8 *tty;
};

struct tty_port_operations___8 {
	int (*carrier_raised)(struct tty_port___8 *);
	void (*dtr_rts)(struct tty_port___8 *, int);
	void (*shutdown)(struct tty_port___8 *);
	int (*activate)(struct tty_port___8 *, struct tty_struct___8 *);
	void (*destruct)(struct tty_port___8 *);
};

struct tty_port_client_operations___8 {
	int (*receive_buf)(struct tty_port___8 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___8 *);
};

struct audit_netlink_list {
	__u32 portid;
	struct net___9 *net;
	struct sk_buff_head___6 q;
};

struct audit_net {
	struct sock___7 *sk;
};

struct auditd_connection {
	struct pid___47 *pid;
	u32 portid;
	struct net___9 *net;
	struct callback_head rcu;
};

struct audit_ctl_mutex {
	struct mutex lock;
	void *owner;
};

struct audit_buffer {
	struct sk_buff___8 *skb;
	struct audit_context___2 *ctx;
	gfp_t gfp_mask;
};

struct audit_reply {
	__u32 portid;
	struct net___9 *net;
	struct sk_buff___8 *skb;
};

enum {
	Audit_equal = 0,
	Audit_not_equal = 1,
	Audit_bitmask = 2,
	Audit_bittest = 3,
	Audit_lt = 4,
	Audit_gt = 5,
	Audit_le = 6,
	Audit_ge = 7,
	Audit_bad = 8,
};

struct audit_rule_data {
	__u32 flags;
	__u32 action;
	__u32 field_count;
	__u32 mask[64];
	__u32 fields[64];
	__u32 values[64];
	__u32 fieldflags[64];
	__u32 buflen;
	char buf[0];
};

struct audit_field;

struct audit_watch;

struct audit_tree;

struct audit_fsnotify_mark;

struct audit_krule {
	u32 pflags;
	u32 flags;
	u32 listnr;
	u32 action;
	u32 mask[64];
	u32 buflen;
	u32 field_count;
	char *filterkey;
	struct audit_field *fields;
	struct audit_field *arch_f;
	struct audit_field *inode_f;
	struct audit_watch *watch;
	struct audit_tree *tree;
	struct audit_fsnotify_mark *exe;
	struct list_head rlist;
	struct list_head list;
	u64 prio;
};

struct audit_field {
	u32 type;
	union {
		u32 val;
		kuid_t uid;
		kgid_t gid;
		struct {
			bool lsm_isset;
			char *lsm_str;
			void *lsm_rules[4];
		};
	};
	u32 op;
};

struct audit_entry {
	struct list_head list;
	struct callback_head rcu;
	struct audit_krule rule;
};

struct audit_buffer___2;

typedef int __kernel_key_t;

typedef __kernel_key_t key_t;

struct dentry___54;

struct super_block___54;

struct module___53;

struct file_system_type___53 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___54 * (*mount)(struct file_system_type___53 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___54 *);
	struct module___53 *owner;
	struct file_system_type___53 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___54;

struct kiocb___53;

struct iov_iter___28;

struct poll_table_struct___39;

struct vm_area_struct___58;

struct inode___54;

struct file_lock___53;

struct page___58;

struct pipe_inode_info___16;

struct seq_file___52;

struct file_operations___53 {
	struct module___53 *owner;
	loff_t (*llseek)(struct file___54 *, loff_t, int);
	ssize_t (*read)(struct file___54 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___54 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___53 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___53 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___53 *, bool);
	int (*iterate)(struct file___54 *, struct dir_context *);
	int (*iterate_shared)(struct file___54 *, struct dir_context *);
	__poll_t (*poll)(struct file___54 *, struct poll_table_struct___39 *);
	long int (*unlocked_ioctl)(struct file___54 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___54 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___54 *, struct vm_area_struct___58 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___54 *, struct file___54 *);
	int (*flush)(struct file___54 *, fl_owner_t);
	int (*release)(struct inode___54 *, struct file___54 *);
	int (*fsync)(struct file___54 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___54 *, int);
	int (*lock)(struct file___54 *, int, struct file_lock___53 *);
	ssize_t (*sendpage)(struct file___54 *, struct page___58 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___54 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___54 *, long unsigned int);
	int (*flock)(struct file___54 *, int, struct file_lock___53 *);
	ssize_t (*splice_write)(struct pipe_inode_info___16 *, struct file___54 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___54 *, loff_t *, struct pipe_inode_info___16 *, size_t, unsigned int);
	int (*setlease)(struct file___54 *, long int, struct file_lock___53 **, void **);
	long int (*fallocate)(struct file___54 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___52 *, struct file___54 *);
	ssize_t (*copy_file_range)(struct file___54 *, loff_t, struct file___54 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___54 *, loff_t, struct file___54 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___54 *, loff_t, loff_t, int);
};

struct vmacache___58 {
	u64 seqnum;
	struct vm_area_struct___58 *vmas[4];
};

struct page_frag___58 {
	struct page___58 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___36;

struct debug_info___36 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___36 *hbp_break[16];
	struct perf_event___36 *hbp_watch[16];
};

struct thread_struct___36 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___36 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___59;

struct pid___48;

struct fs_struct___9;

struct nsproxy___53;

struct signal_struct___54;

struct css_set___44;

struct perf_event_context___36;

struct vm_struct___55;

struct task_struct___59 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___59 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___59 *mm;
	struct mm_struct___59 *active_mm;
	struct vmacache___58 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___59 *real_parent;
	struct task_struct___59 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___59 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___48 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___9 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___53 *nsproxy;
	struct signal_struct___54 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___59 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___25 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___44 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___36 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___16 *splice_pipe;
	struct page_frag___58 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___59 *oom_reaper_list;
	struct vm_struct___55 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___36 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___54;

struct kobj_type___54;

struct kernfs_node___54;

struct kobject___54 {
	const char *name;
	struct list_head entry;
	struct kobject___54 *parent;
	struct kset___54 *kset;
	struct kobj_type___54 *ktype;
	struct kernfs_node___54 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___51 {
	struct kobject___54 kobj;
	struct module___53 *mod;
	struct kobject___54 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___51 {
	struct module___53 *mod;
	struct latch_tree_node node;
};

struct module_layout___51 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___51 mtn;
};

struct module_attribute___51;

struct kernel_param___51;

struct trace_event_call___31;

struct module___53 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___51 mkobj;
	struct module_attribute___51 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___54 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___51 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___51 core_layout;
	struct module_layout___51 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___31 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___36 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___59 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___36)(struct perf_event___36 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___36;

struct fasync_struct___53;

struct pid_namespace___48;

struct perf_cgroup___36;

struct perf_event___36 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___36 *group_leader;
	struct pmu___36 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___36 hw;
	struct perf_event_context___36 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___36 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___59 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___53 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___36 *aux_event;
	void (*destroy)(struct perf_event___36 *);
	struct callback_head callback_head;
	struct pid_namespace___48 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___36 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___36 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___31 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___36 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___53;

struct dentry___54 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___54 *d_parent;
	struct qstr d_name;
	struct inode___54 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___53 *d_op;
	struct super_block___54 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___53;

struct address_space___53 {
	struct inode___54 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___53 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___53;

struct cdev___19;

struct inode___54 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___53 *i_op;
	struct super_block___54 *i_sb;
	struct address_space___53 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___53 *i_fop;
		void (*free_inode)(struct inode___54 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___53 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___16 *i_pipe;
		struct cdev___19 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___53;

struct path___53;

struct dentry_operations___53 {
	int (*d_revalidate)(struct dentry___54 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___54 *, unsigned int);
	int (*d_hash)(const struct dentry___54 *, struct qstr *);
	int (*d_compare)(const struct dentry___54 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___54 *);
	int (*d_init)(struct dentry___54 *);
	void (*d_release)(struct dentry___54 *);
	void (*d_prune)(struct dentry___54 *);
	void (*d_iput)(struct dentry___54 *, struct inode___54 *);
	char * (*d_dname)(struct dentry___54 *, char *, int);
	struct vfsmount___53 * (*d_automount)(struct path___53 *);
	int (*d_manage)(const struct path___53 *, bool);
	struct dentry___54 * (*d_real)(struct dentry___54 *, const struct inode___54 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___53;

struct mem_dqinfo___53 {
	struct quota_format_type___53 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___53;

struct quota_info___53 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___54 *files[3];
	struct mem_dqinfo___53 info[3];
	const struct quota_format_ops___53 *ops[3];
};

struct rcuwait___54 {
	struct task_struct___59 *task;
};

struct percpu_rw_semaphore___54 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___54 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___53 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___54 rw_sem[3];
};

struct super_operations___53;

struct dquot_operations___53;

struct quotactl_ops___53;

struct super_block___54 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___53 *s_type;
	const struct super_operations___53 *s_op;
	const struct dquot_operations___53 *dq_op;
	const struct quotactl_ops___53 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___54 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___53 s_dquot;
	struct sb_writers___53 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___53 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___53 {
	struct dentry___54 *mnt_root;
	struct super_block___54 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct path___53 {
	struct vfsmount___53 *mnt;
	struct dentry___54 *dentry;
};

struct upid___48 {
	int nr;
	struct pid_namespace___48 *ns;
};

struct pid_namespace___48 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___59 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___48 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___48 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___48 numbers[1];
};

struct kern_ipc_perm {
	spinlock_t lock;
	bool deleted;
	int id;
	key_t key;
	kuid_t uid;
	kgid_t gid;
	kuid_t cuid;
	kgid_t cgid;
	umode_t mode;
	long unsigned int seq;
	void *security;
	struct rhash_head khtnode;
	struct callback_head rcu;
	refcount_t refcount;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___58 *pgtable_t___58;

struct page_pool___15;

struct dev_pagemap___52;

struct page___58 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___53 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___15 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___58 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___58 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___59 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___52 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___52;

struct vm_area_struct___58 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___58 *vm_next;
	struct vm_area_struct___58 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___59 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___52 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___54 *vm_file;
	struct file___54 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___9;

struct signal_struct___54 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___59 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___59 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___48 *pids[4];
	struct pid___48 *tty_old_pgrp;
	int leader;
	struct tty_struct___9 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___59 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___12;

struct core_state___58;

struct mm_struct___59 {
	struct {
		struct vm_area_struct___58 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___54 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___12 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___58 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___59 *owner;
		struct user_namespace___10 *user_ns;
		struct file___54 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fs_struct___9 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___53 root;
	struct path___53 pwd;
};

struct cgroup_namespace___44;

struct nsproxy___53 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___48 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___44 *cgroup_ns;
};

struct audit_context {
	int dummy;
	int in_syscall;
	enum audit_state state;
	enum audit_state current_state;
	unsigned int serial;
	int major;
	struct timespec64 ctime;
	long unsigned int argv[4];
	long int return_code;
	u64 prio;
	int return_valid;
	struct audit_names preallocated_names[5];
	int name_count;
	struct list_head names_list;
	char *filterkey;
	struct path___53 pwd;
	struct audit_aux_data *aux;
	struct audit_aux_data *aux_pids;
	struct __kernel_sockaddr_storage *sockaddr;
	size_t sockaddr_len;
	pid_t pid;
	pid_t ppid;
	kuid_t uid;
	kuid_t euid;
	kuid_t suid;
	kuid_t fsuid;
	kgid_t gid;
	kgid_t egid;
	kgid_t sgid;
	kgid_t fsgid;
	long unsigned int personality;
	int arch;
	pid_t target_pid;
	kuid_t target_auid;
	kuid_t target_uid;
	unsigned int target_sessionid;
	struct lsmblob target_lsm;
	char target_comm[16];
	struct audit_tree_refs *trees;
	struct audit_tree_refs *first_trees;
	struct list_head killed_trees;
	int tree_count;
	int type;
	union {
		struct {
			int nargs;
			long int args[6];
		} socketcall;
		struct {
			kuid_t uid;
			kgid_t gid;
			umode_t mode;
			struct lsmblob oblob;
			int has_perm;
			uid_t perm_uid;
			gid_t perm_gid;
			umode_t perm_mode;
			long unsigned int qbytes;
		} ipc;
		struct {
			mqd_t mqdes;
			struct mq_attr mqstat;
		} mq_getsetattr;
		struct {
			mqd_t mqdes;
			int sigev_signo;
		} mq_notify;
		struct {
			mqd_t mqdes;
			size_t msg_len;
			unsigned int msg_prio;
			struct timespec64 abs_timeout;
		} mq_sendrecv;
		struct {
			int oflag;
			umode_t mode;
			struct mq_attr attr;
		} mq_open;
		struct {
			pid_t pid;
			struct audit_cap_data cap;
		} capset;
		struct {
			int fd;
			int flags;
		} mmap;
		struct {
			int argc;
		} execve;
		struct {
			char *name;
		} module;
		struct {
			struct audit_ntp_data ntp_data;
			struct timespec64 tk_injoffset;
		} time;
	};
	int fds[2];
	struct audit_proctitle proctitle;
};

struct cgroup_subsys_state___44;

struct cgroup___44;

struct css_set___44 {
	struct cgroup_subsys_state___44 *subsys[14];
	refcount_t refcount;
	struct css_set___44 *dom_cset;
	struct cgroup___44 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___44 *mg_src_cgrp;
	struct cgroup___44 *mg_dst_cgrp;
	struct css_set___44 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___36 {
	struct pmu___36 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___59 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___36 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___16;

struct pipe_inode_info___16 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___58 *tmp_page;
	struct fasync_struct___53 *fasync_readers;
	struct fasync_struct___53 *fasync_writers;
	struct pipe_buffer___16 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___55 {
	struct vm_struct___55 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___58 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct device___48;

struct page_pool_params___15 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___48 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___15 {
	u32 count;
	struct page___58 *cache[128];
};

struct page_pool___15 {
	struct page_pool_params___15 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___58 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___15 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___52;

struct dev_pagemap___52 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___52 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___48 {
	rwlock_t lock;
	struct pid___48 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___54 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___53 f_path;
	struct inode___54 *f_inode;
	const struct file_operations___53 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___48 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___53 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___52;

struct vm_operations_struct___52 {
	void (*open)(struct vm_area_struct___58 *);
	void (*close)(struct vm_area_struct___58 *);
	int (*may_split)(struct vm_area_struct___58 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___58 *);
	int (*mprotect)(struct vm_area_struct___58 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___52 *);
	vm_fault_t (*huge_fault)(struct vm_fault___52 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___52 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___58 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___52 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___52 *);
	int (*access)(struct vm_area_struct___58 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___58 *);
	int (*set_policy)(struct vm_area_struct___58 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___58 *, long unsigned int);
	struct page___58 * (*find_special_page)(struct vm_area_struct___58 *, long unsigned int);
};

struct core_thread___58 {
	struct task_struct___59 *task;
	struct core_thread___58 *next;
};

struct core_state___58 {
	atomic_t nr_threads;
	struct core_thread___58 dumper;
	struct completion startup;
};

struct linux_binprm___13;

struct coredump_params___12;

struct linux_binfmt___12 {
	struct list_head lh;
	struct module___53 *module;
	int (*load_binary)(struct linux_binprm___13 *);
	int (*load_shlib)(struct file___54 *);
	int (*core_dump)(struct coredump_params___12 *);
	long unsigned int min_coredump;
};

struct vm_fault___52 {
	const struct {
		struct vm_area_struct___58 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___58 *cow_page;
	struct page___58 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___58 prealloc_pte;
};

struct cpu_vfs_cap_data {
	__u32 magic_etc;
	kernel_cap_t permitted;
	kernel_cap_t inheritable;
	kuid_t rootid;
};

struct cgroup_subsys___44;

struct cgroup_subsys_state___44 {
	struct cgroup___44 *cgroup;
	struct cgroup_subsys___44 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___44 *parent;
};

struct cgroup_file___44 {
	struct kernfs_node___54 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___44 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___59 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___44;

struct cgroup_rstat_cpu___44;

struct cgroup___44 {
	struct cgroup_subsys_state___44 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___54 *kn;
	struct cgroup_file___44 procs_file;
	struct cgroup_file___44 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___44 *subsys[14];
	struct cgroup_root___44 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___44 *dom_cgrp;
	struct cgroup___44 *old_dom_cgrp;
	struct cgroup_rstat_cpu___44 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___44 psi;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___9;

struct tty_operations___9;

struct tty_ldisc___9;

struct tty_port___9;

struct tty_struct___9 {
	int magic;
	struct kref kref;
	struct device___48 *dev;
	struct tty_driver___9 *driver;
	const struct tty_operations___9 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___9 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___48 *pgrp;
		struct pid___48 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___9 *link;
	struct fasync_struct___53 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___9 *port;
};

struct kiocb___53 {
	struct file___54 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___53 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___54 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___54 *ia_file;
};

struct dquot___53 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___54 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___53 {
	int qf_fmt_id;
	const struct quota_format_ops___53 *qf_ops;
	struct module___53 *qf_owner;
	struct quota_format_type___53 *qf_next;
};

struct quota_format_ops___53 {
	int (*check_quota_file)(struct super_block___54 *, int);
	int (*read_file_info)(struct super_block___54 *, int);
	int (*write_file_info)(struct super_block___54 *, int);
	int (*free_file_info)(struct super_block___54 *, int);
	int (*read_dqblk)(struct dquot___53 *);
	int (*commit_dqblk)(struct dquot___53 *);
	int (*release_dqblk)(struct dquot___53 *);
	int (*get_next_id)(struct super_block___54 *, struct kqid *);
};

struct dquot_operations___53 {
	int (*write_dquot)(struct dquot___53 *);
	struct dquot___53 * (*alloc_dquot)(struct super_block___54 *, int);
	void (*destroy_dquot)(struct dquot___53 *);
	int (*acquire_dquot)(struct dquot___53 *);
	int (*release_dquot)(struct dquot___53 *);
	int (*mark_dirty)(struct dquot___53 *);
	int (*write_info)(struct super_block___54 *, int);
	qsize_t * (*get_reserved_space)(struct inode___54 *);
	int (*get_projid)(struct inode___54 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___54 *, qsize_t *);
	int (*get_next_id)(struct super_block___54 *, struct kqid *);
};

struct quotactl_ops___53 {
	int (*quota_on)(struct super_block___54 *, int, int, const struct path___53 *);
	int (*quota_off)(struct super_block___54 *, int);
	int (*quota_enable)(struct super_block___54 *, unsigned int);
	int (*quota_disable)(struct super_block___54 *, unsigned int);
	int (*quota_sync)(struct super_block___54 *, int);
	int (*set_info)(struct super_block___54 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___54 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___54 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___54 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___54 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___54 *, unsigned int);
};

struct address_space_operations___53 {
	int (*writepage)(struct page___58 *, struct writeback_control___3 *);
	int (*readpage)(struct file___54 *, struct page___58 *);
	int (*writepages)(struct address_space___53 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___58 *);
	int (*readpages)(struct file___54 *, struct address_space___53 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___54 *, struct address_space___53 *, loff_t, unsigned int, unsigned int, struct page___58 **, void **);
	int (*write_end)(struct file___54 *, struct address_space___53 *, loff_t, unsigned int, unsigned int, struct page___58 *, void *);
	sector_t (*bmap)(struct address_space___53 *, sector_t);
	void (*invalidatepage)(struct page___58 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___58 *, gfp_t);
	void (*freepage)(struct page___58 *);
	ssize_t (*direct_IO)(struct kiocb___53 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___53 *, struct page___58 *, struct page___58 *, enum migrate_mode);
	bool (*isolate_page)(struct page___58 *, isolate_mode_t);
	void (*putback_page)(struct page___58 *);
	int (*launder_page)(struct page___58 *);
	int (*is_partially_uptodate)(struct page___58 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___58 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___53 *, struct page___58 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___54 *, sector_t *);
	void (*swap_deactivate)(struct file___54 *);
};

struct bio_vec___28;

struct iov_iter___28 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___28 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___16 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___19 {
	struct kobject___54 kobj;
	struct module___53 *owner;
	const struct file_operations___53 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___53 {
	struct dentry___54 * (*lookup)(struct inode___54 *, struct dentry___54 *, unsigned int);
	const char * (*get_link)(struct dentry___54 *, struct inode___54 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___54 *, int);
	struct posix_acl * (*get_acl)(struct inode___54 *, int, bool);
	int (*readlink)(struct dentry___54 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___54 *, struct dentry___54 *, umode_t, bool);
	int (*link)(struct dentry___54 *, struct inode___54 *, struct dentry___54 *);
	int (*unlink)(struct inode___54 *, struct dentry___54 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___54 *, struct dentry___54 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___54 *, struct dentry___54 *, umode_t);
	int (*rmdir)(struct inode___54 *, struct dentry___54 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___54 *, struct dentry___54 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___54 *, struct dentry___54 *, struct inode___54 *, struct dentry___54 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___54 *, struct iattr___54 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___53 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___54 *, char *, size_t);
	int (*fiemap)(struct inode___54 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___54 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___54 *, struct dentry___54 *, struct file___54 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___54 *, struct dentry___54 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___54 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___54 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___54 *, struct fileattr *);
	long: 64;
};

typedef struct fsnotify_mark_connector *fsnotify_connp_t;

struct fsnotify_mark_connector {
	spinlock_t lock;
	short unsigned int type;
	short unsigned int flags;
	__kernel_fsid_t fsid;
	union {
		fsnotify_connp_t *obj;
		struct fsnotify_mark_connector *destroy_next;
	};
	struct hlist_head list;
};

struct file_lock_operations___53 {
	void (*fl_copy_lock)(struct file_lock___53 *, struct file_lock___53 *);
	void (*fl_release_private)(struct file_lock___53 *);
};

struct lock_manager_operations___53;

struct file_lock___53 {
	struct file_lock___53 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___54 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___53 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___53 *fl_ops;
	const struct lock_manager_operations___53 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___53 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___53 *);
	int (*lm_grant)(struct file_lock___53 *, int);
	bool (*lm_break)(struct file_lock___53 *);
	int (*lm_change)(struct file_lock___53 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___53 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___53 *);
};

struct fasync_struct___53 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___53 *fa_next;
	struct file___54 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___53 {
	struct inode___54 * (*alloc_inode)(struct super_block___54 *);
	void (*destroy_inode)(struct inode___54 *);
	void (*free_inode)(struct inode___54 *);
	void (*dirty_inode)(struct inode___54 *, int);
	int (*write_inode)(struct inode___54 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___54 *);
	void (*evict_inode)(struct inode___54 *);
	void (*put_super)(struct super_block___54 *);
	int (*sync_fs)(struct super_block___54 *, int);
	int (*freeze_super)(struct super_block___54 *);
	int (*freeze_fs)(struct super_block___54 *);
	int (*thaw_super)(struct super_block___54 *);
	int (*unfreeze_fs)(struct super_block___54 *);
	int (*statfs)(struct dentry___54 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___54 *, int *, char *);
	void (*umount_begin)(struct super_block___54 *);
	int (*show_options)(struct seq_file___52 *, struct dentry___54 *);
	int (*show_devname)(struct seq_file___52 *, struct dentry___54 *);
	int (*show_path)(struct seq_file___52 *, struct dentry___54 *);
	int (*show_stats)(struct seq_file___52 *, struct dentry___54 *);
	ssize_t (*quota_read)(struct super_block___54 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___54 *, int, const char *, size_t, loff_t);
	struct dquot___53 ** (*get_dquots)(struct inode___54 *);
	long int (*nr_cached_objects)(struct super_block___54 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___54 *, struct shrink_control___22 *);
	struct file___54 * (*real_loop)(struct file___54 *);
};

typedef void (*poll_queue_proc___39)(struct file___54 *, wait_queue_head_t *, struct poll_table_struct___39 *);

struct poll_table_struct___39 {
	poll_queue_proc___39 _qproc;
	__poll_t _key;
};

struct seq_operations___52;

struct seq_file___52 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___52 *op;
	int poll_event;
	const struct file___54 *file;
	void *private;
};

struct dev_pagemap_ops___52 {
	void (*page_free)(struct page___58 *);
	void (*kill)(struct dev_pagemap___52 *);
	void (*cleanup)(struct dev_pagemap___52 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___52 *);
};

struct bio_vec___28 {
	struct page___58 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct cgroup_namespace___44 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___44 *root_cset;
};

enum audit_nfcfgop {
	AUDIT_XT_OP_REGISTER = 0,
	AUDIT_XT_OP_REPLACE = 1,
	AUDIT_XT_OP_UNREGISTER = 2,
	AUDIT_NFT_OP_TABLE_REGISTER = 3,
	AUDIT_NFT_OP_TABLE_UNREGISTER = 4,
	AUDIT_NFT_OP_CHAIN_REGISTER = 5,
	AUDIT_NFT_OP_CHAIN_UNREGISTER = 6,
	AUDIT_NFT_OP_RULE_REGISTER = 7,
	AUDIT_NFT_OP_RULE_UNREGISTER = 8,
	AUDIT_NFT_OP_SET_REGISTER = 9,
	AUDIT_NFT_OP_SET_UNREGISTER = 10,
	AUDIT_NFT_OP_SETELEM_REGISTER = 11,
	AUDIT_NFT_OP_SETELEM_UNREGISTER = 12,
	AUDIT_NFT_OP_GEN_REGISTER = 13,
	AUDIT_NFT_OP_OBJ_REGISTER = 14,
	AUDIT_NFT_OP_OBJ_UNREGISTER = 15,
	AUDIT_NFT_OP_OBJ_RESET = 16,
	AUDIT_NFT_OP_FLOWTABLE_REGISTER = 17,
	AUDIT_NFT_OP_FLOWTABLE_UNREGISTER = 18,
	AUDIT_NFT_OP_INVALID = 19,
};

struct fwnode_operations___48;

struct fwnode_handle___48 {
	struct fwnode_handle___48 *secondary;
	const struct fwnode_operations___48 *ops;
	struct device___48 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___48;

struct fwnode_endpoint___48;

struct fwnode_operations___48 {
	struct fwnode_handle___48 * (*get)(struct fwnode_handle___48 *);
	void (*put)(struct fwnode_handle___48 *);
	bool (*device_is_available)(const struct fwnode_handle___48 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___48 *, const struct device___48 *);
	bool (*property_present)(const struct fwnode_handle___48 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___48 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___48 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___48 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*get_parent)(const struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*get_next_child_node)(const struct fwnode_handle___48 *, struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*get_named_child_node)(const struct fwnode_handle___48 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___48 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___48 *);
	struct fwnode_handle___48 * (*graph_get_next_endpoint)(const struct fwnode_handle___48 *, struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*graph_get_remote_endpoint)(const struct fwnode_handle___48 *);
	struct fwnode_handle___48 * (*graph_get_port_parent)(struct fwnode_handle___48 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___48 *, struct fwnode_endpoint___48 *);
	int (*add_links)(struct fwnode_handle___48 *);
};

struct wakeup_source___48;

struct dev_pm_info___48 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___48 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___48 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___48;

struct bus_type___48;

struct device_driver___48;

struct dev_pm_domain___48;

struct class___48;

struct attribute_group___54;

struct device___48 {
	struct kobject___54 kobj;
	struct device___48 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___48 *type;
	struct bus_type___48 *bus;
	struct device_driver___48 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___48 power;
	struct dev_pm_domain___48 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___48 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___48 *class;
	const struct attribute_group___54 **groups;
	void (*release)(struct device___48 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___48 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___48 *local_fwnode;
};

struct fwnode_reference_args___48 {
	struct fwnode_handle___48 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___54;

struct kernfs_elem_dir___54 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___54 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___54;

struct kernfs_root___54 {
	struct kernfs_node___54 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___54 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___54 {
	struct kernfs_node___54 *target_kn;
};

struct kernfs_ops___54;

struct kernfs_elem_attr___54 {
	const struct kernfs_ops___54 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___54 *notify_next;
};

struct kernfs_node___54 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___54 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___54 dir;
		struct kernfs_elem_symlink___54 symlink;
		struct kernfs_elem_attr___54 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___54;

struct kernfs_ops___54 {
	int (*open)(struct kernfs_open_file___54 *);
	void (*release)(struct kernfs_open_file___54 *);
	int (*seq_show)(struct seq_file___52 *, void *);
	void * (*seq_start)(struct seq_file___52 *, loff_t *);
	void * (*seq_next)(struct seq_file___52 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___52 *, void *);
	ssize_t (*read)(struct kernfs_open_file___54 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___54 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___54 *, struct poll_table_struct___39 *);
	int (*mmap)(struct kernfs_open_file___54 *, struct vm_area_struct___58 *);
};

struct kernfs_syscall_ops___54 {
	int (*show_options)(struct seq_file___52 *, struct kernfs_root___54 *);
	int (*mkdir)(struct kernfs_node___54 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___54 *);
	int (*rename)(struct kernfs_node___54 *, struct kernfs_node___54 *, const char *);
	int (*show_path)(struct seq_file___52 *, struct kernfs_node___54 *, struct kernfs_root___54 *);
};

struct kernfs_open_file___54 {
	struct kernfs_node___54 *kn;
	struct file___54 *file;
	struct seq_file___52 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___52 *vm_ops;
};

struct bin_attribute___54;

struct attribute_group___54 {
	const char *name;
	umode_t (*is_visible)(struct kobject___54 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___54 *, struct bin_attribute___54 *, int);
	struct attribute **attrs;
	struct bin_attribute___54 **bin_attrs;
};

struct bin_attribute___54 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___53 * (*f_mapping)();
	ssize_t (*read)(struct file___54 *, struct kobject___54 *, struct bin_attribute___54 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___54 *, struct kobject___54 *, struct bin_attribute___54 *, char *, loff_t, size_t);
	int (*mmap)(struct file___54 *, struct kobject___54 *, struct bin_attribute___54 *, struct vm_area_struct___58 *);
};

struct sysfs_ops___54 {
	ssize_t (*show)(struct kobject___54 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___54 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___54;

struct kset___54 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___54 kobj;
	const struct kset_uevent_ops___54 *uevent_ops;
};

struct kobj_type___54 {
	void (*release)(struct kobject___54 *);
	const struct sysfs_ops___54 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___54 **default_groups;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___54 *);
	const void * (*namespace)(struct kobject___54 *);
	void (*get_ownership)(struct kobject___54 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___54 {
	int (* const filter)(struct kset___54 *, struct kobject___54 *);
	const char * (* const name)(struct kset___54 *, struct kobject___54 *);
	int (* const uevent)(struct kset___54 *, struct kobject___54 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___51 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___51 *);
	int (*get)(char *, const struct kernel_param___51 *);
	void (*free)(void *);
};

struct kparam_array___51;

struct kernel_param___51 {
	const char *name;
	struct module___53 *mod;
	const struct kernel_param_ops___51 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___51 *arr;
	};
};

struct kparam_array___51 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___51 *ops;
	void *elem;
};

struct module_attribute___51 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___51 *, struct module_kobject___51 *, char *);
	ssize_t (*store)(struct module_attribute___51 *, struct module_kobject___51 *, const char *, size_t);
	void (*setup)(struct module___53 *, const char *);
	int (*test)(struct module___53 *);
	void (*free)(struct module___53 *);
};

struct trace_event_class___31;

struct trace_event_call___31 {
	struct list_head list;
	struct trace_event_class___31 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___31 *, struct perf_event___36 *);
};

struct dev_pm_ops___48 {
	int (*prepare)(struct device___48 *);
	void (*complete)(struct device___48 *);
	int (*suspend)(struct device___48 *);
	int (*resume)(struct device___48 *);
	int (*freeze)(struct device___48 *);
	int (*thaw)(struct device___48 *);
	int (*poweroff)(struct device___48 *);
	int (*restore)(struct device___48 *);
	int (*suspend_late)(struct device___48 *);
	int (*resume_early)(struct device___48 *);
	int (*freeze_late)(struct device___48 *);
	int (*thaw_early)(struct device___48 *);
	int (*poweroff_late)(struct device___48 *);
	int (*restore_early)(struct device___48 *);
	int (*suspend_noirq)(struct device___48 *);
	int (*resume_noirq)(struct device___48 *);
	int (*freeze_noirq)(struct device___48 *);
	int (*thaw_noirq)(struct device___48 *);
	int (*poweroff_noirq)(struct device___48 *);
	int (*restore_noirq)(struct device___48 *);
	int (*runtime_suspend)(struct device___48 *);
	int (*runtime_resume)(struct device___48 *);
	int (*runtime_idle)(struct device___48 *);
};

struct wakeup_source___48 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___48 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___48 {
	struct dev_pm_ops___48 ops;
	int (*start)(struct device___48 *);
	void (*detach)(struct device___48 *, bool);
	int (*activate)(struct device___48 *);
	void (*sync)(struct device___48 *);
	void (*dismiss)(struct device___48 *);
};

struct bus_type___48 {
	const char *name;
	const char *dev_name;
	struct device___48 *dev_root;
	const struct attribute_group___54 **bus_groups;
	const struct attribute_group___54 **dev_groups;
	const struct attribute_group___54 **drv_groups;
	int (*match)(struct device___48 *, struct device_driver___48 *);
	int (*uevent)(struct device___48 *, struct kobj_uevent_env *);
	int (*probe)(struct device___48 *);
	void (*sync_state)(struct device___48 *);
	void (*remove)(struct device___48 *);
	void (*shutdown)(struct device___48 *);
	int (*online)(struct device___48 *);
	int (*offline)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	int (*num_vf)(struct device___48 *);
	int (*dma_configure)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___48 {
	const char *name;
	struct bus_type___48 *bus;
	struct module___53 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___48 *);
	void (*sync_state)(struct device___48 *);
	int (*remove)(struct device___48 *);
	void (*shutdown)(struct device___48 *);
	int (*suspend)(struct device___48 *, pm_message_t);
	int (*resume)(struct device___48 *);
	const struct attribute_group___54 **groups;
	const struct attribute_group___54 **dev_groups;
	const struct dev_pm_ops___48 *pm;
	void (*coredump)(struct device___48 *);
	struct driver_private *p;
};

struct device_type___48 {
	const char *name;
	const struct attribute_group___54 **groups;
	int (*uevent)(struct device___48 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___48 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___48 *);
	const struct dev_pm_ops___48 *pm;
};

struct class___48 {
	const char *name;
	struct module___53 *owner;
	const struct attribute_group___54 **class_groups;
	const struct attribute_group___54 **dev_groups;
	struct kobject___54 *dev_kobj;
	int (*dev_uevent)(struct device___48 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___48 *, umode_t *);
	void (*class_release)(struct class___48 *);
	void (*dev_release)(struct device___48 *);
	int (*shutdown_pre)(struct device___48 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___48 *);
	void (*get_ownership)(struct device___48 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___48 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___16;

struct pipe_buffer___16 {
	struct page___58 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___16 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___16 {
	int (*confirm)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
	void (*release)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
	bool (*try_steal)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
	bool (*get)(struct pipe_inode_info___16 *, struct pipe_buffer___16 *);
};

struct linux_binprm___13 {
	struct vm_area_struct___58 *vma;
	long unsigned int vma_pages;
	struct mm_struct___59 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___54 *executable;
	struct file___54 *interpreter;
	struct file___54 *file;
	struct cred___9 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___12 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___54 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct seq_operations___52 {
	void * (*start)(struct seq_file___52 *, loff_t *);
	void (*stop)(struct seq_file___52 *, void *);
	void * (*next)(struct seq_file___52 *, void *, loff_t *);
	int (*show)(struct seq_file___52 *, void *);
};

struct cftype___44;

struct cgroup_subsys___44 {
	struct cgroup_subsys_state___44 * (*css_alloc)(struct cgroup_subsys_state___44 *);
	int (*css_online)(struct cgroup_subsys_state___44 *);
	void (*css_offline)(struct cgroup_subsys_state___44 *);
	void (*css_released)(struct cgroup_subsys_state___44 *);
	void (*css_free)(struct cgroup_subsys_state___44 *);
	void (*css_reset)(struct cgroup_subsys_state___44 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___44 *, int);
	int (*css_extra_stat_show)(struct seq_file___52 *, struct cgroup_subsys_state___44 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___59 *, struct css_set___44 *);
	void (*cancel_fork)(struct task_struct___59 *, struct css_set___44 *);
	void (*fork)(struct task_struct___59 *);
	void (*exit)(struct task_struct___59 *);
	void (*release)(struct task_struct___59 *);
	void (*bind)(struct cgroup_subsys_state___44 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___44 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___44 *dfl_cftypes;
	struct cftype___44 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___44 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___44 *updated_children;
	struct cgroup___44 *updated_next;
};

struct cgroup_root___44 {
	struct kernfs_root___54 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___44 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___44 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___44 *ss;
	struct list_head node;
	struct kernfs_ops___54 *kf_ops;
	int (*open)(struct kernfs_open_file___54 *);
	void (*release)(struct kernfs_open_file___54 *);
	u64 (*read_u64)(struct cgroup_subsys_state___44 *, struct cftype___44 *);
	s64 (*read_s64)(struct cgroup_subsys_state___44 *, struct cftype___44 *);
	int (*seq_show)(struct seq_file___52 *, void *);
	void * (*seq_start)(struct seq_file___52 *, loff_t *);
	void * (*seq_next)(struct seq_file___52 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___52 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___44 *, struct cftype___44 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___44 *, struct cftype___44 *, s64);
	ssize_t (*write)(struct kernfs_open_file___54 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___54 *, struct poll_table_struct___39 *);
};

struct perf_cpu_context___36;

struct perf_output_handle___36;

struct pmu___36 {
	struct list_head entry;
	struct module___53 *module;
	struct device___48 *dev;
	const struct attribute_group___54 **attr_groups;
	const struct attribute_group___54 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___36 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___36 *);
	void (*pmu_disable)(struct pmu___36 *);
	int (*event_init)(struct perf_event___36 *);
	void (*event_mapped)(struct perf_event___36 *, struct mm_struct___59 *);
	void (*event_unmapped)(struct perf_event___36 *, struct mm_struct___59 *);
	int (*add)(struct perf_event___36 *, int);
	void (*del)(struct perf_event___36 *, int);
	void (*start)(struct perf_event___36 *, int);
	void (*stop)(struct perf_event___36 *, int);
	void (*read)(struct perf_event___36 *);
	void (*start_txn)(struct pmu___36 *, unsigned int);
	int (*commit_txn)(struct pmu___36 *);
	void (*cancel_txn)(struct pmu___36 *);
	int (*event_idx)(struct perf_event___36 *);
	void (*sched_task)(struct perf_event_context___36 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___36 *, struct perf_event_context___36 *);
	void * (*setup_aux)(struct perf_event___36 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___36 *, struct perf_output_handle___36 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___36 *);
	int (*aux_output_match)(struct perf_event___36 *);
	int (*filter_match)(struct perf_event___36 *);
	int (*check_period)(struct perf_event___36 *, u64);
};

struct perf_cpu_context___36 {
	struct perf_event_context___36 ctx;
	struct perf_event_context___36 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___36 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___36 **heap;
	struct perf_event___36 *heap_default[2];
};

struct perf_output_handle___36 {
	struct perf_event___36 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___36 {
	struct cgroup_subsys_state___44 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___31 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___31 *);
	};
};

struct trace_event_class___31 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___31 *, enum trace_reg, void *);
	struct trace_event_fields___31 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___31 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___31 *);
};

enum fsnotify_obj_type {
	FSNOTIFY_OBJ_TYPE_INODE = 0,
	FSNOTIFY_OBJ_TYPE_PARENT = 1,
	FSNOTIFY_OBJ_TYPE_VFSMOUNT = 2,
	FSNOTIFY_OBJ_TYPE_SB = 3,
	FSNOTIFY_OBJ_TYPE_COUNT = 4,
	FSNOTIFY_OBJ_TYPE_DETACHED = 4,
};

struct tty_operations___9 {
	struct tty_struct___9 * (*lookup)(struct tty_driver___9 *, struct file___54 *, int);
	int (*install)(struct tty_driver___9 *, struct tty_struct___9 *);
	void (*remove)(struct tty_driver___9 *, struct tty_struct___9 *);
	int (*open)(struct tty_struct___9 *, struct file___54 *);
	void (*close)(struct tty_struct___9 *, struct file___54 *);
	void (*shutdown)(struct tty_struct___9 *);
	void (*cleanup)(struct tty_struct___9 *);
	int (*write)(struct tty_struct___9 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___9 *, unsigned char);
	void (*flush_chars)(struct tty_struct___9 *);
	unsigned int (*write_room)(struct tty_struct___9 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___9 *);
	int (*ioctl)(struct tty_struct___9 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___9 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___9 *, struct ktermios *);
	void (*throttle)(struct tty_struct___9 *);
	void (*unthrottle)(struct tty_struct___9 *);
	void (*stop)(struct tty_struct___9 *);
	void (*start)(struct tty_struct___9 *);
	void (*hangup)(struct tty_struct___9 *);
	int (*break_ctl)(struct tty_struct___9 *, int);
	void (*flush_buffer)(struct tty_struct___9 *);
	void (*set_ldisc)(struct tty_struct___9 *);
	void (*wait_until_sent)(struct tty_struct___9 *, int);
	void (*send_xchar)(struct tty_struct___9 *, char);
	int (*tiocmget)(struct tty_struct___9 *);
	int (*tiocmset)(struct tty_struct___9 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___9 *, struct winsize *);
	int (*get_icount)(struct tty_struct___9 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___9 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___9 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___9 *, struct seq_file___52 *);
	int (*poll_init)(struct tty_driver___9 *, int, char *);
	int (*poll_get_char)(struct tty_driver___9 *, int);
	void (*poll_put_char)(struct tty_driver___9 *, int, char);
	int (*proc_show)(struct seq_file___52 *, void *);
};

struct tty_driver___9 {
	int magic;
	struct kref kref;
	struct cdev___19 **cdevs;
	struct module___53 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___9 *other;
	struct tty_struct___9 **ttys;
	struct tty_port___9 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___9 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___9;

struct tty_port_client_operations___9;

struct tty_port___9 {
	struct tty_bufhead buf;
	struct tty_struct___9 *tty;
	struct tty_struct___9 *itty;
	const struct tty_port_operations___9 *ops;
	const struct tty_port_client_operations___9 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___9 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___9 *);
	void (*close)(struct tty_struct___9 *);
	void (*flush_buffer)(struct tty_struct___9 *);
	ssize_t (*read)(struct tty_struct___9 *, struct file___54 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___9 *, struct file___54 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___9 *, struct file___54 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___9 *, struct file___54 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___9 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___9 *, struct file___54 *, struct poll_table_struct___39 *);
	int (*hangup)(struct tty_struct___9 *);
	void (*receive_buf)(struct tty_struct___9 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___9 *);
	void (*dcd_change)(struct tty_struct___9 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___9 *, const unsigned char *, const char *, int);
	struct module___53 *owner;
};

struct tty_ldisc___9 {
	struct tty_ldisc_ops___9 *ops;
	struct tty_struct___9 *tty;
};

struct tty_port_operations___9 {
	int (*carrier_raised)(struct tty_port___9 *);
	void (*dtr_rts)(struct tty_port___9 *, int);
	void (*shutdown)(struct tty_port___9 *);
	int (*activate)(struct tty_port___9 *, struct tty_struct___9 *);
	void (*destruct)(struct tty_port___9 *);
};

struct tty_port_client_operations___9 {
	int (*receive_buf)(struct tty_port___9 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___9 *);
};

struct audit_aux_data {
	struct audit_aux_data *next;
	int type;
};

struct audit_chunk;

struct audit_tree_refs {
	struct audit_tree_refs *next;
	struct audit_chunk *c[31];
};

struct audit_aux_data_pids {
	struct audit_aux_data d;
	pid_t target_pid[16];
	kuid_t target_auid[16];
	kuid_t target_uid[16];
	unsigned int target_sessionid[16];
	struct lsmblob target_lsm[16];
	char target_comm[256];
	int pid_count;
};

struct audit_aux_data_bprm_fcaps {
	struct audit_aux_data d;
	struct audit_cap_data fcap;
	unsigned int fcap_ver;
	struct audit_cap_data old_pcap;
	struct audit_cap_data new_pcap;
};

struct audit_nfcfgop_tab {
	enum audit_nfcfgop op;
	const char *s;
};

struct audit_parent;

struct audit_watch {
	refcount_t count;
	dev_t dev;
	char *path;
	long unsigned int ino;
	struct audit_parent *parent;
	struct list_head wlist;
	struct list_head rules;
};

struct fsnotify_group;

struct fsnotify_iter_info;

struct fsnotify_mark;

struct fsnotify_event;

struct fsnotify_ops {
	int (*handle_event)(struct fsnotify_group *, u32, const void *, int, struct inode___54 *, const struct qstr *, u32, struct fsnotify_iter_info *);
	int (*handle_inode_event)(struct fsnotify_mark *, u32, struct inode___54 *, struct inode___54 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group *);
	void (*freeing_mark)(struct fsnotify_mark *, struct fsnotify_group *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark *);
};

struct inotify_group_private_data {
	spinlock_t idr_lock;
	struct idr idr;
	struct ucounts___10 *ucounts;
};

struct fanotify_group_private_data {
	struct hlist_head *merge_hash;
	struct list_head access_list;
	wait_queue_head_t access_waitq;
	int flags;
	int f_flags;
	struct ucounts___10 *ucounts;
};

struct fsnotify_group {
	const struct fsnotify_ops *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___53 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info {
	struct fsnotify_mark *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct fsnotify_event {
	struct list_head list;
};

struct audit_parent {
	struct list_head watches;
	struct fsnotify_mark mark;
};

struct audit_fsnotify_mark {
	dev_t dev;
	long unsigned int ino;
	char *path;
	struct fsnotify_mark mark;
	struct audit_krule *rule;
};

struct audit_chunk___2;

struct audit_tree {
	refcount_t count;
	int goner;
	struct audit_chunk___2 *root;
	struct list_head chunks;
	struct list_head rules;
	struct list_head list;
	struct list_head same_root;
	struct callback_head head;
	char pathname[0];
};

struct node {
	struct list_head list;
	struct audit_tree *owner;
	unsigned int index;
};

struct audit_chunk___2 {
	struct list_head hash;
	long unsigned int key;
	struct fsnotify_mark *mark;
	struct list_head trees;
	int count;
	atomic_long_t refs;
	struct callback_head head;
	struct node owners[0];
};

struct audit_tree_mark {
	struct fsnotify_mark mark;
	struct audit_chunk___2 *chunk;
};

enum {
	HASH_SIZE = 128,
};

struct prev_kprobe___2 {
	struct kprobe___2 *kp;
	unsigned int status;
};

struct kprobe_ctlblk___2 {
	unsigned int kprobe_status;
	long unsigned int saved_irqflag;
	struct prev_kprobe___2 prev_kprobe;
};

struct kretprobe_instance___2;

typedef int (*kretprobe_handler_t___2)(struct kretprobe_instance___2 *, struct pt_regs *);

struct kretprobe_holder___2;

struct kretprobe_instance___2 {
	union {
		struct freelist_node freelist;
		struct callback_head rcu;
	};
	struct llist_node llist;
	struct kretprobe_holder___2 *rph;
	kprobe_opcode_t *ret_addr;
	void *fp;
	char data[0];
};

struct kretprobe___2;

struct kretprobe_holder___2 {
	struct kretprobe___2 *rp;
	refcount_t ref;
};

struct kretprobe___2 {
	struct kprobe___2 kp;
	kretprobe_handler_t___2 handler;
	kretprobe_handler_t___2 entry_handler;
	int maxactive;
	int nmissed;
	size_t data_size;
	struct freelist_head freelist;
	struct kretprobe_holder___2 *rph;
};

struct kprobe_blacklist_entry {
	struct list_head list;
	long unsigned int start_addr;
	long unsigned int end_addr;
};

enum perf_record_ksymbol_type {
	PERF_RECORD_KSYMBOL_TYPE_UNKNOWN = 0,
	PERF_RECORD_KSYMBOL_TYPE_BPF = 1,
	PERF_RECORD_KSYMBOL_TYPE_OOL = 2,
	PERF_RECORD_KSYMBOL_TYPE_MAX = 3,
};

struct kprobe_insn_page {
	struct list_head list;
	kprobe_opcode_t *insns;
	struct kprobe_insn_cache *cache;
	int nused;
	int ngarbage;
	char slot_used[0];
};

enum kprobe_slot_state {
	SLOT_CLEAN = 0,
	SLOT_DIRTY = 1,
	SLOT_USED = 2,
};

struct console___2 {
	char name[16];
	void (*write)(struct console___2 *, const char *, unsigned int);
	int (*read)(struct console___2 *, char *, unsigned int);
	struct tty_driver___2 * (*device)(struct console___2 *, int *);
	void (*unblank)();
	int (*setup)(struct console___2 *, char *);
	int (*exit)(struct console___2 *);
	int (*match)(struct console___2 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___2 *next;
};

struct kgdb_io {
	const char *name;
	int (*read_char)();
	void (*write_char)(u8);
	void (*flush)();
	int (*init)();
	void (*deinit)();
	void (*pre_exception)();
	void (*post_exception)();
	struct console___2 *cons;
};

enum {
	KDB_NOT_INITIALIZED = 0,
	KDB_INIT_EARLY = 1,
	KDB_INIT_FULL = 2,
};

struct kgdb_state {
	int ex_vector;
	int signo;
	int err_code;
	int cpu;
	int pass_exception;
	long unsigned int thr_query;
	long unsigned int threadid;
	long int kgdb_usethreadid;
	struct pt_regs *linux_regs;
	atomic_t *send_ready;
};

struct debuggerinfo_struct {
	void *debuggerinfo;
	struct task_struct___59 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
	bool rounding_up;
};

typedef int (*get_char_func)();

struct module_use___2 {
	struct list_head source_list;
	struct list_head target_list;
	struct module___16 *source;
	struct module___16 *target;
};

typedef enum {
	KDB_ENABLE_ALL = 1,
	KDB_ENABLE_MEM_READ = 2,
	KDB_ENABLE_MEM_WRITE = 4,
	KDB_ENABLE_REG_READ = 8,
	KDB_ENABLE_REG_WRITE = 16,
	KDB_ENABLE_INSPECT = 32,
	KDB_ENABLE_FLOW_CTRL = 64,
	KDB_ENABLE_SIGNAL = 128,
	KDB_ENABLE_REBOOT = 256,
	KDB_ENABLE_ALWAYS_SAFE = 512,
	KDB_ENABLE_MASK = 1023,
	KDB_ENABLE_ALL_NO_ARGS = 1024,
	KDB_ENABLE_MEM_READ_NO_ARGS = 2048,
	KDB_ENABLE_MEM_WRITE_NO_ARGS = 4096,
	KDB_ENABLE_REG_READ_NO_ARGS = 8192,
	KDB_ENABLE_REG_WRITE_NO_ARGS = 16384,
	KDB_ENABLE_INSPECT_NO_ARGS = 32768,
	KDB_ENABLE_FLOW_CTRL_NO_ARGS = 65536,
	KDB_ENABLE_SIGNAL_NO_ARGS = 131072,
	KDB_ENABLE_REBOOT_NO_ARGS = 262144,
	KDB_ENABLE_ALWAYS_SAFE_NO_ARGS = 524288,
	KDB_ENABLE_MASK_NO_ARGS = 1047552,
	KDB_REPEAT_NO_ARGS = 1073741824,
	KDB_REPEAT_WITH_ARGS = 2147483648,
} kdb_cmdflags_t;

typedef int (*kdb_func_t)(int, const char **);

struct _kdbtab {
	char *name;
	kdb_func_t func;
	char *usage;
	char *help;
	short int minlen;
	kdb_cmdflags_t flags;
	struct list_head list_node;
};

typedef struct _kdbtab kdbtab_t;

typedef enum {
	KDB_REASON_ENTER = 1,
	KDB_REASON_ENTER_SLAVE = 2,
	KDB_REASON_BREAK = 3,
	KDB_REASON_DEBUG = 4,
	KDB_REASON_OOPS = 5,
	KDB_REASON_SWITCH = 6,
	KDB_REASON_KEYBOARD = 7,
	KDB_REASON_NMI = 8,
	KDB_REASON_RECURSE = 9,
	KDB_REASON_SSTEP = 10,
	KDB_REASON_SYSTEM_NMI = 11,
} kdb_reason_t;

struct debuggerinfo_struct___2 {
	void *debuggerinfo;
	struct task_struct___16 *task;
	int exception_state;
	int ret_state;
	int irq_depth;
	int enter_kgdb;
	bool rounding_up;
};

struct __ksymtab {
	long unsigned int value;
	const char *mod_name;
	long unsigned int mod_start;
	long unsigned int mod_end;
	const char *sec_name;
	long unsigned int sec_start;
	long unsigned int sec_end;
	const char *sym_name;
	long unsigned int sym_start;
	long unsigned int sym_end;
};

typedef struct __ksymtab kdb_symtab_t;

typedef enum {
	KDB_DB_BPT = 0,
	KDB_DB_SS = 1,
	KDB_DB_SSBPT = 2,
	KDB_DB_NOBPT = 3,
} kdb_dbtrap_t;

struct _kdbmsg {
	int km_diag;
	char *km_msg;
};

typedef struct _kdbmsg kdbmsg_t;

struct kdb_macro {
	kdbtab_t cmd;
	struct list_head statements;
};

struct kdb_macro_statement {
	char *statement;
	struct list_head list_node;
};

struct kgdb_arch___2 {
	unsigned char gdb_bpt_instr[4];
	long unsigned int flags;
	int (*set_breakpoint)(long unsigned int, char *);
	int (*remove_breakpoint)(long unsigned int, char *);
	int (*set_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	int (*remove_hw_breakpoint)(long unsigned int, int, enum kgdb_bptype);
	void (*disable_hw_break)(struct pt_regs___2 *);
	void (*remove_all_hw_break)();
	void (*correct_hw_break)();
	void (*enable_nmi)(bool);
};

struct _kdb_bp {
	long unsigned int bp_addr;
	unsigned int bp_free: 1;
	unsigned int bp_enabled: 1;
	unsigned int bp_type: 4;
	unsigned int bp_installed: 1;
	unsigned int bp_delay: 1;
	unsigned int bp_delayed: 1;
	long: 31;
	long: 64;
	unsigned int bph_length;
};

typedef struct _kdb_bp kdb_bp_t;

typedef short unsigned int u_short;

struct seccomp_notif_sizes {
	__u16 seccomp_notif;
	__u16 seccomp_notif_resp;
	__u16 seccomp_data;
};

struct seccomp_notif {
	__u64 id;
	__u32 pid;
	__u32 flags;
	struct seccomp_data data;
};

struct seccomp_notif_resp {
	__u64 id;
	__s64 val;
	__s32 error;
	__u32 flags;
};

struct seccomp_notif_addfd {
	__u64 id;
	__u32 flags;
	__u32 srcfd;
	__u32 newfd;
	__u32 newfd_flags;
};

struct action_cache {
	long unsigned int allow_native[8];
	long unsigned int allow_compat[8];
};

struct notification;

struct seccomp_filter {
	refcount_t refs;
	refcount_t users;
	bool log;
	struct action_cache cache;
	struct seccomp_filter *prev;
	struct bpf_prog___4 *prog;
	struct notification *notif;
	struct mutex notify_lock;
	wait_queue_head_t wqh;
};

struct seccomp_metadata {
	__u64 filter_off;
	__u64 flags;
};

typedef struct poll_table_struct___26 poll_table___8;

struct sock_fprog {
	short unsigned int len;
	struct sock_filter *filter;
};

struct compat_sock_fprog {
	u16 len;
	compat_uptr_t filter;
};

typedef unsigned int (*bpf_dispatcher_fn)(const void *, const struct bpf_insn *, unsigned int (*)(const void *, const struct bpf_insn *));

typedef int (*bpf_aux_classic_check_t)(struct sock_filter *, unsigned int);

enum notify_state {
	SECCOMP_NOTIFY_INIT = 0,
	SECCOMP_NOTIFY_SENT = 1,
	SECCOMP_NOTIFY_REPLIED = 2,
};

struct seccomp_knotif {
	struct task_struct___35 *task;
	u64 id;
	const struct seccomp_data *data;
	enum notify_state state;
	int error;
	long int val;
	u32 flags;
	struct completion ready;
	struct list_head list;
	struct list_head addfd;
};

struct seccomp_kaddfd {
	struct file___34 *file;
	int fd;
	unsigned int flags;
	__u32 ioctl_flags;
	union {
		bool setfd;
		int ret;
	};
	struct completion completion;
	struct list_head list;
};

struct notification {
	struct semaphore request;
	u64 next_id;
	struct list_head notifications;
};

struct seccomp_log_name {
	u32 log;
	const char *name;
};

struct dentry___55;

struct super_block___55;

struct file_system_type___54 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___55 * (*mount)(struct file_system_type___54 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___55 *);
	struct module___8 *owner;
	struct file_system_type___54 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___55;

struct kiocb___54;

struct poll_table_struct___40;

struct vm_area_struct___59;

struct inode___55;

struct file_lock___54;

struct page___59;

struct pipe_inode_info___17;

struct file_operations___54 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___55 *, loff_t, int);
	ssize_t (*read)(struct file___55 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___55 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___54 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___54 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___54 *, bool);
	int (*iterate)(struct file___55 *, struct dir_context *);
	int (*iterate_shared)(struct file___55 *, struct dir_context *);
	__poll_t (*poll)(struct file___55 *, struct poll_table_struct___40 *);
	long int (*unlocked_ioctl)(struct file___55 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___55 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___55 *, struct vm_area_struct___59 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___55 *, struct file___55 *);
	int (*flush)(struct file___55 *, fl_owner_t);
	int (*release)(struct inode___55 *, struct file___55 *);
	int (*fsync)(struct file___55 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___55 *, int);
	int (*lock)(struct file___55 *, int, struct file_lock___54 *);
	ssize_t (*sendpage)(struct file___55 *, struct page___59 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___55 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___55 *, long unsigned int);
	int (*flock)(struct file___55 *, int, struct file_lock___54 *);
	ssize_t (*splice_write)(struct pipe_inode_info___17 *, struct file___55 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___55 *, loff_t *, struct pipe_inode_info___17 *, size_t, unsigned int);
	int (*setlease)(struct file___55 *, long int, struct file_lock___54 **, void **);
	long int (*fallocate)(struct file___55 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___55 *);
	ssize_t (*copy_file_range)(struct file___55 *, loff_t, struct file___55 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___55 *, loff_t, struct file___55 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___55 *, loff_t, loff_t, int);
};

struct vmacache___59 {
	u64 seqnum;
	struct vm_area_struct___59 *vmas[4];
};

struct page_frag___59 {
	struct page___59 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___60;

struct signal_struct___55;

struct vm_struct___56;

struct task_struct___60 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___60 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___60 *mm;
	struct mm_struct___60 *active_mm;
	struct vmacache___59 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___60 *real_parent;
	struct task_struct___60 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___60 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___48 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___55 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___60 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___25 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___17 *splice_pipe;
	struct page_frag___59 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___60 *oom_reaper_list;
	struct vm_struct___56 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___36 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___59 *pgtable_t___59;

struct address_space___54;

struct dev_pagemap___53;

struct page___59 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___54 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___15 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___59 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___59 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___60 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___53 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___53;

struct vm_area_struct___59 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___59 *vm_next;
	struct vm_area_struct___59 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___60 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___53 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___55 *vm_file;
	struct file___55 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___59;

struct mm_struct___60 {
	struct {
		struct vm_area_struct___59 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___55 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___59 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___60 *owner;
		struct user_namespace *user_ns;
		struct file___55 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___54;

struct address_space___54 {
	struct inode___55 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___54 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___53;

struct dev_pagemap___53 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___53 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___54;

struct path___54 {
	struct vfsmount___54 *mnt;
	struct dentry___55 *dentry;
};

struct file___55 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___54 f_path;
	struct inode___55 *f_inode;
	const struct file_operations___54 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___48 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___54 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___53;

struct vm_operations_struct___53 {
	void (*open)(struct vm_area_struct___59 *);
	void (*close)(struct vm_area_struct___59 *);
	int (*may_split)(struct vm_area_struct___59 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___59 *);
	int (*mprotect)(struct vm_area_struct___59 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___53 *);
	vm_fault_t (*huge_fault)(struct vm_fault___53 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___53 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___59 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___53 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___53 *);
	int (*access)(struct vm_area_struct___59 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___59 *);
	int (*set_policy)(struct vm_area_struct___59 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___59 *, long unsigned int);
	struct page___59 * (*find_special_page)(struct vm_area_struct___59 *, long unsigned int);
};

struct core_thread___59 {
	struct task_struct___60 *task;
	struct core_thread___59 *next;
};

struct core_state___59 {
	atomic_t nr_threads;
	struct core_thread___59 dumper;
	struct completion startup;
};

struct vm_fault___53 {
	const struct {
		struct vm_area_struct___59 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___59 *cow_page;
	struct page___59 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___59 prealloc_pte;
};

struct signal_struct___55 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___60 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___60 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___48 *pids[4];
	struct pid___48 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___60 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fasync_struct___54;

struct pipe_buffer___17;

struct pipe_inode_info___17 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___59 *tmp_page;
	struct fasync_struct___54 *fasync_readers;
	struct fasync_struct___54 *fasync_writers;
	struct pipe_buffer___17 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___56 {
	struct vm_struct___56 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___59 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___54;

struct dentry___55 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___55 *d_parent;
	struct qstr d_name;
	struct inode___55 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___54 *d_op;
	struct super_block___55 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___54;

struct inode___55 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___54 *i_op;
	struct super_block___55 *i_sb;
	struct address_space___54 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___54 *i_fop;
		void (*free_inode)(struct inode___55 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___54 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___17 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___54 {
	int (*d_revalidate)(struct dentry___55 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___55 *, unsigned int);
	int (*d_hash)(const struct dentry___55 *, struct qstr *);
	int (*d_compare)(const struct dentry___55 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___55 *);
	int (*d_init)(struct dentry___55 *);
	void (*d_release)(struct dentry___55 *);
	void (*d_prune)(struct dentry___55 *);
	void (*d_iput)(struct dentry___55 *, struct inode___55 *);
	char * (*d_dname)(struct dentry___55 *, char *, int);
	struct vfsmount___54 * (*d_automount)(struct path___54 *);
	int (*d_manage)(const struct path___54 *, bool);
	struct dentry___55 * (*d_real)(struct dentry___55 *, const struct inode___55 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___54;

struct mem_dqinfo___54 {
	struct quota_format_type___54 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___54;

struct quota_info___54 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___55 *files[3];
	struct mem_dqinfo___54 info[3];
	const struct quota_format_ops___54 *ops[3];
};

struct rcuwait___55 {
	struct task_struct___60 *task;
};

struct percpu_rw_semaphore___55 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___55 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___54 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___55 rw_sem[3];
};

struct super_operations___54;

struct dquot_operations___54;

struct quotactl_ops___54;

struct super_block___55 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___54 *s_type;
	const struct super_operations___54 *s_op;
	const struct dquot_operations___54 *dq_op;
	const struct quotactl_ops___54 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___55 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___54 s_dquot;
	struct sb_writers___54 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___54 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___54 {
	struct dentry___55 *mnt_root;
	struct super_block___55 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___54 {
	struct file___55 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___54 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___55 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___55 *ia_file;
};

struct dquot___54 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___55 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___54 {
	int qf_fmt_id;
	const struct quota_format_ops___54 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___54 *qf_next;
};

struct quota_format_ops___54 {
	int (*check_quota_file)(struct super_block___55 *, int);
	int (*read_file_info)(struct super_block___55 *, int);
	int (*write_file_info)(struct super_block___55 *, int);
	int (*free_file_info)(struct super_block___55 *, int);
	int (*read_dqblk)(struct dquot___54 *);
	int (*commit_dqblk)(struct dquot___54 *);
	int (*release_dqblk)(struct dquot___54 *);
	int (*get_next_id)(struct super_block___55 *, struct kqid *);
};

struct dquot_operations___54 {
	int (*write_dquot)(struct dquot___54 *);
	struct dquot___54 * (*alloc_dquot)(struct super_block___55 *, int);
	void (*destroy_dquot)(struct dquot___54 *);
	int (*acquire_dquot)(struct dquot___54 *);
	int (*release_dquot)(struct dquot___54 *);
	int (*mark_dirty)(struct dquot___54 *);
	int (*write_info)(struct super_block___55 *, int);
	qsize_t * (*get_reserved_space)(struct inode___55 *);
	int (*get_projid)(struct inode___55 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___55 *, qsize_t *);
	int (*get_next_id)(struct super_block___55 *, struct kqid *);
};

struct quotactl_ops___54 {
	int (*quota_on)(struct super_block___55 *, int, int, const struct path___54 *);
	int (*quota_off)(struct super_block___55 *, int);
	int (*quota_enable)(struct super_block___55 *, unsigned int);
	int (*quota_disable)(struct super_block___55 *, unsigned int);
	int (*quota_sync)(struct super_block___55 *, int);
	int (*set_info)(struct super_block___55 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___55 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___55 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___55 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___55 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___55 *, unsigned int);
};

struct address_space_operations___54 {
	int (*writepage)(struct page___59 *, struct writeback_control___3 *);
	int (*readpage)(struct file___55 *, struct page___59 *);
	int (*writepages)(struct address_space___54 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___59 *);
	int (*readpages)(struct file___55 *, struct address_space___54 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___55 *, struct address_space___54 *, loff_t, unsigned int, unsigned int, struct page___59 **, void **);
	int (*write_end)(struct file___55 *, struct address_space___54 *, loff_t, unsigned int, unsigned int, struct page___59 *, void *);
	sector_t (*bmap)(struct address_space___54 *, sector_t);
	void (*invalidatepage)(struct page___59 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___59 *, gfp_t);
	void (*freepage)(struct page___59 *);
	ssize_t (*direct_IO)(struct kiocb___54 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___54 *, struct page___59 *, struct page___59 *, enum migrate_mode);
	bool (*isolate_page)(struct page___59 *, isolate_mode_t);
	void (*putback_page)(struct page___59 *);
	int (*launder_page)(struct page___59 *);
	int (*is_partially_uptodate)(struct page___59 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___59 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___54 *, struct page___59 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___55 *, sector_t *);
	void (*swap_deactivate)(struct file___55 *);
};

struct inode_operations___54 {
	struct dentry___55 * (*lookup)(struct inode___55 *, struct dentry___55 *, unsigned int);
	const char * (*get_link)(struct dentry___55 *, struct inode___55 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___55 *, int);
	struct posix_acl * (*get_acl)(struct inode___55 *, int, bool);
	int (*readlink)(struct dentry___55 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___55 *, struct dentry___55 *, umode_t, bool);
	int (*link)(struct dentry___55 *, struct inode___55 *, struct dentry___55 *);
	int (*unlink)(struct inode___55 *, struct dentry___55 *);
	int (*symlink)(struct user_namespace *, struct inode___55 *, struct dentry___55 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___55 *, struct dentry___55 *, umode_t);
	int (*rmdir)(struct inode___55 *, struct dentry___55 *);
	int (*mknod)(struct user_namespace *, struct inode___55 *, struct dentry___55 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___55 *, struct dentry___55 *, struct inode___55 *, struct dentry___55 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___55 *, struct iattr___55 *);
	int (*getattr)(struct user_namespace *, const struct path___54 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___55 *, char *, size_t);
	int (*fiemap)(struct inode___55 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___55 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___55 *, struct dentry___55 *, struct file___55 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___55 *, struct dentry___55 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___55 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___55 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___55 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___54 {
	void (*fl_copy_lock)(struct file_lock___54 *, struct file_lock___54 *);
	void (*fl_release_private)(struct file_lock___54 *);
};

struct lock_manager_operations___54;

struct file_lock___54 {
	struct file_lock___54 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___55 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___54 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___54 *fl_ops;
	const struct lock_manager_operations___54 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___54 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___54 *);
	int (*lm_grant)(struct file_lock___54 *, int);
	bool (*lm_break)(struct file_lock___54 *);
	int (*lm_change)(struct file_lock___54 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___54 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___54 *);
};

struct fasync_struct___54 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___54 *fa_next;
	struct file___55 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___54 {
	struct inode___55 * (*alloc_inode)(struct super_block___55 *);
	void (*destroy_inode)(struct inode___55 *);
	void (*free_inode)(struct inode___55 *);
	void (*dirty_inode)(struct inode___55 *, int);
	int (*write_inode)(struct inode___55 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___55 *);
	void (*evict_inode)(struct inode___55 *);
	void (*put_super)(struct super_block___55 *);
	int (*sync_fs)(struct super_block___55 *, int);
	int (*freeze_super)(struct super_block___55 *);
	int (*freeze_fs)(struct super_block___55 *);
	int (*thaw_super)(struct super_block___55 *);
	int (*unfreeze_fs)(struct super_block___55 *);
	int (*statfs)(struct dentry___55 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___55 *, int *, char *);
	void (*umount_begin)(struct super_block___55 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___55 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___55 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___55 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___55 *);
	ssize_t (*quota_read)(struct super_block___55 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___55 *, int, const char *, size_t, loff_t);
	struct dquot___54 ** (*get_dquots)(struct inode___55 *);
	long int (*nr_cached_objects)(struct super_block___55 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___55 *, struct shrink_control___22 *);
	struct file___55 * (*real_loop)(struct file___55 *);
};

typedef void (*poll_queue_proc___40)(struct file___55 *, wait_queue_head_t *, struct poll_table_struct___40 *);

struct poll_table_struct___40 {
	poll_queue_proc___40 _qproc;
	__poll_t _key;
};

typedef struct poll_table_struct___40 poll_table___9;

struct rchan;

struct rchan_buf {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___55 *dentry;
	struct kref kref;
	struct page___59 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks;

struct rchan {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf **buf;
	int is_global;
	struct list_head list;
	struct dentry___55 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks {
	int (*subbuf_start)(struct rchan_buf *, void *, void *, size_t);
	struct dentry___55 * (*create_buf_file)(const char *, struct dentry___55 *, umode_t, struct rchan_buf *, int *);
	int (*remove_buf_file)(struct dentry___55 *);
};

struct dev_pagemap_ops___53 {
	void (*page_free)(struct page___59 *);
	void (*kill)(struct dev_pagemap___53 *);
	void (*cleanup)(struct dev_pagemap___53 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___53 *);
};

struct pipe_buf_operations___17;

struct pipe_buffer___17 {
	struct page___59 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___17 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___17 {
	int (*confirm)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
	void (*release)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
	bool (*try_steal)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
	bool (*get)(struct pipe_inode_info___17 *, struct pipe_buffer___17 *);
};

struct partial_page {
	unsigned int offset;
	unsigned int len;
	long unsigned int private;
};

struct splice_pipe_desc {
	struct page___59 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___17 *ops;
	void (*spd_release)(struct splice_pipe_desc *, unsigned int);
};

struct rchan_percpu_buf_dispatcher {
	struct rchan_buf *buf;
	struct dentry___55 *dentry;
};

enum {
	TASKSTATS_TYPE_UNSPEC = 0,
	TASKSTATS_TYPE_PID = 1,
	TASKSTATS_TYPE_TGID = 2,
	TASKSTATS_TYPE_STATS = 3,
	TASKSTATS_TYPE_AGGR_PID = 4,
	TASKSTATS_TYPE_AGGR_TGID = 5,
	TASKSTATS_TYPE_NULL = 6,
	__TASKSTATS_TYPE_MAX = 7,
};

enum {
	TASKSTATS_CMD_ATTR_UNSPEC = 0,
	TASKSTATS_CMD_ATTR_PID = 1,
	TASKSTATS_CMD_ATTR_TGID = 2,
	TASKSTATS_CMD_ATTR_REGISTER_CPUMASK = 3,
	TASKSTATS_CMD_ATTR_DEREGISTER_CPUMASK = 4,
	__TASKSTATS_CMD_ATTR_MAX = 5,
};

enum {
	CGROUPSTATS_CMD_UNSPEC = 3,
	CGROUPSTATS_CMD_GET = 4,
	CGROUPSTATS_CMD_NEW = 5,
	__CGROUPSTATS_CMD_MAX = 6,
};

enum {
	CGROUPSTATS_TYPE_UNSPEC = 0,
	CGROUPSTATS_TYPE_CGROUP_STATS = 1,
	__CGROUPSTATS_TYPE_MAX = 2,
};

enum {
	CGROUPSTATS_CMD_ATTR_UNSPEC = 0,
	CGROUPSTATS_CMD_ATTR_FD = 1,
	__CGROUPSTATS_CMD_ATTR_MAX = 2,
};

struct genlmsghdr {
	__u8 cmd;
	__u8 version;
	__u16 reserved;
};

enum {
	NLA_UNSPEC = 0,
	NLA_U8 = 1,
	NLA_U16 = 2,
	NLA_U32 = 3,
	NLA_U64 = 4,
	NLA_STRING = 5,
	NLA_FLAG = 6,
	NLA_MSECS = 7,
	NLA_NESTED = 8,
	NLA_NESTED_ARRAY = 9,
	NLA_NUL_STRING = 10,
	NLA_BINARY = 11,
	NLA_S8 = 12,
	NLA_S16 = 13,
	NLA_S32 = 14,
	NLA_S64 = 15,
	NLA_BITFIELD32 = 16,
	NLA_REJECT = 17,
	__NLA_TYPE_MAX = 18,
};

struct genl_multicast_group {
	char name[16];
	u8 flags;
};

struct genl_ops;

struct genl_info;

struct genl_small_ops;

struct genl_family {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops *, struct sk_buff___8 *, struct genl_info *);
	void (*post_doit)(const struct genl_ops *, struct sk_buff___8 *, struct genl_info *);
	const struct genl_ops *ops;
	const struct genl_small_ops *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___52 *module;
};

struct genl_ops {
	int (*doit)(struct sk_buff___8 *, struct genl_info *);
	int (*start)(struct netlink_callback___6 *);
	int (*dumpit)(struct sk_buff___8 *, struct netlink_callback___6 *);
	int (*done)(struct netlink_callback___6 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___6 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops {
	int (*doit)(struct sk_buff___8 *, struct genl_info *);
	int (*dumpit)(struct sk_buff___8 *, struct netlink_callback___6 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

enum genl_validate_flags {
	GENL_DONT_VALIDATE_STRICT = 1,
	GENL_DONT_VALIDATE_DUMP = 2,
	GENL_DONT_VALIDATE_DUMP_STRICT = 4,
};

struct listener {
	struct list_head list;
	pid_t pid;
	char valid;
};

struct listener_list {
	struct rw_semaphore sem;
	struct list_head list;
};

enum actions {
	REGISTER = 0,
	DEREGISTER = 1,
	CPU_DONT_CARE = 2,
};

struct tp_module {
	struct list_head list;
	struct module___8 *mod;
};

enum tp_func_state {
	TP_FUNC_0 = 0,
	TP_FUNC_1 = 1,
	TP_FUNC_2 = 2,
	TP_FUNC_N = 3,
};

enum tp_transition_sync {
	TP_TRANSITION_SYNC_1_0_1 = 0,
	TP_TRANSITION_SYNC_N_2_1 = 1,
	_NR_TP_TRANSITION_SYNC = 2,
};

struct tp_transition_snapshot {
	long unsigned int rcu;
	long unsigned int srcu;
	bool ongoing;
};

struct tp_probes {
	struct callback_head rcu;
	struct tracepoint_func probes[0];
};

struct dentry___56;

struct super_block___56;

struct module___54;

struct file_system_type___55 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___56 * (*mount)(struct file_system_type___55 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___56 *);
	struct module___54 *owner;
	struct file_system_type___55 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___56;

struct kiocb___55;

struct poll_table_struct___41;

struct vm_area_struct___60;

struct inode___56;

struct file_lock___55;

struct page___60;

struct seq_file___53;

struct file_operations___55 {
	struct module___54 *owner;
	loff_t (*llseek)(struct file___56 *, loff_t, int);
	ssize_t (*read)(struct file___56 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___56 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___55 *, struct iov_iter___28 *);
	ssize_t (*write_iter)(struct kiocb___55 *, struct iov_iter___28 *);
	int (*iopoll)(struct kiocb___55 *, bool);
	int (*iterate)(struct file___56 *, struct dir_context *);
	int (*iterate_shared)(struct file___56 *, struct dir_context *);
	__poll_t (*poll)(struct file___56 *, struct poll_table_struct___41 *);
	long int (*unlocked_ioctl)(struct file___56 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___56 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___56 *, struct vm_area_struct___60 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___56 *, struct file___56 *);
	int (*flush)(struct file___56 *, fl_owner_t);
	int (*release)(struct inode___56 *, struct file___56 *);
	int (*fsync)(struct file___56 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___56 *, int);
	int (*lock)(struct file___56 *, int, struct file_lock___55 *);
	ssize_t (*sendpage)(struct file___56 *, struct page___60 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___56 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___56 *, long unsigned int);
	int (*flock)(struct file___56 *, int, struct file_lock___55 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___56 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___56 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___56 *, long int, struct file_lock___55 **, void **);
	long int (*fallocate)(struct file___56 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___53 *, struct file___56 *);
	ssize_t (*copy_file_range)(struct file___56 *, loff_t, struct file___56 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___56 *, loff_t, struct file___56 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___56 *, loff_t, loff_t, int);
};

struct vmacache___60 {
	u64 seqnum;
	struct vm_area_struct___60 *vmas[4];
};

struct page_frag___60 {
	struct page___60 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___37;

struct debug_info___37 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___37 *hbp_break[16];
	struct perf_event___37 *hbp_watch[16];
};

struct thread_struct___37 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___37 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___61;

struct pid___49;

struct nsproxy___54;

struct signal_struct___56;

struct css_set___45;

struct perf_event_context___37;

struct vm_struct___57;

struct task_struct___61 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___61 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___61 *mm;
	struct mm_struct___61 *active_mm;
	struct vmacache___60 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___61 *real_parent;
	struct task_struct___61 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___61 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___49 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___54 *nsproxy;
	struct signal_struct___56 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___61 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___25 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___45 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___37 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___60 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___61 *oom_reaper_list;
	struct vm_struct___57 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___37 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___55;

struct kobj_type___55;

struct kernfs_node___55;

struct kobject___55 {
	const char *name;
	struct list_head entry;
	struct kobject___55 *parent;
	struct kset___55 *kset;
	struct kobj_type___55 *ktype;
	struct kernfs_node___55 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___52 {
	struct kobject___55 kobj;
	struct module___54 *mod;
	struct kobject___55 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___52 {
	struct module___54 *mod;
	struct latch_tree_node node;
};

struct module_layout___52 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___52 mtn;
};

struct module_attribute___52;

struct kernel_param___52;

struct trace_event_call___32;

struct module___54 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___52 mkobj;
	struct module_attribute___52 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___55 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___52 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___52 core_layout;
	struct module_layout___52 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___32 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___37 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___61 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___37)(struct perf_event___37 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___37;

struct fasync_struct___55;

struct pid_namespace___49;

struct perf_cgroup___37;

struct perf_event___37 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___37 *group_leader;
	struct pmu___37 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___37 hw;
	struct perf_event_context___37 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___37 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___61 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___55 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___37 *aux_event;
	void (*destroy)(struct perf_event___37 *);
	struct callback_head callback_head;
	struct pid_namespace___49 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___37 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___37 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___32 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___37 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___49 {
	int nr;
	struct pid_namespace___49 *ns;
};

struct pid_namespace___49 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___61 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___49 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___49 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___49 numbers[1];
};

typedef struct page___60 *pgtable_t___60;

struct address_space___55;

struct dev_pagemap___54;

struct page___60 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___55 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___15 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___60 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___60 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___61 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___54 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___54;

struct vm_area_struct___60 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___60 *vm_next;
	struct vm_area_struct___60 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___61 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___54 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___56 *vm_file;
	struct file___56 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___56 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___61 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___61 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___49 *pids[4];
	struct pid___49 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___61 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___13;

struct core_state___60;

struct mm_struct___61 {
	struct {
		struct vm_area_struct___60 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___56 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___13 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___60 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___61 *owner;
		struct user_namespace___10 *user_ns;
		struct file___56 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___45;

struct nsproxy___54 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___49 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___45 *cgroup_ns;
};

struct cgroup_subsys_state___45;

struct cgroup___45;

struct css_set___45 {
	struct cgroup_subsys_state___45 *subsys[14];
	refcount_t refcount;
	struct css_set___45 *dom_cset;
	struct cgroup___45 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___45 *mg_src_cgrp;
	struct cgroup___45 *mg_dst_cgrp;
	struct css_set___45 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___37 {
	struct pmu___37 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___61 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___37 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___57 {
	struct vm_struct___57 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___60 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___55;

struct address_space___55 {
	struct inode___56 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___55 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___54;

struct dev_pagemap___54 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___54 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___55;

struct path___55 {
	struct vfsmount___55 *mnt;
	struct dentry___56 *dentry;
};

struct fown_struct___49 {
	rwlock_t lock;
	struct pid___49 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___56 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___55 f_path;
	struct inode___56 *f_inode;
	const struct file_operations___55 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___49 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___55 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___54;

struct vm_operations_struct___54 {
	void (*open)(struct vm_area_struct___60 *);
	void (*close)(struct vm_area_struct___60 *);
	int (*may_split)(struct vm_area_struct___60 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___60 *);
	int (*mprotect)(struct vm_area_struct___60 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___54 *);
	vm_fault_t (*huge_fault)(struct vm_fault___54 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___54 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___60 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___54 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___54 *);
	int (*access)(struct vm_area_struct___60 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___60 *);
	int (*set_policy)(struct vm_area_struct___60 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___60 *, long unsigned int);
	struct page___60 * (*find_special_page)(struct vm_area_struct___60 *, long unsigned int);
};

struct core_thread___60 {
	struct task_struct___61 *task;
	struct core_thread___60 *next;
};

struct core_state___60 {
	atomic_t nr_threads;
	struct core_thread___60 dumper;
	struct completion startup;
};

struct linux_binprm___14;

struct coredump_params___13;

struct linux_binfmt___13 {
	struct list_head lh;
	struct module___54 *module;
	int (*load_binary)(struct linux_binprm___14 *);
	int (*load_shlib)(struct file___56 *);
	int (*core_dump)(struct coredump_params___13 *);
	long unsigned int min_coredump;
};

struct vm_fault___54 {
	const struct {
		struct vm_area_struct___60 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___60 *cow_page;
	struct page___60 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___60 prealloc_pte;
};

struct kernfs_root___55;

struct kernfs_elem_dir___55 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___55 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___55;

struct kernfs_root___55 {
	struct kernfs_node___55 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___55 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___55 {
	struct kernfs_node___55 *target_kn;
};

struct kernfs_ops___55;

struct kernfs_elem_attr___55 {
	const struct kernfs_ops___55 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___55 *notify_next;
};

struct kernfs_node___55 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___55 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___55 dir;
		struct kernfs_elem_symlink___55 symlink;
		struct kernfs_elem_attr___55 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___55;

struct kernfs_ops___55 {
	int (*open)(struct kernfs_open_file___55 *);
	void (*release)(struct kernfs_open_file___55 *);
	int (*seq_show)(struct seq_file___53 *, void *);
	void * (*seq_start)(struct seq_file___53 *, loff_t *);
	void * (*seq_next)(struct seq_file___53 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___53 *, void *);
	ssize_t (*read)(struct kernfs_open_file___55 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___55 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___55 *, struct poll_table_struct___41 *);
	int (*mmap)(struct kernfs_open_file___55 *, struct vm_area_struct___60 *);
};

struct kernfs_syscall_ops___55 {
	int (*show_options)(struct seq_file___53 *, struct kernfs_root___55 *);
	int (*mkdir)(struct kernfs_node___55 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___55 *);
	int (*rename)(struct kernfs_node___55 *, struct kernfs_node___55 *, const char *);
	int (*show_path)(struct seq_file___53 *, struct kernfs_node___55 *, struct kernfs_root___55 *);
};

struct seq_operations___53;

struct seq_file___53 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___53 *op;
	int poll_event;
	const struct file___56 *file;
	void *private;
};

struct kernfs_open_file___55 {
	struct kernfs_node___55 *kn;
	struct file___56 *file;
	struct seq_file___53 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___54 *vm_ops;
};

typedef void (*poll_queue_proc___41)(struct file___56 *, wait_queue_head_t *, struct poll_table_struct___41 *);

struct poll_table_struct___41 {
	poll_queue_proc___41 _qproc;
	__poll_t _key;
};

struct bin_attribute___55;

struct attribute_group___55 {
	const char *name;
	umode_t (*is_visible)(struct kobject___55 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___55 *, struct bin_attribute___55 *, int);
	struct attribute **attrs;
	struct bin_attribute___55 **bin_attrs;
};

struct bin_attribute___55 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___55 * (*f_mapping)();
	ssize_t (*read)(struct file___56 *, struct kobject___55 *, struct bin_attribute___55 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___56 *, struct kobject___55 *, struct bin_attribute___55 *, char *, loff_t, size_t);
	int (*mmap)(struct file___56 *, struct kobject___55 *, struct bin_attribute___55 *, struct vm_area_struct___60 *);
};

struct sysfs_ops___55 {
	ssize_t (*show)(struct kobject___55 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___55 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___55;

struct kset___55 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___55 kobj;
	const struct kset_uevent_ops___55 *uevent_ops;
};

struct kobj_type___55 {
	void (*release)(struct kobject___55 *);
	const struct sysfs_ops___55 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___55 **default_groups;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___55 *);
	const void * (*namespace)(struct kobject___55 *);
	void (*get_ownership)(struct kobject___55 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___55 {
	int (* const filter)(struct kset___55 *, struct kobject___55 *);
	const char * (* const name)(struct kset___55 *, struct kobject___55 *);
	int (* const uevent)(struct kset___55 *, struct kobject___55 *, struct kobj_uevent_env *);
};

struct wakeup_source___49;

struct device___49;

struct dev_pm_info___49 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___49 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___49 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___49;

struct bus_type___49;

struct device_driver___49;

struct dev_pm_domain___49;

struct device_node___29;

struct fwnode_handle___49;

struct class___49;

struct device___49 {
	struct kobject___55 kobj;
	struct device___49 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___49 *type;
	struct bus_type___49 *bus;
	struct device_driver___49 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___49 power;
	struct dev_pm_domain___49 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___29 *of_node;
	struct fwnode_handle___49 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___49 *class;
	const struct attribute_group___55 **groups;
	void (*release)(struct device___49 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___49 {
	int (*prepare)(struct device___49 *);
	void (*complete)(struct device___49 *);
	int (*suspend)(struct device___49 *);
	int (*resume)(struct device___49 *);
	int (*freeze)(struct device___49 *);
	int (*thaw)(struct device___49 *);
	int (*poweroff)(struct device___49 *);
	int (*restore)(struct device___49 *);
	int (*suspend_late)(struct device___49 *);
	int (*resume_early)(struct device___49 *);
	int (*freeze_late)(struct device___49 *);
	int (*thaw_early)(struct device___49 *);
	int (*poweroff_late)(struct device___49 *);
	int (*restore_early)(struct device___49 *);
	int (*suspend_noirq)(struct device___49 *);
	int (*resume_noirq)(struct device___49 *);
	int (*freeze_noirq)(struct device___49 *);
	int (*thaw_noirq)(struct device___49 *);
	int (*poweroff_noirq)(struct device___49 *);
	int (*restore_noirq)(struct device___49 *);
	int (*runtime_suspend)(struct device___49 *);
	int (*runtime_resume)(struct device___49 *);
	int (*runtime_idle)(struct device___49 *);
};

struct wakeup_source___49 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___49 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___49 {
	struct dev_pm_ops___49 ops;
	int (*start)(struct device___49 *);
	void (*detach)(struct device___49 *, bool);
	int (*activate)(struct device___49 *);
	void (*sync)(struct device___49 *);
	void (*dismiss)(struct device___49 *);
};

struct bus_type___49 {
	const char *name;
	const char *dev_name;
	struct device___49 *dev_root;
	const struct attribute_group___55 **bus_groups;
	const struct attribute_group___55 **dev_groups;
	const struct attribute_group___55 **drv_groups;
	int (*match)(struct device___49 *, struct device_driver___49 *);
	int (*uevent)(struct device___49 *, struct kobj_uevent_env *);
	int (*probe)(struct device___49 *);
	void (*sync_state)(struct device___49 *);
	void (*remove)(struct device___49 *);
	void (*shutdown)(struct device___49 *);
	int (*online)(struct device___49 *);
	int (*offline)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	int (*num_vf)(struct device___49 *);
	int (*dma_configure)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___49 {
	const char *name;
	struct bus_type___49 *bus;
	struct module___54 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___49 *);
	void (*sync_state)(struct device___49 *);
	int (*remove)(struct device___49 *);
	void (*shutdown)(struct device___49 *);
	int (*suspend)(struct device___49 *, pm_message_t);
	int (*resume)(struct device___49 *);
	const struct attribute_group___55 **groups;
	const struct attribute_group___55 **dev_groups;
	const struct dev_pm_ops___49 *pm;
	void (*coredump)(struct device___49 *);
	struct driver_private *p;
};

struct device_type___49 {
	const char *name;
	const struct attribute_group___55 **groups;
	int (*uevent)(struct device___49 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___49 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___49 *);
	const struct dev_pm_ops___49 *pm;
};

struct class___49 {
	const char *name;
	struct module___54 *owner;
	const struct attribute_group___55 **class_groups;
	const struct attribute_group___55 **dev_groups;
	struct kobject___55 *dev_kobj;
	int (*dev_uevent)(struct device___49 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___49 *, umode_t *);
	void (*class_release)(struct class___49 *);
	void (*dev_release)(struct device___49 *);
	int (*shutdown_pre)(struct device___49 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___49 *);
	void (*get_ownership)(struct device___49 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___49 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___49;

struct fwnode_handle___49 {
	struct fwnode_handle___49 *secondary;
	const struct fwnode_operations___49 *ops;
	struct device___49 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___25;

struct device_node___29 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___49 fwnode;
	struct property___25 *properties;
	struct property___25 *deadprops;
	struct device_node___29 *parent;
	struct device_node___29 *child;
	struct device_node___29 *sibling;
	struct kobject___55 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___49;

struct fwnode_endpoint___49;

struct fwnode_operations___49 {
	struct fwnode_handle___49 * (*get)(struct fwnode_handle___49 *);
	void (*put)(struct fwnode_handle___49 *);
	bool (*device_is_available)(const struct fwnode_handle___49 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___49 *, const struct device___49 *);
	bool (*property_present)(const struct fwnode_handle___49 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___49 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___49 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___49 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*get_parent)(const struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*get_next_child_node)(const struct fwnode_handle___49 *, struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*get_named_child_node)(const struct fwnode_handle___49 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___49 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___49 *);
	struct fwnode_handle___49 * (*graph_get_next_endpoint)(const struct fwnode_handle___49 *, struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*graph_get_remote_endpoint)(const struct fwnode_handle___49 *);
	struct fwnode_handle___49 * (*graph_get_port_parent)(struct fwnode_handle___49 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___49 *, struct fwnode_endpoint___49 *);
	int (*add_links)(struct fwnode_handle___49 *);
};

struct fwnode_endpoint___49 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___49 *local_fwnode;
};

struct fwnode_reference_args___49 {
	struct fwnode_handle___49 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___25 {
	char *name;
	int length;
	void *value;
	struct property___25 *next;
	long unsigned int _flags;
	struct bin_attribute___55 attr;
};

struct cgroup_subsys___45;

struct cgroup_subsys_state___45 {
	struct cgroup___45 *cgroup;
	struct cgroup_subsys___45 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___45 *parent;
};

struct cgroup_file___45 {
	struct kernfs_node___55 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___45 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___61 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___45;

struct cgroup_rstat_cpu___45;

struct cgroup___45 {
	struct cgroup_subsys_state___45 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___55 *kn;
	struct cgroup_file___45 procs_file;
	struct cgroup_file___45 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___45 *subsys[14];
	struct cgroup_root___45 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___45 *dom_cgrp;
	struct cgroup___45 *old_dom_cgrp;
	struct cgroup_rstat_cpu___45 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___45 psi;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct dev_pagemap_ops___54 {
	void (*page_free)(struct page___60 *);
	void (*kill)(struct dev_pagemap___54 *);
	void (*cleanup)(struct dev_pagemap___54 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___54 *);
};

struct dentry_operations___55;

struct dentry___56 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___56 *d_parent;
	struct qstr d_name;
	struct inode___56 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___55 *d_op;
	struct super_block___56 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___55;

struct inode___56 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___55 *i_op;
	struct super_block___56 *i_sb;
	struct address_space___55 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___55 *i_fop;
		void (*free_inode)(struct inode___56 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___55 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___17 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___55 {
	int (*d_revalidate)(struct dentry___56 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___56 *, unsigned int);
	int (*d_hash)(const struct dentry___56 *, struct qstr *);
	int (*d_compare)(const struct dentry___56 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___56 *);
	int (*d_init)(struct dentry___56 *);
	void (*d_release)(struct dentry___56 *);
	void (*d_prune)(struct dentry___56 *);
	void (*d_iput)(struct dentry___56 *, struct inode___56 *);
	char * (*d_dname)(struct dentry___56 *, char *, int);
	struct vfsmount___55 * (*d_automount)(struct path___55 *);
	int (*d_manage)(const struct path___55 *, bool);
	struct dentry___56 * (*d_real)(struct dentry___56 *, const struct inode___56 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___55;

struct mem_dqinfo___55 {
	struct quota_format_type___55 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___55;

struct quota_info___55 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___56 *files[3];
	struct mem_dqinfo___55 info[3];
	const struct quota_format_ops___55 *ops[3];
};

struct rcuwait___56 {
	struct task_struct___61 *task;
};

struct percpu_rw_semaphore___56 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___56 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___55 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___56 rw_sem[3];
};

struct super_operations___55;

struct dquot_operations___55;

struct quotactl_ops___55;

struct super_block___56 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___55 *s_type;
	const struct super_operations___55 *s_op;
	const struct dquot_operations___55 *dq_op;
	const struct quotactl_ops___55 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___56 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___55 s_dquot;
	struct sb_writers___55 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___55 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___55 {
	struct dentry___56 *mnt_root;
	struct super_block___56 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct kiocb___55 {
	struct file___56 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___55 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___25 *ki_waitq;
	};
};

struct iattr___56 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___56 *ia_file;
};

struct dquot___55 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___56 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___55 {
	int qf_fmt_id;
	const struct quota_format_ops___55 *qf_ops;
	struct module___54 *qf_owner;
	struct quota_format_type___55 *qf_next;
};

struct quota_format_ops___55 {
	int (*check_quota_file)(struct super_block___56 *, int);
	int (*read_file_info)(struct super_block___56 *, int);
	int (*write_file_info)(struct super_block___56 *, int);
	int (*free_file_info)(struct super_block___56 *, int);
	int (*read_dqblk)(struct dquot___55 *);
	int (*commit_dqblk)(struct dquot___55 *);
	int (*release_dqblk)(struct dquot___55 *);
	int (*get_next_id)(struct super_block___56 *, struct kqid *);
};

struct dquot_operations___55 {
	int (*write_dquot)(struct dquot___55 *);
	struct dquot___55 * (*alloc_dquot)(struct super_block___56 *, int);
	void (*destroy_dquot)(struct dquot___55 *);
	int (*acquire_dquot)(struct dquot___55 *);
	int (*release_dquot)(struct dquot___55 *);
	int (*mark_dirty)(struct dquot___55 *);
	int (*write_info)(struct super_block___56 *, int);
	qsize_t * (*get_reserved_space)(struct inode___56 *);
	int (*get_projid)(struct inode___56 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___56 *, qsize_t *);
	int (*get_next_id)(struct super_block___56 *, struct kqid *);
};

struct quotactl_ops___55 {
	int (*quota_on)(struct super_block___56 *, int, int, const struct path___55 *);
	int (*quota_off)(struct super_block___56 *, int);
	int (*quota_enable)(struct super_block___56 *, unsigned int);
	int (*quota_disable)(struct super_block___56 *, unsigned int);
	int (*quota_sync)(struct super_block___56 *, int);
	int (*set_info)(struct super_block___56 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___56 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___56 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___56 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___56 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___56 *, unsigned int);
};

struct address_space_operations___55 {
	int (*writepage)(struct page___60 *, struct writeback_control___3 *);
	int (*readpage)(struct file___56 *, struct page___60 *);
	int (*writepages)(struct address_space___55 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___60 *);
	int (*readpages)(struct file___56 *, struct address_space___55 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___56 *, struct address_space___55 *, loff_t, unsigned int, unsigned int, struct page___60 **, void **);
	int (*write_end)(struct file___56 *, struct address_space___55 *, loff_t, unsigned int, unsigned int, struct page___60 *, void *);
	sector_t (*bmap)(struct address_space___55 *, sector_t);
	void (*invalidatepage)(struct page___60 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___60 *, gfp_t);
	void (*freepage)(struct page___60 *);
	ssize_t (*direct_IO)(struct kiocb___55 *, struct iov_iter___28 *);
	int (*migratepage)(struct address_space___55 *, struct page___60 *, struct page___60 *, enum migrate_mode);
	bool (*isolate_page)(struct page___60 *, isolate_mode_t);
	void (*putback_page)(struct page___60 *);
	int (*launder_page)(struct page___60 *);
	int (*is_partially_uptodate)(struct page___60 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___60 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___55 *, struct page___60 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___56 *, sector_t *);
	void (*swap_deactivate)(struct file___56 *);
};

struct inode_operations___55 {
	struct dentry___56 * (*lookup)(struct inode___56 *, struct dentry___56 *, unsigned int);
	const char * (*get_link)(struct dentry___56 *, struct inode___56 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___56 *, int);
	struct posix_acl * (*get_acl)(struct inode___56 *, int, bool);
	int (*readlink)(struct dentry___56 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___56 *, struct dentry___56 *, umode_t, bool);
	int (*link)(struct dentry___56 *, struct inode___56 *, struct dentry___56 *);
	int (*unlink)(struct inode___56 *, struct dentry___56 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___56 *, struct dentry___56 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___56 *, struct dentry___56 *, umode_t);
	int (*rmdir)(struct inode___56 *, struct dentry___56 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___56 *, struct dentry___56 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___56 *, struct dentry___56 *, struct inode___56 *, struct dentry___56 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___56 *, struct iattr___56 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___55 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___56 *, char *, size_t);
	int (*fiemap)(struct inode___56 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___56 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___56 *, struct dentry___56 *, struct file___56 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___56 *, struct dentry___56 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___56 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___56 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___56 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___55 {
	void (*fl_copy_lock)(struct file_lock___55 *, struct file_lock___55 *);
	void (*fl_release_private)(struct file_lock___55 *);
};

struct lock_manager_operations___55;

struct file_lock___55 {
	struct file_lock___55 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___56 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___55 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___55 *fl_ops;
	const struct lock_manager_operations___55 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___55 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___55 *);
	int (*lm_grant)(struct file_lock___55 *, int);
	bool (*lm_break)(struct file_lock___55 *);
	int (*lm_change)(struct file_lock___55 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___55 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___55 *);
};

struct fasync_struct___55 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___55 *fa_next;
	struct file___56 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___55 {
	struct inode___56 * (*alloc_inode)(struct super_block___56 *);
	void (*destroy_inode)(struct inode___56 *);
	void (*free_inode)(struct inode___56 *);
	void (*dirty_inode)(struct inode___56 *, int);
	int (*write_inode)(struct inode___56 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___56 *);
	void (*evict_inode)(struct inode___56 *);
	void (*put_super)(struct super_block___56 *);
	int (*sync_fs)(struct super_block___56 *, int);
	int (*freeze_super)(struct super_block___56 *);
	int (*freeze_fs)(struct super_block___56 *);
	int (*thaw_super)(struct super_block___56 *);
	int (*unfreeze_fs)(struct super_block___56 *);
	int (*statfs)(struct dentry___56 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___56 *, int *, char *);
	void (*umount_begin)(struct super_block___56 *);
	int (*show_options)(struct seq_file___53 *, struct dentry___56 *);
	int (*show_devname)(struct seq_file___53 *, struct dentry___56 *);
	int (*show_path)(struct seq_file___53 *, struct dentry___56 *);
	int (*show_stats)(struct seq_file___53 *, struct dentry___56 *);
	ssize_t (*quota_read)(struct super_block___56 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___56 *, int, const char *, size_t, loff_t);
	struct dquot___55 ** (*get_dquots)(struct inode___56 *);
	long int (*nr_cached_objects)(struct super_block___56 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___56 *, struct shrink_control___22 *);
	struct file___56 * (*real_loop)(struct file___56 *);
};

struct kernel_param_ops___52 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___52 *);
	int (*get)(char *, const struct kernel_param___52 *);
	void (*free)(void *);
};

struct kparam_array___52;

struct kernel_param___52 {
	const char *name;
	struct module___54 *mod;
	const struct kernel_param_ops___52 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___52 *arr;
	};
};

struct kparam_array___52 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___52 *ops;
	void *elem;
};

struct module_attribute___52 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___52 *, struct module_kobject___52 *, char *);
	ssize_t (*store)(struct module_attribute___52 *, struct module_kobject___52 *, const char *, size_t);
	void (*setup)(struct module___54 *, const char *);
	int (*test)(struct module___54 *);
	void (*free)(struct module___54 *);
};

struct trace_event_class___32;

struct trace_event_call___32 {
	struct list_head list;
	struct trace_event_class___32 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___32 *, struct perf_event___37 *);
};

struct seq_operations___53 {
	void * (*start)(struct seq_file___53 *, loff_t *);
	void (*stop)(struct seq_file___53 *, void *);
	void * (*next)(struct seq_file___53 *, void *, loff_t *);
	int (*show)(struct seq_file___53 *, void *);
};

enum {
	TRACE_FTRACE_BIT = 0,
	TRACE_FTRACE_NMI_BIT = 1,
	TRACE_FTRACE_IRQ_BIT = 2,
	TRACE_FTRACE_SIRQ_BIT = 3,
	TRACE_FTRACE_TRANSITION_BIT = 4,
	TRACE_INTERNAL_BIT = 5,
	TRACE_INTERNAL_NMI_BIT = 6,
	TRACE_INTERNAL_IRQ_BIT = 7,
	TRACE_INTERNAL_SIRQ_BIT = 8,
	TRACE_INTERNAL_TRANSITION_BIT = 9,
	TRACE_BRANCH_BIT = 10,
	TRACE_IRQ_BIT = 11,
	TRACE_GRAPH_BIT = 12,
	TRACE_GRAPH_DEPTH_START_BIT = 13,
	TRACE_GRAPH_DEPTH_END_BIT = 14,
	TRACE_GRAPH_NOTRACE_BIT = 15,
	TRACE_RECORD_RECURSION_BIT = 16,
};

enum {
	TRACE_CTX_NMI = 0,
	TRACE_CTX_IRQ = 1,
	TRACE_CTX_SOFTIRQ = 2,
	TRACE_CTX_NORMAL = 3,
	TRACE_CTX_TRANSITION = 4,
};

struct cgroup_namespace___45 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___45 *root_cset;
};

enum {
	FTRACE_OPS_FL_ENABLED = 1,
	FTRACE_OPS_FL_DYNAMIC = 2,
	FTRACE_OPS_FL_SAVE_REGS = 4,
	FTRACE_OPS_FL_SAVE_REGS_IF_SUPPORTED = 8,
	FTRACE_OPS_FL_RECURSION = 16,
	FTRACE_OPS_FL_STUB = 32,
	FTRACE_OPS_FL_INITIALIZED = 64,
	FTRACE_OPS_FL_DELETED = 128,
	FTRACE_OPS_FL_ADDING = 256,
	FTRACE_OPS_FL_REMOVING = 512,
	FTRACE_OPS_FL_MODIFYING = 1024,
	FTRACE_OPS_FL_ALLOC_TRAMP = 2048,
	FTRACE_OPS_FL_IPMODIFY = 4096,
	FTRACE_OPS_FL_PID = 8192,
	FTRACE_OPS_FL_RCU = 16384,
	FTRACE_OPS_FL_TRACE_ARRAY = 32768,
	FTRACE_OPS_FL_PERMANENT = 65536,
	FTRACE_OPS_FL_DIRECT = 131072,
};

struct ftrace_hash {
	long unsigned int size_bits;
	struct hlist_head *buckets;
	long unsigned int count;
	long unsigned int flags;
	struct callback_head rcu;
};

struct ftrace_func_entry {
	struct hlist_node hlist;
	long unsigned int ip;
	long unsigned int direct;
};

enum ftrace_bug_type {
	FTRACE_BUG_UNKNOWN = 0,
	FTRACE_BUG_INIT = 1,
	FTRACE_BUG_NOP = 2,
	FTRACE_BUG_CALL = 3,
	FTRACE_BUG_UPDATE = 4,
};

enum {
	FTRACE_FL_ENABLED = 2147483648,
	FTRACE_FL_REGS = 1073741824,
	FTRACE_FL_REGS_EN = 536870912,
	FTRACE_FL_TRAMP = 268435456,
	FTRACE_FL_TRAMP_EN = 134217728,
	FTRACE_FL_IPMODIFY = 67108864,
	FTRACE_FL_DISABLED = 33554432,
	FTRACE_FL_DIRECT = 16777216,
	FTRACE_FL_DIRECT_EN = 8388608,
};

enum {
	FTRACE_UPDATE_IGNORE = 0,
	FTRACE_UPDATE_MAKE_CALL = 1,
	FTRACE_UPDATE_MODIFY_CALL = 2,
	FTRACE_UPDATE_MAKE_NOP = 3,
};

enum {
	FTRACE_ITER_FILTER = 1,
	FTRACE_ITER_NOTRACE = 2,
	FTRACE_ITER_PRINTALL = 4,
	FTRACE_ITER_DO_PROBES = 8,
	FTRACE_ITER_PROBE = 16,
	FTRACE_ITER_MOD = 32,
	FTRACE_ITER_ENABLED = 64,
};

struct ftrace_graph_ent {
	long unsigned int func;
	int depth;
} __attribute__((packed));

struct ftrace_graph_ret {
	long unsigned int func;
	int depth;
	unsigned int overrun;
	long long unsigned int calltime;
	long long unsigned int rettime;
};

typedef void (*trace_func_graph_ret_t)(struct ftrace_graph_ret *);

typedef int (*trace_func_graph_ent_t)(struct ftrace_graph_ent *);

struct fgraph_ops {
	trace_func_graph_ent_t entryfunc;
	trace_func_graph_ret_t retfunc;
};

struct linux_binprm___14 {
	struct vm_area_struct___60 *vma;
	long unsigned int vma_pages;
	struct mm_struct___61 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___56 *executable;
	struct file___56 *interpreter;
	struct file___56 *file;
	struct cred___9 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___13 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___56 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct cftype___45;

struct cgroup_subsys___45 {
	struct cgroup_subsys_state___45 * (*css_alloc)(struct cgroup_subsys_state___45 *);
	int (*css_online)(struct cgroup_subsys_state___45 *);
	void (*css_offline)(struct cgroup_subsys_state___45 *);
	void (*css_released)(struct cgroup_subsys_state___45 *);
	void (*css_free)(struct cgroup_subsys_state___45 *);
	void (*css_reset)(struct cgroup_subsys_state___45 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___45 *, int);
	int (*css_extra_stat_show)(struct seq_file___53 *, struct cgroup_subsys_state___45 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___61 *, struct css_set___45 *);
	void (*cancel_fork)(struct task_struct___61 *, struct css_set___45 *);
	void (*fork)(struct task_struct___61 *);
	void (*exit)(struct task_struct___61 *);
	void (*release)(struct task_struct___61 *);
	void (*bind)(struct cgroup_subsys_state___45 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___45 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___45 *dfl_cftypes;
	struct cftype___45 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___45 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___45 *updated_children;
	struct cgroup___45 *updated_next;
};

struct cgroup_root___45 {
	struct kernfs_root___55 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___45 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___45 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___45 *ss;
	struct list_head node;
	struct kernfs_ops___55 *kf_ops;
	int (*open)(struct kernfs_open_file___55 *);
	void (*release)(struct kernfs_open_file___55 *);
	u64 (*read_u64)(struct cgroup_subsys_state___45 *, struct cftype___45 *);
	s64 (*read_s64)(struct cgroup_subsys_state___45 *, struct cftype___45 *);
	int (*seq_show)(struct seq_file___53 *, void *);
	void * (*seq_start)(struct seq_file___53 *, loff_t *);
	void * (*seq_next)(struct seq_file___53 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___53 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___45 *, struct cftype___45 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___45 *, struct cftype___45 *, s64);
	ssize_t (*write)(struct kernfs_open_file___55 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___55 *, struct poll_table_struct___41 *);
};

struct perf_cpu_context___37;

struct perf_output_handle___37;

struct pmu___37 {
	struct list_head entry;
	struct module___54 *module;
	struct device___49 *dev;
	const struct attribute_group___55 **attr_groups;
	const struct attribute_group___55 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___37 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___37 *);
	void (*pmu_disable)(struct pmu___37 *);
	int (*event_init)(struct perf_event___37 *);
	void (*event_mapped)(struct perf_event___37 *, struct mm_struct___61 *);
	void (*event_unmapped)(struct perf_event___37 *, struct mm_struct___61 *);
	int (*add)(struct perf_event___37 *, int);
	void (*del)(struct perf_event___37 *, int);
	void (*start)(struct perf_event___37 *, int);
	void (*stop)(struct perf_event___37 *, int);
	void (*read)(struct perf_event___37 *);
	void (*start_txn)(struct pmu___37 *, unsigned int);
	int (*commit_txn)(struct pmu___37 *);
	void (*cancel_txn)(struct pmu___37 *);
	int (*event_idx)(struct perf_event___37 *);
	void (*sched_task)(struct perf_event_context___37 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___37 *, struct perf_event_context___37 *);
	void * (*setup_aux)(struct perf_event___37 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___37 *, struct perf_output_handle___37 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___37 *);
	int (*aux_output_match)(struct perf_event___37 *);
	int (*filter_match)(struct perf_event___37 *);
	int (*check_period)(struct perf_event___37 *, u64);
};

struct perf_cpu_context___37 {
	struct perf_event_context___37 ctx;
	struct perf_event_context___37 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___37 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___37 **heap;
	struct perf_event___37 *heap_default[2];
};

struct perf_output_handle___37 {
	struct perf_event___37 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct prog_entry;

struct event_filter {
	struct prog_entry *prog;
	char *filter_string;
};

struct perf_cgroup___37 {
	struct cgroup_subsys_state___45 css;
	struct perf_cgroup_info *info;
};

struct trace_array_cpu;

struct array_buffer {
	struct trace_array *tr;
	struct trace_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_pid_list;

struct trace_event_file___14;

struct trace_options;

struct cond_snapshot;

struct trace_func_repeats;

struct trace_array {
	struct list_head list;
	char *name;
	struct array_buffer array_buffer;
	struct array_buffer max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct dentry___56 *d_max_latency;
	struct work_struct fsnotify_work;
	struct irq_work fsnotify_irqwork;
	struct trace_pid_list *filtered_pids;
	struct trace_pid_list *filtered_no_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___14 *enter_syscall_files[449];
	struct trace_event_file___14 *exit_syscall_files[449];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	int buffer_percent;
	unsigned int n_err_log_entries;
	struct tracer *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct list_head err_log;
	struct dentry___56 *dir;
	struct dentry___56 *options;
	struct dentry___56 *percpu_dir;
	struct dentry___56 *event_dir;
	struct trace_options *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___14 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	int trace_ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct trace_pid_list *function_no_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int no_filter_buffering_ref;
	struct list_head hist_vars;
	struct cond_snapshot *cond_snapshot;
	struct trace_func_repeats *last_func_repeats;
};

struct tracer_flags;

struct tracer {
	const char *name;
	int (*init)(struct trace_array *);
	void (*reset)(struct trace_array *);
	void (*start)(struct trace_array *);
	void (*stop)(struct trace_array *);
	int (*update_thresh)(struct trace_array *);
	void (*open)(struct trace_iterator *);
	void (*pipe_open)(struct trace_iterator *);
	void (*close)(struct trace_iterator *);
	void (*pipe_close)(struct trace_iterator *);
	ssize_t (*read)(struct trace_iterator *, struct file___56 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator *, struct file___56 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___53 *);
	enum print_line_t (*print_line)(struct trace_iterator *);
	int (*set_flag)(struct trace_array *, u32, u32, int);
	int (*flag_changed)(struct trace_array *, u32, int);
	struct tracer *next;
	struct tracer_flags *flags;
	int enabled;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

struct trace_event_fields___32 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___32 *);
	};
};

struct trace_event_class___32 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___32 *, enum trace_reg, void *);
	struct trace_event_fields___32 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___32 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___32 *);
};

struct trace_event_file___14 {
	struct list_head list;
	struct trace_event_call___32 *event_call;
	struct event_filter *filter;
	struct dentry___56 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct event_subsystem;

struct trace_subsystem_dir {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array *tr;
	struct dentry___56 *entry;
	int ref_count;
	int nr_events;
};

struct trace_array_cpu {
	atomic_t disabled;
	void *buffer_page;
	long unsigned int entries;
	long unsigned int saved_latency;
	long unsigned int critical_start;
	long unsigned int critical_end;
	long unsigned int critical_sequence;
	long unsigned int nice;
	long unsigned int policy;
	long unsigned int rt_priority;
	long unsigned int skipped_entries;
	u64 preempt_timestamp;
	pid_t pid;
	kuid_t uid;
	char comm[16];
	int ftrace_ignore_pid;
	bool ignore_pid;
};

struct trace_option_dentry;

struct trace_options {
	struct tracer *tracer;
	struct trace_option_dentry *topts;
};

struct tracer_opt;

struct trace_option_dentry {
	struct tracer_opt *opt;
	struct tracer_flags *flags;
	struct trace_array *tr;
	struct dentry___56 *entry;
};

struct trace_pid_list {
	int pid_max;
	long unsigned int *pids;
};

enum {
	TRACE_PIDS = 1,
	TRACE_NO_PIDS = 2,
};

typedef bool (*cond_update_fn_t)(struct trace_array *, void *);

struct cond_snapshot {
	void *cond_data;
	cond_update_fn_t update;
};

struct trace_func_repeats {
	long unsigned int ip;
	long unsigned int parent_ip;
	long unsigned int count;
	u64 ts_last_call;
};

enum {
	TRACE_ARRAY_FL_GLOBAL = 1,
};

struct tracer_opt {
	const char *name;
	u32 bit;
};

struct tracer_flags {
	u32 val;
	struct tracer_opt *opts;
	struct tracer *trace;
};

struct ftrace_mod_load {
	struct list_head list;
	char *func;
	char *module;
	int enable;
};

enum {
	FTRACE_HASH_FL_MOD = 1,
};

struct ftrace_func_command {
	struct list_head list;
	char *name;
	int (*func)(struct trace_array *, struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops {
	void (*func)(long unsigned int, long unsigned int, struct trace_array *, struct ftrace_probe_ops *, void *);
	int (*init)(struct ftrace_probe_ops *, struct trace_array *, long unsigned int, void *, void **);
	void (*free)(struct ftrace_probe_ops *, struct trace_array *, long unsigned int, void *);
	int (*print)(struct seq_file___53 *, long unsigned int, struct ftrace_probe_ops *, void *);
};

typedef int (*ftrace_mapper_func)(void *);

struct trace_parser {
	bool cont;
	char *buffer;
	unsigned int idx;
	unsigned int size;
};

enum trace_iterator_bits {
	TRACE_ITER_PRINT_PARENT_BIT = 0,
	TRACE_ITER_SYM_OFFSET_BIT = 1,
	TRACE_ITER_SYM_ADDR_BIT = 2,
	TRACE_ITER_VERBOSE_BIT = 3,
	TRACE_ITER_RAW_BIT = 4,
	TRACE_ITER_HEX_BIT = 5,
	TRACE_ITER_BIN_BIT = 6,
	TRACE_ITER_BLOCK_BIT = 7,
	TRACE_ITER_PRINTK_BIT = 8,
	TRACE_ITER_ANNOTATE_BIT = 9,
	TRACE_ITER_USERSTACKTRACE_BIT = 10,
	TRACE_ITER_SYM_USEROBJ_BIT = 11,
	TRACE_ITER_PRINTK_MSGONLY_BIT = 12,
	TRACE_ITER_CONTEXT_INFO_BIT = 13,
	TRACE_ITER_LATENCY_FMT_BIT = 14,
	TRACE_ITER_RECORD_CMD_BIT = 15,
	TRACE_ITER_RECORD_TGID_BIT = 16,
	TRACE_ITER_OVERWRITE_BIT = 17,
	TRACE_ITER_STOP_ON_FREE_BIT = 18,
	TRACE_ITER_IRQ_INFO_BIT = 19,
	TRACE_ITER_MARKERS_BIT = 20,
	TRACE_ITER_EVENT_FORK_BIT = 21,
	TRACE_ITER_PAUSE_ON_TRACE_BIT = 22,
	TRACE_ITER_HASH_PTR_BIT = 23,
	TRACE_ITER_FUNCTION_BIT = 24,
	TRACE_ITER_FUNC_FORK_BIT = 25,
	TRACE_ITER_DISPLAY_GRAPH_BIT = 26,
	TRACE_ITER_STACKTRACE_BIT = 27,
	TRACE_ITER_LAST_BIT = 28,
};

struct event_subsystem {
	struct list_head list;
	const char *name;
	struct event_filter *filter;
	int ref_count;
};

enum regex_type {
	MATCH_FULL = 0,
	MATCH_FRONT_ONLY = 1,
	MATCH_MIDDLE_ONLY = 2,
	MATCH_END_ONLY = 3,
	MATCH_GLOB = 4,
	MATCH_INDEX = 5,
};

struct tracer_stat {
	const char *name;
	void * (*stat_start)(struct tracer_stat *);
	void * (*stat_next)(void *, int);
	cmp_func_t stat_cmp;
	int (*stat_show)(struct seq_file___53 *, void *);
	void (*stat_release)(void *);
	int (*stat_headers)(struct seq_file___53 *);
};

enum {
	FTRACE_MODIFY_ENABLE_FL = 1,
	FTRACE_MODIFY_MAY_SLEEP_FL = 2,
};

struct ftrace_profile {
	struct hlist_node node;
	long unsigned int ip;
	long unsigned int counter;
	long long unsigned int time;
	long long unsigned int time_squared;
};

struct ftrace_profile_page {
	struct ftrace_profile_page *next;
	long unsigned int index;
	struct ftrace_profile records[0];
};

struct ftrace_profile_stat {
	atomic_t disabled;
	struct hlist_head *hash;
	struct ftrace_profile_page *pages;
	struct ftrace_profile_page *start;
	struct tracer_stat stat;
};

struct ftrace_func_probe {
	struct ftrace_probe_ops *probe_ops;
	struct ftrace_ops ops;
	struct trace_array *tr;
	struct list_head list;
	void *data;
	int ref;
};

struct ftrace_page {
	struct ftrace_page *next;
	struct dyn_ftrace *records;
	int index;
	int order;
};

struct ftrace_rec_iter {
	struct ftrace_page *pg;
	int index;
};

struct ftrace_iterator {
	loff_t pos;
	loff_t func_pos;
	loff_t mod_pos;
	struct ftrace_page *pg;
	struct dyn_ftrace *func;
	struct ftrace_func_probe *probe;
	struct ftrace_func_entry *probe_entry;
	struct trace_parser parser;
	struct ftrace_hash *hash;
	struct ftrace_ops *ops;
	struct trace_array *tr;
	struct list_head *mod_list;
	int pidx;
	int idx;
	unsigned int flags;
};

struct ftrace_glob {
	char *search;
	unsigned int len;
	int type;
};

struct ftrace_func_map {
	struct ftrace_func_entry entry;
	void *data;
};

struct ftrace_func_mapper {
	struct ftrace_hash hash;
};

enum graph_filter_type {
	GRAPH_FILTER_NOTRACE = 0,
	GRAPH_FILTER_FUNCTION = 1,
};

struct ftrace_graph_data {
	struct ftrace_hash *hash;
	struct ftrace_func_entry *entry;
	int idx;
	enum graph_filter_type type;
	struct ftrace_hash *new_hash;
	const struct seq_operations___53 *seq_ops;
	struct trace_parser parser;
};

struct ftrace_mod_func {
	struct list_head list;
	char *name;
	long unsigned int ip;
	unsigned int size;
};

struct ftrace_mod_map {
	struct callback_head rcu;
	struct list_head list;
	struct module___54 *mod;
	long unsigned int start_addr;
	long unsigned int end_addr;
	struct list_head funcs;
	unsigned int num_funcs;
};

struct ftrace_init_func {
	struct list_head list;
	long unsigned int ip;
};

typedef struct poll_table_struct___41 poll_table___10;

enum ring_buffer_type {
	RINGBUF_TYPE_DATA_TYPE_LEN_MAX = 28,
	RINGBUF_TYPE_PADDING = 29,
	RINGBUF_TYPE_TIME_EXTEND = 30,
	RINGBUF_TYPE_TIME_STAMP = 31,
};

enum ring_buffer_flags {
	RB_FL_OVERWRITE = 1,
};

struct ring_buffer_per_cpu;

struct buffer_page;

struct ring_buffer_iter {
	struct ring_buffer_per_cpu *cpu_buffer;
	long unsigned int head;
	long unsigned int next_event;
	struct buffer_page *head_page;
	struct buffer_page *cache_reader_page;
	long unsigned int cache_read;
	u64 read_stamp;
	u64 page_stamp;
	struct ring_buffer_event *event;
	int missed_events;
};

struct rb_irq_work {
	struct irq_work work;
	wait_queue_head_t waiters;
	wait_queue_head_t full_waiters;
	bool waiters_pending;
	bool full_waiters_pending;
	bool wakeup_full;
};

struct trace_buffer___2 {
	unsigned int flags;
	int cpus;
	atomic_t record_disabled;
	cpumask_var_t cpumask;
	struct lock_class_key *reader_lock_key;
	struct mutex mutex;
	struct ring_buffer_per_cpu **buffers;
	struct hlist_node node;
	u64 (*clock)();
	struct rb_irq_work irq_work;
	bool time_stamp_abs;
};

enum {
	RB_LEN_TIME_EXTEND = 8,
	RB_LEN_TIME_STAMP = 8,
};

struct buffer_data_page {
	u64 time_stamp;
	local_t commit;
	unsigned char data[0];
};

struct buffer_page {
	struct list_head list;
	local_t write;
	unsigned int read;
	local_t entries;
	long unsigned int real_end;
	struct buffer_data_page *page;
};

struct rb_event_info {
	u64 ts;
	u64 delta;
	u64 before;
	u64 after;
	long unsigned int length;
	struct buffer_page *tail_page;
	int add_timestamp;
};

enum {
	RB_ADD_STAMP_NONE = 0,
	RB_ADD_STAMP_EXTEND = 2,
	RB_ADD_STAMP_ABSOLUTE = 4,
	RB_ADD_STAMP_FORCE = 8,
};

enum {
	RB_CTX_TRANSITION = 0,
	RB_CTX_NMI = 1,
	RB_CTX_IRQ = 2,
	RB_CTX_SOFTIRQ = 3,
	RB_CTX_NORMAL = 4,
	RB_CTX_MAX = 5,
};

struct rb_time_struct {
	local64_t time;
};

typedef struct rb_time_struct rb_time_t;

struct ring_buffer_per_cpu {
	int cpu;
	atomic_t record_disabled;
	atomic_t resize_disabled;
	struct trace_buffer___2 *buffer;
	raw_spinlock_t reader_lock;
	arch_spinlock_t lock;
	struct lock_class_key lock_key;
	struct buffer_data_page *free_page;
	long unsigned int nr_pages;
	unsigned int current_context;
	struct list_head *pages;
	struct buffer_page *head_page;
	struct buffer_page *tail_page;
	struct buffer_page *commit_page;
	struct buffer_page *reader_page;
	long unsigned int lost_events;
	long unsigned int last_overrun;
	long unsigned int nest;
	local_t entries_bytes;
	local_t entries;
	local_t overrun;
	local_t commit_overrun;
	local_t dropped_events;
	local_t committing;
	local_t commits;
	local_t pages_touched;
	local_t pages_read;
	long int last_pages_touch;
	size_t shortest_full;
	long unsigned int read;
	long unsigned int read_bytes;
	rb_time_t write_stamp;
	rb_time_t before_stamp;
	u64 event_stamp[5];
	u64 read_stamp;
	long int nr_pages_to_update;
	struct list_head new_pages;
	struct work_struct update_pages_work;
	struct completion update_done;
	struct rb_irq_work irq_work;
};

struct dentry___57;

struct super_block___57;

struct module___55;

struct file_system_type___56 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___57 * (*mount)(struct file_system_type___56 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___57 *);
	struct module___55 *owner;
	struct file_system_type___56 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___57;

struct kiocb___56;

struct iov_iter___29;

struct poll_table_struct___42;

struct vm_area_struct___61;

struct inode___57;

struct file_lock___56;

struct page___61;

struct pipe_inode_info___18;

struct seq_file___54;

struct file_operations___56 {
	struct module___55 *owner;
	loff_t (*llseek)(struct file___57 *, loff_t, int);
	ssize_t (*read)(struct file___57 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___57 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___56 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___56 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___56 *, bool);
	int (*iterate)(struct file___57 *, struct dir_context *);
	int (*iterate_shared)(struct file___57 *, struct dir_context *);
	__poll_t (*poll)(struct file___57 *, struct poll_table_struct___42 *);
	long int (*unlocked_ioctl)(struct file___57 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___57 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___57 *, struct vm_area_struct___61 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___57 *, struct file___57 *);
	int (*flush)(struct file___57 *, fl_owner_t);
	int (*release)(struct inode___57 *, struct file___57 *);
	int (*fsync)(struct file___57 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___57 *, int);
	int (*lock)(struct file___57 *, int, struct file_lock___56 *);
	ssize_t (*sendpage)(struct file___57 *, struct page___61 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___57 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___57 *, long unsigned int);
	int (*flock)(struct file___57 *, int, struct file_lock___56 *);
	ssize_t (*splice_write)(struct pipe_inode_info___18 *, struct file___57 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___57 *, loff_t *, struct pipe_inode_info___18 *, size_t, unsigned int);
	int (*setlease)(struct file___57 *, long int, struct file_lock___56 **, void **);
	long int (*fallocate)(struct file___57 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___54 *, struct file___57 *);
	ssize_t (*copy_file_range)(struct file___57 *, loff_t, struct file___57 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___57 *, loff_t, struct file___57 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___57 *, loff_t, loff_t, int);
};

struct vmacache___61 {
	u64 seqnum;
	struct vm_area_struct___61 *vmas[4];
};

struct page_frag___61 {
	struct page___61 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___38;

struct debug_info___38 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___38 *hbp_break[16];
	struct perf_event___38 *hbp_watch[16];
};

struct thread_struct___38 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___38 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___62;

struct pid___50;

struct nsproxy___55;

struct signal_struct___57;

struct bio_list___25;

struct backing_dev_info___24;

struct io_context___26;

struct css_set___46;

struct perf_event_context___38;

struct request_queue___26;

struct vm_struct___58;

struct task_struct___62 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___62 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___62 *mm;
	struct mm_struct___62 *active_mm;
	struct vmacache___61 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___62 *real_parent;
	struct task_struct___62 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___62 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___50 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___55 *nsproxy;
	struct signal_struct___57 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___62 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___25 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___24 *backing_dev_info;
	struct io_context___26 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___46 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___38 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___18 *splice_pipe;
	struct page_frag___61 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___26 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___62 *oom_reaper_list;
	struct vm_struct___58 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___38 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___56;

struct kobj_type___56;

struct kernfs_node___56;

struct kobject___56 {
	const char *name;
	struct list_head entry;
	struct kobject___56 *parent;
	struct kset___56 *kset;
	struct kobj_type___56 *ktype;
	struct kernfs_node___56 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___53 {
	struct kobject___56 kobj;
	struct module___55 *mod;
	struct kobject___56 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___53 {
	struct module___55 *mod;
	struct latch_tree_node node;
};

struct module_layout___53 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___53 mtn;
};

struct module_attribute___53;

struct kernel_param___53;

struct trace_event_call___33;

struct module___55 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___53 mkobj;
	struct module_attribute___53 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___56 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___53 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___53 core_layout;
	struct module_layout___53 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___33 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___38 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___62 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___38)(struct perf_event___38 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___38;

struct fasync_struct___56;

struct pid_namespace___50;

struct perf_cgroup___38;

struct perf_event___38 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___38 *group_leader;
	struct pmu___38 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___38 hw;
	struct perf_event_context___38 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___38 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___62 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___56 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___38 *aux_event;
	void (*destroy)(struct perf_event___38 *);
	struct callback_head callback_head;
	struct pid_namespace___50 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___38 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___38 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___33 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___38 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___61 *pgtable_t___61;

struct address_space___56;

struct dev_pagemap___55;

struct page___61 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___56 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___15 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___61 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___61 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___62 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___55 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___55;

struct vm_area_struct___61 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___61 *vm_next;
	struct vm_area_struct___61 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___62 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___55 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___57 *vm_file;
	struct file___57 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___61;

struct mm_struct___62 {
	struct {
		struct vm_area_struct___61 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___57 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___61 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___62 *owner;
		struct user_namespace___10 *user_ns;
		struct file___57 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___56;

struct address_space___56 {
	struct inode___57 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___56 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___55;

struct dev_pagemap___55 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___55 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___56;

struct path___56 {
	struct vfsmount___56 *mnt;
	struct dentry___57 *dentry;
};

struct fown_struct___50 {
	rwlock_t lock;
	struct pid___50 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___57 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___56 f_path;
	struct inode___57 *f_inode;
	const struct file_operations___56 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___50 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___56 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___55;

struct vm_operations_struct___55 {
	void (*open)(struct vm_area_struct___61 *);
	void (*close)(struct vm_area_struct___61 *);
	int (*may_split)(struct vm_area_struct___61 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___61 *);
	int (*mprotect)(struct vm_area_struct___61 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___55 *);
	vm_fault_t (*huge_fault)(struct vm_fault___55 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___55 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___61 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___55 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___55 *);
	int (*access)(struct vm_area_struct___61 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___61 *);
	int (*set_policy)(struct vm_area_struct___61 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___61 *, long unsigned int);
	struct page___61 * (*find_special_page)(struct vm_area_struct___61 *, long unsigned int);
};

struct core_thread___61 {
	struct task_struct___62 *task;
	struct core_thread___61 *next;
};

struct core_state___61 {
	atomic_t nr_threads;
	struct core_thread___61 dumper;
	struct completion startup;
};

struct vm_fault___55 {
	const struct {
		struct vm_area_struct___61 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___61 *cow_page;
	struct page___61 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___61 prealloc_pte;
};

struct dev_pagemap_ops___55 {
	void (*page_free)(struct page___61 *);
	void (*kill)(struct dev_pagemap___55 *);
	void (*cleanup)(struct dev_pagemap___55 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___55 *);
};

struct upid___50 {
	int nr;
	struct pid_namespace___50 *ns;
};

struct pid_namespace___50 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___62 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___50 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___50 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___50 numbers[1];
};

struct signal_struct___57 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___62 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___62 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___50 *pids[4];
	struct pid___50 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___62 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___46;

struct nsproxy___55 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___50 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___46 *cgroup_ns;
};

struct bio___25;

struct bio_list___25 {
	struct bio___25 *head;
	struct bio___25 *tail;
};

struct cgroup_subsys_state___46;

struct bdi_writeback___24 {
	struct backing_dev_info___24 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___46 *memcg_css;
	struct cgroup_subsys_state___46 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___50;

struct backing_dev_info___24 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___24 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___50 *dev;
	char dev_name[64];
	struct device___50 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___57 *debug_dir;
};

struct io_cq___25;

struct io_context___26 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___25 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___46;

struct css_set___46 {
	struct cgroup_subsys_state___46 *subsys[14];
	refcount_t refcount;
	struct css_set___46 *dom_cset;
	struct cgroup___46 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___46 *mg_src_cgrp;
	struct cgroup___46 *mg_dst_cgrp;
	struct css_set___46 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___38 {
	struct pmu___38 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___62 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___38 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___18;

struct pipe_inode_info___18 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___61 *tmp_page;
	struct fasync_struct___56 *fasync_readers;
	struct fasync_struct___56 *fasync_writers;
	struct pipe_buffer___18 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___25;

struct blk_integrity___25 {
	const struct blk_integrity_profile___25 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___25 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___25 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___25;

struct elevator_queue___25;

struct blk_mq_ops___24;

struct blk_mq_hw_ctx___24;

struct gendisk___25;

struct blkcg_gq___24;

struct blk_mq_tag_set___24;

struct request_queue___26 {
	struct request___25 *last_merge;
	struct elevator_queue___25 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___24 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___24 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___25 *disk;
	struct kobject___56 kobj;
	struct kobject___56 *mq_kobj;
	struct blk_integrity___25 integrity;
	struct device___50 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___24 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___24 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___25 bio_split;
	struct dentry___57 *debugfs_dir;
	struct dentry___57 *sched_debugfs_dir;
	struct dentry___57 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___58 {
	struct vm_struct___58 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___61 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___56;

struct dentry___57 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___57 *d_parent;
	struct qstr d_name;
	struct inode___57 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___56 *d_op;
	struct super_block___57 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___56;

struct inode___57 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___56 *i_op;
	struct super_block___57 *i_sb;
	struct address_space___56 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___24 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___56 *i_fop;
		void (*free_inode)(struct inode___57 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___56 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___18 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___56 {
	int (*d_revalidate)(struct dentry___57 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___57 *, unsigned int);
	int (*d_hash)(const struct dentry___57 *, struct qstr *);
	int (*d_compare)(const struct dentry___57 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___57 *);
	int (*d_init)(struct dentry___57 *);
	void (*d_release)(struct dentry___57 *);
	void (*d_prune)(struct dentry___57 *);
	void (*d_iput)(struct dentry___57 *, struct inode___57 *);
	char * (*d_dname)(struct dentry___57 *, char *, int);
	struct vfsmount___56 * (*d_automount)(struct path___56 *);
	int (*d_manage)(const struct path___56 *, bool);
	struct dentry___57 * (*d_real)(struct dentry___57 *, const struct inode___57 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___56;

struct mem_dqinfo___56 {
	struct quota_format_type___56 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___56;

struct quota_info___56 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___57 *files[3];
	struct mem_dqinfo___56 info[3];
	const struct quota_format_ops___56 *ops[3];
};

struct rcuwait___57 {
	struct task_struct___62 *task;
};

struct percpu_rw_semaphore___57 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___57 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___56 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___57 rw_sem[3];
};

struct super_operations___56;

struct dquot_operations___56;

struct quotactl_ops___56;

struct block_device___26;

struct super_block___57 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___56 *s_type;
	const struct super_operations___56 *s_op;
	const struct dquot_operations___56 *dq_op;
	const struct quotactl_ops___56 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___57 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___26 *s_bdev;
	struct backing_dev_info___24 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___56 s_dquot;
	struct sb_writers___56 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___56 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___56 {
	struct dentry___57 *mnt_root;
	struct super_block___57 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct cgroup_subsys___46;

struct cgroup_subsys_state___46 {
	struct cgroup___46 *cgroup;
	struct cgroup_subsys___46 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___46 *parent;
};

struct cgroup_file___46 {
	struct kernfs_node___56 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___46 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___62 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___46;

struct cgroup_rstat_cpu___46;

struct cgroup___46 {
	struct cgroup_subsys_state___46 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___56 *kn;
	struct cgroup_file___46 procs_file;
	struct cgroup_file___46 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___46 *subsys[14];
	struct cgroup_root___46 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___46 *dom_cgrp;
	struct cgroup___46 *old_dom_cgrp;
	struct cgroup_rstat_cpu___46 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___46 psi;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___25 {
	struct request_queue___26 *q;
	struct io_context___26 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___26;

struct kiocb___56 {
	struct file___57 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___56 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___26 *ki_waitq;
	};
};

struct iattr___57 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___57 *ia_file;
};

struct dquot___56 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___57 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___56 {
	int qf_fmt_id;
	const struct quota_format_ops___56 *qf_ops;
	struct module___55 *qf_owner;
	struct quota_format_type___56 *qf_next;
};

struct quota_format_ops___56 {
	int (*check_quota_file)(struct super_block___57 *, int);
	int (*read_file_info)(struct super_block___57 *, int);
	int (*write_file_info)(struct super_block___57 *, int);
	int (*free_file_info)(struct super_block___57 *, int);
	int (*read_dqblk)(struct dquot___56 *);
	int (*commit_dqblk)(struct dquot___56 *);
	int (*release_dqblk)(struct dquot___56 *);
	int (*get_next_id)(struct super_block___57 *, struct kqid *);
};

struct dquot_operations___56 {
	int (*write_dquot)(struct dquot___56 *);
	struct dquot___56 * (*alloc_dquot)(struct super_block___57 *, int);
	void (*destroy_dquot)(struct dquot___56 *);
	int (*acquire_dquot)(struct dquot___56 *);
	int (*release_dquot)(struct dquot___56 *);
	int (*mark_dirty)(struct dquot___56 *);
	int (*write_info)(struct super_block___57 *, int);
	qsize_t * (*get_reserved_space)(struct inode___57 *);
	int (*get_projid)(struct inode___57 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___57 *, qsize_t *);
	int (*get_next_id)(struct super_block___57 *, struct kqid *);
};

struct quotactl_ops___56 {
	int (*quota_on)(struct super_block___57 *, int, int, const struct path___56 *);
	int (*quota_off)(struct super_block___57 *, int);
	int (*quota_enable)(struct super_block___57 *, unsigned int);
	int (*quota_disable)(struct super_block___57 *, unsigned int);
	int (*quota_sync)(struct super_block___57 *, int);
	int (*set_info)(struct super_block___57 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___57 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___57 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___57 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___57 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___57 *, unsigned int);
};

struct wait_page_queue___26 {
	struct page___61 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___24;

struct readahead_control___26;

struct address_space_operations___56 {
	int (*writepage)(struct page___61 *, struct writeback_control___24 *);
	int (*readpage)(struct file___57 *, struct page___61 *);
	int (*writepages)(struct address_space___56 *, struct writeback_control___24 *);
	int (*set_page_dirty)(struct page___61 *);
	int (*readpages)(struct file___57 *, struct address_space___56 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___26 *);
	int (*write_begin)(struct file___57 *, struct address_space___56 *, loff_t, unsigned int, unsigned int, struct page___61 **, void **);
	int (*write_end)(struct file___57 *, struct address_space___56 *, loff_t, unsigned int, unsigned int, struct page___61 *, void *);
	sector_t (*bmap)(struct address_space___56 *, sector_t);
	void (*invalidatepage)(struct page___61 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___61 *, gfp_t);
	void (*freepage)(struct page___61 *);
	ssize_t (*direct_IO)(struct kiocb___56 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___56 *, struct page___61 *, struct page___61 *, enum migrate_mode);
	bool (*isolate_page)(struct page___61 *, isolate_mode_t);
	void (*putback_page)(struct page___61 *);
	int (*launder_page)(struct page___61 *);
	int (*is_partially_uptodate)(struct page___61 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___61 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___56 *, struct page___61 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___57 *, sector_t *);
	void (*swap_deactivate)(struct file___57 *);
};

struct writeback_control___24 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___24 *wb;
	struct inode___57 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___26 {
	struct file___57 *file;
	struct address_space___56 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___29;

struct iov_iter___29 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___29 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___18 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___56 {
	struct dentry___57 * (*lookup)(struct inode___57 *, struct dentry___57 *, unsigned int);
	const char * (*get_link)(struct dentry___57 *, struct inode___57 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___57 *, int);
	struct posix_acl * (*get_acl)(struct inode___57 *, int, bool);
	int (*readlink)(struct dentry___57 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___57 *, struct dentry___57 *, umode_t, bool);
	int (*link)(struct dentry___57 *, struct inode___57 *, struct dentry___57 *);
	int (*unlink)(struct inode___57 *, struct dentry___57 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___57 *, struct dentry___57 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___57 *, struct dentry___57 *, umode_t);
	int (*rmdir)(struct inode___57 *, struct dentry___57 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___57 *, struct dentry___57 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___57 *, struct dentry___57 *, struct inode___57 *, struct dentry___57 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___57 *, struct iattr___57 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___56 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___57 *, char *, size_t);
	int (*fiemap)(struct inode___57 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___57 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___57 *, struct dentry___57 *, struct file___57 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___57 *, struct dentry___57 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___57 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___57 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___57 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___56 {
	void (*fl_copy_lock)(struct file_lock___56 *, struct file_lock___56 *);
	void (*fl_release_private)(struct file_lock___56 *);
};

struct lock_manager_operations___56;

struct file_lock___56 {
	struct file_lock___56 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___57 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___56 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___56 *fl_ops;
	const struct lock_manager_operations___56 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___56 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___56 *);
	int (*lm_grant)(struct file_lock___56 *, int);
	bool (*lm_break)(struct file_lock___56 *);
	int (*lm_change)(struct file_lock___56 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___56 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___56 *);
};

struct fasync_struct___56 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___56 *fa_next;
	struct file___57 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___56 {
	struct inode___57 * (*alloc_inode)(struct super_block___57 *);
	void (*destroy_inode)(struct inode___57 *);
	void (*free_inode)(struct inode___57 *);
	void (*dirty_inode)(struct inode___57 *, int);
	int (*write_inode)(struct inode___57 *, struct writeback_control___24 *);
	int (*drop_inode)(struct inode___57 *);
	void (*evict_inode)(struct inode___57 *);
	void (*put_super)(struct super_block___57 *);
	int (*sync_fs)(struct super_block___57 *, int);
	int (*freeze_super)(struct super_block___57 *);
	int (*freeze_fs)(struct super_block___57 *);
	int (*thaw_super)(struct super_block___57 *);
	int (*unfreeze_fs)(struct super_block___57 *);
	int (*statfs)(struct dentry___57 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___57 *, int *, char *);
	void (*umount_begin)(struct super_block___57 *);
	int (*show_options)(struct seq_file___54 *, struct dentry___57 *);
	int (*show_devname)(struct seq_file___54 *, struct dentry___57 *);
	int (*show_path)(struct seq_file___54 *, struct dentry___57 *);
	int (*show_stats)(struct seq_file___54 *, struct dentry___57 *);
	ssize_t (*quota_read)(struct super_block___57 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___57 *, int, const char *, size_t, loff_t);
	struct dquot___56 ** (*get_dquots)(struct inode___57 *);
	long int (*nr_cached_objects)(struct super_block___57 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___57 *, struct shrink_control___22 *);
	struct file___57 * (*real_loop)(struct file___57 *);
};

struct wakeup_source___50;

struct dev_pm_info___50 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___50 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___50 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___50;

struct bus_type___50;

struct device_driver___50;

struct dev_pm_domain___50;

struct device_node___30;

struct fwnode_handle___50;

struct class___50;

struct attribute_group___56;

struct device___50 {
	struct kobject___56 kobj;
	struct device___50 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___50 *type;
	struct bus_type___50 *bus;
	struct device_driver___50 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___50 power;
	struct dev_pm_domain___50 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___30 *of_node;
	struct fwnode_handle___50 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___50 *class;
	const struct attribute_group___56 **groups;
	void (*release)(struct device___50 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___26 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___57 *bd_inode;
	struct super_block___57 *bd_super;
	void *bd_claiming;
	struct device___50 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___56 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___25 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___57 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___42)(struct file___57 *, wait_queue_head_t *, struct poll_table_struct___42 *);

struct poll_table_struct___42 {
	poll_queue_proc___42 _qproc;
	__poll_t _key;
};

struct seq_operations___54;

struct seq_file___54 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___54 *op;
	int poll_event;
	const struct file___57 *file;
	void *private;
};

typedef void bio_end_io_t___25(struct bio___25 *);

struct bio_vec___29 {
	struct page___61 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___25;

struct bio___25 {
	struct bio___25 *bi_next;
	struct block_device___26 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___25 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___24 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___25 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___29 *bi_io_vec;
	struct bio_set___25 *bi_pool;
	struct bio_vec___29 bi_inline_vecs[0];
};

struct seq_operations___54 {
	void * (*start)(struct seq_file___54 *, loff_t *);
	void (*stop)(struct seq_file___54 *, void *);
	void * (*next)(struct seq_file___54 *, void *, loff_t *);
	int (*show)(struct seq_file___54 *, void *);
};

typedef struct poll_table_struct___42 poll_table___11;

struct fwnode_operations___50;

struct fwnode_handle___50 {
	struct fwnode_handle___50 *secondary;
	const struct fwnode_operations___50 *ops;
	struct device___50 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___50;

struct fwnode_endpoint___50;

struct fwnode_operations___50 {
	struct fwnode_handle___50 * (*get)(struct fwnode_handle___50 *);
	void (*put)(struct fwnode_handle___50 *);
	bool (*device_is_available)(const struct fwnode_handle___50 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___50 *, const struct device___50 *);
	bool (*property_present)(const struct fwnode_handle___50 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___50 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___50 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___50 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*get_parent)(const struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*get_next_child_node)(const struct fwnode_handle___50 *, struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*get_named_child_node)(const struct fwnode_handle___50 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___50 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___50 *);
	struct fwnode_handle___50 * (*graph_get_next_endpoint)(const struct fwnode_handle___50 *, struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*graph_get_remote_endpoint)(const struct fwnode_handle___50 *);
	struct fwnode_handle___50 * (*graph_get_port_parent)(struct fwnode_handle___50 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___50 *, struct fwnode_endpoint___50 *);
	int (*add_links)(struct fwnode_handle___50 *);
};

struct fwnode_endpoint___50 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___50 *local_fwnode;
};

struct fwnode_reference_args___50 {
	struct fwnode_handle___50 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___56;

struct kernfs_elem_dir___56 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___56 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___56;

struct kernfs_root___56 {
	struct kernfs_node___56 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___56 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___56 {
	struct kernfs_node___56 *target_kn;
};

struct kernfs_ops___56;

struct kernfs_elem_attr___56 {
	const struct kernfs_ops___56 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___56 *notify_next;
};

struct kernfs_node___56 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___56 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___56 dir;
		struct kernfs_elem_symlink___56 symlink;
		struct kernfs_elem_attr___56 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___56;

struct kernfs_ops___56 {
	int (*open)(struct kernfs_open_file___56 *);
	void (*release)(struct kernfs_open_file___56 *);
	int (*seq_show)(struct seq_file___54 *, void *);
	void * (*seq_start)(struct seq_file___54 *, loff_t *);
	void * (*seq_next)(struct seq_file___54 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___54 *, void *);
	ssize_t (*read)(struct kernfs_open_file___56 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___56 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___56 *, struct poll_table_struct___42 *);
	int (*mmap)(struct kernfs_open_file___56 *, struct vm_area_struct___61 *);
};

struct kernfs_syscall_ops___56 {
	int (*show_options)(struct seq_file___54 *, struct kernfs_root___56 *);
	int (*mkdir)(struct kernfs_node___56 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___56 *);
	int (*rename)(struct kernfs_node___56 *, struct kernfs_node___56 *, const char *);
	int (*show_path)(struct seq_file___54 *, struct kernfs_node___56 *, struct kernfs_root___56 *);
};

struct kernfs_open_file___56 {
	struct kernfs_node___56 *kn;
	struct file___57 *file;
	struct seq_file___54 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___55 *vm_ops;
};

struct bin_attribute___56;

struct attribute_group___56 {
	const char *name;
	umode_t (*is_visible)(struct kobject___56 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___56 *, struct bin_attribute___56 *, int);
	struct attribute **attrs;
	struct bin_attribute___56 **bin_attrs;
};

struct bin_attribute___56 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___56 * (*f_mapping)();
	ssize_t (*read)(struct file___57 *, struct kobject___56 *, struct bin_attribute___56 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___57 *, struct kobject___56 *, struct bin_attribute___56 *, char *, loff_t, size_t);
	int (*mmap)(struct file___57 *, struct kobject___56 *, struct bin_attribute___56 *, struct vm_area_struct___61 *);
};

struct sysfs_ops___56 {
	ssize_t (*show)(struct kobject___56 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___56 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___56;

struct kset___56 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___56 kobj;
	const struct kset_uevent_ops___56 *uevent_ops;
};

struct kobj_type___56 {
	void (*release)(struct kobject___56 *);
	const struct sysfs_ops___56 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___56 **default_groups;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___56 *);
	const void * (*namespace)(struct kobject___56 *);
	void (*get_ownership)(struct kobject___56 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___56 {
	int (* const filter)(struct kset___56 *, struct kobject___56 *);
	const char * (* const name)(struct kset___56 *, struct kobject___56 *);
	int (* const uevent)(struct kset___56 *, struct kobject___56 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___53 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___53 *);
	int (*get)(char *, const struct kernel_param___53 *);
	void (*free)(void *);
};

struct kparam_array___53;

struct kernel_param___53 {
	const char *name;
	struct module___55 *mod;
	const struct kernel_param_ops___53 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___53 *arr;
	};
};

struct kparam_array___53 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___53 *ops;
	void *elem;
};

struct module_attribute___53 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___53 *, struct module_kobject___53 *, char *);
	ssize_t (*store)(struct module_attribute___53 *, struct module_kobject___53 *, const char *, size_t);
	void (*setup)(struct module___55 *, const char *);
	int (*test)(struct module___55 *);
	void (*free)(struct module___55 *);
};

struct trace_event_functions___2;

struct trace_event___2 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___2 *funcs;
};

struct trace_event_class___33;

struct trace_event_call___33 {
	struct list_head list;
	struct trace_event_class___33 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___2 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___33 *, struct perf_event___38 *);
};

struct cgroup_namespace___46 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___46 *root_cset;
};

struct dev_pm_ops___50 {
	int (*prepare)(struct device___50 *);
	void (*complete)(struct device___50 *);
	int (*suspend)(struct device___50 *);
	int (*resume)(struct device___50 *);
	int (*freeze)(struct device___50 *);
	int (*thaw)(struct device___50 *);
	int (*poweroff)(struct device___50 *);
	int (*restore)(struct device___50 *);
	int (*suspend_late)(struct device___50 *);
	int (*resume_early)(struct device___50 *);
	int (*freeze_late)(struct device___50 *);
	int (*thaw_early)(struct device___50 *);
	int (*poweroff_late)(struct device___50 *);
	int (*restore_early)(struct device___50 *);
	int (*suspend_noirq)(struct device___50 *);
	int (*resume_noirq)(struct device___50 *);
	int (*freeze_noirq)(struct device___50 *);
	int (*thaw_noirq)(struct device___50 *);
	int (*poweroff_noirq)(struct device___50 *);
	int (*restore_noirq)(struct device___50 *);
	int (*runtime_suspend)(struct device___50 *);
	int (*runtime_resume)(struct device___50 *);
	int (*runtime_idle)(struct device___50 *);
};

struct wakeup_source___50 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___50 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___50 {
	struct dev_pm_ops___50 ops;
	int (*start)(struct device___50 *);
	void (*detach)(struct device___50 *, bool);
	int (*activate)(struct device___50 *);
	void (*sync)(struct device___50 *);
	void (*dismiss)(struct device___50 *);
};

struct bus_type___50 {
	const char *name;
	const char *dev_name;
	struct device___50 *dev_root;
	const struct attribute_group___56 **bus_groups;
	const struct attribute_group___56 **dev_groups;
	const struct attribute_group___56 **drv_groups;
	int (*match)(struct device___50 *, struct device_driver___50 *);
	int (*uevent)(struct device___50 *, struct kobj_uevent_env *);
	int (*probe)(struct device___50 *);
	void (*sync_state)(struct device___50 *);
	void (*remove)(struct device___50 *);
	void (*shutdown)(struct device___50 *);
	int (*online)(struct device___50 *);
	int (*offline)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	int (*num_vf)(struct device___50 *);
	int (*dma_configure)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___50 {
	const char *name;
	struct bus_type___50 *bus;
	struct module___55 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___50 *);
	void (*sync_state)(struct device___50 *);
	int (*remove)(struct device___50 *);
	void (*shutdown)(struct device___50 *);
	int (*suspend)(struct device___50 *, pm_message_t);
	int (*resume)(struct device___50 *);
	const struct attribute_group___56 **groups;
	const struct attribute_group___56 **dev_groups;
	const struct dev_pm_ops___50 *pm;
	void (*coredump)(struct device___50 *);
	struct driver_private *p;
};

struct device_type___50 {
	const char *name;
	const struct attribute_group___56 **groups;
	int (*uevent)(struct device___50 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___50 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___50 *);
	const struct dev_pm_ops___50 *pm;
};

struct class___50 {
	const char *name;
	struct module___55 *owner;
	const struct attribute_group___56 **class_groups;
	const struct attribute_group___56 **dev_groups;
	struct kobject___56 *dev_kobj;
	int (*dev_uevent)(struct device___50 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___50 *, umode_t *);
	void (*class_release)(struct class___50 *);
	void (*dev_release)(struct device___50 *);
	int (*shutdown_pre)(struct device___50 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___50 *);
	void (*get_ownership)(struct device___50 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___50 *pm;
	struct subsys_private *p;
};

struct property___26;

struct device_node___30 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___50 fwnode;
	struct property___26 *properties;
	struct property___26 *deadprops;
	struct device_node___30 *parent;
	struct device_node___30 *child;
	struct device_node___30 *sibling;
	struct kobject___56 kobj;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___25;

struct gendisk___25 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___26 *part0;
	const struct block_device_operations___25 *fops;
	struct request_queue___26 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___24 *bdi;
	struct kobject___56 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___56 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___25 {
	struct bio___25 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___29 *bip_vec;
	struct bio_vec___29 bip_inline_vecs[0];
};

struct blkcg___24;

struct blkg_policy_data___24;

struct blkcg_gq___24 {
	struct request_queue___26 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___24 *blkcg;
	struct blkcg_gq___24 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___24 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___25 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

struct cftype___46;

struct cgroup_subsys___46 {
	struct cgroup_subsys_state___46 * (*css_alloc)(struct cgroup_subsys_state___46 *);
	int (*css_online)(struct cgroup_subsys_state___46 *);
	void (*css_offline)(struct cgroup_subsys_state___46 *);
	void (*css_released)(struct cgroup_subsys_state___46 *);
	void (*css_free)(struct cgroup_subsys_state___46 *);
	void (*css_reset)(struct cgroup_subsys_state___46 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___46 *, int);
	int (*css_extra_stat_show)(struct seq_file___54 *, struct cgroup_subsys_state___46 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___62 *, struct css_set___46 *);
	void (*cancel_fork)(struct task_struct___62 *, struct css_set___46 *);
	void (*fork)(struct task_struct___62 *);
	void (*exit)(struct task_struct___62 *);
	void (*release)(struct task_struct___62 *);
	void (*bind)(struct cgroup_subsys_state___46 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___46 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___46 *dfl_cftypes;
	struct cftype___46 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___46 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___46 *updated_children;
	struct cgroup___46 *updated_next;
};

struct cgroup_root___46 {
	struct kernfs_root___56 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___46 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___46 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___46 *ss;
	struct list_head node;
	struct kernfs_ops___56 *kf_ops;
	int (*open)(struct kernfs_open_file___56 *);
	void (*release)(struct kernfs_open_file___56 *);
	u64 (*read_u64)(struct cgroup_subsys_state___46 *, struct cftype___46 *);
	s64 (*read_s64)(struct cgroup_subsys_state___46 *, struct cftype___46 *);
	int (*seq_show)(struct seq_file___54 *, void *);
	void * (*seq_start)(struct seq_file___54 *, loff_t *);
	void * (*seq_next)(struct seq_file___54 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___54 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___46 *, struct cftype___46 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___46 *, struct cftype___46 *, s64);
	ssize_t (*write)(struct kernfs_open_file___56 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___56 *, struct poll_table_struct___42 *);
};

typedef void integrity_prepare_fn___25(struct request___25 *);

typedef void integrity_complete_fn___25(struct request___25 *, unsigned int);

struct blk_integrity_profile___25 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___25 *prepare_fn;
	integrity_complete_fn___25 *complete_fn;
	const char *name;
};

struct block_device_operations___25 {
	blk_qc_t (*submit_bio)(struct bio___25 *);
	int (*open)(struct block_device___26 *, fmode_t);
	void (*release)(struct gendisk___25 *, fmode_t);
	int (*rw_page)(struct block_device___26 *, sector_t, struct page___61 *, unsigned int);
	int (*ioctl)(struct block_device___26 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___26 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___25 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___25 *);
	int (*getgeo)(struct block_device___26 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___26 *, bool);
	void (*swap_slot_free_notify)(struct block_device___26 *, long unsigned int);
	int (*report_zones)(struct gendisk___25 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___25 *, umode_t *);
	struct module___55 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___25 *, sector_t *);
};

typedef void rq_end_io_fn___25(struct request___25 *, blk_status_t);

struct request___25 {
	struct request_queue___26 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___24 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___25 *bio;
	struct bio___25 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___29 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___25 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___25 *saved_end_io;
		} flush;
	};
	struct gendisk___25 *rq_disk;
	struct block_device___26 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___25 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___24 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___26 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___56 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___57 *debugfs_dir;
	struct dentry___57 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___25;

struct elevator_mq_ops___25 {
	int (*init_sched)(struct request_queue___26 *, struct elevator_type___25 *);
	void (*exit_sched)(struct elevator_queue___25 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___24 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___24 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___24 *);
	bool (*allow_merge)(struct request_queue___26 *, struct request___25 *, struct bio___25 *);
	bool (*bio_merge)(struct request_queue___26 *, struct bio___25 *, unsigned int);
	int (*request_merge)(struct request_queue___26 *, struct request___25 **, struct bio___25 *);
	void (*request_merged)(struct request_queue___26 *, struct request___25 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___26 *, struct request___25 *, struct request___25 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___25 *);
	void (*finish_request)(struct request___25 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___24 *, struct list_head *, bool);
	struct request___25 * (*dispatch_request)(struct blk_mq_hw_ctx___24 *);
	bool (*has_work)(struct blk_mq_hw_ctx___24 *);
	void (*completed_request)(struct request___25 *, u64);
	void (*requeue_request)(struct request___25 *);
	struct request___25 * (*former_request)(struct request_queue___26 *, struct request___25 *);
	struct request___25 * (*next_request)(struct request_queue___26 *, struct request___25 *);
	void (*init_icq)(struct io_cq___25 *);
	void (*exit_icq)(struct io_cq___25 *);
};

struct elv_fs_entry___25;

struct elevator_type___25 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___25 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___25 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___55 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___25 {
	struct elevator_type___25 *type;
	void *elevator_data;
	struct kobject___56 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___25 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___25 *, char *);
	ssize_t (*store)(struct elevator_queue___25 *, const char *, size_t);
};

struct blk_mq_queue_data___24;

struct blk_mq_ops___24 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___24 *, const struct blk_mq_queue_data___24 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___24 *);
	int (*get_budget)(struct request_queue___26 *);
	void (*put_budget)(struct request_queue___26 *, int);
	void (*set_rq_budget_token)(struct request___25 *, int);
	int (*get_rq_budget_token)(struct request___25 *);
	enum blk_eh_timer_return (*timeout)(struct request___25 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___24 *);
	void (*complete)(struct request___25 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___24 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___24 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___24 *, struct request___25 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___24 *, struct request___25 *, unsigned int);
	void (*initialize_rq_fn)(struct request___25 *);
	void (*cleanup_rq)(struct request___25 *);
	bool (*busy)(struct request_queue___26 *);
	int (*map_queues)(struct blk_mq_tag_set___24 *);
	void (*show_rq)(struct seq_file___54 *, struct request___25 *);
};

struct blk_mq_tag_set___24 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___24 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___24 {
	struct request___25 *rq;
	bool last;
};

struct blkcg_policy_data___24;

struct blkcg___24 {
	struct cgroup_subsys_state___46 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___24 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___24 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___24 {
	struct blkcg___24 *blkcg;
	int plid;
};

struct blkg_policy_data___24 {
	struct blkcg_gq___24 *blkg;
	int plid;
};

typedef struct vfsmount___56 * (*debugfs_automount_t)(struct dentry___57 *, void *);

struct pipe_buf_operations___18;

struct pipe_buffer___18 {
	struct page___61 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___18 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___18 {
	int (*confirm)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
	void (*release)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
	bool (*try_steal)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
	bool (*get)(struct pipe_inode_info___18 *, struct pipe_buffer___18 *);
};

struct splice_pipe_desc___2 {
	struct page___61 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___18 *ops;
	void (*spd_release)(struct splice_pipe_desc___2 *, unsigned int);
};

struct trace_export {
	struct trace_export *next;
	void (*write)(struct trace_export *, const void *, unsigned int);
	int flags;
};

enum fsnotify_data_type {
	FSNOTIFY_EVENT_NONE = 0,
	FSNOTIFY_EVENT_PATH = 1,
	FSNOTIFY_EVENT_INODE = 2,
};

struct property___26 {
	char *name;
	int length;
	void *value;
	struct property___26 *next;
	long unsigned int _flags;
	struct bin_attribute___56 attr;
};

struct perf_cpu_context___38;

struct perf_output_handle___38;

struct pmu___38 {
	struct list_head entry;
	struct module___55 *module;
	struct device___50 *dev;
	const struct attribute_group___56 **attr_groups;
	const struct attribute_group___56 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___38 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___38 *);
	void (*pmu_disable)(struct pmu___38 *);
	int (*event_init)(struct perf_event___38 *);
	void (*event_mapped)(struct perf_event___38 *, struct mm_struct___62 *);
	void (*event_unmapped)(struct perf_event___38 *, struct mm_struct___62 *);
	int (*add)(struct perf_event___38 *, int);
	void (*del)(struct perf_event___38 *, int);
	void (*start)(struct perf_event___38 *, int);
	void (*stop)(struct perf_event___38 *, int);
	void (*read)(struct perf_event___38 *);
	void (*start_txn)(struct pmu___38 *, unsigned int);
	int (*commit_txn)(struct pmu___38 *);
	void (*cancel_txn)(struct pmu___38 *);
	int (*event_idx)(struct perf_event___38 *);
	void (*sched_task)(struct perf_event_context___38 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___38 *, struct perf_event_context___38 *);
	void * (*setup_aux)(struct perf_event___38 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___38 *, struct perf_output_handle___38 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___38 *);
	int (*aux_output_match)(struct perf_event___38 *);
	int (*filter_match)(struct perf_event___38 *);
	int (*check_period)(struct perf_event___38 *, u64);
};

struct perf_cpu_context___38 {
	struct perf_event_context___38 ctx;
	struct perf_event_context___38 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___38 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___38 **heap;
	struct perf_event___38 *heap_default[2];
};

struct perf_output_handle___38 {
	struct perf_event___38 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___38 {
	struct cgroup_subsys_state___46 css;
	struct perf_cgroup_info *info;
};

struct trace_array___2;

struct tracer___2;

struct array_buffer___2;

struct trace_iterator___2 {
	struct trace_array___2 *tr;
	struct tracer___2 *trace;
	struct array_buffer___2 *array_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	void *temp;
	unsigned int temp_size;
	char *fmt;
	unsigned int fmt_size;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct array_buffer___2 {
	struct trace_array___2 *tr;
	struct trace_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___15;

struct trace_options___2;

struct cond_snapshot___2;

struct trace_array___2 {
	struct list_head list;
	char *name;
	struct array_buffer___2 array_buffer;
	struct array_buffer___2 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct dentry___57 *d_max_latency;
	struct work_struct fsnotify_work;
	struct irq_work fsnotify_irqwork;
	struct trace_pid_list *filtered_pids;
	struct trace_pid_list *filtered_no_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___15 *enter_syscall_files[449];
	struct trace_event_file___15 *exit_syscall_files[449];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	int buffer_percent;
	unsigned int n_err_log_entries;
	struct tracer___2 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct list_head err_log;
	struct dentry___57 *dir;
	struct dentry___57 *options;
	struct dentry___57 *percpu_dir;
	struct dentry___57 *event_dir;
	struct trace_options___2 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___15 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	int trace_ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct trace_pid_list *function_no_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int no_filter_buffering_ref;
	struct list_head hist_vars;
	struct cond_snapshot___2 *cond_snapshot;
	struct trace_func_repeats *last_func_repeats;
};

struct tracer_flags___2;

struct tracer___2 {
	const char *name;
	int (*init)(struct trace_array___2 *);
	void (*reset)(struct trace_array___2 *);
	void (*start)(struct trace_array___2 *);
	void (*stop)(struct trace_array___2 *);
	int (*update_thresh)(struct trace_array___2 *);
	void (*open)(struct trace_iterator___2 *);
	void (*pipe_open)(struct trace_iterator___2 *);
	void (*close)(struct trace_iterator___2 *);
	void (*pipe_close)(struct trace_iterator___2 *);
	ssize_t (*read)(struct trace_iterator___2 *, struct file___57 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___2 *, struct file___57 *, loff_t *, struct pipe_inode_info___18 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___54 *);
	enum print_line_t (*print_line)(struct trace_iterator___2 *);
	int (*set_flag)(struct trace_array___2 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___2 *, u32, int);
	struct tracer___2 *next;
	struct tracer_flags___2 *flags;
	int enabled;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

enum trace_iter_flags {
	TRACE_FILE_LAT_FMT = 1,
	TRACE_FILE_ANNOTATE = 2,
	TRACE_FILE_TIME_IN_NS = 4,
};

typedef enum print_line_t (*trace_print_func___2)(struct trace_iterator___2 *, int, struct trace_event___2 *);

struct trace_event_functions___2 {
	trace_print_func___2 trace;
	trace_print_func___2 raw;
	trace_print_func___2 hex;
	trace_print_func___2 binary;
};

enum trace_flag_type {
	TRACE_FLAG_IRQS_OFF = 1,
	TRACE_FLAG_IRQS_NOSUPPORT = 2,
	TRACE_FLAG_NEED_RESCHED = 4,
	TRACE_FLAG_HARDIRQ = 8,
	TRACE_FLAG_SOFTIRQ = 16,
	TRACE_FLAG_PREEMPT_RESCHED = 32,
	TRACE_FLAG_NMI = 64,
};

struct trace_event_fields___33 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___33 *);
	};
};

struct trace_event_class___33 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___33 *, enum trace_reg, void *);
	struct trace_event_fields___33 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___33 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___33 *);
};

struct trace_event_buffer___14 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___15 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_subsystem_dir___2;

struct trace_event_file___15 {
	struct list_head list;
	struct trace_event_call___33 *event_call;
	struct event_filter *filter;
	struct dentry___57 *dir;
	struct trace_array___2 *tr;
	struct trace_subsystem_dir___2 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___2 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___2 *tr;
	struct dentry___57 *entry;
	int ref_count;
	int nr_events;
};

enum trace_type {
	__TRACE_FIRST_TYPE = 0,
	TRACE_FN = 1,
	TRACE_CTX = 2,
	TRACE_WAKE = 3,
	TRACE_STACK = 4,
	TRACE_PRINT = 5,
	TRACE_BPRINT = 6,
	TRACE_MMIO_RW = 7,
	TRACE_MMIO_MAP = 8,
	TRACE_BRANCH = 9,
	TRACE_GRAPH_RET = 10,
	TRACE_GRAPH_ENT = 11,
	TRACE_USER_STACK = 12,
	TRACE_BLK = 13,
	TRACE_BPUTS = 14,
	TRACE_HWLAT = 15,
	TRACE_OSNOISE = 16,
	TRACE_TIMERLAT = 17,
	TRACE_RAW_DATA = 18,
	TRACE_FUNC_REPEATS = 19,
	__TRACE_LAST_TYPE = 20,
};

struct ftrace_entry {
	struct trace_entry ent;
	long unsigned int ip;
	long unsigned int parent_ip;
};

struct stack_entry {
	struct trace_entry ent;
	int size;
	long unsigned int caller[8];
};

struct bprint_entry {
	struct trace_entry ent;
	long unsigned int ip;
	const char *fmt;
	u32 buf[0];
};

struct print_entry {
	struct trace_entry ent;
	long unsigned int ip;
	char buf[0];
};

struct raw_data_entry {
	struct trace_entry ent;
	unsigned int id;
	char buf[0];
};

struct bputs_entry {
	struct trace_entry ent;
	long unsigned int ip;
	const char *str;
};

struct func_repeats_entry {
	struct trace_entry ent;
	long unsigned int ip;
	long unsigned int parent_ip;
	u16 count;
	u16 top_delta_ts;
	u32 bottom_delta_ts;
};

struct trace_option_dentry___2;

struct trace_options___2 {
	struct tracer___2 *tracer;
	struct trace_option_dentry___2 *topts;
};

struct trace_option_dentry___2 {
	struct tracer_opt *opt;
	struct tracer_flags___2 *flags;
	struct trace_array___2 *tr;
	struct dentry___57 *entry;
};

typedef bool (*cond_update_fn_t___2)(struct trace_array___2 *, void *);

struct cond_snapshot___2 {
	void *cond_data;
	cond_update_fn_t___2 update;
};

struct tracer_flags___2 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___2 *trace;
};

struct ftrace_func_command___2 {
	struct list_head list;
	char *name;
	int (*func)(struct trace_array___2 *, struct ftrace_hash *, char *, char *, char *, int);
};

struct ftrace_probe_ops___2 {
	void (*func)(long unsigned int, long unsigned int, struct trace_array___2 *, struct ftrace_probe_ops___2 *, void *);
	int (*init)(struct ftrace_probe_ops___2 *, struct trace_array___2 *, long unsigned int, void *, void **);
	void (*free)(struct ftrace_probe_ops___2 *, struct trace_array___2 *, long unsigned int, void *);
	int (*print)(struct seq_file___54 *, long unsigned int, struct ftrace_probe_ops___2 *, void *);
};

enum trace_iterator_flags {
	TRACE_ITER_PRINT_PARENT = 1,
	TRACE_ITER_SYM_OFFSET = 2,
	TRACE_ITER_SYM_ADDR = 4,
	TRACE_ITER_VERBOSE = 8,
	TRACE_ITER_RAW = 16,
	TRACE_ITER_HEX = 32,
	TRACE_ITER_BIN = 64,
	TRACE_ITER_BLOCK = 128,
	TRACE_ITER_PRINTK = 256,
	TRACE_ITER_ANNOTATE = 512,
	TRACE_ITER_USERSTACKTRACE = 1024,
	TRACE_ITER_SYM_USEROBJ = 2048,
	TRACE_ITER_PRINTK_MSGONLY = 4096,
	TRACE_ITER_CONTEXT_INFO = 8192,
	TRACE_ITER_LATENCY_FMT = 16384,
	TRACE_ITER_RECORD_CMD = 32768,
	TRACE_ITER_RECORD_TGID = 65536,
	TRACE_ITER_OVERWRITE = 131072,
	TRACE_ITER_STOP_ON_FREE = 262144,
	TRACE_ITER_IRQ_INFO = 524288,
	TRACE_ITER_MARKERS = 1048576,
	TRACE_ITER_EVENT_FORK = 2097152,
	TRACE_ITER_PAUSE_ON_TRACE = 4194304,
	TRACE_ITER_HASH_PTR = 8388608,
	TRACE_ITER_FUNCTION = 16777216,
	TRACE_ITER_FUNC_FORK = 33554432,
	TRACE_ITER_DISPLAY_GRAPH = 67108864,
	TRACE_ITER_STACKTRACE = 134217728,
};

struct trace_min_max_param {
	struct mutex *lock;
	u64 *val;
	u64 *min;
	u64 *max;
};

struct saved_cmdlines_buffer {
	unsigned int map_pid_to_cmdline[32769];
	unsigned int *map_cmdline_to_pid;
	unsigned int cmdline_num;
	int cmdline_idx;
	char *saved_cmdlines;
};

struct ftrace_stack {
	long unsigned int calls[1024];
};

struct ftrace_stacks {
	struct ftrace_stack stacks[4];
};

struct trace_buffer_struct {
	int nesting;
	char buffer[4096];
};

struct ftrace_buffer_info {
	struct trace_iterator___2 iter;
	void *spare;
	unsigned int spare_cpu;
	unsigned int read;
};

struct err_info {
	const char **errs;
	u8 type;
	u8 pos;
	u64 ts;
};

struct tracing_log_err {
	struct list_head list;
	struct err_info info;
	char loc[128];
	char cmd[256];
};

struct buffer_ref {
	struct trace_buffer *buffer;
	void *page;
	int cpu;
	refcount_t refcount;
};

struct ftrace_func_mapper___2;

struct ctx_switch_entry {
	struct trace_entry ent;
	unsigned int prev_pid;
	unsigned int next_pid;
	unsigned int next_cpu;
	unsigned char prev_prio;
	unsigned char prev_state;
	unsigned char next_prio;
	unsigned char next_state;
};

struct userstack_entry {
	struct trace_entry ent;
	unsigned int tgid;
	long unsigned int caller[8];
};

struct hwlat_entry {
	struct trace_entry ent;
	u64 duration;
	u64 outer_duration;
	u64 nmi_total_ts;
	struct timespec64 timestamp;
	unsigned int nmi_count;
	unsigned int seqnum;
	unsigned int count;
};

struct osnoise_entry {
	struct trace_entry ent;
	u64 noise;
	u64 runtime;
	u64 max_sample;
	unsigned int hw_count;
	unsigned int nmi_count;
	unsigned int irq_count;
	unsigned int softirq_count;
	unsigned int thread_count;
};

struct timerlat_entry {
	struct trace_entry ent;
	unsigned int seqnum;
	int context;
	u64 timer_latency;
};

struct trace_mark {
	long long unsigned int val;
	char sym;
};

struct stat_node {
	struct rb_node node;
	void *stat;
};

struct stat_session {
	struct list_head session_list;
	struct tracer_stat *ts;
	struct rb_root stat_root;
	struct mutex stat_mutex;
	struct dentry___57 *file;
};

struct trace_bprintk_fmt {
	struct list_head list;
	const char *fmt;
};

struct static_key___4 {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry *entries;
		struct static_key_mod *next;
	};
	long: 64;
	long: 64;
};

struct static_key_false___4 {
	struct static_key___4 key;
};

typedef int (*tracing_map_cmp_fn_t)(void *, void *);

struct tracing_map_field {
	tracing_map_cmp_fn_t cmp_fn;
	union {
		atomic64_t sum;
		unsigned int offset;
	};
	long: 64;
	long: 64;
};

struct tracing_map;

struct tracing_map_elt {
	struct tracing_map *map;
	struct tracing_map_field *fields;
	atomic64_t *vars;
	bool *var_set;
	void *key;
	void *private_data;
};

struct tracing_map_sort_key {
	unsigned int field_idx;
	bool descending;
};

struct tracing_map_array;

struct tracing_map_ops;

struct tracing_map {
	unsigned int key_size;
	unsigned int map_bits;
	unsigned int map_size;
	unsigned int max_elts;
	atomic_t next_elt;
	struct tracing_map_array *elts;
	struct tracing_map_array *map;
	const struct tracing_map_ops *ops;
	void *private_data;
	struct tracing_map_field fields[6];
	unsigned int n_fields;
	int key_idx[3];
	unsigned int n_keys;
	struct tracing_map_sort_key sort_key;
	unsigned int n_vars;
	atomic64_t hits;
	atomic64_t drops;
};

struct tracing_map_entry {
	u32 key;
	struct tracing_map_elt *val;
};

struct tracing_map_sort_entry {
	void *key;
	struct tracing_map_elt *elt;
	bool elt_copied;
	bool dup;
};

struct tracing_map_array {
	unsigned int entries_per_page;
	unsigned int entry_size_shift;
	unsigned int entry_shift;
	unsigned int entry_mask;
	unsigned int n_pages;
	void **pages;
};

struct tracing_map_ops {
	int (*elt_alloc)(struct tracing_map_elt *);
	void (*elt_free)(struct tracing_map_elt *);
	void (*elt_clear)(struct tracing_map_elt *);
	void (*elt_init)(struct tracing_map_elt *);
};

enum {
	TRACE_FUNC_NO_OPTS = 0,
	TRACE_FUNC_OPT_STACK = 1,
	TRACE_FUNC_OPT_NO_REPEATS = 2,
	TRACE_FUNC_OPT_HIGHEST_BIT = 4,
};

enum {
	MODE_NONE = 0,
	MODE_ROUND_ROBIN = 1,
	MODE_PER_CPU = 2,
	MODE_MAX = 3,
};

struct hwlat_kthread_data {
	struct task_struct___62 *kthread;
	u64 nmi_ts_start;
	u64 nmi_total_ts;
	int nmi_count;
	int nmi_cpu;
};

struct hwlat_sample {
	u64 seqnum;
	u64 duration;
	u64 outer_duration;
	u64 nmi_total_ts;
	struct timespec64 timestamp;
	int nmi_count;
	int count;
};

struct hwlat_data {
	struct mutex lock;
	u64 count;
	u64 sample_window;
	u64 sample_width;
	int thread_mode;
};

enum {
	TRACE_NOP_OPT_ACCEPT = 1,
	TRACE_NOP_OPT_REFUSE = 2,
};

struct ftrace_graph_ent_entry {
	struct trace_entry ent;
	struct ftrace_graph_ent graph_ent;
} __attribute__((packed));

struct ftrace_graph_ret_entry {
	struct trace_entry ent;
	struct ftrace_graph_ret ret;
};

struct fgraph_cpu_data {
	pid_t last_pid;
	int depth;
	int depth_irq;
	int ignore;
	long unsigned int enter_funcs[50];
};

struct fgraph_data {
	struct fgraph_cpu_data *cpu_data;
	struct ftrace_graph_ent_entry ent;
	struct ftrace_graph_ret_entry ret;
	int failed;
	int cpu;
	int: 32;
} __attribute__((packed));

enum {
	FLAGS_FILL_FULL = 268435456,
	FLAGS_FILL_START = 536870912,
	FLAGS_FILL_END = 805306368,
};

struct device_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct device___50 *, struct device_attribute___7 *, char *);
	ssize_t (*store)(struct device___50 *, struct device_attribute___7 *, const char *, size_t);
};

struct disk_stats {
	u64 nsecs[4];
	long unsigned int sectors[4];
	long unsigned int ios[4];
	long unsigned int merges[4];
	long unsigned int io_ticks;
	local_t in_flight[2];
};

struct blk_crypto_key;

struct bio_crypt_ctx {
	const struct blk_crypto_key *bc_key;
	u64 bc_dun[4];
};

enum req_opf {
	REQ_OP_READ = 0,
	REQ_OP_WRITE = 1,
	REQ_OP_FLUSH = 2,
	REQ_OP_DISCARD = 3,
	REQ_OP_SECURE_ERASE = 5,
	REQ_OP_WRITE_SAME = 7,
	REQ_OP_WRITE_ZEROES = 9,
	REQ_OP_ZONE_OPEN = 10,
	REQ_OP_ZONE_CLOSE = 11,
	REQ_OP_ZONE_FINISH = 12,
	REQ_OP_ZONE_APPEND = 13,
	REQ_OP_ZONE_RESET = 15,
	REQ_OP_ZONE_RESET_ALL = 17,
	REQ_OP_DRV_IN = 34,
	REQ_OP_DRV_OUT = 35,
	REQ_OP_LAST = 36,
};

enum req_flag_bits {
	__REQ_FAILFAST_DEV = 8,
	__REQ_FAILFAST_TRANSPORT = 9,
	__REQ_FAILFAST_DRIVER = 10,
	__REQ_SYNC = 11,
	__REQ_META = 12,
	__REQ_PRIO = 13,
	__REQ_NOMERGE = 14,
	__REQ_IDLE = 15,
	__REQ_INTEGRITY = 16,
	__REQ_FUA = 17,
	__REQ_PREFLUSH = 18,
	__REQ_RAHEAD = 19,
	__REQ_BACKGROUND = 20,
	__REQ_NOWAIT = 21,
	__REQ_CGROUP_PUNT = 22,
	__REQ_NOUNMAP = 23,
	__REQ_HIPRI = 24,
	__REQ_DRV = 25,
	__REQ_SWAP = 26,
	__REQ_NR_BITS = 27,
};

struct blk_mq_ctxs;

struct blk_mq_ctx {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___24 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___26 *queue;
	struct blk_mq_ctxs *ctxs;
	struct kobject___56 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_alloc_data {
	struct request_queue___26 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx *ctx;
	struct blk_mq_hw_ctx___24 *hctx;
};

struct blk_stat_callback {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___25 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback *);
	void *data;
	struct callback_head rcu;
};

struct rchan___2;

struct blk_trace {
	int trace_state;
	struct rchan___2 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___57 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___25 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct rchan_buf___2 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___2 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___57 *dentry;
	struct kref kref;
	struct page___61 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___2;

struct rchan___2 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___2 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___2 **buf;
	int is_global;
	struct list_head list;
	struct dentry___57 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___2 {
	int (*subbuf_start)(struct rchan_buf___2 *, void *, void *, size_t);
	struct dentry___57 * (*create_buf_file)(const char *, struct dentry___57 *, umode_t, struct rchan_buf___2 *, int *);
	int (*remove_buf_file)(struct dentry___57 *);
};

enum blktrace_cat {
	BLK_TC_READ = 1,
	BLK_TC_WRITE = 2,
	BLK_TC_FLUSH = 4,
	BLK_TC_SYNC = 8,
	BLK_TC_SYNCIO = 8,
	BLK_TC_QUEUE = 16,
	BLK_TC_REQUEUE = 32,
	BLK_TC_ISSUE = 64,
	BLK_TC_COMPLETE = 128,
	BLK_TC_FS = 256,
	BLK_TC_PC = 512,
	BLK_TC_NOTIFY = 1024,
	BLK_TC_AHEAD = 2048,
	BLK_TC_META = 4096,
	BLK_TC_DISCARD = 8192,
	BLK_TC_DRV_DATA = 16384,
	BLK_TC_FUA = 32768,
	BLK_TC_END = 32768,
};

enum blktrace_act {
	__BLK_TA_QUEUE = 1,
	__BLK_TA_BACKMERGE = 2,
	__BLK_TA_FRONTMERGE = 3,
	__BLK_TA_GETRQ = 4,
	__BLK_TA_SLEEPRQ = 5,
	__BLK_TA_REQUEUE = 6,
	__BLK_TA_ISSUE = 7,
	__BLK_TA_COMPLETE = 8,
	__BLK_TA_PLUG = 9,
	__BLK_TA_UNPLUG_IO = 10,
	__BLK_TA_UNPLUG_TIMER = 11,
	__BLK_TA_INSERT = 12,
	__BLK_TA_SPLIT = 13,
	__BLK_TA_BOUNCE = 14,
	__BLK_TA_REMAP = 15,
	__BLK_TA_ABORT = 16,
	__BLK_TA_DRV_DATA = 17,
	__BLK_TA_CGROUP = 256,
};

enum blktrace_notify {
	__BLK_TN_PROCESS = 0,
	__BLK_TN_TIMESTAMP = 1,
	__BLK_TN_MESSAGE = 2,
	__BLK_TN_CGROUP = 256,
};

struct blk_io_trace {
	__u32 magic;
	__u32 sequence;
	__u64 time;
	__u64 sector;
	__u32 bytes;
	__u32 action;
	__u32 pid;
	__u32 device;
	__u32 cpu;
	__u16 error;
	__u16 pdu_len;
};

struct blk_io_trace_remap {
	__be32 device_from;
	__be32 device_to;
	__be64 sector_from;
};

enum {
	Blktrace_setup = 1,
	Blktrace_running = 2,
	Blktrace_stopped = 3,
};

struct blk_user_trace_setup {
	char name[32];
	__u16 act_mask;
	__u32 buf_size;
	__u32 buf_nr;
	__u64 start_lba;
	__u64 end_lba;
	__u32 pid;
};

struct blk_mq_tags {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___25 **rqs;
	struct request___25 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

enum blk_crypto_mode_num {
	BLK_ENCRYPTION_MODE_INVALID = 0,
	BLK_ENCRYPTION_MODE_AES_256_XTS = 1,
	BLK_ENCRYPTION_MODE_AES_128_CBC_ESSIV = 2,
	BLK_ENCRYPTION_MODE_ADIANTUM = 3,
	BLK_ENCRYPTION_MODE_MAX = 4,
};

struct blk_crypto_config {
	enum blk_crypto_mode_num crypto_mode;
	unsigned int data_unit_size;
	unsigned int dun_bytes;
};

struct blk_crypto_key {
	struct blk_crypto_config crypto_cfg;
	unsigned int data_unit_size_bits;
	unsigned int size;
	u8 raw[64];
};

struct blk_mq_ctxs {
	struct kobject___56 kobj;
	struct blk_mq_ctx *queue_ctx;
};

typedef void blk_log_action_t(struct trace_iterator___2 *, const char *, bool);

struct trace_event_buffer___15 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___14 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct ftrace_event_field {
	struct list_head link;
	const char *name;
	const char *type;
	int filter_type;
	int offset;
	int size;
	int is_signed;
};

struct module_string {
	struct list_head next;
	struct module___54 *module;
	char *str;
};

enum {
	FORMAT_HEADER = 1,
	FORMAT_FIELD_SEPERATOR = 2,
	FORMAT_PRINTFMT = 3,
};

struct event_probe_data {
	struct trace_event_file___14 *file;
	long unsigned int count;
	int ref;
	bool enable;
};

struct dentry___58;

struct super_block___58;

struct module___56;

struct file_system_type___57 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___58 * (*mount)(struct file_system_type___57 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___58 *);
	struct module___56 *owner;
	struct file_system_type___57 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___58;

struct kiocb___57;

struct poll_table_struct___43;

struct vm_area_struct___62;

struct inode___58;

struct file_lock___57;

struct page___62;

struct seq_file___55;

struct file_operations___57 {
	struct module___56 *owner;
	loff_t (*llseek)(struct file___58 *, loff_t, int);
	ssize_t (*read)(struct file___58 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___58 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___57 *, struct iov_iter___29 *);
	ssize_t (*write_iter)(struct kiocb___57 *, struct iov_iter___29 *);
	int (*iopoll)(struct kiocb___57 *, bool);
	int (*iterate)(struct file___58 *, struct dir_context *);
	int (*iterate_shared)(struct file___58 *, struct dir_context *);
	__poll_t (*poll)(struct file___58 *, struct poll_table_struct___43 *);
	long int (*unlocked_ioctl)(struct file___58 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___58 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___58 *, struct vm_area_struct___62 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___58 *, struct file___58 *);
	int (*flush)(struct file___58 *, fl_owner_t);
	int (*release)(struct inode___58 *, struct file___58 *);
	int (*fsync)(struct file___58 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___58 *, int);
	int (*lock)(struct file___58 *, int, struct file_lock___57 *);
	ssize_t (*sendpage)(struct file___58 *, struct page___62 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___58 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___58 *, long unsigned int);
	int (*flock)(struct file___58 *, int, struct file_lock___57 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___58 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___58 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___58 *, long int, struct file_lock___57 **, void **);
	long int (*fallocate)(struct file___58 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___55 *, struct file___58 *);
	ssize_t (*copy_file_range)(struct file___58 *, loff_t, struct file___58 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___58 *, loff_t, struct file___58 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___58 *, loff_t, loff_t, int);
};

struct vmacache___62 {
	u64 seqnum;
	struct vm_area_struct___62 *vmas[4];
};

struct page_frag___62 {
	struct page___62 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___39;

struct debug_info___39 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___39 *hbp_break[16];
	struct perf_event___39 *hbp_watch[16];
};

struct thread_struct___39 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___39 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___63;

struct pid___51;

struct nsproxy___56;

struct signal_struct___58;

struct css_set___47;

struct perf_event_context___39;

struct vm_struct___59;

struct task_struct___63 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___63 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___63 *mm;
	struct mm_struct___63 *active_mm;
	struct vmacache___62 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___63 *real_parent;
	struct task_struct___63 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___63 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___51 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___56 *nsproxy;
	struct signal_struct___58 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___63 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___26 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___47 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___39 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___62 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___63 *oom_reaper_list;
	struct vm_struct___59 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___39 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___57;

struct kobj_type___57;

struct kernfs_node___57;

struct kobject___57 {
	const char *name;
	struct list_head entry;
	struct kobject___57 *parent;
	struct kset___57 *kset;
	struct kobj_type___57 *ktype;
	struct kernfs_node___57 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___54 {
	struct kobject___57 kobj;
	struct module___56 *mod;
	struct kobject___57 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___54 {
	struct module___56 *mod;
	struct latch_tree_node node;
};

struct module_layout___54 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___54 mtn;
};

struct module_attribute___54;

struct kernel_param___54;

struct trace_event_call___34;

struct module___56 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___54 mkobj;
	struct module_attribute___54 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___57 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___54 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___54 core_layout;
	struct module_layout___54 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___34 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___39 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___63 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___39)(struct perf_event___39 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___39;

struct fasync_struct___57;

struct pid_namespace___51;

struct perf_cgroup___39;

struct perf_event___39 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___39 *group_leader;
	struct pmu___39 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___39 hw;
	struct perf_event_context___39 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___39 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___63 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___57 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___39 *aux_event;
	void (*destroy)(struct perf_event___39 *);
	struct callback_head callback_head;
	struct pid_namespace___51 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___39 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___39 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___34 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___39 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___51 {
	int nr;
	struct pid_namespace___51 *ns;
};

struct pid_namespace___51 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___63 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___51 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___51 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___51 numbers[1];
};

typedef struct page___62 *pgtable_t___62;

struct address_space___57;

struct dev_pagemap___56;

struct page___62 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___57 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___15 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___62 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___62 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___63 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___56 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___56;

struct vm_area_struct___62 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___62 *vm_next;
	struct vm_area_struct___62 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___63 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___56 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___58 *vm_file;
	struct file___58 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___58 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___63 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___63 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___51 *pids[4];
	struct pid___51 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___63 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___62;

struct mm_struct___63 {
	struct {
		struct vm_area_struct___62 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___58 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___62 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___63 *owner;
		struct user_namespace___10 *user_ns;
		struct file___58 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___47;

struct nsproxy___56 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___51 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___47 *cgroup_ns;
};

struct cgroup_subsys_state___47;

struct cgroup___47;

struct css_set___47 {
	struct cgroup_subsys_state___47 *subsys[14];
	refcount_t refcount;
	struct css_set___47 *dom_cset;
	struct cgroup___47 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___47 *mg_src_cgrp;
	struct cgroup___47 *mg_dst_cgrp;
	struct css_set___47 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___39 {
	struct pmu___39 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___63 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___39 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___59 {
	struct vm_struct___59 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___62 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___57;

struct address_space___57 {
	struct inode___58 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___57 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___56;

struct dev_pagemap___56 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___56 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___57;

struct path___57 {
	struct vfsmount___57 *mnt;
	struct dentry___58 *dentry;
};

struct fown_struct___51 {
	rwlock_t lock;
	struct pid___51 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___58 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___57 f_path;
	struct inode___58 *f_inode;
	const struct file_operations___57 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___51 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___57 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___56;

struct vm_operations_struct___56 {
	void (*open)(struct vm_area_struct___62 *);
	void (*close)(struct vm_area_struct___62 *);
	int (*may_split)(struct vm_area_struct___62 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___62 *);
	int (*mprotect)(struct vm_area_struct___62 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___56 *);
	vm_fault_t (*huge_fault)(struct vm_fault___56 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___56 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___62 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___56 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___56 *);
	int (*access)(struct vm_area_struct___62 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___62 *);
	int (*set_policy)(struct vm_area_struct___62 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___62 *, long unsigned int);
	struct page___62 * (*find_special_page)(struct vm_area_struct___62 *, long unsigned int);
};

struct core_thread___62 {
	struct task_struct___63 *task;
	struct core_thread___62 *next;
};

struct core_state___62 {
	atomic_t nr_threads;
	struct core_thread___62 dumper;
	struct completion startup;
};

struct vm_fault___56 {
	const struct {
		struct vm_area_struct___62 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___62 *cow_page;
	struct page___62 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___62 prealloc_pte;
};

struct kernfs_root___57;

struct kernfs_elem_dir___57 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___57 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___57;

struct kernfs_root___57 {
	struct kernfs_node___57 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___57 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___57 {
	struct kernfs_node___57 *target_kn;
};

struct kernfs_ops___57;

struct kernfs_elem_attr___57 {
	const struct kernfs_ops___57 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___57 *notify_next;
};

struct kernfs_node___57 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___57 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___57 dir;
		struct kernfs_elem_symlink___57 symlink;
		struct kernfs_elem_attr___57 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___57;

struct kernfs_ops___57 {
	int (*open)(struct kernfs_open_file___57 *);
	void (*release)(struct kernfs_open_file___57 *);
	int (*seq_show)(struct seq_file___55 *, void *);
	void * (*seq_start)(struct seq_file___55 *, loff_t *);
	void * (*seq_next)(struct seq_file___55 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___55 *, void *);
	ssize_t (*read)(struct kernfs_open_file___57 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___57 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___57 *, struct poll_table_struct___43 *);
	int (*mmap)(struct kernfs_open_file___57 *, struct vm_area_struct___62 *);
};

struct kernfs_syscall_ops___57 {
	int (*show_options)(struct seq_file___55 *, struct kernfs_root___57 *);
	int (*mkdir)(struct kernfs_node___57 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___57 *);
	int (*rename)(struct kernfs_node___57 *, struct kernfs_node___57 *, const char *);
	int (*show_path)(struct seq_file___55 *, struct kernfs_node___57 *, struct kernfs_root___57 *);
};

struct seq_operations___55;

struct seq_file___55 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___55 *op;
	int poll_event;
	const struct file___58 *file;
	void *private;
};

struct kernfs_open_file___57 {
	struct kernfs_node___57 *kn;
	struct file___58 *file;
	struct seq_file___55 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___56 *vm_ops;
};

typedef void (*poll_queue_proc___43)(struct file___58 *, wait_queue_head_t *, struct poll_table_struct___43 *);

struct poll_table_struct___43 {
	poll_queue_proc___43 _qproc;
	__poll_t _key;
};

struct bin_attribute___57;

struct attribute_group___57 {
	const char *name;
	umode_t (*is_visible)(struct kobject___57 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___57 *, struct bin_attribute___57 *, int);
	struct attribute **attrs;
	struct bin_attribute___57 **bin_attrs;
};

struct bin_attribute___57 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___57 * (*f_mapping)();
	ssize_t (*read)(struct file___58 *, struct kobject___57 *, struct bin_attribute___57 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___58 *, struct kobject___57 *, struct bin_attribute___57 *, char *, loff_t, size_t);
	int (*mmap)(struct file___58 *, struct kobject___57 *, struct bin_attribute___57 *, struct vm_area_struct___62 *);
};

struct sysfs_ops___57 {
	ssize_t (*show)(struct kobject___57 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___57 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___57;

struct kset___57 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___57 kobj;
	const struct kset_uevent_ops___57 *uevent_ops;
};

struct kobj_type___57 {
	void (*release)(struct kobject___57 *);
	const struct sysfs_ops___57 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___57 **default_groups;
	const struct kobj_ns_type_operations___5 * (*child_ns_type)(struct kobject___57 *);
	const void * (*namespace)(struct kobject___57 *);
	void (*get_ownership)(struct kobject___57 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___57 {
	int (* const filter)(struct kset___57 *, struct kobject___57 *);
	const char * (* const name)(struct kset___57 *, struct kobject___57 *);
	int (* const uevent)(struct kset___57 *, struct kobject___57 *, struct kobj_uevent_env *);
};

struct wakeup_source___51;

struct device___51;

struct dev_pm_info___51 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___51 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___51 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___51;

struct bus_type___51;

struct device_driver___51;

struct dev_pm_domain___51;

struct device_node___31;

struct fwnode_handle___51;

struct class___51;

struct device___51 {
	struct kobject___57 kobj;
	struct device___51 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___51 *type;
	struct bus_type___51 *bus;
	struct device_driver___51 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___51 power;
	struct dev_pm_domain___51 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___31 *of_node;
	struct fwnode_handle___51 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___51 *class;
	const struct attribute_group___57 **groups;
	void (*release)(struct device___51 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___51 {
	int (*prepare)(struct device___51 *);
	void (*complete)(struct device___51 *);
	int (*suspend)(struct device___51 *);
	int (*resume)(struct device___51 *);
	int (*freeze)(struct device___51 *);
	int (*thaw)(struct device___51 *);
	int (*poweroff)(struct device___51 *);
	int (*restore)(struct device___51 *);
	int (*suspend_late)(struct device___51 *);
	int (*resume_early)(struct device___51 *);
	int (*freeze_late)(struct device___51 *);
	int (*thaw_early)(struct device___51 *);
	int (*poweroff_late)(struct device___51 *);
	int (*restore_early)(struct device___51 *);
	int (*suspend_noirq)(struct device___51 *);
	int (*resume_noirq)(struct device___51 *);
	int (*freeze_noirq)(struct device___51 *);
	int (*thaw_noirq)(struct device___51 *);
	int (*poweroff_noirq)(struct device___51 *);
	int (*restore_noirq)(struct device___51 *);
	int (*runtime_suspend)(struct device___51 *);
	int (*runtime_resume)(struct device___51 *);
	int (*runtime_idle)(struct device___51 *);
};

struct wakeup_source___51 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___51 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___51 {
	struct dev_pm_ops___51 ops;
	int (*start)(struct device___51 *);
	void (*detach)(struct device___51 *, bool);
	int (*activate)(struct device___51 *);
	void (*sync)(struct device___51 *);
	void (*dismiss)(struct device___51 *);
};

struct bus_type___51 {
	const char *name;
	const char *dev_name;
	struct device___51 *dev_root;
	const struct attribute_group___57 **bus_groups;
	const struct attribute_group___57 **dev_groups;
	const struct attribute_group___57 **drv_groups;
	int (*match)(struct device___51 *, struct device_driver___51 *);
	int (*uevent)(struct device___51 *, struct kobj_uevent_env *);
	int (*probe)(struct device___51 *);
	void (*sync_state)(struct device___51 *);
	void (*remove)(struct device___51 *);
	void (*shutdown)(struct device___51 *);
	int (*online)(struct device___51 *);
	int (*offline)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	int (*num_vf)(struct device___51 *);
	int (*dma_configure)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___51 {
	const char *name;
	struct bus_type___51 *bus;
	struct module___56 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___51 *);
	void (*sync_state)(struct device___51 *);
	int (*remove)(struct device___51 *);
	void (*shutdown)(struct device___51 *);
	int (*suspend)(struct device___51 *, pm_message_t);
	int (*resume)(struct device___51 *);
	const struct attribute_group___57 **groups;
	const struct attribute_group___57 **dev_groups;
	const struct dev_pm_ops___51 *pm;
	void (*coredump)(struct device___51 *);
	struct driver_private *p;
};

struct device_type___51 {
	const char *name;
	const struct attribute_group___57 **groups;
	int (*uevent)(struct device___51 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___51 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___51 *);
	const struct dev_pm_ops___51 *pm;
};

struct class___51 {
	const char *name;
	struct module___56 *owner;
	const struct attribute_group___57 **class_groups;
	const struct attribute_group___57 **dev_groups;
	struct kobject___57 *dev_kobj;
	int (*dev_uevent)(struct device___51 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___51 *, umode_t *);
	void (*class_release)(struct class___51 *);
	void (*dev_release)(struct device___51 *);
	int (*shutdown_pre)(struct device___51 *);
	const struct kobj_ns_type_operations___5 *ns_type;
	const void * (*namespace)(struct device___51 *);
	void (*get_ownership)(struct device___51 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___51 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___51;

struct fwnode_handle___51 {
	struct fwnode_handle___51 *secondary;
	const struct fwnode_operations___51 *ops;
	struct device___51 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___27;

struct device_node___31 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___51 fwnode;
	struct property___27 *properties;
	struct property___27 *deadprops;
	struct device_node___31 *parent;
	struct device_node___31 *child;
	struct device_node___31 *sibling;
	struct kobject___57 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___56 {
	void (*page_free)(struct page___62 *);
	void (*kill)(struct dev_pagemap___56 *);
	void (*cleanup)(struct dev_pagemap___56 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___56 *);
};

struct dentry_operations___57;

struct dentry___58 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___58 *d_parent;
	struct qstr d_name;
	struct inode___58 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___57 *d_op;
	struct super_block___58 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___57;

struct inode___58 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___57 *i_op;
	struct super_block___58 *i_sb;
	struct address_space___57 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___57 *i_fop;
		void (*free_inode)(struct inode___58 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___57 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___18 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___57 {
	int (*d_revalidate)(struct dentry___58 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___58 *, unsigned int);
	int (*d_hash)(const struct dentry___58 *, struct qstr *);
	int (*d_compare)(const struct dentry___58 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___58 *);
	int (*d_init)(struct dentry___58 *);
	void (*d_release)(struct dentry___58 *);
	void (*d_prune)(struct dentry___58 *);
	void (*d_iput)(struct dentry___58 *, struct inode___58 *);
	char * (*d_dname)(struct dentry___58 *, char *, int);
	struct vfsmount___57 * (*d_automount)(struct path___57 *);
	int (*d_manage)(const struct path___57 *, bool);
	struct dentry___58 * (*d_real)(struct dentry___58 *, const struct inode___58 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___57;

struct mem_dqinfo___57 {
	struct quota_format_type___57 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___57;

struct quota_info___57 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___58 *files[3];
	struct mem_dqinfo___57 info[3];
	const struct quota_format_ops___57 *ops[3];
};

struct rcuwait___58 {
	struct task_struct___63 *task;
};

struct percpu_rw_semaphore___58 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___58 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___57 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___58 rw_sem[3];
};

struct super_operations___57;

struct dquot_operations___57;

struct quotactl_ops___57;

struct super_block___58 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___57 *s_type;
	const struct super_operations___57 *s_op;
	const struct dquot_operations___57 *dq_op;
	const struct quotactl_ops___57 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___58 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___57 s_dquot;
	struct sb_writers___57 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___57 *s_d_op;
	int cleancache_poolid;
	struct shrinker___22 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___57 {
	struct dentry___58 *mnt_root;
	struct super_block___58 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct cgroup_subsys___47;

struct cgroup_subsys_state___47 {
	struct cgroup___47 *cgroup;
	struct cgroup_subsys___47 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___47 *parent;
};

struct cgroup_file___47 {
	struct kernfs_node___57 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___47 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___63 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___47;

struct cgroup_rstat_cpu___47;

struct cgroup___47 {
	struct cgroup_subsys_state___47 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___57 *kn;
	struct cgroup_file___47 procs_file;
	struct cgroup_file___47 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___47 *subsys[14];
	struct cgroup_root___47 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___47 *dom_cgrp;
	struct cgroup___47 *old_dom_cgrp;
	struct cgroup_rstat_cpu___47 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___47 psi;
	struct cgroup_bpf___6 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___57 {
	struct file___58 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___57 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___26 *ki_waitq;
	};
};

struct iattr___58 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___58 *ia_file;
};

struct dquot___57 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___58 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___57 {
	int qf_fmt_id;
	const struct quota_format_ops___57 *qf_ops;
	struct module___56 *qf_owner;
	struct quota_format_type___57 *qf_next;
};

struct quota_format_ops___57 {
	int (*check_quota_file)(struct super_block___58 *, int);
	int (*read_file_info)(struct super_block___58 *, int);
	int (*write_file_info)(struct super_block___58 *, int);
	int (*free_file_info)(struct super_block___58 *, int);
	int (*read_dqblk)(struct dquot___57 *);
	int (*commit_dqblk)(struct dquot___57 *);
	int (*release_dqblk)(struct dquot___57 *);
	int (*get_next_id)(struct super_block___58 *, struct kqid *);
};

struct dquot_operations___57 {
	int (*write_dquot)(struct dquot___57 *);
	struct dquot___57 * (*alloc_dquot)(struct super_block___58 *, int);
	void (*destroy_dquot)(struct dquot___57 *);
	int (*acquire_dquot)(struct dquot___57 *);
	int (*release_dquot)(struct dquot___57 *);
	int (*mark_dirty)(struct dquot___57 *);
	int (*write_info)(struct super_block___58 *, int);
	qsize_t * (*get_reserved_space)(struct inode___58 *);
	int (*get_projid)(struct inode___58 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___58 *, qsize_t *);
	int (*get_next_id)(struct super_block___58 *, struct kqid *);
};

struct quotactl_ops___57 {
	int (*quota_on)(struct super_block___58 *, int, int, const struct path___57 *);
	int (*quota_off)(struct super_block___58 *, int);
	int (*quota_enable)(struct super_block___58 *, unsigned int);
	int (*quota_disable)(struct super_block___58 *, unsigned int);
	int (*quota_sync)(struct super_block___58 *, int);
	int (*set_info)(struct super_block___58 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___58 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___58 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___58 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___58 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___58 *, unsigned int);
};

struct address_space_operations___57 {
	int (*writepage)(struct page___62 *, struct writeback_control___3 *);
	int (*readpage)(struct file___58 *, struct page___62 *);
	int (*writepages)(struct address_space___57 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___62 *);
	int (*readpages)(struct file___58 *, struct address_space___57 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___58 *, struct address_space___57 *, loff_t, unsigned int, unsigned int, struct page___62 **, void **);
	int (*write_end)(struct file___58 *, struct address_space___57 *, loff_t, unsigned int, unsigned int, struct page___62 *, void *);
	sector_t (*bmap)(struct address_space___57 *, sector_t);
	void (*invalidatepage)(struct page___62 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___62 *, gfp_t);
	void (*freepage)(struct page___62 *);
	ssize_t (*direct_IO)(struct kiocb___57 *, struct iov_iter___29 *);
	int (*migratepage)(struct address_space___57 *, struct page___62 *, struct page___62 *, enum migrate_mode);
	bool (*isolate_page)(struct page___62 *, isolate_mode_t);
	void (*putback_page)(struct page___62 *);
	int (*launder_page)(struct page___62 *);
	int (*is_partially_uptodate)(struct page___62 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___62 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___57 *, struct page___62 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___58 *, sector_t *);
	void (*swap_deactivate)(struct file___58 *);
};

struct inode_operations___57 {
	struct dentry___58 * (*lookup)(struct inode___58 *, struct dentry___58 *, unsigned int);
	const char * (*get_link)(struct dentry___58 *, struct inode___58 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___58 *, int);
	struct posix_acl * (*get_acl)(struct inode___58 *, int, bool);
	int (*readlink)(struct dentry___58 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___58 *, struct dentry___58 *, umode_t, bool);
	int (*link)(struct dentry___58 *, struct inode___58 *, struct dentry___58 *);
	int (*unlink)(struct inode___58 *, struct dentry___58 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___58 *, struct dentry___58 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___58 *, struct dentry___58 *, umode_t);
	int (*rmdir)(struct inode___58 *, struct dentry___58 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___58 *, struct dentry___58 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___58 *, struct dentry___58 *, struct inode___58 *, struct dentry___58 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___58 *, struct iattr___58 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___57 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___58 *, char *, size_t);
	int (*fiemap)(struct inode___58 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___58 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___58 *, struct dentry___58 *, struct file___58 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___58 *, struct dentry___58 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___58 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___58 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___58 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___57 {
	void (*fl_copy_lock)(struct file_lock___57 *, struct file_lock___57 *);
	void (*fl_release_private)(struct file_lock___57 *);
};

struct lock_manager_operations___57;

struct file_lock___57 {
	struct file_lock___57 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___58 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___57 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___57 *fl_ops;
	const struct lock_manager_operations___57 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___57 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___57 *);
	int (*lm_grant)(struct file_lock___57 *, int);
	bool (*lm_break)(struct file_lock___57 *);
	int (*lm_change)(struct file_lock___57 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___57 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___57 *);
};

struct fasync_struct___57 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___57 *fa_next;
	struct file___58 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___57 {
	struct inode___58 * (*alloc_inode)(struct super_block___58 *);
	void (*destroy_inode)(struct inode___58 *);
	void (*free_inode)(struct inode___58 *);
	void (*dirty_inode)(struct inode___58 *, int);
	int (*write_inode)(struct inode___58 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___58 *);
	void (*evict_inode)(struct inode___58 *);
	void (*put_super)(struct super_block___58 *);
	int (*sync_fs)(struct super_block___58 *, int);
	int (*freeze_super)(struct super_block___58 *);
	int (*freeze_fs)(struct super_block___58 *);
	int (*thaw_super)(struct super_block___58 *);
	int (*unfreeze_fs)(struct super_block___58 *);
	int (*statfs)(struct dentry___58 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___58 *, int *, char *);
	void (*umount_begin)(struct super_block___58 *);
	int (*show_options)(struct seq_file___55 *, struct dentry___58 *);
	int (*show_devname)(struct seq_file___55 *, struct dentry___58 *);
	int (*show_path)(struct seq_file___55 *, struct dentry___58 *);
	int (*show_stats)(struct seq_file___55 *, struct dentry___58 *);
	ssize_t (*quota_read)(struct super_block___58 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___58 *, int, const char *, size_t, loff_t);
	struct dquot___57 ** (*get_dquots)(struct inode___58 *);
	long int (*nr_cached_objects)(struct super_block___58 *, struct shrink_control___22 *);
	long int (*free_cached_objects)(struct super_block___58 *, struct shrink_control___22 *);
	struct file___58 * (*real_loop)(struct file___58 *);
};

struct seq_operations___55 {
	void * (*start)(struct seq_file___55 *, loff_t *);
	void (*stop)(struct seq_file___55 *, void *);
	void * (*next)(struct seq_file___55 *, void *, loff_t *);
	int (*show)(struct seq_file___55 *, void *);
};

struct fwnode_reference_args___51;

struct fwnode_endpoint___51;

struct fwnode_operations___51 {
	struct fwnode_handle___51 * (*get)(struct fwnode_handle___51 *);
	void (*put)(struct fwnode_handle___51 *);
	bool (*device_is_available)(const struct fwnode_handle___51 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___51 *, const struct device___51 *);
	bool (*property_present)(const struct fwnode_handle___51 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___51 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___51 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___51 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*get_parent)(const struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*get_next_child_node)(const struct fwnode_handle___51 *, struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*get_named_child_node)(const struct fwnode_handle___51 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___51 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___51 *);
	struct fwnode_handle___51 * (*graph_get_next_endpoint)(const struct fwnode_handle___51 *, struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*graph_get_remote_endpoint)(const struct fwnode_handle___51 *);
	struct fwnode_handle___51 * (*graph_get_port_parent)(struct fwnode_handle___51 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___51 *, struct fwnode_endpoint___51 *);
	int (*add_links)(struct fwnode_handle___51 *);
};

struct fwnode_endpoint___51 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___51 *local_fwnode;
};

struct fwnode_reference_args___51 {
	struct fwnode_handle___51 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___47 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___47 *root_cset;
};

struct kernel_param_ops___54 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___54 *);
	int (*get)(char *, const struct kernel_param___54 *);
	void (*free)(void *);
};

struct kparam_array___54;

struct kernel_param___54 {
	const char *name;
	struct module___56 *mod;
	const struct kernel_param_ops___54 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___54 *arr;
	};
};

struct kparam_array___54 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___54 *ops;
	void *elem;
};

struct module_attribute___54 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___54 *, struct module_kobject___54 *, char *);
	ssize_t (*store)(struct module_attribute___54 *, struct module_kobject___54 *, const char *, size_t);
	void (*setup)(struct module___56 *, const char *);
	int (*test)(struct module___56 *);
	void (*free)(struct module___56 *);
};

struct trace_event_functions___3;

struct trace_event___3 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___3 *funcs;
};

struct trace_event_class___34;

struct trace_event_call___34 {
	struct list_head list;
	struct trace_event_class___34 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___3 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___6 *prog_array;
	int (*perf_perm)(struct trace_event_call___34 *, struct perf_event___39 *);
};

struct cftype___47;

struct cgroup_subsys___47 {
	struct cgroup_subsys_state___47 * (*css_alloc)(struct cgroup_subsys_state___47 *);
	int (*css_online)(struct cgroup_subsys_state___47 *);
	void (*css_offline)(struct cgroup_subsys_state___47 *);
	void (*css_released)(struct cgroup_subsys_state___47 *);
	void (*css_free)(struct cgroup_subsys_state___47 *);
	void (*css_reset)(struct cgroup_subsys_state___47 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___47 *, int);
	int (*css_extra_stat_show)(struct seq_file___55 *, struct cgroup_subsys_state___47 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___63 *, struct css_set___47 *);
	void (*cancel_fork)(struct task_struct___63 *, struct css_set___47 *);
	void (*fork)(struct task_struct___63 *);
	void (*exit)(struct task_struct___63 *);
	void (*release)(struct task_struct___63 *);
	void (*bind)(struct cgroup_subsys_state___47 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___47 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___47 *dfl_cftypes;
	struct cftype___47 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___47 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___47 *updated_children;
	struct cgroup___47 *updated_next;
};

struct cgroup_root___47 {
	struct kernfs_root___57 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___47 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___47 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___47 *ss;
	struct list_head node;
	struct kernfs_ops___57 *kf_ops;
	int (*open)(struct kernfs_open_file___57 *);
	void (*release)(struct kernfs_open_file___57 *);
	u64 (*read_u64)(struct cgroup_subsys_state___47 *, struct cftype___47 *);
	s64 (*read_s64)(struct cgroup_subsys_state___47 *, struct cftype___47 *);
	int (*seq_show)(struct seq_file___55 *, void *);
	void * (*seq_start)(struct seq_file___55 *, loff_t *);
	void * (*seq_next)(struct seq_file___55 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___55 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___47 *, struct cftype___47 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___47 *, struct cftype___47 *, s64);
	ssize_t (*write)(struct kernfs_open_file___57 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___57 *, struct poll_table_struct___43 *);
};

struct perf_cpu_context___39;

struct perf_output_handle___39;

struct pmu___39 {
	struct list_head entry;
	struct module___56 *module;
	struct device___51 *dev;
	const struct attribute_group___57 **attr_groups;
	const struct attribute_group___57 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___39 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___39 *);
	void (*pmu_disable)(struct pmu___39 *);
	int (*event_init)(struct perf_event___39 *);
	void (*event_mapped)(struct perf_event___39 *, struct mm_struct___63 *);
	void (*event_unmapped)(struct perf_event___39 *, struct mm_struct___63 *);
	int (*add)(struct perf_event___39 *, int);
	void (*del)(struct perf_event___39 *, int);
	void (*start)(struct perf_event___39 *, int);
	void (*stop)(struct perf_event___39 *, int);
	void (*read)(struct perf_event___39 *);
	void (*start_txn)(struct pmu___39 *, unsigned int);
	int (*commit_txn)(struct pmu___39 *);
	void (*cancel_txn)(struct pmu___39 *);
	int (*event_idx)(struct perf_event___39 *);
	void (*sched_task)(struct perf_event_context___39 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___39 *, struct perf_event_context___39 *);
	void * (*setup_aux)(struct perf_event___39 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___39 *, struct perf_output_handle___39 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___39 *);
	int (*aux_output_match)(struct perf_event___39 *);
	int (*filter_match)(struct perf_event___39 *);
	int (*check_period)(struct perf_event___39 *, u64);
};

struct perf_cpu_context___39 {
	struct perf_event_context___39 ctx;
	struct perf_event_context___39 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___39 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___39 **heap;
	struct perf_event___39 *heap_default[2];
};

struct perf_output_handle___39 {
	struct perf_event___39 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___39 {
	struct cgroup_subsys_state___47 css;
	struct perf_cgroup_info *info;
};

struct trace_array___3;

struct tracer___3;

struct array_buffer___3;

struct trace_iterator___3 {
	struct trace_array___3 *tr;
	struct tracer___3 *trace;
	struct array_buffer___3 *array_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	void *temp;
	unsigned int temp_size;
	char *fmt;
	unsigned int fmt_size;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct array_buffer___3 {
	struct trace_array___3 *tr;
	struct trace_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___16;

struct trace_options___3;

struct cond_snapshot___3;

struct trace_array___3 {
	struct list_head list;
	char *name;
	struct array_buffer___3 array_buffer;
	struct array_buffer___3 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct dentry___58 *d_max_latency;
	struct work_struct fsnotify_work;
	struct irq_work fsnotify_irqwork;
	struct trace_pid_list *filtered_pids;
	struct trace_pid_list *filtered_no_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___16 *enter_syscall_files[449];
	struct trace_event_file___16 *exit_syscall_files[449];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	int buffer_percent;
	unsigned int n_err_log_entries;
	struct tracer___3 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct list_head err_log;
	struct dentry___58 *dir;
	struct dentry___58 *options;
	struct dentry___58 *percpu_dir;
	struct dentry___58 *event_dir;
	struct trace_options___3 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___16 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	int trace_ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct trace_pid_list *function_no_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int no_filter_buffering_ref;
	struct list_head hist_vars;
	struct cond_snapshot___3 *cond_snapshot;
	struct trace_func_repeats *last_func_repeats;
};

struct tracer_flags___3;

struct tracer___3 {
	const char *name;
	int (*init)(struct trace_array___3 *);
	void (*reset)(struct trace_array___3 *);
	void (*start)(struct trace_array___3 *);
	void (*stop)(struct trace_array___3 *);
	int (*update_thresh)(struct trace_array___3 *);
	void (*open)(struct trace_iterator___3 *);
	void (*pipe_open)(struct trace_iterator___3 *);
	void (*close)(struct trace_iterator___3 *);
	void (*pipe_close)(struct trace_iterator___3 *);
	ssize_t (*read)(struct trace_iterator___3 *, struct file___58 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___3 *, struct file___58 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___55 *);
	enum print_line_t (*print_line)(struct trace_iterator___3 *);
	int (*set_flag)(struct trace_array___3 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___3 *, u32, int);
	struct tracer___3 *next;
	struct tracer_flags___3 *flags;
	int enabled;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___3)(struct trace_iterator___3 *, int, struct trace_event___3 *);

struct trace_event_functions___3 {
	trace_print_func___3 trace;
	trace_print_func___3 raw;
	trace_print_func___3 hex;
	trace_print_func___3 binary;
};

struct trace_event_fields___34 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___34 *);
	};
};

struct trace_event_class___34 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___34 *, enum trace_reg, void *);
	struct trace_event_fields___34 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___34 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___34 *);
};

struct trace_subsystem_dir___3;

struct trace_event_file___16 {
	struct list_head list;
	struct trace_event_call___34 *event_call;
	struct event_filter *filter;
	struct dentry___58 *dir;
	struct trace_array___3 *tr;
	struct trace_subsystem_dir___3 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___3 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___3 *tr;
	struct dentry___58 *entry;
	int ref_count;
	int nr_events;
};

struct syscall_metadata___14 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___34 *enter_event;
	struct trace_event_call___34 *exit_event;
};

struct property___27 {
	char *name;
	int length;
	void *value;
	struct property___27 *next;
	long unsigned int _flags;
	struct bin_attribute___57 attr;
};

struct syscall_trace_enter {
	struct trace_entry ent;
	int nr;
	long unsigned int args[0];
};

struct syscall_trace_exit {
	struct trace_entry ent;
	int nr;
	long int ret;
};

struct trace_option_dentry___3;

struct trace_options___3 {
	struct tracer___3 *tracer;
	struct trace_option_dentry___3 *topts;
};

struct trace_option_dentry___3 {
	struct tracer_opt *opt;
	struct tracer_flags___3 *flags;
	struct trace_array___3 *tr;
	struct dentry___58 *entry;
};

typedef bool (*cond_update_fn_t___3)(struct trace_array___3 *, void *);

struct cond_snapshot___3 {
	void *cond_data;
	cond_update_fn_t___3 update;
};

struct tracer_flags___3 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___3 *trace;
};

struct syscall_tp_t {
	long long unsigned int regs;
	long unsigned int syscall_nr;
	long unsigned int ret;
};

struct syscall_tp_t___2 {
	long long unsigned int regs;
	long unsigned int syscall_nr;
	long unsigned int args[6];
};

enum perf_event_sample_format {
	PERF_SAMPLE_IP = 1,
	PERF_SAMPLE_TID = 2,
	PERF_SAMPLE_TIME = 4,
	PERF_SAMPLE_ADDR = 8,
	PERF_SAMPLE_READ = 16,
	PERF_SAMPLE_CALLCHAIN = 32,
	PERF_SAMPLE_ID = 64,
	PERF_SAMPLE_CPU = 128,
	PERF_SAMPLE_PERIOD = 256,
	PERF_SAMPLE_STREAM_ID = 512,
	PERF_SAMPLE_RAW = 1024,
	PERF_SAMPLE_BRANCH_STACK = 2048,
	PERF_SAMPLE_REGS_USER = 4096,
	PERF_SAMPLE_STACK_USER = 8192,
	PERF_SAMPLE_WEIGHT = 16384,
	PERF_SAMPLE_DATA_SRC = 32768,
	PERF_SAMPLE_IDENTIFIER = 65536,
	PERF_SAMPLE_TRANSACTION = 131072,
	PERF_SAMPLE_REGS_INTR = 262144,
	PERF_SAMPLE_PHYS_ADDR = 524288,
	PERF_SAMPLE_AUX = 1048576,
	PERF_SAMPLE_CGROUP = 2097152,
	PERF_SAMPLE_DATA_PAGE_SIZE = 4194304,
	PERF_SAMPLE_CODE_PAGE_SIZE = 8388608,
	PERF_SAMPLE_WEIGHT_STRUCT = 16777216,
	PERF_SAMPLE_MAX = 33554432,
	__PERF_SAMPLE_CALLCHAIN_EARLY = 0,
};

typedef long unsigned int perf_trace_t[256];

struct filter_pred;

struct prog_entry {
	int target;
	int when_to_branch;
	struct filter_pred *pred;
};

typedef int (*filter_pred_fn_t)(struct filter_pred *, void *);

struct regex;

typedef int (*regex_match_func)(char *, struct regex *, int);

struct regex {
	char pattern[256];
	int len;
	int field_len;
	regex_match_func match;
};

struct filter_pred {
	filter_pred_fn_t fn;
	u64 val;
	struct regex regex;
	short unsigned int *ops;
	struct ftrace_event_field *field;
	int offset;
	int not;
	int op;
};

enum filter_op_ids {
	OP_GLOB = 0,
	OP_NE = 1,
	OP_EQ = 2,
	OP_LE = 3,
	OP_LT = 4,
	OP_GE = 5,
	OP_GT = 6,
	OP_BAND = 7,
	OP_MAX = 8,
};

enum {
	FILT_ERR_NONE = 0,
	FILT_ERR_INVALID_OP = 1,
	FILT_ERR_TOO_MANY_OPEN = 2,
	FILT_ERR_TOO_MANY_CLOSE = 3,
	FILT_ERR_MISSING_QUOTE = 4,
	FILT_ERR_OPERAND_TOO_LONG = 5,
	FILT_ERR_EXPECT_STRING = 6,
	FILT_ERR_EXPECT_DIGIT = 7,
	FILT_ERR_ILLEGAL_FIELD_OP = 8,
	FILT_ERR_FIELD_NOT_FOUND = 9,
	FILT_ERR_ILLEGAL_INTVAL = 10,
	FILT_ERR_BAD_SUBSYS_FILTER = 11,
	FILT_ERR_TOO_MANY_PREDS = 12,
	FILT_ERR_INVALID_FILTER = 13,
	FILT_ERR_IP_FIELD_ONLY = 14,
	FILT_ERR_INVALID_VALUE = 15,
	FILT_ERR_ERRNO = 16,
	FILT_ERR_NO_FILTER = 17,
};

struct filter_parse_error {
	int lasterr;
	int lasterr_pos;
};

typedef int (*parse_pred_fn)(const char *, void *, int, struct filter_parse_error *, struct filter_pred **);

enum {
	INVERT = 1,
	PROCESS_AND = 2,
	PROCESS_OR = 4,
};

struct ustring_buffer {
	char buffer[1024];
};

enum {
	TOO_MANY_CLOSE = 4294967295,
	TOO_MANY_OPEN = 4294967294,
	MISSING_QUOTE = 4294967293,
};

struct filter_list {
	struct list_head list;
	struct event_filter *filter;
};

struct function_filter_data {
	struct ftrace_ops *ops;
	int first_filter;
	int first_notrace;
};

enum {
	EVENT_TRIGGER_FL_PROBE = 1,
};

struct event_trigger_ops;

struct event_command;

struct event_trigger_data {
	long unsigned int count;
	int ref;
	int flags;
	struct event_trigger_ops *ops;
	struct event_command *cmd_ops;
	struct event_filter *filter;
	char *filter_str;
	void *private_data;
	bool paused;
	bool paused_tmp;
	struct list_head list;
	char *name;
	struct list_head named_list;
	struct event_trigger_data *named_data;
};

struct event_trigger_ops {
	void (*func)(struct event_trigger_data *, struct trace_buffer *, void *, struct ring_buffer_event *);
	int (*init)(struct event_trigger_ops *, struct event_trigger_data *);
	void (*free)(struct event_trigger_ops *, struct event_trigger_data *);
	int (*print)(struct seq_file___54 *, struct event_trigger_ops *, struct event_trigger_data *);
};

struct event_command {
	struct list_head list;
	char *name;
	enum event_trigger_type trigger_type;
	int flags;
	int (*func)(struct event_command *, struct trace_event_file___15 *, char *, char *, char *);
	int (*reg)(char *, struct event_trigger_ops *, struct event_trigger_data *, struct trace_event_file___15 *);
	void (*unreg)(char *, struct event_trigger_ops *, struct event_trigger_data *, struct trace_event_file___15 *);
	void (*unreg_all)(struct trace_event_file___15 *);
	int (*set_filter)(char *, struct event_trigger_data *, struct trace_event_file___15 *);
	struct event_trigger_ops * (*get_trigger_ops)(char *, char *);
};

struct enable_trigger_data {
	struct trace_event_file___15 *file;
	bool enable;
	bool hist;
};

enum event_command_flags {
	EVENT_CMD_FL_POST_TRIGGER = 1,
	EVENT_CMD_FL_NEEDS_REC = 2,
};

struct eprobe_trace_entry_head {
	struct trace_entry ent;
	unsigned int type;
};

struct dyn_event;

struct dyn_event_operations {
	struct list_head list;
	int (*create)(const char *);
	int (*show)(struct seq_file___54 *, struct dyn_event *);
	bool (*is_busy)(struct dyn_event *);
	int (*free)(struct dyn_event *);
	bool (*match)(const char *, const char *, int, const char **, struct dyn_event *);
};

struct dyn_event {
	struct list_head list;
	struct dyn_event_operations *ops;
};

typedef int (*print_type_func_t)(struct trace_seq *, void *, void *);

enum fetch_op {
	FETCH_OP_NOP = 0,
	FETCH_OP_REG = 1,
	FETCH_OP_STACK = 2,
	FETCH_OP_STACKP = 3,
	FETCH_OP_RETVAL = 4,
	FETCH_OP_IMM = 5,
	FETCH_OP_COMM = 6,
	FETCH_OP_ARG = 7,
	FETCH_OP_FOFFS = 8,
	FETCH_OP_DATA = 9,
	FETCH_OP_DEREF = 10,
	FETCH_OP_UDEREF = 11,
	FETCH_OP_ST_RAW = 12,
	FETCH_OP_ST_MEM = 13,
	FETCH_OP_ST_UMEM = 14,
	FETCH_OP_ST_STRING = 15,
	FETCH_OP_ST_USTRING = 16,
	FETCH_OP_MOD_BF = 17,
	FETCH_OP_LP_ARRAY = 18,
	FETCH_OP_TP_ARG = 19,
	FETCH_OP_END = 20,
	FETCH_NOP_SYMBOL = 21,
};

struct fetch_insn {
	enum fetch_op op;
	union {
		unsigned int param;
		struct {
			unsigned int size;
			int offset;
		};
		struct {
			unsigned char basesize;
			unsigned char lshift;
			unsigned char rshift;
		};
		long unsigned int immediate;
		void *data;
	};
};

struct fetch_type {
	const char *name;
	size_t size;
	int is_signed;
	print_type_func_t print;
	const char *fmt;
	const char *fmttype;
};

struct probe_arg {
	struct fetch_insn *code;
	bool dynamic;
	unsigned int offset;
	unsigned int count;
	const char *name;
	const char *comm;
	char *fmt;
	const struct fetch_type *type;
};

struct trace_uprobe_filter {
	rwlock_t rwlock;
	int nr_systemwide;
	struct list_head perf_events;
};

struct trace_probe_event {
	unsigned int flags;
	struct trace_event_class___33 class;
	struct trace_event_call___33 call;
	struct list_head files;
	struct list_head probes;
	struct trace_uprobe_filter filter[0];
};

struct trace_probe {
	struct list_head list;
	struct trace_probe_event *event;
	ssize_t size;
	unsigned int nr_args;
	struct probe_arg args[0];
};

struct event_file_link {
	struct trace_event_file___15 *file;
	struct list_head list;
};

enum probe_print_type {
	PROBE_PRINT_NORMAL = 0,
	PROBE_PRINT_RETURN = 1,
	PROBE_PRINT_EVENT = 2,
};

enum {
	TP_ERR_FILE_NOT_FOUND = 0,
	TP_ERR_NO_REGULAR_FILE = 1,
	TP_ERR_BAD_REFCNT = 2,
	TP_ERR_REFCNT_OPEN_BRACE = 3,
	TP_ERR_BAD_REFCNT_SUFFIX = 4,
	TP_ERR_BAD_UPROBE_OFFS = 5,
	TP_ERR_MAXACT_NO_KPROBE = 6,
	TP_ERR_BAD_MAXACT = 7,
	TP_ERR_MAXACT_TOO_BIG = 8,
	TP_ERR_BAD_PROBE_ADDR = 9,
	TP_ERR_BAD_RETPROBE = 10,
	TP_ERR_BAD_ADDR_SUFFIX = 11,
	TP_ERR_NO_GROUP_NAME = 12,
	TP_ERR_GROUP_TOO_LONG = 13,
	TP_ERR_BAD_GROUP_NAME = 14,
	TP_ERR_NO_EVENT_NAME = 15,
	TP_ERR_EVENT_TOO_LONG = 16,
	TP_ERR_BAD_EVENT_NAME = 17,
	TP_ERR_EVENT_EXIST = 18,
	TP_ERR_RETVAL_ON_PROBE = 19,
	TP_ERR_BAD_STACK_NUM = 20,
	TP_ERR_BAD_ARG_NUM = 21,
	TP_ERR_BAD_VAR = 22,
	TP_ERR_BAD_REG_NAME = 23,
	TP_ERR_BAD_MEM_ADDR = 24,
	TP_ERR_BAD_IMM = 25,
	TP_ERR_IMMSTR_NO_CLOSE = 26,
	TP_ERR_FILE_ON_KPROBE = 27,
	TP_ERR_BAD_FILE_OFFS = 28,
	TP_ERR_SYM_ON_UPROBE = 29,
	TP_ERR_TOO_MANY_OPS = 30,
	TP_ERR_DEREF_NEED_BRACE = 31,
	TP_ERR_BAD_DEREF_OFFS = 32,
	TP_ERR_DEREF_OPEN_BRACE = 33,
	TP_ERR_COMM_CANT_DEREF = 34,
	TP_ERR_BAD_FETCH_ARG = 35,
	TP_ERR_ARRAY_NO_CLOSE = 36,
	TP_ERR_BAD_ARRAY_SUFFIX = 37,
	TP_ERR_BAD_ARRAY_NUM = 38,
	TP_ERR_ARRAY_TOO_BIG = 39,
	TP_ERR_BAD_TYPE = 40,
	TP_ERR_BAD_STRING = 41,
	TP_ERR_BAD_BITFIELD = 42,
	TP_ERR_ARG_NAME_TOO_LONG = 43,
	TP_ERR_NO_ARG_NAME = 44,
	TP_ERR_BAD_ARG_NAME = 45,
	TP_ERR_USED_ARG_NAME = 46,
	TP_ERR_ARG_TOO_LONG = 47,
	TP_ERR_NO_ARG_BODY = 48,
	TP_ERR_BAD_INSN_BNDRY = 49,
	TP_ERR_FAIL_REG_PROBE = 50,
	TP_ERR_DIFF_PROBE_TYPE = 51,
	TP_ERR_DIFF_ARG_TYPE = 52,
	TP_ERR_SAME_PROBE = 53,
};

struct trace_eprobe {
	const char *event_system;
	const char *event_name;
	struct trace_event_call___33 *event;
	struct dyn_event devent;
	struct trace_probe tp;
};

struct eprobe_data {
	struct trace_event_file___15 *file;
	struct trace_eprobe *ep;
};

enum dynevent_type {
	DYNEVENT_TYPE_SYNTH = 1,
	DYNEVENT_TYPE_KPROBE = 2,
	DYNEVENT_TYPE_NONE = 3,
};

struct dynevent_cmd;

typedef int (*dynevent_create_fn_t)(struct dynevent_cmd *);

struct dynevent_cmd {
	struct seq_buf seq;
	const char *event_name;
	unsigned int n_fields;
	enum dynevent_type type;
	dynevent_create_fn_t run_command;
	void *private_data;
};

struct synth_field_desc {
	const char *type;
	const char *name;
};

struct synth_trace_event;

struct synth_event;

struct synth_event_trace_state {
	struct trace_event_buffer___15 fbuffer;
	struct synth_trace_event *entry;
	struct trace_buffer *buffer;
	struct synth_event *event;
	unsigned int cur_field;
	unsigned int n_u64;
	bool disabled;
	bool add_next;
	bool add_name;
};

struct synth_trace_event {
	struct trace_entry ent;
	u64 fields[0];
};

struct synth_field;

struct synth_event {
	struct dyn_event devent;
	int ref;
	char *name;
	struct synth_field **fields;
	unsigned int n_fields;
	struct synth_field **dynamic_fields;
	unsigned int n_dynamic_fields;
	unsigned int n_u64;
	struct trace_event_class___33 class;
	struct trace_event_call___33 call;
	struct tracepoint *tp;
	struct module___55 *mod;
};

typedef int (*dynevent_check_arg_fn_t)(void *);

struct dynevent_arg {
	const char *str;
	char separator;
};

struct dynevent_arg_pair {
	const char *lhs;
	const char *rhs;
	char operator;
	char separator;
};

struct synth_field {
	char *type;
	char *name;
	size_t size;
	unsigned int offset;
	unsigned int field_pos;
	bool is_signed;
	bool is_string;
	bool is_dynamic;
};

enum {
	SYNTH_ERR_BAD_NAME = 0,
	SYNTH_ERR_INVALID_CMD = 1,
	SYNTH_ERR_INVALID_DYN_CMD = 2,
	SYNTH_ERR_EVENT_EXISTS = 3,
	SYNTH_ERR_TOO_MANY_FIELDS = 4,
	SYNTH_ERR_INCOMPLETE_TYPE = 5,
	SYNTH_ERR_INVALID_TYPE = 6,
	SYNTH_ERR_INVALID_FIELD = 7,
	SYNTH_ERR_INVALID_ARRAY_SPEC = 8,
};

struct tracing_map_field___2 {
	tracing_map_cmp_fn_t cmp_fn;
	union {
		atomic64_t sum;
		unsigned int offset;
	};
};

struct tracing_map___2;

struct tracing_map_elt___2 {
	struct tracing_map___2 *map;
	struct tracing_map_field___2 *fields;
	atomic64_t *vars;
	bool *var_set;
	void *key;
	void *private_data;
};

struct tracing_map_ops___2;

struct tracing_map___2 {
	unsigned int key_size;
	unsigned int map_bits;
	unsigned int map_size;
	unsigned int max_elts;
	atomic_t next_elt;
	struct tracing_map_array *elts;
	struct tracing_map_array *map;
	const struct tracing_map_ops___2 *ops;
	void *private_data;
	struct tracing_map_field___2 fields[6];
	unsigned int n_fields;
	int key_idx[3];
	unsigned int n_keys;
	struct tracing_map_sort_key sort_key;
	unsigned int n_vars;
	atomic64_t hits;
	atomic64_t drops;
};

struct tracing_map_sort_entry___2 {
	void *key;
	struct tracing_map_elt___2 *elt;
	bool elt_copied;
	bool dup;
};

struct tracing_map_ops___2 {
	int (*elt_alloc)(struct tracing_map_elt___2 *);
	void (*elt_free)(struct tracing_map_elt___2 *);
	void (*elt_clear)(struct tracing_map_elt___2 *);
	void (*elt_init)(struct tracing_map_elt___2 *);
};

enum {
	HIST_ERR_NONE = 0,
	HIST_ERR_DUPLICATE_VAR = 1,
	HIST_ERR_VAR_NOT_UNIQUE = 2,
	HIST_ERR_TOO_MANY_VARS = 3,
	HIST_ERR_MALFORMED_ASSIGNMENT = 4,
	HIST_ERR_NAMED_MISMATCH = 5,
	HIST_ERR_TRIGGER_EEXIST = 6,
	HIST_ERR_TRIGGER_ENOENT_CLEAR = 7,
	HIST_ERR_SET_CLOCK_FAIL = 8,
	HIST_ERR_BAD_FIELD_MODIFIER = 9,
	HIST_ERR_TOO_MANY_SUBEXPR = 10,
	HIST_ERR_TIMESTAMP_MISMATCH = 11,
	HIST_ERR_TOO_MANY_FIELD_VARS = 12,
	HIST_ERR_EVENT_FILE_NOT_FOUND = 13,
	HIST_ERR_HIST_NOT_FOUND = 14,
	HIST_ERR_HIST_CREATE_FAIL = 15,
	HIST_ERR_SYNTH_VAR_NOT_FOUND = 16,
	HIST_ERR_SYNTH_EVENT_NOT_FOUND = 17,
	HIST_ERR_SYNTH_TYPE_MISMATCH = 18,
	HIST_ERR_SYNTH_COUNT_MISMATCH = 19,
	HIST_ERR_FIELD_VAR_PARSE_FAIL = 20,
	HIST_ERR_VAR_CREATE_FIND_FAIL = 21,
	HIST_ERR_ONX_NOT_VAR = 22,
	HIST_ERR_ONX_VAR_NOT_FOUND = 23,
	HIST_ERR_ONX_VAR_CREATE_FAIL = 24,
	HIST_ERR_FIELD_VAR_CREATE_FAIL = 25,
	HIST_ERR_TOO_MANY_PARAMS = 26,
	HIST_ERR_PARAM_NOT_FOUND = 27,
	HIST_ERR_INVALID_PARAM = 28,
	HIST_ERR_ACTION_NOT_FOUND = 29,
	HIST_ERR_NO_SAVE_PARAMS = 30,
	HIST_ERR_TOO_MANY_SAVE_ACTIONS = 31,
	HIST_ERR_ACTION_MISMATCH = 32,
	HIST_ERR_NO_CLOSING_PAREN = 33,
	HIST_ERR_SUBSYS_NOT_FOUND = 34,
	HIST_ERR_INVALID_SUBSYS_EVENT = 35,
	HIST_ERR_INVALID_REF_KEY = 36,
	HIST_ERR_VAR_NOT_FOUND = 37,
	HIST_ERR_FIELD_NOT_FOUND = 38,
	HIST_ERR_EMPTY_ASSIGNMENT = 39,
	HIST_ERR_INVALID_SORT_MODIFIER = 40,
	HIST_ERR_EMPTY_SORT_FIELD = 41,
	HIST_ERR_TOO_MANY_SORT_FIELDS = 42,
	HIST_ERR_INVALID_SORT_FIELD = 43,
	HIST_ERR_INVALID_STR_OPERAND = 44,
};

struct hist_field;

typedef u64 (*hist_field_fn_t)(struct hist_field *, struct tracing_map_elt___2 *, struct trace_buffer *, struct ring_buffer_event *, void *);

struct hist_trigger_data;

struct hist_var {
	char *name;
	struct hist_trigger_data *hist_data;
	unsigned int idx;
};

enum field_op_id {
	FIELD_OP_NONE = 0,
	FIELD_OP_PLUS = 1,
	FIELD_OP_MINUS = 2,
	FIELD_OP_UNARY_MINUS = 3,
};

struct hist_field {
	struct ftrace_event_field *field;
	long unsigned int flags;
	hist_field_fn_t fn;
	unsigned int ref;
	unsigned int size;
	unsigned int offset;
	unsigned int is_signed;
	long unsigned int buckets;
	const char *type;
	struct hist_field *operands[2];
	struct hist_trigger_data *hist_data;
	struct hist_var var;
	enum field_op_id operator;
	char *system;
	char *event_name;
	char *name;
	unsigned int var_ref_idx;
	bool read_once;
	unsigned int var_str_idx;
};

struct hist_trigger_attrs;

struct action_data;

struct field_var;

struct field_var_hist;

struct hist_trigger_data {
	struct hist_field *fields[22];
	unsigned int n_vals;
	unsigned int n_keys;
	unsigned int n_fields;
	unsigned int n_vars;
	unsigned int n_var_str;
	unsigned int key_size;
	struct tracing_map_sort_key sort_keys[2];
	unsigned int n_sort_keys;
	struct trace_event_file___15 *event_file;
	struct hist_trigger_attrs *attrs;
	struct tracing_map___2 *map;
	bool enable_timestamps;
	bool remove;
	struct hist_field *var_refs[16];
	unsigned int n_var_refs;
	struct action_data *actions[8];
	unsigned int n_actions;
	struct field_var *field_vars[64];
	unsigned int n_field_vars;
	unsigned int n_field_var_str;
	struct field_var_hist *field_var_hists[64];
	unsigned int n_field_var_hists;
	struct field_var *save_vars[64];
	unsigned int n_save_vars;
	unsigned int n_save_var_str;
};

enum hist_field_flags {
	HIST_FIELD_FL_HITCOUNT = 1,
	HIST_FIELD_FL_KEY = 2,
	HIST_FIELD_FL_STRING = 4,
	HIST_FIELD_FL_HEX = 8,
	HIST_FIELD_FL_SYM = 16,
	HIST_FIELD_FL_SYM_OFFSET = 32,
	HIST_FIELD_FL_EXECNAME = 64,
	HIST_FIELD_FL_SYSCALL = 128,
	HIST_FIELD_FL_STACKTRACE = 256,
	HIST_FIELD_FL_LOG2 = 512,
	HIST_FIELD_FL_TIMESTAMP = 1024,
	HIST_FIELD_FL_TIMESTAMP_USECS = 2048,
	HIST_FIELD_FL_VAR = 4096,
	HIST_FIELD_FL_EXPR = 8192,
	HIST_FIELD_FL_VAR_REF = 16384,
	HIST_FIELD_FL_CPU = 32768,
	HIST_FIELD_FL_ALIAS = 65536,
	HIST_FIELD_FL_BUCKET = 131072,
};

struct var_defs {
	unsigned int n_vars;
	char *name[16];
	char *expr[16];
};

struct hist_trigger_attrs {
	char *keys_str;
	char *vals_str;
	char *sort_key_str;
	char *name;
	char *clock;
	bool pause;
	bool cont;
	bool clear;
	bool ts_in_usecs;
	unsigned int map_bits;
	char *assignment_str[16];
	unsigned int n_assignments;
	char *action_str[8];
	unsigned int n_actions;
	struct var_defs var_defs;
};

struct field_var {
	struct hist_field *var;
	struct hist_field *val;
};

struct field_var_hist {
	struct hist_trigger_data *hist_data;
	char *cmd;
};

enum handler_id {
	HANDLER_ONMATCH = 1,
	HANDLER_ONMAX = 2,
	HANDLER_ONCHANGE = 3,
};

enum action_id {
	ACTION_SAVE = 1,
	ACTION_TRACE = 2,
	ACTION_SNAPSHOT = 3,
};

typedef void (*action_fn_t)(struct hist_trigger_data *, struct tracing_map_elt___2 *, struct trace_buffer *, void *, struct ring_buffer_event *, void *, struct action_data *, u64 *);

typedef bool (*check_track_val_fn_t)(u64, u64);

struct action_data {
	enum handler_id handler;
	enum action_id action;
	char *action_name;
	action_fn_t fn;
	unsigned int n_params;
	char *params[64];
	unsigned int var_ref_idx[16];
	struct synth_event *synth_event;
	bool use_trace_keyword;
	char *synth_event_name;
	union {
		struct {
			char *event;
			char *event_system;
		} match_data;
		struct {
			char *var_str;
			struct hist_field *var_ref;
			struct hist_field *track_var;
			check_track_val_fn_t check_val;
			action_fn_t save_data;
		} track_data;
	};
};

struct track_data {
	u64 track_val;
	bool updated;
	unsigned int key_len;
	void *key;
	struct tracing_map_elt___2 elt;
	struct action_data *action_data;
	struct hist_trigger_data *hist_data;
};

struct hist_elt_data {
	char *comm;
	u64 *var_ref_vals;
	char **field_var_str;
	int n_field_var_str;
};

struct snapshot_context {
	struct tracing_map_elt___2 *elt;
	void *key;
};

typedef void (*synth_probe_func_t)(void *, u64 *, unsigned int *);

struct hist_var_data {
	struct list_head list;
	struct hist_trigger_data *hist_data;
};

struct dentry___59;

struct super_block___59;

struct module___57;

struct file_system_type___58 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___59 * (*mount)(struct file_system_type___58 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___59 *);
	struct module___57 *owner;
	struct file_system_type___58 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___59;

struct kiocb___58;

struct iov_iter___30;

struct poll_table_struct___44;

struct vm_area_struct___63;

struct inode___59;

struct file_lock___58;

struct page___63;

struct pipe_inode_info___19;

struct seq_file___56;

struct file_operations___58 {
	struct module___57 *owner;
	loff_t (*llseek)(struct file___59 *, loff_t, int);
	ssize_t (*read)(struct file___59 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___59 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___58 *, struct iov_iter___30 *);
	ssize_t (*write_iter)(struct kiocb___58 *, struct iov_iter___30 *);
	int (*iopoll)(struct kiocb___58 *, bool);
	int (*iterate)(struct file___59 *, struct dir_context *);
	int (*iterate_shared)(struct file___59 *, struct dir_context *);
	__poll_t (*poll)(struct file___59 *, struct poll_table_struct___44 *);
	long int (*unlocked_ioctl)(struct file___59 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___59 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___59 *, struct vm_area_struct___63 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___59 *, struct file___59 *);
	int (*flush)(struct file___59 *, fl_owner_t);
	int (*release)(struct inode___59 *, struct file___59 *);
	int (*fsync)(struct file___59 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___59 *, int);
	int (*lock)(struct file___59 *, int, struct file_lock___58 *);
	ssize_t (*sendpage)(struct file___59 *, struct page___63 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___59 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___59 *, long unsigned int);
	int (*flock)(struct file___59 *, int, struct file_lock___58 *);
	ssize_t (*splice_write)(struct pipe_inode_info___19 *, struct file___59 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___59 *, loff_t *, struct pipe_inode_info___19 *, size_t, unsigned int);
	int (*setlease)(struct file___59 *, long int, struct file_lock___58 **, void **);
	long int (*fallocate)(struct file___59 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___56 *, struct file___59 *);
	ssize_t (*copy_file_range)(struct file___59 *, loff_t, struct file___59 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___59 *, loff_t, struct file___59 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___59 *, loff_t, loff_t, int);
};

struct vmacache___63 {
	u64 seqnum;
	struct vm_area_struct___63 *vmas[4];
};

struct page_frag___63 {
	struct page___63 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___40;

struct debug_info___40 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___40 *hbp_break[16];
	struct perf_event___40 *hbp_watch[16];
};

struct thread_struct___40 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___40 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___64;

struct pid___52;

struct nsproxy___57;

struct signal_struct___59;

struct bio_list___26;

struct backing_dev_info___25;

struct io_context___27;

struct css_set___48;

struct perf_event_context___40;

struct mem_cgroup___23;

struct request_queue___27;

struct vm_struct___60;

struct bpf_local_storage___2;

struct task_struct___64 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___64 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___64 *mm;
	struct mm_struct___64 *active_mm;
	struct vmacache___63 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___64 *real_parent;
	struct task_struct___64 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___64 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___52 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___57 *nsproxy;
	struct signal_struct___59 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___64 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___26 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___25 *backing_dev_info;
	struct io_context___27 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___48 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___40 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___19 *splice_pipe;
	struct page_frag___63 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___23 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___23 *active_memcg;
	struct request_queue___27 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___64 *oom_reaper_list;
	struct vm_struct___60 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___2 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___40 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___58;

struct kobj_type___58;

struct kernfs_node___58;

struct kobject___58 {
	const char *name;
	struct list_head entry;
	struct kobject___58 *parent;
	struct kset___58 *kset;
	struct kobj_type___58 *ktype;
	struct kernfs_node___58 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___55 {
	struct kobject___58 kobj;
	struct module___57 *mod;
	struct kobject___58 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___55 {
	struct module___57 *mod;
	struct latch_tree_node node;
};

struct module_layout___55 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___55 mtn;
};

struct module_attribute___55;

struct kernel_param___55;

struct trace_event_call___35;

struct module___57 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___55 mkobj;
	struct module_attribute___55 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___58 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___55 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___55 core_layout;
	struct module_layout___55 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___35 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___40 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___64 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___40)(struct perf_event___40 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___40;

struct fasync_struct___58;

struct pid_namespace___52;

struct bpf_prog___7;

struct perf_cgroup___40;

struct perf_event___40 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___40 *group_leader;
	struct pmu___40 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___40 hw;
	struct perf_event_context___40 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___40 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___64 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___58 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___40 *aux_event;
	void (*destroy)(struct perf_event___40 *);
	struct callback_head callback_head;
	struct pid_namespace___52 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___40 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___40 orig_overflow_handler;
	struct bpf_prog___7 *prog;
	u64 bpf_cookie;
	struct trace_event_call___35 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___40 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___63 *pgtable_t___63;

struct address_space___58;

struct page_pool___16;

struct dev_pagemap___57;

struct page___63 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___58 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___16 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___63 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___63 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___64 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___57 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___57;

struct vm_area_struct___63 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___63 *vm_next;
	struct vm_area_struct___63 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___64 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___57 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___59 *vm_file;
	struct file___59 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___63;

struct mm_struct___64 {
	struct {
		struct vm_area_struct___63 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___59 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___63 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___64 *owner;
		struct user_namespace___10 *user_ns;
		struct file___59 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___58;

struct address_space___58 {
	struct inode___59 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___58 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___52;

struct page_pool_params___16 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___52 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___16 {
	u32 count;
	struct page___63 *cache[128];
};

struct page_pool___16 {
	struct page_pool_params___16 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___63 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___16 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___57;

struct dev_pagemap___57 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___57 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___58;

struct path___58 {
	struct vfsmount___58 *mnt;
	struct dentry___59 *dentry;
};

struct fown_struct___52 {
	rwlock_t lock;
	struct pid___52 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___59 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___58 f_path;
	struct inode___59 *f_inode;
	const struct file_operations___58 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___52 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___58 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___57;

struct vm_operations_struct___57 {
	void (*open)(struct vm_area_struct___63 *);
	void (*close)(struct vm_area_struct___63 *);
	int (*may_split)(struct vm_area_struct___63 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___63 *);
	int (*mprotect)(struct vm_area_struct___63 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___57 *);
	vm_fault_t (*huge_fault)(struct vm_fault___57 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___57 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___63 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___57 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___57 *);
	int (*access)(struct vm_area_struct___63 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___63 *);
	int (*set_policy)(struct vm_area_struct___63 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___63 *, long unsigned int);
	struct page___63 * (*find_special_page)(struct vm_area_struct___63 *, long unsigned int);
};

struct core_thread___63 {
	struct task_struct___64 *task;
	struct core_thread___63 *next;
};

struct core_state___63 {
	atomic_t nr_threads;
	struct core_thread___63 dumper;
	struct completion startup;
};

struct vm_fault___57 {
	const struct {
		struct vm_area_struct___63 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___63 *cow_page;
	struct page___63 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___63 prealloc_pte;
};

struct pglist_data___24;

struct lruvec___24 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___24 *pgdat;
};

struct zone___24 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___24 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___24 {
	struct zone___24 *zone;
	int zone_idx;
};

struct zonelist___24 {
	struct zoneref___24 _zonerefs[321];
};

struct pglist_data___24 {
	struct zone___24 node_zones[5];
	struct zonelist___24 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___64 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___64 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___24 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

enum bpf_func_id {
	BPF_FUNC_unspec = 0,
	BPF_FUNC_map_lookup_elem = 1,
	BPF_FUNC_map_update_elem = 2,
	BPF_FUNC_map_delete_elem = 3,
	BPF_FUNC_probe_read = 4,
	BPF_FUNC_ktime_get_ns = 5,
	BPF_FUNC_trace_printk = 6,
	BPF_FUNC_get_prandom_u32 = 7,
	BPF_FUNC_get_smp_processor_id = 8,
	BPF_FUNC_skb_store_bytes = 9,
	BPF_FUNC_l3_csum_replace = 10,
	BPF_FUNC_l4_csum_replace = 11,
	BPF_FUNC_tail_call = 12,
	BPF_FUNC_clone_redirect = 13,
	BPF_FUNC_get_current_pid_tgid = 14,
	BPF_FUNC_get_current_uid_gid = 15,
	BPF_FUNC_get_current_comm = 16,
	BPF_FUNC_get_cgroup_classid = 17,
	BPF_FUNC_skb_vlan_push = 18,
	BPF_FUNC_skb_vlan_pop = 19,
	BPF_FUNC_skb_get_tunnel_key = 20,
	BPF_FUNC_skb_set_tunnel_key = 21,
	BPF_FUNC_perf_event_read = 22,
	BPF_FUNC_redirect = 23,
	BPF_FUNC_get_route_realm = 24,
	BPF_FUNC_perf_event_output = 25,
	BPF_FUNC_skb_load_bytes = 26,
	BPF_FUNC_get_stackid = 27,
	BPF_FUNC_csum_diff = 28,
	BPF_FUNC_skb_get_tunnel_opt = 29,
	BPF_FUNC_skb_set_tunnel_opt = 30,
	BPF_FUNC_skb_change_proto = 31,
	BPF_FUNC_skb_change_type = 32,
	BPF_FUNC_skb_under_cgroup = 33,
	BPF_FUNC_get_hash_recalc = 34,
	BPF_FUNC_get_current_task = 35,
	BPF_FUNC_probe_write_user = 36,
	BPF_FUNC_current_task_under_cgroup = 37,
	BPF_FUNC_skb_change_tail = 38,
	BPF_FUNC_skb_pull_data = 39,
	BPF_FUNC_csum_update = 40,
	BPF_FUNC_set_hash_invalid = 41,
	BPF_FUNC_get_numa_node_id = 42,
	BPF_FUNC_skb_change_head = 43,
	BPF_FUNC_xdp_adjust_head = 44,
	BPF_FUNC_probe_read_str = 45,
	BPF_FUNC_get_socket_cookie = 46,
	BPF_FUNC_get_socket_uid = 47,
	BPF_FUNC_set_hash = 48,
	BPF_FUNC_setsockopt = 49,
	BPF_FUNC_skb_adjust_room = 50,
	BPF_FUNC_redirect_map = 51,
	BPF_FUNC_sk_redirect_map = 52,
	BPF_FUNC_sock_map_update = 53,
	BPF_FUNC_xdp_adjust_meta = 54,
	BPF_FUNC_perf_event_read_value = 55,
	BPF_FUNC_perf_prog_read_value = 56,
	BPF_FUNC_getsockopt = 57,
	BPF_FUNC_override_return = 58,
	BPF_FUNC_sock_ops_cb_flags_set = 59,
	BPF_FUNC_msg_redirect_map = 60,
	BPF_FUNC_msg_apply_bytes = 61,
	BPF_FUNC_msg_cork_bytes = 62,
	BPF_FUNC_msg_pull_data = 63,
	BPF_FUNC_bind = 64,
	BPF_FUNC_xdp_adjust_tail = 65,
	BPF_FUNC_skb_get_xfrm_state = 66,
	BPF_FUNC_get_stack = 67,
	BPF_FUNC_skb_load_bytes_relative = 68,
	BPF_FUNC_fib_lookup = 69,
	BPF_FUNC_sock_hash_update = 70,
	BPF_FUNC_msg_redirect_hash = 71,
	BPF_FUNC_sk_redirect_hash = 72,
	BPF_FUNC_lwt_push_encap = 73,
	BPF_FUNC_lwt_seg6_store_bytes = 74,
	BPF_FUNC_lwt_seg6_adjust_srh = 75,
	BPF_FUNC_lwt_seg6_action = 76,
	BPF_FUNC_rc_repeat = 77,
	BPF_FUNC_rc_keydown = 78,
	BPF_FUNC_skb_cgroup_id = 79,
	BPF_FUNC_get_current_cgroup_id = 80,
	BPF_FUNC_get_local_storage = 81,
	BPF_FUNC_sk_select_reuseport = 82,
	BPF_FUNC_skb_ancestor_cgroup_id = 83,
	BPF_FUNC_sk_lookup_tcp = 84,
	BPF_FUNC_sk_lookup_udp = 85,
	BPF_FUNC_sk_release = 86,
	BPF_FUNC_map_push_elem = 87,
	BPF_FUNC_map_pop_elem = 88,
	BPF_FUNC_map_peek_elem = 89,
	BPF_FUNC_msg_push_data = 90,
	BPF_FUNC_msg_pop_data = 91,
	BPF_FUNC_rc_pointer_rel = 92,
	BPF_FUNC_spin_lock = 93,
	BPF_FUNC_spin_unlock = 94,
	BPF_FUNC_sk_fullsock = 95,
	BPF_FUNC_tcp_sock = 96,
	BPF_FUNC_skb_ecn_set_ce = 97,
	BPF_FUNC_get_listener_sock = 98,
	BPF_FUNC_skc_lookup_tcp = 99,
	BPF_FUNC_tcp_check_syncookie = 100,
	BPF_FUNC_sysctl_get_name = 101,
	BPF_FUNC_sysctl_get_current_value = 102,
	BPF_FUNC_sysctl_get_new_value = 103,
	BPF_FUNC_sysctl_set_new_value = 104,
	BPF_FUNC_strtol = 105,
	BPF_FUNC_strtoul = 106,
	BPF_FUNC_sk_storage_get = 107,
	BPF_FUNC_sk_storage_delete = 108,
	BPF_FUNC_send_signal = 109,
	BPF_FUNC_tcp_gen_syncookie = 110,
	BPF_FUNC_skb_output = 111,
	BPF_FUNC_probe_read_user = 112,
	BPF_FUNC_probe_read_kernel = 113,
	BPF_FUNC_probe_read_user_str = 114,
	BPF_FUNC_probe_read_kernel_str = 115,
	BPF_FUNC_tcp_send_ack = 116,
	BPF_FUNC_send_signal_thread = 117,
	BPF_FUNC_jiffies64 = 118,
	BPF_FUNC_read_branch_records = 119,
	BPF_FUNC_get_ns_current_pid_tgid = 120,
	BPF_FUNC_xdp_output = 121,
	BPF_FUNC_get_netns_cookie = 122,
	BPF_FUNC_get_current_ancestor_cgroup_id = 123,
	BPF_FUNC_sk_assign = 124,
	BPF_FUNC_ktime_get_boot_ns = 125,
	BPF_FUNC_seq_printf = 126,
	BPF_FUNC_seq_write = 127,
	BPF_FUNC_sk_cgroup_id = 128,
	BPF_FUNC_sk_ancestor_cgroup_id = 129,
	BPF_FUNC_ringbuf_output = 130,
	BPF_FUNC_ringbuf_reserve = 131,
	BPF_FUNC_ringbuf_submit = 132,
	BPF_FUNC_ringbuf_discard = 133,
	BPF_FUNC_ringbuf_query = 134,
	BPF_FUNC_csum_level = 135,
	BPF_FUNC_skc_to_tcp6_sock = 136,
	BPF_FUNC_skc_to_tcp_sock = 137,
	BPF_FUNC_skc_to_tcp_timewait_sock = 138,
	BPF_FUNC_skc_to_tcp_request_sock = 139,
	BPF_FUNC_skc_to_udp6_sock = 140,
	BPF_FUNC_get_task_stack = 141,
	BPF_FUNC_load_hdr_opt = 142,
	BPF_FUNC_store_hdr_opt = 143,
	BPF_FUNC_reserve_hdr_opt = 144,
	BPF_FUNC_inode_storage_get = 145,
	BPF_FUNC_inode_storage_delete = 146,
	BPF_FUNC_d_path = 147,
	BPF_FUNC_copy_from_user = 148,
	BPF_FUNC_snprintf_btf = 149,
	BPF_FUNC_seq_printf_btf = 150,
	BPF_FUNC_skb_cgroup_classid = 151,
	BPF_FUNC_redirect_neigh = 152,
	BPF_FUNC_per_cpu_ptr = 153,
	BPF_FUNC_this_cpu_ptr = 154,
	BPF_FUNC_redirect_peer = 155,
	BPF_FUNC_task_storage_get = 156,
	BPF_FUNC_task_storage_delete = 157,
	BPF_FUNC_get_current_task_btf = 158,
	BPF_FUNC_bprm_opts_set = 159,
	BPF_FUNC_ktime_get_coarse_ns = 160,
	BPF_FUNC_ima_inode_hash = 161,
	BPF_FUNC_sock_from_file = 162,
	BPF_FUNC_check_mtu = 163,
	BPF_FUNC_for_each_map_elem = 164,
	BPF_FUNC_snprintf = 165,
	BPF_FUNC_sys_bpf = 166,
	BPF_FUNC_btf_find_by_name_kind = 167,
	BPF_FUNC_sys_close = 168,
	BPF_FUNC_timer_init = 169,
	BPF_FUNC_timer_set_callback = 170,
	BPF_FUNC_timer_start = 171,
	BPF_FUNC_timer_cancel = 172,
	BPF_FUNC_get_func_ip = 173,
	BPF_FUNC_get_attach_cookie = 174,
	BPF_FUNC_task_pt_regs = 175,
	__BPF_FUNC_MAX_ID = 176,
};

enum {
	BPF_F_INDEX_MASK = 0,
	BPF_F_CURRENT_CPU = 0,
	BPF_F_CTXLEN_MASK = 0,
};

enum {
	BPF_F_GET_BRANCH_RECORDS_SIZE = 1,
};

struct bpf_perf_event_value {
	__u64 counter;
	__u64 enabled;
	__u64 running;
};

struct bpf_raw_tracepoint_args {
	__u64 args[0];
};

enum bpf_task_fd_type {
	BPF_FD_TYPE_RAW_TRACEPOINT = 0,
	BPF_FD_TYPE_TRACEPOINT = 1,
	BPF_FD_TYPE_KPROBE = 2,
	BPF_FD_TYPE_KRETPROBE = 3,
	BPF_FD_TYPE_UPROBE = 4,
	BPF_FD_TYPE_URETPROBE = 5,
};

struct btf_ptr {
	void *ptr;
	__u32 type_id;
	__u32 flags;
};

enum {
	BTF_F_COMPACT = 1,
	BTF_F_NONAME = 2,
	BTF_F_PTR_RAW = 4,
	BTF_F_ZERO = 8,
};

struct upid___52 {
	int nr;
	struct pid_namespace___52 *ns;
};

struct pid_namespace___52 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___64 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___52 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___52 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___52 numbers[1];
};

struct signal_struct___59 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___64 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___64 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___52 *pids[4];
	struct pid___52 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___64 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___10;

struct cgroup_namespace___48;

struct nsproxy___57 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___52 *pid_ns_for_children;
	struct net___10 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___48 *cgroup_ns;
};

struct bio___26;

struct bio_list___26 {
	struct bio___26 *head;
	struct bio___26 *tail;
};

struct cgroup_subsys_state___48;

struct bdi_writeback___25 {
	struct backing_dev_info___25 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___48 *memcg_css;
	struct cgroup_subsys_state___48 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___25 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___25 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___52 *dev;
	char dev_name[64];
	struct device___52 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___59 *debug_dir;
};

struct io_cq___26;

struct io_context___27 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___26 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___48;

struct css_set___48 {
	struct cgroup_subsys_state___48 *subsys[14];
	refcount_t refcount;
	struct css_set___48 *dom_cset;
	struct cgroup___48 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___48 *mg_src_cgrp;
	struct cgroup___48 *mg_dst_cgrp;
	struct css_set___48 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___40 {
	struct pmu___40 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___64 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___40 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___19;

struct pipe_inode_info___19 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___63 *tmp_page;
	struct fasync_struct___58 *fasync_readers;
	struct fasync_struct___58 *fasync_writers;
	struct pipe_buffer___19 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___48;

struct cgroup_subsys_state___48 {
	struct cgroup___48 *cgroup;
	struct cgroup_subsys___48 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___48 *parent;
};

struct cgroup_file___48 {
	struct kernfs_node___58 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___23;

struct mem_cgroup_per_node___23;

struct mem_cgroup___23 {
	struct cgroup_subsys_state___48 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___48 events_file;
	struct cgroup_file___48 events_local_file;
	struct cgroup_file___48 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___23 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___64 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___23 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___26;

struct blk_integrity___26 {
	const struct blk_integrity_profile___26 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___26 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___26 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___26;

struct elevator_queue___26;

struct blk_mq_ops___25;

struct blk_mq_hw_ctx___25;

struct gendisk___26;

struct blkcg_gq___25;

struct blk_mq_tag_set___25;

struct request_queue___27 {
	struct request___26 *last_merge;
	struct elevator_queue___26 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___25 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___25 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___26 *disk;
	struct kobject___58 kobj;
	struct kobject___58 *mq_kobj;
	struct blk_integrity___26 integrity;
	struct device___52 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___25 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___25 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___26 bio_split;
	struct dentry___59 *debugfs_dir;
	struct dentry___59 *sched_debugfs_dir;
	struct dentry___59 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___60 {
	struct vm_struct___60 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___63 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data;

struct bpf_local_storage___2 {
	struct bpf_local_storage_data *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct dentry_operations___58;

struct dentry___59 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___59 *d_parent;
	struct qstr d_name;
	struct inode___59 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___58 *d_op;
	struct super_block___59 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___58;

struct inode___59 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___58 *i_op;
	struct super_block___59 *i_sb;
	struct address_space___58 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___25 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___58 *i_fop;
		void (*free_inode)(struct inode___59 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___58 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___19 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___58 {
	int (*d_revalidate)(struct dentry___59 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___59 *, unsigned int);
	int (*d_hash)(const struct dentry___59 *, struct qstr *);
	int (*d_compare)(const struct dentry___59 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___59 *);
	int (*d_init)(struct dentry___59 *);
	void (*d_release)(struct dentry___59 *);
	void (*d_prune)(struct dentry___59 *);
	void (*d_iput)(struct dentry___59 *, struct inode___59 *);
	char * (*d_dname)(struct dentry___59 *, char *, int);
	struct vfsmount___58 * (*d_automount)(struct path___58 *);
	int (*d_manage)(const struct path___58 *, bool);
	struct dentry___59 * (*d_real)(struct dentry___59 *, const struct inode___59 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___58;

struct mem_dqinfo___58 {
	struct quota_format_type___58 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___58;

struct quota_info___58 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___59 *files[3];
	struct mem_dqinfo___58 info[3];
	const struct quota_format_ops___58 *ops[3];
};

struct rcuwait___59 {
	struct task_struct___64 *task;
};

struct percpu_rw_semaphore___59 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___59 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___58 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___59 rw_sem[3];
};

struct shrink_control___23;

struct shrinker___23 {
	long unsigned int (*count_objects)(struct shrinker___23 *, struct shrink_control___23 *);
	long unsigned int (*scan_objects)(struct shrinker___23 *, struct shrink_control___23 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___58;

struct dquot_operations___58;

struct quotactl_ops___58;

struct block_device___27;

struct super_block___59 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___58 *s_type;
	const struct super_operations___58 *s_op;
	const struct dquot_operations___58 *dq_op;
	const struct quotactl_ops___58 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___59 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___27 *s_bdev;
	struct backing_dev_info___25 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___58 s_dquot;
	struct sb_writers___58 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___58 *s_d_op;
	int cleancache_poolid;
	struct shrinker___23 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___58 {
	struct dentry___59 *mnt_root;
	struct super_block___59 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct shrink_control___23 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___23 *memcg;
};

struct psi_group___48 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___64 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___7;

struct cgroup_bpf___7 {
	struct bpf_prog_array___7 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___7 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___48;

struct cgroup_rstat_cpu___48;

struct cgroup___48 {
	struct cgroup_subsys_state___48 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___58 *kn;
	struct cgroup_file___48 procs_file;
	struct cgroup_file___48 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___48 *subsys[14];
	struct cgroup_root___48 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___48 *dom_cgrp;
	struct cgroup___48 *old_dom_cgrp;
	struct cgroup_rstat_cpu___48 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___48 psi;
	struct cgroup_bpf___7 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___26 {
	struct request_queue___27 *q;
	struct io_context___27 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___27;

struct kiocb___58 {
	struct file___59 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___58 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___59 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___59 *ia_file;
};

struct dquot___58 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___59 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___58 {
	int qf_fmt_id;
	const struct quota_format_ops___58 *qf_ops;
	struct module___57 *qf_owner;
	struct quota_format_type___58 *qf_next;
};

struct quota_format_ops___58 {
	int (*check_quota_file)(struct super_block___59 *, int);
	int (*read_file_info)(struct super_block___59 *, int);
	int (*write_file_info)(struct super_block___59 *, int);
	int (*free_file_info)(struct super_block___59 *, int);
	int (*read_dqblk)(struct dquot___58 *);
	int (*commit_dqblk)(struct dquot___58 *);
	int (*release_dqblk)(struct dquot___58 *);
	int (*get_next_id)(struct super_block___59 *, struct kqid *);
};

struct dquot_operations___58 {
	int (*write_dquot)(struct dquot___58 *);
	struct dquot___58 * (*alloc_dquot)(struct super_block___59 *, int);
	void (*destroy_dquot)(struct dquot___58 *);
	int (*acquire_dquot)(struct dquot___58 *);
	int (*release_dquot)(struct dquot___58 *);
	int (*mark_dirty)(struct dquot___58 *);
	int (*write_info)(struct super_block___59 *, int);
	qsize_t * (*get_reserved_space)(struct inode___59 *);
	int (*get_projid)(struct inode___59 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___59 *, qsize_t *);
	int (*get_next_id)(struct super_block___59 *, struct kqid *);
};

struct quotactl_ops___58 {
	int (*quota_on)(struct super_block___59 *, int, int, const struct path___58 *);
	int (*quota_off)(struct super_block___59 *, int);
	int (*quota_enable)(struct super_block___59 *, unsigned int);
	int (*quota_disable)(struct super_block___59 *, unsigned int);
	int (*quota_sync)(struct super_block___59 *, int);
	int (*set_info)(struct super_block___59 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___59 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___59 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___59 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___59 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___59 *, unsigned int);
};

struct wait_page_queue___27 {
	struct page___63 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___25;

struct readahead_control___27;

struct swap_info_struct___17;

struct address_space_operations___58 {
	int (*writepage)(struct page___63 *, struct writeback_control___25 *);
	int (*readpage)(struct file___59 *, struct page___63 *);
	int (*writepages)(struct address_space___58 *, struct writeback_control___25 *);
	int (*set_page_dirty)(struct page___63 *);
	int (*readpages)(struct file___59 *, struct address_space___58 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___27 *);
	int (*write_begin)(struct file___59 *, struct address_space___58 *, loff_t, unsigned int, unsigned int, struct page___63 **, void **);
	int (*write_end)(struct file___59 *, struct address_space___58 *, loff_t, unsigned int, unsigned int, struct page___63 *, void *);
	sector_t (*bmap)(struct address_space___58 *, sector_t);
	void (*invalidatepage)(struct page___63 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___63 *, gfp_t);
	void (*freepage)(struct page___63 *);
	ssize_t (*direct_IO)(struct kiocb___58 *, struct iov_iter___30 *);
	int (*migratepage)(struct address_space___58 *, struct page___63 *, struct page___63 *, enum migrate_mode);
	bool (*isolate_page)(struct page___63 *, isolate_mode_t);
	void (*putback_page)(struct page___63 *);
	int (*launder_page)(struct page___63 *);
	int (*is_partially_uptodate)(struct page___63 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___63 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___58 *, struct page___63 *);
	int (*swap_activate)(struct swap_info_struct___17 *, struct file___59 *, sector_t *);
	void (*swap_deactivate)(struct file___59 *);
};

struct writeback_control___25 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___25 *wb;
	struct inode___59 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___27 {
	struct file___59 *file;
	struct address_space___58 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___30;

struct iov_iter___30 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___30 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___19 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___17 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___27 *bdev;
	struct file___59 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___58 {
	struct dentry___59 * (*lookup)(struct inode___59 *, struct dentry___59 *, unsigned int);
	const char * (*get_link)(struct dentry___59 *, struct inode___59 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___59 *, int);
	struct posix_acl * (*get_acl)(struct inode___59 *, int, bool);
	int (*readlink)(struct dentry___59 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___59 *, struct dentry___59 *, umode_t, bool);
	int (*link)(struct dentry___59 *, struct inode___59 *, struct dentry___59 *);
	int (*unlink)(struct inode___59 *, struct dentry___59 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___59 *, struct dentry___59 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___59 *, struct dentry___59 *, umode_t);
	int (*rmdir)(struct inode___59 *, struct dentry___59 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___59 *, struct dentry___59 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___59 *, struct dentry___59 *, struct inode___59 *, struct dentry___59 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___59 *, struct iattr___59 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___58 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___59 *, char *, size_t);
	int (*fiemap)(struct inode___59 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___59 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___59 *, struct dentry___59 *, struct file___59 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___59 *, struct dentry___59 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___59 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___59 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___59 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___58 {
	void (*fl_copy_lock)(struct file_lock___58 *, struct file_lock___58 *);
	void (*fl_release_private)(struct file_lock___58 *);
};

struct lock_manager_operations___58;

struct file_lock___58 {
	struct file_lock___58 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___59 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___58 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___58 *fl_ops;
	const struct lock_manager_operations___58 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___58 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___58 *);
	int (*lm_grant)(struct file_lock___58 *, int);
	bool (*lm_break)(struct file_lock___58 *);
	int (*lm_change)(struct file_lock___58 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___58 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___58 *);
};

struct fasync_struct___58 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___58 *fa_next;
	struct file___59 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___58 {
	struct inode___59 * (*alloc_inode)(struct super_block___59 *);
	void (*destroy_inode)(struct inode___59 *);
	void (*free_inode)(struct inode___59 *);
	void (*dirty_inode)(struct inode___59 *, int);
	int (*write_inode)(struct inode___59 *, struct writeback_control___25 *);
	int (*drop_inode)(struct inode___59 *);
	void (*evict_inode)(struct inode___59 *);
	void (*put_super)(struct super_block___59 *);
	int (*sync_fs)(struct super_block___59 *, int);
	int (*freeze_super)(struct super_block___59 *);
	int (*freeze_fs)(struct super_block___59 *);
	int (*thaw_super)(struct super_block___59 *);
	int (*unfreeze_fs)(struct super_block___59 *);
	int (*statfs)(struct dentry___59 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___59 *, int *, char *);
	void (*umount_begin)(struct super_block___59 *);
	int (*show_options)(struct seq_file___56 *, struct dentry___59 *);
	int (*show_devname)(struct seq_file___56 *, struct dentry___59 *);
	int (*show_path)(struct seq_file___56 *, struct dentry___59 *);
	int (*show_stats)(struct seq_file___56 *, struct dentry___59 *);
	ssize_t (*quota_read)(struct super_block___59 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___59 *, int, const char *, size_t, loff_t);
	struct dquot___58 ** (*get_dquots)(struct inode___59 *);
	long int (*nr_cached_objects)(struct super_block___59 *, struct shrink_control___23 *);
	long int (*free_cached_objects)(struct super_block___59 *, struct shrink_control___23 *);
	struct file___59 * (*real_loop)(struct file___59 *);
};

struct wakeup_source___52;

struct dev_pm_info___52 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___52 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___52 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___52;

struct bus_type___52;

struct device_driver___52;

struct dev_pm_domain___52;

struct device_node___32;

struct fwnode_handle___52;

struct class___52;

struct attribute_group___58;

struct device___52 {
	struct kobject___58 kobj;
	struct device___52 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___52 *type;
	struct bus_type___52 *bus;
	struct device_driver___52 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___52 power;
	struct dev_pm_domain___52 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___32 *of_node;
	struct fwnode_handle___52 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___52 *class;
	const struct attribute_group___58 **groups;
	void (*release)(struct device___52 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___27 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___59 *bd_inode;
	struct super_block___59 *bd_super;
	void *bd_claiming;
	struct device___52 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___58 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___26 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___59 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___44)(struct file___59 *, wait_queue_head_t *, struct poll_table_struct___44 *);

struct poll_table_struct___44 {
	poll_queue_proc___44 _qproc;
	__poll_t _key;
};

struct seq_operations___56;

struct seq_file___56 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___56 *op;
	int poll_event;
	const struct file___59 *file;
	void *private;
};

typedef void bio_end_io_t___26(struct bio___26 *);

struct bio_vec___30 {
	struct page___63 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___26;

struct bio___26 {
	struct bio___26 *bi_next;
	struct block_device___27 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___26 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___25 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___26 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___30 *bi_io_vec;
	struct bio_set___26 *bi_pool;
	struct bio_vec___30 bi_inline_vecs[0];
};

struct kernfs_root___58;

struct kernfs_elem_dir___58 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___58 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___58;

struct kernfs_root___58 {
	struct kernfs_node___58 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___58 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___58 {
	struct kernfs_node___58 *target_kn;
};

struct kernfs_ops___58;

struct kernfs_elem_attr___58 {
	const struct kernfs_ops___58 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___58 *notify_next;
};

struct kernfs_node___58 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___58 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___58 dir;
		struct kernfs_elem_symlink___58 symlink;
		struct kernfs_elem_attr___58 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___58;

struct kernfs_ops___58 {
	int (*open)(struct kernfs_open_file___58 *);
	void (*release)(struct kernfs_open_file___58 *);
	int (*seq_show)(struct seq_file___56 *, void *);
	void * (*seq_start)(struct seq_file___56 *, loff_t *);
	void * (*seq_next)(struct seq_file___56 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___56 *, void *);
	ssize_t (*read)(struct kernfs_open_file___58 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___58 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___58 *, struct poll_table_struct___44 *);
	int (*mmap)(struct kernfs_open_file___58 *, struct vm_area_struct___63 *);
};

struct kernfs_syscall_ops___58 {
	int (*show_options)(struct seq_file___56 *, struct kernfs_root___58 *);
	int (*mkdir)(struct kernfs_node___58 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___58 *);
	int (*rename)(struct kernfs_node___58 *, struct kernfs_node___58 *, const char *);
	int (*show_path)(struct seq_file___56 *, struct kernfs_node___58 *, struct kernfs_root___58 *);
};

struct kernfs_open_file___58 {
	struct kernfs_node___58 *kn;
	struct file___59 *file;
	struct seq_file___56 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___57 *vm_ops;
};

struct sock___8;

struct kobj_ns_type_operations___6 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___8 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___10 *net;
} possible_net_t___7;

struct proto___6;

struct sock_common___6 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___6 *skc_prot;
	possible_net_t___7 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___8 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___9;

struct sk_buff_head___7 {
	struct sk_buff___9 *next;
	struct sk_buff___9 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___6 {
	struct cgroup___48 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___6;

struct socket_wq___6;

struct dst_entry___6;

struct socket___6;

struct net_device___12;

struct sock___8 {
	struct sock_common___6 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___7 sk_error_queue;
	struct sk_buff___9 *sk_rx_skb_cache;
	struct sk_buff_head___7 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___9 *head;
		struct sk_buff___9 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___6 *sk_filter;
	union {
		struct socket_wq___6 *sk_wq;
		struct socket_wq___6 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___6 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___6 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___9 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___9 *sk_tx_skb_cache;
	struct sk_buff_head___7 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___63 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___6 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___52 *sk_peer_pid;
	const struct cred___9 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___6 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___6 sk_cgrp_data;
	struct mem_cgroup___23 *sk_memcg;
	void (*sk_state_change)(struct sock___8 *);
	void (*sk_data_ready)(struct sock___8 *);
	void (*sk_write_space)(struct sock___8 *);
	void (*sk_error_report)(struct sock___8 *);
	int (*sk_backlog_rcv)(struct sock___8 *, struct sk_buff___9 *);
	struct sk_buff___9 * (*sk_validate_xmit_skb)(struct sock___8 *, struct net_device___12 *, struct sk_buff___9 *);
	void (*sk_destruct)(struct sock___8 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage___2 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___58;

struct attribute_group___58 {
	const char *name;
	umode_t (*is_visible)(struct kobject___58 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___58 *, struct bin_attribute___58 *, int);
	struct attribute **attrs;
	struct bin_attribute___58 **bin_attrs;
};

struct bin_attribute___58 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___58 * (*f_mapping)();
	ssize_t (*read)(struct file___59 *, struct kobject___58 *, struct bin_attribute___58 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___59 *, struct kobject___58 *, struct bin_attribute___58 *, char *, loff_t, size_t);
	int (*mmap)(struct file___59 *, struct kobject___58 *, struct bin_attribute___58 *, struct vm_area_struct___63 *);
};

struct sysfs_ops___58 {
	ssize_t (*show)(struct kobject___58 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___58 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___58;

struct kset___58 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___58 kobj;
	const struct kset_uevent_ops___58 *uevent_ops;
};

struct kobj_type___58 {
	void (*release)(struct kobject___58 *);
	const struct sysfs_ops___58 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___58 **default_groups;
	const struct kobj_ns_type_operations___6 * (*child_ns_type)(struct kobject___58 *);
	const void * (*namespace)(struct kobject___58 *);
	void (*get_ownership)(struct kobject___58 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___58 {
	int (* const filter)(struct kset___58 *, struct kobject___58 *);
	const char * (* const name)(struct kset___58 *, struct kobject___58 *);
	int (* const uevent)(struct kset___58 *, struct kobject___58 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___55 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___55 *);
	int (*get)(char *, const struct kernel_param___55 *);
	void (*free)(void *);
};

struct kparam_array___55;

struct kernel_param___55 {
	const char *name;
	struct module___57 *mod;
	const struct kernel_param_ops___55 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___55 *arr;
	};
};

struct kparam_array___55 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___55 *ops;
	void *elem;
};

struct module_attribute___55 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___55 *, struct module_kobject___55 *, char *);
	ssize_t (*store)(struct module_attribute___55 *, struct module_kobject___55 *, const char *, size_t);
	void (*setup)(struct module___57 *, const char *);
	int (*test)(struct module___57 *);
	void (*free)(struct module___57 *);
};

struct trace_event_functions___4;

struct trace_event___4 {
	struct hlist_node node;
	struct list_head list;
	int type;
	struct trace_event_functions___4 *funcs;
};

struct trace_event_class___35;

struct trace_event_call___35 {
	struct list_head list;
	struct trace_event_class___35 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___7 *prog_array;
	int (*perf_perm)(struct trace_event_call___35 *, struct perf_event___40 *);
};

struct dev_pagemap_ops___57 {
	void (*page_free)(struct page___63 *);
	void (*kill)(struct dev_pagemap___57 *);
	void (*cleanup)(struct dev_pagemap___57 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___57 *);
};

struct bpf_iter_aux_info___7;

typedef int (*bpf_iter_init_seq_priv_t___7)(void *, struct bpf_iter_aux_info___7 *);

struct bpf_map___7;

struct bpf_iter_aux_info___7 {
	struct bpf_map___7 *map;
};

struct bpf_iter_seq_info___7 {
	const struct seq_operations___56 *seq_ops;
	bpf_iter_init_seq_priv_t___7 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___56 {
	void * (*start)(struct seq_file___56 *, loff_t *);
	void (*stop)(struct seq_file___56 *, void *);
	void * (*next)(struct seq_file___56 *, void *, loff_t *);
	int (*show)(struct seq_file___56 *, void *);
};

struct bpf_prog_aux___7;

struct bpf_local_storage_map___2;

struct bpf_map_ops___7 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___7 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___7 *, struct file___59 *);
	void (*map_free)(struct bpf_map___7 *);
	int (*map_get_next_key)(struct bpf_map___7 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___7 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___7 *, void *);
	int (*map_lookup_batch)(struct bpf_map___7 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___7 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___7 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___7 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___7 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___7 *, void *);
	int (*map_update_elem)(struct bpf_map___7 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___7 *, void *);
	int (*map_push_elem)(struct bpf_map___7 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___7 *, void *);
	int (*map_peek_elem)(struct bpf_map___7 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___7 *, struct file___59 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___7 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___7 *, void *, struct seq_file___56 *);
	int (*map_check_btf)(const struct bpf_map___7 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___7 *, struct bpf_prog_aux___7 *);
	void (*map_poke_untrack)(struct bpf_map___7 *, struct bpf_prog_aux___7 *);
	void (*map_poke_run)(struct bpf_map___7 *, u32, struct bpf_prog___7 *, struct bpf_prog___7 *);
	int (*map_direct_value_addr)(const struct bpf_map___7 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___7 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___7 *, struct vm_area_struct___63 *);
	__poll_t (*map_poll)(struct bpf_map___7 *, struct file___59 *, struct poll_table_struct___44 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___2 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___2 *, void *, u32);
	struct bpf_local_storage___2 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___7 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___7 *, const struct bpf_map___7 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___7 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___7 *iter_seq_info;
};

struct bpf_map___7 {
	const struct bpf_map_ops___7 *ops;
	struct bpf_map___7 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___23 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___7;

struct bpf_jit_poke_descriptor___7;

struct bpf_prog_ops___7;

struct btf_mod_pair___7;

struct bpf_prog_offload___7;

struct bpf_prog_aux___7 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___7 *dst_prog;
	struct bpf_trampoline___7 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___7 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___7 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___7 *ops;
	struct bpf_map___7 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___7 *used_btfs;
	struct bpf_prog___7 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___7 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___7 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___7 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___7 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_local_storage_map_bucket;

struct bpf_local_storage_map___2 {
	struct bpf_map___7 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___7;

struct bpf_map_dev_ops___7 {
	int (*map_get_next_key)(struct bpf_offloaded_map___7 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___7 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___7 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___7 *, void *);
};

struct bpf_offloaded_map___7 {
	struct bpf_map___7 map;
	struct net_device___12 *netdev;
	const struct bpf_map_dev_ops___7 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___7(struct sk_buff___9 **);

struct bpf_xdp_entity___7 {
	struct bpf_prog___7 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___7;

struct net_device_ops___7;

struct l3mdev_ops___6;

struct xfrmdev_ops___7;

struct header_ops___7;

struct netdev_rx_queue___7;

struct mini_Qdisc___7;

struct netdev_queue___7;

struct Qdisc___7;

struct rtnl_link_ops___7;

struct dcbnl_rtnl_ops___7;

struct net_device___12 {
	char name[16];
	struct netdev_name_node___7 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___7 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___6 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___7 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___7 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___58 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___7 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___7 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___7 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___7 *miniq_ingress;
	struct netdev_queue___7 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___7 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___7 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___7 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___7 = 0,
		NETREG_REGISTERED___7 = 1,
		NETREG_UNREGISTERING___7 = 2,
		NETREG_UNREGISTERED___7 = 3,
		NETREG_RELEASED___7 = 4,
		NETREG_DUMMY___7 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___7 = 0,
		RTNL_LINK_INITIALIZING___7 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___12 *);
	struct netpoll_info *npinfo;
	possible_net_t___7 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___52 dev;
	const struct attribute_group___58 *sysfs_groups[4];
	const struct attribute_group___58 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___7 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___7 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___7 xdp_state[3];
	long: 64;
};

enum bpf_arg_type {
	ARG_DONTCARE = 0,
	ARG_CONST_MAP_PTR = 1,
	ARG_PTR_TO_MAP_KEY = 2,
	ARG_PTR_TO_MAP_VALUE = 3,
	ARG_PTR_TO_UNINIT_MAP_VALUE = 4,
	ARG_PTR_TO_MAP_VALUE_OR_NULL = 5,
	ARG_PTR_TO_MEM = 6,
	ARG_PTR_TO_MEM_OR_NULL = 7,
	ARG_PTR_TO_UNINIT_MEM = 8,
	ARG_CONST_SIZE = 9,
	ARG_CONST_SIZE_OR_ZERO = 10,
	ARG_PTR_TO_CTX = 11,
	ARG_PTR_TO_CTX_OR_NULL = 12,
	ARG_ANYTHING = 13,
	ARG_PTR_TO_SPIN_LOCK = 14,
	ARG_PTR_TO_SOCK_COMMON = 15,
	ARG_PTR_TO_INT = 16,
	ARG_PTR_TO_LONG = 17,
	ARG_PTR_TO_SOCKET = 18,
	ARG_PTR_TO_SOCKET_OR_NULL = 19,
	ARG_PTR_TO_BTF_ID = 20,
	ARG_PTR_TO_ALLOC_MEM = 21,
	ARG_PTR_TO_ALLOC_MEM_OR_NULL = 22,
	ARG_CONST_ALLOC_SIZE_OR_ZERO = 23,
	ARG_PTR_TO_BTF_ID_SOCK_COMMON = 24,
	ARG_PTR_TO_PERCPU_BTF_ID = 25,
	ARG_PTR_TO_FUNC = 26,
	ARG_PTR_TO_STACK_OR_NULL = 27,
	ARG_PTR_TO_CONST_STR = 28,
	ARG_PTR_TO_TIMER = 29,
	__BPF_ARG_TYPE_MAX = 30,
};

enum bpf_return_type {
	RET_INTEGER = 0,
	RET_VOID = 1,
	RET_PTR_TO_MAP_VALUE = 2,
	RET_PTR_TO_MAP_VALUE_OR_NULL = 3,
	RET_PTR_TO_SOCKET_OR_NULL = 4,
	RET_PTR_TO_TCP_SOCK_OR_NULL = 5,
	RET_PTR_TO_SOCK_COMMON_OR_NULL = 6,
	RET_PTR_TO_ALLOC_MEM_OR_NULL = 7,
	RET_PTR_TO_BTF_ID_OR_NULL = 8,
	RET_PTR_TO_MEM_OR_BTF_ID_OR_NULL = 9,
	RET_PTR_TO_MEM_OR_BTF_ID = 10,
	RET_PTR_TO_BTF_ID = 11,
};

struct bpf_func_proto {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___7 *);
};

enum bpf_access_type {
	BPF_READ = 1,
	BPF_WRITE = 2,
};

struct bpf_verifier_log;

struct bpf_insn_access_aux {
	enum bpf_reg_type reg_type;
	union {
		int ctx_field_size;
		struct {
			struct btf *btf;
			u32 btf_id;
		};
	};
	struct bpf_verifier_log *log;
};

struct bpf_prog_ops___7 {
	int (*test_run)(struct bpf_prog___7 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops {
	const struct bpf_func_proto * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___7 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___7 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___7 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___7 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___7 {
	struct bpf_prog___7 *prog;
	struct net_device___12 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___7 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___7 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___57 *mod;
};

struct bpf_jit_poke_descriptor___7 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___7 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___7 {
	struct btf *btf;
	struct module___57 *module;
};

struct bpf_array_aux {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___7 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_array {
	struct bpf_map___7 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_event_entry {
	struct perf_event___40 *event;
	struct file___59 *perf_file;
	struct file___59 *map_file;
	struct callback_head rcu;
};

typedef long unsigned int (*bpf_ctx_copy_t)(void *, const void *, long unsigned int, long unsigned int);

struct bpf_prog_array_item___7 {
	struct bpf_prog___7 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___7 {
	struct callback_head rcu;
	struct bpf_prog_array_item___7 items[0];
};

struct bpf_trace_run_ctx {
	struct bpf_run_ctx run_ctx;
	u64 bpf_cookie;
};

typedef u32 (*bpf_prog_run_fn)(const struct bpf_prog___7 *, const void *);

struct sk_buff___9 {
	union {
		struct {
			struct sk_buff___9 *next;
			struct sk_buff___9 *prev;
			union {
				struct net_device___12 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___9 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

typedef struct user_pt_regs bpf_user_pt_regs_t;

struct bpf_perf_event_data {
	bpf_user_pt_regs_t regs;
	__u64 sample_period;
	__u64 addr;
};

struct msghdr___6 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___30 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___58 *msg_iocb;
};

struct fwnode_operations___52;

struct fwnode_handle___52 {
	struct fwnode_handle___52 *secondary;
	const struct fwnode_operations___52 *ops;
	struct device___52 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___52;

struct fwnode_endpoint___52;

struct fwnode_operations___52 {
	struct fwnode_handle___52 * (*get)(struct fwnode_handle___52 *);
	void (*put)(struct fwnode_handle___52 *);
	bool (*device_is_available)(const struct fwnode_handle___52 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___52 *, const struct device___52 *);
	bool (*property_present)(const struct fwnode_handle___52 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___52 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___52 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___52 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*get_parent)(const struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*get_next_child_node)(const struct fwnode_handle___52 *, struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*get_named_child_node)(const struct fwnode_handle___52 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___52 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___52 *);
	struct fwnode_handle___52 * (*graph_get_next_endpoint)(const struct fwnode_handle___52 *, struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*graph_get_remote_endpoint)(const struct fwnode_handle___52 *);
	struct fwnode_handle___52 * (*graph_get_port_parent)(struct fwnode_handle___52 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___52 *, struct fwnode_endpoint___52 *);
	int (*add_links)(struct fwnode_handle___52 *);
};

struct fwnode_endpoint___52 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___52 *local_fwnode;
};

struct fwnode_reference_args___52 {
	struct fwnode_handle___52 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___6;

struct fqdir___9;

struct fib_notifier_ops___6;

struct netns_ipv4___9 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___6 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___8 *fibnl;
	struct sock___8 **icmp_sk;
	struct sock___8 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___8 **tcp_sk;
	struct fqdir___9 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___6 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___6 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___6 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___6;

struct dst_ops___9 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___9 *);
	struct dst_entry___6 * (*check)(struct dst_entry___6 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___6 *);
	unsigned int (*mtu)(const struct dst_entry___6 *);
	u32 * (*cow_metrics)(struct dst_entry___6 *, long unsigned int);
	void (*destroy)(struct dst_entry___6 *);
	void (*ifdown)(struct dst_entry___6 *, struct net_device___12 *, int);
	struct dst_entry___6 * (*negative_advice)(struct dst_entry___6 *);
	void (*link_failure)(struct sk_buff___9 *);
	void (*update_pmtu)(struct dst_entry___6 *, struct sock___8 *, struct sk_buff___9 *, u32, bool);
	void (*redirect)(struct dst_entry___6 *, struct sock___8 *, struct sk_buff___9 *);
	int (*local_out)(struct net___10 *, struct sock___8 *, struct sk_buff___9 *);
	struct neighbour___6 * (*neigh_lookup)(const struct dst_entry___6 *, struct sk_buff___9 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___6 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___9 {
	struct dst_ops___9 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___9 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___6 *fib6_rules_ops;
	struct sock___8 **icmp_sk;
	struct sock___8 *ndisc_sk;
	struct sock___8 *tcp_sk;
	struct sock___8 *igmp_sk;
	struct sock___8 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___6 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___6 *notifier_ops;
	struct fib_notifier_ops___6 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___9 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___9 *fqdir;
};

struct netns_sctp___6 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___8 *ctl_sock;
	struct sock___8 *udp4_sock;
	struct sock___8 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___7 {
	struct bpf_prog_array___7 *run_array[2];
	struct bpf_prog___7 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___9 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___8 *nlsk;
	struct sock___8 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___9 xfrm4_dst_ops;
	struct dst_ops___9 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___10 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___8 *rtnl;
	struct sock___8 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___12 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___9 ipv4;
	struct netns_ipv6___9 ipv6;
	struct netns_ieee802154_lowpan___9 ieee802154_lowpan;
	struct netns_sctp___6 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___7 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___7 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___9 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___8 *crypto_nlsk;
	struct sock___8 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___48 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___48 *root_cset;
};

struct socket_wq___6 {
	wait_queue_head_t wait;
	struct fasync_struct___58 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___6;

struct socket___6 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___59 *file;
	struct sock___8 *sk;
	const struct proto_ops___6 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___6 wq;
};

typedef int (*sk_read_actor_t___6)(read_descriptor_t *, struct sk_buff___9 *, unsigned int, size_t);

struct proto_ops___6 {
	int family;
	struct module___57 *owner;
	int (*release)(struct socket___6 *);
	int (*bind)(struct socket___6 *, struct sockaddr *, int);
	int (*connect)(struct socket___6 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___6 *, struct socket___6 *);
	int (*accept)(struct socket___6 *, struct socket___6 *, int, bool);
	int (*getname)(struct socket___6 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___59 *, struct socket___6 *, struct poll_table_struct___44 *);
	int (*ioctl)(struct socket___6 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___6 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___6 *, void *, bool, bool);
	int (*listen)(struct socket___6 *, int);
	int (*shutdown)(struct socket___6 *, int);
	int (*setsockopt)(struct socket___6 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___6 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___56 *, struct socket___6 *);
	int (*sendmsg)(struct socket___6 *, struct msghdr___6 *, size_t);
	int (*recvmsg)(struct socket___6 *, struct msghdr___6 *, size_t, int);
	int (*mmap)(struct file___59 *, struct socket___6 *, struct vm_area_struct___63 *);
	ssize_t (*sendpage)(struct socket___6 *, struct page___63 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___6 *, loff_t *, struct pipe_inode_info___19 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___8 *, int);
	int (*peek_len)(struct socket___6 *);
	int (*read_sock)(struct sock___8 *, read_descriptor_t *, sk_read_actor_t___6);
	int (*sendpage_locked)(struct sock___8 *, struct page___63 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___8 *, struct msghdr___6 *, size_t);
	int (*set_rcvlowat)(struct sock___8 *, int);
};

struct dev_pm_ops___52 {
	int (*prepare)(struct device___52 *);
	void (*complete)(struct device___52 *);
	int (*suspend)(struct device___52 *);
	int (*resume)(struct device___52 *);
	int (*freeze)(struct device___52 *);
	int (*thaw)(struct device___52 *);
	int (*poweroff)(struct device___52 *);
	int (*restore)(struct device___52 *);
	int (*suspend_late)(struct device___52 *);
	int (*resume_early)(struct device___52 *);
	int (*freeze_late)(struct device___52 *);
	int (*thaw_early)(struct device___52 *);
	int (*poweroff_late)(struct device___52 *);
	int (*restore_early)(struct device___52 *);
	int (*suspend_noirq)(struct device___52 *);
	int (*resume_noirq)(struct device___52 *);
	int (*freeze_noirq)(struct device___52 *);
	int (*thaw_noirq)(struct device___52 *);
	int (*poweroff_noirq)(struct device___52 *);
	int (*restore_noirq)(struct device___52 *);
	int (*runtime_suspend)(struct device___52 *);
	int (*runtime_resume)(struct device___52 *);
	int (*runtime_idle)(struct device___52 *);
};

struct wakeup_source___52 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___52 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___52 {
	struct dev_pm_ops___52 ops;
	int (*start)(struct device___52 *);
	void (*detach)(struct device___52 *, bool);
	int (*activate)(struct device___52 *);
	void (*sync)(struct device___52 *);
	void (*dismiss)(struct device___52 *);
};

struct bus_type___52 {
	const char *name;
	const char *dev_name;
	struct device___52 *dev_root;
	const struct attribute_group___58 **bus_groups;
	const struct attribute_group___58 **dev_groups;
	const struct attribute_group___58 **drv_groups;
	int (*match)(struct device___52 *, struct device_driver___52 *);
	int (*uevent)(struct device___52 *, struct kobj_uevent_env *);
	int (*probe)(struct device___52 *);
	void (*sync_state)(struct device___52 *);
	void (*remove)(struct device___52 *);
	void (*shutdown)(struct device___52 *);
	int (*online)(struct device___52 *);
	int (*offline)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	int (*num_vf)(struct device___52 *);
	int (*dma_configure)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___52 {
	const char *name;
	struct bus_type___52 *bus;
	struct module___57 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___52 *);
	void (*sync_state)(struct device___52 *);
	int (*remove)(struct device___52 *);
	void (*shutdown)(struct device___52 *);
	int (*suspend)(struct device___52 *, pm_message_t);
	int (*resume)(struct device___52 *);
	const struct attribute_group___58 **groups;
	const struct attribute_group___58 **dev_groups;
	const struct dev_pm_ops___52 *pm;
	void (*coredump)(struct device___52 *);
	struct driver_private *p;
};

struct device_type___52 {
	const char *name;
	const struct attribute_group___58 **groups;
	int (*uevent)(struct device___52 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___52 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___52 *);
	const struct dev_pm_ops___52 *pm;
};

struct class___52 {
	const char *name;
	struct module___57 *owner;
	const struct attribute_group___58 **class_groups;
	const struct attribute_group___58 **dev_groups;
	struct kobject___58 *dev_kobj;
	int (*dev_uevent)(struct device___52 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___52 *, umode_t *);
	void (*class_release)(struct class___52 *);
	void (*dev_release)(struct device___52 *);
	int (*shutdown_pre)(struct device___52 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___52 *);
	void (*get_ownership)(struct device___52 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___52 *pm;
	struct subsys_private *p;
};

struct property___28;

struct device_node___32 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___52 fwnode;
	struct property___28 *properties;
	struct property___28 *deadprops;
	struct device_node___32 *parent;
	struct device_node___32 *child;
	struct device_node___32 *sibling;
	struct kobject___58 kobj;
	long unsigned int _flags;
	void *data;
};

struct pipe_buf_operations___19;

struct pipe_buffer___19 {
	struct page___63 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___19 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___19 {
	int (*confirm)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
	void (*release)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
	bool (*try_steal)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
	bool (*get)(struct pipe_inode_info___19 *, struct pipe_buffer___19 *);
};

struct inet_frags___9;

struct fqdir___9 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___9 *f;
	struct net___10 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___9;

struct inet_frags___9 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___9 *, const void *);
	void (*destructor)(struct inet_frag_queue___9 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___9 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___9 *fragments_tail;
	struct sk_buff___9 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___9 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___6;

struct fib_lookup_arg___6;

struct fib_rules_ops___6 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___6 *, struct flowi *, int, struct fib_lookup_arg___6 *);
	bool (*suppress)(struct fib_rule___6 *, int, struct fib_lookup_arg___6 *);
	int (*match)(struct fib_rule___6 *, struct flowi *, int);
	int (*configure)(struct fib_rule___6 *, struct sk_buff___9 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___6 *);
	int (*compare)(struct fib_rule___6 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___6 *, struct sk_buff___9 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___6 *);
	void (*flush_cache)(struct fib_rules_ops___6 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___57 *owner;
	struct net___10 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___6 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___10 *);
	int (*fib_dump)(struct net___10 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___57 *owner;
	struct callback_head rcu;
};

struct dst_entry___6 {
	struct net_device___12 *dev;
	struct dst_ops___9 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___9 *);
	int (*output)(struct net___10 *, struct sock___8 *, struct sk_buff___9 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___6;

struct neigh_parms___6;

struct neigh_ops___6;

struct neighbour___6 {
	struct neighbour___6 *next;
	struct neigh_table___6 *tbl;
	struct neigh_parms___6 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___7 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___6 *, struct sk_buff___9 *);
	const struct neigh_ops___6 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___12 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___7 {
	int (*ieee_getets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___12 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___12 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___12 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___12 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___12 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___12 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___12 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___12 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___12 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___12 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___12 *);
	u8 (*setstate)(struct net_device___12 *, u8);
	void (*getpermhwaddr)(struct net_device___12 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___12 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___12 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___12 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___12 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___12 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___12 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___12 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___12 *, int, u8 *);
	void (*setpfccfg)(struct net_device___12 *, int, u8);
	void (*getpfccfg)(struct net_device___12 *, int, u8 *);
	u8 (*setall)(struct net_device___12 *);
	u8 (*getcap)(struct net_device___12 *, int, u8 *);
	int (*getnumtcs)(struct net_device___12 *, int, u8 *);
	int (*setnumtcs)(struct net_device___12 *, int, u8);
	u8 (*getpfcstate)(struct net_device___12 *);
	void (*setpfcstate)(struct net_device___12 *, u8);
	void (*getbcncfg)(struct net_device___12 *, int, u32 *);
	void (*setbcncfg)(struct net_device___12 *, int, u32);
	void (*getbcnrp)(struct net_device___12 *, int, u8 *);
	void (*setbcnrp)(struct net_device___12 *, int, u8);
	int (*setapp)(struct net_device___12 *, u8, u16, u8);
	int (*getapp)(struct net_device___12 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___12 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___12 *, int, u8);
	u8 (*getdcbx)(struct net_device___12 *);
	u8 (*setdcbx)(struct net_device___12 *, u8);
	int (*peer_getappinfo)(struct net_device___12 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___12 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___12 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___12 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___12 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___12 *, struct dcbnl_buffer *);
};

struct cftype___48;

struct cgroup_subsys___48 {
	struct cgroup_subsys_state___48 * (*css_alloc)(struct cgroup_subsys_state___48 *);
	int (*css_online)(struct cgroup_subsys_state___48 *);
	void (*css_offline)(struct cgroup_subsys_state___48 *);
	void (*css_released)(struct cgroup_subsys_state___48 *);
	void (*css_free)(struct cgroup_subsys_state___48 *);
	void (*css_reset)(struct cgroup_subsys_state___48 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___48 *, int);
	int (*css_extra_stat_show)(struct seq_file___56 *, struct cgroup_subsys_state___48 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___64 *, struct css_set___48 *);
	void (*cancel_fork)(struct task_struct___64 *, struct css_set___48 *);
	void (*fork)(struct task_struct___64 *);
	void (*exit)(struct task_struct___64 *);
	void (*release)(struct task_struct___64 *);
	void (*bind)(struct cgroup_subsys_state___48 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___48 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___48 *dfl_cftypes;
	struct cftype___48 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___48 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___48 *updated_children;
	struct cgroup___48 *updated_next;
};

struct cgroup_root___48 {
	struct kernfs_root___58 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___48 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___48 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___48 *ss;
	struct list_head node;
	struct kernfs_ops___58 *kf_ops;
	int (*open)(struct kernfs_open_file___58 *);
	void (*release)(struct kernfs_open_file___58 *);
	u64 (*read_u64)(struct cgroup_subsys_state___48 *, struct cftype___48 *);
	s64 (*read_s64)(struct cgroup_subsys_state___48 *, struct cftype___48 *);
	int (*seq_show)(struct seq_file___56 *, void *);
	void * (*seq_start)(struct seq_file___56 *, loff_t *);
	void * (*seq_next)(struct seq_file___56 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___56 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___48 *, struct cftype___48 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___48 *, struct cftype___48 *, s64);
	ssize_t (*write)(struct kernfs_open_file___58 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___58 *, struct poll_table_struct___44 *);
};

struct xdp_rxq_info___7 {
	struct net_device___12 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___7 {
	struct net_device___12 *dev;
};

struct xdp_buff___7 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___7 *rxq;
	struct xdp_txq_info___7 *txq;
	u32 frame_sz;
};

struct xdp_frame___7 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___12 *dev_rx;
};

struct netlink_callback___7 {
	struct sk_buff___9 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___9 *, struct netlink_callback___7 *);
	int (*done)(struct netlink_callback___7 *);
	void *data;
	struct module___57 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___7 {
	int (*create)(struct sk_buff___9 *, struct net_device___12 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___9 *, unsigned char *);
	int (*cache)(const struct neighbour___6 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___12 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___9 *);
};

struct netdev_queue___7 {
	struct net_device___12 *dev;
	struct Qdisc___7 *qdisc;
	struct Qdisc___7 *qdisc_sleeping;
	struct kobject___58 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___12 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___7 {
	struct sk_buff___9 *head;
	struct sk_buff___9 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___7;

struct Qdisc___7 {
	int (*enqueue)(struct sk_buff___9 *, struct Qdisc___7 *, struct sk_buff___9 **);
	struct sk_buff___9 * (*dequeue)(struct Qdisc___7 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___7 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___7 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___7 gso_skb;
	struct qdisc_skb_head___7 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___7 *next_sched;
	struct sk_buff_head___7 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___7 {
	struct xdp_rxq_info___7 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___58 kobj;
	struct net_device___12 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___7 {
	enum net_device_path_type type;
	const struct net_device___12 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___7 = 0,
				DEV_PATH_BR_VLAN_TAG___7 = 1,
				DEV_PATH_BR_VLAN_UNTAG___7 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___7 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___7 {
	const struct net_device___12 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___7 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___7 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___7 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___7 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___9 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___7 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___12 *dev;
	const char *name;
};

struct net_device_ops___7 {
	int (*ndo_init)(struct net_device___12 *);
	void (*ndo_uninit)(struct net_device___12 *);
	int (*ndo_open)(struct net_device___12 *);
	int (*ndo_stop)(struct net_device___12 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___9 *, struct net_device___12 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___9 *, struct net_device___12 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___12 *, struct sk_buff___9 *, struct net_device___12 *);
	void (*ndo_change_rx_flags)(struct net_device___12 *, int);
	void (*ndo_set_rx_mode)(struct net_device___12 *);
	int (*ndo_set_mac_address)(struct net_device___12 *, void *);
	int (*ndo_validate_addr)(struct net_device___12 *);
	int (*ndo_do_ioctl)(struct net_device___12 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___12 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___12 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___12 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___12 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___12 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___12 *, int);
	int (*ndo_neigh_setup)(struct net_device___12 *, struct neigh_parms___6 *);
	void (*ndo_tx_timeout)(struct net_device___12 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___12 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___12 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___12 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___12 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___12 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___12 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___12 *);
	int (*ndo_netpoll_setup)(struct net_device___12 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___12 *);
	int (*ndo_set_vf_mac)(struct net_device___12 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___12 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___12 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___12 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___12 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___12 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___12 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___12 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___12 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___12 *, int, struct sk_buff___9 *);
	int (*ndo_get_vf_guid)(struct net_device___12 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___12 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___12 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___12 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___12 *);
	int (*ndo_fcoe_disable)(struct net_device___12 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___12 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___12 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___12 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___12 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___12 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___12 *, const struct sk_buff___9 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___12 *, struct net_device___12 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___12 *, struct net_device___12 *);
	struct net_device___12 * (*ndo_get_xmit_slave)(struct net_device___12 *, struct sk_buff___9 *, bool);
	struct net_device___12 * (*ndo_sk_get_lower_dev)(struct net_device___12 *, struct sock___8 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___12 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___12 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___12 *, struct neighbour___6 *);
	void (*ndo_neigh_destroy)(struct net_device___12 *, struct neighbour___6 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___9 *, struct netlink_callback___7 *, struct net_device___12 *, struct net_device___12 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___9 *, struct nlattr **, struct net_device___12 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___12 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___9 *, u32, u32, struct net_device___12 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___12 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___12 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___12 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___12 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___12 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___12 *, struct net_device___12 *);
	void (*ndo_dfwd_del_station)(struct net_device___12 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___12 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___12 *);
	int (*ndo_change_proto_down)(struct net_device___12 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___12 *, struct sk_buff___9 *);
	void (*ndo_set_rx_headroom)(struct net_device___12 *, int);
	int (*ndo_bpf)(struct net_device___12 *, struct netdev_bpf___7 *);
	int (*ndo_xdp_xmit)(struct net_device___12 *, int, struct xdp_frame___7 **, u32);
	struct net_device___12 * (*ndo_xdp_get_xmit_slave)(struct net_device___12 *, struct xdp_buff___7 *);
	int (*ndo_xsk_wakeup)(struct net_device___12 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___12 *);
	int (*ndo_tunnel_ctl)(struct net_device___12 *, struct ip_tunnel_parm *, int);
	struct net_device___12 * (*ndo_get_peer_dev)(struct net_device___12 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___7 *, struct net_device_path___7 *);
};

struct neigh_parms___6 {
	possible_net_t___7 net;
	struct net_device___12 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___6 *);
	struct neigh_table___6 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___6 {
	u32 (*l3mdev_fib_table)(const struct net_device___12 *);
	struct sk_buff___9 * (*l3mdev_l3_rcv)(struct net_device___12 *, struct sk_buff___9 *, u16);
	struct sk_buff___9 * (*l3mdev_l3_out)(struct net_device___12 *, struct sock___8 *, struct sk_buff___9 *, u16);
	struct dst_entry___6 * (*l3mdev_link_scope_lookup)(const struct net_device___12 *, struct flowi6 *);
};

struct tcf_proto___7;

struct tcf_block___7;

struct mini_Qdisc___7 {
	struct tcf_proto___7 *filter_list;
	struct tcf_block___7 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___7 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___12 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___12 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___10 *, struct net_device___12 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___12 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___12 *, struct list_head *);
	size_t (*get_size)(const struct net_device___12 *);
	int (*fill_info)(struct sk_buff___9 *, const struct net_device___12 *);
	size_t (*get_xstats_size)(const struct net_device___12 *);
	int (*fill_xstats)(struct sk_buff___9 *, const struct net_device___12 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___12 *, struct net_device___12 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___12 *, const struct net_device___12 *);
	int (*fill_slave_info)(struct sk_buff___9 *, const struct net_device___12 *, const struct net_device___12 *);
	struct net___10 * (*get_link_net)(const struct net_device___12 *);
	size_t (*get_linkxstats_size)(const struct net_device___12 *, int);
	int (*fill_linkxstats)(struct sk_buff___9 *, const struct net_device___12 *, int *, int);
};

struct gnet_dump___7 {
	spinlock_t *lock;
	struct sk_buff___9 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___7;

struct Qdisc_ops___7 {
	struct Qdisc_ops___7 *next;
	const struct Qdisc_class_ops___7 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___9 *, struct Qdisc___7 *, struct sk_buff___9 **);
	struct sk_buff___9 * (*dequeue)(struct Qdisc___7 *);
	struct sk_buff___9 * (*peek)(struct Qdisc___7 *);
	int (*init)(struct Qdisc___7 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___7 *);
	void (*destroy)(struct Qdisc___7 *);
	int (*change)(struct Qdisc___7 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___7 *);
	int (*change_tx_queue_len)(struct Qdisc___7 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___7 *, unsigned int);
	int (*dump)(struct Qdisc___7 *, struct sk_buff___9 *);
	int (*dump_stats)(struct Qdisc___7 *, struct gnet_dump___7 *);
	void (*ingress_block_set)(struct Qdisc___7 *, u32);
	void (*egress_block_set)(struct Qdisc___7 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___7 *);
	u32 (*egress_block_get)(struct Qdisc___7 *);
	struct module___57 *owner;
};

struct Qdisc_class_ops___7 {
	unsigned int flags;
	struct netdev_queue___7 * (*select_queue)(struct Qdisc___7 *, struct tcmsg *);
	int (*graft)(struct Qdisc___7 *, long unsigned int, struct Qdisc___7 *, struct Qdisc___7 **, struct netlink_ext_ack *);
	struct Qdisc___7 * (*leaf)(struct Qdisc___7 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___7 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___7 *, u32);
	int (*change)(struct Qdisc___7 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___7 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___7 *, struct qdisc_walker *);
	struct tcf_block___7 * (*tcf_block)(struct Qdisc___7 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___7 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___7 *, long unsigned int);
	int (*dump)(struct Qdisc___7 *, long unsigned int, struct sk_buff___9 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___7 *, long unsigned int, struct gnet_dump___7 *);
};

struct tcf_chain___7;

struct tcf_block___7 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___10 *net;
	struct Qdisc___7 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___7 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___7;

struct tcf_proto_ops___7;

struct tcf_proto___7 {
	struct tcf_proto___7 *next;
	void *root;
	int (*classify)(struct sk_buff___9 *, const struct tcf_proto___7 *, struct tcf_result___7 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___7 *ops;
	struct tcf_chain___7 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___7 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___7 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___7 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___9 *, const struct tcf_proto___7 *, struct tcf_result___7 *);
	int (*init)(struct tcf_proto___7 *);
	void (*destroy)(struct tcf_proto___7 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___7 *, u32);
	void (*put)(struct tcf_proto___7 *, void *);
	int (*change)(struct net___10 *, struct sk_buff___9 *, struct tcf_proto___7 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___7 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___7 *);
	void (*walk)(struct tcf_proto___7 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___7 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___7 *, void *);
	void (*hw_del)(struct tcf_proto___7 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___10 *, struct tcf_chain___7 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___10 *, struct tcf_proto___7 *, void *, struct sk_buff___9 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___10 *, struct tcf_proto___7 *, void *, struct sk_buff___9 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___9 *, struct net___10 *, void *);
	struct module___57 *owner;
	int flags;
};

struct tcf_chain___7 {
	struct mutex filter_chain_lock;
	struct tcf_proto___7 *filter_chain;
	struct list_head list;
	struct tcf_block___7 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___7 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___6 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___7 *prog;
};

struct perf_event_query_bpf {
	__u32 ids_len;
	__u32 prog_cnt;
	__u32 ids[0];
};

struct perf_cpu_context___40;

struct perf_output_handle___40;

struct pmu___40 {
	struct list_head entry;
	struct module___57 *module;
	struct device___52 *dev;
	const struct attribute_group___58 **attr_groups;
	const struct attribute_group___58 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___40 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___40 *);
	void (*pmu_disable)(struct pmu___40 *);
	int (*event_init)(struct perf_event___40 *);
	void (*event_mapped)(struct perf_event___40 *, struct mm_struct___64 *);
	void (*event_unmapped)(struct perf_event___40 *, struct mm_struct___64 *);
	int (*add)(struct perf_event___40 *, int);
	void (*del)(struct perf_event___40 *, int);
	void (*start)(struct perf_event___40 *, int);
	void (*stop)(struct perf_event___40 *, int);
	void (*read)(struct perf_event___40 *);
	void (*start_txn)(struct pmu___40 *, unsigned int);
	int (*commit_txn)(struct pmu___40 *);
	void (*cancel_txn)(struct pmu___40 *);
	int (*event_idx)(struct perf_event___40 *);
	void (*sched_task)(struct perf_event_context___40 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___40 *, struct perf_event_context___40 *);
	void * (*setup_aux)(struct perf_event___40 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___40 *, struct perf_output_handle___40 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___40 *);
	int (*aux_output_match)(struct perf_event___40 *);
	int (*filter_match)(struct perf_event___40 *);
	int (*check_period)(struct perf_event___40 *, u64);
};

struct perf_cpu_context___40 {
	struct perf_event_context___40 ctx;
	struct perf_event_context___40 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___40 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___40 **heap;
	struct perf_event___40 *heap_default[2];
};

struct perf_output_handle___40 {
	struct perf_event___40 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___40 {
	struct cgroup_subsys_state___48 css;
	struct perf_cgroup_info *info;
};

struct bpf_perf_event_data_kern {
	bpf_user_pt_regs_t *regs;
	struct perf_sample_data___2 *data;
	struct perf_event___40 *event;
};

struct trace_array___4;

struct tracer___4;

struct array_buffer___4;

struct trace_iterator___4 {
	struct trace_array___4 *tr;
	struct tracer___4 *trace;
	struct array_buffer___4 *array_buffer;
	void *private;
	int cpu_file;
	struct mutex mutex;
	struct ring_buffer_iter **buffer_iter;
	long unsigned int iter_flags;
	void *temp;
	unsigned int temp_size;
	char *fmt;
	unsigned int fmt_size;
	struct trace_seq tmp_seq;
	cpumask_var_t started;
	bool snapshot;
	struct trace_seq seq;
	struct trace_entry *ent;
	long unsigned int lost_events;
	int leftover;
	int ent_size;
	int cpu;
	u64 ts;
	loff_t pos;
	long int idx;
};

struct array_buffer___4 {
	struct trace_array___4 *tr;
	struct trace_buffer *buffer;
	struct trace_array_cpu *data;
	u64 time_start;
	int cpu;
};

struct trace_event_file___17;

struct trace_options___4;

struct cond_snapshot___4;

struct trace_array___4 {
	struct list_head list;
	char *name;
	struct array_buffer___4 array_buffer;
	struct array_buffer___4 max_buffer;
	bool allocated_snapshot;
	long unsigned int max_latency;
	struct dentry___59 *d_max_latency;
	struct work_struct fsnotify_work;
	struct irq_work fsnotify_irqwork;
	struct trace_pid_list *filtered_pids;
	struct trace_pid_list *filtered_no_pids;
	arch_spinlock_t max_lock;
	int buffer_disabled;
	int sys_refcount_enter;
	int sys_refcount_exit;
	struct trace_event_file___17 *enter_syscall_files[449];
	struct trace_event_file___17 *exit_syscall_files[449];
	int stop_count;
	int clock_id;
	int nr_topts;
	bool clear_trace;
	int buffer_percent;
	unsigned int n_err_log_entries;
	struct tracer___4 *current_trace;
	unsigned int trace_flags;
	unsigned char trace_flags_index[32];
	unsigned int flags;
	raw_spinlock_t start_lock;
	struct list_head err_log;
	struct dentry___59 *dir;
	struct dentry___59 *options;
	struct dentry___59 *percpu_dir;
	struct dentry___59 *event_dir;
	struct trace_options___4 *topts;
	struct list_head systems;
	struct list_head events;
	struct trace_event_file___17 *trace_marker_file;
	cpumask_var_t tracing_cpumask;
	int ref;
	int trace_ref;
	struct ftrace_ops *ops;
	struct trace_pid_list *function_pids;
	struct trace_pid_list *function_no_pids;
	struct list_head func_probes;
	struct list_head mod_trace;
	struct list_head mod_notrace;
	int function_enabled;
	int no_filter_buffering_ref;
	struct list_head hist_vars;
	struct cond_snapshot___4 *cond_snapshot;
	struct trace_func_repeats *last_func_repeats;
};

struct tracer_flags___4;

struct tracer___4 {
	const char *name;
	int (*init)(struct trace_array___4 *);
	void (*reset)(struct trace_array___4 *);
	void (*start)(struct trace_array___4 *);
	void (*stop)(struct trace_array___4 *);
	int (*update_thresh)(struct trace_array___4 *);
	void (*open)(struct trace_iterator___4 *);
	void (*pipe_open)(struct trace_iterator___4 *);
	void (*close)(struct trace_iterator___4 *);
	void (*pipe_close)(struct trace_iterator___4 *);
	ssize_t (*read)(struct trace_iterator___4 *, struct file___59 *, char *, size_t, loff_t *);
	ssize_t (*splice_read)(struct trace_iterator___4 *, struct file___59 *, loff_t *, struct pipe_inode_info___19 *, size_t, unsigned int);
	void (*print_header)(struct seq_file___56 *);
	enum print_line_t (*print_line)(struct trace_iterator___4 *);
	int (*set_flag)(struct trace_array___4 *, u32, u32, int);
	int (*flag_changed)(struct trace_array___4 *, u32, int);
	struct tracer___4 *next;
	struct tracer_flags___4 *flags;
	int enabled;
	bool print_max;
	bool allow_instances;
	bool use_max_tr;
	bool noboot;
};

typedef enum print_line_t (*trace_print_func___4)(struct trace_iterator___4 *, int, struct trace_event___4 *);

struct trace_event_functions___4 {
	trace_print_func___4 trace;
	trace_print_func___4 raw;
	trace_print_func___4 hex;
	trace_print_func___4 binary;
};

struct trace_event_fields___35 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___35 *);
	};
};

struct trace_event_class___35 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___35 *, enum trace_reg, void *);
	struct trace_event_fields___35 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___35 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___35 *);
};

struct trace_event_buffer___16 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___17 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_subsystem_dir___4;

struct trace_event_file___17 {
	struct list_head list;
	struct trace_event_call___35 *event_call;
	struct event_filter *filter;
	struct dentry___59 *dir;
	struct trace_array___4 *tr;
	struct trace_subsystem_dir___4 *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_subsystem_dir___4 {
	struct list_head list;
	struct event_subsystem *subsystem;
	struct trace_array___4 *tr;
	struct dentry___59 *entry;
	int ref_count;
	int nr_events;
};

struct btf_id_set {
	u32 cnt;
	u32 ids[0];
};

struct block_device_operations___26;

struct gendisk___26 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___27 *part0;
	const struct block_device_operations___26 *fops;
	struct request_queue___27 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___25 *bdi;
	struct kobject___58 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___58 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___26 {
	struct bio___26 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___30 *bip_vec;
	struct bio_vec___30 bip_inline_vecs[0];
};

struct blkcg___25;

struct blkg_policy_data___25;

struct blkcg_gq___25 {
	struct request_queue___27 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___25 *blkcg;
	struct blkcg_gq___25 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___25 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___26 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___26(struct request___26 *);

typedef void integrity_complete_fn___26(struct request___26 *, unsigned int);

struct blk_integrity_profile___26 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___26 *prepare_fn;
	integrity_complete_fn___26 *complete_fn;
	const char *name;
};

struct block_device_operations___26 {
	blk_qc_t (*submit_bio)(struct bio___26 *);
	int (*open)(struct block_device___27 *, fmode_t);
	void (*release)(struct gendisk___26 *, fmode_t);
	int (*rw_page)(struct block_device___27 *, sector_t, struct page___63 *, unsigned int);
	int (*ioctl)(struct block_device___27 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___27 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___26 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___26 *);
	int (*getgeo)(struct block_device___27 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___27 *, bool);
	void (*swap_slot_free_notify)(struct block_device___27 *, long unsigned int);
	int (*report_zones)(struct gendisk___26 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___26 *, umode_t *);
	struct module___57 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___26 *, sector_t *);
};

typedef void rq_end_io_fn___26(struct request___26 *, blk_status_t);

struct request___26 {
	struct request_queue___27 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___25 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___26 *bio;
	struct bio___26 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___30 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___26 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___26 *saved_end_io;
		} flush;
	};
	struct gendisk___26 *rq_disk;
	struct block_device___27 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___26 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___25 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___27 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___58 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___59 *debugfs_dir;
	struct dentry___59 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___26;

struct elevator_mq_ops___26 {
	int (*init_sched)(struct request_queue___27 *, struct elevator_type___26 *);
	void (*exit_sched)(struct elevator_queue___26 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___25 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___25 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___25 *);
	bool (*allow_merge)(struct request_queue___27 *, struct request___26 *, struct bio___26 *);
	bool (*bio_merge)(struct request_queue___27 *, struct bio___26 *, unsigned int);
	int (*request_merge)(struct request_queue___27 *, struct request___26 **, struct bio___26 *);
	void (*request_merged)(struct request_queue___27 *, struct request___26 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___27 *, struct request___26 *, struct request___26 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___26 *);
	void (*finish_request)(struct request___26 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___25 *, struct list_head *, bool);
	struct request___26 * (*dispatch_request)(struct blk_mq_hw_ctx___25 *);
	bool (*has_work)(struct blk_mq_hw_ctx___25 *);
	void (*completed_request)(struct request___26 *, u64);
	void (*requeue_request)(struct request___26 *);
	struct request___26 * (*former_request)(struct request_queue___27 *, struct request___26 *);
	struct request___26 * (*next_request)(struct request_queue___27 *, struct request___26 *);
	void (*init_icq)(struct io_cq___26 *);
	void (*exit_icq)(struct io_cq___26 *);
};

struct elv_fs_entry___26;

struct elevator_type___26 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___26 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___26 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___57 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___26 {
	struct elevator_type___26 *type;
	void *elevator_data;
	struct kobject___58 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___26 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___26 *, char *);
	ssize_t (*store)(struct elevator_queue___26 *, const char *, size_t);
};

struct blk_mq_queue_data___25;

struct blk_mq_ops___25 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___25 *, const struct blk_mq_queue_data___25 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___25 *);
	int (*get_budget)(struct request_queue___27 *);
	void (*put_budget)(struct request_queue___27 *, int);
	void (*set_rq_budget_token)(struct request___26 *, int);
	int (*get_rq_budget_token)(struct request___26 *);
	enum blk_eh_timer_return (*timeout)(struct request___26 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___25 *);
	void (*complete)(struct request___26 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___25 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___25 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___25 *, struct request___26 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___25 *, struct request___26 *, unsigned int);
	void (*initialize_rq_fn)(struct request___26 *);
	void (*cleanup_rq)(struct request___26 *);
	bool (*busy)(struct request_queue___27 *);
	int (*map_queues)(struct blk_mq_tag_set___25 *);
	void (*show_rq)(struct seq_file___56 *, struct request___26 *);
};

struct blk_mq_tag_set___25 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___25 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___25 {
	struct request___26 *rq;
	bool last;
};

struct blkcg_policy_data___25;

struct blkcg___25 {
	struct cgroup_subsys_state___48 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___25 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___25 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___25 {
	struct blkcg___25 *blkcg;
	int plid;
};

struct blkg_policy_data___25 {
	struct blkcg_gq___25 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___23 {
	struct mem_cgroup___23 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___23 {
	struct lruvec___24 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___23 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___23 *memcg;
};

struct obj_cgroup___23 {
	struct percpu_ref refcnt;
	struct mem_cgroup___23 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___6;

struct neigh_hash_table___6;

struct neigh_table___6 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___12 *, __u32 *);
	bool (*key_eq)(const struct neighbour___6 *, const void *);
	int (*constructor)(struct neighbour___6 *);
	int (*pconstructor)(struct pneigh_entry___6 *);
	void (*pdestructor)(struct pneigh_entry___6 *);
	void (*proxy_redo)(struct sk_buff___9 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___12 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___6 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___7 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___6 *nht;
	struct pneigh_entry___6 **phash_buckets;
};

struct neigh_ops___6 {
	int family;
	void (*solicit)(struct neighbour___6 *, struct sk_buff___9 *);
	void (*error_report)(struct neighbour___6 *, struct sk_buff___9 *);
	int (*output)(struct neighbour___6 *, struct sk_buff___9 *);
	int (*connected_output)(struct neighbour___6 *, struct sk_buff___9 *);
};

struct pneigh_entry___6 {
	struct pneigh_entry___6 *next;
	possible_net_t___7 net;
	struct net_device___12 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___6 {
	struct neighbour___6 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___6 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___6 *ctarget;
	struct net___10 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___6 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___6 *rule;
	u32 table;
	int flags;
};

struct proto___6 {
	void (*close)(struct sock___8 *, long int);
	int (*pre_connect)(struct sock___8 *, struct sockaddr *, int);
	int (*connect)(struct sock___8 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___8 *, int);
	struct sock___8 * (*accept)(struct sock___8 *, int, int *, bool);
	int (*ioctl)(struct sock___8 *, int, long unsigned int);
	int (*init)(struct sock___8 *);
	void (*destroy)(struct sock___8 *);
	void (*shutdown)(struct sock___8 *, int);
	int (*setsockopt)(struct sock___8 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___8 *, int, int, char *, int *);
	void (*keepalive)(struct sock___8 *, int);
	int (*compat_ioctl)(struct sock___8 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___8 *, struct msghdr___6 *, size_t);
	int (*recvmsg)(struct sock___8 *, struct msghdr___6 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___8 *, struct page___63 *, int, size_t, int);
	int (*bind)(struct sock___8 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___8 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___8 *, struct sk_buff___9 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___8 *);
	int (*hash)(struct sock___8 *);
	void (*unhash)(struct sock___8 *);
	void (*rehash)(struct sock___8 *);
	int (*get_port)(struct sock___8 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___8 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___8 *, int);
	bool (*sock_is_readable)(struct sock___8 *);
	void (*enter_memory_pressure)(struct sock___8 *);
	void (*leave_memory_pressure)(struct sock___8 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___57 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___8 *, int);
};

struct bpf_local_storage_map_bucket {
	struct hlist_head list;
	raw_spinlock_t lock;
};

struct bpf_local_storage_data {
	struct bpf_local_storage_map___2 *smap;
	u8 data[0];
};

struct property___28 {
	char *name;
	int length;
	void *value;
	struct property___28 *next;
	long unsigned int _flags;
	struct bin_attribute___58 attr;
};

struct trace_option_dentry___4;

struct trace_options___4 {
	struct tracer___4 *tracer;
	struct trace_option_dentry___4 *topts;
};

struct trace_option_dentry___4 {
	struct tracer_opt *opt;
	struct tracer_flags___4 *flags;
	struct trace_array___4 *tr;
	struct dentry___59 *entry;
};

typedef bool (*cond_update_fn_t___4)(struct trace_array___4 *, void *);

struct cond_snapshot___4 {
	void *cond_data;
	cond_update_fn_t___4 update;
};

struct tracer_flags___4 {
	u32 val;
	struct tracer_opt *opts;
	struct tracer___4 *trace;
};

struct trace_event_raw_bpf_trace_printk {
	struct trace_entry ent;
	u32 __data_loc_bpf_string;
	char __data[0];
};

struct trace_event_data_offsets_bpf_trace_printk {
	u32 bpf_string;
};

typedef void (*btf_trace_bpf_trace_printk)(void *, const char *);

struct bpf_trace_module {
	struct module___57 *module;
	struct list_head list;
};

typedef u64 (*btf_bpf_override_return)(struct pt_regs *, long unsigned int);

typedef u64 (*btf_bpf_probe_read_user)(void *, u32, const void *);

typedef u64 (*btf_bpf_probe_read_user_str)(void *, u32, const void *);

typedef u64 (*btf_bpf_probe_read_kernel)(void *, u32, const void *);

typedef u64 (*btf_bpf_probe_read_kernel_str)(void *, u32, const void *);

typedef u64 (*btf_bpf_probe_read_compat)(void *, u32, const void *);

typedef u64 (*btf_bpf_probe_read_compat_str)(void *, u32, const void *);

typedef u64 (*btf_bpf_probe_write_user)(void *, const void *, u32);

typedef u64 (*btf_bpf_trace_printk)(char *, u32, u64, u64, u64);

typedef u64 (*btf_bpf_seq_printf)(struct seq_file___56 *, char *, u32, const void *, u32);

typedef u64 (*btf_bpf_seq_write)(struct seq_file___56 *, const void *, u32);

typedef u64 (*btf_bpf_seq_printf_btf)(struct seq_file___56 *, struct btf_ptr *, u32, u64);

typedef u64 (*btf_bpf_perf_event_read)(struct bpf_map___7 *, u64);

typedef u64 (*btf_bpf_perf_event_read_value)(struct bpf_map___7 *, u64, struct bpf_perf_event_value *, u32);

struct bpf_trace_sample_data {
	struct perf_sample_data___2 sds[3];
};

typedef u64 (*btf_bpf_perf_event_output)(struct pt_regs *, struct bpf_map___7 *, u64, void *, u64);

struct bpf_nested_pt_regs {
	struct pt_regs regs[3];
};

typedef u64 (*btf_bpf_get_current_task)();

typedef u64 (*btf_bpf_get_current_task_btf)();

typedef u64 (*btf_bpf_task_pt_regs)(struct task_struct___64 *);

typedef u64 (*btf_bpf_current_task_under_cgroup)(struct bpf_map___7 *, u32);

struct send_signal_irq_work {
	struct irq_work irq_work;
	struct task_struct___64 *task;
	u32 sig;
	enum pid_type type;
};

typedef u64 (*btf_bpf_send_signal)(u32);

typedef u64 (*btf_bpf_send_signal_thread)(u32);

typedef u64 (*btf_bpf_d_path)(struct path___58 *, char *, u32);

typedef u64 (*btf_bpf_snprintf_btf)(char *, u32, struct btf_ptr *, u32, u64);

typedef u64 (*btf_bpf_get_func_ip_tracing)(void *);

typedef u64 (*btf_bpf_get_func_ip_kprobe)(struct pt_regs *);

typedef u64 (*btf_bpf_get_attach_cookie_trace)(void *);

typedef u64 (*btf_bpf_get_attach_cookie_pe)(struct bpf_perf_event_data_kern *);

typedef u64 (*btf_bpf_perf_event_output_tp)(void *, struct bpf_map___7 *, u64, void *, u64);

typedef u64 (*btf_bpf_get_stackid_tp)(void *, struct bpf_map___7 *, u64);

typedef u64 (*btf_bpf_get_stack_tp)(void *, void *, u32, u64);

typedef u64 (*btf_bpf_perf_prog_read_value)(struct bpf_perf_event_data_kern *, struct bpf_perf_event_value *, u32);

typedef u64 (*btf_bpf_read_branch_records)(struct bpf_perf_event_data_kern *, void *, u32, u64);

struct bpf_raw_tp_regs {
	struct pt_regs regs[3];
};

typedef u64 (*btf_bpf_perf_event_output_raw_tp)(struct bpf_raw_tracepoint_args *, struct bpf_map___7 *, u64, void *, u64);

typedef u64 (*btf_bpf_get_stackid_raw_tp)(struct bpf_raw_tracepoint_args *, struct bpf_map___7 *, u64);

typedef u64 (*btf_bpf_get_stack_raw_tp)(struct bpf_raw_tracepoint_args *, void *, u32, u64);

struct kprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int ip;
};

struct kretprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int func;
	long unsigned int ret_ip;
};

struct trace_kprobe {
	struct dyn_event devent;
	struct kretprobe___2 rp;
	long unsigned int *nhit;
	const char *symbol;
	struct trace_probe tp;
};

enum error_detector {
	ERROR_DETECTOR_KFENCE = 0,
	ERROR_DETECTOR_KASAN = 1,
};

struct trace_event_raw_error_report_template {
	struct trace_entry ent;
	enum error_detector error_detector;
	long unsigned int id;
	char __data[0];
};

struct trace_event_data_offsets_error_report_template {};

typedef void (*btf_trace_error_report_end)(void *, enum error_detector, long unsigned int);

struct trace_event_raw_cpu {
	struct trace_entry ent;
	u32 state;
	u32 cpu_id;
	char __data[0];
};

struct trace_event_raw_powernv_throttle {
	struct trace_entry ent;
	int chip_id;
	u32 __data_loc_reason;
	int pmax;
	char __data[0];
};

struct trace_event_raw_pstate_sample {
	struct trace_entry ent;
	u32 core_busy;
	u32 scaled_busy;
	u32 from;
	u32 to;
	u64 mperf;
	u64 aperf;
	u64 tsc;
	u32 freq;
	u32 io_boost;
	char __data[0];
};

struct trace_event_raw_cpu_frequency_limits {
	struct trace_entry ent;
	u32 min_freq;
	u32 max_freq;
	u32 cpu_id;
	char __data[0];
};

struct trace_event_raw_device_pm_callback_start {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	u32 __data_loc_parent;
	u32 __data_loc_pm_ops;
	int event;
	char __data[0];
};

struct trace_event_raw_device_pm_callback_end {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	int error;
	char __data[0];
};

struct trace_event_raw_suspend_resume {
	struct trace_entry ent;
	const char *action;
	int val;
	bool start;
	char __data[0];
};

struct trace_event_raw_wakeup_source {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	char __data[0];
};

struct trace_event_raw_clock {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	u64 cpu_id;
	char __data[0];
};

struct trace_event_raw_power_domain {
	struct trace_entry ent;
	u32 __data_loc_name;
	u64 state;
	u64 cpu_id;
	char __data[0];
};

struct trace_event_raw_cpu_latency_qos_request {
	struct trace_entry ent;
	s32 value;
	char __data[0];
};

struct trace_event_raw_pm_qos_update {
	struct trace_entry ent;
	enum pm_qos_req_action action;
	int prev_value;
	int curr_value;
	char __data[0];
};

struct trace_event_raw_dev_pm_qos_request {
	struct trace_entry ent;
	u32 __data_loc_name;
	enum dev_pm_qos_req_type type;
	s32 new_value;
	char __data[0];
};

struct trace_event_data_offsets_cpu {};

struct trace_event_data_offsets_powernv_throttle {
	u32 reason;
};

struct trace_event_data_offsets_pstate_sample {};

struct trace_event_data_offsets_cpu_frequency_limits {};

struct trace_event_data_offsets_device_pm_callback_start {
	u32 device;
	u32 driver;
	u32 parent;
	u32 pm_ops;
};

struct trace_event_data_offsets_device_pm_callback_end {
	u32 device;
	u32 driver;
};

struct trace_event_data_offsets_suspend_resume {};

struct trace_event_data_offsets_wakeup_source {
	u32 name;
};

struct trace_event_data_offsets_clock {
	u32 name;
};

struct trace_event_data_offsets_power_domain {
	u32 name;
};

struct trace_event_data_offsets_cpu_latency_qos_request {};

struct trace_event_data_offsets_pm_qos_update {};

struct trace_event_data_offsets_dev_pm_qos_request {
	u32 name;
};

typedef void (*btf_trace_cpu_idle)(void *, unsigned int, unsigned int);

typedef void (*btf_trace_powernv_throttle)(void *, int, const char *, int);

typedef void (*btf_trace_pstate_sample)(void *, u32, u32, u32, u32, u64, u64, u64, u32, u32);

typedef void (*btf_trace_cpu_frequency)(void *, unsigned int, unsigned int);

typedef void (*btf_trace_cpu_frequency_limits)(void *, struct cpufreq_policy___3 *);

typedef void (*btf_trace_device_pm_callback_start)(void *, struct device___33 *, const char *, int);

typedef void (*btf_trace_device_pm_callback_end)(void *, struct device___33 *, int);

typedef void (*btf_trace_suspend_resume)(void *, const char *, int, bool);

typedef void (*btf_trace_wakeup_source_activate)(void *, const char *, unsigned int);

typedef void (*btf_trace_wakeup_source_deactivate)(void *, const char *, unsigned int);

typedef void (*btf_trace_clock_enable)(void *, const char *, unsigned int, unsigned int);

typedef void (*btf_trace_clock_disable)(void *, const char *, unsigned int, unsigned int);

typedef void (*btf_trace_clock_set_rate)(void *, const char *, unsigned int, unsigned int);

typedef void (*btf_trace_power_domain_target)(void *, const char *, unsigned int, unsigned int);

typedef void (*btf_trace_pm_qos_add_request)(void *, s32);

typedef void (*btf_trace_pm_qos_update_request)(void *, s32);

typedef void (*btf_trace_pm_qos_remove_request)(void *, s32);

typedef void (*btf_trace_pm_qos_update_target)(void *, enum pm_qos_req_action, int, int);

typedef void (*btf_trace_pm_qos_update_flags)(void *, enum pm_qos_req_action, int, int);

typedef void (*btf_trace_dev_pm_qos_add_request)(void *, const char *, enum dev_pm_qos_req_type, s32);

typedef void (*btf_trace_dev_pm_qos_update_request)(void *, const char *, enum dev_pm_qos_req_type, s32);

typedef void (*btf_trace_dev_pm_qos_remove_request)(void *, const char *, enum dev_pm_qos_req_type, s32);

struct trace_event_raw_rpm_internal {
	struct trace_entry ent;
	u32 __data_loc_name;
	int flags;
	int usage_count;
	int disable_depth;
	int runtime_auto;
	int request_pending;
	int irq_safe;
	int child_count;
	char __data[0];
};

struct trace_event_raw_rpm_return_int {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int ip;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_rpm_internal {
	u32 name;
};

struct trace_event_data_offsets_rpm_return_int {
	u32 name;
};

typedef void (*btf_trace_rpm_suspend)(void *, struct device___50 *, int);

typedef void (*btf_trace_rpm_resume)(void *, struct device___50 *, int);

typedef void (*btf_trace_rpm_idle)(void *, struct device___50 *, int);

typedef void (*btf_trace_rpm_usage)(void *, struct device___50 *, int);

typedef void (*btf_trace_rpm_return_int)(void *, struct device___50 *, long unsigned int, int);

struct trace_probe_log {
	const char *subsystem;
	const char **argv;
	int argc;
	int index;
};

enum uprobe_filter_ctx {
	UPROBE_FILTER_REGISTER = 0,
	UPROBE_FILTER_UNREGISTER = 1,
	UPROBE_FILTER_MMAP = 2,
};

struct uprobe_consumer {
	int (*handler)(struct uprobe_consumer *, struct pt_regs *);
	int (*ret_handler)(struct uprobe_consumer *, long unsigned int, struct pt_regs *);
	bool (*filter)(struct uprobe_consumer *, enum uprobe_filter_ctx, struct mm_struct___62 *);
	struct uprobe_consumer *next;
};

struct uprobe_trace_entry_head {
	struct trace_entry ent;
	long unsigned int vaddr[0];
};

struct trace_uprobe {
	struct dyn_event devent;
	struct uprobe_consumer consumer;
	struct path___56 path;
	struct inode___57 *inode;
	char *filename;
	long unsigned int offset;
	long unsigned int ref_ctr_offset;
	long unsigned int nhit;
	struct trace_probe tp;
};

struct uprobe_dispatch_data {
	struct trace_uprobe *tu;
	long unsigned int bp_addr;
};

struct uprobe_cpu_buffer {
	struct mutex mutex;
	void *buf;
};

typedef bool (*filter_func_t)(struct uprobe_consumer *, enum uprobe_filter_ctx, struct mm_struct___62 *);

struct dentry___60;

struct super_block___60;

struct module___58;

struct file_system_type___59 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___60 * (*mount)(struct file_system_type___59 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___60 *);
	struct module___58 *owner;
	struct file_system_type___59 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___60;

struct kiocb___59;

struct iov_iter___31;

struct poll_table_struct___45;

struct vm_area_struct___64;

struct inode___60;

struct file_lock___59;

struct page___64;

struct pipe_inode_info___20;

struct seq_file___57;

struct file_operations___59 {
	struct module___58 *owner;
	loff_t (*llseek)(struct file___60 *, loff_t, int);
	ssize_t (*read)(struct file___60 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___60 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___59 *, struct iov_iter___31 *);
	ssize_t (*write_iter)(struct kiocb___59 *, struct iov_iter___31 *);
	int (*iopoll)(struct kiocb___59 *, bool);
	int (*iterate)(struct file___60 *, struct dir_context *);
	int (*iterate_shared)(struct file___60 *, struct dir_context *);
	__poll_t (*poll)(struct file___60 *, struct poll_table_struct___45 *);
	long int (*unlocked_ioctl)(struct file___60 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___60 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___60 *, struct vm_area_struct___64 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___60 *, struct file___60 *);
	int (*flush)(struct file___60 *, fl_owner_t);
	int (*release)(struct inode___60 *, struct file___60 *);
	int (*fsync)(struct file___60 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___60 *, int);
	int (*lock)(struct file___60 *, int, struct file_lock___59 *);
	ssize_t (*sendpage)(struct file___60 *, struct page___64 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___60 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___60 *, long unsigned int);
	int (*flock)(struct file___60 *, int, struct file_lock___59 *);
	ssize_t (*splice_write)(struct pipe_inode_info___20 *, struct file___60 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___60 *, loff_t *, struct pipe_inode_info___20 *, size_t, unsigned int);
	int (*setlease)(struct file___60 *, long int, struct file_lock___59 **, void **);
	long int (*fallocate)(struct file___60 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___57 *, struct file___60 *);
	ssize_t (*copy_file_range)(struct file___60 *, loff_t, struct file___60 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___60 *, loff_t, struct file___60 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___60 *, loff_t, loff_t, int);
};

struct vmacache___64 {
	u64 seqnum;
	struct vm_area_struct___64 *vmas[4];
};

struct page_frag___64 {
	struct page___64 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___41;

struct debug_info___41 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___41 *hbp_break[16];
	struct perf_event___41 *hbp_watch[16];
};

struct thread_struct___41 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___41 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___65;

struct pid___53;

struct nsproxy___58;

struct signal_struct___60;

struct css_set___49;

struct perf_event_context___41;

struct vm_struct___61;

struct task_struct___65 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___65 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___65 *mm;
	struct mm_struct___65 *active_mm;
	struct vmacache___64 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___65 *real_parent;
	struct task_struct___65 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___65 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___53 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___58 *nsproxy;
	struct signal_struct___60 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___65 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___27 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___49 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___41 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___20 *splice_pipe;
	struct page_frag___64 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___65 *oom_reaper_list;
	struct vm_struct___61 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___41 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___59;

struct kobj_type___59;

struct kernfs_node___59;

struct kobject___59 {
	const char *name;
	struct list_head entry;
	struct kobject___59 *parent;
	struct kset___59 *kset;
	struct kobj_type___59 *ktype;
	struct kernfs_node___59 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___56 {
	struct kobject___59 kobj;
	struct module___58 *mod;
	struct kobject___59 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___56 {
	struct module___58 *mod;
	struct latch_tree_node node;
};

struct module_layout___56 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___56 mtn;
};

struct module_attribute___56;

struct kernel_param___56;

struct trace_event_call___36;

struct module___58 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___56 mkobj;
	struct module_attribute___56 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___59 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___56 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___56 core_layout;
	struct module_layout___56 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___36 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rnd_state {
	__u32 s1;
	__u32 s2;
	__u32 s3;
	__u32 s4;
};

struct hw_perf_event___41 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___65 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___41)(struct perf_event___41 *, struct perf_sample_data___3 *, struct pt_regs *);

struct pmu___41;

struct fasync_struct___59;

struct pid_namespace___53;

struct bpf_prog___8;

struct perf_cgroup___41;

struct perf_event___41 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___41 *group_leader;
	struct pmu___41 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___41 hw;
	struct perf_event_context___41 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___41 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___65 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___59 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___41 *aux_event;
	void (*destroy)(struct perf_event___41 *);
	struct callback_head callback_head;
	struct pid_namespace___53 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___41 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___41 orig_overflow_handler;
	struct bpf_prog___8 *prog;
	u64 bpf_cookie;
	struct trace_event_call___36 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___41 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___53 {
	int nr;
	struct pid_namespace___53 *ns;
};

struct pid_namespace___53 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___65 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___53 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___53 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___53 numbers[1];
};

struct rhash_lock_head;

struct bucket_table {
	unsigned int size;
	unsigned int nest;
	u32 hash_rnd;
	struct list_head walkers;
	struct callback_head rcu;
	struct bucket_table *future_tbl;
	struct lockdep_map dep_map;
	long: 64;
	struct rhash_lock_head *buckets[0];
};

typedef struct page___64 *pgtable_t___64;

struct address_space___59;

struct page_pool___17;

struct dev_pagemap___58;

struct page___64 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___59 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___17 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___64 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___64 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___65 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___58 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___58;

struct vm_area_struct___64 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___64 *vm_next;
	struct vm_area_struct___64 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___65 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___58 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___60 *vm_file;
	struct file___60 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___60 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___65 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___65 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___53 *pids[4];
	struct pid___53 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___65 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___64;

struct mm_struct___65 {
	struct {
		struct vm_area_struct___64 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___60 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___64 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___65 *owner;
		struct user_namespace___10 *user_ns;
		struct file___60 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___11;

struct cgroup_namespace___49;

struct nsproxy___58 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___53 *pid_ns_for_children;
	struct net___11 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___49 *cgroup_ns;
};

struct cgroup_subsys_state___49;

struct cgroup___49;

struct css_set___49 {
	struct cgroup_subsys_state___49 *subsys[14];
	refcount_t refcount;
	struct css_set___49 *dom_cset;
	struct cgroup___49 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___49 *mg_src_cgrp;
	struct cgroup___49 *mg_dst_cgrp;
	struct css_set___49 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___41 {
	struct pmu___41 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___65 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___41 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___20;

struct pipe_inode_info___20 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___64 *tmp_page;
	struct fasync_struct___59 *fasync_readers;
	struct fasync_struct___59 *fasync_writers;
	struct pipe_buffer___20 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___61 {
	struct vm_struct___61 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___64 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___31 {
	struct page___64 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___31 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___31 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___20 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct kiocb___59 {
	struct file___60 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___59 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct dentry_operations___59;

struct dentry___60 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___60 *d_parent;
	struct qstr d_name;
	struct inode___60 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___59 *d_op;
	struct super_block___60 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___59;

struct address_space___59 {
	struct inode___60 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___59 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___59;

struct inode___60 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___59 *i_op;
	struct super_block___60 *i_sb;
	struct address_space___59 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___59 *i_fop;
		void (*free_inode)(struct inode___60 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___59 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___20 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___59;

struct path___59;

struct dentry_operations___59 {
	int (*d_revalidate)(struct dentry___60 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___60 *, unsigned int);
	int (*d_hash)(const struct dentry___60 *, struct qstr *);
	int (*d_compare)(const struct dentry___60 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___60 *);
	int (*d_init)(struct dentry___60 *);
	void (*d_release)(struct dentry___60 *);
	void (*d_prune)(struct dentry___60 *);
	void (*d_iput)(struct dentry___60 *, struct inode___60 *);
	char * (*d_dname)(struct dentry___60 *, char *, int);
	struct vfsmount___59 * (*d_automount)(struct path___59 *);
	int (*d_manage)(const struct path___59 *, bool);
	struct dentry___60 * (*d_real)(struct dentry___60 *, const struct inode___60 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___59;

struct mem_dqinfo___59 {
	struct quota_format_type___59 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___59;

struct quota_info___59 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___60 *files[3];
	struct mem_dqinfo___59 info[3];
	const struct quota_format_ops___59 *ops[3];
};

struct rcuwait___60 {
	struct task_struct___65 *task;
};

struct percpu_rw_semaphore___60 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___60 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___59 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___60 rw_sem[3];
};

struct super_operations___59;

struct dquot_operations___59;

struct quotactl_ops___59;

struct super_block___60 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___59 *s_type;
	const struct super_operations___59 *s_op;
	const struct dquot_operations___59 *dq_op;
	const struct quotactl_ops___59 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___60 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___59 s_dquot;
	struct sb_writers___59 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___59 *s_d_op;
	int cleancache_poolid;
	struct shrinker___23 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___59 {
	struct dentry___60 *mnt_root;
	struct super_block___60 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct path___59 {
	struct vfsmount___59 *mnt;
	struct dentry___60 *dentry;
};

struct device___53;

struct page_pool_params___17 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___53 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___17 {
	u32 count;
	struct page___64 *cache[128];
};

struct page_pool___17 {
	struct page_pool_params___17 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___64 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___17 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___58;

struct dev_pagemap___58 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___58 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___53 {
	rwlock_t lock;
	struct pid___53 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___60 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___59 f_path;
	struct inode___60 *f_inode;
	const struct file_operations___59 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___53 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___59 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___58;

struct vm_operations_struct___58 {
	void (*open)(struct vm_area_struct___64 *);
	void (*close)(struct vm_area_struct___64 *);
	int (*may_split)(struct vm_area_struct___64 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___64 *);
	int (*mprotect)(struct vm_area_struct___64 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___58 *);
	vm_fault_t (*huge_fault)(struct vm_fault___58 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___58 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___64 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___58 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___58 *);
	int (*access)(struct vm_area_struct___64 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___64 *);
	int (*set_policy)(struct vm_area_struct___64 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___64 *, long unsigned int);
	struct page___64 * (*find_special_page)(struct vm_area_struct___64 *, long unsigned int);
};

struct core_thread___64 {
	struct task_struct___65 *task;
	struct core_thread___64 *next;
};

struct core_state___64 {
	atomic_t nr_threads;
	struct core_thread___64 dumper;
	struct completion startup;
};

struct vm_fault___58 {
	const struct {
		struct vm_area_struct___64 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___64 *cow_page;
	struct page___64 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___64 prealloc_pte;
};

struct cgroup_subsys___49;

struct cgroup_subsys_state___49 {
	struct cgroup___49 *cgroup;
	struct cgroup_subsys___49 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___49 *parent;
};

struct cgroup_file___49 {
	struct kernfs_node___59 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___49 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___65 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___8;

struct cgroup_bpf___8 {
	struct bpf_prog_array___8 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___8 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___49;

struct cgroup_rstat_cpu___49;

struct cgroup___49 {
	struct cgroup_subsys_state___49 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___59 *kn;
	struct cgroup_file___49 procs_file;
	struct cgroup_file___49 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___49 *subsys[14];
	struct cgroup_root___49 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___49 *dom_cgrp;
	struct cgroup___49 *old_dom_cgrp;
	struct cgroup_rstat_cpu___49 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___49 psi;
	struct cgroup_bpf___8 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___60 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___60 *ia_file;
};

struct dquot___59 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___60 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___59 {
	int qf_fmt_id;
	const struct quota_format_ops___59 *qf_ops;
	struct module___58 *qf_owner;
	struct quota_format_type___59 *qf_next;
};

struct quota_format_ops___59 {
	int (*check_quota_file)(struct super_block___60 *, int);
	int (*read_file_info)(struct super_block___60 *, int);
	int (*write_file_info)(struct super_block___60 *, int);
	int (*free_file_info)(struct super_block___60 *, int);
	int (*read_dqblk)(struct dquot___59 *);
	int (*commit_dqblk)(struct dquot___59 *);
	int (*release_dqblk)(struct dquot___59 *);
	int (*get_next_id)(struct super_block___60 *, struct kqid *);
};

struct dquot_operations___59 {
	int (*write_dquot)(struct dquot___59 *);
	struct dquot___59 * (*alloc_dquot)(struct super_block___60 *, int);
	void (*destroy_dquot)(struct dquot___59 *);
	int (*acquire_dquot)(struct dquot___59 *);
	int (*release_dquot)(struct dquot___59 *);
	int (*mark_dirty)(struct dquot___59 *);
	int (*write_info)(struct super_block___60 *, int);
	qsize_t * (*get_reserved_space)(struct inode___60 *);
	int (*get_projid)(struct inode___60 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___60 *, qsize_t *);
	int (*get_next_id)(struct super_block___60 *, struct kqid *);
};

struct quotactl_ops___59 {
	int (*quota_on)(struct super_block___60 *, int, int, const struct path___59 *);
	int (*quota_off)(struct super_block___60 *, int);
	int (*quota_enable)(struct super_block___60 *, unsigned int);
	int (*quota_disable)(struct super_block___60 *, unsigned int);
	int (*quota_sync)(struct super_block___60 *, int);
	int (*set_info)(struct super_block___60 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___60 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___60 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___60 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___60 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___60 *, unsigned int);
};

struct address_space_operations___59 {
	int (*writepage)(struct page___64 *, struct writeback_control___3 *);
	int (*readpage)(struct file___60 *, struct page___64 *);
	int (*writepages)(struct address_space___59 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___64 *);
	int (*readpages)(struct file___60 *, struct address_space___59 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___60 *, struct address_space___59 *, loff_t, unsigned int, unsigned int, struct page___64 **, void **);
	int (*write_end)(struct file___60 *, struct address_space___59 *, loff_t, unsigned int, unsigned int, struct page___64 *, void *);
	sector_t (*bmap)(struct address_space___59 *, sector_t);
	void (*invalidatepage)(struct page___64 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___64 *, gfp_t);
	void (*freepage)(struct page___64 *);
	ssize_t (*direct_IO)(struct kiocb___59 *, struct iov_iter___31 *);
	int (*migratepage)(struct address_space___59 *, struct page___64 *, struct page___64 *, enum migrate_mode);
	bool (*isolate_page)(struct page___64 *, isolate_mode_t);
	void (*putback_page)(struct page___64 *);
	int (*launder_page)(struct page___64 *);
	int (*is_partially_uptodate)(struct page___64 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___64 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___59 *, struct page___64 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___60 *, sector_t *);
	void (*swap_deactivate)(struct file___60 *);
};

struct inode_operations___59 {
	struct dentry___60 * (*lookup)(struct inode___60 *, struct dentry___60 *, unsigned int);
	const char * (*get_link)(struct dentry___60 *, struct inode___60 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___60 *, int);
	struct posix_acl * (*get_acl)(struct inode___60 *, int, bool);
	int (*readlink)(struct dentry___60 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___60 *, struct dentry___60 *, umode_t, bool);
	int (*link)(struct dentry___60 *, struct inode___60 *, struct dentry___60 *);
	int (*unlink)(struct inode___60 *, struct dentry___60 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___60 *, struct dentry___60 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___60 *, struct dentry___60 *, umode_t);
	int (*rmdir)(struct inode___60 *, struct dentry___60 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___60 *, struct dentry___60 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___60 *, struct dentry___60 *, struct inode___60 *, struct dentry___60 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___60 *, struct iattr___60 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___59 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___60 *, char *, size_t);
	int (*fiemap)(struct inode___60 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___60 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___60 *, struct dentry___60 *, struct file___60 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___60 *, struct dentry___60 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___60 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___60 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___60 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___59 {
	void (*fl_copy_lock)(struct file_lock___59 *, struct file_lock___59 *);
	void (*fl_release_private)(struct file_lock___59 *);
};

struct lock_manager_operations___59;

struct file_lock___59 {
	struct file_lock___59 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___60 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___59 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___59 *fl_ops;
	const struct lock_manager_operations___59 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___59 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___59 *);
	int (*lm_grant)(struct file_lock___59 *, int);
	bool (*lm_break)(struct file_lock___59 *);
	int (*lm_change)(struct file_lock___59 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___59 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___59 *);
};

struct fasync_struct___59 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___59 *fa_next;
	struct file___60 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___59 {
	struct inode___60 * (*alloc_inode)(struct super_block___60 *);
	void (*destroy_inode)(struct inode___60 *);
	void (*free_inode)(struct inode___60 *);
	void (*dirty_inode)(struct inode___60 *, int);
	int (*write_inode)(struct inode___60 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___60 *);
	void (*evict_inode)(struct inode___60 *);
	void (*put_super)(struct super_block___60 *);
	int (*sync_fs)(struct super_block___60 *, int);
	int (*freeze_super)(struct super_block___60 *);
	int (*freeze_fs)(struct super_block___60 *);
	int (*thaw_super)(struct super_block___60 *);
	int (*unfreeze_fs)(struct super_block___60 *);
	int (*statfs)(struct dentry___60 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___60 *, int *, char *);
	void (*umount_begin)(struct super_block___60 *);
	int (*show_options)(struct seq_file___57 *, struct dentry___60 *);
	int (*show_devname)(struct seq_file___57 *, struct dentry___60 *);
	int (*show_path)(struct seq_file___57 *, struct dentry___60 *);
	int (*show_stats)(struct seq_file___57 *, struct dentry___60 *);
	ssize_t (*quota_read)(struct super_block___60 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___60 *, int, const char *, size_t, loff_t);
	struct dquot___59 ** (*get_dquots)(struct inode___60 *);
	long int (*nr_cached_objects)(struct super_block___60 *, struct shrink_control___23 *);
	long int (*free_cached_objects)(struct super_block___60 *, struct shrink_control___23 *);
	struct file___60 * (*real_loop)(struct file___60 *);
};

typedef void (*poll_queue_proc___45)(struct file___60 *, wait_queue_head_t *, struct poll_table_struct___45 *);

struct poll_table_struct___45 {
	poll_queue_proc___45 _qproc;
	__poll_t _key;
};

struct seq_operations___57;

struct seq_file___57 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___57 *op;
	int poll_event;
	const struct file___60 *file;
	void *private;
};

struct dev_pagemap_ops___58 {
	void (*page_free)(struct page___64 *);
	void (*kill)(struct dev_pagemap___58 *);
	void (*cleanup)(struct dev_pagemap___58 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___58 *);
};

struct fwnode_operations___53;

struct fwnode_handle___53 {
	struct fwnode_handle___53 *secondary;
	const struct fwnode_operations___53 *ops;
	struct device___53 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___53;

struct fwnode_endpoint___53;

struct fwnode_operations___53 {
	struct fwnode_handle___53 * (*get)(struct fwnode_handle___53 *);
	void (*put)(struct fwnode_handle___53 *);
	bool (*device_is_available)(const struct fwnode_handle___53 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___53 *, const struct device___53 *);
	bool (*property_present)(const struct fwnode_handle___53 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___53 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___53 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___53 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*get_parent)(const struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*get_next_child_node)(const struct fwnode_handle___53 *, struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*get_named_child_node)(const struct fwnode_handle___53 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___53 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___53 *);
	struct fwnode_handle___53 * (*graph_get_next_endpoint)(const struct fwnode_handle___53 *, struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*graph_get_remote_endpoint)(const struct fwnode_handle___53 *);
	struct fwnode_handle___53 * (*graph_get_port_parent)(struct fwnode_handle___53 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___53 *, struct fwnode_endpoint___53 *);
	int (*add_links)(struct fwnode_handle___53 *);
};

struct wakeup_source___53;

struct dev_pm_info___53 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___53 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___53 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___53;

struct bus_type___53;

struct device_driver___53;

struct dev_pm_domain___53;

struct class___53;

struct attribute_group___59;

struct device___53 {
	struct kobject___59 kobj;
	struct device___53 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___53 *type;
	struct bus_type___53 *bus;
	struct device_driver___53 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___53 power;
	struct dev_pm_domain___53 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___53 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___53 *class;
	const struct attribute_group___59 **groups;
	void (*release)(struct device___53 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___53 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___53 *local_fwnode;
};

struct fwnode_reference_args___53 {
	struct fwnode_handle___53 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___59;

struct kernfs_elem_dir___59 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___59 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___59;

struct kernfs_root___59 {
	struct kernfs_node___59 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___59 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___59 {
	struct kernfs_node___59 *target_kn;
};

struct kernfs_ops___59;

struct kernfs_elem_attr___59 {
	const struct kernfs_ops___59 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___59 *notify_next;
};

struct kernfs_node___59 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___59 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___59 dir;
		struct kernfs_elem_symlink___59 symlink;
		struct kernfs_elem_attr___59 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___59;

struct kernfs_ops___59 {
	int (*open)(struct kernfs_open_file___59 *);
	void (*release)(struct kernfs_open_file___59 *);
	int (*seq_show)(struct seq_file___57 *, void *);
	void * (*seq_start)(struct seq_file___57 *, loff_t *);
	void * (*seq_next)(struct seq_file___57 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___57 *, void *);
	ssize_t (*read)(struct kernfs_open_file___59 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___59 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___59 *, struct poll_table_struct___45 *);
	int (*mmap)(struct kernfs_open_file___59 *, struct vm_area_struct___64 *);
};

struct kernfs_syscall_ops___59 {
	int (*show_options)(struct seq_file___57 *, struct kernfs_root___59 *);
	int (*mkdir)(struct kernfs_node___59 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___59 *);
	int (*rename)(struct kernfs_node___59 *, struct kernfs_node___59 *, const char *);
	int (*show_path)(struct seq_file___57 *, struct kernfs_node___59 *, struct kernfs_root___59 *);
};

struct kernfs_open_file___59 {
	struct kernfs_node___59 *kn;
	struct file___60 *file;
	struct seq_file___57 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___58 *vm_ops;
};

struct bin_attribute___59;

struct attribute_group___59 {
	const char *name;
	umode_t (*is_visible)(struct kobject___59 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___59 *, struct bin_attribute___59 *, int);
	struct attribute **attrs;
	struct bin_attribute___59 **bin_attrs;
};

struct bin_attribute___59 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___59 * (*f_mapping)();
	ssize_t (*read)(struct file___60 *, struct kobject___59 *, struct bin_attribute___59 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___60 *, struct kobject___59 *, struct bin_attribute___59 *, char *, loff_t, size_t);
	int (*mmap)(struct file___60 *, struct kobject___59 *, struct bin_attribute___59 *, struct vm_area_struct___64 *);
};

struct sysfs_ops___59 {
	ssize_t (*show)(struct kobject___59 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___59 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___59;

struct kset___59 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___59 kobj;
	const struct kset_uevent_ops___59 *uevent_ops;
};

struct kobj_type___59 {
	void (*release)(struct kobject___59 *);
	const struct sysfs_ops___59 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___59 **default_groups;
	const struct kobj_ns_type_operations___6 * (*child_ns_type)(struct kobject___59 *);
	const void * (*namespace)(struct kobject___59 *);
	void (*get_ownership)(struct kobject___59 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___59 {
	int (* const filter)(struct kset___59 *, struct kobject___59 *);
	const char * (* const name)(struct kset___59 *, struct kobject___59 *);
	int (* const uevent)(struct kset___59 *, struct kobject___59 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___56 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___56 *);
	int (*get)(char *, const struct kernel_param___56 *);
	void (*free)(void *);
};

struct kparam_array___56;

struct kernel_param___56 {
	const char *name;
	struct module___58 *mod;
	const struct kernel_param_ops___56 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___56 *arr;
	};
};

struct kparam_array___56 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___56 *ops;
	void *elem;
};

struct module_attribute___56 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___56 *, struct module_kobject___56 *, char *);
	ssize_t (*store)(struct module_attribute___56 *, struct module_kobject___56 *, const char *, size_t);
	void (*setup)(struct module___58 *, const char *);
	int (*test)(struct module___58 *);
	void (*free)(struct module___58 *);
};

struct trace_event_class___36;

struct trace_event_call___36 {
	struct list_head list;
	struct trace_event_class___36 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___8 *prog_array;
	int (*perf_perm)(struct trace_event_call___36 *, struct perf_event___41 *);
};

struct fqdir___10;

struct netns_ipv4___10 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___10 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___13;

struct sk_buff___10;

struct dst_ops___10 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___10 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___13 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___10 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___10 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___10 *);
	int (*local_out)(struct net___11 *, struct sock *, struct sk_buff___10 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___10 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___10 {
	struct dst_ops___10 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___10 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___10 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___10 *fqdir;
};

struct sk_buff_head___8 {
	struct sk_buff___10 *next;
	struct sk_buff___10 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___8 {
	struct bpf_prog_array___8 *run_array[2];
	struct bpf_prog___8 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___10 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___10 xfrm4_dst_ops;
	struct dst_ops___10 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___11 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___13 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___10 ipv4;
	struct netns_ipv6___10 ipv6;
	struct netns_ieee802154_lowpan___10 ieee802154_lowpan;
	struct netns_sctp___6 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___8 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___8 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___10 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___49 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___49 *root_cset;
};

struct sk_buff___10 {
	union {
		struct {
			struct sk_buff___10 *next;
			struct sk_buff___10 *prev;
			union {
				struct net_device___13 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___10 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___53 {
	int (*prepare)(struct device___53 *);
	void (*complete)(struct device___53 *);
	int (*suspend)(struct device___53 *);
	int (*resume)(struct device___53 *);
	int (*freeze)(struct device___53 *);
	int (*thaw)(struct device___53 *);
	int (*poweroff)(struct device___53 *);
	int (*restore)(struct device___53 *);
	int (*suspend_late)(struct device___53 *);
	int (*resume_early)(struct device___53 *);
	int (*freeze_late)(struct device___53 *);
	int (*thaw_early)(struct device___53 *);
	int (*poweroff_late)(struct device___53 *);
	int (*restore_early)(struct device___53 *);
	int (*suspend_noirq)(struct device___53 *);
	int (*resume_noirq)(struct device___53 *);
	int (*freeze_noirq)(struct device___53 *);
	int (*thaw_noirq)(struct device___53 *);
	int (*poweroff_noirq)(struct device___53 *);
	int (*restore_noirq)(struct device___53 *);
	int (*runtime_suspend)(struct device___53 *);
	int (*runtime_resume)(struct device___53 *);
	int (*runtime_idle)(struct device___53 *);
};

struct wakeup_source___53 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___53 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___53 {
	struct dev_pm_ops___53 ops;
	int (*start)(struct device___53 *);
	void (*detach)(struct device___53 *, bool);
	int (*activate)(struct device___53 *);
	void (*sync)(struct device___53 *);
	void (*dismiss)(struct device___53 *);
};

struct bus_type___53 {
	const char *name;
	const char *dev_name;
	struct device___53 *dev_root;
	const struct attribute_group___59 **bus_groups;
	const struct attribute_group___59 **dev_groups;
	const struct attribute_group___59 **drv_groups;
	int (*match)(struct device___53 *, struct device_driver___53 *);
	int (*uevent)(struct device___53 *, struct kobj_uevent_env *);
	int (*probe)(struct device___53 *);
	void (*sync_state)(struct device___53 *);
	void (*remove)(struct device___53 *);
	void (*shutdown)(struct device___53 *);
	int (*online)(struct device___53 *);
	int (*offline)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	int (*num_vf)(struct device___53 *);
	int (*dma_configure)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___53 {
	const char *name;
	struct bus_type___53 *bus;
	struct module___58 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___53 *);
	void (*sync_state)(struct device___53 *);
	int (*remove)(struct device___53 *);
	void (*shutdown)(struct device___53 *);
	int (*suspend)(struct device___53 *, pm_message_t);
	int (*resume)(struct device___53 *);
	const struct attribute_group___59 **groups;
	const struct attribute_group___59 **dev_groups;
	const struct dev_pm_ops___53 *pm;
	void (*coredump)(struct device___53 *);
	struct driver_private *p;
};

struct device_type___53 {
	const char *name;
	const struct attribute_group___59 **groups;
	int (*uevent)(struct device___53 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___53 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___53 *);
	const struct dev_pm_ops___53 *pm;
};

struct class___53 {
	const char *name;
	struct module___58 *owner;
	const struct attribute_group___59 **class_groups;
	const struct attribute_group___59 **dev_groups;
	struct kobject___59 *dev_kobj;
	int (*dev_uevent)(struct device___53 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___53 *, umode_t *);
	void (*class_release)(struct class___53 *);
	void (*dev_release)(struct device___53 *);
	int (*shutdown_pre)(struct device___53 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___53 *);
	void (*get_ownership)(struct device___53 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___53 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___20;

struct pipe_buffer___20 {
	struct page___64 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___20 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___20 {
	int (*confirm)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
	void (*release)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
	bool (*try_steal)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
	bool (*get)(struct pipe_inode_info___20 *, struct pipe_buffer___20 *);
};

typedef rx_handler_result_t rx_handler_func_t___8(struct sk_buff___10 **);

typedef struct {
	struct net___11 *net;
} possible_net_t___8;

struct bpf_xdp_entity___8 {
	struct bpf_prog___8 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___8;

struct net_device_ops___8;

struct xfrmdev_ops___8;

struct header_ops___8;

struct netdev_rx_queue___8;

struct mini_Qdisc___8;

struct netdev_queue___8;

struct Qdisc___8;

struct rtnl_link_ops___8;

struct dcbnl_rtnl_ops___8;

struct net_device___13 {
	char name[16];
	struct netdev_name_node___8 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___8 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___8 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___8 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___59 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___8 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___8 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___8 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___8 *miniq_ingress;
	struct netdev_queue___8 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___8 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___8 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___8 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___8 = 0,
		NETREG_REGISTERED___8 = 1,
		NETREG_UNREGISTERING___8 = 2,
		NETREG_UNREGISTERED___8 = 3,
		NETREG_RELEASED___8 = 4,
		NETREG_DUMMY___8 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___8 = 0,
		RTNL_LINK_INITIALIZING___8 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___13 *);
	struct netpoll_info *npinfo;
	possible_net_t___8 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___53 dev;
	const struct attribute_group___59 *sysfs_groups[4];
	const struct attribute_group___59 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___8 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___8 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___8 xdp_state[3];
	long: 64;
};

struct inet_frags___10;

struct fqdir___10 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___10 *f;
	struct net___11 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___10;

struct inet_frags___10 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___10 *, const void *);
	void (*destructor)(struct inet_frag_queue___10 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___10 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___10 *fragments_tail;
	struct sk_buff___10 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___10 *fqdir;
	struct callback_head rcu;
};

enum xdp_action {
	XDP_ABORTED = 0,
	XDP_DROP = 1,
	XDP_PASS = 2,
	XDP_TX = 3,
	XDP_REDIRECT = 4,
};

struct bpf_prog_array_item___8 {
	struct bpf_prog___8 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___8 {
	struct callback_head rcu;
	struct bpf_prog_array_item___8 items[0];
};

struct bpf_prog_aux___8;

struct bpf_prog___8 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___8 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___57 {
	void * (*start)(struct seq_file___57 *, loff_t *);
	void (*stop)(struct seq_file___57 *, void *);
	void * (*next)(struct seq_file___57 *, void *, loff_t *);
	int (*show)(struct seq_file___57 *, void *);
};

struct dcbnl_rtnl_ops___8 {
	int (*ieee_getets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___13 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___13 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___13 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___13 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___13 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___13 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___13 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___13 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___13 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___13 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___13 *);
	u8 (*setstate)(struct net_device___13 *, u8);
	void (*getpermhwaddr)(struct net_device___13 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___13 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___13 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___13 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___13 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___13 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___13 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___13 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___13 *, int, u8 *);
	void (*setpfccfg)(struct net_device___13 *, int, u8);
	void (*getpfccfg)(struct net_device___13 *, int, u8 *);
	u8 (*setall)(struct net_device___13 *);
	u8 (*getcap)(struct net_device___13 *, int, u8 *);
	int (*getnumtcs)(struct net_device___13 *, int, u8 *);
	int (*setnumtcs)(struct net_device___13 *, int, u8);
	u8 (*getpfcstate)(struct net_device___13 *);
	void (*setpfcstate)(struct net_device___13 *, u8);
	void (*getbcncfg)(struct net_device___13 *, int, u32 *);
	void (*setbcncfg)(struct net_device___13 *, int, u32);
	void (*getbcnrp)(struct net_device___13 *, int, u8 *);
	void (*setbcnrp)(struct net_device___13 *, int, u8);
	int (*setapp)(struct net_device___13 *, u8, u16, u8);
	int (*getapp)(struct net_device___13 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___13 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___13 *, int, u8);
	u8 (*getdcbx)(struct net_device___13 *);
	u8 (*setdcbx)(struct net_device___13 *, u8);
	int (*peer_getappinfo)(struct net_device___13 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___13 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___13 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___13 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___13 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___13 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___8;

typedef int (*bpf_iter_init_seq_priv_t___8)(void *, struct bpf_iter_aux_info___8 *);

struct bpf_map___8;

struct bpf_iter_aux_info___8 {
	struct bpf_map___8 *map;
};

struct bpf_iter_seq_info___8 {
	const struct seq_operations___57 *seq_ops;
	bpf_iter_init_seq_priv_t___8 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___8 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___8 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___8 *, struct file___60 *);
	void (*map_free)(struct bpf_map___8 *);
	int (*map_get_next_key)(struct bpf_map___8 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___8 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___8 *, void *);
	int (*map_lookup_batch)(struct bpf_map___8 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___8 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___8 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___8 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___8 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___8 *, void *);
	int (*map_update_elem)(struct bpf_map___8 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___8 *, void *);
	int (*map_push_elem)(struct bpf_map___8 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___8 *, void *);
	int (*map_peek_elem)(struct bpf_map___8 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___8 *, struct file___60 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___8 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___8 *, void *, struct seq_file___57 *);
	int (*map_check_btf)(const struct bpf_map___8 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___8 *, struct bpf_prog_aux___8 *);
	void (*map_poke_untrack)(struct bpf_map___8 *, struct bpf_prog_aux___8 *);
	void (*map_poke_run)(struct bpf_map___8 *, u32, struct bpf_prog___8 *, struct bpf_prog___8 *);
	int (*map_direct_value_addr)(const struct bpf_map___8 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___8 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___8 *, struct vm_area_struct___64 *);
	__poll_t (*map_poll)(struct bpf_map___8 *, struct file___60 *, struct poll_table_struct___45 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___8 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___8 *, const struct bpf_map___8 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___8 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___8 *iter_seq_info;
};

struct bpf_map___8 {
	const struct bpf_map_ops___8 *ops;
	struct bpf_map___8 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___8;

struct bpf_jit_poke_descriptor___8;

struct bpf_prog_ops___8;

struct btf_mod_pair___8;

struct bpf_prog_offload___8;

struct bpf_prog_aux___8 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___8 *dst_prog;
	struct bpf_trampoline___8 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___8 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___8 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___8 *ops;
	struct bpf_map___8 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___8 *used_btfs;
	struct bpf_prog___8 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___8 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___8 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___8;

struct bpf_map_dev_ops___8 {
	int (*map_get_next_key)(struct bpf_offloaded_map___8 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___8 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___8 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___8 *, void *);
};

struct bpf_offloaded_map___8 {
	struct bpf_map___8 map;
	struct net_device___13 *netdev;
	const struct bpf_map_dev_ops___8 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_func_proto___2 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___8 *);
};

struct bpf_prog_ops___8 {
	int (*test_run)(struct bpf_prog___8 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___8 {
	struct bpf_prog___8 *prog;
	struct net_device___13 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___8 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___8 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___58 *mod;
};

enum bpf_jit_poke_reason {
	BPF_POKE_REASON_TAIL_CALL = 0,
};

struct bpf_jit_poke_descriptor___8 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___8 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___8 {
	struct btf *btf;
	struct module___58 *module;
};

struct bpf_array_aux___2 {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___8 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_array___2 {
	struct bpf_map___8 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux___2 *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum bpf_text_poke_type {
	BPF_MOD_CALL = 0,
	BPF_MOD_JUMP = 1,
};

struct cftype___49;

struct cgroup_subsys___49 {
	struct cgroup_subsys_state___49 * (*css_alloc)(struct cgroup_subsys_state___49 *);
	int (*css_online)(struct cgroup_subsys_state___49 *);
	void (*css_offline)(struct cgroup_subsys_state___49 *);
	void (*css_released)(struct cgroup_subsys_state___49 *);
	void (*css_free)(struct cgroup_subsys_state___49 *);
	void (*css_reset)(struct cgroup_subsys_state___49 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___49 *, int);
	int (*css_extra_stat_show)(struct seq_file___57 *, struct cgroup_subsys_state___49 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___65 *, struct css_set___49 *);
	void (*cancel_fork)(struct task_struct___65 *, struct css_set___49 *);
	void (*fork)(struct task_struct___65 *);
	void (*exit)(struct task_struct___65 *);
	void (*release)(struct task_struct___65 *);
	void (*bind)(struct cgroup_subsys_state___49 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___49 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___49 *dfl_cftypes;
	struct cftype___49 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___49 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___49 *updated_children;
	struct cgroup___49 *updated_next;
};

struct cgroup_root___49 {
	struct kernfs_root___59 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___49 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___49 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___49 *ss;
	struct list_head node;
	struct kernfs_ops___59 *kf_ops;
	int (*open)(struct kernfs_open_file___59 *);
	void (*release)(struct kernfs_open_file___59 *);
	u64 (*read_u64)(struct cgroup_subsys_state___49 *, struct cftype___49 *);
	s64 (*read_s64)(struct cgroup_subsys_state___49 *, struct cftype___49 *);
	int (*seq_show)(struct seq_file___57 *, void *);
	void * (*seq_start)(struct seq_file___57 *, loff_t *);
	void * (*seq_next)(struct seq_file___57 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___57 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___49 *, struct cftype___49 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___49 *, struct cftype___49 *, s64);
	ssize_t (*write)(struct kernfs_open_file___59 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___59 *, struct poll_table_struct___45 *);
};

enum xdp_mem_type {
	MEM_TYPE_PAGE_SHARED = 0,
	MEM_TYPE_PAGE_ORDER0 = 1,
	MEM_TYPE_PAGE_POOL = 2,
	MEM_TYPE_XSK_BUFF_POOL = 3,
	MEM_TYPE_MAX = 4,
};

struct xdp_rxq_info___8 {
	struct net_device___13 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___8 {
	struct net_device___13 *dev;
};

struct xdp_buff___8 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___8 *rxq;
	struct xdp_txq_info___8 *txq;
	u32 frame_sz;
};

struct xdp_frame___8 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___13 *dev_rx;
};

struct xdp_cpumap_stats {
	unsigned int redirect;
	unsigned int pass;
	unsigned int drop;
};

struct netlink_callback___8 {
	struct sk_buff___10 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___10 *, struct netlink_callback___8 *);
	int (*done)(struct netlink_callback___8 *);
	void *data;
	struct module___58 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___8 {
	int (*create)(struct sk_buff___10 *, struct net_device___13 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___10 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___13 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___10 *);
};

struct netdev_queue___8 {
	struct net_device___13 *dev;
	struct Qdisc___8 *qdisc;
	struct Qdisc___8 *qdisc_sleeping;
	struct kobject___59 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___13 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___8 {
	struct sk_buff___10 *head;
	struct sk_buff___10 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___8;

struct Qdisc___8 {
	int (*enqueue)(struct sk_buff___10 *, struct Qdisc___8 *, struct sk_buff___10 **);
	struct sk_buff___10 * (*dequeue)(struct Qdisc___8 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___8 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___8 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___8 gso_skb;
	struct qdisc_skb_head___8 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___8 *next_sched;
	struct sk_buff_head___8 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___8 {
	struct xdp_rxq_info___8 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___59 kobj;
	struct net_device___13 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___8 {
	enum net_device_path_type type;
	const struct net_device___13 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___8 = 0,
				DEV_PATH_BR_VLAN_TAG___8 = 1,
				DEV_PATH_BR_VLAN_UNTAG___8 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___8 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___8 {
	const struct net_device___13 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___8 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___8 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___8 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___8 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___10 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___8 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___13 *dev;
	const char *name;
};

struct net_device_ops___8 {
	int (*ndo_init)(struct net_device___13 *);
	void (*ndo_uninit)(struct net_device___13 *);
	int (*ndo_open)(struct net_device___13 *);
	int (*ndo_stop)(struct net_device___13 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___10 *, struct net_device___13 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___10 *, struct net_device___13 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___13 *, struct sk_buff___10 *, struct net_device___13 *);
	void (*ndo_change_rx_flags)(struct net_device___13 *, int);
	void (*ndo_set_rx_mode)(struct net_device___13 *);
	int (*ndo_set_mac_address)(struct net_device___13 *, void *);
	int (*ndo_validate_addr)(struct net_device___13 *);
	int (*ndo_do_ioctl)(struct net_device___13 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___13 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___13 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___13 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___13 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___13 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___13 *, int);
	int (*ndo_neigh_setup)(struct net_device___13 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___13 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___13 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___13 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___13 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___13 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___13 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___13 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___13 *);
	int (*ndo_netpoll_setup)(struct net_device___13 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___13 *);
	int (*ndo_set_vf_mac)(struct net_device___13 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___13 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___13 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___13 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___13 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___13 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___13 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___13 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___13 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___13 *, int, struct sk_buff___10 *);
	int (*ndo_get_vf_guid)(struct net_device___13 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___13 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___13 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___13 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___13 *);
	int (*ndo_fcoe_disable)(struct net_device___13 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___13 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___13 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___13 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___13 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___13 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___13 *, const struct sk_buff___10 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___13 *, struct net_device___13 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___13 *, struct net_device___13 *);
	struct net_device___13 * (*ndo_get_xmit_slave)(struct net_device___13 *, struct sk_buff___10 *, bool);
	struct net_device___13 * (*ndo_sk_get_lower_dev)(struct net_device___13 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___13 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___13 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___13 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___13 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___10 *, struct netlink_callback___8 *, struct net_device___13 *, struct net_device___13 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___10 *, struct nlattr **, struct net_device___13 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___13 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___10 *, u32, u32, struct net_device___13 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___13 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___13 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___13 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___13 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___13 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___13 *, struct net_device___13 *);
	void (*ndo_dfwd_del_station)(struct net_device___13 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___13 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___13 *);
	int (*ndo_change_proto_down)(struct net_device___13 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___13 *, struct sk_buff___10 *);
	void (*ndo_set_rx_headroom)(struct net_device___13 *, int);
	int (*ndo_bpf)(struct net_device___13 *, struct netdev_bpf___8 *);
	int (*ndo_xdp_xmit)(struct net_device___13 *, int, struct xdp_frame___8 **, u32);
	struct net_device___13 * (*ndo_xdp_get_xmit_slave)(struct net_device___13 *, struct xdp_buff___8 *);
	int (*ndo_xsk_wakeup)(struct net_device___13 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___13 *);
	int (*ndo_tunnel_ctl)(struct net_device___13 *, struct ip_tunnel_parm *, int);
	struct net_device___13 * (*ndo_get_peer_dev)(struct net_device___13 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___8 *, struct net_device_path___8 *);
};

struct tcf_proto___8;

struct tcf_block___8;

struct mini_Qdisc___8 {
	struct tcf_proto___8 *filter_list;
	struct tcf_block___8 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___8 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___13 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___13 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___11 *, struct net_device___13 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___13 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___13 *, struct list_head *);
	size_t (*get_size)(const struct net_device___13 *);
	int (*fill_info)(struct sk_buff___10 *, const struct net_device___13 *);
	size_t (*get_xstats_size)(const struct net_device___13 *);
	int (*fill_xstats)(struct sk_buff___10 *, const struct net_device___13 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___13 *, struct net_device___13 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___13 *, const struct net_device___13 *);
	int (*fill_slave_info)(struct sk_buff___10 *, const struct net_device___13 *, const struct net_device___13 *);
	struct net___11 * (*get_link_net)(const struct net_device___13 *);
	size_t (*get_linkxstats_size)(const struct net_device___13 *, int);
	int (*fill_linkxstats)(struct sk_buff___10 *, const struct net_device___13 *, int *, int);
};

struct gnet_dump___8 {
	spinlock_t *lock;
	struct sk_buff___10 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___8;

struct Qdisc_ops___8 {
	struct Qdisc_ops___8 *next;
	const struct Qdisc_class_ops___8 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___10 *, struct Qdisc___8 *, struct sk_buff___10 **);
	struct sk_buff___10 * (*dequeue)(struct Qdisc___8 *);
	struct sk_buff___10 * (*peek)(struct Qdisc___8 *);
	int (*init)(struct Qdisc___8 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___8 *);
	void (*destroy)(struct Qdisc___8 *);
	int (*change)(struct Qdisc___8 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___8 *);
	int (*change_tx_queue_len)(struct Qdisc___8 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___8 *, unsigned int);
	int (*dump)(struct Qdisc___8 *, struct sk_buff___10 *);
	int (*dump_stats)(struct Qdisc___8 *, struct gnet_dump___8 *);
	void (*ingress_block_set)(struct Qdisc___8 *, u32);
	void (*egress_block_set)(struct Qdisc___8 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___8 *);
	u32 (*egress_block_get)(struct Qdisc___8 *);
	struct module___58 *owner;
};

struct Qdisc_class_ops___8 {
	unsigned int flags;
	struct netdev_queue___8 * (*select_queue)(struct Qdisc___8 *, struct tcmsg *);
	int (*graft)(struct Qdisc___8 *, long unsigned int, struct Qdisc___8 *, struct Qdisc___8 **, struct netlink_ext_ack *);
	struct Qdisc___8 * (*leaf)(struct Qdisc___8 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___8 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___8 *, u32);
	int (*change)(struct Qdisc___8 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___8 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___8 *, struct qdisc_walker *);
	struct tcf_block___8 * (*tcf_block)(struct Qdisc___8 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___8 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___8 *, long unsigned int);
	int (*dump)(struct Qdisc___8 *, long unsigned int, struct sk_buff___10 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___8 *, long unsigned int, struct gnet_dump___8 *);
};

struct tcf_chain___8;

struct tcf_block___8 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___11 *net;
	struct Qdisc___8 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___8 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___8;

struct tcf_proto_ops___8;

struct tcf_proto___8 {
	struct tcf_proto___8 *next;
	void *root;
	int (*classify)(struct sk_buff___10 *, const struct tcf_proto___8 *, struct tcf_result___8 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___8 *ops;
	struct tcf_chain___8 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___8 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___8 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___8 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___10 *, const struct tcf_proto___8 *, struct tcf_result___8 *);
	int (*init)(struct tcf_proto___8 *);
	void (*destroy)(struct tcf_proto___8 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___8 *, u32);
	void (*put)(struct tcf_proto___8 *, void *);
	int (*change)(struct net___11 *, struct sk_buff___10 *, struct tcf_proto___8 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___8 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___8 *);
	void (*walk)(struct tcf_proto___8 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___8 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___8 *, void *);
	void (*hw_del)(struct tcf_proto___8 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___11 *, struct tcf_chain___8 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___11 *, struct tcf_proto___8 *, void *, struct sk_buff___10 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___11 *, struct tcf_proto___8 *, void *, struct sk_buff___10 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___10 *, struct net___11 *, void *);
	struct module___58 *owner;
	int flags;
};

struct tcf_chain___8 {
	struct mutex filter_chain_lock;
	struct tcf_proto___8 *filter_chain;
	struct list_head list;
	struct tcf_block___8 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___8 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct perf_cpu_context___41;

struct perf_output_handle___41;

struct pmu___41 {
	struct list_head entry;
	struct module___58 *module;
	struct device___53 *dev;
	const struct attribute_group___59 **attr_groups;
	const struct attribute_group___59 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___41 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___41 *);
	void (*pmu_disable)(struct pmu___41 *);
	int (*event_init)(struct perf_event___41 *);
	void (*event_mapped)(struct perf_event___41 *, struct mm_struct___65 *);
	void (*event_unmapped)(struct perf_event___41 *, struct mm_struct___65 *);
	int (*add)(struct perf_event___41 *, int);
	void (*del)(struct perf_event___41 *, int);
	void (*start)(struct perf_event___41 *, int);
	void (*stop)(struct perf_event___41 *, int);
	void (*read)(struct perf_event___41 *);
	void (*start_txn)(struct pmu___41 *, unsigned int);
	int (*commit_txn)(struct pmu___41 *);
	void (*cancel_txn)(struct pmu___41 *);
	int (*event_idx)(struct perf_event___41 *);
	void (*sched_task)(struct perf_event_context___41 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___41 *, struct perf_event_context___41 *);
	void * (*setup_aux)(struct perf_event___41 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___41 *, struct perf_output_handle___41 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___41 *);
	int (*aux_output_match)(struct perf_event___41 *);
	int (*filter_match)(struct perf_event___41 *);
	int (*check_period)(struct perf_event___41 *, u64);
};

struct perf_cpu_context___41 {
	struct perf_event_context___41 ctx;
	struct perf_event_context___41 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___41 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___41 **heap;
	struct perf_event___41 *heap_default[2];
};

struct perf_output_handle___41 {
	struct perf_event___41 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___41 {
	struct cgroup_subsys_state___49 css;
	struct perf_cgroup_info *info;
};

struct bpf_prog_dummy {
	struct bpf_prog___8 prog;
};

typedef u64 (*btf_bpf_user_rnd_u32)();

typedef u64 (*btf_bpf_get_raw_cpu_id)();

struct _bpf_dtab_netdev {
	struct net_device___13 *dev;
};

struct rhash_lock_head {};

struct zero_copy_allocator;

struct xdp_mem_allocator {
	struct xdp_mem_info mem;
	union {
		void *allocator;
		struct page_pool___17 *page_pool;
		struct zero_copy_allocator *zc_alloc;
	};
	struct rhash_head node;
	struct callback_head rcu;
};

struct trace_event_fields___36 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___36 *);
	};
};

struct trace_event_class___36 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___36 *, enum trace_reg, void *);
	struct trace_event_fields___36 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___36 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___36 *);
};

struct trace_event_file___18;

struct trace_event_buffer___17 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___18 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___18 {
	struct list_head list;
	struct trace_event_call___36 *event_call;
	struct event_filter *filter;
	struct dentry___60 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_xdp_exception {
	struct trace_entry ent;
	int prog_id;
	u32 act;
	int ifindex;
	char __data[0];
};

struct trace_event_raw_xdp_bulk_tx {
	struct trace_entry ent;
	int ifindex;
	u32 act;
	int drops;
	int sent;
	int err;
	char __data[0];
};

struct trace_event_raw_xdp_redirect_template {
	struct trace_entry ent;
	int prog_id;
	u32 act;
	int ifindex;
	int err;
	int to_ifindex;
	u32 map_id;
	int map_index;
	char __data[0];
};

struct trace_event_raw_xdp_cpumap_kthread {
	struct trace_entry ent;
	int map_id;
	u32 act;
	int cpu;
	unsigned int drops;
	unsigned int processed;
	int sched;
	unsigned int xdp_pass;
	unsigned int xdp_drop;
	unsigned int xdp_redirect;
	char __data[0];
};

struct trace_event_raw_xdp_cpumap_enqueue {
	struct trace_entry ent;
	int map_id;
	u32 act;
	int cpu;
	unsigned int drops;
	unsigned int processed;
	int to_cpu;
	char __data[0];
};

struct trace_event_raw_xdp_devmap_xmit {
	struct trace_entry ent;
	int from_ifindex;
	u32 act;
	int to_ifindex;
	int drops;
	int sent;
	int err;
	char __data[0];
};

struct trace_event_raw_mem_disconnect {
	struct trace_entry ent;
	const struct xdp_mem_allocator *xa;
	u32 mem_id;
	u32 mem_type;
	const void *allocator;
	char __data[0];
};

struct trace_event_raw_mem_connect {
	struct trace_entry ent;
	const struct xdp_mem_allocator *xa;
	u32 mem_id;
	u32 mem_type;
	const void *allocator;
	const struct xdp_rxq_info___8 *rxq;
	int ifindex;
	char __data[0];
};

struct trace_event_raw_mem_return_failed {
	struct trace_entry ent;
	const struct page___64 *page;
	u32 mem_id;
	u32 mem_type;
	char __data[0];
};

struct trace_event_data_offsets_xdp_exception {};

struct trace_event_data_offsets_xdp_bulk_tx {};

struct trace_event_data_offsets_xdp_redirect_template {};

struct trace_event_data_offsets_xdp_cpumap_kthread {};

struct trace_event_data_offsets_xdp_cpumap_enqueue {};

struct trace_event_data_offsets_xdp_devmap_xmit {};

struct trace_event_data_offsets_mem_disconnect {};

struct trace_event_data_offsets_mem_connect {};

struct trace_event_data_offsets_mem_return_failed {};

typedef void (*btf_trace_xdp_exception)(void *, const struct net_device___13 *, const struct bpf_prog___8 *, u32);

typedef void (*btf_trace_xdp_bulk_tx)(void *, const struct net_device___13 *, int, int, int);

typedef void (*btf_trace_xdp_redirect)(void *, const struct net_device___13 *, const struct bpf_prog___8 *, const void *, int, enum bpf_map_type, u32, u32);

typedef void (*btf_trace_xdp_redirect_err)(void *, const struct net_device___13 *, const struct bpf_prog___8 *, const void *, int, enum bpf_map_type, u32, u32);

typedef void (*btf_trace_xdp_redirect_map)(void *, const struct net_device___13 *, const struct bpf_prog___8 *, const void *, int, enum bpf_map_type, u32, u32);

typedef void (*btf_trace_xdp_redirect_map_err)(void *, const struct net_device___13 *, const struct bpf_prog___8 *, const void *, int, enum bpf_map_type, u32, u32);

typedef void (*btf_trace_xdp_cpumap_kthread)(void *, int, unsigned int, unsigned int, int, struct xdp_cpumap_stats *);

typedef void (*btf_trace_xdp_cpumap_enqueue)(void *, int, unsigned int, unsigned int, int);

typedef void (*btf_trace_xdp_devmap_xmit)(void *, const struct net_device___13 *, const struct net_device___13 *, int, int, int);

typedef void (*btf_trace_mem_disconnect)(void *, const struct xdp_mem_allocator *);

typedef void (*btf_trace_mem_connect)(void *, const struct xdp_mem_allocator *, const struct xdp_rxq_info___8 *);

typedef void (*btf_trace_mem_return_failed)(void *, const struct xdp_mem_info *, const struct page___64 *);

enum bpf_cmd {
	BPF_MAP_CREATE = 0,
	BPF_MAP_LOOKUP_ELEM = 1,
	BPF_MAP_UPDATE_ELEM = 2,
	BPF_MAP_DELETE_ELEM = 3,
	BPF_MAP_GET_NEXT_KEY = 4,
	BPF_PROG_LOAD = 5,
	BPF_OBJ_PIN = 6,
	BPF_OBJ_GET = 7,
	BPF_PROG_ATTACH = 8,
	BPF_PROG_DETACH = 9,
	BPF_PROG_TEST_RUN = 10,
	BPF_PROG_RUN = 10,
	BPF_PROG_GET_NEXT_ID = 11,
	BPF_MAP_GET_NEXT_ID = 12,
	BPF_PROG_GET_FD_BY_ID = 13,
	BPF_MAP_GET_FD_BY_ID = 14,
	BPF_OBJ_GET_INFO_BY_FD = 15,
	BPF_PROG_QUERY = 16,
	BPF_RAW_TRACEPOINT_OPEN = 17,
	BPF_BTF_LOAD = 18,
	BPF_BTF_GET_FD_BY_ID = 19,
	BPF_TASK_FD_QUERY = 20,
	BPF_MAP_LOOKUP_AND_DELETE_ELEM = 21,
	BPF_MAP_FREEZE = 22,
	BPF_BTF_GET_NEXT_ID = 23,
	BPF_MAP_LOOKUP_BATCH = 24,
	BPF_MAP_LOOKUP_AND_DELETE_BATCH = 25,
	BPF_MAP_UPDATE_BATCH = 26,
	BPF_MAP_DELETE_BATCH = 27,
	BPF_LINK_CREATE = 28,
	BPF_LINK_UPDATE = 29,
	BPF_LINK_GET_FD_BY_ID = 30,
	BPF_LINK_GET_NEXT_ID = 31,
	BPF_ENABLE_STATS = 32,
	BPF_ITER_CREATE = 33,
	BPF_LINK_DETACH = 34,
	BPF_PROG_BIND_MAP = 35,
};

enum {
	BPF_ANY = 0,
	BPF_NOEXIST = 1,
	BPF_EXIST = 2,
	BPF_F_LOCK = 4,
};

enum {
	BPF_F_NO_PREALLOC = 1,
	BPF_F_NO_COMMON_LRU = 2,
	BPF_F_NUMA_NODE = 4,
	BPF_F_RDONLY = 8,
	BPF_F_WRONLY = 16,
	BPF_F_STACK_BUILD_ID = 32,
	BPF_F_ZERO_SEED = 64,
	BPF_F_RDONLY_PROG = 128,
	BPF_F_WRONLY_PROG = 256,
	BPF_F_CLONE = 512,
	BPF_F_MMAPABLE = 1024,
	BPF_F_PRESERVE_ELEMS = 2048,
	BPF_F_INNER_MAP = 4096,
};

enum bpf_stats_type {
	BPF_STATS_RUN_TIME = 0,
};

struct bpf_prog_info {
	__u32 type;
	__u32 id;
	__u8 tag[8];
	__u32 jited_prog_len;
	__u32 xlated_prog_len;
	__u64 jited_prog_insns;
	__u64 xlated_prog_insns;
	__u64 load_time;
	__u32 created_by_uid;
	__u32 nr_map_ids;
	__u64 map_ids;
	char name[16];
	__u32 ifindex;
	__u32 gpl_compatible: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u64 netns_dev;
	__u64 netns_ino;
	__u32 nr_jited_ksyms;
	__u32 nr_jited_func_lens;
	__u64 jited_ksyms;
	__u64 jited_func_lens;
	__u32 btf_id;
	__u32 func_info_rec_size;
	__u64 func_info;
	__u32 nr_func_info;
	__u32 nr_line_info;
	__u64 line_info;
	__u64 jited_line_info;
	__u32 nr_jited_line_info;
	__u32 line_info_rec_size;
	__u32 jited_line_info_rec_size;
	__u32 nr_prog_tags;
	__u64 prog_tags;
	__u64 run_time_ns;
	__u64 run_cnt;
	__u64 recursion_misses;
};

struct bpf_map_info {
	__u32 type;
	__u32 id;
	__u32 key_size;
	__u32 value_size;
	__u32 max_entries;
	__u32 map_flags;
	char name[16];
	__u32 ifindex;
	__u32 btf_vmlinux_value_type_id;
	__u64 netns_dev;
	__u64 netns_ino;
	__u32 btf_id;
	__u32 btf_key_type_id;
	__u32 btf_value_type_id;
};

struct bpf_btf_info {
	__u64 btf;
	__u32 btf_size;
	__u32 id;
	__u64 name;
	__u32 name_len;
	__u32 kernel_btf;
};

struct dentry___61;

struct super_block___61;

struct module___59;

struct file_system_type___60 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___61 * (*mount)(struct file_system_type___60 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___61 *);
	struct module___59 *owner;
	struct file_system_type___60 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___61;

struct kiocb___60;

struct iov_iter___32;

struct poll_table_struct___46;

struct vm_area_struct___65;

struct inode___61;

struct file_lock___60;

struct page___65;

struct pipe_inode_info___21;

struct seq_file___58;

struct file_operations___60 {
	struct module___59 *owner;
	loff_t (*llseek)(struct file___61 *, loff_t, int);
	ssize_t (*read)(struct file___61 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___61 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___60 *, struct iov_iter___32 *);
	ssize_t (*write_iter)(struct kiocb___60 *, struct iov_iter___32 *);
	int (*iopoll)(struct kiocb___60 *, bool);
	int (*iterate)(struct file___61 *, struct dir_context *);
	int (*iterate_shared)(struct file___61 *, struct dir_context *);
	__poll_t (*poll)(struct file___61 *, struct poll_table_struct___46 *);
	long int (*unlocked_ioctl)(struct file___61 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___61 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___61 *, struct vm_area_struct___65 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___61 *, struct file___61 *);
	int (*flush)(struct file___61 *, fl_owner_t);
	int (*release)(struct inode___61 *, struct file___61 *);
	int (*fsync)(struct file___61 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___61 *, int);
	int (*lock)(struct file___61 *, int, struct file_lock___60 *);
	ssize_t (*sendpage)(struct file___61 *, struct page___65 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___61 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___61 *, long unsigned int);
	int (*flock)(struct file___61 *, int, struct file_lock___60 *);
	ssize_t (*splice_write)(struct pipe_inode_info___21 *, struct file___61 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___61 *, loff_t *, struct pipe_inode_info___21 *, size_t, unsigned int);
	int (*setlease)(struct file___61 *, long int, struct file_lock___60 **, void **);
	long int (*fallocate)(struct file___61 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___58 *, struct file___61 *);
	ssize_t (*copy_file_range)(struct file___61 *, loff_t, struct file___61 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___61 *, loff_t, struct file___61 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___61 *, loff_t, loff_t, int);
};

struct vmacache___65 {
	u64 seqnum;
	struct vm_area_struct___65 *vmas[4];
};

struct page_frag___65 {
	struct page___65 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___42;

struct debug_info___42 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___42 *hbp_break[16];
	struct perf_event___42 *hbp_watch[16];
};

struct thread_struct___42 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___42 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___66;

struct pid___54;

struct files_struct___4;

struct nsproxy___59;

struct signal_struct___61;

struct bio_list___27;

struct backing_dev_info___26;

struct io_context___28;

struct css_set___50;

struct perf_event_context___42;

struct mem_cgroup___24;

struct request_queue___28;

struct vm_struct___62;

struct task_struct___66 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___66 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___66 *mm;
	struct mm_struct___66 *active_mm;
	struct vmacache___65 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___66 *real_parent;
	struct task_struct___66 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___66 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___54 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___4 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___59 *nsproxy;
	struct signal_struct___61 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___66 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___27 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___26 *backing_dev_info;
	struct io_context___28 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___50 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___42 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___21 *splice_pipe;
	struct page_frag___65 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___24 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___24 *active_memcg;
	struct request_queue___28 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___66 *oom_reaper_list;
	struct vm_struct___62 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___42 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___60;

struct kobj_type___60;

struct kernfs_node___60;

struct kobject___60 {
	const char *name;
	struct list_head entry;
	struct kobject___60 *parent;
	struct kset___60 *kset;
	struct kobj_type___60 *ktype;
	struct kernfs_node___60 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___57 {
	struct kobject___60 kobj;
	struct module___59 *mod;
	struct kobject___60 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___57 {
	struct module___59 *mod;
	struct latch_tree_node node;
};

struct module_layout___57 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___57 mtn;
};

struct module_attribute___57;

struct kernel_param___57;

struct trace_event_call___37;

struct module___59 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___57 mkobj;
	struct module_attribute___57 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___60 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___57 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___57 core_layout;
	struct module_layout___57 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___37 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___42 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___66 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___42)(struct perf_event___42 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___42;

struct fasync_struct___60;

struct pid_namespace___54;

struct bpf_prog___9;

struct perf_cgroup___42;

struct perf_event___42 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___42 *group_leader;
	struct pmu___42 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___42 hw;
	struct perf_event_context___42 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___42 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___66 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___60 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___42 *aux_event;
	void (*destroy)(struct perf_event___42 *);
	struct callback_head callback_head;
	struct pid_namespace___54 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___42 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___42 orig_overflow_handler;
	struct bpf_prog___9 *prog;
	u64 bpf_cookie;
	struct trace_event_call___37 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___42 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct fd___6 {
	struct file___61 *file;
	unsigned int flags;
};

struct vfsmount___60;

struct path___60 {
	struct vfsmount___60 *mnt;
	struct dentry___61 *dentry;
};

struct fown_struct___54 {
	rwlock_t lock;
	struct pid___54 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___60;

struct file___61 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___60 f_path;
	struct inode___61 *f_inode;
	const struct file_operations___60 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___54 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___60 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___65 *pgtable_t___65;

struct page_pool___18;

struct dev_pagemap___59;

struct page___65 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___60 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___18 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___65 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___65 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___66 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___59 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___59;

struct vm_area_struct___65 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___65 *vm_next;
	struct vm_area_struct___65 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___66 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___59 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___61 *vm_file;
	struct file___61 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___65;

struct mm_struct___66 {
	struct {
		struct vm_area_struct___65 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___61 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___65 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___66 *owner;
		struct user_namespace___10 *user_ns;
		struct file___61 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___60;

struct address_space___60 {
	struct inode___61 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___60 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___54;

struct page_pool_params___18 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___54 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___18 {
	u32 count;
	struct page___65 *cache[128];
};

struct page_pool___18 {
	struct page_pool_params___18 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___65 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___18 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___59;

struct dev_pagemap___59 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___59 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___59;

struct vm_operations_struct___59 {
	void (*open)(struct vm_area_struct___65 *);
	void (*close)(struct vm_area_struct___65 *);
	int (*may_split)(struct vm_area_struct___65 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___65 *);
	int (*mprotect)(struct vm_area_struct___65 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___59 *);
	vm_fault_t (*huge_fault)(struct vm_fault___59 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___59 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___65 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___59 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___59 *);
	int (*access)(struct vm_area_struct___65 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___65 *);
	int (*set_policy)(struct vm_area_struct___65 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___65 *, long unsigned int);
	struct page___65 * (*find_special_page)(struct vm_area_struct___65 *, long unsigned int);
};

struct core_thread___65 {
	struct task_struct___66 *task;
	struct core_thread___65 *next;
};

struct core_state___65 {
	atomic_t nr_threads;
	struct core_thread___65 dumper;
	struct completion startup;
};

struct vm_fault___59 {
	const struct {
		struct vm_area_struct___65 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___65 *cow_page;
	struct page___65 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___65 prealloc_pte;
};

struct upid___54 {
	int nr;
	struct pid_namespace___54 *ns;
};

struct pid_namespace___54 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___66 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___54 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___54 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___54 numbers[1];
};

struct signal_struct___61 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___66 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___66 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___54 *pids[4];
	struct pid___54 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___66 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fdtable___4 {
	unsigned int max_fds;
	struct file___61 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___4 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___4 *fdt;
	struct fdtable___4 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___61 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___12;

struct cgroup_namespace___50;

struct nsproxy___59 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___54 *pid_ns_for_children;
	struct net___12 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___50 *cgroup_ns;
};

struct bio___27;

struct bio_list___27 {
	struct bio___27 *head;
	struct bio___27 *tail;
};

struct cgroup_subsys_state___50;

struct bdi_writeback___26 {
	struct backing_dev_info___26 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___50 *memcg_css;
	struct cgroup_subsys_state___50 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___26 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___26 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___54 *dev;
	char dev_name[64];
	struct device___54 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___61 *debug_dir;
};

struct io_cq___27;

struct io_context___28 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___27 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___50;

struct css_set___50 {
	struct cgroup_subsys_state___50 *subsys[14];
	refcount_t refcount;
	struct css_set___50 *dom_cset;
	struct cgroup___50 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___50 *mg_src_cgrp;
	struct cgroup___50 *mg_dst_cgrp;
	struct css_set___50 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___42 {
	struct pmu___42 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___66 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___42 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___21;

struct pipe_inode_info___21 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___65 *tmp_page;
	struct fasync_struct___60 *fasync_readers;
	struct fasync_struct___60 *fasync_writers;
	struct pipe_buffer___21 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___50;

struct cgroup_subsys_state___50 {
	struct cgroup___50 *cgroup;
	struct cgroup_subsys___50 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___50 *parent;
};

struct cgroup_file___50 {
	struct kernfs_node___60 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___24;

struct mem_cgroup_per_node___24;

struct mem_cgroup___24 {
	struct cgroup_subsys_state___50 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___50 events_file;
	struct cgroup_file___50 events_local_file;
	struct cgroup_file___50 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___24 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___66 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___24 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___27;

struct blk_integrity___27 {
	const struct blk_integrity_profile___27 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___27 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___27 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___27;

struct elevator_queue___27;

struct blk_mq_ops___26;

struct blk_mq_hw_ctx___26;

struct gendisk___27;

struct blkcg_gq___26;

struct blk_mq_tag_set___26;

struct request_queue___28 {
	struct request___27 *last_merge;
	struct elevator_queue___27 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___26 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___26 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___27 *disk;
	struct kobject___60 kobj;
	struct kobject___60 *mq_kobj;
	struct blk_integrity___27 integrity;
	struct device___54 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___26 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___26 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___27 bio_split;
	struct dentry___61 *debugfs_dir;
	struct dentry___61 *sched_debugfs_dir;
	struct dentry___61 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___62 {
	struct vm_struct___62 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___65 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___25;

struct lruvec___25 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___25 *pgdat;
};

struct zone___25 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___25 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___25 {
	struct zone___25 *zone;
	int zone_idx;
};

struct zonelist___25 {
	struct zoneref___25 _zonerefs[321];
};

struct pglist_data___25 {
	struct zone___25 node_zones[5];
	struct zonelist___25 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___66 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___66 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___25 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___60;

struct dentry___61 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___61 *d_parent;
	struct qstr d_name;
	struct inode___61 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___60 *d_op;
	struct super_block___61 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___60;

struct inode___61 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___60 *i_op;
	struct super_block___61 *i_sb;
	struct address_space___60 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___26 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___60 *i_fop;
		void (*free_inode)(struct inode___61 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___60 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___21 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___60 {
	int (*d_revalidate)(struct dentry___61 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___61 *, unsigned int);
	int (*d_hash)(const struct dentry___61 *, struct qstr *);
	int (*d_compare)(const struct dentry___61 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___61 *);
	int (*d_init)(struct dentry___61 *);
	void (*d_release)(struct dentry___61 *);
	void (*d_prune)(struct dentry___61 *);
	void (*d_iput)(struct dentry___61 *, struct inode___61 *);
	char * (*d_dname)(struct dentry___61 *, char *, int);
	struct vfsmount___60 * (*d_automount)(struct path___60 *);
	int (*d_manage)(const struct path___60 *, bool);
	struct dentry___61 * (*d_real)(struct dentry___61 *, const struct inode___61 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___60;

struct mem_dqinfo___60 {
	struct quota_format_type___60 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___60;

struct quota_info___60 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___61 *files[3];
	struct mem_dqinfo___60 info[3];
	const struct quota_format_ops___60 *ops[3];
};

struct rcuwait___61 {
	struct task_struct___66 *task;
};

struct percpu_rw_semaphore___61 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___61 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___60 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___61 rw_sem[3];
};

struct shrink_control___24;

struct shrinker___24 {
	long unsigned int (*count_objects)(struct shrinker___24 *, struct shrink_control___24 *);
	long unsigned int (*scan_objects)(struct shrinker___24 *, struct shrink_control___24 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___60;

struct dquot_operations___60;

struct quotactl_ops___60;

struct block_device___28;

struct super_block___61 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___60 *s_type;
	const struct super_operations___60 *s_op;
	const struct dquot_operations___60 *dq_op;
	const struct quotactl_ops___60 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___61 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___28 *s_bdev;
	struct backing_dev_info___26 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___60 s_dquot;
	struct sb_writers___60 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___60 *s_d_op;
	int cleancache_poolid;
	struct shrinker___24 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___60 {
	struct dentry___61 *mnt_root;
	struct super_block___61 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct shrink_control___24 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___24 *memcg;
};

struct psi_group___50 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___66 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___9;

struct cgroup_bpf___9 {
	struct bpf_prog_array___9 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___9 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___50;

struct cgroup_rstat_cpu___50;

struct cgroup___50 {
	struct cgroup_subsys_state___50 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___60 *kn;
	struct cgroup_file___50 procs_file;
	struct cgroup_file___50 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___50 *subsys[14];
	struct cgroup_root___50 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___50 *dom_cgrp;
	struct cgroup___50 *old_dom_cgrp;
	struct cgroup_rstat_cpu___50 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___50 psi;
	struct cgroup_bpf___9 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___27 {
	struct request_queue___28 *q;
	struct io_context___28 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___60 {
	struct file___61 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___60 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___61 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___61 *ia_file;
};

struct dquot___60 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___61 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___60 {
	int qf_fmt_id;
	const struct quota_format_ops___60 *qf_ops;
	struct module___59 *qf_owner;
	struct quota_format_type___60 *qf_next;
};

struct quota_format_ops___60 {
	int (*check_quota_file)(struct super_block___61 *, int);
	int (*read_file_info)(struct super_block___61 *, int);
	int (*write_file_info)(struct super_block___61 *, int);
	int (*free_file_info)(struct super_block___61 *, int);
	int (*read_dqblk)(struct dquot___60 *);
	int (*commit_dqblk)(struct dquot___60 *);
	int (*release_dqblk)(struct dquot___60 *);
	int (*get_next_id)(struct super_block___61 *, struct kqid *);
};

struct dquot_operations___60 {
	int (*write_dquot)(struct dquot___60 *);
	struct dquot___60 * (*alloc_dquot)(struct super_block___61 *, int);
	void (*destroy_dquot)(struct dquot___60 *);
	int (*acquire_dquot)(struct dquot___60 *);
	int (*release_dquot)(struct dquot___60 *);
	int (*mark_dirty)(struct dquot___60 *);
	int (*write_info)(struct super_block___61 *, int);
	qsize_t * (*get_reserved_space)(struct inode___61 *);
	int (*get_projid)(struct inode___61 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___61 *, qsize_t *);
	int (*get_next_id)(struct super_block___61 *, struct kqid *);
};

struct quotactl_ops___60 {
	int (*quota_on)(struct super_block___61 *, int, int, const struct path___60 *);
	int (*quota_off)(struct super_block___61 *, int);
	int (*quota_enable)(struct super_block___61 *, unsigned int);
	int (*quota_disable)(struct super_block___61 *, unsigned int);
	int (*quota_sync)(struct super_block___61 *, int);
	int (*set_info)(struct super_block___61 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___61 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___61 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___61 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___61 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___61 *, unsigned int);
};

struct writeback_control___26;

struct address_space_operations___60 {
	int (*writepage)(struct page___65 *, struct writeback_control___26 *);
	int (*readpage)(struct file___61 *, struct page___65 *);
	int (*writepages)(struct address_space___60 *, struct writeback_control___26 *);
	int (*set_page_dirty)(struct page___65 *);
	int (*readpages)(struct file___61 *, struct address_space___60 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___61 *, struct address_space___60 *, loff_t, unsigned int, unsigned int, struct page___65 **, void **);
	int (*write_end)(struct file___61 *, struct address_space___60 *, loff_t, unsigned int, unsigned int, struct page___65 *, void *);
	sector_t (*bmap)(struct address_space___60 *, sector_t);
	void (*invalidatepage)(struct page___65 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___65 *, gfp_t);
	void (*freepage)(struct page___65 *);
	ssize_t (*direct_IO)(struct kiocb___60 *, struct iov_iter___32 *);
	int (*migratepage)(struct address_space___60 *, struct page___65 *, struct page___65 *, enum migrate_mode);
	bool (*isolate_page)(struct page___65 *, isolate_mode_t);
	void (*putback_page)(struct page___65 *);
	int (*launder_page)(struct page___65 *);
	int (*is_partially_uptodate)(struct page___65 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___65 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___60 *, struct page___65 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___61 *, sector_t *);
	void (*swap_deactivate)(struct file___61 *);
};

struct writeback_control___26 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___26 *wb;
	struct inode___61 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___32;

struct iov_iter___32 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___32 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___21 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___60 {
	struct dentry___61 * (*lookup)(struct inode___61 *, struct dentry___61 *, unsigned int);
	const char * (*get_link)(struct dentry___61 *, struct inode___61 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___61 *, int);
	struct posix_acl * (*get_acl)(struct inode___61 *, int, bool);
	int (*readlink)(struct dentry___61 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___61 *, struct dentry___61 *, umode_t, bool);
	int (*link)(struct dentry___61 *, struct inode___61 *, struct dentry___61 *);
	int (*unlink)(struct inode___61 *, struct dentry___61 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___61 *, struct dentry___61 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___61 *, struct dentry___61 *, umode_t);
	int (*rmdir)(struct inode___61 *, struct dentry___61 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___61 *, struct dentry___61 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___61 *, struct dentry___61 *, struct inode___61 *, struct dentry___61 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___61 *, struct iattr___61 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___60 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___61 *, char *, size_t);
	int (*fiemap)(struct inode___61 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___61 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___61 *, struct dentry___61 *, struct file___61 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___61 *, struct dentry___61 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___61 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___61 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___61 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___60 {
	void (*fl_copy_lock)(struct file_lock___60 *, struct file_lock___60 *);
	void (*fl_release_private)(struct file_lock___60 *);
};

struct lock_manager_operations___60;

struct file_lock___60 {
	struct file_lock___60 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___61 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___60 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___60 *fl_ops;
	const struct lock_manager_operations___60 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___60 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___60 *);
	int (*lm_grant)(struct file_lock___60 *, int);
	bool (*lm_break)(struct file_lock___60 *);
	int (*lm_change)(struct file_lock___60 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___60 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___60 *);
};

struct fasync_struct___60 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___60 *fa_next;
	struct file___61 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___60 {
	struct inode___61 * (*alloc_inode)(struct super_block___61 *);
	void (*destroy_inode)(struct inode___61 *);
	void (*free_inode)(struct inode___61 *);
	void (*dirty_inode)(struct inode___61 *, int);
	int (*write_inode)(struct inode___61 *, struct writeback_control___26 *);
	int (*drop_inode)(struct inode___61 *);
	void (*evict_inode)(struct inode___61 *);
	void (*put_super)(struct super_block___61 *);
	int (*sync_fs)(struct super_block___61 *, int);
	int (*freeze_super)(struct super_block___61 *);
	int (*freeze_fs)(struct super_block___61 *);
	int (*thaw_super)(struct super_block___61 *);
	int (*unfreeze_fs)(struct super_block___61 *);
	int (*statfs)(struct dentry___61 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___61 *, int *, char *);
	void (*umount_begin)(struct super_block___61 *);
	int (*show_options)(struct seq_file___58 *, struct dentry___61 *);
	int (*show_devname)(struct seq_file___58 *, struct dentry___61 *);
	int (*show_path)(struct seq_file___58 *, struct dentry___61 *);
	int (*show_stats)(struct seq_file___58 *, struct dentry___61 *);
	ssize_t (*quota_read)(struct super_block___61 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___61 *, int, const char *, size_t, loff_t);
	struct dquot___60 ** (*get_dquots)(struct inode___61 *);
	long int (*nr_cached_objects)(struct super_block___61 *, struct shrink_control___24 *);
	long int (*free_cached_objects)(struct super_block___61 *, struct shrink_control___24 *);
	struct file___61 * (*real_loop)(struct file___61 *);
};

struct wakeup_source___54;

struct dev_pm_info___54 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___54 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___54 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___54;

struct bus_type___54;

struct device_driver___54;

struct dev_pm_domain___54;

struct fwnode_handle___54;

struct class___54;

struct attribute_group___60;

struct device___54 {
	struct kobject___60 kobj;
	struct device___54 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___54 *type;
	struct bus_type___54 *bus;
	struct device_driver___54 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___54 power;
	struct dev_pm_domain___54 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___54 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___54 *class;
	const struct attribute_group___60 **groups;
	void (*release)(struct device___54 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___28 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___61 *bd_inode;
	struct super_block___61 *bd_super;
	void *bd_claiming;
	struct device___54 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___60 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___27 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___61 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___46)(struct file___61 *, wait_queue_head_t *, struct poll_table_struct___46 *);

struct poll_table_struct___46 {
	poll_queue_proc___46 _qproc;
	__poll_t _key;
};

struct seq_operations___58;

struct seq_file___58 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___58 *op;
	int poll_event;
	const struct file___61 *file;
	void *private;
};

typedef void bio_end_io_t___27(struct bio___27 *);

struct bio_vec___32 {
	struct page___65 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___27;

struct bio___27 {
	struct bio___27 *bi_next;
	struct block_device___28 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___27 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___26 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___27 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___32 *bi_io_vec;
	struct bio_set___27 *bi_pool;
	struct bio_vec___32 bi_inline_vecs[0];
};

struct kernfs_root___60;

struct kernfs_elem_dir___60 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___60 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___60;

struct kernfs_root___60 {
	struct kernfs_node___60 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___60 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___60 {
	struct kernfs_node___60 *target_kn;
};

struct kernfs_ops___60;

struct kernfs_elem_attr___60 {
	const struct kernfs_ops___60 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___60 *notify_next;
};

struct kernfs_node___60 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___60 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___60 dir;
		struct kernfs_elem_symlink___60 symlink;
		struct kernfs_elem_attr___60 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___60;

struct kernfs_ops___60 {
	int (*open)(struct kernfs_open_file___60 *);
	void (*release)(struct kernfs_open_file___60 *);
	int (*seq_show)(struct seq_file___58 *, void *);
	void * (*seq_start)(struct seq_file___58 *, loff_t *);
	void * (*seq_next)(struct seq_file___58 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___58 *, void *);
	ssize_t (*read)(struct kernfs_open_file___60 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___60 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___60 *, struct poll_table_struct___46 *);
	int (*mmap)(struct kernfs_open_file___60 *, struct vm_area_struct___65 *);
};

struct kernfs_syscall_ops___60 {
	int (*show_options)(struct seq_file___58 *, struct kernfs_root___60 *);
	int (*mkdir)(struct kernfs_node___60 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___60 *);
	int (*rename)(struct kernfs_node___60 *, struct kernfs_node___60 *, const char *);
	int (*show_path)(struct seq_file___58 *, struct kernfs_node___60 *, struct kernfs_root___60 *);
};

struct kernfs_open_file___60 {
	struct kernfs_node___60 *kn;
	struct file___61 *file;
	struct seq_file___58 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___59 *vm_ops;
};

struct bin_attribute___60;

struct attribute_group___60 {
	const char *name;
	umode_t (*is_visible)(struct kobject___60 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___60 *, struct bin_attribute___60 *, int);
	struct attribute **attrs;
	struct bin_attribute___60 **bin_attrs;
};

struct bin_attribute___60 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___60 * (*f_mapping)();
	ssize_t (*read)(struct file___61 *, struct kobject___60 *, struct bin_attribute___60 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___61 *, struct kobject___60 *, struct bin_attribute___60 *, char *, loff_t, size_t);
	int (*mmap)(struct file___61 *, struct kobject___60 *, struct bin_attribute___60 *, struct vm_area_struct___65 *);
};

struct sysfs_ops___60 {
	ssize_t (*show)(struct kobject___60 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___60 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___60;

struct kset___60 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___60 kobj;
	const struct kset_uevent_ops___60 *uevent_ops;
};

struct kobj_type___60 {
	void (*release)(struct kobject___60 *);
	const struct sysfs_ops___60 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___60 **default_groups;
	const struct kobj_ns_type_operations___6 * (*child_ns_type)(struct kobject___60 *);
	const void * (*namespace)(struct kobject___60 *);
	void (*get_ownership)(struct kobject___60 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___60 {
	int (* const filter)(struct kset___60 *, struct kobject___60 *);
	const char * (* const name)(struct kset___60 *, struct kobject___60 *);
	int (* const uevent)(struct kset___60 *, struct kobject___60 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___57 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___57 *);
	int (*get)(char *, const struct kernel_param___57 *);
	void (*free)(void *);
};

struct kparam_array___57;

struct kernel_param___57 {
	const char *name;
	struct module___59 *mod;
	const struct kernel_param_ops___57 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___57 *arr;
	};
};

struct kparam_array___57 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___57 *ops;
	void *elem;
};

struct module_attribute___57 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___57 *, struct module_kobject___57 *, char *);
	ssize_t (*store)(struct module_attribute___57 *, struct module_kobject___57 *, const char *, size_t);
	void (*setup)(struct module___59 *, const char *);
	int (*test)(struct module___59 *);
	void (*free)(struct module___59 *);
};

struct trace_event_class___37;

struct trace_event_call___37 {
	struct list_head list;
	struct trace_event_class___37 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___9 *prog_array;
	int (*perf_perm)(struct trace_event_call___37 *, struct perf_event___42 *);
};

struct dev_pagemap_ops___59 {
	void (*page_free)(struct page___65 *);
	void (*kill)(struct dev_pagemap___59 *);
	void (*cleanup)(struct dev_pagemap___59 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___59 *);
};

typedef sockptr_t bpfptr_t;

struct bpf_iter_aux_info___9;

typedef int (*bpf_iter_init_seq_priv_t___9)(void *, struct bpf_iter_aux_info___9 *);

struct bpf_map___9;

struct bpf_iter_aux_info___9 {
	struct bpf_map___9 *map;
};

struct bpf_iter_seq_info___9 {
	const struct seq_operations___58 *seq_ops;
	bpf_iter_init_seq_priv_t___9 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___58 {
	void * (*start)(struct seq_file___58 *, loff_t *);
	void (*stop)(struct seq_file___58 *, void *);
	void * (*next)(struct seq_file___58 *, void *, loff_t *);
	int (*show)(struct seq_file___58 *, void *);
};

struct bpf_prog_aux___9;

struct bpf_verifier_env___2;

struct bpf_func_state___2;

struct bpf_map_ops___9 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___9 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___9 *, struct file___61 *);
	void (*map_free)(struct bpf_map___9 *);
	int (*map_get_next_key)(struct bpf_map___9 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___9 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___9 *, void *);
	int (*map_lookup_batch)(struct bpf_map___9 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___9 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___9 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___9 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___9 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___9 *, void *);
	int (*map_update_elem)(struct bpf_map___9 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___9 *, void *);
	int (*map_push_elem)(struct bpf_map___9 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___9 *, void *);
	int (*map_peek_elem)(struct bpf_map___9 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___9 *, struct file___61 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___9 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___9 *, void *, struct seq_file___58 *);
	int (*map_check_btf)(const struct bpf_map___9 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___9 *, struct bpf_prog_aux___9 *);
	void (*map_poke_untrack)(struct bpf_map___9 *, struct bpf_prog_aux___9 *);
	void (*map_poke_run)(struct bpf_map___9 *, u32, struct bpf_prog___9 *, struct bpf_prog___9 *);
	int (*map_direct_value_addr)(const struct bpf_map___9 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___9 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___9 *, struct vm_area_struct___65 *);
	__poll_t (*map_poll)(struct bpf_map___9 *, struct file___61 *, struct poll_table_struct___46 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___9 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___9 *, const struct bpf_map___9 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env___2 *, struct bpf_func_state___2 *, struct bpf_func_state___2 *);
	int (*map_for_each_callback)(struct bpf_map___9 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___9 *iter_seq_info;
};

struct bpf_map___9 {
	const struct bpf_map_ops___9 *ops;
	struct bpf_map___9 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___24 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___9;

struct bpf_jit_poke_descriptor___9;

struct bpf_prog_ops___9;

struct btf_mod_pair___9;

struct bpf_prog_offload___9;

struct bpf_prog_aux___9 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___9 *dst_prog;
	struct bpf_trampoline___9 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___9 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___9 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___9 *ops;
	struct bpf_map___9 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___9 *used_btfs;
	struct bpf_prog___9 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___9 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___9 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___9 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___9 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_verifier_stack_elem;

struct btf_mod_pair___9 {
	struct btf *btf;
	struct module___59 *module;
};

struct bpf_verifier_log {
	u32 level;
	char kbuf[1024];
	char *ubuf;
	u32 len_used;
	u32 len_total;
};

struct bpf_subprog_info {
	u32 start;
	u32 linfo_idx;
	u16 stack_depth;
	bool has_tail_call;
	bool tail_call_reachable;
	bool has_ld_abs;
	bool is_async_cb;
};

struct bpf_id_pair {
	u32 old;
	u32 cur;
};

struct bpf_verifier_ops___2;

struct bpf_verifier_state;

struct bpf_verifier_state_list;

struct bpf_insn_aux_data;

struct bpf_verifier_env___2 {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___9 *prog;
	const struct bpf_verifier_ops___2 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	bool test_state_freq;
	struct bpf_verifier_state *cur_state;
	struct bpf_verifier_state_list **explored_states;
	struct bpf_verifier_state_list *free_list;
	struct bpf_map___9 *used_maps[64];
	struct btf_mod_pair___9 used_btfs[64];
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 id_gen;
	bool explore_alu_limits;
	bool allow_ptr_leaks;
	bool allow_uninit_stack;
	bool allow_ptr_to_map_access;
	bool bpf_capable;
	bool bypass_spec_v1;
	bool bypass_spec_v4;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	struct bpf_id_pair idmap_scratch[75];
	struct {
		int *insn_state;
		int *insn_stack;
		int cur_stack;
	} cfg;
	u32 pass_cnt;
	u32 subprog_cnt;
	u32 prev_insn_processed;
	u32 insn_processed;
	u32 prev_jmps_processed;
	u32 jmps_processed;
	u64 verification_time;
	u32 max_states_per_insn;
	u32 total_states;
	u32 peak_states;
	u32 longest_mark_read_walk;
	bpfptr_t fd_array;
};

struct tnum {
	u64 value;
	u64 mask;
};

enum bpf_reg_liveness {
	REG_LIVE_NONE = 0,
	REG_LIVE_READ32 = 1,
	REG_LIVE_READ64 = 2,
	REG_LIVE_READ = 3,
	REG_LIVE_WRITTEN = 4,
	REG_LIVE_DONE = 8,
};

struct bpf_reg_state {
	enum bpf_reg_type type;
	s32 off;
	union {
		int range;
		struct {
			struct bpf_map___9 *map_ptr;
			u32 map_uid;
		};
		struct {
			struct btf *btf;
			u32 btf_id;
		};
		u32 mem_size;
		struct {
			long unsigned int raw1;
			long unsigned int raw2;
		} raw;
		u32 subprogno;
	};
	u32 id;
	u32 ref_obj_id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	s32 s32_min_value;
	s32 s32_max_value;
	u32 u32_min_value;
	u32 u32_max_value;
	struct bpf_reg_state *parent;
	u32 frameno;
	s32 subreg_def;
	enum bpf_reg_liveness live;
	bool precise;
};

struct bpf_reference_state;

struct bpf_stack_state;

struct bpf_func_state___2 {
	struct bpf_reg_state regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	u32 async_entry_cnt;
	bool in_callback_fn;
	bool in_async_callback_fn;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state *stack;
};

struct bpf_offloaded_map___9;

struct bpf_map_dev_ops___9 {
	int (*map_get_next_key)(struct bpf_offloaded_map___9 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___9 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___9 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___9 *, void *);
};

struct net_device___14;

struct bpf_offloaded_map___9 {
	struct bpf_map___9 map;
	struct net_device___14 *netdev;
	const struct bpf_map_dev_ops___9 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___11;

typedef rx_handler_result_t rx_handler_func_t___9(struct sk_buff___11 **);

typedef struct {
	struct net___12 *net;
} possible_net_t___9;

struct bpf_xdp_entity___9 {
	struct bpf_prog___9 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___9;

struct net_device_ops___9;

struct xfrmdev_ops___9;

struct header_ops___9;

struct netdev_rx_queue___9;

struct mini_Qdisc___9;

struct netdev_queue___9;

struct Qdisc___9;

struct rtnl_link_ops___9;

struct dcbnl_rtnl_ops___9;

struct net_device___14 {
	char name[16];
	struct netdev_name_node___9 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___9 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___9 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___9 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___60 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___9 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___9 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___9 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___9 *miniq_ingress;
	struct netdev_queue___9 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___9 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___9 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___9 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___9 = 0,
		NETREG_REGISTERED___9 = 1,
		NETREG_UNREGISTERING___9 = 2,
		NETREG_UNREGISTERED___9 = 3,
		NETREG_RELEASED___9 = 4,
		NETREG_DUMMY___9 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___9 = 0,
		RTNL_LINK_INITIALIZING___9 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___14 *);
	struct netpoll_info *npinfo;
	possible_net_t___9 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___54 dev;
	const struct attribute_group___60 *sysfs_groups[4];
	const struct attribute_group___60 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___9 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___9 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___9 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___3 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___9 *);
};

struct bpf_prog_ops___9 {
	int (*test_run)(struct bpf_prog___9 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___2 {
	const struct bpf_func_proto___3 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___9 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___9 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___9 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___9 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___9 {
	struct bpf_prog___9 *prog;
	struct net_device___14 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___9 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___9 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___59 *mod;
};

struct bpf_attach_target_info {
	struct btf_func_model fmodel;
	long int tgt_addr;
	const char *tgt_name;
	const struct btf_type *tgt_type;
};

struct bpf_jit_poke_descriptor___9 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___9 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct bpf_array_aux___3 {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___9 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_link_ops___2;

struct bpf_link___2 {
	atomic64_t refcnt;
	u32 id;
	enum bpf_link_type type;
	const struct bpf_link_ops___2 *ops;
	struct bpf_prog___9 *prog;
	struct work_struct work;
};

struct bpf_link_ops___2 {
	void (*release)(struct bpf_link___2 *);
	void (*dealloc)(struct bpf_link___2 *);
	int (*detach)(struct bpf_link___2 *);
	int (*update_prog)(struct bpf_link___2 *, struct bpf_prog___9 *, struct bpf_prog___9 *);
	void (*show_fdinfo)(const struct bpf_link___2 *, struct seq_file___58 *);
	int (*fill_link_info)(const struct bpf_link___2 *, struct bpf_link_info *);
};

struct bpf_link_primer {
	struct bpf_link___2 *link;
	struct file___61 *file;
	int fd;
	u32 id;
};

struct bpf_array___3 {
	struct bpf_map___9 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux___3 *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_array_item___9 {
	struct bpf_prog___9 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___9 {
	struct callback_head rcu;
	struct bpf_prog_array_item___9 items[0];
};

struct sk_buff___11 {
	union {
		struct {
			struct sk_buff___11 *next;
			struct sk_buff___11 *prev;
			union {
				struct net_device___14 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___8 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___11 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___11;

struct fqdir___11 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___11 *f;
	struct net___12 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___11;

struct inet_frags___11 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___11 *, const void *);
	void (*destructor)(struct inet_frag_queue___11 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct netns_ipv4___11 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___11 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___11 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___11 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___14 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___11 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___11 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___11 *);
	int (*local_out)(struct net___12 *, struct sock *, struct sk_buff___11 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___11 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___11 {
	struct dst_ops___11 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___11 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___11 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___11 *fqdir;
};

struct sk_buff_head___9 {
	struct sk_buff___11 *next;
	struct sk_buff___11 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___9 {
	struct bpf_prog_array___9 *run_array[2];
	struct bpf_prog___9 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___11 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___11 xfrm4_dst_ops;
	struct dst_ops___11 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___12 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___14 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___11 ipv4;
	struct netns_ipv6___11 ipv6;
	struct netns_ieee802154_lowpan___11 ieee802154_lowpan;
	struct netns_sctp___6 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___9 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___9 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___11 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___11 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___11 *fragments_tail;
	struct sk_buff___11 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___11 *fqdir;
	struct callback_head rcu;
};

struct fwnode_operations___54;

struct fwnode_handle___54 {
	struct fwnode_handle___54 *secondary;
	const struct fwnode_operations___54 *ops;
	struct device___54 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___54;

struct fwnode_endpoint___54;

struct fwnode_operations___54 {
	struct fwnode_handle___54 * (*get)(struct fwnode_handle___54 *);
	void (*put)(struct fwnode_handle___54 *);
	bool (*device_is_available)(const struct fwnode_handle___54 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___54 *, const struct device___54 *);
	bool (*property_present)(const struct fwnode_handle___54 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___54 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___54 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___54 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*get_parent)(const struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*get_next_child_node)(const struct fwnode_handle___54 *, struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*get_named_child_node)(const struct fwnode_handle___54 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___54 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___54 *);
	struct fwnode_handle___54 * (*graph_get_next_endpoint)(const struct fwnode_handle___54 *, struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*graph_get_remote_endpoint)(const struct fwnode_handle___54 *);
	struct fwnode_handle___54 * (*graph_get_port_parent)(struct fwnode_handle___54 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___54 *, struct fwnode_endpoint___54 *);
	int (*add_links)(struct fwnode_handle___54 *);
};

struct fwnode_endpoint___54 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___54 *local_fwnode;
};

struct fwnode_reference_args___54 {
	struct fwnode_handle___54 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___50 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___50 *root_cset;
};

struct dev_pm_ops___54 {
	int (*prepare)(struct device___54 *);
	void (*complete)(struct device___54 *);
	int (*suspend)(struct device___54 *);
	int (*resume)(struct device___54 *);
	int (*freeze)(struct device___54 *);
	int (*thaw)(struct device___54 *);
	int (*poweroff)(struct device___54 *);
	int (*restore)(struct device___54 *);
	int (*suspend_late)(struct device___54 *);
	int (*resume_early)(struct device___54 *);
	int (*freeze_late)(struct device___54 *);
	int (*thaw_early)(struct device___54 *);
	int (*poweroff_late)(struct device___54 *);
	int (*restore_early)(struct device___54 *);
	int (*suspend_noirq)(struct device___54 *);
	int (*resume_noirq)(struct device___54 *);
	int (*freeze_noirq)(struct device___54 *);
	int (*thaw_noirq)(struct device___54 *);
	int (*poweroff_noirq)(struct device___54 *);
	int (*restore_noirq)(struct device___54 *);
	int (*runtime_suspend)(struct device___54 *);
	int (*runtime_resume)(struct device___54 *);
	int (*runtime_idle)(struct device___54 *);
};

struct wakeup_source___54 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___54 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___54 {
	struct dev_pm_ops___54 ops;
	int (*start)(struct device___54 *);
	void (*detach)(struct device___54 *, bool);
	int (*activate)(struct device___54 *);
	void (*sync)(struct device___54 *);
	void (*dismiss)(struct device___54 *);
};

struct bus_type___54 {
	const char *name;
	const char *dev_name;
	struct device___54 *dev_root;
	const struct attribute_group___60 **bus_groups;
	const struct attribute_group___60 **dev_groups;
	const struct attribute_group___60 **drv_groups;
	int (*match)(struct device___54 *, struct device_driver___54 *);
	int (*uevent)(struct device___54 *, struct kobj_uevent_env *);
	int (*probe)(struct device___54 *);
	void (*sync_state)(struct device___54 *);
	void (*remove)(struct device___54 *);
	void (*shutdown)(struct device___54 *);
	int (*online)(struct device___54 *);
	int (*offline)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	int (*num_vf)(struct device___54 *);
	int (*dma_configure)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___54 {
	const char *name;
	struct bus_type___54 *bus;
	struct module___59 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___54 *);
	void (*sync_state)(struct device___54 *);
	int (*remove)(struct device___54 *);
	void (*shutdown)(struct device___54 *);
	int (*suspend)(struct device___54 *, pm_message_t);
	int (*resume)(struct device___54 *);
	const struct attribute_group___60 **groups;
	const struct attribute_group___60 **dev_groups;
	const struct dev_pm_ops___54 *pm;
	void (*coredump)(struct device___54 *);
	struct driver_private *p;
};

struct device_type___54 {
	const char *name;
	const struct attribute_group___60 **groups;
	int (*uevent)(struct device___54 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___54 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___54 *);
	const struct dev_pm_ops___54 *pm;
};

struct class___54 {
	const char *name;
	struct module___59 *owner;
	const struct attribute_group___60 **class_groups;
	const struct attribute_group___60 **dev_groups;
	struct kobject___60 *dev_kobj;
	int (*dev_uevent)(struct device___54 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___54 *, umode_t *);
	void (*class_release)(struct class___54 *);
	void (*dev_release)(struct device___54 *);
	int (*shutdown_pre)(struct device___54 *);
	const struct kobj_ns_type_operations___6 *ns_type;
	const void * (*namespace)(struct device___54 *);
	void (*get_ownership)(struct device___54 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___54 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___21;

struct pipe_buffer___21 {
	struct page___65 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___21 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___21 {
	int (*confirm)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
	void (*release)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
	bool (*try_steal)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
	bool (*get)(struct pipe_inode_info___21 *, struct pipe_buffer___21 *);
};

struct dcbnl_rtnl_ops___9 {
	int (*ieee_getets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___14 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___14 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___14 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___14 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___14 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___14 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___14 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___14 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___14 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___14 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___14 *);
	u8 (*setstate)(struct net_device___14 *, u8);
	void (*getpermhwaddr)(struct net_device___14 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___14 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___14 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___14 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___14 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___14 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___14 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___14 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___14 *, int, u8 *);
	void (*setpfccfg)(struct net_device___14 *, int, u8);
	void (*getpfccfg)(struct net_device___14 *, int, u8 *);
	u8 (*setall)(struct net_device___14 *);
	u8 (*getcap)(struct net_device___14 *, int, u8 *);
	int (*getnumtcs)(struct net_device___14 *, int, u8 *);
	int (*setnumtcs)(struct net_device___14 *, int, u8);
	u8 (*getpfcstate)(struct net_device___14 *);
	void (*setpfcstate)(struct net_device___14 *, u8);
	void (*getbcncfg)(struct net_device___14 *, int, u32 *);
	void (*setbcncfg)(struct net_device___14 *, int, u32);
	void (*getbcnrp)(struct net_device___14 *, int, u8 *);
	void (*setbcnrp)(struct net_device___14 *, int, u8);
	int (*setapp)(struct net_device___14 *, u8, u16, u8);
	int (*getapp)(struct net_device___14 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___14 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___14 *, int, u8);
	u8 (*getdcbx)(struct net_device___14 *);
	u8 (*setdcbx)(struct net_device___14 *, u8);
	int (*peer_getappinfo)(struct net_device___14 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___14 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___14 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___14 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___14 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___14 *, struct dcbnl_buffer *);
};

struct cftype___50;

struct cgroup_subsys___50 {
	struct cgroup_subsys_state___50 * (*css_alloc)(struct cgroup_subsys_state___50 *);
	int (*css_online)(struct cgroup_subsys_state___50 *);
	void (*css_offline)(struct cgroup_subsys_state___50 *);
	void (*css_released)(struct cgroup_subsys_state___50 *);
	void (*css_free)(struct cgroup_subsys_state___50 *);
	void (*css_reset)(struct cgroup_subsys_state___50 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___50 *, int);
	int (*css_extra_stat_show)(struct seq_file___58 *, struct cgroup_subsys_state___50 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___66 *, struct css_set___50 *);
	void (*cancel_fork)(struct task_struct___66 *, struct css_set___50 *);
	void (*fork)(struct task_struct___66 *);
	void (*exit)(struct task_struct___66 *);
	void (*release)(struct task_struct___66 *);
	void (*bind)(struct cgroup_subsys_state___50 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___50 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___50 *dfl_cftypes;
	struct cftype___50 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___50 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___50 *updated_children;
	struct cgroup___50 *updated_next;
};

struct cgroup_root___50 {
	struct kernfs_root___60 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___50 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___50 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___50 *ss;
	struct list_head node;
	struct kernfs_ops___60 *kf_ops;
	int (*open)(struct kernfs_open_file___60 *);
	void (*release)(struct kernfs_open_file___60 *);
	u64 (*read_u64)(struct cgroup_subsys_state___50 *, struct cftype___50 *);
	s64 (*read_s64)(struct cgroup_subsys_state___50 *, struct cftype___50 *);
	int (*seq_show)(struct seq_file___58 *, void *);
	void * (*seq_start)(struct seq_file___58 *, loff_t *);
	void * (*seq_next)(struct seq_file___58 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___58 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___50 *, struct cftype___50 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___50 *, struct cftype___50 *, s64);
	ssize_t (*write)(struct kernfs_open_file___60 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___60 *, struct poll_table_struct___46 *);
};

struct xdp_rxq_info___9 {
	struct net_device___14 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___9 {
	struct net_device___14 *dev;
};

struct xdp_buff___9 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___9 *rxq;
	struct xdp_txq_info___9 *txq;
	u32 frame_sz;
};

struct xdp_frame___9 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___14 *dev_rx;
};

struct netlink_callback___9 {
	struct sk_buff___11 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___11 *, struct netlink_callback___9 *);
	int (*done)(struct netlink_callback___9 *);
	void *data;
	struct module___59 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___9 {
	int (*create)(struct sk_buff___11 *, struct net_device___14 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___11 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___14 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___11 *);
};

struct netdev_queue___9 {
	struct net_device___14 *dev;
	struct Qdisc___9 *qdisc;
	struct Qdisc___9 *qdisc_sleeping;
	struct kobject___60 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___14 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___9 {
	struct sk_buff___11 *head;
	struct sk_buff___11 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___9;

struct Qdisc___9 {
	int (*enqueue)(struct sk_buff___11 *, struct Qdisc___9 *, struct sk_buff___11 **);
	struct sk_buff___11 * (*dequeue)(struct Qdisc___9 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___9 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___9 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___9 gso_skb;
	struct qdisc_skb_head___9 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___9 *next_sched;
	struct sk_buff_head___9 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___9 {
	struct xdp_rxq_info___9 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___60 kobj;
	struct net_device___14 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___9 {
	enum net_device_path_type type;
	const struct net_device___14 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___9 = 0,
				DEV_PATH_BR_VLAN_TAG___9 = 1,
				DEV_PATH_BR_VLAN_UNTAG___9 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___9 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___9 {
	const struct net_device___14 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___9 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___9 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___9 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___9 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___11 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___9 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___14 *dev;
	const char *name;
};

struct net_device_ops___9 {
	int (*ndo_init)(struct net_device___14 *);
	void (*ndo_uninit)(struct net_device___14 *);
	int (*ndo_open)(struct net_device___14 *);
	int (*ndo_stop)(struct net_device___14 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___11 *, struct net_device___14 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___11 *, struct net_device___14 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___14 *, struct sk_buff___11 *, struct net_device___14 *);
	void (*ndo_change_rx_flags)(struct net_device___14 *, int);
	void (*ndo_set_rx_mode)(struct net_device___14 *);
	int (*ndo_set_mac_address)(struct net_device___14 *, void *);
	int (*ndo_validate_addr)(struct net_device___14 *);
	int (*ndo_do_ioctl)(struct net_device___14 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___14 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___14 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___14 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___14 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___14 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___14 *, int);
	int (*ndo_neigh_setup)(struct net_device___14 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___14 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___14 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___14 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___14 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___14 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___14 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___14 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___14 *);
	int (*ndo_netpoll_setup)(struct net_device___14 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___14 *);
	int (*ndo_set_vf_mac)(struct net_device___14 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___14 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___14 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___14 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___14 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___14 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___14 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___14 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___14 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___14 *, int, struct sk_buff___11 *);
	int (*ndo_get_vf_guid)(struct net_device___14 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___14 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___14 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___14 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___14 *);
	int (*ndo_fcoe_disable)(struct net_device___14 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___14 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___14 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___14 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___14 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___14 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___14 *, const struct sk_buff___11 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___14 *, struct net_device___14 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___14 *, struct net_device___14 *);
	struct net_device___14 * (*ndo_get_xmit_slave)(struct net_device___14 *, struct sk_buff___11 *, bool);
	struct net_device___14 * (*ndo_sk_get_lower_dev)(struct net_device___14 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___14 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___14 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___14 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___14 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___11 *, struct netlink_callback___9 *, struct net_device___14 *, struct net_device___14 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___11 *, struct nlattr **, struct net_device___14 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___14 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___11 *, u32, u32, struct net_device___14 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___14 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___14 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___14 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___14 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___14 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___14 *, struct net_device___14 *);
	void (*ndo_dfwd_del_station)(struct net_device___14 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___14 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___14 *);
	int (*ndo_change_proto_down)(struct net_device___14 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___14 *, struct sk_buff___11 *);
	void (*ndo_set_rx_headroom)(struct net_device___14 *, int);
	int (*ndo_bpf)(struct net_device___14 *, struct netdev_bpf___9 *);
	int (*ndo_xdp_xmit)(struct net_device___14 *, int, struct xdp_frame___9 **, u32);
	struct net_device___14 * (*ndo_xdp_get_xmit_slave)(struct net_device___14 *, struct xdp_buff___9 *);
	int (*ndo_xsk_wakeup)(struct net_device___14 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___14 *);
	int (*ndo_tunnel_ctl)(struct net_device___14 *, struct ip_tunnel_parm *, int);
	struct net_device___14 * (*ndo_get_peer_dev)(struct net_device___14 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___9 *, struct net_device_path___9 *);
};

struct tcf_proto___9;

struct tcf_block___9;

struct mini_Qdisc___9 {
	struct tcf_proto___9 *filter_list;
	struct tcf_block___9 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___9 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___14 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___14 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___12 *, struct net_device___14 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___14 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___14 *, struct list_head *);
	size_t (*get_size)(const struct net_device___14 *);
	int (*fill_info)(struct sk_buff___11 *, const struct net_device___14 *);
	size_t (*get_xstats_size)(const struct net_device___14 *);
	int (*fill_xstats)(struct sk_buff___11 *, const struct net_device___14 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___14 *, struct net_device___14 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___14 *, const struct net_device___14 *);
	int (*fill_slave_info)(struct sk_buff___11 *, const struct net_device___14 *, const struct net_device___14 *);
	struct net___12 * (*get_link_net)(const struct net_device___14 *);
	size_t (*get_linkxstats_size)(const struct net_device___14 *, int);
	int (*fill_linkxstats)(struct sk_buff___11 *, const struct net_device___14 *, int *, int);
};

struct gnet_dump___9 {
	spinlock_t *lock;
	struct sk_buff___11 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___9;

struct Qdisc_ops___9 {
	struct Qdisc_ops___9 *next;
	const struct Qdisc_class_ops___9 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___11 *, struct Qdisc___9 *, struct sk_buff___11 **);
	struct sk_buff___11 * (*dequeue)(struct Qdisc___9 *);
	struct sk_buff___11 * (*peek)(struct Qdisc___9 *);
	int (*init)(struct Qdisc___9 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___9 *);
	void (*destroy)(struct Qdisc___9 *);
	int (*change)(struct Qdisc___9 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___9 *);
	int (*change_tx_queue_len)(struct Qdisc___9 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___9 *, unsigned int);
	int (*dump)(struct Qdisc___9 *, struct sk_buff___11 *);
	int (*dump_stats)(struct Qdisc___9 *, struct gnet_dump___9 *);
	void (*ingress_block_set)(struct Qdisc___9 *, u32);
	void (*egress_block_set)(struct Qdisc___9 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___9 *);
	u32 (*egress_block_get)(struct Qdisc___9 *);
	struct module___59 *owner;
};

struct Qdisc_class_ops___9 {
	unsigned int flags;
	struct netdev_queue___9 * (*select_queue)(struct Qdisc___9 *, struct tcmsg *);
	int (*graft)(struct Qdisc___9 *, long unsigned int, struct Qdisc___9 *, struct Qdisc___9 **, struct netlink_ext_ack *);
	struct Qdisc___9 * (*leaf)(struct Qdisc___9 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___9 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___9 *, u32);
	int (*change)(struct Qdisc___9 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___9 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___9 *, struct qdisc_walker *);
	struct tcf_block___9 * (*tcf_block)(struct Qdisc___9 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___9 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___9 *, long unsigned int);
	int (*dump)(struct Qdisc___9 *, long unsigned int, struct sk_buff___11 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___9 *, long unsigned int, struct gnet_dump___9 *);
};

struct tcf_chain___9;

struct tcf_block___9 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___12 *net;
	struct Qdisc___9 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___9 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___9;

struct tcf_proto_ops___9;

struct tcf_proto___9 {
	struct tcf_proto___9 *next;
	void *root;
	int (*classify)(struct sk_buff___11 *, const struct tcf_proto___9 *, struct tcf_result___9 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___9 *ops;
	struct tcf_chain___9 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___9 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___9 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___9 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___11 *, const struct tcf_proto___9 *, struct tcf_result___9 *);
	int (*init)(struct tcf_proto___9 *);
	void (*destroy)(struct tcf_proto___9 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___9 *, u32);
	void (*put)(struct tcf_proto___9 *, void *);
	int (*change)(struct net___12 *, struct sk_buff___11 *, struct tcf_proto___9 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___9 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___9 *);
	void (*walk)(struct tcf_proto___9 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___9 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___9 *, void *);
	void (*hw_del)(struct tcf_proto___9 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___12 *, struct tcf_chain___9 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___12 *, struct tcf_proto___9 *, void *, struct sk_buff___11 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___12 *, struct tcf_proto___9 *, void *, struct sk_buff___11 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___11 *, struct net___12 *, void *);
	struct module___59 *owner;
	int flags;
};

struct tcf_chain___9 {
	struct mutex filter_chain_lock;
	struct tcf_proto___9 *filter_chain;
	struct list_head list;
	struct tcf_block___9 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___9 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_stack_state {
	struct bpf_reg_state spilled_ptr;
	u8 slot_type[8];
};

struct bpf_reference_state {
	int id;
	int insn_idx;
};

struct bpf_idx_pair {
	u32 prev_idx;
	u32 idx;
};

struct bpf_verifier_state {
	struct bpf_func_state___2 *frame[8];
	struct bpf_verifier_state *parent;
	u32 branches;
	u32 insn_idx;
	u32 curframe;
	u32 active_spin_lock;
	bool speculative;
	u32 first_insn_idx;
	u32 last_insn_idx;
	struct bpf_idx_pair *jmp_history;
	u32 jmp_history_cnt;
};

struct bpf_verifier_state_list {
	struct bpf_verifier_state state;
	struct bpf_verifier_state_list *next;
	int miss_cnt;
	int hit_cnt;
};

struct bpf_insn_aux_data {
	union {
		enum bpf_reg_type ptr_type;
		long unsigned int map_ptr_state;
		s32 call_imm;
		u32 alu_limit;
		struct {
			u32 map_index;
			u32 map_off;
		};
		struct {
			enum bpf_reg_type reg_type;
			union {
				struct {
					struct btf *btf;
					u32 btf_id;
				};
				u32 mem_size;
			};
		} btf_var;
	};
	u64 map_key_state;
	int ctx_field_size;
	u32 seen;
	bool sanitize_stack_spill;
	bool zext_dst;
	u8 alu_state;
	unsigned int orig_idx;
	bool prune_point;
};

enum perf_bpf_event_type {
	PERF_BPF_EVENT_UNKNOWN = 0,
	PERF_BPF_EVENT_PROG_LOAD = 1,
	PERF_BPF_EVENT_PROG_UNLOAD = 2,
	PERF_BPF_EVENT_MAX = 3,
};

struct perf_cpu_context___42;

struct perf_output_handle___42;

struct pmu___42 {
	struct list_head entry;
	struct module___59 *module;
	struct device___54 *dev;
	const struct attribute_group___60 **attr_groups;
	const struct attribute_group___60 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___42 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___42 *);
	void (*pmu_disable)(struct pmu___42 *);
	int (*event_init)(struct perf_event___42 *);
	void (*event_mapped)(struct perf_event___42 *, struct mm_struct___66 *);
	void (*event_unmapped)(struct perf_event___42 *, struct mm_struct___66 *);
	int (*add)(struct perf_event___42 *, int);
	void (*del)(struct perf_event___42 *, int);
	void (*start)(struct perf_event___42 *, int);
	void (*stop)(struct perf_event___42 *, int);
	void (*read)(struct perf_event___42 *);
	void (*start_txn)(struct pmu___42 *, unsigned int);
	int (*commit_txn)(struct pmu___42 *);
	void (*cancel_txn)(struct pmu___42 *);
	int (*event_idx)(struct perf_event___42 *);
	void (*sched_task)(struct perf_event_context___42 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___42 *, struct perf_event_context___42 *);
	void * (*setup_aux)(struct perf_event___42 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___42 *, struct perf_output_handle___42 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___42 *);
	int (*aux_output_match)(struct perf_event___42 *);
	int (*filter_match)(struct perf_event___42 *);
	int (*check_period)(struct perf_event___42 *, u64);
};

struct perf_cpu_context___42 {
	struct perf_event_context___42 ctx;
	struct perf_event_context___42 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___42 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___42 **heap;
	struct perf_event___42 *heap_default[2];
};

struct perf_output_handle___42 {
	struct perf_event___42 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___42 {
	struct cgroup_subsys_state___50 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___37 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___37 *);
	};
};

struct trace_event_class___37 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___37 *, enum trace_reg, void *);
	struct trace_event_fields___37 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___37 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___37 *);
};

struct syscall_metadata___15 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___37 *enter_event;
	struct trace_event_call___37 *exit_event;
};

struct block_device_operations___27;

struct gendisk___27 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___28 *part0;
	const struct block_device_operations___27 *fops;
	struct request_queue___28 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___26 *bdi;
	struct kobject___60 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___60 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___27 {
	struct bio___27 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___32 *bip_vec;
	struct bio_vec___32 bip_inline_vecs[0];
};

struct blkcg___26;

struct blkg_policy_data___26;

struct blkcg_gq___26 {
	struct request_queue___28 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___26 *blkcg;
	struct blkcg_gq___26 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___26 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___27 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___27(struct request___27 *);

typedef void integrity_complete_fn___27(struct request___27 *, unsigned int);

struct blk_integrity_profile___27 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___27 *prepare_fn;
	integrity_complete_fn___27 *complete_fn;
	const char *name;
};

struct block_device_operations___27 {
	blk_qc_t (*submit_bio)(struct bio___27 *);
	int (*open)(struct block_device___28 *, fmode_t);
	void (*release)(struct gendisk___27 *, fmode_t);
	int (*rw_page)(struct block_device___28 *, sector_t, struct page___65 *, unsigned int);
	int (*ioctl)(struct block_device___28 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___28 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___27 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___27 *);
	int (*getgeo)(struct block_device___28 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___28 *, bool);
	void (*swap_slot_free_notify)(struct block_device___28 *, long unsigned int);
	int (*report_zones)(struct gendisk___27 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___27 *, umode_t *);
	struct module___59 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___27 *, sector_t *);
};

typedef void rq_end_io_fn___27(struct request___27 *, blk_status_t);

struct request___27 {
	struct request_queue___28 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___26 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___27 *bio;
	struct bio___27 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___32 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___27 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___27 *saved_end_io;
		} flush;
	};
	struct gendisk___27 *rq_disk;
	struct block_device___28 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___27 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___26 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___28 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___60 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___61 *debugfs_dir;
	struct dentry___61 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___27;

struct elevator_mq_ops___27 {
	int (*init_sched)(struct request_queue___28 *, struct elevator_type___27 *);
	void (*exit_sched)(struct elevator_queue___27 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___26 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___26 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___26 *);
	bool (*allow_merge)(struct request_queue___28 *, struct request___27 *, struct bio___27 *);
	bool (*bio_merge)(struct request_queue___28 *, struct bio___27 *, unsigned int);
	int (*request_merge)(struct request_queue___28 *, struct request___27 **, struct bio___27 *);
	void (*request_merged)(struct request_queue___28 *, struct request___27 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___28 *, struct request___27 *, struct request___27 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___27 *);
	void (*finish_request)(struct request___27 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___26 *, struct list_head *, bool);
	struct request___27 * (*dispatch_request)(struct blk_mq_hw_ctx___26 *);
	bool (*has_work)(struct blk_mq_hw_ctx___26 *);
	void (*completed_request)(struct request___27 *, u64);
	void (*requeue_request)(struct request___27 *);
	struct request___27 * (*former_request)(struct request_queue___28 *, struct request___27 *);
	struct request___27 * (*next_request)(struct request_queue___28 *, struct request___27 *);
	void (*init_icq)(struct io_cq___27 *);
	void (*exit_icq)(struct io_cq___27 *);
};

struct elv_fs_entry___27;

struct elevator_type___27 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___27 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___27 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___59 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___27 {
	struct elevator_type___27 *type;
	void *elevator_data;
	struct kobject___60 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___27 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___27 *, char *);
	ssize_t (*store)(struct elevator_queue___27 *, const char *, size_t);
};

struct blk_mq_queue_data___26;

struct blk_mq_ops___26 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___26 *, const struct blk_mq_queue_data___26 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___26 *);
	int (*get_budget)(struct request_queue___28 *);
	void (*put_budget)(struct request_queue___28 *, int);
	void (*set_rq_budget_token)(struct request___27 *, int);
	int (*get_rq_budget_token)(struct request___27 *);
	enum blk_eh_timer_return (*timeout)(struct request___27 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___26 *);
	void (*complete)(struct request___27 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___26 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___26 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___26 *, struct request___27 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___26 *, struct request___27 *, unsigned int);
	void (*initialize_rq_fn)(struct request___27 *);
	void (*cleanup_rq)(struct request___27 *);
	bool (*busy)(struct request_queue___28 *);
	int (*map_queues)(struct blk_mq_tag_set___26 *);
	void (*show_rq)(struct seq_file___58 *, struct request___27 *);
};

struct blk_mq_tag_set___26 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___26 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___26 {
	struct request___27 *rq;
	bool last;
};

struct blkcg_policy_data___26;

struct blkcg___26 {
	struct cgroup_subsys_state___50 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___26 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___26 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___26 {
	struct blkcg___26 *blkcg;
	int plid;
};

struct blkg_policy_data___26 {
	struct blkcg_gq___26 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___24 {
	struct mem_cgroup___24 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___24 {
	struct lruvec___25 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___24 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___24 *memcg;
};

struct obj_cgroup___24 {
	struct percpu_ref refcnt;
	struct mem_cgroup___24 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum bpf_audit {
	BPF_AUDIT_LOAD = 0,
	BPF_AUDIT_UNLOAD = 1,
	BPF_AUDIT_MAX = 2,
};

struct bpf_prog_kstats {
	u64 nsecs;
	u64 cnt;
	u64 misses;
};

struct bpf_tracing_link {
	struct bpf_link___2 link;
	enum bpf_attach_type attach_type;
	struct bpf_trampoline___9 *trampoline;
	struct bpf_prog___9 *tgt_prog;
};

struct bpf_raw_tp_link {
	struct bpf_link___2 link;
	struct bpf_raw_event_map *btp;
};

struct bpf_perf_link {
	struct bpf_link___2 link;
	struct file___61 *perf_file;
};

typedef u64 (*btf_bpf_sys_bpf)(int, void *, u32);

typedef u64 (*btf_bpf_sys_close)(u32);

struct btf_member {
	__u32 name_off;
	__u32 type;
	__u32 offset;
};

struct btf_param {
	__u32 name_off;
	__u32 type;
};

enum btf_func_linkage {
	BTF_FUNC_STATIC = 0,
	BTF_FUNC_GLOBAL = 1,
	BTF_FUNC_EXTERN = 2,
};

struct btf_var_secinfo {
	__u32 type;
	__u32 offset;
	__u32 size;
};

enum sk_action {
	SK_DROP = 0,
	SK_PASS = 1,
};

struct bpf_verifier_ops___3;

struct bpf_verifier_stack_elem___2;

struct bpf_verifier_state___2;

struct bpf_verifier_state_list___2;

struct bpf_verifier_env {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___6 *prog;
	const struct bpf_verifier_ops___3 *ops;
	struct bpf_verifier_stack_elem___2 *head;
	int stack_size;
	bool strict_alignment;
	bool test_state_freq;
	struct bpf_verifier_state___2 *cur_state;
	struct bpf_verifier_state_list___2 **explored_states;
	struct bpf_verifier_state_list___2 *free_list;
	struct bpf_map___6 *used_maps[64];
	struct btf_mod_pair___6 used_btfs[64];
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 id_gen;
	bool explore_alu_limits;
	bool allow_ptr_leaks;
	bool allow_uninit_stack;
	bool allow_ptr_to_map_access;
	bool bpf_capable;
	bool bypass_spec_v1;
	bool bypass_spec_v4;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	struct bpf_id_pair idmap_scratch[75];
	struct {
		int *insn_state;
		int *insn_stack;
		int cur_stack;
	} cfg;
	u32 pass_cnt;
	u32 subprog_cnt;
	u32 prev_insn_processed;
	u32 insn_processed;
	u32 prev_jmps_processed;
	u32 jmps_processed;
	u64 verification_time;
	u32 max_states_per_insn;
	u32 total_states;
	u32 peak_states;
	u32 longest_mark_read_walk;
	bpfptr_t fd_array;
};

struct bpf_reg_state___2 {
	enum bpf_reg_type type;
	s32 off;
	union {
		int range;
		struct {
			struct bpf_map___6 *map_ptr;
			u32 map_uid;
		};
		struct {
			struct btf *btf;
			u32 btf_id;
		};
		u32 mem_size;
		struct {
			long unsigned int raw1;
			long unsigned int raw2;
		} raw;
		u32 subprogno;
	};
	u32 id;
	u32 ref_obj_id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	s32 s32_min_value;
	s32 s32_max_value;
	u32 u32_min_value;
	u32 u32_max_value;
	struct bpf_reg_state___2 *parent;
	u32 frameno;
	s32 subreg_def;
	enum bpf_reg_liveness live;
	bool precise;
};

struct bpf_stack_state___2;

struct bpf_func_state {
	struct bpf_reg_state___2 regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	u32 async_entry_cnt;
	bool in_callback_fn;
	bool in_async_callback_fn;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state___2 *stack;
};

struct bpf_func_proto___4 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___6 *);
};

struct bpf_verifier_ops___3 {
	const struct bpf_func_proto___4 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___6 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___6 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___6 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___6 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_kfunc_desc {
	struct btf_func_model func_model;
	u32 func_id;
	s32 imm;
};

struct bpf_kfunc_desc_tab {
	struct bpf_kfunc_desc descs[256];
	u32 nr_descs;
};

struct bpf_array_aux___4 {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___6 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_struct_ops {
	const struct bpf_verifier_ops___3 *verifier_ops;
	int (*init)(struct btf *);
	int (*check_member)(const struct btf_type *, const struct btf_member *);
	int (*init_member)(const struct btf_type *, const struct btf_member *, void *, const void *);
	int (*reg)(void *);
	void (*unreg)(void *);
	const struct btf_type *type;
	const struct btf_type *value_type;
	const char *name;
	struct btf_func_model func_models[64];
	u32 type_id;
	u32 value_id;
};

struct bpf_array___4 {
	struct bpf_map___6 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux___4 *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef u32 (*bpf_convert_ctx_access_t)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___6 *, u32 *);

enum bpf_stack_slot_type {
	STACK_INVALID = 0,
	STACK_SPILL = 1,
	STACK_MISC = 2,
	STACK_ZERO = 3,
};

struct bpf_stack_state___2 {
	struct bpf_reg_state___2 spilled_ptr;
	u8 slot_type[8];
};

struct bpf_verifier_state___2 {
	struct bpf_func_state *frame[8];
	struct bpf_verifier_state___2 *parent;
	u32 branches;
	u32 insn_idx;
	u32 curframe;
	u32 active_spin_lock;
	bool speculative;
	u32 first_insn_idx;
	u32 last_insn_idx;
	struct bpf_idx_pair *jmp_history;
	u32 jmp_history_cnt;
};

struct bpf_verifier_state_list___2 {
	struct bpf_verifier_state___2 state;
	struct bpf_verifier_state_list___2 *next;
	int miss_cnt;
	int hit_cnt;
};

struct bpf_verifier_stack_elem___2 {
	struct bpf_verifier_state___2 st;
	int insn_idx;
	int prev_insn_idx;
	struct bpf_verifier_stack_elem___2 *next;
	u32 log_pos;
};

enum {
	BTF_SOCK_TYPE_INET = 0,
	BTF_SOCK_TYPE_INET_CONN = 1,
	BTF_SOCK_TYPE_INET_REQ = 2,
	BTF_SOCK_TYPE_INET_TW = 3,
	BTF_SOCK_TYPE_REQ = 4,
	BTF_SOCK_TYPE_SOCK = 5,
	BTF_SOCK_TYPE_SOCK_COMMON = 6,
	BTF_SOCK_TYPE_TCP = 7,
	BTF_SOCK_TYPE_TCP_REQ = 8,
	BTF_SOCK_TYPE_TCP_TW = 9,
	BTF_SOCK_TYPE_TCP6 = 10,
	BTF_SOCK_TYPE_UDP = 11,
	BTF_SOCK_TYPE_UDP6 = 12,
	BTF_SOCK_TYPE_UNIX = 13,
	MAX_BTF_SOCK_TYPE = 14,
};

typedef void (*bpf_insn_print_t)(void *, const char *, ...);

typedef const char * (*bpf_insn_revmap_call_t)(void *, const struct bpf_insn *);

typedef const char * (*bpf_insn_print_imm_t)(void *, const struct bpf_insn *, __u64);

struct bpf_insn_cbs {
	bpf_insn_print_t cb_print;
	bpf_insn_revmap_call_t cb_call;
	bpf_insn_print_imm_t cb_imm;
	void *private_data;
};

struct bpf_call_arg_meta {
	struct bpf_map___6 *map_ptr;
	bool raw_mode;
	bool pkt_access;
	int regno;
	int access_size;
	int mem_size;
	u64 msize_max_value;
	int ref_obj_id;
	int map_uid;
	int func_id;
	struct btf *btf;
	u32 btf_id;
	struct btf *ret_btf;
	u32 ret_btf_id;
	u32 subprogno;
};

enum reg_arg_type {
	SRC_OP = 0,
	DST_OP = 1,
	DST_OP_NO_MARK = 2,
};

enum stack_access_src {
	ACCESS_DIRECT = 1,
	ACCESS_HELPER = 2,
};

struct bpf_reg_types {
	const enum bpf_reg_type types[10];
	u32 *btf_id;
};

enum {
	AT_PKT_END = 4294967295,
	BEYOND_PKT_END = 4294967294,
};

typedef int (*set_callee_state_fn)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *, int);

enum {
	REASON_BOUNDS = 4294967295,
	REASON_TYPE = 4294967294,
	REASON_PATHS = 4294967293,
	REASON_LIMIT = 4294967292,
	REASON_STACK = 4294967291,
};

struct bpf_sanitize_info {
	struct bpf_insn_aux_data aux;
	bool mask_to_left;
};

enum {
	DISCOVERED = 16,
	EXPLORED = 32,
	FALLTHROUGH = 1,
	BRANCH = 2,
};

enum {
	DONE_EXPLORING = 0,
	KEEP_EXPLORING = 1,
};

struct tree_descr {
	const char *name;
	const struct file_operations___2 *ops;
	int mode;
};

struct bpf_link_ops___3;

struct bpf_link___3 {
	atomic64_t refcnt;
	u32 id;
	enum bpf_link_type type;
	const struct bpf_link_ops___3 *ops;
	struct bpf_prog *prog;
	struct work_struct work;
};

struct bpf_link_ops___3 {
	void (*release)(struct bpf_link___3 *);
	void (*dealloc)(struct bpf_link___3 *);
	int (*detach)(struct bpf_link___3 *);
	int (*update_prog)(struct bpf_link___3 *, struct bpf_prog *, struct bpf_prog *);
	void (*show_fdinfo)(const struct bpf_link___3 *, struct seq_file___4 *);
	int (*fill_link_info)(const struct bpf_link___3 *, struct bpf_link_info *);
};

struct umd_info___2 {
	const char *driver_name;
	struct file___3 *pipe_to_umh;
	struct file___3 *pipe_from_umh;
	struct path___2 wd;
	struct pid___2 *tgid;
};

struct bpf_preload_info {
	char link_name[16];
	int link_id;
};

struct bpf_preload_ops {
	struct umd_info___2 info;
	int (*preload)(struct bpf_preload_info *);
	int (*finish)();
	struct module___5 *owner;
};

enum bpf_type {
	BPF_TYPE_UNSPEC = 0,
	BPF_TYPE_PROG = 1,
	BPF_TYPE_MAP = 2,
	BPF_TYPE_LINK = 3,
};

struct map_iter {
	void *key;
	bool done;
};

enum {
	OPT_MODE = 0,
};

struct bpf_mount_opts {
	umode_t mode;
};

struct bpf_spin_lock {
	__u32 val;
};

struct bpf_pidns_info {
	__u32 pid;
	__u32 tgid;
};

struct bpf_func_proto___5 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___4 *);
};

struct bpf_array_aux___5 {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___4 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_array___5 {
	struct bpf_map___4 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux___5 *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_cg_run_ctx {
	struct bpf_run_ctx run_ctx;
	const struct bpf_prog_array_item___4 *prog_item;
};

typedef u64 (*btf_bpf_map_lookup_elem)(struct bpf_map___4 *, void *);

typedef u64 (*btf_bpf_map_update_elem)(struct bpf_map___4 *, void *, void *, u64);

typedef u64 (*btf_bpf_map_delete_elem)(struct bpf_map___4 *, void *);

typedef u64 (*btf_bpf_map_push_elem)(struct bpf_map___4 *, void *, u64);

typedef u64 (*btf_bpf_map_pop_elem)(struct bpf_map___4 *, void *);

typedef u64 (*btf_bpf_map_peek_elem)(struct bpf_map___4 *, void *);

typedef u64 (*btf_bpf_get_smp_processor_id)();

typedef u64 (*btf_bpf_get_numa_node_id)();

typedef u64 (*btf_bpf_ktime_get_ns)();

typedef u64 (*btf_bpf_ktime_get_boot_ns)();

typedef u64 (*btf_bpf_ktime_get_coarse_ns)();

typedef u64 (*btf_bpf_get_current_pid_tgid)();

typedef u64 (*btf_bpf_get_current_uid_gid)();

typedef u64 (*btf_bpf_get_current_comm)(char *, u32);

typedef u64 (*btf_bpf_spin_lock)(struct bpf_spin_lock *);

typedef u64 (*btf_bpf_spin_unlock)(struct bpf_spin_lock *);

typedef u64 (*btf_bpf_jiffies64)();

typedef u64 (*btf_bpf_get_current_cgroup_id)();

typedef u64 (*btf_bpf_get_current_ancestor_cgroup_id)(int);

typedef u64 (*btf_bpf_get_local_storage)(struct bpf_map___4 *, u64);

typedef u64 (*btf_bpf_strtol)(const char *, size_t, u64, long int *);

typedef u64 (*btf_bpf_strtoul)(const char *, size_t, u64, long unsigned int *);

typedef u64 (*btf_bpf_get_ns_current_pid_tgid)(u64, u64, struct bpf_pidns_info *, u32);

typedef u64 (*btf_bpf_event_output_data)(void *, struct bpf_map___4 *, u64, void *, u64);

typedef u64 (*btf_bpf_copy_from_user)(void *, u32, const void *);

typedef u64 (*btf_bpf_per_cpu_ptr)(const void *, u32);

typedef u64 (*btf_bpf_this_cpu_ptr)(const void *);

struct bpf_bprintf_buffers {
	char tmp_bufs[1536];
};

typedef u64 (*btf_bpf_snprintf)(char *, u32, char *, const void *, u32);

struct bpf_hrtimer {
	struct hrtimer timer;
	struct bpf_map___4 *map;
	struct bpf_prog___4 *prog;
	void *callback_fn;
	void *value;
};

struct bpf_timer_kern {
	struct bpf_hrtimer *timer;
	struct bpf_spin_lock lock;
};

typedef u64 (*btf_bpf_timer_init)(struct bpf_timer_kern *, struct bpf_map___4 *, u64);

typedef u64 (*btf_bpf_timer_set_callback)(struct bpf_timer_kern *, void *, struct bpf_prog_aux___4 *);

typedef u64 (*btf_bpf_timer_start)(struct bpf_timer_kern *, u64, u64);

typedef u64 (*btf_bpf_timer_cancel)(struct bpf_timer_kern *);

union bpf_iter_link_info {
	struct {
		__u32 map_fd;
	} map;
};

typedef int (*bpf_iter_attach_target_t)(struct bpf_prog___9 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___9 *);

typedef void (*bpf_iter_detach_target_t)(struct bpf_iter_aux_info___9 *);

typedef void (*bpf_iter_show_fdinfo_t)(const struct bpf_iter_aux_info___9 *, struct seq_file___58 *);

typedef int (*bpf_iter_fill_link_info_t)(const struct bpf_iter_aux_info___9 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___5 * (*bpf_iter_get_func_proto_t)(enum bpf_func_id, const struct bpf_prog___9 *);

enum bpf_iter_feature {
	BPF_ITER_RESCHED = 1,
};

struct bpf_iter_reg {
	const char *target;
	bpf_iter_attach_target_t attach_target;
	bpf_iter_detach_target_t detach_target;
	bpf_iter_show_fdinfo_t show_fdinfo;
	bpf_iter_fill_link_info_t fill_link_info;
	bpf_iter_get_func_proto_t get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___9 *seq_info;
};

struct bpf_iter_meta {
	union {
		struct seq_file___58 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct bpf_iter_target_info {
	struct list_head list;
	const struct bpf_iter_reg *reg_info;
	u32 btf_id;
};

struct bpf_iter_link {
	struct bpf_link___2 link;
	struct bpf_iter_aux_info___9 aux;
	struct bpf_iter_target_info *tinfo;
};

struct bpf_iter_priv_data {
	struct bpf_iter_target_info *tinfo;
	const struct bpf_iter_seq_info___9 *seq_info;
	struct bpf_prog___9 *prog;
	u64 session_id;
	u64 seq_num;
	bool done_stop;
	long: 56;
	u8 target_private[0];
};

typedef u64 (*btf_bpf_for_each_map_elem)(struct bpf_map___9 *, void *, void *, u64);

struct bpf_iter_seq_map_info {
	u32 map_id;
};

struct bpf_iter__bpf_map {
	union {
		struct bpf_iter_meta *meta;
	};
	union {
		struct bpf_map___9 *map;
	};
};

typedef const struct bpf_func_proto___3 * (*bpf_iter_get_func_proto_t___2)(enum bpf_func_id, const struct bpf_prog___9 *);

struct bpf_iter_seq_task_common {
	struct pid_namespace___54 *ns;
};

struct bpf_iter_seq_task_info {
	struct bpf_iter_seq_task_common common;
	u32 tid;
};

struct bpf_iter__task {
	union {
		struct bpf_iter_meta *meta;
	};
	union {
		struct task_struct___66 *task;
	};
};

struct bpf_iter_seq_task_file_info {
	struct bpf_iter_seq_task_common common;
	struct task_struct___66 *task;
	u32 tid;
	u32 fd;
};

struct bpf_iter__task_file {
	union {
		struct bpf_iter_meta *meta;
	};
	union {
		struct task_struct___66 *task;
	};
	u32 fd;
	union {
		struct file___61 *file;
	};
};

struct bpf_iter_seq_task_vma_info {
	struct bpf_iter_seq_task_common common;
	struct task_struct___66 *task;
	struct vm_area_struct___65 *vma;
	u32 tid;
	long unsigned int prev_vm_start;
	long unsigned int prev_vm_end;
};

enum bpf_task_vma_iter_find_op {
	task_vma_iter_first_vma = 0,
	task_vma_iter_next_vma = 1,
	task_vma_iter_find_vma = 2,
};

struct bpf_iter__task_vma {
	union {
		struct bpf_iter_meta *meta;
	};
	union {
		struct task_struct___66 *task;
	};
	union {
		struct vm_area_struct___65 *vma;
	};
};

struct bpf_iter_seq_prog_info {
	u32 prog_id;
};

struct bpf_iter__bpf_prog {
	union {
		struct bpf_iter_meta *meta;
	};
	union {
		struct bpf_prog___9 *prog;
	};
};

struct bpf_iter__bpf_map_elem {
	union {
		struct bpf_iter_meta *meta;
	};
	union {
		struct bpf_map___9 *map;
	};
	union {
		void *key;
	};
	union {
		void *value;
	};
};

struct pcpu_freelist_node;

struct pcpu_freelist_head {
	struct pcpu_freelist_node *first;
	raw_spinlock_t lock;
};

struct pcpu_freelist_node {
	struct pcpu_freelist_node *next;
};

struct pcpu_freelist {
	struct pcpu_freelist_head *freelist;
	struct pcpu_freelist_head extralist;
};

struct bpf_lru_node {
	struct list_head list;
	u16 cpu;
	u8 type;
	u8 ref;
};

struct bpf_lru_list {
	struct list_head lists[3];
	unsigned int counts[2];
	struct list_head *next_inactive_rotation;
	raw_spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_lru_locallist {
	struct list_head lists[2];
	u16 next_steal;
	raw_spinlock_t lock;
};

struct bpf_common_lru {
	struct bpf_lru_list lru_list;
	struct bpf_lru_locallist *local_list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef bool (*del_from_htab_func)(void *, struct bpf_lru_node *);

struct bpf_lru {
	union {
		struct bpf_common_lru common_lru;
		struct bpf_lru_list *percpu_lru;
	};
	del_from_htab_func del_from_htab;
	void *del_arg;
	unsigned int hash_offset;
	unsigned int nr_scans;
	bool percpu;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bucket {
	struct hlist_nulls_head head;
	union {
		raw_spinlock_t raw_lock;
		spinlock_t lock;
	};
};

struct htab_elem;

struct bpf_htab {
	struct bpf_map___9 map;
	struct bucket *buckets;
	void *elems;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct pcpu_freelist freelist;
		struct bpf_lru lru;
	};
	struct htab_elem **extra_elems;
	atomic_t count;
	u32 n_buckets;
	u32 elem_size;
	u32 hashrnd;
	struct lock_class_key lockdep_key;
	int *map_locked[8];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct htab_elem {
	union {
		struct hlist_nulls_node hash_node;
		struct {
			void *padding;
			union {
				struct bpf_htab *htab;
				struct pcpu_freelist_node fnode;
				struct htab_elem *batch_flink;
			};
		};
	};
	union {
		struct callback_head rcu;
		struct bpf_lru_node lru_node;
	};
	u32 hash;
	int: 32;
	char key[0];
};

struct bpf_iter_seq_hash_map_info {
	struct bpf_map___9 *map;
	struct bpf_htab *htab;
	void *percpu_value_buf;
	u32 bucket_id;
	u32 skip_elems;
};

struct bpf_event_entry___2 {
	struct perf_event___35 *event;
	struct file___53 *perf_file;
	struct file___53 *map_file;
	struct callback_head rcu;
};

struct bpf_iter_meta___2 {
	union {
		struct seq_file___51 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct bpf_iter__bpf_map_elem___2 {
	union {
		struct bpf_iter_meta___2 *meta;
	};
	union {
		struct bpf_map___6 *map;
	};
	union {
		void *key;
	};
	union {
		void *value;
	};
};

struct bpf_iter_seq_array_map_info {
	struct bpf_map___6 *map;
	void *percpu_value_buf;
	u32 index;
};

struct prog_poke_elem {
	struct list_head list;
	struct bpf_prog_aux___6 *aux;
};

struct task_struct___67;

enum bpf_lru_list_type {
	BPF_LRU_LIST_T_ACTIVE = 0,
	BPF_LRU_LIST_T_INACTIVE = 1,
	BPF_LRU_LIST_T_FREE = 2,
	BPF_LRU_LOCAL_LIST_T_FREE = 3,
	BPF_LRU_LOCAL_LIST_T_PENDING = 4,
};

struct bpf_lpm_trie_key {
	__u32 prefixlen;
	__u8 data[0];
};

struct dentry___62;

struct super_block___62;

struct module___60;

struct file_system_type___61 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___62 * (*mount)(struct file_system_type___61 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___62 *);
	struct module___60 *owner;
	struct file_system_type___61 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___62;

struct kiocb___61;

struct iov_iter___33;

struct poll_table_struct___47;

struct vm_area_struct___66;

struct inode___62;

struct file_lock___61;

struct page___66;

struct pipe_inode_info___22;

struct seq_file___59;

struct file_operations___61 {
	struct module___60 *owner;
	loff_t (*llseek)(struct file___62 *, loff_t, int);
	ssize_t (*read)(struct file___62 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___62 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___61 *, struct iov_iter___33 *);
	ssize_t (*write_iter)(struct kiocb___61 *, struct iov_iter___33 *);
	int (*iopoll)(struct kiocb___61 *, bool);
	int (*iterate)(struct file___62 *, struct dir_context *);
	int (*iterate_shared)(struct file___62 *, struct dir_context *);
	__poll_t (*poll)(struct file___62 *, struct poll_table_struct___47 *);
	long int (*unlocked_ioctl)(struct file___62 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___62 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___62 *, struct vm_area_struct___66 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___62 *, struct file___62 *);
	int (*flush)(struct file___62 *, fl_owner_t);
	int (*release)(struct inode___62 *, struct file___62 *);
	int (*fsync)(struct file___62 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___62 *, int);
	int (*lock)(struct file___62 *, int, struct file_lock___61 *);
	ssize_t (*sendpage)(struct file___62 *, struct page___66 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___62 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___62 *, long unsigned int);
	int (*flock)(struct file___62 *, int, struct file_lock___61 *);
	ssize_t (*splice_write)(struct pipe_inode_info___22 *, struct file___62 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___62 *, loff_t *, struct pipe_inode_info___22 *, size_t, unsigned int);
	int (*setlease)(struct file___62 *, long int, struct file_lock___61 **, void **);
	long int (*fallocate)(struct file___62 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___59 *, struct file___62 *);
	ssize_t (*copy_file_range)(struct file___62 *, loff_t, struct file___62 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___62 *, loff_t, struct file___62 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___62 *, loff_t, loff_t, int);
};

struct vmacache___66 {
	u64 seqnum;
	struct vm_area_struct___66 *vmas[4];
};

struct page_frag___66 {
	struct page___66 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___67;

struct pid___55;

struct nsproxy___60;

struct signal_struct___62;

struct bio_list___28;

struct backing_dev_info___27;

struct css_set___51;

struct mem_cgroup___25;

struct request_queue___29;

struct vm_struct___63;

struct task_struct___68 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___68 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___67 *mm;
	struct mm_struct___67 *active_mm;
	struct vmacache___66 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___68 *real_parent;
	struct task_struct___68 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___68 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___55 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___60 *nsproxy;
	struct signal_struct___62 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___68 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___28 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___27 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___51 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___22 *splice_pipe;
	struct page_frag___66 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___25 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___25 *active_memcg;
	struct request_queue___29 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___68 *oom_reaper_list;
	struct vm_struct___63 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___42 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___61;

struct kobj_type___61;

struct kernfs_node___61;

struct kobject___61 {
	const char *name;
	struct list_head entry;
	struct kobject___61 *parent;
	struct kset___61 *kset;
	struct kobj_type___61 *ktype;
	struct kernfs_node___61 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___58 {
	struct kobject___61 kobj;
	struct module___60 *mod;
	struct kobject___61 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___58 {
	struct module___60 *mod;
	struct latch_tree_node node;
};

struct module_layout___58 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___58 mtn;
};

struct module_attribute___58;

struct kernel_param___58;

struct module___60 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___58 mkobj;
	struct module_attribute___58 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___61 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___58 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___58 core_layout;
	struct module_layout___58 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___61;

struct path___61 {
	struct vfsmount___61 *mnt;
	struct dentry___62 *dentry;
};

struct fown_struct___55 {
	rwlock_t lock;
	struct pid___55 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___61;

struct file___62 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___61 f_path;
	struct inode___62 *f_inode;
	const struct file_operations___61 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___55 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___61 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___66 *pgtable_t___66;

struct page_pool___19;

struct dev_pagemap___60;

struct page___66 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___61 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___19 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___66 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___66 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___67 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___60 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___60;

struct vm_area_struct___66 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___66 *vm_next;
	struct vm_area_struct___66 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___67 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___60 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___62 *vm_file;
	struct file___62 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___66;

struct mm_struct___67 {
	struct {
		struct vm_area_struct___66 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___62 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___66 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___68 *owner;
		struct user_namespace___10 *user_ns;
		struct file___62 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___61;

struct address_space___61 {
	struct inode___62 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___61 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___55;

struct page_pool_params___19 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___55 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___19 {
	u32 count;
	struct page___66 *cache[128];
};

struct page_pool___19 {
	struct page_pool_params___19 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___66 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___19 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___60;

struct dev_pagemap___60 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___60 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___60;

struct vm_operations_struct___60 {
	void (*open)(struct vm_area_struct___66 *);
	void (*close)(struct vm_area_struct___66 *);
	int (*may_split)(struct vm_area_struct___66 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___66 *);
	int (*mprotect)(struct vm_area_struct___66 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___60 *);
	vm_fault_t (*huge_fault)(struct vm_fault___60 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___60 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___66 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___60 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___60 *);
	int (*access)(struct vm_area_struct___66 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___66 *);
	int (*set_policy)(struct vm_area_struct___66 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___66 *, long unsigned int);
	struct page___66 * (*find_special_page)(struct vm_area_struct___66 *, long unsigned int);
};

struct core_thread___66 {
	struct task_struct___68 *task;
	struct core_thread___66 *next;
};

struct core_state___66 {
	atomic_t nr_threads;
	struct core_thread___66 dumper;
	struct completion startup;
};

struct vm_fault___60 {
	const struct {
		struct vm_area_struct___66 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___66 *cow_page;
	struct page___66 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___66 prealloc_pte;
};

struct pid_namespace___55;

struct upid___55 {
	int nr;
	struct pid_namespace___55 *ns;
};

struct pid_namespace___55 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___68 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___55 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___55 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___55 numbers[1];
};

struct signal_struct___62 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___68 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___68 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___55 *pids[4];
	struct pid___55 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___67 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___13;

struct cgroup_namespace___51;

struct nsproxy___60 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___55 *pid_ns_for_children;
	struct net___13 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___51 *cgroup_ns;
};

struct bio___28;

struct bio_list___28 {
	struct bio___28 *head;
	struct bio___28 *tail;
};

struct cgroup_subsys_state___51;

struct bdi_writeback___27 {
	struct backing_dev_info___27 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___51 *memcg_css;
	struct cgroup_subsys_state___51 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___27 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___27 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___55 *dev;
	char dev_name[64];
	struct device___55 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___62 *debug_dir;
};

struct io_cq___28;

struct io_context___2 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___28 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___51;

struct css_set___51 {
	struct cgroup_subsys_state___51 *subsys[14];
	refcount_t refcount;
	struct css_set___51 *dom_cset;
	struct cgroup___51 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___51 *mg_src_cgrp;
	struct cgroup___51 *mg_dst_cgrp;
	struct css_set___51 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___61;

struct pipe_buffer___22;

struct pipe_inode_info___22 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___66 *tmp_page;
	struct fasync_struct___61 *fasync_readers;
	struct fasync_struct___61 *fasync_writers;
	struct pipe_buffer___22 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___51;

struct cgroup_subsys_state___51 {
	struct cgroup___51 *cgroup;
	struct cgroup_subsys___51 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___51 *parent;
};

struct cgroup_file___51 {
	struct kernfs_node___61 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___25;

struct mem_cgroup_per_node___25;

struct mem_cgroup___25 {
	struct cgroup_subsys_state___51 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___51 events_file;
	struct cgroup_file___51 events_local_file;
	struct cgroup_file___51 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___25 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___68 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___25 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___28;

struct blk_integrity___28 {
	const struct blk_integrity_profile___28 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___28 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___28 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___28;

struct elevator_queue___28;

struct blk_mq_ops___27;

struct blk_mq_hw_ctx___27;

struct gendisk___28;

struct blkcg_gq___27;

struct blk_mq_tag_set___27;

struct request_queue___29 {
	struct request___28 *last_merge;
	struct elevator_queue___28 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___27 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___27 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___28 *disk;
	struct kobject___61 kobj;
	struct kobject___61 *mq_kobj;
	struct blk_integrity___28 integrity;
	struct device___55 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___27 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___27 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___28 bio_split;
	struct dentry___62 *debugfs_dir;
	struct dentry___62 *sched_debugfs_dir;
	struct dentry___62 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___63 {
	struct vm_struct___63 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___66 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___26;

struct lruvec___26 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___26 *pgdat;
};

struct zone___26 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___26 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___26 {
	struct zone___26 *zone;
	int zone_idx;
};

struct zonelist___26 {
	struct zoneref___26 _zonerefs[321];
};

struct pglist_data___26 {
	struct zone___26 node_zones[5];
	struct zonelist___26 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___68 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___68 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___26 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___61;

struct dentry___62 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___62 *d_parent;
	struct qstr d_name;
	struct inode___62 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___61 *d_op;
	struct super_block___62 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___61;

struct inode___62 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___61 *i_op;
	struct super_block___62 *i_sb;
	struct address_space___61 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___27 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___61 *i_fop;
		void (*free_inode)(struct inode___62 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___61 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___22 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___61 {
	int (*d_revalidate)(struct dentry___62 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___62 *, unsigned int);
	int (*d_hash)(const struct dentry___62 *, struct qstr *);
	int (*d_compare)(const struct dentry___62 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___62 *);
	int (*d_init)(struct dentry___62 *);
	void (*d_release)(struct dentry___62 *);
	void (*d_prune)(struct dentry___62 *);
	void (*d_iput)(struct dentry___62 *, struct inode___62 *);
	char * (*d_dname)(struct dentry___62 *, char *, int);
	struct vfsmount___61 * (*d_automount)(struct path___61 *);
	int (*d_manage)(const struct path___61 *, bool);
	struct dentry___62 * (*d_real)(struct dentry___62 *, const struct inode___62 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___61;

struct mem_dqinfo___61 {
	struct quota_format_type___61 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___61;

struct quota_info___61 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___62 *files[3];
	struct mem_dqinfo___61 info[3];
	const struct quota_format_ops___61 *ops[3];
};

struct rcuwait___62 {
	struct task_struct___68 *task;
};

struct percpu_rw_semaphore___62 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___62 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___61 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___62 rw_sem[3];
};

struct shrink_control___25;

struct shrinker___25 {
	long unsigned int (*count_objects)(struct shrinker___25 *, struct shrink_control___25 *);
	long unsigned int (*scan_objects)(struct shrinker___25 *, struct shrink_control___25 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___61;

struct dquot_operations___61;

struct quotactl_ops___61;

struct block_device___29;

struct super_block___62 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___61 *s_type;
	const struct super_operations___61 *s_op;
	const struct dquot_operations___61 *dq_op;
	const struct quotactl_ops___61 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___62 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___29 *s_bdev;
	struct backing_dev_info___27 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___61 s_dquot;
	struct sb_writers___61 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___61 *s_d_op;
	int cleancache_poolid;
	struct shrinker___25 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___61 {
	struct dentry___62 *mnt_root;
	struct super_block___62 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct shrink_control___25 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___25 *memcg;
};

struct psi_group___51 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___68 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___10;

struct cgroup_bpf___10 {
	struct bpf_prog_array___10 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___10 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___51;

struct cgroup_rstat_cpu___51;

struct cgroup___51 {
	struct cgroup_subsys_state___51 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___61 *kn;
	struct cgroup_file___51 procs_file;
	struct cgroup_file___51 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___51 *subsys[14];
	struct cgroup_root___51 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___51 *dom_cgrp;
	struct cgroup___51 *old_dom_cgrp;
	struct cgroup_rstat_cpu___51 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___51 psi;
	struct cgroup_bpf___10 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___28 {
	struct request_queue___29 *q;
	struct io_context___2 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___61 {
	struct file___62 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___61 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___62 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___62 *ia_file;
};

struct dquot___61 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___62 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___61 {
	int qf_fmt_id;
	const struct quota_format_ops___61 *qf_ops;
	struct module___60 *qf_owner;
	struct quota_format_type___61 *qf_next;
};

struct quota_format_ops___61 {
	int (*check_quota_file)(struct super_block___62 *, int);
	int (*read_file_info)(struct super_block___62 *, int);
	int (*write_file_info)(struct super_block___62 *, int);
	int (*free_file_info)(struct super_block___62 *, int);
	int (*read_dqblk)(struct dquot___61 *);
	int (*commit_dqblk)(struct dquot___61 *);
	int (*release_dqblk)(struct dquot___61 *);
	int (*get_next_id)(struct super_block___62 *, struct kqid *);
};

struct dquot_operations___61 {
	int (*write_dquot)(struct dquot___61 *);
	struct dquot___61 * (*alloc_dquot)(struct super_block___62 *, int);
	void (*destroy_dquot)(struct dquot___61 *);
	int (*acquire_dquot)(struct dquot___61 *);
	int (*release_dquot)(struct dquot___61 *);
	int (*mark_dirty)(struct dquot___61 *);
	int (*write_info)(struct super_block___62 *, int);
	qsize_t * (*get_reserved_space)(struct inode___62 *);
	int (*get_projid)(struct inode___62 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___62 *, qsize_t *);
	int (*get_next_id)(struct super_block___62 *, struct kqid *);
};

struct quotactl_ops___61 {
	int (*quota_on)(struct super_block___62 *, int, int, const struct path___61 *);
	int (*quota_off)(struct super_block___62 *, int);
	int (*quota_enable)(struct super_block___62 *, unsigned int);
	int (*quota_disable)(struct super_block___62 *, unsigned int);
	int (*quota_sync)(struct super_block___62 *, int);
	int (*set_info)(struct super_block___62 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___62 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___62 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___62 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___62 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___62 *, unsigned int);
};

struct writeback_control___27;

struct address_space_operations___61 {
	int (*writepage)(struct page___66 *, struct writeback_control___27 *);
	int (*readpage)(struct file___62 *, struct page___66 *);
	int (*writepages)(struct address_space___61 *, struct writeback_control___27 *);
	int (*set_page_dirty)(struct page___66 *);
	int (*readpages)(struct file___62 *, struct address_space___61 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___62 *, struct address_space___61 *, loff_t, unsigned int, unsigned int, struct page___66 **, void **);
	int (*write_end)(struct file___62 *, struct address_space___61 *, loff_t, unsigned int, unsigned int, struct page___66 *, void *);
	sector_t (*bmap)(struct address_space___61 *, sector_t);
	void (*invalidatepage)(struct page___66 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___66 *, gfp_t);
	void (*freepage)(struct page___66 *);
	ssize_t (*direct_IO)(struct kiocb___61 *, struct iov_iter___33 *);
	int (*migratepage)(struct address_space___61 *, struct page___66 *, struct page___66 *, enum migrate_mode);
	bool (*isolate_page)(struct page___66 *, isolate_mode_t);
	void (*putback_page)(struct page___66 *);
	int (*launder_page)(struct page___66 *);
	int (*is_partially_uptodate)(struct page___66 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___66 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___61 *, struct page___66 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___62 *, sector_t *);
	void (*swap_deactivate)(struct file___62 *);
};

struct writeback_control___27 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___27 *wb;
	struct inode___62 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___33;

struct iov_iter___33 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___33 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___22 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___61 {
	struct dentry___62 * (*lookup)(struct inode___62 *, struct dentry___62 *, unsigned int);
	const char * (*get_link)(struct dentry___62 *, struct inode___62 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___62 *, int);
	struct posix_acl * (*get_acl)(struct inode___62 *, int, bool);
	int (*readlink)(struct dentry___62 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___62 *, struct dentry___62 *, umode_t, bool);
	int (*link)(struct dentry___62 *, struct inode___62 *, struct dentry___62 *);
	int (*unlink)(struct inode___62 *, struct dentry___62 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___62 *, struct dentry___62 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___62 *, struct dentry___62 *, umode_t);
	int (*rmdir)(struct inode___62 *, struct dentry___62 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___62 *, struct dentry___62 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___62 *, struct dentry___62 *, struct inode___62 *, struct dentry___62 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___62 *, struct iattr___62 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___61 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___62 *, char *, size_t);
	int (*fiemap)(struct inode___62 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___62 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___62 *, struct dentry___62 *, struct file___62 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___62 *, struct dentry___62 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___62 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___62 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___62 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___61 {
	void (*fl_copy_lock)(struct file_lock___61 *, struct file_lock___61 *);
	void (*fl_release_private)(struct file_lock___61 *);
};

struct lock_manager_operations___61;

struct file_lock___61 {
	struct file_lock___61 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___62 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___61 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___61 *fl_ops;
	const struct lock_manager_operations___61 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___61 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___61 *);
	int (*lm_grant)(struct file_lock___61 *, int);
	bool (*lm_break)(struct file_lock___61 *);
	int (*lm_change)(struct file_lock___61 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___61 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___61 *);
};

struct fasync_struct___61 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___61 *fa_next;
	struct file___62 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___61 {
	struct inode___62 * (*alloc_inode)(struct super_block___62 *);
	void (*destroy_inode)(struct inode___62 *);
	void (*free_inode)(struct inode___62 *);
	void (*dirty_inode)(struct inode___62 *, int);
	int (*write_inode)(struct inode___62 *, struct writeback_control___27 *);
	int (*drop_inode)(struct inode___62 *);
	void (*evict_inode)(struct inode___62 *);
	void (*put_super)(struct super_block___62 *);
	int (*sync_fs)(struct super_block___62 *, int);
	int (*freeze_super)(struct super_block___62 *);
	int (*freeze_fs)(struct super_block___62 *);
	int (*thaw_super)(struct super_block___62 *);
	int (*unfreeze_fs)(struct super_block___62 *);
	int (*statfs)(struct dentry___62 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___62 *, int *, char *);
	void (*umount_begin)(struct super_block___62 *);
	int (*show_options)(struct seq_file___59 *, struct dentry___62 *);
	int (*show_devname)(struct seq_file___59 *, struct dentry___62 *);
	int (*show_path)(struct seq_file___59 *, struct dentry___62 *);
	int (*show_stats)(struct seq_file___59 *, struct dentry___62 *);
	ssize_t (*quota_read)(struct super_block___62 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___62 *, int, const char *, size_t, loff_t);
	struct dquot___61 ** (*get_dquots)(struct inode___62 *);
	long int (*nr_cached_objects)(struct super_block___62 *, struct shrink_control___25 *);
	long int (*free_cached_objects)(struct super_block___62 *, struct shrink_control___25 *);
	struct file___62 * (*real_loop)(struct file___62 *);
};

struct wakeup_source___55;

struct dev_pm_info___55 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___55 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___55 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___55;

struct bus_type___55;

struct device_driver___55;

struct dev_pm_domain___55;

struct fwnode_handle___55;

struct class___55;

struct attribute_group___61;

struct device___55 {
	struct kobject___61 kobj;
	struct device___55 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___55 *type;
	struct bus_type___55 *bus;
	struct device_driver___55 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___55 power;
	struct dev_pm_domain___55 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___55 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___55 *class;
	const struct attribute_group___61 **groups;
	void (*release)(struct device___55 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___29 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___62 *bd_inode;
	struct super_block___62 *bd_super;
	void *bd_claiming;
	struct device___55 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___61 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___28 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___62 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___47)(struct file___62 *, wait_queue_head_t *, struct poll_table_struct___47 *);

struct poll_table_struct___47 {
	poll_queue_proc___47 _qproc;
	__poll_t _key;
};

struct seq_operations___59;

struct seq_file___59 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___59 *op;
	int poll_event;
	const struct file___62 *file;
	void *private;
};

typedef void bio_end_io_t___28(struct bio___28 *);

struct bio_vec___33 {
	struct page___66 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___28;

struct bio___28 {
	struct bio___28 *bi_next;
	struct block_device___29 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___28 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___27 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___28 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___33 *bi_io_vec;
	struct bio_set___28 *bi_pool;
	struct bio_vec___33 bi_inline_vecs[0];
};

struct kernfs_root___61;

struct kernfs_elem_dir___61 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___61 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___61;

struct kernfs_root___61 {
	struct kernfs_node___61 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___61 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___61 {
	struct kernfs_node___61 *target_kn;
};

struct kernfs_ops___61;

struct kernfs_elem_attr___61 {
	const struct kernfs_ops___61 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___61 *notify_next;
};

struct kernfs_node___61 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___61 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___61 dir;
		struct kernfs_elem_symlink___61 symlink;
		struct kernfs_elem_attr___61 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___61;

struct kernfs_ops___61 {
	int (*open)(struct kernfs_open_file___61 *);
	void (*release)(struct kernfs_open_file___61 *);
	int (*seq_show)(struct seq_file___59 *, void *);
	void * (*seq_start)(struct seq_file___59 *, loff_t *);
	void * (*seq_next)(struct seq_file___59 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___59 *, void *);
	ssize_t (*read)(struct kernfs_open_file___61 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___61 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___61 *, struct poll_table_struct___47 *);
	int (*mmap)(struct kernfs_open_file___61 *, struct vm_area_struct___66 *);
};

struct kernfs_syscall_ops___61 {
	int (*show_options)(struct seq_file___59 *, struct kernfs_root___61 *);
	int (*mkdir)(struct kernfs_node___61 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___61 *);
	int (*rename)(struct kernfs_node___61 *, struct kernfs_node___61 *, const char *);
	int (*show_path)(struct seq_file___59 *, struct kernfs_node___61 *, struct kernfs_root___61 *);
};

struct kernfs_open_file___61 {
	struct kernfs_node___61 *kn;
	struct file___62 *file;
	struct seq_file___59 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___60 *vm_ops;
};

struct sock___9;

struct kobj_ns_type_operations___7 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___9 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___13 *net;
} possible_net_t___10;

struct proto___7;

struct sock_common___7 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___7 *skc_prot;
	possible_net_t___10 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___9 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___12;

struct sk_buff_head___10 {
	struct sk_buff___12 *next;
	struct sk_buff___12 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___7 {
	struct cgroup___51 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___7;

struct socket_wq___7;

struct dst_entry___7;

struct socket___7;

struct net_device___15;

struct sock___9 {
	struct sock_common___7 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___10 sk_error_queue;
	struct sk_buff___12 *sk_rx_skb_cache;
	struct sk_buff_head___10 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___12 *head;
		struct sk_buff___12 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___7 *sk_filter;
	union {
		struct socket_wq___7 *sk_wq;
		struct socket_wq___7 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___7 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___7 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___12 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___12 *sk_tx_skb_cache;
	struct sk_buff_head___10 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___66 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___7 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___55 *sk_peer_pid;
	const struct cred___9 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___7 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___7 sk_cgrp_data;
	struct mem_cgroup___25 *sk_memcg;
	void (*sk_state_change)(struct sock___9 *);
	void (*sk_data_ready)(struct sock___9 *);
	void (*sk_write_space)(struct sock___9 *);
	void (*sk_error_report)(struct sock___9 *);
	int (*sk_backlog_rcv)(struct sock___9 *, struct sk_buff___12 *);
	struct sk_buff___12 * (*sk_validate_xmit_skb)(struct sock___9 *, struct net_device___15 *, struct sk_buff___12 *);
	void (*sk_destruct)(struct sock___9 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___61;

struct attribute_group___61 {
	const char *name;
	umode_t (*is_visible)(struct kobject___61 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___61 *, struct bin_attribute___61 *, int);
	struct attribute **attrs;
	struct bin_attribute___61 **bin_attrs;
};

struct bin_attribute___61 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___61 * (*f_mapping)();
	ssize_t (*read)(struct file___62 *, struct kobject___61 *, struct bin_attribute___61 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___62 *, struct kobject___61 *, struct bin_attribute___61 *, char *, loff_t, size_t);
	int (*mmap)(struct file___62 *, struct kobject___61 *, struct bin_attribute___61 *, struct vm_area_struct___66 *);
};

struct sysfs_ops___61 {
	ssize_t (*show)(struct kobject___61 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___61 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___61;

struct kset___61 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___61 kobj;
	const struct kset_uevent_ops___61 *uevent_ops;
};

struct kobj_type___61 {
	void (*release)(struct kobject___61 *);
	const struct sysfs_ops___61 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___61 **default_groups;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___61 *);
	const void * (*namespace)(struct kobject___61 *);
	void (*get_ownership)(struct kobject___61 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___61 {
	int (* const filter)(struct kset___61 *, struct kobject___61 *);
	const char * (* const name)(struct kset___61 *, struct kobject___61 *);
	int (* const uevent)(struct kset___61 *, struct kobject___61 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___58 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___58 *);
	int (*get)(char *, const struct kernel_param___58 *);
	void (*free)(void *);
};

struct kparam_array___58;

struct kernel_param___58 {
	const char *name;
	struct module___60 *mod;
	const struct kernel_param_ops___58 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___58 *arr;
	};
};

struct kparam_array___58 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___58 *ops;
	void *elem;
};

struct module_attribute___58 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___58 *, struct module_kobject___58 *, char *);
	ssize_t (*store)(struct module_attribute___58 *, struct module_kobject___58 *, const char *, size_t);
	void (*setup)(struct module___60 *, const char *);
	int (*test)(struct module___60 *);
	void (*free)(struct module___60 *);
};

struct dev_pagemap_ops___60 {
	void (*page_free)(struct page___66 *);
	void (*kill)(struct dev_pagemap___60 *);
	void (*cleanup)(struct dev_pagemap___60 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___60 *);
};

struct bpf_iter_aux_info___10;

typedef int (*bpf_iter_init_seq_priv_t___10)(void *, struct bpf_iter_aux_info___10 *);

struct bpf_map___10;

struct bpf_iter_aux_info___10 {
	struct bpf_map___10 *map;
};

struct bpf_iter_seq_info___10 {
	const struct seq_operations___59 *seq_ops;
	bpf_iter_init_seq_priv_t___10 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___59 {
	void * (*start)(struct seq_file___59 *, loff_t *);
	void (*stop)(struct seq_file___59 *, void *);
	void * (*next)(struct seq_file___59 *, void *, loff_t *);
	int (*show)(struct seq_file___59 *, void *);
};

struct bpf_prog_aux___10;

struct bpf_prog___10;

struct bpf_map_ops___10 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___10 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___10 *, struct file___62 *);
	void (*map_free)(struct bpf_map___10 *);
	int (*map_get_next_key)(struct bpf_map___10 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___10 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___10 *, void *);
	int (*map_lookup_batch)(struct bpf_map___10 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___10 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___10 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___10 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___10 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___10 *, void *);
	int (*map_update_elem)(struct bpf_map___10 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___10 *, void *);
	int (*map_push_elem)(struct bpf_map___10 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___10 *, void *);
	int (*map_peek_elem)(struct bpf_map___10 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___10 *, struct file___62 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___10 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___10 *, void *, struct seq_file___59 *);
	int (*map_check_btf)(const struct bpf_map___10 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___10 *, struct bpf_prog_aux___10 *);
	void (*map_poke_untrack)(struct bpf_map___10 *, struct bpf_prog_aux___10 *);
	void (*map_poke_run)(struct bpf_map___10 *, u32, struct bpf_prog___10 *, struct bpf_prog___10 *);
	int (*map_direct_value_addr)(const struct bpf_map___10 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___10 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___10 *, struct vm_area_struct___66 *);
	__poll_t (*map_poll)(struct bpf_map___10 *, struct file___62 *, struct poll_table_struct___47 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___10 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___10 *, const struct bpf_map___10 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___10 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___10 *iter_seq_info;
};

struct bpf_map___10 {
	const struct bpf_map_ops___10 *ops;
	struct bpf_map___10 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___25 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___10;

struct bpf_jit_poke_descriptor___10;

struct bpf_prog_ops___10;

struct btf_mod_pair___10;

struct bpf_prog_offload___10;

struct bpf_prog_aux___10 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___10 *dst_prog;
	struct bpf_trampoline___10 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___10 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___10 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___10 *ops;
	struct bpf_map___10 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___10 *used_btfs;
	struct bpf_prog___10 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___10 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___10 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___10 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___10 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___10;

struct bpf_map_dev_ops___10 {
	int (*map_get_next_key)(struct bpf_offloaded_map___10 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___10 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___10 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___10 *, void *);
};

struct bpf_offloaded_map___10 {
	struct bpf_map___10 map;
	struct net_device___15 *netdev;
	const struct bpf_map_dev_ops___10 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___10(struct sk_buff___12 **);

struct bpf_xdp_entity___10 {
	struct bpf_prog___10 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___10;

struct net_device_ops___10;

struct l3mdev_ops___7;

struct ndisc_ops___3;

struct xfrmdev_ops___10;

struct header_ops___10;

struct inet6_dev___3;

struct netdev_rx_queue___10;

struct mini_Qdisc___10;

struct netdev_queue___10;

struct Qdisc___10;

struct rtnl_link_ops___10;

struct dcbnl_rtnl_ops___10;

struct net_device___15 {
	char name[16];
	struct netdev_name_node___10 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___10 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___7 *l3mdev_ops;
	const struct ndisc_ops___3 *ndisc_ops;
	const struct xfrmdev_ops___10 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___10 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___61 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___3 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___10 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___10 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___10 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___10 *miniq_ingress;
	struct netdev_queue___10 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___10 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___10 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___10 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___10 = 0,
		NETREG_REGISTERED___10 = 1,
		NETREG_UNREGISTERING___10 = 2,
		NETREG_UNREGISTERED___10 = 3,
		NETREG_RELEASED___10 = 4,
		NETREG_DUMMY___10 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___10 = 0,
		RTNL_LINK_INITIALIZING___10 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___15 *);
	struct netpoll_info *npinfo;
	possible_net_t___10 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___55 dev;
	const struct attribute_group___61 *sysfs_groups[4];
	const struct attribute_group___61 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___10 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___10 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___10 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___10 {
	int (*test_run)(struct bpf_prog___10 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___10 {
	struct bpf_prog___10 *prog;
	struct net_device___15 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___10 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___10 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___60 *mod;
};

struct bpf_jit_poke_descriptor___10 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___10 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___10 {
	struct btf *btf;
	struct module___60 *module;
};

struct bpf_prog_array_item___10 {
	struct bpf_prog___10 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___10 {
	struct callback_head rcu;
	struct bpf_prog_array_item___10 items[0];
};

struct sk_buff___12 {
	union {
		struct {
			struct sk_buff___12 *next;
			struct sk_buff___12 *prev;
			union {
				struct net_device___15 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___9 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___12 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct fwnode_operations___55;

struct fwnode_handle___55 {
	struct fwnode_handle___55 *secondary;
	const struct fwnode_operations___55 *ops;
	struct device___55 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___55;

struct fwnode_endpoint___55;

struct fwnode_operations___55 {
	struct fwnode_handle___55 * (*get)(struct fwnode_handle___55 *);
	void (*put)(struct fwnode_handle___55 *);
	bool (*device_is_available)(const struct fwnode_handle___55 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___55 *, const struct device___55 *);
	bool (*property_present)(const struct fwnode_handle___55 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___55 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___55 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___55 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*get_parent)(const struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*get_next_child_node)(const struct fwnode_handle___55 *, struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*get_named_child_node)(const struct fwnode_handle___55 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___55 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___55 *);
	struct fwnode_handle___55 * (*graph_get_next_endpoint)(const struct fwnode_handle___55 *, struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*graph_get_remote_endpoint)(const struct fwnode_handle___55 *);
	struct fwnode_handle___55 * (*graph_get_port_parent)(struct fwnode_handle___55 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___55 *, struct fwnode_endpoint___55 *);
	int (*add_links)(struct fwnode_handle___55 *);
};

struct fwnode_endpoint___55 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___55 *local_fwnode;
};

struct fwnode_reference_args___55 {
	struct fwnode_handle___55 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___7;

struct fqdir___12;

struct fib_notifier_ops___7;

struct netns_ipv4___12 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___7 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___9 *fibnl;
	struct sock___9 **icmp_sk;
	struct sock___9 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___9 **tcp_sk;
	struct fqdir___12 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___7 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___7 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___7 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___7;

struct dst_ops___12 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___12 *);
	struct dst_entry___7 * (*check)(struct dst_entry___7 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___7 *);
	unsigned int (*mtu)(const struct dst_entry___7 *);
	u32 * (*cow_metrics)(struct dst_entry___7 *, long unsigned int);
	void (*destroy)(struct dst_entry___7 *);
	void (*ifdown)(struct dst_entry___7 *, struct net_device___15 *, int);
	struct dst_entry___7 * (*negative_advice)(struct dst_entry___7 *);
	void (*link_failure)(struct sk_buff___12 *);
	void (*update_pmtu)(struct dst_entry___7 *, struct sock___9 *, struct sk_buff___12 *, u32, bool);
	void (*redirect)(struct dst_entry___7 *, struct sock___9 *, struct sk_buff___12 *);
	int (*local_out)(struct net___13 *, struct sock___9 *, struct sk_buff___12 *);
	struct neighbour___7 * (*neigh_lookup)(const struct dst_entry___7 *, struct sk_buff___12 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___7 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___12 {
	struct dst_ops___12 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___12 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___7 *fib6_rules_ops;
	struct sock___9 **icmp_sk;
	struct sock___9 *ndisc_sk;
	struct sock___9 *tcp_sk;
	struct sock___9 *igmp_sk;
	struct sock___9 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___7 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___7 *notifier_ops;
	struct fib_notifier_ops___7 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___12 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___12 *fqdir;
};

struct netns_sctp___7 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___9 *ctl_sock;
	struct sock___9 *udp4_sock;
	struct sock___9 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___10 {
	struct bpf_prog_array___10 *run_array[2];
	struct bpf_prog___10 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___12 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___9 *nlsk;
	struct sock___9 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___12 xfrm4_dst_ops;
	struct dst_ops___12 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___13 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___9 *rtnl;
	struct sock___9 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___15 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___12 ipv4;
	struct netns_ipv6___12 ipv6;
	struct netns_ieee802154_lowpan___12 ieee802154_lowpan;
	struct netns_sctp___7 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___10 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___10 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___12 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___9 *crypto_nlsk;
	struct sock___9 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___51 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___51 *root_cset;
};

struct msghdr___7 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___33 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___61 *msg_iocb;
};

struct socket_wq___7 {
	wait_queue_head_t wait;
	struct fasync_struct___61 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___7;

struct socket___7 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___62 *file;
	struct sock___9 *sk;
	const struct proto_ops___7 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___7 wq;
};

typedef int (*sk_read_actor_t___7)(read_descriptor_t *, struct sk_buff___12 *, unsigned int, size_t);

struct proto_ops___7 {
	int family;
	struct module___60 *owner;
	int (*release)(struct socket___7 *);
	int (*bind)(struct socket___7 *, struct sockaddr *, int);
	int (*connect)(struct socket___7 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___7 *, struct socket___7 *);
	int (*accept)(struct socket___7 *, struct socket___7 *, int, bool);
	int (*getname)(struct socket___7 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___62 *, struct socket___7 *, struct poll_table_struct___47 *);
	int (*ioctl)(struct socket___7 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___7 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___7 *, void *, bool, bool);
	int (*listen)(struct socket___7 *, int);
	int (*shutdown)(struct socket___7 *, int);
	int (*setsockopt)(struct socket___7 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___7 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___59 *, struct socket___7 *);
	int (*sendmsg)(struct socket___7 *, struct msghdr___7 *, size_t);
	int (*recvmsg)(struct socket___7 *, struct msghdr___7 *, size_t, int);
	int (*mmap)(struct file___62 *, struct socket___7 *, struct vm_area_struct___66 *);
	ssize_t (*sendpage)(struct socket___7 *, struct page___66 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___7 *, loff_t *, struct pipe_inode_info___22 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___9 *, int);
	int (*peek_len)(struct socket___7 *);
	int (*read_sock)(struct sock___9 *, read_descriptor_t *, sk_read_actor_t___7);
	int (*sendpage_locked)(struct sock___9 *, struct page___66 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___9 *, struct msghdr___7 *, size_t);
	int (*set_rcvlowat)(struct sock___9 *, int);
};

struct dev_pm_ops___55 {
	int (*prepare)(struct device___55 *);
	void (*complete)(struct device___55 *);
	int (*suspend)(struct device___55 *);
	int (*resume)(struct device___55 *);
	int (*freeze)(struct device___55 *);
	int (*thaw)(struct device___55 *);
	int (*poweroff)(struct device___55 *);
	int (*restore)(struct device___55 *);
	int (*suspend_late)(struct device___55 *);
	int (*resume_early)(struct device___55 *);
	int (*freeze_late)(struct device___55 *);
	int (*thaw_early)(struct device___55 *);
	int (*poweroff_late)(struct device___55 *);
	int (*restore_early)(struct device___55 *);
	int (*suspend_noirq)(struct device___55 *);
	int (*resume_noirq)(struct device___55 *);
	int (*freeze_noirq)(struct device___55 *);
	int (*thaw_noirq)(struct device___55 *);
	int (*poweroff_noirq)(struct device___55 *);
	int (*restore_noirq)(struct device___55 *);
	int (*runtime_suspend)(struct device___55 *);
	int (*runtime_resume)(struct device___55 *);
	int (*runtime_idle)(struct device___55 *);
};

struct wakeup_source___55 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___55 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___55 {
	struct dev_pm_ops___55 ops;
	int (*start)(struct device___55 *);
	void (*detach)(struct device___55 *, bool);
	int (*activate)(struct device___55 *);
	void (*sync)(struct device___55 *);
	void (*dismiss)(struct device___55 *);
};

struct bus_type___55 {
	const char *name;
	const char *dev_name;
	struct device___55 *dev_root;
	const struct attribute_group___61 **bus_groups;
	const struct attribute_group___61 **dev_groups;
	const struct attribute_group___61 **drv_groups;
	int (*match)(struct device___55 *, struct device_driver___55 *);
	int (*uevent)(struct device___55 *, struct kobj_uevent_env *);
	int (*probe)(struct device___55 *);
	void (*sync_state)(struct device___55 *);
	void (*remove)(struct device___55 *);
	void (*shutdown)(struct device___55 *);
	int (*online)(struct device___55 *);
	int (*offline)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	int (*num_vf)(struct device___55 *);
	int (*dma_configure)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___55 {
	const char *name;
	struct bus_type___55 *bus;
	struct module___60 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___55 *);
	void (*sync_state)(struct device___55 *);
	int (*remove)(struct device___55 *);
	void (*shutdown)(struct device___55 *);
	int (*suspend)(struct device___55 *, pm_message_t);
	int (*resume)(struct device___55 *);
	const struct attribute_group___61 **groups;
	const struct attribute_group___61 **dev_groups;
	const struct dev_pm_ops___55 *pm;
	void (*coredump)(struct device___55 *);
	struct driver_private *p;
};

struct device_type___55 {
	const char *name;
	const struct attribute_group___61 **groups;
	int (*uevent)(struct device___55 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___55 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___55 *);
	const struct dev_pm_ops___55 *pm;
};

struct class___55 {
	const char *name;
	struct module___60 *owner;
	const struct attribute_group___61 **class_groups;
	const struct attribute_group___61 **dev_groups;
	struct kobject___61 *dev_kobj;
	int (*dev_uevent)(struct device___55 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___55 *, umode_t *);
	void (*class_release)(struct class___55 *);
	void (*dev_release)(struct device___55 *);
	int (*shutdown_pre)(struct device___55 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___55 *);
	void (*get_ownership)(struct device___55 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___55 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___22;

struct pipe_buffer___22 {
	struct page___66 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___22 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___22 {
	int (*confirm)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
	void (*release)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
	bool (*try_steal)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
	bool (*get)(struct pipe_inode_info___22 *, struct pipe_buffer___22 *);
};

struct inet_frags___12;

struct fqdir___12 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___12 *f;
	struct net___13 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___12;

struct inet_frags___12 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___12 *, const void *);
	void (*destructor)(struct inet_frag_queue___12 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___12 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___12 *fragments_tail;
	struct sk_buff___12 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___12 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___7;

struct fib_lookup_arg___7;

struct fib_rules_ops___7 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___7 *, struct flowi *, int, struct fib_lookup_arg___7 *);
	bool (*suppress)(struct fib_rule___7 *, int, struct fib_lookup_arg___7 *);
	int (*match)(struct fib_rule___7 *, struct flowi *, int);
	int (*configure)(struct fib_rule___7 *, struct sk_buff___12 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___7 *);
	int (*compare)(struct fib_rule___7 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___7 *, struct sk_buff___12 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___7 *);
	void (*flush_cache)(struct fib_rules_ops___7 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___60 *owner;
	struct net___13 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___7 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___13 *);
	int (*fib_dump)(struct net___13 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___60 *owner;
	struct callback_head rcu;
};

struct dst_entry___7 {
	struct net_device___15 *dev;
	struct dst_ops___12 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___12 *);
	int (*output)(struct net___13 *, struct sock___9 *, struct sk_buff___12 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___7;

struct neigh_parms___7;

struct neigh_ops___7;

struct neighbour___7 {
	struct neighbour___7 *next;
	struct neigh_table___7 *tbl;
	struct neigh_parms___7 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___10 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___7 *, struct sk_buff___12 *);
	const struct neigh_ops___7 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___15 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___10 {
	int (*ieee_getets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___15 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___15 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___15 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___15 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___15 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___15 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___15 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___15 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___15 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___15 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___15 *);
	u8 (*setstate)(struct net_device___15 *, u8);
	void (*getpermhwaddr)(struct net_device___15 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___15 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___15 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___15 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___15 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___15 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___15 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___15 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___15 *, int, u8 *);
	void (*setpfccfg)(struct net_device___15 *, int, u8);
	void (*getpfccfg)(struct net_device___15 *, int, u8 *);
	u8 (*setall)(struct net_device___15 *);
	u8 (*getcap)(struct net_device___15 *, int, u8 *);
	int (*getnumtcs)(struct net_device___15 *, int, u8 *);
	int (*setnumtcs)(struct net_device___15 *, int, u8);
	u8 (*getpfcstate)(struct net_device___15 *);
	void (*setpfcstate)(struct net_device___15 *, u8);
	void (*getbcncfg)(struct net_device___15 *, int, u32 *);
	void (*setbcncfg)(struct net_device___15 *, int, u32);
	void (*getbcnrp)(struct net_device___15 *, int, u8 *);
	void (*setbcnrp)(struct net_device___15 *, int, u8);
	int (*setapp)(struct net_device___15 *, u8, u16, u8);
	int (*getapp)(struct net_device___15 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___15 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___15 *, int, u8);
	u8 (*getdcbx)(struct net_device___15 *);
	u8 (*setdcbx)(struct net_device___15 *, u8);
	int (*peer_getappinfo)(struct net_device___15 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___15 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___15 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___15 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___15 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___15 *, struct dcbnl_buffer *);
};

struct cftype___51;

struct cgroup_subsys___51 {
	struct cgroup_subsys_state___51 * (*css_alloc)(struct cgroup_subsys_state___51 *);
	int (*css_online)(struct cgroup_subsys_state___51 *);
	void (*css_offline)(struct cgroup_subsys_state___51 *);
	void (*css_released)(struct cgroup_subsys_state___51 *);
	void (*css_free)(struct cgroup_subsys_state___51 *);
	void (*css_reset)(struct cgroup_subsys_state___51 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___51 *, int);
	int (*css_extra_stat_show)(struct seq_file___59 *, struct cgroup_subsys_state___51 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___68 *, struct css_set___51 *);
	void (*cancel_fork)(struct task_struct___68 *, struct css_set___51 *);
	void (*fork)(struct task_struct___68 *);
	void (*exit)(struct task_struct___68 *);
	void (*release)(struct task_struct___68 *);
	void (*bind)(struct cgroup_subsys_state___51 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___51 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___51 *dfl_cftypes;
	struct cftype___51 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___51 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___51 *updated_children;
	struct cgroup___51 *updated_next;
};

struct cgroup_root___51 {
	struct kernfs_root___61 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___51 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___51 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___51 *ss;
	struct list_head node;
	struct kernfs_ops___61 *kf_ops;
	int (*open)(struct kernfs_open_file___61 *);
	void (*release)(struct kernfs_open_file___61 *);
	u64 (*read_u64)(struct cgroup_subsys_state___51 *, struct cftype___51 *);
	s64 (*read_s64)(struct cgroup_subsys_state___51 *, struct cftype___51 *);
	int (*seq_show)(struct seq_file___59 *, void *);
	void * (*seq_start)(struct seq_file___59 *, loff_t *);
	void * (*seq_next)(struct seq_file___59 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___59 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___51 *, struct cftype___51 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___51 *, struct cftype___51 *, s64);
	ssize_t (*write)(struct kernfs_open_file___61 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___61 *, struct poll_table_struct___47 *);
};

struct xdp_rxq_info___10 {
	struct net_device___15 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___10 {
	struct net_device___15 *dev;
};

struct xdp_buff___10 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___10 *rxq;
	struct xdp_txq_info___10 *txq;
	u32 frame_sz;
};

struct xdp_frame___10 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___15 *dev_rx;
};

struct netlink_callback___10 {
	struct sk_buff___12 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___12 *, struct netlink_callback___10 *);
	int (*done)(struct netlink_callback___10 *);
	void *data;
	struct module___60 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___10 {
	int (*create)(struct sk_buff___12 *, struct net_device___15 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___12 *, unsigned char *);
	int (*cache)(const struct neighbour___7 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___15 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___12 *);
};

struct netdev_queue___10 {
	struct net_device___15 *dev;
	struct Qdisc___10 *qdisc;
	struct Qdisc___10 *qdisc_sleeping;
	struct kobject___61 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___15 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___10 {
	struct sk_buff___12 *head;
	struct sk_buff___12 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___10;

struct Qdisc___10 {
	int (*enqueue)(struct sk_buff___12 *, struct Qdisc___10 *, struct sk_buff___12 **);
	struct sk_buff___12 * (*dequeue)(struct Qdisc___10 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___10 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___10 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___10 gso_skb;
	struct qdisc_skb_head___10 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___10 *next_sched;
	struct sk_buff_head___10 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___10 {
	struct xdp_rxq_info___10 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___61 kobj;
	struct net_device___15 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___10 {
	enum net_device_path_type type;
	const struct net_device___15 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___10 = 0,
				DEV_PATH_BR_VLAN_TAG___10 = 1,
				DEV_PATH_BR_VLAN_UNTAG___10 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___10 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___10 {
	const struct net_device___15 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___10 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___10 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___10 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___10 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___12 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___10 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___15 *dev;
	const char *name;
};

struct net_device_ops___10 {
	int (*ndo_init)(struct net_device___15 *);
	void (*ndo_uninit)(struct net_device___15 *);
	int (*ndo_open)(struct net_device___15 *);
	int (*ndo_stop)(struct net_device___15 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___12 *, struct net_device___15 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___12 *, struct net_device___15 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___15 *, struct sk_buff___12 *, struct net_device___15 *);
	void (*ndo_change_rx_flags)(struct net_device___15 *, int);
	void (*ndo_set_rx_mode)(struct net_device___15 *);
	int (*ndo_set_mac_address)(struct net_device___15 *, void *);
	int (*ndo_validate_addr)(struct net_device___15 *);
	int (*ndo_do_ioctl)(struct net_device___15 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___15 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___15 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___15 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___15 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___15 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___15 *, int);
	int (*ndo_neigh_setup)(struct net_device___15 *, struct neigh_parms___7 *);
	void (*ndo_tx_timeout)(struct net_device___15 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___15 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___15 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___15 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___15 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___15 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___15 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___15 *);
	int (*ndo_netpoll_setup)(struct net_device___15 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___15 *);
	int (*ndo_set_vf_mac)(struct net_device___15 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___15 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___15 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___15 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___15 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___15 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___15 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___15 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___15 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___15 *, int, struct sk_buff___12 *);
	int (*ndo_get_vf_guid)(struct net_device___15 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___15 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___15 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___15 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___15 *);
	int (*ndo_fcoe_disable)(struct net_device___15 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___15 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___15 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___15 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___15 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___15 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___15 *, const struct sk_buff___12 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___15 *, struct net_device___15 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___15 *, struct net_device___15 *);
	struct net_device___15 * (*ndo_get_xmit_slave)(struct net_device___15 *, struct sk_buff___12 *, bool);
	struct net_device___15 * (*ndo_sk_get_lower_dev)(struct net_device___15 *, struct sock___9 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___15 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___15 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___15 *, struct neighbour___7 *);
	void (*ndo_neigh_destroy)(struct net_device___15 *, struct neighbour___7 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___12 *, struct netlink_callback___10 *, struct net_device___15 *, struct net_device___15 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___12 *, struct nlattr **, struct net_device___15 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___15 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___12 *, u32, u32, struct net_device___15 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___15 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___15 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___15 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___15 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___15 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___15 *, struct net_device___15 *);
	void (*ndo_dfwd_del_station)(struct net_device___15 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___15 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___15 *);
	int (*ndo_change_proto_down)(struct net_device___15 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___15 *, struct sk_buff___12 *);
	void (*ndo_set_rx_headroom)(struct net_device___15 *, int);
	int (*ndo_bpf)(struct net_device___15 *, struct netdev_bpf___10 *);
	int (*ndo_xdp_xmit)(struct net_device___15 *, int, struct xdp_frame___10 **, u32);
	struct net_device___15 * (*ndo_xdp_get_xmit_slave)(struct net_device___15 *, struct xdp_buff___10 *);
	int (*ndo_xsk_wakeup)(struct net_device___15 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___15 *);
	int (*ndo_tunnel_ctl)(struct net_device___15 *, struct ip_tunnel_parm *, int);
	struct net_device___15 * (*ndo_get_peer_dev)(struct net_device___15 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___10 *, struct net_device_path___10 *);
};

struct neigh_parms___7 {
	possible_net_t___10 net;
	struct net_device___15 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___7 *);
	struct neigh_table___7 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___7 {
	u32 (*l3mdev_fib_table)(const struct net_device___15 *);
	struct sk_buff___12 * (*l3mdev_l3_rcv)(struct net_device___15 *, struct sk_buff___12 *, u16);
	struct sk_buff___12 * (*l3mdev_l3_out)(struct net_device___15 *, struct sock___9 *, struct sk_buff___12 *, u16);
	struct dst_entry___7 * (*l3mdev_link_scope_lookup)(const struct net_device___15 *, struct flowi6 *);
};

struct ndisc_ops___3 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___15 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___15 *, struct neighbour___7 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___15 *, u8, struct neighbour___7 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___15 *, struct sk_buff___12 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___13 *, struct net_device___15 *, const struct prefix_info *, struct inet6_dev___3 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___3;

struct inet6_dev___3 {
	struct net_device___15 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___3 *mc_list;
	struct ifmcaddr6___3 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___10 mc_query_queue;
	struct sk_buff_head___10 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___7 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___10;

struct tcf_block___10;

struct mini_Qdisc___10 {
	struct tcf_proto___10 *filter_list;
	struct tcf_block___10 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___10 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___15 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___15 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___13 *, struct net_device___15 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___15 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___15 *, struct list_head *);
	size_t (*get_size)(const struct net_device___15 *);
	int (*fill_info)(struct sk_buff___12 *, const struct net_device___15 *);
	size_t (*get_xstats_size)(const struct net_device___15 *);
	int (*fill_xstats)(struct sk_buff___12 *, const struct net_device___15 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___15 *, struct net_device___15 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___15 *, const struct net_device___15 *);
	int (*fill_slave_info)(struct sk_buff___12 *, const struct net_device___15 *, const struct net_device___15 *);
	struct net___13 * (*get_link_net)(const struct net_device___15 *);
	size_t (*get_linkxstats_size)(const struct net_device___15 *, int);
	int (*fill_linkxstats)(struct sk_buff___12 *, const struct net_device___15 *, int *, int);
};

struct block_device_operations___28;

struct gendisk___28 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___29 *part0;
	const struct block_device_operations___28 *fops;
	struct request_queue___29 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___27 *bdi;
	struct kobject___61 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___61 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___28 {
	struct bio___28 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___33 *bip_vec;
	struct bio_vec___33 bip_inline_vecs[0];
};

struct blkcg___27;

struct blkg_policy_data___27;

struct blkcg_gq___27 {
	struct request_queue___29 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___27 *blkcg;
	struct blkcg_gq___27 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___27 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___28 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___28(struct request___28 *);

typedef void integrity_complete_fn___28(struct request___28 *, unsigned int);

struct blk_integrity_profile___28 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___28 *prepare_fn;
	integrity_complete_fn___28 *complete_fn;
	const char *name;
};

struct block_device_operations___28 {
	blk_qc_t (*submit_bio)(struct bio___28 *);
	int (*open)(struct block_device___29 *, fmode_t);
	void (*release)(struct gendisk___28 *, fmode_t);
	int (*rw_page)(struct block_device___29 *, sector_t, struct page___66 *, unsigned int);
	int (*ioctl)(struct block_device___29 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___29 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___28 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___28 *);
	int (*getgeo)(struct block_device___29 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___29 *, bool);
	void (*swap_slot_free_notify)(struct block_device___29 *, long unsigned int);
	int (*report_zones)(struct gendisk___28 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___28 *, umode_t *);
	struct module___60 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___28 *, sector_t *);
};

typedef void rq_end_io_fn___28(struct request___28 *, blk_status_t);

struct request___28 {
	struct request_queue___29 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___27 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___28 *bio;
	struct bio___28 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___33 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___28 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___28 *saved_end_io;
		} flush;
	};
	struct gendisk___28 *rq_disk;
	struct block_device___29 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___28 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___27 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___29 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___61 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___62 *debugfs_dir;
	struct dentry___62 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___28;

struct elevator_mq_ops___28 {
	int (*init_sched)(struct request_queue___29 *, struct elevator_type___28 *);
	void (*exit_sched)(struct elevator_queue___28 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___27 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___27 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___27 *);
	bool (*allow_merge)(struct request_queue___29 *, struct request___28 *, struct bio___28 *);
	bool (*bio_merge)(struct request_queue___29 *, struct bio___28 *, unsigned int);
	int (*request_merge)(struct request_queue___29 *, struct request___28 **, struct bio___28 *);
	void (*request_merged)(struct request_queue___29 *, struct request___28 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___29 *, struct request___28 *, struct request___28 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___28 *);
	void (*finish_request)(struct request___28 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___27 *, struct list_head *, bool);
	struct request___28 * (*dispatch_request)(struct blk_mq_hw_ctx___27 *);
	bool (*has_work)(struct blk_mq_hw_ctx___27 *);
	void (*completed_request)(struct request___28 *, u64);
	void (*requeue_request)(struct request___28 *);
	struct request___28 * (*former_request)(struct request_queue___29 *, struct request___28 *);
	struct request___28 * (*next_request)(struct request_queue___29 *, struct request___28 *);
	void (*init_icq)(struct io_cq___28 *);
	void (*exit_icq)(struct io_cq___28 *);
};

struct elv_fs_entry___28;

struct elevator_type___28 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___28 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___28 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___60 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___28 {
	struct elevator_type___28 *type;
	void *elevator_data;
	struct kobject___61 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___28 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___28 *, char *);
	ssize_t (*store)(struct elevator_queue___28 *, const char *, size_t);
};

struct blk_mq_queue_data___27;

struct blk_mq_ops___27 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___27 *, const struct blk_mq_queue_data___27 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___27 *);
	int (*get_budget)(struct request_queue___29 *);
	void (*put_budget)(struct request_queue___29 *, int);
	void (*set_rq_budget_token)(struct request___28 *, int);
	int (*get_rq_budget_token)(struct request___28 *);
	enum blk_eh_timer_return (*timeout)(struct request___28 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___27 *);
	void (*complete)(struct request___28 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___27 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___27 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___27 *, struct request___28 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___27 *, struct request___28 *, unsigned int);
	void (*initialize_rq_fn)(struct request___28 *);
	void (*cleanup_rq)(struct request___28 *);
	bool (*busy)(struct request_queue___29 *);
	int (*map_queues)(struct blk_mq_tag_set___27 *);
	void (*show_rq)(struct seq_file___59 *, struct request___28 *);
};

struct blk_mq_tag_set___27 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___27 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___27 {
	struct request___28 *rq;
	bool last;
};

struct blkcg_policy_data___27;

struct blkcg___27 {
	struct cgroup_subsys_state___51 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___27 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___27 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___27 {
	struct blkcg___27 *blkcg;
	int plid;
};

struct blkg_policy_data___27 {
	struct blkcg_gq___27 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___25 {
	struct mem_cgroup___25 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___25 {
	struct lruvec___26 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___25 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___25 *memcg;
};

struct obj_cgroup___25 {
	struct percpu_ref refcnt;
	struct mem_cgroup___25 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___10 {
	spinlock_t *lock;
	struct sk_buff___12 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___10;

struct Qdisc_ops___10 {
	struct Qdisc_ops___10 *next;
	const struct Qdisc_class_ops___10 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___12 *, struct Qdisc___10 *, struct sk_buff___12 **);
	struct sk_buff___12 * (*dequeue)(struct Qdisc___10 *);
	struct sk_buff___12 * (*peek)(struct Qdisc___10 *);
	int (*init)(struct Qdisc___10 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___10 *);
	void (*destroy)(struct Qdisc___10 *);
	int (*change)(struct Qdisc___10 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___10 *);
	int (*change_tx_queue_len)(struct Qdisc___10 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___10 *, unsigned int);
	int (*dump)(struct Qdisc___10 *, struct sk_buff___12 *);
	int (*dump_stats)(struct Qdisc___10 *, struct gnet_dump___10 *);
	void (*ingress_block_set)(struct Qdisc___10 *, u32);
	void (*egress_block_set)(struct Qdisc___10 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___10 *);
	u32 (*egress_block_get)(struct Qdisc___10 *);
	struct module___60 *owner;
};

struct Qdisc_class_ops___10 {
	unsigned int flags;
	struct netdev_queue___10 * (*select_queue)(struct Qdisc___10 *, struct tcmsg *);
	int (*graft)(struct Qdisc___10 *, long unsigned int, struct Qdisc___10 *, struct Qdisc___10 **, struct netlink_ext_ack *);
	struct Qdisc___10 * (*leaf)(struct Qdisc___10 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___10 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___10 *, u32);
	int (*change)(struct Qdisc___10 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___10 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___10 *, struct qdisc_walker *);
	struct tcf_block___10 * (*tcf_block)(struct Qdisc___10 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___10 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___10 *, long unsigned int);
	int (*dump)(struct Qdisc___10 *, long unsigned int, struct sk_buff___12 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___10 *, long unsigned int, struct gnet_dump___10 *);
};

struct tcf_chain___10;

struct tcf_block___10 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___13 *net;
	struct Qdisc___10 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___10 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___10;

struct tcf_proto_ops___10;

struct tcf_proto___10 {
	struct tcf_proto___10 *next;
	void *root;
	int (*classify)(struct sk_buff___12 *, const struct tcf_proto___10 *, struct tcf_result___10 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___10 *ops;
	struct tcf_chain___10 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___10 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___10 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___10 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___12 *, const struct tcf_proto___10 *, struct tcf_result___10 *);
	int (*init)(struct tcf_proto___10 *);
	void (*destroy)(struct tcf_proto___10 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___10 *, u32);
	void (*put)(struct tcf_proto___10 *, void *);
	int (*change)(struct net___13 *, struct sk_buff___12 *, struct tcf_proto___10 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___10 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___10 *);
	void (*walk)(struct tcf_proto___10 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___10 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___10 *, void *);
	void (*hw_del)(struct tcf_proto___10 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___13 *, struct tcf_chain___10 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___13 *, struct tcf_proto___10 *, void *, struct sk_buff___12 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___13 *, struct tcf_proto___10 *, void *, struct sk_buff___12 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___12 *, struct net___13 *, void *);
	struct module___60 *owner;
	int flags;
};

struct tcf_chain___10 {
	struct mutex filter_chain_lock;
	struct tcf_proto___10 *filter_chain;
	struct list_head list;
	struct tcf_block___10 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___10 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___7 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___10 *prog;
};

struct pneigh_entry___7;

struct neigh_hash_table___7;

struct neigh_table___7 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___15 *, __u32 *);
	bool (*key_eq)(const struct neighbour___7 *, const void *);
	int (*constructor)(struct neighbour___7 *);
	int (*pconstructor)(struct pneigh_entry___7 *);
	void (*pdestructor)(struct pneigh_entry___7 *);
	void (*proxy_redo)(struct sk_buff___12 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___15 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___7 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___10 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___7 *nht;
	struct pneigh_entry___7 **phash_buckets;
};

struct neigh_ops___7 {
	int family;
	void (*solicit)(struct neighbour___7 *, struct sk_buff___12 *);
	void (*error_report)(struct neighbour___7 *, struct sk_buff___12 *);
	int (*output)(struct neighbour___7 *, struct sk_buff___12 *);
	int (*connected_output)(struct neighbour___7 *, struct sk_buff___12 *);
};

struct pneigh_entry___7 {
	struct pneigh_entry___7 *next;
	possible_net_t___10 net;
	struct net_device___15 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___7 {
	struct neighbour___7 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___7 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___7 *ctarget;
	struct net___13 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___7 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___7 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___4;

struct timewait_sock_ops___4;

struct proto___7 {
	void (*close)(struct sock___9 *, long int);
	int (*pre_connect)(struct sock___9 *, struct sockaddr *, int);
	int (*connect)(struct sock___9 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___9 *, int);
	struct sock___9 * (*accept)(struct sock___9 *, int, int *, bool);
	int (*ioctl)(struct sock___9 *, int, long unsigned int);
	int (*init)(struct sock___9 *);
	void (*destroy)(struct sock___9 *);
	void (*shutdown)(struct sock___9 *, int);
	int (*setsockopt)(struct sock___9 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___9 *, int, int, char *, int *);
	void (*keepalive)(struct sock___9 *, int);
	int (*compat_ioctl)(struct sock___9 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___9 *, struct msghdr___7 *, size_t);
	int (*recvmsg)(struct sock___9 *, struct msghdr___7 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___9 *, struct page___66 *, int, size_t, int);
	int (*bind)(struct sock___9 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___9 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___9 *, struct sk_buff___12 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___9 *);
	int (*hash)(struct sock___9 *);
	void (*unhash)(struct sock___9 *);
	void (*rehash)(struct sock___9 *);
	int (*get_port)(struct sock___9 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___9 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___9 *, int);
	bool (*sock_is_readable)(struct sock___9 *);
	void (*enter_memory_pressure)(struct sock___9 *);
	void (*leave_memory_pressure)(struct sock___9 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___4 *rsk_prot;
	struct timewait_sock_ops___4 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___60 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___9 *, int);
};

struct request_sock___3;

struct request_sock_ops___4 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___9 *, struct request_sock___3 *);
	void (*send_ack)(const struct sock___9 *, struct sk_buff___12 *, struct request_sock___3 *);
	void (*send_reset)(const struct sock___9 *, struct sk_buff___12 *);
	void (*destructor)(struct request_sock___3 *);
	void (*syn_ack_timeout)(const struct request_sock___3 *);
};

struct timewait_sock_ops___4 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___9 *, struct sock___9 *, void *);
	void (*twsk_destructor)(struct sock___9 *);
};

struct request_sock___3 {
	struct sock_common___7 __req_common;
	struct request_sock___3 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___4 *rsk_ops;
	struct sock___9 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___3 {
	struct in6_addr mca_addr;
	struct inet6_dev___3 *idev;
	struct ifmcaddr6___3 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct lpm_trie_node {
	struct callback_head rcu;
	struct lpm_trie_node *child[2];
	u32 prefixlen;
	u32 flags;
	u8 data[0];
};

struct lpm_trie {
	struct bpf_map___10 map;
	struct lpm_trie_node *root;
	size_t n_entries;
	size_t max_prefixlen;
	size_t data_size;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___63;

struct super_block___63;

struct module___61;

struct file_system_type___62 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___63 * (*mount)(struct file_system_type___62 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___63 *);
	struct module___61 *owner;
	struct file_system_type___62 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___62;

struct vm_area_struct___67;

struct inode___63;

struct file_lock___62;

struct page___67;

struct file_operations___62 {
	struct module___61 *owner;
	loff_t (*llseek)(struct file___29 *, loff_t, int);
	ssize_t (*read)(struct file___29 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___29 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___62 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___62 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___62 *, bool);
	int (*iterate)(struct file___29 *, struct dir_context *);
	int (*iterate_shared)(struct file___29 *, struct dir_context *);
	__poll_t (*poll)(struct file___29 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___29 *, struct vm_area_struct___67 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___63 *, struct file___29 *);
	int (*flush)(struct file___29 *, fl_owner_t);
	int (*release)(struct inode___63 *, struct file___29 *);
	int (*fsync)(struct file___29 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___29 *, int);
	int (*lock)(struct file___29 *, int, struct file_lock___62 *);
	ssize_t (*sendpage)(struct file___29 *, struct page___67 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___29 *, long unsigned int);
	int (*flock)(struct file___29 *, int, struct file_lock___62 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___29 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___29 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___29 *, long int, struct file_lock___62 **, void **);
	long int (*fallocate)(struct file___29 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___29 *);
	ssize_t (*copy_file_range)(struct file___29 *, loff_t, struct file___29 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___29 *, loff_t, struct file___29 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___29 *, loff_t, loff_t, int);
};

struct vmacache___67 {
	u64 seqnum;
	struct vm_area_struct___67 *vmas[4];
};

struct page_frag___67 {
	struct page___67 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___68;

struct signal_struct___63;

struct task_struct___69 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___69 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___68 *mm;
	struct mm_struct___68 *active_mm;
	struct vmacache___67 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___69 *real_parent;
	struct task_struct___69 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___69 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___55 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___63 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___69 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___67 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___69 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___42 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___62;

struct kobj_type___62;

struct kernfs_node___62;

struct kobject___62 {
	const char *name;
	struct list_head entry;
	struct kobject___62 *parent;
	struct kset___62 *kset;
	struct kobj_type___62 *ktype;
	struct kernfs_node___62 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___59 {
	struct kobject___62 kobj;
	struct module___61 *mod;
	struct kobject___62 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___59 {
	struct module___61 *mod;
	struct latch_tree_node node;
};

struct module_layout___59 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___59 mtn;
};

struct module_attribute___59;

struct kernel_param___59;

struct module___61 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___59 mkobj;
	struct module_attribute___59 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___62 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___59 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___59 core_layout;
	struct module_layout___59 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___67 *pgtable_t___67;

struct address_space___62;

struct dev_pagemap___61;

struct page___67 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___62 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___19 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___67 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___67 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___68 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___61 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___61;

struct vm_area_struct___67 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___67 *vm_next;
	struct vm_area_struct___67 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___68 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___61 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___29 *vm_file;
	struct file___29 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___67;

struct mm_struct___68 {
	struct {
		struct vm_area_struct___67 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___67 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___69 *owner;
		struct user_namespace *user_ns;
		struct file___29 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___62;

struct address_space___62 {
	struct inode___63 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___62 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___61;

struct dev_pagemap___61 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___61 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___62;

struct path___62 {
	struct vfsmount___62 *mnt;
	struct dentry___63 *dentry;
};

struct file___29 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___62 f_path;
	struct inode___63 *f_inode;
	const struct file_operations___62 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___55 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___62 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___61;

struct vm_operations_struct___61 {
	void (*open)(struct vm_area_struct___67 *);
	void (*close)(struct vm_area_struct___67 *);
	int (*may_split)(struct vm_area_struct___67 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___67 *);
	int (*mprotect)(struct vm_area_struct___67 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___61 *);
	vm_fault_t (*huge_fault)(struct vm_fault___61 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___61 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___67 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___61 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___61 *);
	int (*access)(struct vm_area_struct___67 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___67 *);
	int (*set_policy)(struct vm_area_struct___67 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___67 *, long unsigned int);
	struct page___67 * (*find_special_page)(struct vm_area_struct___67 *, long unsigned int);
};

struct core_thread___67 {
	struct task_struct___69 *task;
	struct core_thread___67 *next;
};

struct core_state___67 {
	atomic_t nr_threads;
	struct core_thread___67 dumper;
	struct completion startup;
};

struct vm_fault___61 {
	const struct {
		struct vm_area_struct___67 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___67 *cow_page;
	struct page___67 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___67 prealloc_pte;
};

struct fd___7 {
	struct file___29 *file;
	unsigned int flags;
};

struct signal_struct___63 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___69 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___69 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___55 *pids[4];
	struct pid___55 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___68 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct dentry_operations___62;

struct dentry___63 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___63 *d_parent;
	struct qstr d_name;
	struct inode___63 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___62 *d_op;
	struct super_block___63 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___62;

struct inode___63 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___62 *i_op;
	struct super_block___63 *i_sb;
	struct address_space___62 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___62 *i_fop;
		void (*free_inode)(struct inode___63 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___62 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___22 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___62 {
	int (*d_revalidate)(struct dentry___63 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___63 *, unsigned int);
	int (*d_hash)(const struct dentry___63 *, struct qstr *);
	int (*d_compare)(const struct dentry___63 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___63 *);
	int (*d_init)(struct dentry___63 *);
	void (*d_release)(struct dentry___63 *);
	void (*d_prune)(struct dentry___63 *);
	void (*d_iput)(struct dentry___63 *, struct inode___63 *);
	char * (*d_dname)(struct dentry___63 *, char *, int);
	struct vfsmount___62 * (*d_automount)(struct path___62 *);
	int (*d_manage)(const struct path___62 *, bool);
	struct dentry___63 * (*d_real)(struct dentry___63 *, const struct inode___63 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___62;

struct mem_dqinfo___62 {
	struct quota_format_type___62 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___62;

struct quota_info___62 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___63 *files[3];
	struct mem_dqinfo___62 info[3];
	const struct quota_format_ops___62 *ops[3];
};

struct rcuwait___63 {
	struct task_struct___69 *task;
};

struct percpu_rw_semaphore___63 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___63 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___62 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___63 rw_sem[3];
};

struct super_operations___62;

struct dquot_operations___62;

struct quotactl_ops___62;

struct super_block___63 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___62 *s_type;
	const struct super_operations___62 *s_op;
	const struct dquot_operations___62 *dq_op;
	const struct quotactl_ops___62 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___63 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___62 s_dquot;
	struct sb_writers___62 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___62 *s_d_op;
	int cleancache_poolid;
	struct shrinker___25 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___62 {
	struct dentry___63 *mnt_root;
	struct super_block___63 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___62 {
	struct file___29 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___62 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___63 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___29 *ia_file;
};

struct dquot___62 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___63 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___62 {
	int qf_fmt_id;
	const struct quota_format_ops___62 *qf_ops;
	struct module___61 *qf_owner;
	struct quota_format_type___62 *qf_next;
};

struct quota_format_ops___62 {
	int (*check_quota_file)(struct super_block___63 *, int);
	int (*read_file_info)(struct super_block___63 *, int);
	int (*write_file_info)(struct super_block___63 *, int);
	int (*free_file_info)(struct super_block___63 *, int);
	int (*read_dqblk)(struct dquot___62 *);
	int (*commit_dqblk)(struct dquot___62 *);
	int (*release_dqblk)(struct dquot___62 *);
	int (*get_next_id)(struct super_block___63 *, struct kqid *);
};

struct dquot_operations___62 {
	int (*write_dquot)(struct dquot___62 *);
	struct dquot___62 * (*alloc_dquot)(struct super_block___63 *, int);
	void (*destroy_dquot)(struct dquot___62 *);
	int (*acquire_dquot)(struct dquot___62 *);
	int (*release_dquot)(struct dquot___62 *);
	int (*mark_dirty)(struct dquot___62 *);
	int (*write_info)(struct super_block___63 *, int);
	qsize_t * (*get_reserved_space)(struct inode___63 *);
	int (*get_projid)(struct inode___63 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___63 *, qsize_t *);
	int (*get_next_id)(struct super_block___63 *, struct kqid *);
};

struct quotactl_ops___62 {
	int (*quota_on)(struct super_block___63 *, int, int, const struct path___62 *);
	int (*quota_off)(struct super_block___63 *, int);
	int (*quota_enable)(struct super_block___63 *, unsigned int);
	int (*quota_disable)(struct super_block___63 *, unsigned int);
	int (*quota_sync)(struct super_block___63 *, int);
	int (*set_info)(struct super_block___63 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___63 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___63 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___63 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___63 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___63 *, unsigned int);
};

struct address_space_operations___62 {
	int (*writepage)(struct page___67 *, struct writeback_control___3 *);
	int (*readpage)(struct file___29 *, struct page___67 *);
	int (*writepages)(struct address_space___62 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___67 *);
	int (*readpages)(struct file___29 *, struct address_space___62 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___29 *, struct address_space___62 *, loff_t, unsigned int, unsigned int, struct page___67 **, void **);
	int (*write_end)(struct file___29 *, struct address_space___62 *, loff_t, unsigned int, unsigned int, struct page___67 *, void *);
	sector_t (*bmap)(struct address_space___62 *, sector_t);
	void (*invalidatepage)(struct page___67 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___67 *, gfp_t);
	void (*freepage)(struct page___67 *);
	ssize_t (*direct_IO)(struct kiocb___62 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___62 *, struct page___67 *, struct page___67 *, enum migrate_mode);
	bool (*isolate_page)(struct page___67 *, isolate_mode_t);
	void (*putback_page)(struct page___67 *);
	int (*launder_page)(struct page___67 *);
	int (*is_partially_uptodate)(struct page___67 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___67 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___62 *, struct page___67 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___29 *, sector_t *);
	void (*swap_deactivate)(struct file___29 *);
};

struct inode_operations___62 {
	struct dentry___63 * (*lookup)(struct inode___63 *, struct dentry___63 *, unsigned int);
	const char * (*get_link)(struct dentry___63 *, struct inode___63 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___63 *, int);
	struct posix_acl * (*get_acl)(struct inode___63 *, int, bool);
	int (*readlink)(struct dentry___63 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___63 *, struct dentry___63 *, umode_t, bool);
	int (*link)(struct dentry___63 *, struct inode___63 *, struct dentry___63 *);
	int (*unlink)(struct inode___63 *, struct dentry___63 *);
	int (*symlink)(struct user_namespace *, struct inode___63 *, struct dentry___63 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___63 *, struct dentry___63 *, umode_t);
	int (*rmdir)(struct inode___63 *, struct dentry___63 *);
	int (*mknod)(struct user_namespace *, struct inode___63 *, struct dentry___63 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___63 *, struct dentry___63 *, struct inode___63 *, struct dentry___63 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___63 *, struct iattr___63 *);
	int (*getattr)(struct user_namespace *, const struct path___62 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___63 *, char *, size_t);
	int (*fiemap)(struct inode___63 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___63 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___63 *, struct dentry___63 *, struct file___29 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___63 *, struct dentry___63 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___63 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___63 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___63 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___62 {
	void (*fl_copy_lock)(struct file_lock___62 *, struct file_lock___62 *);
	void (*fl_release_private)(struct file_lock___62 *);
};

struct fasync_struct___62;

struct lock_manager_operations___62;

struct file_lock___62 {
	struct file_lock___62 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___29 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___62 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___62 *fl_ops;
	const struct lock_manager_operations___62 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___62 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___62 *);
	int (*lm_grant)(struct file_lock___62 *, int);
	bool (*lm_break)(struct file_lock___62 *);
	int (*lm_change)(struct file_lock___62 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___62 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___62 *);
};

struct fasync_struct___62 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___62 *fa_next;
	struct file___29 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___62 {
	struct inode___63 * (*alloc_inode)(struct super_block___63 *);
	void (*destroy_inode)(struct inode___63 *);
	void (*free_inode)(struct inode___63 *);
	void (*dirty_inode)(struct inode___63 *, int);
	int (*write_inode)(struct inode___63 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___63 *);
	void (*evict_inode)(struct inode___63 *);
	void (*put_super)(struct super_block___63 *);
	int (*sync_fs)(struct super_block___63 *, int);
	int (*freeze_super)(struct super_block___63 *);
	int (*freeze_fs)(struct super_block___63 *);
	int (*thaw_super)(struct super_block___63 *);
	int (*unfreeze_fs)(struct super_block___63 *);
	int (*statfs)(struct dentry___63 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___63 *, int *, char *);
	void (*umount_begin)(struct super_block___63 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___63 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___63 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___63 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___63 *);
	ssize_t (*quota_read)(struct super_block___63 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___63 *, int, const char *, size_t, loff_t);
	struct dquot___62 ** (*get_dquots)(struct inode___63 *);
	long int (*nr_cached_objects)(struct super_block___63 *, struct shrink_control___25 *);
	long int (*free_cached_objects)(struct super_block___63 *, struct shrink_control___25 *);
	struct file___29 * (*real_loop)(struct file___29 *);
};

struct kernfs_root___62;

struct kernfs_elem_dir___62 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___62 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___62;

struct kernfs_root___62 {
	struct kernfs_node___62 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___62 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___62 {
	struct kernfs_node___62 *target_kn;
};

struct kernfs_ops___62;

struct kernfs_elem_attr___62 {
	const struct kernfs_ops___62 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___62 *notify_next;
};

struct kernfs_node___62 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___62 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___62 dir;
		struct kernfs_elem_symlink___62 symlink;
		struct kernfs_elem_attr___62 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___62;

struct kernfs_ops___62 {
	int (*open)(struct kernfs_open_file___62 *);
	void (*release)(struct kernfs_open_file___62 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___62 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___62 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___62 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___62 *, struct vm_area_struct___67 *);
};

struct kernfs_syscall_ops___62 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___62 *);
	int (*mkdir)(struct kernfs_node___62 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___62 *);
	int (*rename)(struct kernfs_node___62 *, struct kernfs_node___62 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___62 *, struct kernfs_root___62 *);
};

struct kernfs_open_file___62 {
	struct kernfs_node___62 *kn;
	struct file___29 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___61 *vm_ops;
};

struct bin_attribute___62;

struct attribute_group___62 {
	const char *name;
	umode_t (*is_visible)(struct kobject___62 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___62 *, struct bin_attribute___62 *, int);
	struct attribute **attrs;
	struct bin_attribute___62 **bin_attrs;
};

struct bin_attribute___62 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___62 * (*f_mapping)();
	ssize_t (*read)(struct file___29 *, struct kobject___62 *, struct bin_attribute___62 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___62 *, struct bin_attribute___62 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___62 *, struct bin_attribute___62 *, struct vm_area_struct___67 *);
};

struct sysfs_ops___62 {
	ssize_t (*show)(struct kobject___62 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___62 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___62;

struct kset___62 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___62 kobj;
	const struct kset_uevent_ops___62 *uevent_ops;
};

struct kobj_type___62 {
	void (*release)(struct kobject___62 *);
	const struct sysfs_ops___62 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___62 **default_groups;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___62 *);
	const void * (*namespace)(struct kobject___62 *);
	void (*get_ownership)(struct kobject___62 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___62 {
	int (* const filter)(struct kset___62 *, struct kobject___62 *);
	const char * (* const name)(struct kset___62 *, struct kobject___62 *);
	int (* const uevent)(struct kset___62 *, struct kobject___62 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___59 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___59 *);
	int (*get)(char *, const struct kernel_param___59 *);
	void (*free)(void *);
};

struct kparam_array___59;

struct kernel_param___59 {
	const char *name;
	struct module___61 *mod;
	const struct kernel_param_ops___59 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___59 *arr;
	};
};

struct kparam_array___59 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___59 *ops;
	void *elem;
};

struct module_attribute___59 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___59 *, struct module_kobject___59 *, char *);
	ssize_t (*store)(struct module_attribute___59 *, struct module_kobject___59 *, const char *, size_t);
	void (*setup)(struct module___61 *, const char *);
	int (*test)(struct module___61 *);
	void (*free)(struct module___61 *);
};

struct dev_pagemap_ops___61 {
	void (*page_free)(struct page___67 *);
	void (*kill)(struct dev_pagemap___61 *);
	void (*cleanup)(struct dev_pagemap___61 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___61 *);
};

struct bpf_iter_aux_info___11;

typedef int (*bpf_iter_init_seq_priv_t___11)(void *, struct bpf_iter_aux_info___11 *);

struct bpf_map___11;

struct bpf_iter_aux_info___11 {
	struct bpf_map___11 *map;
};

struct seq_operations___60;

struct bpf_iter_seq_info___11 {
	const struct seq_operations___60 *seq_ops;
	bpf_iter_init_seq_priv_t___11 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_file___60;

struct seq_operations___60 {
	void * (*start)(struct seq_file___60 *, loff_t *);
	void (*stop)(struct seq_file___60 *, void *);
	void * (*next)(struct seq_file___60 *, void *, loff_t *);
	int (*show)(struct seq_file___60 *, void *);
};

struct bpf_prog_aux___11;

struct bpf_map_ops___11 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___11 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___11 *, struct file___29 *);
	void (*map_free)(struct bpf_map___11 *);
	int (*map_get_next_key)(struct bpf_map___11 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___11 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___11 *, void *);
	int (*map_lookup_batch)(struct bpf_map___11 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___11 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___11 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___11 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___11 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___11 *, void *);
	int (*map_update_elem)(struct bpf_map___11 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___11 *, void *);
	int (*map_push_elem)(struct bpf_map___11 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___11 *, void *);
	int (*map_peek_elem)(struct bpf_map___11 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___11 *, struct file___29 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___11 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___11 *, void *, struct seq_file___9 *);
	int (*map_check_btf)(const struct bpf_map___11 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___11 *, struct bpf_prog_aux___11 *);
	void (*map_poke_untrack)(struct bpf_map___11 *, struct bpf_prog_aux___11 *);
	void (*map_poke_run)(struct bpf_map___11 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___11 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___11 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___11 *, struct vm_area_struct___67 *);
	__poll_t (*map_poll)(struct bpf_map___11 *, struct file___29 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___11 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___11 *, const struct bpf_map___11 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___11 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___11 *iter_seq_info;
};

struct bpf_map___11 {
	const struct bpf_map_ops___11 *ops;
	struct bpf_map___11 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___11;

struct bpf_jit_poke_descriptor___11;

struct btf_mod_pair___11;

struct bpf_prog_aux___11 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___11 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___11 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___10 *ops;
	struct bpf_map___11 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___11 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___11 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___10 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_trampoline___11 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___61 *mod;
};

struct bpf_jit_poke_descriptor___11 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___11 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___11 {
	struct btf *btf;
	struct module___61 *module;
};

struct bpf_array_aux___6 {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___11 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_array___6 {
	struct bpf_map___11 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux___6 *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_local_storage_data___2;

struct bpf_local_storage {
	struct bpf_local_storage_data___2 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct bpf_local_storage_map {
	struct bpf_map map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_cgroup_storage_map {
	struct bpf_map map;
	spinlock_t lock;
	struct rb_root root;
	struct list_head list;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_local_storage_data___2 {
	struct bpf_local_storage_map *smap;
	u8 data[0];
};

struct cgroup_taskset {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___3 *cur_cset;
	struct task_struct___4 *cur_task;
};

struct bpf_queue_stack {
	struct bpf_map___11 map;
	raw_spinlock_t lock;
	u32 head;
	u32 tail;
	u32 size;
	char elements[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	BPF_RB_NO_WAKEUP = 1,
	BPF_RB_FORCE_WAKEUP = 2,
};

enum {
	BPF_RB_AVAIL_DATA = 0,
	BPF_RB_RING_SIZE = 1,
	BPF_RB_CONS_POS = 2,
	BPF_RB_PROD_POS = 3,
};

enum {
	BPF_RINGBUF_BUSY_BIT = 2147483648,
	BPF_RINGBUF_DISCARD_BIT = 1073741824,
	BPF_RINGBUF_HDR_SZ = 8,
};

typedef struct poll_table_struct___47 poll_table___12;

struct bpf_ringbuf {
	wait_queue_head_t waitq;
	struct irq_work work;
	u64 mask;
	struct page___66 **pages;
	int nr_pages;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t spinlock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int consumer_pos;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int producer_pos;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char data[0];
};

struct bpf_ringbuf_map {
	struct bpf_map___10 map;
	struct bpf_ringbuf *rb;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_ringbuf_hdr {
	u32 len;
	u32 pg_off;
};

typedef u64 (*btf_bpf_ringbuf_reserve)(struct bpf_map___10 *, u64, u64);

typedef u64 (*btf_bpf_ringbuf_submit)(void *, u64);

typedef u64 (*btf_bpf_ringbuf_discard)(void *, u64);

typedef u64 (*btf_bpf_ringbuf_output)(struct bpf_map___10 *, void *, u64, u64);

typedef u64 (*btf_bpf_ringbuf_query)(struct bpf_map___10 *, u64);

struct bpf_local_storage_elem {
	struct hlist_node map_node;
	struct hlist_node snode;
	struct bpf_local_storage___2 *local_storage;
	struct callback_head rcu;
	long: 64;
	struct bpf_local_storage_data sdata;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_local_storage_cache {
	spinlock_t idx_lock;
	u64 idx_usage_counts[16];
};

struct dentry___64;

struct super_block___64;

struct module___62;

struct file_system_type___63 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___64 * (*mount)(struct file_system_type___63 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___64 *);
	struct module___62 *owner;
	struct file_system_type___63 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___63;

struct kiocb___63;

struct iov_iter___34;

struct vm_area_struct___68;

struct inode___64;

struct file_lock___63;

struct page___68;

struct pipe_inode_info___23;

struct seq_file___61;

struct file_operations___63 {
	struct module___62 *owner;
	loff_t (*llseek)(struct file___63 *, loff_t, int);
	ssize_t (*read)(struct file___63 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___63 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___63 *, struct iov_iter___34 *);
	ssize_t (*write_iter)(struct kiocb___63 *, struct iov_iter___34 *);
	int (*iopoll)(struct kiocb___63 *, bool);
	int (*iterate)(struct file___63 *, struct dir_context *);
	int (*iterate_shared)(struct file___63 *, struct dir_context *);
	__poll_t (*poll)(struct file___63 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___63 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___63 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___63 *, struct vm_area_struct___68 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___64 *, struct file___63 *);
	int (*flush)(struct file___63 *, fl_owner_t);
	int (*release)(struct inode___64 *, struct file___63 *);
	int (*fsync)(struct file___63 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___63 *, int);
	int (*lock)(struct file___63 *, int, struct file_lock___63 *);
	ssize_t (*sendpage)(struct file___63 *, struct page___68 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___63 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___63 *, long unsigned int);
	int (*flock)(struct file___63 *, int, struct file_lock___63 *);
	ssize_t (*splice_write)(struct pipe_inode_info___23 *, struct file___63 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___63 *, loff_t *, struct pipe_inode_info___23 *, size_t, unsigned int);
	int (*setlease)(struct file___63 *, long int, struct file_lock___63 **, void **);
	long int (*fallocate)(struct file___63 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___61 *, struct file___63 *);
	ssize_t (*copy_file_range)(struct file___63 *, loff_t, struct file___63 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___63 *, loff_t, struct file___63 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___63 *, loff_t, loff_t, int);
};

struct vmacache___68 {
	u64 seqnum;
	struct vm_area_struct___68 *vmas[4];
};

struct page_frag___68 {
	struct page___68 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___69;

struct pid___56;

struct files_struct___5;

struct nsproxy___61;

struct signal_struct___64;

struct css_set___52;

struct vm_struct___64;

struct bpf_local_storage___3;

struct task_struct___70 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___70 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___69 *mm;
	struct mm_struct___69 *active_mm;
	struct vmacache___68 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___70 *real_parent;
	struct task_struct___70 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___70 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___56 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___5 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___61 *nsproxy;
	struct signal_struct___64 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___70 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___2 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___52 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___23 *splice_pipe;
	struct page_frag___68 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___70 *oom_reaper_list;
	struct vm_struct___64 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___3 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___42 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___63;

struct kobj_type___63;

struct kernfs_node___63;

struct kobject___63 {
	const char *name;
	struct list_head entry;
	struct kobject___63 *parent;
	struct kset___63 *kset;
	struct kobj_type___63 *ktype;
	struct kernfs_node___63 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___60 {
	struct kobject___63 kobj;
	struct module___62 *mod;
	struct kobject___63 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___60 {
	struct module___62 *mod;
	struct latch_tree_node node;
};

struct module_layout___60 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___60 mtn;
};

struct module_attribute___60;

struct kernel_param___60;

struct module___62 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___60 mkobj;
	struct module_attribute___60 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___63 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___60 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___60 core_layout;
	struct module_layout___60 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___56;

struct upid___56 {
	int nr;
	struct pid_namespace___56 *ns;
};

struct pid_namespace___56 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___70 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___56 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___56 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___56 numbers[1];
};

typedef struct page___68 *pgtable_t___68;

struct address_space___63;

struct page_pool___20;

struct dev_pagemap___62;

struct page___68 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___63 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___20 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___68 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___68 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___69 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___62 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___62;

struct vm_area_struct___68 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___68 *vm_next;
	struct vm_area_struct___68 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___69 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___62 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___63 *vm_file;
	struct file___63 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___64 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___70 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___70 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___56 *pids[4];
	struct pid___56 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___69 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___68;

struct mm_struct___69 {
	struct {
		struct vm_area_struct___68 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___63 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___68 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___70 *owner;
		struct user_namespace___10 *user_ns;
		struct file___63 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___5 {
	unsigned int max_fds;
	struct file___63 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___5 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___5 *fdt;
	struct fdtable___5 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___63 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___14;

struct cgroup_namespace___52;

struct nsproxy___61 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___56 *pid_ns_for_children;
	struct net___14 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___52 *cgroup_ns;
};

struct cgroup_subsys_state___52;

struct cgroup___52;

struct css_set___52 {
	struct cgroup_subsys_state___52 *subsys[14];
	refcount_t refcount;
	struct css_set___52 *dom_cset;
	struct cgroup___52 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___52 *mg_src_cgrp;
	struct cgroup___52 *mg_dst_cgrp;
	struct css_set___52 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___63;

struct pipe_buffer___23;

struct pipe_inode_info___23 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___68 *tmp_page;
	struct fasync_struct___63 *fasync_readers;
	struct fasync_struct___63 *fasync_writers;
	struct pipe_buffer___23 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___64 {
	struct vm_struct___64 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___68 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___3;

struct bpf_local_storage___3 {
	struct bpf_local_storage_data___3 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

enum {
	BPF_LOCAL_STORAGE_GET_F_CREATE = 1,
	BPF_SK_STORAGE_GET_F_CREATE = 1,
};

struct vfsmount___63;

struct path___63 {
	struct vfsmount___63 *mnt;
	struct dentry___64 *dentry;
};

struct fown_struct___56 {
	rwlock_t lock;
	struct pid___56 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___63 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___63 f_path;
	struct inode___64 *f_inode;
	const struct file_operations___63 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___56 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___63 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct address_space_operations___63;

struct address_space___63 {
	struct inode___64 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___63 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___56;

struct page_pool_params___20 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___56 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___20 {
	u32 count;
	struct page___68 *cache[128];
};

struct page_pool___20 {
	struct page_pool_params___20 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___68 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___20 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___62;

struct dev_pagemap___62 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___62 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___62;

struct vm_operations_struct___62 {
	void (*open)(struct vm_area_struct___68 *);
	void (*close)(struct vm_area_struct___68 *);
	int (*may_split)(struct vm_area_struct___68 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___68 *);
	int (*mprotect)(struct vm_area_struct___68 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___62 *);
	vm_fault_t (*huge_fault)(struct vm_fault___62 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___62 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___68 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___62 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___62 *);
	int (*access)(struct vm_area_struct___68 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___68 *);
	int (*set_policy)(struct vm_area_struct___68 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___68 *, long unsigned int);
	struct page___68 * (*find_special_page)(struct vm_area_struct___68 *, long unsigned int);
};

struct core_thread___68 {
	struct task_struct___70 *task;
	struct core_thread___68 *next;
};

struct core_state___68 {
	atomic_t nr_threads;
	struct core_thread___68 dumper;
	struct completion startup;
};

struct vm_fault___62 {
	const struct {
		struct vm_area_struct___68 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___68 *cow_page;
	struct page___68 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___68 prealloc_pte;
};

struct dentry_operations___63;

struct dentry___64 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___64 *d_parent;
	struct qstr d_name;
	struct inode___64 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___63 *d_op;
	struct super_block___64 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___63;

struct inode___64 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___63 *i_op;
	struct super_block___64 *i_sb;
	struct address_space___63 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___63 *i_fop;
		void (*free_inode)(struct inode___64 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___63 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___23 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___63 {
	int (*d_revalidate)(struct dentry___64 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___64 *, unsigned int);
	int (*d_hash)(const struct dentry___64 *, struct qstr *);
	int (*d_compare)(const struct dentry___64 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___64 *);
	int (*d_init)(struct dentry___64 *);
	void (*d_release)(struct dentry___64 *);
	void (*d_prune)(struct dentry___64 *);
	void (*d_iput)(struct dentry___64 *, struct inode___64 *);
	char * (*d_dname)(struct dentry___64 *, char *, int);
	struct vfsmount___63 * (*d_automount)(struct path___63 *);
	int (*d_manage)(const struct path___63 *, bool);
	struct dentry___64 * (*d_real)(struct dentry___64 *, const struct inode___64 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___63;

struct mem_dqinfo___63 {
	struct quota_format_type___63 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___63;

struct quota_info___63 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___64 *files[3];
	struct mem_dqinfo___63 info[3];
	const struct quota_format_ops___63 *ops[3];
};

struct rcuwait___64 {
	struct task_struct___70 *task;
};

struct percpu_rw_semaphore___64 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___64 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___63 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___64 rw_sem[3];
};

struct super_operations___63;

struct dquot_operations___63;

struct quotactl_ops___63;

struct super_block___64 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___63 *s_type;
	const struct super_operations___63 *s_op;
	const struct dquot_operations___63 *dq_op;
	const struct quotactl_ops___63 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___64 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___63 s_dquot;
	struct sb_writers___63 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___63 *s_d_op;
	int cleancache_poolid;
	struct shrinker___25 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___63 {
	struct dentry___64 *mnt_root;
	struct super_block___64 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct cgroup_subsys___52;

struct cgroup_subsys_state___52 {
	struct cgroup___52 *cgroup;
	struct cgroup_subsys___52 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___52 *parent;
};

struct cgroup_file___52 {
	struct kernfs_node___63 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___52 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___70 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___11;

struct cgroup_bpf___11 {
	struct bpf_prog_array___11 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___11 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___52;

struct cgroup_rstat_cpu___52;

struct cgroup___52 {
	struct cgroup_subsys_state___52 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___63 *kn;
	struct cgroup_file___52 procs_file;
	struct cgroup_file___52 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___52 *subsys[14];
	struct cgroup_root___52 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___52 *dom_cgrp;
	struct cgroup___52 *old_dom_cgrp;
	struct cgroup_rstat_cpu___52 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___52 psi;
	struct cgroup_bpf___11 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___63 {
	struct file___63 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___63 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___64 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___63 *ia_file;
};

struct dquot___63 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___64 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___63 {
	int qf_fmt_id;
	const struct quota_format_ops___63 *qf_ops;
	struct module___62 *qf_owner;
	struct quota_format_type___63 *qf_next;
};

struct quota_format_ops___63 {
	int (*check_quota_file)(struct super_block___64 *, int);
	int (*read_file_info)(struct super_block___64 *, int);
	int (*write_file_info)(struct super_block___64 *, int);
	int (*free_file_info)(struct super_block___64 *, int);
	int (*read_dqblk)(struct dquot___63 *);
	int (*commit_dqblk)(struct dquot___63 *);
	int (*release_dqblk)(struct dquot___63 *);
	int (*get_next_id)(struct super_block___64 *, struct kqid *);
};

struct dquot_operations___63 {
	int (*write_dquot)(struct dquot___63 *);
	struct dquot___63 * (*alloc_dquot)(struct super_block___64 *, int);
	void (*destroy_dquot)(struct dquot___63 *);
	int (*acquire_dquot)(struct dquot___63 *);
	int (*release_dquot)(struct dquot___63 *);
	int (*mark_dirty)(struct dquot___63 *);
	int (*write_info)(struct super_block___64 *, int);
	qsize_t * (*get_reserved_space)(struct inode___64 *);
	int (*get_projid)(struct inode___64 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___64 *, qsize_t *);
	int (*get_next_id)(struct super_block___64 *, struct kqid *);
};

struct quotactl_ops___63 {
	int (*quota_on)(struct super_block___64 *, int, int, const struct path___63 *);
	int (*quota_off)(struct super_block___64 *, int);
	int (*quota_enable)(struct super_block___64 *, unsigned int);
	int (*quota_disable)(struct super_block___64 *, unsigned int);
	int (*quota_sync)(struct super_block___64 *, int);
	int (*set_info)(struct super_block___64 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___64 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___64 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___64 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___64 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___64 *, unsigned int);
};

struct address_space_operations___63 {
	int (*writepage)(struct page___68 *, struct writeback_control___3 *);
	int (*readpage)(struct file___63 *, struct page___68 *);
	int (*writepages)(struct address_space___63 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___68 *);
	int (*readpages)(struct file___63 *, struct address_space___63 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___63 *, struct address_space___63 *, loff_t, unsigned int, unsigned int, struct page___68 **, void **);
	int (*write_end)(struct file___63 *, struct address_space___63 *, loff_t, unsigned int, unsigned int, struct page___68 *, void *);
	sector_t (*bmap)(struct address_space___63 *, sector_t);
	void (*invalidatepage)(struct page___68 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___68 *, gfp_t);
	void (*freepage)(struct page___68 *);
	ssize_t (*direct_IO)(struct kiocb___63 *, struct iov_iter___34 *);
	int (*migratepage)(struct address_space___63 *, struct page___68 *, struct page___68 *, enum migrate_mode);
	bool (*isolate_page)(struct page___68 *, isolate_mode_t);
	void (*putback_page)(struct page___68 *);
	int (*launder_page)(struct page___68 *);
	int (*is_partially_uptodate)(struct page___68 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___68 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___63 *, struct page___68 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___63 *, sector_t *);
	void (*swap_deactivate)(struct file___63 *);
};

struct bio_vec___34;

struct iov_iter___34 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___34 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___23 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___63 {
	struct dentry___64 * (*lookup)(struct inode___64 *, struct dentry___64 *, unsigned int);
	const char * (*get_link)(struct dentry___64 *, struct inode___64 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___64 *, int);
	struct posix_acl * (*get_acl)(struct inode___64 *, int, bool);
	int (*readlink)(struct dentry___64 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___64 *, struct dentry___64 *, umode_t, bool);
	int (*link)(struct dentry___64 *, struct inode___64 *, struct dentry___64 *);
	int (*unlink)(struct inode___64 *, struct dentry___64 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___64 *, struct dentry___64 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___64 *, struct dentry___64 *, umode_t);
	int (*rmdir)(struct inode___64 *, struct dentry___64 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___64 *, struct dentry___64 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___64 *, struct dentry___64 *, struct inode___64 *, struct dentry___64 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___64 *, struct iattr___64 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___63 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___64 *, char *, size_t);
	int (*fiemap)(struct inode___64 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___64 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___64 *, struct dentry___64 *, struct file___63 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___64 *, struct dentry___64 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___64 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___64 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___64 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___63 {
	void (*fl_copy_lock)(struct file_lock___63 *, struct file_lock___63 *);
	void (*fl_release_private)(struct file_lock___63 *);
};

struct lock_manager_operations___63;

struct file_lock___63 {
	struct file_lock___63 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___63 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___63 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___63 *fl_ops;
	const struct lock_manager_operations___63 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___63 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___63 *);
	int (*lm_grant)(struct file_lock___63 *, int);
	bool (*lm_break)(struct file_lock___63 *);
	int (*lm_change)(struct file_lock___63 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___63 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___63 *);
};

struct fasync_struct___63 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___63 *fa_next;
	struct file___63 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___63 {
	struct inode___64 * (*alloc_inode)(struct super_block___64 *);
	void (*destroy_inode)(struct inode___64 *);
	void (*free_inode)(struct inode___64 *);
	void (*dirty_inode)(struct inode___64 *, int);
	int (*write_inode)(struct inode___64 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___64 *);
	void (*evict_inode)(struct inode___64 *);
	void (*put_super)(struct super_block___64 *);
	int (*sync_fs)(struct super_block___64 *, int);
	int (*freeze_super)(struct super_block___64 *);
	int (*freeze_fs)(struct super_block___64 *);
	int (*thaw_super)(struct super_block___64 *);
	int (*unfreeze_fs)(struct super_block___64 *);
	int (*statfs)(struct dentry___64 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___64 *, int *, char *);
	void (*umount_begin)(struct super_block___64 *);
	int (*show_options)(struct seq_file___61 *, struct dentry___64 *);
	int (*show_devname)(struct seq_file___61 *, struct dentry___64 *);
	int (*show_path)(struct seq_file___61 *, struct dentry___64 *);
	int (*show_stats)(struct seq_file___61 *, struct dentry___64 *);
	ssize_t (*quota_read)(struct super_block___64 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___64 *, int, const char *, size_t, loff_t);
	struct dquot___63 ** (*get_dquots)(struct inode___64 *);
	long int (*nr_cached_objects)(struct super_block___64 *, struct shrink_control___25 *);
	long int (*free_cached_objects)(struct super_block___64 *, struct shrink_control___25 *);
	struct file___63 * (*real_loop)(struct file___63 *);
};

struct seq_operations___61;

struct seq_file___61 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___61 *op;
	int poll_event;
	const struct file___63 *file;
	void *private;
};

struct kernfs_root___63;

struct kernfs_elem_dir___63 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___63 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___63;

struct kernfs_root___63 {
	struct kernfs_node___63 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___63 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___63 {
	struct kernfs_node___63 *target_kn;
};

struct kernfs_ops___63;

struct kernfs_elem_attr___63 {
	const struct kernfs_ops___63 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___63 *notify_next;
};

struct kernfs_node___63 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___63 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___63 dir;
		struct kernfs_elem_symlink___63 symlink;
		struct kernfs_elem_attr___63 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___63;

struct kernfs_ops___63 {
	int (*open)(struct kernfs_open_file___63 *);
	void (*release)(struct kernfs_open_file___63 *);
	int (*seq_show)(struct seq_file___61 *, void *);
	void * (*seq_start)(struct seq_file___61 *, loff_t *);
	void * (*seq_next)(struct seq_file___61 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___61 *, void *);
	ssize_t (*read)(struct kernfs_open_file___63 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___63 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___63 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___63 *, struct vm_area_struct___68 *);
};

struct kernfs_syscall_ops___63 {
	int (*show_options)(struct seq_file___61 *, struct kernfs_root___63 *);
	int (*mkdir)(struct kernfs_node___63 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___63 *);
	int (*rename)(struct kernfs_node___63 *, struct kernfs_node___63 *, const char *);
	int (*show_path)(struct seq_file___61 *, struct kernfs_node___63 *, struct kernfs_root___63 *);
};

struct kernfs_open_file___63 {
	struct kernfs_node___63 *kn;
	struct file___63 *file;
	struct seq_file___61 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___62 *vm_ops;
};

struct bin_attribute___63;

struct attribute_group___63 {
	const char *name;
	umode_t (*is_visible)(struct kobject___63 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___63 *, struct bin_attribute___63 *, int);
	struct attribute **attrs;
	struct bin_attribute___63 **bin_attrs;
};

struct bin_attribute___63 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___63 * (*f_mapping)();
	ssize_t (*read)(struct file___63 *, struct kobject___63 *, struct bin_attribute___63 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___63 *, struct kobject___63 *, struct bin_attribute___63 *, char *, loff_t, size_t);
	int (*mmap)(struct file___63 *, struct kobject___63 *, struct bin_attribute___63 *, struct vm_area_struct___68 *);
};

struct sysfs_ops___63 {
	ssize_t (*show)(struct kobject___63 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___63 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___63;

struct kset___63 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___63 kobj;
	const struct kset_uevent_ops___63 *uevent_ops;
};

struct kobj_type___63 {
	void (*release)(struct kobject___63 *);
	const struct sysfs_ops___63 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___63 **default_groups;
	const struct kobj_ns_type_operations___7 * (*child_ns_type)(struct kobject___63 *);
	const void * (*namespace)(struct kobject___63 *);
	void (*get_ownership)(struct kobject___63 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___63 {
	int (* const filter)(struct kset___63 *, struct kobject___63 *);
	const char * (* const name)(struct kset___63 *, struct kobject___63 *);
	int (* const uevent)(struct kset___63 *, struct kobject___63 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___60 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___60 *);
	int (*get)(char *, const struct kernel_param___60 *);
	void (*free)(void *);
};

struct kparam_array___60;

struct kernel_param___60 {
	const char *name;
	struct module___62 *mod;
	const struct kernel_param_ops___60 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___60 *arr;
	};
};

struct kparam_array___60 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___60 *ops;
	void *elem;
};

struct module_attribute___60 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___60 *, struct module_kobject___60 *, char *);
	ssize_t (*store)(struct module_attribute___60 *, struct module_kobject___60 *, const char *, size_t);
	void (*setup)(struct module___62 *, const char *);
	int (*test)(struct module___62 *);
	void (*free)(struct module___62 *);
};

struct dev_pagemap_ops___62 {
	void (*page_free)(struct page___68 *);
	void (*kill)(struct dev_pagemap___62 *);
	void (*cleanup)(struct dev_pagemap___62 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___62 *);
};

struct bpf_iter_aux_info___12;

typedef int (*bpf_iter_init_seq_priv_t___12)(void *, struct bpf_iter_aux_info___12 *);

struct bpf_map___12;

struct bpf_iter_aux_info___12 {
	struct bpf_map___12 *map;
};

struct bpf_iter_seq_info___12 {
	const struct seq_operations___61 *seq_ops;
	bpf_iter_init_seq_priv_t___12 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___61 {
	void * (*start)(struct seq_file___61 *, loff_t *);
	void (*stop)(struct seq_file___61 *, void *);
	void * (*next)(struct seq_file___61 *, void *, loff_t *);
	int (*show)(struct seq_file___61 *, void *);
};

struct bpf_prog_aux___12;

struct bpf_prog___11;

struct bpf_local_storage_map___3;

struct bpf_map_ops___12 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___12 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___12 *, struct file___63 *);
	void (*map_free)(struct bpf_map___12 *);
	int (*map_get_next_key)(struct bpf_map___12 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___12 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___12 *, void *);
	int (*map_lookup_batch)(struct bpf_map___12 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___12 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___12 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___12 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___12 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___12 *, void *);
	int (*map_update_elem)(struct bpf_map___12 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___12 *, void *);
	int (*map_push_elem)(struct bpf_map___12 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___12 *, void *);
	int (*map_peek_elem)(struct bpf_map___12 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___12 *, struct file___63 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___12 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___12 *, void *, struct seq_file___61 *);
	int (*map_check_btf)(const struct bpf_map___12 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___12 *, struct bpf_prog_aux___12 *);
	void (*map_poke_untrack)(struct bpf_map___12 *, struct bpf_prog_aux___12 *);
	void (*map_poke_run)(struct bpf_map___12 *, u32, struct bpf_prog___11 *, struct bpf_prog___11 *);
	int (*map_direct_value_addr)(const struct bpf_map___12 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___12 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___12 *, struct vm_area_struct___68 *);
	__poll_t (*map_poll)(struct bpf_map___12 *, struct file___63 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___3 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___3 *, void *, u32);
	struct bpf_local_storage___3 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___12 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___12 *, const struct bpf_map___12 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___12 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___12 *iter_seq_info;
};

struct bpf_map___12 {
	const struct bpf_map_ops___12 *ops;
	struct bpf_map___12 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___12;

struct bpf_jit_poke_descriptor___12;

struct bpf_prog_ops___11;

struct btf_mod_pair___12;

struct bpf_prog_offload___11;

struct bpf_prog_aux___12 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___11 *dst_prog;
	struct bpf_trampoline___12 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___11 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___12 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___11 *ops;
	struct bpf_map___12 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___12 *used_btfs;
	struct bpf_prog___11 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___12 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___11 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___11 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___12 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_local_storage_map___3 {
	struct bpf_map___12 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___11;

struct bpf_map_dev_ops___11 {
	int (*map_get_next_key)(struct bpf_offloaded_map___11 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___11 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___11 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___11 *, void *);
};

struct net_device___16;

struct bpf_offloaded_map___11 {
	struct bpf_map___12 map;
	struct net_device___16 *netdev;
	const struct bpf_map_dev_ops___11 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___13;

typedef rx_handler_result_t rx_handler_func_t___11(struct sk_buff___13 **);

typedef struct {
	struct net___14 *net;
} possible_net_t___11;

struct wakeup_source___56;

struct dev_pm_info___56 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___56 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___56 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___56;

struct bus_type___56;

struct device_driver___56;

struct dev_pm_domain___56;

struct fwnode_handle___56;

struct class___56;

struct device___56 {
	struct kobject___63 kobj;
	struct device___56 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___56 *type;
	struct bus_type___56 *bus;
	struct device_driver___56 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___56 power;
	struct dev_pm_domain___56 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___56 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___56 *class;
	const struct attribute_group___63 **groups;
	void (*release)(struct device___56 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___11 {
	struct bpf_prog___11 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___11;

struct net_device_ops___11;

struct xfrmdev_ops___11;

struct header_ops___11;

struct netdev_rx_queue___11;

struct mini_Qdisc___11;

struct netdev_queue___11;

struct Qdisc___11;

struct rtnl_link_ops___11;

struct dcbnl_rtnl_ops___11;

struct net_device___16 {
	char name[16];
	struct netdev_name_node___11 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___11 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___11 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___11 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___63 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___11 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___11 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___11 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___11 *miniq_ingress;
	struct netdev_queue___11 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___11 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___11 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___11 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___11 = 0,
		NETREG_REGISTERED___11 = 1,
		NETREG_UNREGISTERING___11 = 2,
		NETREG_UNREGISTERED___11 = 3,
		NETREG_RELEASED___11 = 4,
		NETREG_DUMMY___11 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___11 = 0,
		RTNL_LINK_INITIALIZING___11 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___16 *);
	struct netpoll_info *npinfo;
	possible_net_t___11 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___56 dev;
	const struct attribute_group___63 *sysfs_groups[4];
	const struct attribute_group___63 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___11 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___11 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___11 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___6 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___11 *);
};

struct bpf_prog_ops___11 {
	int (*test_run)(struct bpf_prog___11 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___11 {
	struct bpf_prog___11 *prog;
	struct net_device___16 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___12 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___11 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___62 *mod;
};

struct bpf_jit_poke_descriptor___12 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___12 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___12 {
	struct btf *btf;
	struct module___62 *module;
};

struct bpf_prog_array_item___11 {
	struct bpf_prog___11 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___11 {
	struct callback_head rcu;
	struct bpf_prog_array_item___11 items[0];
};

struct sk_buff___13 {
	union {
		struct {
			struct sk_buff___13 *next;
			struct sk_buff___13 *prev;
			union {
				struct net_device___16 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___9 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___13 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bpf_local_storage_data___3 {
	struct bpf_local_storage_map___3 *smap;
	u8 data[0];
};

struct bpf_local_storage_elem___2 {
	struct hlist_node map_node;
	struct hlist_node snode;
	struct bpf_local_storage___3 *local_storage;
	struct callback_head rcu;
	long: 64;
	struct bpf_local_storage_data___3 sdata;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___34 {
	struct page___68 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fwnode_operations___56;

struct fwnode_handle___56 {
	struct fwnode_handle___56 *secondary;
	const struct fwnode_operations___56 *ops;
	struct device___56 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___56;

struct fwnode_endpoint___56;

struct fwnode_operations___56 {
	struct fwnode_handle___56 * (*get)(struct fwnode_handle___56 *);
	void (*put)(struct fwnode_handle___56 *);
	bool (*device_is_available)(const struct fwnode_handle___56 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___56 *, const struct device___56 *);
	bool (*property_present)(const struct fwnode_handle___56 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___56 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___56 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___56 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*get_parent)(const struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*get_next_child_node)(const struct fwnode_handle___56 *, struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*get_named_child_node)(const struct fwnode_handle___56 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___56 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___56 *);
	struct fwnode_handle___56 * (*graph_get_next_endpoint)(const struct fwnode_handle___56 *, struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*graph_get_remote_endpoint)(const struct fwnode_handle___56 *);
	struct fwnode_handle___56 * (*graph_get_port_parent)(struct fwnode_handle___56 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___56 *, struct fwnode_endpoint___56 *);
	int (*add_links)(struct fwnode_handle___56 *);
};

struct fwnode_endpoint___56 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___56 *local_fwnode;
};

struct fwnode_reference_args___56 {
	struct fwnode_handle___56 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fqdir___13;

struct netns_ipv4___13 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___13 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___13 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___13 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___16 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___13 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___13 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___13 *);
	int (*local_out)(struct net___14 *, struct sock *, struct sk_buff___13 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___13 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___13 {
	struct dst_ops___13 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___13 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___13 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___13 *fqdir;
};

struct sk_buff_head___11 {
	struct sk_buff___13 *next;
	struct sk_buff___13 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___11 {
	struct bpf_prog_array___11 *run_array[2];
	struct bpf_prog___11 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___13 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___13 xfrm4_dst_ops;
	struct dst_ops___13 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___14 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___16 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___13 ipv4;
	struct netns_ipv6___13 ipv6;
	struct netns_ieee802154_lowpan___13 ieee802154_lowpan;
	struct netns_sctp___7 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___11 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___11 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___13 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___52 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___52 *root_cset;
};

struct dev_pm_ops___56 {
	int (*prepare)(struct device___56 *);
	void (*complete)(struct device___56 *);
	int (*suspend)(struct device___56 *);
	int (*resume)(struct device___56 *);
	int (*freeze)(struct device___56 *);
	int (*thaw)(struct device___56 *);
	int (*poweroff)(struct device___56 *);
	int (*restore)(struct device___56 *);
	int (*suspend_late)(struct device___56 *);
	int (*resume_early)(struct device___56 *);
	int (*freeze_late)(struct device___56 *);
	int (*thaw_early)(struct device___56 *);
	int (*poweroff_late)(struct device___56 *);
	int (*restore_early)(struct device___56 *);
	int (*suspend_noirq)(struct device___56 *);
	int (*resume_noirq)(struct device___56 *);
	int (*freeze_noirq)(struct device___56 *);
	int (*thaw_noirq)(struct device___56 *);
	int (*poweroff_noirq)(struct device___56 *);
	int (*restore_noirq)(struct device___56 *);
	int (*runtime_suspend)(struct device___56 *);
	int (*runtime_resume)(struct device___56 *);
	int (*runtime_idle)(struct device___56 *);
};

struct wakeup_source___56 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___56 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___56 {
	struct dev_pm_ops___56 ops;
	int (*start)(struct device___56 *);
	void (*detach)(struct device___56 *, bool);
	int (*activate)(struct device___56 *);
	void (*sync)(struct device___56 *);
	void (*dismiss)(struct device___56 *);
};

struct bus_type___56 {
	const char *name;
	const char *dev_name;
	struct device___56 *dev_root;
	const struct attribute_group___63 **bus_groups;
	const struct attribute_group___63 **dev_groups;
	const struct attribute_group___63 **drv_groups;
	int (*match)(struct device___56 *, struct device_driver___56 *);
	int (*uevent)(struct device___56 *, struct kobj_uevent_env *);
	int (*probe)(struct device___56 *);
	void (*sync_state)(struct device___56 *);
	void (*remove)(struct device___56 *);
	void (*shutdown)(struct device___56 *);
	int (*online)(struct device___56 *);
	int (*offline)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	int (*num_vf)(struct device___56 *);
	int (*dma_configure)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___56 {
	const char *name;
	struct bus_type___56 *bus;
	struct module___62 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___56 *);
	void (*sync_state)(struct device___56 *);
	int (*remove)(struct device___56 *);
	void (*shutdown)(struct device___56 *);
	int (*suspend)(struct device___56 *, pm_message_t);
	int (*resume)(struct device___56 *);
	const struct attribute_group___63 **groups;
	const struct attribute_group___63 **dev_groups;
	const struct dev_pm_ops___56 *pm;
	void (*coredump)(struct device___56 *);
	struct driver_private *p;
};

struct device_type___56 {
	const char *name;
	const struct attribute_group___63 **groups;
	int (*uevent)(struct device___56 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___56 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___56 *);
	const struct dev_pm_ops___56 *pm;
};

struct class___56 {
	const char *name;
	struct module___62 *owner;
	const struct attribute_group___63 **class_groups;
	const struct attribute_group___63 **dev_groups;
	struct kobject___63 *dev_kobj;
	int (*dev_uevent)(struct device___56 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___56 *, umode_t *);
	void (*class_release)(struct class___56 *);
	void (*dev_release)(struct device___56 *);
	int (*shutdown_pre)(struct device___56 *);
	const struct kobj_ns_type_operations___7 *ns_type;
	const void * (*namespace)(struct device___56 *);
	void (*get_ownership)(struct device___56 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___56 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___23;

struct pipe_buffer___23 {
	struct page___68 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___23 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___23 {
	int (*confirm)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
	void (*release)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
	bool (*try_steal)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
	bool (*get)(struct pipe_inode_info___23 *, struct pipe_buffer___23 *);
};

struct inet_frags___13;

struct fqdir___13 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___13 *f;
	struct net___14 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___13;

struct inet_frags___13 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___13 *, const void *);
	void (*destructor)(struct inet_frag_queue___13 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___13 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___13 *fragments_tail;
	struct sk_buff___13 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___13 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___11 {
	int (*ieee_getets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___16 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___16 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___16 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___16 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___16 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___16 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___16 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___16 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___16 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___16 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___16 *);
	u8 (*setstate)(struct net_device___16 *, u8);
	void (*getpermhwaddr)(struct net_device___16 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___16 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___16 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___16 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___16 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___16 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___16 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___16 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___16 *, int, u8 *);
	void (*setpfccfg)(struct net_device___16 *, int, u8);
	void (*getpfccfg)(struct net_device___16 *, int, u8 *);
	u8 (*setall)(struct net_device___16 *);
	u8 (*getcap)(struct net_device___16 *, int, u8 *);
	int (*getnumtcs)(struct net_device___16 *, int, u8 *);
	int (*setnumtcs)(struct net_device___16 *, int, u8);
	u8 (*getpfcstate)(struct net_device___16 *);
	void (*setpfcstate)(struct net_device___16 *, u8);
	void (*getbcncfg)(struct net_device___16 *, int, u32 *);
	void (*setbcncfg)(struct net_device___16 *, int, u32);
	void (*getbcnrp)(struct net_device___16 *, int, u8 *);
	void (*setbcnrp)(struct net_device___16 *, int, u8);
	int (*setapp)(struct net_device___16 *, u8, u16, u8);
	int (*getapp)(struct net_device___16 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___16 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___16 *, int, u8);
	u8 (*getdcbx)(struct net_device___16 *);
	u8 (*setdcbx)(struct net_device___16 *, u8);
	int (*peer_getappinfo)(struct net_device___16 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___16 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___16 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___16 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___16 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___16 *, struct dcbnl_buffer *);
};

struct cftype___52;

struct cgroup_subsys___52 {
	struct cgroup_subsys_state___52 * (*css_alloc)(struct cgroup_subsys_state___52 *);
	int (*css_online)(struct cgroup_subsys_state___52 *);
	void (*css_offline)(struct cgroup_subsys_state___52 *);
	void (*css_released)(struct cgroup_subsys_state___52 *);
	void (*css_free)(struct cgroup_subsys_state___52 *);
	void (*css_reset)(struct cgroup_subsys_state___52 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___52 *, int);
	int (*css_extra_stat_show)(struct seq_file___61 *, struct cgroup_subsys_state___52 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___70 *, struct css_set___52 *);
	void (*cancel_fork)(struct task_struct___70 *, struct css_set___52 *);
	void (*fork)(struct task_struct___70 *);
	void (*exit)(struct task_struct___70 *);
	void (*release)(struct task_struct___70 *);
	void (*bind)(struct cgroup_subsys_state___52 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___52 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___52 *dfl_cftypes;
	struct cftype___52 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___52 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___52 *updated_children;
	struct cgroup___52 *updated_next;
};

struct cgroup_root___52 {
	struct kernfs_root___63 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___52 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___52 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___52 *ss;
	struct list_head node;
	struct kernfs_ops___63 *kf_ops;
	int (*open)(struct kernfs_open_file___63 *);
	void (*release)(struct kernfs_open_file___63 *);
	u64 (*read_u64)(struct cgroup_subsys_state___52 *, struct cftype___52 *);
	s64 (*read_s64)(struct cgroup_subsys_state___52 *, struct cftype___52 *);
	int (*seq_show)(struct seq_file___61 *, void *);
	void * (*seq_start)(struct seq_file___61 *, loff_t *);
	void * (*seq_next)(struct seq_file___61 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___61 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___52 *, struct cftype___52 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___52 *, struct cftype___52 *, s64);
	ssize_t (*write)(struct kernfs_open_file___63 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___63 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___11 {
	struct net_device___16 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___11 {
	struct net_device___16 *dev;
};

struct xdp_buff___11 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___11 *rxq;
	struct xdp_txq_info___11 *txq;
	u32 frame_sz;
};

struct xdp_frame___11 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___16 *dev_rx;
};

struct netlink_callback___11 {
	struct sk_buff___13 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___13 *, struct netlink_callback___11 *);
	int (*done)(struct netlink_callback___11 *);
	void *data;
	struct module___62 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___11 {
	int (*create)(struct sk_buff___13 *, struct net_device___16 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___13 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___16 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___13 *);
};

struct netdev_queue___11 {
	struct net_device___16 *dev;
	struct Qdisc___11 *qdisc;
	struct Qdisc___11 *qdisc_sleeping;
	struct kobject___63 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___16 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___11 {
	struct sk_buff___13 *head;
	struct sk_buff___13 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___11;

struct Qdisc___11 {
	int (*enqueue)(struct sk_buff___13 *, struct Qdisc___11 *, struct sk_buff___13 **);
	struct sk_buff___13 * (*dequeue)(struct Qdisc___11 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___11 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___11 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___11 gso_skb;
	struct qdisc_skb_head___11 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___11 *next_sched;
	struct sk_buff_head___11 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___11 {
	struct xdp_rxq_info___11 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___63 kobj;
	struct net_device___16 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___11 {
	enum net_device_path_type type;
	const struct net_device___16 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___11 = 0,
				DEV_PATH_BR_VLAN_TAG___11 = 1,
				DEV_PATH_BR_VLAN_UNTAG___11 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___11 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___11 {
	const struct net_device___16 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___11 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___11 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___11 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___11 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___13 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___11 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___16 *dev;
	const char *name;
};

struct net_device_ops___11 {
	int (*ndo_init)(struct net_device___16 *);
	void (*ndo_uninit)(struct net_device___16 *);
	int (*ndo_open)(struct net_device___16 *);
	int (*ndo_stop)(struct net_device___16 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___13 *, struct net_device___16 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___13 *, struct net_device___16 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___16 *, struct sk_buff___13 *, struct net_device___16 *);
	void (*ndo_change_rx_flags)(struct net_device___16 *, int);
	void (*ndo_set_rx_mode)(struct net_device___16 *);
	int (*ndo_set_mac_address)(struct net_device___16 *, void *);
	int (*ndo_validate_addr)(struct net_device___16 *);
	int (*ndo_do_ioctl)(struct net_device___16 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___16 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___16 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___16 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___16 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___16 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___16 *, int);
	int (*ndo_neigh_setup)(struct net_device___16 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___16 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___16 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___16 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___16 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___16 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___16 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___16 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___16 *);
	int (*ndo_netpoll_setup)(struct net_device___16 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___16 *);
	int (*ndo_set_vf_mac)(struct net_device___16 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___16 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___16 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___16 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___16 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___16 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___16 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___16 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___16 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___16 *, int, struct sk_buff___13 *);
	int (*ndo_get_vf_guid)(struct net_device___16 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___16 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___16 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___16 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___16 *);
	int (*ndo_fcoe_disable)(struct net_device___16 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___16 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___16 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___16 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___16 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___16 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___16 *, const struct sk_buff___13 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___16 *, struct net_device___16 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___16 *, struct net_device___16 *);
	struct net_device___16 * (*ndo_get_xmit_slave)(struct net_device___16 *, struct sk_buff___13 *, bool);
	struct net_device___16 * (*ndo_sk_get_lower_dev)(struct net_device___16 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___16 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___16 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___16 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___16 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___13 *, struct netlink_callback___11 *, struct net_device___16 *, struct net_device___16 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___13 *, struct nlattr **, struct net_device___16 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___16 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___13 *, u32, u32, struct net_device___16 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___16 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___16 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___16 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___16 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___16 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___16 *, struct net_device___16 *);
	void (*ndo_dfwd_del_station)(struct net_device___16 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___16 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___16 *);
	int (*ndo_change_proto_down)(struct net_device___16 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___16 *, struct sk_buff___13 *);
	void (*ndo_set_rx_headroom)(struct net_device___16 *, int);
	int (*ndo_bpf)(struct net_device___16 *, struct netdev_bpf___11 *);
	int (*ndo_xdp_xmit)(struct net_device___16 *, int, struct xdp_frame___11 **, u32);
	struct net_device___16 * (*ndo_xdp_get_xmit_slave)(struct net_device___16 *, struct xdp_buff___11 *);
	int (*ndo_xsk_wakeup)(struct net_device___16 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___16 *);
	int (*ndo_tunnel_ctl)(struct net_device___16 *, struct ip_tunnel_parm *, int);
	struct net_device___16 * (*ndo_get_peer_dev)(struct net_device___16 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___11 *, struct net_device_path___11 *);
};

struct tcf_proto___11;

struct tcf_block___11;

struct mini_Qdisc___11 {
	struct tcf_proto___11 *filter_list;
	struct tcf_block___11 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___11 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___16 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___16 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___14 *, struct net_device___16 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___16 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___16 *, struct list_head *);
	size_t (*get_size)(const struct net_device___16 *);
	int (*fill_info)(struct sk_buff___13 *, const struct net_device___16 *);
	size_t (*get_xstats_size)(const struct net_device___16 *);
	int (*fill_xstats)(struct sk_buff___13 *, const struct net_device___16 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___16 *, struct net_device___16 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___16 *, const struct net_device___16 *);
	int (*fill_slave_info)(struct sk_buff___13 *, const struct net_device___16 *, const struct net_device___16 *);
	struct net___14 * (*get_link_net)(const struct net_device___16 *);
	size_t (*get_linkxstats_size)(const struct net_device___16 *, int);
	int (*fill_linkxstats)(struct sk_buff___13 *, const struct net_device___16 *, int *, int);
};

struct gnet_dump___11 {
	spinlock_t *lock;
	struct sk_buff___13 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___11;

struct Qdisc_ops___11 {
	struct Qdisc_ops___11 *next;
	const struct Qdisc_class_ops___11 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___13 *, struct Qdisc___11 *, struct sk_buff___13 **);
	struct sk_buff___13 * (*dequeue)(struct Qdisc___11 *);
	struct sk_buff___13 * (*peek)(struct Qdisc___11 *);
	int (*init)(struct Qdisc___11 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___11 *);
	void (*destroy)(struct Qdisc___11 *);
	int (*change)(struct Qdisc___11 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___11 *);
	int (*change_tx_queue_len)(struct Qdisc___11 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___11 *, unsigned int);
	int (*dump)(struct Qdisc___11 *, struct sk_buff___13 *);
	int (*dump_stats)(struct Qdisc___11 *, struct gnet_dump___11 *);
	void (*ingress_block_set)(struct Qdisc___11 *, u32);
	void (*egress_block_set)(struct Qdisc___11 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___11 *);
	u32 (*egress_block_get)(struct Qdisc___11 *);
	struct module___62 *owner;
};

struct Qdisc_class_ops___11 {
	unsigned int flags;
	struct netdev_queue___11 * (*select_queue)(struct Qdisc___11 *, struct tcmsg *);
	int (*graft)(struct Qdisc___11 *, long unsigned int, struct Qdisc___11 *, struct Qdisc___11 **, struct netlink_ext_ack *);
	struct Qdisc___11 * (*leaf)(struct Qdisc___11 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___11 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___11 *, u32);
	int (*change)(struct Qdisc___11 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___11 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___11 *, struct qdisc_walker *);
	struct tcf_block___11 * (*tcf_block)(struct Qdisc___11 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___11 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___11 *, long unsigned int);
	int (*dump)(struct Qdisc___11 *, long unsigned int, struct sk_buff___13 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___11 *, long unsigned int, struct gnet_dump___11 *);
};

struct tcf_chain___11;

struct tcf_block___11 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___14 *net;
	struct Qdisc___11 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___11 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___11;

struct tcf_proto_ops___11;

struct tcf_proto___11 {
	struct tcf_proto___11 *next;
	void *root;
	int (*classify)(struct sk_buff___13 *, const struct tcf_proto___11 *, struct tcf_result___11 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___11 *ops;
	struct tcf_chain___11 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___11 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___11 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___11 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___13 *, const struct tcf_proto___11 *, struct tcf_result___11 *);
	int (*init)(struct tcf_proto___11 *);
	void (*destroy)(struct tcf_proto___11 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___11 *, u32);
	void (*put)(struct tcf_proto___11 *, void *);
	int (*change)(struct net___14 *, struct sk_buff___13 *, struct tcf_proto___11 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___11 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___11 *);
	void (*walk)(struct tcf_proto___11 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___11 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___11 *, void *);
	void (*hw_del)(struct tcf_proto___11 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___14 *, struct tcf_chain___11 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___14 *, struct tcf_proto___11 *, void *, struct sk_buff___13 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___14 *, struct tcf_proto___11 *, void *, struct sk_buff___13 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___13 *, struct net___14 *, void *);
	struct module___62 *owner;
	int flags;
};

struct tcf_chain___11 {
	struct mutex filter_chain_lock;
	struct tcf_proto___11 *filter_chain;
	struct list_head list;
	struct tcf_block___11 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___11 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

typedef u64 (*btf_bpf_task_storage_get)(struct bpf_map___12 *, struct task_struct___70 *, void *, u64);

typedef u64 (*btf_bpf_task_storage_delete)(struct bpf_map___12 *, struct task_struct___70 *);

struct dentry___65;

struct super_block___65;

struct module___63;

struct file_system_type___64 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___65 * (*mount)(struct file_system_type___64 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___65 *);
	struct module___63 *owner;
	struct file_system_type___64 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___64;

struct kiocb___64;

struct iov_iter___35;

struct poll_table_struct___48;

struct vm_area_struct___69;

struct inode___65;

struct file_lock___64;

struct page___69;

struct pipe_inode_info___24;

struct seq_file___62;

struct file_operations___64 {
	struct module___63 *owner;
	loff_t (*llseek)(struct file___64 *, loff_t, int);
	ssize_t (*read)(struct file___64 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___64 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___64 *, struct iov_iter___35 *);
	ssize_t (*write_iter)(struct kiocb___64 *, struct iov_iter___35 *);
	int (*iopoll)(struct kiocb___64 *, bool);
	int (*iterate)(struct file___64 *, struct dir_context *);
	int (*iterate_shared)(struct file___64 *, struct dir_context *);
	__poll_t (*poll)(struct file___64 *, struct poll_table_struct___48 *);
	long int (*unlocked_ioctl)(struct file___64 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___64 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___64 *, struct vm_area_struct___69 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___65 *, struct file___64 *);
	int (*flush)(struct file___64 *, fl_owner_t);
	int (*release)(struct inode___65 *, struct file___64 *);
	int (*fsync)(struct file___64 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___64 *, int);
	int (*lock)(struct file___64 *, int, struct file_lock___64 *);
	ssize_t (*sendpage)(struct file___64 *, struct page___69 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___64 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___64 *, long unsigned int);
	int (*flock)(struct file___64 *, int, struct file_lock___64 *);
	ssize_t (*splice_write)(struct pipe_inode_info___24 *, struct file___64 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___64 *, loff_t *, struct pipe_inode_info___24 *, size_t, unsigned int);
	int (*setlease)(struct file___64 *, long int, struct file_lock___64 **, void **);
	long int (*fallocate)(struct file___64 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___62 *, struct file___64 *);
	ssize_t (*copy_file_range)(struct file___64 *, loff_t, struct file___64 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___64 *, loff_t, struct file___64 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___64 *, loff_t, loff_t, int);
};

struct vmacache___69 {
	u64 seqnum;
	struct vm_area_struct___69 *vmas[4];
};

struct page_frag___69 {
	struct page___69 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___70;

struct pid___57;

struct files_struct___6;

struct nsproxy___62;

struct signal_struct___65;

struct bio_list___29;

struct backing_dev_info___28;

struct io_context___29;

struct css_set___53;

struct mem_cgroup___26;

struct request_queue___30;

struct vm_struct___65;

struct bpf_local_storage___4;

struct task_struct___71 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___71 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___70 *mm;
	struct mm_struct___70 *active_mm;
	struct vmacache___69 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___71 *real_parent;
	struct task_struct___71 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___71 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___57 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___6 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___62 *nsproxy;
	struct signal_struct___65 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___71 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___29 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___28 *backing_dev_info;
	struct io_context___29 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___53 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___24 *splice_pipe;
	struct page_frag___69 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___26 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___26 *active_memcg;
	struct request_queue___30 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___71 *oom_reaper_list;
	struct vm_struct___65 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___4 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___42 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___64;

struct kobj_type___64;

struct kernfs_node___64;

struct kobject___64 {
	const char *name;
	struct list_head entry;
	struct kobject___64 *parent;
	struct kset___64 *kset;
	struct kobj_type___64 *ktype;
	struct kernfs_node___64 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___61 {
	struct kobject___64 kobj;
	struct module___63 *mod;
	struct kobject___64 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___61 {
	struct module___63 *mod;
	struct latch_tree_node node;
};

struct module_layout___61 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___61 mtn;
};

struct module_attribute___61;

struct kernel_param___61;

struct module___63 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___61 mkobj;
	struct module_attribute___61 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___64 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___61 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___61 core_layout;
	struct module_layout___61 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___64;

struct path___64 {
	struct vfsmount___64 *mnt;
	struct dentry___65 *dentry;
};

struct fown_struct___57 {
	rwlock_t lock;
	struct pid___57 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___64;

struct file___64 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___64 f_path;
	struct inode___65 *f_inode;
	const struct file_operations___64 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___57 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___64 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___69 *pgtable_t___69;

struct page_pool___21;

struct dev_pagemap___63;

struct page___69 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___64 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___21 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___69 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___69 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___70 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___63 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___63;

struct vm_area_struct___69 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___69 *vm_next;
	struct vm_area_struct___69 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___70 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___63 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___64 *vm_file;
	struct file___64 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___69;

struct mm_struct___70 {
	struct {
		struct vm_area_struct___69 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___64 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___69 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___71 *owner;
		struct user_namespace___10 *user_ns;
		struct file___64 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___64;

struct address_space___64 {
	struct inode___65 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___64 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___57;

struct page_pool_params___21 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___57 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___21 {
	u32 count;
	struct page___69 *cache[128];
};

struct page_pool___21 {
	struct page_pool_params___21 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___69 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___21 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___63;

struct dev_pagemap___63 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___63 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___63;

struct vm_operations_struct___63 {
	void (*open)(struct vm_area_struct___69 *);
	void (*close)(struct vm_area_struct___69 *);
	int (*may_split)(struct vm_area_struct___69 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___69 *);
	int (*mprotect)(struct vm_area_struct___69 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___63 *);
	vm_fault_t (*huge_fault)(struct vm_fault___63 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___63 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___69 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___63 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___63 *);
	int (*access)(struct vm_area_struct___69 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___69 *);
	int (*set_policy)(struct vm_area_struct___69 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___69 *, long unsigned int);
	struct page___69 * (*find_special_page)(struct vm_area_struct___69 *, long unsigned int);
};

struct core_thread___69 {
	struct task_struct___71 *task;
	struct core_thread___69 *next;
};

struct core_state___69 {
	atomic_t nr_threads;
	struct core_thread___69 dumper;
	struct completion startup;
};

struct vm_fault___63 {
	const struct {
		struct vm_area_struct___69 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___69 *cow_page;
	struct page___69 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___69 prealloc_pte;
};

struct pid_namespace___57;

struct upid___57 {
	int nr;
	struct pid_namespace___57 *ns;
};

struct pid_namespace___57 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___71 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___57 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___57 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___57 numbers[1];
};

struct signal_struct___65 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___71 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___71 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___57 *pids[4];
	struct pid___57 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___70 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fdtable___6 {
	unsigned int max_fds;
	struct file___64 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___6 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___6 *fdt;
	struct fdtable___6 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___64 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___15;

struct cgroup_namespace___53;

struct nsproxy___62 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___57 *pid_ns_for_children;
	struct net___15 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___53 *cgroup_ns;
};

struct bio___29;

struct bio_list___29 {
	struct bio___29 *head;
	struct bio___29 *tail;
};

struct cgroup_subsys_state___53;

struct bdi_writeback___28 {
	struct backing_dev_info___28 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___53 *memcg_css;
	struct cgroup_subsys_state___53 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___28 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___28 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___57 *dev;
	char dev_name[64];
	struct device___57 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___65 *debug_dir;
};

struct io_cq___29;

struct io_context___29 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___29 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___53;

struct css_set___53 {
	struct cgroup_subsys_state___53 *subsys[14];
	refcount_t refcount;
	struct css_set___53 *dom_cset;
	struct cgroup___53 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___53 *mg_src_cgrp;
	struct cgroup___53 *mg_dst_cgrp;
	struct css_set___53 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___64;

struct pipe_buffer___24;

struct pipe_inode_info___24 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___69 *tmp_page;
	struct fasync_struct___64 *fasync_readers;
	struct fasync_struct___64 *fasync_writers;
	struct pipe_buffer___24 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___53;

struct cgroup_subsys_state___53 {
	struct cgroup___53 *cgroup;
	struct cgroup_subsys___53 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___53 *parent;
};

struct cgroup_file___53 {
	struct kernfs_node___64 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___26;

struct mem_cgroup_per_node___26;

struct mem_cgroup___26 {
	struct cgroup_subsys_state___53 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___53 events_file;
	struct cgroup_file___53 events_local_file;
	struct cgroup_file___53 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___26 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___71 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___26 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___29;

struct blk_integrity___29 {
	const struct blk_integrity_profile___29 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___29 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___29 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___29;

struct elevator_queue___29;

struct blk_mq_ops___28;

struct blk_mq_hw_ctx___28;

struct gendisk___29;

struct blkcg_gq___28;

struct blk_mq_tag_set___28;

struct request_queue___30 {
	struct request___29 *last_merge;
	struct elevator_queue___29 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___28 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___28 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___29 *disk;
	struct kobject___64 kobj;
	struct kobject___64 *mq_kobj;
	struct blk_integrity___29 integrity;
	struct device___57 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___28 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___28 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___29 bio_split;
	struct dentry___65 *debugfs_dir;
	struct dentry___65 *sched_debugfs_dir;
	struct dentry___65 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___65 {
	struct vm_struct___65 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___69 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___4;

struct bpf_local_storage___4 {
	struct bpf_local_storage_data___4 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct pglist_data___27;

struct lruvec___27 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___27 *pgdat;
};

struct zone___27 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___27 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___27 {
	struct zone___27 *zone;
	int zone_idx;
};

struct zonelist___27 {
	struct zoneref___27 _zonerefs[321];
};

struct pglist_data___27 {
	struct zone___27 node_zones[5];
	struct zonelist___27 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___71 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___71 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___27 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___64;

struct dentry___65 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___65 *d_parent;
	struct qstr d_name;
	struct inode___65 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___64 *d_op;
	struct super_block___65 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___64;

struct inode___65 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___64 *i_op;
	struct super_block___65 *i_sb;
	struct address_space___64 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___28 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___64 *i_fop;
		void (*free_inode)(struct inode___65 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___64 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___24 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___64 {
	int (*d_revalidate)(struct dentry___65 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___65 *, unsigned int);
	int (*d_hash)(const struct dentry___65 *, struct qstr *);
	int (*d_compare)(const struct dentry___65 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___65 *);
	int (*d_init)(struct dentry___65 *);
	void (*d_release)(struct dentry___65 *);
	void (*d_prune)(struct dentry___65 *);
	void (*d_iput)(struct dentry___65 *, struct inode___65 *);
	char * (*d_dname)(struct dentry___65 *, char *, int);
	struct vfsmount___64 * (*d_automount)(struct path___64 *);
	int (*d_manage)(const struct path___64 *, bool);
	struct dentry___65 * (*d_real)(struct dentry___65 *, const struct inode___65 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___64;

struct mem_dqinfo___64 {
	struct quota_format_type___64 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___64;

struct quota_info___64 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___65 *files[3];
	struct mem_dqinfo___64 info[3];
	const struct quota_format_ops___64 *ops[3];
};

struct rcuwait___65 {
	struct task_struct___71 *task;
};

struct percpu_rw_semaphore___65 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___65 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___64 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___65 rw_sem[3];
};

struct shrink_control___26;

struct shrinker___26 {
	long unsigned int (*count_objects)(struct shrinker___26 *, struct shrink_control___26 *);
	long unsigned int (*scan_objects)(struct shrinker___26 *, struct shrink_control___26 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___64;

struct dquot_operations___64;

struct quotactl_ops___64;

struct block_device___30;

struct super_block___65 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___64 *s_type;
	const struct super_operations___64 *s_op;
	const struct dquot_operations___64 *dq_op;
	const struct quotactl_ops___64 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___65 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___30 *s_bdev;
	struct backing_dev_info___28 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___64 s_dquot;
	struct sb_writers___64 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___64 *s_d_op;
	int cleancache_poolid;
	struct shrinker___26 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___64 {
	struct dentry___65 *mnt_root;
	struct super_block___65 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct shrink_control___26 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___26 *memcg;
};

struct psi_group___53 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___71 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___12;

struct cgroup_bpf___12 {
	struct bpf_prog_array___12 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___12 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___53;

struct cgroup_rstat_cpu___53;

struct cgroup___53 {
	struct cgroup_subsys_state___53 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___64 *kn;
	struct cgroup_file___53 procs_file;
	struct cgroup_file___53 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___53 *subsys[14];
	struct cgroup_root___53 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___53 *dom_cgrp;
	struct cgroup___53 *old_dom_cgrp;
	struct cgroup_rstat_cpu___53 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___53 psi;
	struct cgroup_bpf___12 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___29 {
	struct request_queue___30 *q;
	struct io_context___29 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___64 {
	struct file___64 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___64 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___65 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___64 *ia_file;
};

struct dquot___64 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___65 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___64 {
	int qf_fmt_id;
	const struct quota_format_ops___64 *qf_ops;
	struct module___63 *qf_owner;
	struct quota_format_type___64 *qf_next;
};

struct quota_format_ops___64 {
	int (*check_quota_file)(struct super_block___65 *, int);
	int (*read_file_info)(struct super_block___65 *, int);
	int (*write_file_info)(struct super_block___65 *, int);
	int (*free_file_info)(struct super_block___65 *, int);
	int (*read_dqblk)(struct dquot___64 *);
	int (*commit_dqblk)(struct dquot___64 *);
	int (*release_dqblk)(struct dquot___64 *);
	int (*get_next_id)(struct super_block___65 *, struct kqid *);
};

struct dquot_operations___64 {
	int (*write_dquot)(struct dquot___64 *);
	struct dquot___64 * (*alloc_dquot)(struct super_block___65 *, int);
	void (*destroy_dquot)(struct dquot___64 *);
	int (*acquire_dquot)(struct dquot___64 *);
	int (*release_dquot)(struct dquot___64 *);
	int (*mark_dirty)(struct dquot___64 *);
	int (*write_info)(struct super_block___65 *, int);
	qsize_t * (*get_reserved_space)(struct inode___65 *);
	int (*get_projid)(struct inode___65 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___65 *, qsize_t *);
	int (*get_next_id)(struct super_block___65 *, struct kqid *);
};

struct quotactl_ops___64 {
	int (*quota_on)(struct super_block___65 *, int, int, const struct path___64 *);
	int (*quota_off)(struct super_block___65 *, int);
	int (*quota_enable)(struct super_block___65 *, unsigned int);
	int (*quota_disable)(struct super_block___65 *, unsigned int);
	int (*quota_sync)(struct super_block___65 *, int);
	int (*set_info)(struct super_block___65 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___65 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___65 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___65 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___65 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___65 *, unsigned int);
};

struct writeback_control___28;

struct address_space_operations___64 {
	int (*writepage)(struct page___69 *, struct writeback_control___28 *);
	int (*readpage)(struct file___64 *, struct page___69 *);
	int (*writepages)(struct address_space___64 *, struct writeback_control___28 *);
	int (*set_page_dirty)(struct page___69 *);
	int (*readpages)(struct file___64 *, struct address_space___64 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___64 *, struct address_space___64 *, loff_t, unsigned int, unsigned int, struct page___69 **, void **);
	int (*write_end)(struct file___64 *, struct address_space___64 *, loff_t, unsigned int, unsigned int, struct page___69 *, void *);
	sector_t (*bmap)(struct address_space___64 *, sector_t);
	void (*invalidatepage)(struct page___69 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___69 *, gfp_t);
	void (*freepage)(struct page___69 *);
	ssize_t (*direct_IO)(struct kiocb___64 *, struct iov_iter___35 *);
	int (*migratepage)(struct address_space___64 *, struct page___69 *, struct page___69 *, enum migrate_mode);
	bool (*isolate_page)(struct page___69 *, isolate_mode_t);
	void (*putback_page)(struct page___69 *);
	int (*launder_page)(struct page___69 *);
	int (*is_partially_uptodate)(struct page___69 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___69 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___64 *, struct page___69 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___64 *, sector_t *);
	void (*swap_deactivate)(struct file___64 *);
};

struct writeback_control___28 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___28 *wb;
	struct inode___65 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___35;

struct iov_iter___35 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___35 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___24 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___64 {
	struct dentry___65 * (*lookup)(struct inode___65 *, struct dentry___65 *, unsigned int);
	const char * (*get_link)(struct dentry___65 *, struct inode___65 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___65 *, int);
	struct posix_acl * (*get_acl)(struct inode___65 *, int, bool);
	int (*readlink)(struct dentry___65 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___65 *, struct dentry___65 *, umode_t, bool);
	int (*link)(struct dentry___65 *, struct inode___65 *, struct dentry___65 *);
	int (*unlink)(struct inode___65 *, struct dentry___65 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___65 *, struct dentry___65 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___65 *, struct dentry___65 *, umode_t);
	int (*rmdir)(struct inode___65 *, struct dentry___65 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___65 *, struct dentry___65 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___65 *, struct dentry___65 *, struct inode___65 *, struct dentry___65 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___65 *, struct iattr___65 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___64 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___65 *, char *, size_t);
	int (*fiemap)(struct inode___65 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___65 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___65 *, struct dentry___65 *, struct file___64 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___65 *, struct dentry___65 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___65 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___65 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___65 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___64 {
	void (*fl_copy_lock)(struct file_lock___64 *, struct file_lock___64 *);
	void (*fl_release_private)(struct file_lock___64 *);
};

struct lock_manager_operations___64;

struct file_lock___64 {
	struct file_lock___64 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___64 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___64 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___64 *fl_ops;
	const struct lock_manager_operations___64 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___64 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___64 *);
	int (*lm_grant)(struct file_lock___64 *, int);
	bool (*lm_break)(struct file_lock___64 *);
	int (*lm_change)(struct file_lock___64 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___64 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___64 *);
};

struct fasync_struct___64 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___64 *fa_next;
	struct file___64 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___64 {
	struct inode___65 * (*alloc_inode)(struct super_block___65 *);
	void (*destroy_inode)(struct inode___65 *);
	void (*free_inode)(struct inode___65 *);
	void (*dirty_inode)(struct inode___65 *, int);
	int (*write_inode)(struct inode___65 *, struct writeback_control___28 *);
	int (*drop_inode)(struct inode___65 *);
	void (*evict_inode)(struct inode___65 *);
	void (*put_super)(struct super_block___65 *);
	int (*sync_fs)(struct super_block___65 *, int);
	int (*freeze_super)(struct super_block___65 *);
	int (*freeze_fs)(struct super_block___65 *);
	int (*thaw_super)(struct super_block___65 *);
	int (*unfreeze_fs)(struct super_block___65 *);
	int (*statfs)(struct dentry___65 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___65 *, int *, char *);
	void (*umount_begin)(struct super_block___65 *);
	int (*show_options)(struct seq_file___62 *, struct dentry___65 *);
	int (*show_devname)(struct seq_file___62 *, struct dentry___65 *);
	int (*show_path)(struct seq_file___62 *, struct dentry___65 *);
	int (*show_stats)(struct seq_file___62 *, struct dentry___65 *);
	ssize_t (*quota_read)(struct super_block___65 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___65 *, int, const char *, size_t, loff_t);
	struct dquot___64 ** (*get_dquots)(struct inode___65 *);
	long int (*nr_cached_objects)(struct super_block___65 *, struct shrink_control___26 *);
	long int (*free_cached_objects)(struct super_block___65 *, struct shrink_control___26 *);
	struct file___64 * (*real_loop)(struct file___64 *);
};

struct wakeup_source___57;

struct dev_pm_info___57 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___57 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___57 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___57;

struct bus_type___57;

struct device_driver___57;

struct dev_pm_domain___57;

struct fwnode_handle___57;

struct class___57;

struct attribute_group___64;

struct device___57 {
	struct kobject___64 kobj;
	struct device___57 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___57 *type;
	struct bus_type___57 *bus;
	struct device_driver___57 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___57 power;
	struct dev_pm_domain___57 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___57 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___57 *class;
	const struct attribute_group___64 **groups;
	void (*release)(struct device___57 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___30 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___65 *bd_inode;
	struct super_block___65 *bd_super;
	void *bd_claiming;
	struct device___57 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___64 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___29 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___65 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___48)(struct file___64 *, wait_queue_head_t *, struct poll_table_struct___48 *);

struct poll_table_struct___48 {
	poll_queue_proc___48 _qproc;
	__poll_t _key;
};

struct seq_operations___62;

struct seq_file___62 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___62 *op;
	int poll_event;
	const struct file___64 *file;
	void *private;
};

typedef void bio_end_io_t___29(struct bio___29 *);

struct bio_vec___35 {
	struct page___69 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___29;

struct bio___29 {
	struct bio___29 *bi_next;
	struct block_device___30 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___29 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___28 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___29 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___35 *bi_io_vec;
	struct bio_set___29 *bi_pool;
	struct bio_vec___35 bi_inline_vecs[0];
};

struct kernfs_root___64;

struct kernfs_elem_dir___64 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___64 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___64;

struct kernfs_root___64 {
	struct kernfs_node___64 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___64 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___64 {
	struct kernfs_node___64 *target_kn;
};

struct kernfs_ops___64;

struct kernfs_elem_attr___64 {
	const struct kernfs_ops___64 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___64 *notify_next;
};

struct kernfs_node___64 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___64 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___64 dir;
		struct kernfs_elem_symlink___64 symlink;
		struct kernfs_elem_attr___64 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___64;

struct kernfs_ops___64 {
	int (*open)(struct kernfs_open_file___64 *);
	void (*release)(struct kernfs_open_file___64 *);
	int (*seq_show)(struct seq_file___62 *, void *);
	void * (*seq_start)(struct seq_file___62 *, loff_t *);
	void * (*seq_next)(struct seq_file___62 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___62 *, void *);
	ssize_t (*read)(struct kernfs_open_file___64 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___64 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___64 *, struct poll_table_struct___48 *);
	int (*mmap)(struct kernfs_open_file___64 *, struct vm_area_struct___69 *);
};

struct kernfs_syscall_ops___64 {
	int (*show_options)(struct seq_file___62 *, struct kernfs_root___64 *);
	int (*mkdir)(struct kernfs_node___64 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___64 *);
	int (*rename)(struct kernfs_node___64 *, struct kernfs_node___64 *, const char *);
	int (*show_path)(struct seq_file___62 *, struct kernfs_node___64 *, struct kernfs_root___64 *);
};

struct kernfs_open_file___64 {
	struct kernfs_node___64 *kn;
	struct file___64 *file;
	struct seq_file___62 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___63 *vm_ops;
};

struct sock___10;

struct kobj_ns_type_operations___8 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___10 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___15 *net;
} possible_net_t___12;

struct proto___8;

struct sock_common___8 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___8 *skc_prot;
	possible_net_t___12 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___10 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___14;

struct sk_buff_head___12 {
	struct sk_buff___14 *next;
	struct sk_buff___14 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___8 {
	struct cgroup___53 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___8;

struct socket_wq___8;

struct dst_entry___8;

struct socket___8;

struct net_device___17;

struct sock___10 {
	struct sock_common___8 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___12 sk_error_queue;
	struct sk_buff___14 *sk_rx_skb_cache;
	struct sk_buff_head___12 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___14 *head;
		struct sk_buff___14 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___8 *sk_filter;
	union {
		struct socket_wq___8 *sk_wq;
		struct socket_wq___8 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___8 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___8 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___14 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___14 *sk_tx_skb_cache;
	struct sk_buff_head___12 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___69 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___8 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___57 *sk_peer_pid;
	const struct cred___9 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___8 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___8 sk_cgrp_data;
	struct mem_cgroup___26 *sk_memcg;
	void (*sk_state_change)(struct sock___10 *);
	void (*sk_data_ready)(struct sock___10 *);
	void (*sk_write_space)(struct sock___10 *);
	void (*sk_error_report)(struct sock___10 *);
	int (*sk_backlog_rcv)(struct sock___10 *, struct sk_buff___14 *);
	struct sk_buff___14 * (*sk_validate_xmit_skb)(struct sock___10 *, struct net_device___17 *, struct sk_buff___14 *);
	void (*sk_destruct)(struct sock___10 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage___4 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___64;

struct attribute_group___64 {
	const char *name;
	umode_t (*is_visible)(struct kobject___64 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___64 *, struct bin_attribute___64 *, int);
	struct attribute **attrs;
	struct bin_attribute___64 **bin_attrs;
};

struct bin_attribute___64 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___64 * (*f_mapping)();
	ssize_t (*read)(struct file___64 *, struct kobject___64 *, struct bin_attribute___64 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___64 *, struct kobject___64 *, struct bin_attribute___64 *, char *, loff_t, size_t);
	int (*mmap)(struct file___64 *, struct kobject___64 *, struct bin_attribute___64 *, struct vm_area_struct___69 *);
};

struct sysfs_ops___64 {
	ssize_t (*show)(struct kobject___64 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___64 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___64;

struct kset___64 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___64 kobj;
	const struct kset_uevent_ops___64 *uevent_ops;
};

struct kobj_type___64 {
	void (*release)(struct kobject___64 *);
	const struct sysfs_ops___64 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___64 **default_groups;
	const struct kobj_ns_type_operations___8 * (*child_ns_type)(struct kobject___64 *);
	const void * (*namespace)(struct kobject___64 *);
	void (*get_ownership)(struct kobject___64 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___64 {
	int (* const filter)(struct kset___64 *, struct kobject___64 *);
	const char * (* const name)(struct kset___64 *, struct kobject___64 *);
	int (* const uevent)(struct kset___64 *, struct kobject___64 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___61 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___61 *);
	int (*get)(char *, const struct kernel_param___61 *);
	void (*free)(void *);
};

struct kparam_array___61;

struct kernel_param___61 {
	const char *name;
	struct module___63 *mod;
	const struct kernel_param_ops___61 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___61 *arr;
	};
};

struct kparam_array___61 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___61 *ops;
	void *elem;
};

struct module_attribute___61 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___61 *, struct module_kobject___61 *, char *);
	ssize_t (*store)(struct module_attribute___61 *, struct module_kobject___61 *, const char *, size_t);
	void (*setup)(struct module___63 *, const char *);
	int (*test)(struct module___63 *);
	void (*free)(struct module___63 *);
};

struct dev_pagemap_ops___63 {
	void (*page_free)(struct page___69 *);
	void (*kill)(struct dev_pagemap___63 *);
	void (*cleanup)(struct dev_pagemap___63 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___63 *);
};

struct bpf_iter_aux_info___13;

typedef int (*bpf_iter_init_seq_priv_t___13)(void *, struct bpf_iter_aux_info___13 *);

struct bpf_map___13;

struct bpf_iter_aux_info___13 {
	struct bpf_map___13 *map;
};

struct bpf_iter_seq_info___13 {
	const struct seq_operations___62 *seq_ops;
	bpf_iter_init_seq_priv_t___13 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___62 {
	void * (*start)(struct seq_file___62 *, loff_t *);
	void (*stop)(struct seq_file___62 *, void *);
	void * (*next)(struct seq_file___62 *, void *, loff_t *);
	int (*show)(struct seq_file___62 *, void *);
};

struct bpf_prog_aux___13;

struct bpf_prog___12;

struct bpf_local_storage_map___4;

struct bpf_map_ops___13 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___13 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___13 *, struct file___64 *);
	void (*map_free)(struct bpf_map___13 *);
	int (*map_get_next_key)(struct bpf_map___13 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___13 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___13 *, void *);
	int (*map_lookup_batch)(struct bpf_map___13 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___13 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___13 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___13 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___13 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___13 *, void *);
	int (*map_update_elem)(struct bpf_map___13 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___13 *, void *);
	int (*map_push_elem)(struct bpf_map___13 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___13 *, void *);
	int (*map_peek_elem)(struct bpf_map___13 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___13 *, struct file___64 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___13 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___13 *, void *, struct seq_file___62 *);
	int (*map_check_btf)(const struct bpf_map___13 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___13 *, struct bpf_prog_aux___13 *);
	void (*map_poke_untrack)(struct bpf_map___13 *, struct bpf_prog_aux___13 *);
	void (*map_poke_run)(struct bpf_map___13 *, u32, struct bpf_prog___12 *, struct bpf_prog___12 *);
	int (*map_direct_value_addr)(const struct bpf_map___13 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___13 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___13 *, struct vm_area_struct___69 *);
	__poll_t (*map_poll)(struct bpf_map___13 *, struct file___64 *, struct poll_table_struct___48 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___4 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___4 *, void *, u32);
	struct bpf_local_storage___4 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___13 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___13 *, const struct bpf_map___13 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___13 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___13 *iter_seq_info;
};

struct bpf_map___13 {
	const struct bpf_map_ops___13 *ops;
	struct bpf_map___13 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___26 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___13;

struct bpf_jit_poke_descriptor___13;

struct bpf_prog_ops___12;

struct btf_mod_pair___13;

struct bpf_prog_offload___12;

struct bpf_prog_aux___13 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___12 *dst_prog;
	struct bpf_trampoline___13 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___12 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___13 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___12 *ops;
	struct bpf_map___13 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___13 *used_btfs;
	struct bpf_prog___12 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___13 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___12 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___12 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___13 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_local_storage_map___4 {
	struct bpf_map___13 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___12;

struct bpf_map_dev_ops___12 {
	int (*map_get_next_key)(struct bpf_offloaded_map___12 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___12 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___12 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___12 *, void *);
};

struct bpf_offloaded_map___12 {
	struct bpf_map___13 map;
	struct net_device___17 *netdev;
	const struct bpf_map_dev_ops___12 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___12(struct sk_buff___14 **);

struct bpf_xdp_entity___12 {
	struct bpf_prog___12 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___12;

struct net_device_ops___12;

struct l3mdev_ops___8;

struct xfrmdev_ops___12;

struct header_ops___12;

struct netdev_rx_queue___12;

struct mini_Qdisc___12;

struct netdev_queue___12;

struct Qdisc___12;

struct rtnl_link_ops___12;

struct dcbnl_rtnl_ops___12;

struct net_device___17 {
	char name[16];
	struct netdev_name_node___12 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___12 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___8 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___12 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___12 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___64 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___12 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___12 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___12 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___12 *miniq_ingress;
	struct netdev_queue___12 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___12 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___12 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___12 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___12 = 0,
		NETREG_REGISTERED___12 = 1,
		NETREG_UNREGISTERING___12 = 2,
		NETREG_UNREGISTERED___12 = 3,
		NETREG_RELEASED___12 = 4,
		NETREG_DUMMY___12 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___12 = 0,
		RTNL_LINK_INITIALIZING___12 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___17 *);
	struct netpoll_info *npinfo;
	possible_net_t___12 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___57 dev;
	const struct attribute_group___64 *sysfs_groups[4];
	const struct attribute_group___64 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___12 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___12 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___12 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___7 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___12 *);
};

struct bpf_prog_ops___12 {
	int (*test_run)(struct bpf_prog___12 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___12 {
	struct bpf_prog___12 *prog;
	struct net_device___17 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___13 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___12 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___63 *mod;
};

struct bpf_jit_poke_descriptor___13 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___13 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___13 {
	struct btf *btf;
	struct module___63 *module;
};

struct bpf_prog_array_item___12 {
	struct bpf_prog___12 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___12 {
	struct callback_head rcu;
	struct bpf_prog_array_item___12 items[0];
};

struct sk_buff___14 {
	union {
		struct {
			struct sk_buff___14 *next;
			struct sk_buff___14 *prev;
			union {
				struct net_device___17 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___10 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___14 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bpf_local_storage_data___4 {
	struct bpf_local_storage_map___4 *smap;
	u8 data[0];
};

struct bpf_local_storage_elem___3 {
	struct hlist_node map_node;
	struct hlist_node snode;
	struct bpf_local_storage___4 *local_storage;
	struct callback_head rcu;
	long: 64;
	struct bpf_local_storage_data___4 sdata;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___57;

struct fwnode_handle___57 {
	struct fwnode_handle___57 *secondary;
	const struct fwnode_operations___57 *ops;
	struct device___57 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___57;

struct fwnode_endpoint___57;

struct fwnode_operations___57 {
	struct fwnode_handle___57 * (*get)(struct fwnode_handle___57 *);
	void (*put)(struct fwnode_handle___57 *);
	bool (*device_is_available)(const struct fwnode_handle___57 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___57 *, const struct device___57 *);
	bool (*property_present)(const struct fwnode_handle___57 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___57 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___57 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___57 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*get_parent)(const struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*get_next_child_node)(const struct fwnode_handle___57 *, struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*get_named_child_node)(const struct fwnode_handle___57 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___57 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___57 *);
	struct fwnode_handle___57 * (*graph_get_next_endpoint)(const struct fwnode_handle___57 *, struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*graph_get_remote_endpoint)(const struct fwnode_handle___57 *);
	struct fwnode_handle___57 * (*graph_get_port_parent)(struct fwnode_handle___57 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___57 *, struct fwnode_endpoint___57 *);
	int (*add_links)(struct fwnode_handle___57 *);
};

struct fwnode_endpoint___57 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___57 *local_fwnode;
};

struct fwnode_reference_args___57 {
	struct fwnode_handle___57 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msghdr___8 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___35 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___64 *msg_iocb;
};

struct inet_frags___14;

struct fqdir___14 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___14 *f;
	struct net___15 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___14;

struct inet_frags___14 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___14 *, const void *);
	void (*destructor)(struct inet_frag_queue___14 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct fib_rules_ops___8;

struct fib_notifier_ops___8;

struct netns_ipv4___14 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___8 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___10 *fibnl;
	struct sock___10 **icmp_sk;
	struct sock___10 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___10 **tcp_sk;
	struct fqdir___14 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___8 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___8 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___8 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___8;

struct dst_ops___14 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___14 *);
	struct dst_entry___8 * (*check)(struct dst_entry___8 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___8 *);
	unsigned int (*mtu)(const struct dst_entry___8 *);
	u32 * (*cow_metrics)(struct dst_entry___8 *, long unsigned int);
	void (*destroy)(struct dst_entry___8 *);
	void (*ifdown)(struct dst_entry___8 *, struct net_device___17 *, int);
	struct dst_entry___8 * (*negative_advice)(struct dst_entry___8 *);
	void (*link_failure)(struct sk_buff___14 *);
	void (*update_pmtu)(struct dst_entry___8 *, struct sock___10 *, struct sk_buff___14 *, u32, bool);
	void (*redirect)(struct dst_entry___8 *, struct sock___10 *, struct sk_buff___14 *);
	int (*local_out)(struct net___15 *, struct sock___10 *, struct sk_buff___14 *);
	struct neighbour___8 * (*neigh_lookup)(const struct dst_entry___8 *, struct sk_buff___14 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___8 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___14 {
	struct dst_ops___14 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___14 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___8 *fib6_rules_ops;
	struct sock___10 **icmp_sk;
	struct sock___10 *ndisc_sk;
	struct sock___10 *tcp_sk;
	struct sock___10 *igmp_sk;
	struct sock___10 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___8 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___8 *notifier_ops;
	struct fib_notifier_ops___8 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___14 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___14 *fqdir;
};

struct netns_sctp___8 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___10 *ctl_sock;
	struct sock___10 *udp4_sock;
	struct sock___10 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___12 {
	struct bpf_prog_array___12 *run_array[2];
	struct bpf_prog___12 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___14 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___10 *nlsk;
	struct sock___10 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___14 xfrm4_dst_ops;
	struct dst_ops___14 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___15 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___10 *rtnl;
	struct sock___10 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___17 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___14 ipv4;
	struct netns_ipv6___14 ipv6;
	struct netns_ieee802154_lowpan___14 ieee802154_lowpan;
	struct netns_sctp___8 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___12 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___12 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___14 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___10 *crypto_nlsk;
	struct sock___10 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___14 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___14 *fragments_tail;
	struct sk_buff___14 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___14 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___8;

struct fib_lookup_arg___8;

struct fib_rules_ops___8 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___8 *, struct flowi *, int, struct fib_lookup_arg___8 *);
	bool (*suppress)(struct fib_rule___8 *, int, struct fib_lookup_arg___8 *);
	int (*match)(struct fib_rule___8 *, struct flowi *, int);
	int (*configure)(struct fib_rule___8 *, struct sk_buff___14 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___8 *);
	int (*compare)(struct fib_rule___8 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___8 *, struct sk_buff___14 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___8 *);
	void (*flush_cache)(struct fib_rules_ops___8 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___63 *owner;
	struct net___15 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___8 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___15 *);
	int (*fib_dump)(struct net___15 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___63 *owner;
	struct callback_head rcu;
};

struct dst_entry___8 {
	struct net_device___17 *dev;
	struct dst_ops___14 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___14 *);
	int (*output)(struct net___15 *, struct sock___10 *, struct sk_buff___14 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___8;

struct neigh_parms___8;

struct neigh_ops___8;

struct neighbour___8 {
	struct neighbour___8 *next;
	struct neigh_table___8 *tbl;
	struct neigh_parms___8 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___12 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___8 *, struct sk_buff___14 *);
	const struct neigh_ops___8 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___17 *dev;
	u8 primary_key[0];
};

struct cgroup_namespace___53 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___53 *root_cset;
};

struct socket_wq___8 {
	wait_queue_head_t wait;
	struct fasync_struct___64 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___8;

struct socket___8 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___64 *file;
	struct sock___10 *sk;
	const struct proto_ops___8 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___8 wq;
};

typedef int (*sk_read_actor_t___8)(read_descriptor_t *, struct sk_buff___14 *, unsigned int, size_t);

struct proto_ops___8 {
	int family;
	struct module___63 *owner;
	int (*release)(struct socket___8 *);
	int (*bind)(struct socket___8 *, struct sockaddr *, int);
	int (*connect)(struct socket___8 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___8 *, struct socket___8 *);
	int (*accept)(struct socket___8 *, struct socket___8 *, int, bool);
	int (*getname)(struct socket___8 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___64 *, struct socket___8 *, struct poll_table_struct___48 *);
	int (*ioctl)(struct socket___8 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___8 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___8 *, void *, bool, bool);
	int (*listen)(struct socket___8 *, int);
	int (*shutdown)(struct socket___8 *, int);
	int (*setsockopt)(struct socket___8 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___8 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___62 *, struct socket___8 *);
	int (*sendmsg)(struct socket___8 *, struct msghdr___8 *, size_t);
	int (*recvmsg)(struct socket___8 *, struct msghdr___8 *, size_t, int);
	int (*mmap)(struct file___64 *, struct socket___8 *, struct vm_area_struct___69 *);
	ssize_t (*sendpage)(struct socket___8 *, struct page___69 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___8 *, loff_t *, struct pipe_inode_info___24 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___10 *, int);
	int (*peek_len)(struct socket___8 *);
	int (*read_sock)(struct sock___10 *, read_descriptor_t *, sk_read_actor_t___8);
	int (*sendpage_locked)(struct sock___10 *, struct page___69 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___10 *, struct msghdr___8 *, size_t);
	int (*set_rcvlowat)(struct sock___10 *, int);
};

struct dev_pm_ops___57 {
	int (*prepare)(struct device___57 *);
	void (*complete)(struct device___57 *);
	int (*suspend)(struct device___57 *);
	int (*resume)(struct device___57 *);
	int (*freeze)(struct device___57 *);
	int (*thaw)(struct device___57 *);
	int (*poweroff)(struct device___57 *);
	int (*restore)(struct device___57 *);
	int (*suspend_late)(struct device___57 *);
	int (*resume_early)(struct device___57 *);
	int (*freeze_late)(struct device___57 *);
	int (*thaw_early)(struct device___57 *);
	int (*poweroff_late)(struct device___57 *);
	int (*restore_early)(struct device___57 *);
	int (*suspend_noirq)(struct device___57 *);
	int (*resume_noirq)(struct device___57 *);
	int (*freeze_noirq)(struct device___57 *);
	int (*thaw_noirq)(struct device___57 *);
	int (*poweroff_noirq)(struct device___57 *);
	int (*restore_noirq)(struct device___57 *);
	int (*runtime_suspend)(struct device___57 *);
	int (*runtime_resume)(struct device___57 *);
	int (*runtime_idle)(struct device___57 *);
};

struct wakeup_source___57 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___57 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___57 {
	struct dev_pm_ops___57 ops;
	int (*start)(struct device___57 *);
	void (*detach)(struct device___57 *, bool);
	int (*activate)(struct device___57 *);
	void (*sync)(struct device___57 *);
	void (*dismiss)(struct device___57 *);
};

struct bus_type___57 {
	const char *name;
	const char *dev_name;
	struct device___57 *dev_root;
	const struct attribute_group___64 **bus_groups;
	const struct attribute_group___64 **dev_groups;
	const struct attribute_group___64 **drv_groups;
	int (*match)(struct device___57 *, struct device_driver___57 *);
	int (*uevent)(struct device___57 *, struct kobj_uevent_env *);
	int (*probe)(struct device___57 *);
	void (*sync_state)(struct device___57 *);
	void (*remove)(struct device___57 *);
	void (*shutdown)(struct device___57 *);
	int (*online)(struct device___57 *);
	int (*offline)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	int (*num_vf)(struct device___57 *);
	int (*dma_configure)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___57 {
	const char *name;
	struct bus_type___57 *bus;
	struct module___63 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___57 *);
	void (*sync_state)(struct device___57 *);
	int (*remove)(struct device___57 *);
	void (*shutdown)(struct device___57 *);
	int (*suspend)(struct device___57 *, pm_message_t);
	int (*resume)(struct device___57 *);
	const struct attribute_group___64 **groups;
	const struct attribute_group___64 **dev_groups;
	const struct dev_pm_ops___57 *pm;
	void (*coredump)(struct device___57 *);
	struct driver_private *p;
};

struct device_type___57 {
	const char *name;
	const struct attribute_group___64 **groups;
	int (*uevent)(struct device___57 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___57 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___57 *);
	const struct dev_pm_ops___57 *pm;
};

struct class___57 {
	const char *name;
	struct module___63 *owner;
	const struct attribute_group___64 **class_groups;
	const struct attribute_group___64 **dev_groups;
	struct kobject___64 *dev_kobj;
	int (*dev_uevent)(struct device___57 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___57 *, umode_t *);
	void (*class_release)(struct class___57 *);
	void (*dev_release)(struct device___57 *);
	int (*shutdown_pre)(struct device___57 *);
	const struct kobj_ns_type_operations___8 *ns_type;
	const void * (*namespace)(struct device___57 *);
	void (*get_ownership)(struct device___57 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___57 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___24;

struct pipe_buffer___24 {
	struct page___69 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___24 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___24 {
	int (*confirm)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
	void (*release)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
	bool (*try_steal)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
	bool (*get)(struct pipe_inode_info___24 *, struct pipe_buffer___24 *);
};

struct dcbnl_rtnl_ops___12 {
	int (*ieee_getets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___17 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___17 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___17 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___17 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___17 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___17 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___17 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___17 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___17 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___17 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___17 *);
	u8 (*setstate)(struct net_device___17 *, u8);
	void (*getpermhwaddr)(struct net_device___17 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___17 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___17 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___17 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___17 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___17 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___17 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___17 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___17 *, int, u8 *);
	void (*setpfccfg)(struct net_device___17 *, int, u8);
	void (*getpfccfg)(struct net_device___17 *, int, u8 *);
	u8 (*setall)(struct net_device___17 *);
	u8 (*getcap)(struct net_device___17 *, int, u8 *);
	int (*getnumtcs)(struct net_device___17 *, int, u8 *);
	int (*setnumtcs)(struct net_device___17 *, int, u8);
	u8 (*getpfcstate)(struct net_device___17 *);
	void (*setpfcstate)(struct net_device___17 *, u8);
	void (*getbcncfg)(struct net_device___17 *, int, u32 *);
	void (*setbcncfg)(struct net_device___17 *, int, u32);
	void (*getbcnrp)(struct net_device___17 *, int, u8 *);
	void (*setbcnrp)(struct net_device___17 *, int, u8);
	int (*setapp)(struct net_device___17 *, u8, u16, u8);
	int (*getapp)(struct net_device___17 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___17 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___17 *, int, u8);
	u8 (*getdcbx)(struct net_device___17 *);
	u8 (*setdcbx)(struct net_device___17 *, u8);
	int (*peer_getappinfo)(struct net_device___17 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___17 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___17 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___17 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___17 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___17 *, struct dcbnl_buffer *);
};

struct cftype___53;

struct cgroup_subsys___53 {
	struct cgroup_subsys_state___53 * (*css_alloc)(struct cgroup_subsys_state___53 *);
	int (*css_online)(struct cgroup_subsys_state___53 *);
	void (*css_offline)(struct cgroup_subsys_state___53 *);
	void (*css_released)(struct cgroup_subsys_state___53 *);
	void (*css_free)(struct cgroup_subsys_state___53 *);
	void (*css_reset)(struct cgroup_subsys_state___53 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___53 *, int);
	int (*css_extra_stat_show)(struct seq_file___62 *, struct cgroup_subsys_state___53 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___71 *, struct css_set___53 *);
	void (*cancel_fork)(struct task_struct___71 *, struct css_set___53 *);
	void (*fork)(struct task_struct___71 *);
	void (*exit)(struct task_struct___71 *);
	void (*release)(struct task_struct___71 *);
	void (*bind)(struct cgroup_subsys_state___53 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___53 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___53 *dfl_cftypes;
	struct cftype___53 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___53 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___53 *updated_children;
	struct cgroup___53 *updated_next;
};

struct cgroup_root___53 {
	struct kernfs_root___64 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___53 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___53 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___53 *ss;
	struct list_head node;
	struct kernfs_ops___64 *kf_ops;
	int (*open)(struct kernfs_open_file___64 *);
	void (*release)(struct kernfs_open_file___64 *);
	u64 (*read_u64)(struct cgroup_subsys_state___53 *, struct cftype___53 *);
	s64 (*read_s64)(struct cgroup_subsys_state___53 *, struct cftype___53 *);
	int (*seq_show)(struct seq_file___62 *, void *);
	void * (*seq_start)(struct seq_file___62 *, loff_t *);
	void * (*seq_next)(struct seq_file___62 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___62 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___53 *, struct cftype___53 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___53 *, struct cftype___53 *, s64);
	ssize_t (*write)(struct kernfs_open_file___64 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___64 *, struct poll_table_struct___48 *);
};

struct xdp_rxq_info___12 {
	struct net_device___17 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___12 {
	struct net_device___17 *dev;
};

struct xdp_buff___12 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___12 *rxq;
	struct xdp_txq_info___12 *txq;
	u32 frame_sz;
};

struct xdp_frame___12 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___17 *dev_rx;
};

struct netlink_callback___12 {
	struct sk_buff___14 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___14 *, struct netlink_callback___12 *);
	int (*done)(struct netlink_callback___12 *);
	void *data;
	struct module___63 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___12 {
	int (*create)(struct sk_buff___14 *, struct net_device___17 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___14 *, unsigned char *);
	int (*cache)(const struct neighbour___8 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___17 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___14 *);
};

struct netdev_queue___12 {
	struct net_device___17 *dev;
	struct Qdisc___12 *qdisc;
	struct Qdisc___12 *qdisc_sleeping;
	struct kobject___64 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___17 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___12 {
	struct sk_buff___14 *head;
	struct sk_buff___14 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___12;

struct Qdisc___12 {
	int (*enqueue)(struct sk_buff___14 *, struct Qdisc___12 *, struct sk_buff___14 **);
	struct sk_buff___14 * (*dequeue)(struct Qdisc___12 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___12 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___12 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___12 gso_skb;
	struct qdisc_skb_head___12 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___12 *next_sched;
	struct sk_buff_head___12 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___12 {
	struct xdp_rxq_info___12 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___64 kobj;
	struct net_device___17 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___12 {
	enum net_device_path_type type;
	const struct net_device___17 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___12 = 0,
				DEV_PATH_BR_VLAN_TAG___12 = 1,
				DEV_PATH_BR_VLAN_UNTAG___12 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___12 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___12 {
	const struct net_device___17 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___12 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___12 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___12 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___12 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___14 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___12 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___17 *dev;
	const char *name;
};

struct net_device_ops___12 {
	int (*ndo_init)(struct net_device___17 *);
	void (*ndo_uninit)(struct net_device___17 *);
	int (*ndo_open)(struct net_device___17 *);
	int (*ndo_stop)(struct net_device___17 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___14 *, struct net_device___17 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___14 *, struct net_device___17 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___17 *, struct sk_buff___14 *, struct net_device___17 *);
	void (*ndo_change_rx_flags)(struct net_device___17 *, int);
	void (*ndo_set_rx_mode)(struct net_device___17 *);
	int (*ndo_set_mac_address)(struct net_device___17 *, void *);
	int (*ndo_validate_addr)(struct net_device___17 *);
	int (*ndo_do_ioctl)(struct net_device___17 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___17 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___17 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___17 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___17 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___17 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___17 *, int);
	int (*ndo_neigh_setup)(struct net_device___17 *, struct neigh_parms___8 *);
	void (*ndo_tx_timeout)(struct net_device___17 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___17 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___17 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___17 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___17 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___17 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___17 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___17 *);
	int (*ndo_netpoll_setup)(struct net_device___17 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___17 *);
	int (*ndo_set_vf_mac)(struct net_device___17 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___17 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___17 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___17 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___17 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___17 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___17 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___17 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___17 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___17 *, int, struct sk_buff___14 *);
	int (*ndo_get_vf_guid)(struct net_device___17 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___17 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___17 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___17 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___17 *);
	int (*ndo_fcoe_disable)(struct net_device___17 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___17 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___17 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___17 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___17 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___17 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___17 *, const struct sk_buff___14 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___17 *, struct net_device___17 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___17 *, struct net_device___17 *);
	struct net_device___17 * (*ndo_get_xmit_slave)(struct net_device___17 *, struct sk_buff___14 *, bool);
	struct net_device___17 * (*ndo_sk_get_lower_dev)(struct net_device___17 *, struct sock___10 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___17 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___17 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___17 *, struct neighbour___8 *);
	void (*ndo_neigh_destroy)(struct net_device___17 *, struct neighbour___8 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___14 *, struct netlink_callback___12 *, struct net_device___17 *, struct net_device___17 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___14 *, struct nlattr **, struct net_device___17 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___17 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___14 *, u32, u32, struct net_device___17 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___17 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___17 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___17 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___17 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___17 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___17 *, struct net_device___17 *);
	void (*ndo_dfwd_del_station)(struct net_device___17 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___17 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___17 *);
	int (*ndo_change_proto_down)(struct net_device___17 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___17 *, struct sk_buff___14 *);
	void (*ndo_set_rx_headroom)(struct net_device___17 *, int);
	int (*ndo_bpf)(struct net_device___17 *, struct netdev_bpf___12 *);
	int (*ndo_xdp_xmit)(struct net_device___17 *, int, struct xdp_frame___12 **, u32);
	struct net_device___17 * (*ndo_xdp_get_xmit_slave)(struct net_device___17 *, struct xdp_buff___12 *);
	int (*ndo_xsk_wakeup)(struct net_device___17 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___17 *);
	int (*ndo_tunnel_ctl)(struct net_device___17 *, struct ip_tunnel_parm *, int);
	struct net_device___17 * (*ndo_get_peer_dev)(struct net_device___17 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___12 *, struct net_device_path___12 *);
};

struct neigh_parms___8 {
	possible_net_t___12 net;
	struct net_device___17 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___8 *);
	struct neigh_table___8 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___8 {
	u32 (*l3mdev_fib_table)(const struct net_device___17 *);
	struct sk_buff___14 * (*l3mdev_l3_rcv)(struct net_device___17 *, struct sk_buff___14 *, u16);
	struct sk_buff___14 * (*l3mdev_l3_out)(struct net_device___17 *, struct sock___10 *, struct sk_buff___14 *, u16);
	struct dst_entry___8 * (*l3mdev_link_scope_lookup)(const struct net_device___17 *, struct flowi6 *);
};

struct tcf_proto___12;

struct tcf_block___12;

struct mini_Qdisc___12 {
	struct tcf_proto___12 *filter_list;
	struct tcf_block___12 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___12 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___17 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___17 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___15 *, struct net_device___17 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___17 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___17 *, struct list_head *);
	size_t (*get_size)(const struct net_device___17 *);
	int (*fill_info)(struct sk_buff___14 *, const struct net_device___17 *);
	size_t (*get_xstats_size)(const struct net_device___17 *);
	int (*fill_xstats)(struct sk_buff___14 *, const struct net_device___17 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___17 *, struct net_device___17 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___17 *, const struct net_device___17 *);
	int (*fill_slave_info)(struct sk_buff___14 *, const struct net_device___17 *, const struct net_device___17 *);
	struct net___15 * (*get_link_net)(const struct net_device___17 *);
	size_t (*get_linkxstats_size)(const struct net_device___17 *, int);
	int (*fill_linkxstats)(struct sk_buff___14 *, const struct net_device___17 *, int *, int);
};

struct block_device_operations___29;

struct gendisk___29 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___30 *part0;
	const struct block_device_operations___29 *fops;
	struct request_queue___30 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___28 *bdi;
	struct kobject___64 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___64 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___29 {
	struct bio___29 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___35 *bip_vec;
	struct bio_vec___35 bip_inline_vecs[0];
};

struct blkcg___28;

struct blkg_policy_data___28;

struct blkcg_gq___28 {
	struct request_queue___30 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___28 *blkcg;
	struct blkcg_gq___28 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___28 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___29 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___29(struct request___29 *);

typedef void integrity_complete_fn___29(struct request___29 *, unsigned int);

struct blk_integrity_profile___29 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___29 *prepare_fn;
	integrity_complete_fn___29 *complete_fn;
	const char *name;
};

struct block_device_operations___29 {
	blk_qc_t (*submit_bio)(struct bio___29 *);
	int (*open)(struct block_device___30 *, fmode_t);
	void (*release)(struct gendisk___29 *, fmode_t);
	int (*rw_page)(struct block_device___30 *, sector_t, struct page___69 *, unsigned int);
	int (*ioctl)(struct block_device___30 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___30 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___29 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___29 *);
	int (*getgeo)(struct block_device___30 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___30 *, bool);
	void (*swap_slot_free_notify)(struct block_device___30 *, long unsigned int);
	int (*report_zones)(struct gendisk___29 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___29 *, umode_t *);
	struct module___63 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___29 *, sector_t *);
};

typedef void rq_end_io_fn___29(struct request___29 *, blk_status_t);

struct request___29 {
	struct request_queue___30 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___28 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___29 *bio;
	struct bio___29 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___35 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___29 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___29 *saved_end_io;
		} flush;
	};
	struct gendisk___29 *rq_disk;
	struct block_device___30 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___29 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___28 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___30 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___64 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___65 *debugfs_dir;
	struct dentry___65 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___29;

struct elevator_mq_ops___29 {
	int (*init_sched)(struct request_queue___30 *, struct elevator_type___29 *);
	void (*exit_sched)(struct elevator_queue___29 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___28 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___28 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___28 *);
	bool (*allow_merge)(struct request_queue___30 *, struct request___29 *, struct bio___29 *);
	bool (*bio_merge)(struct request_queue___30 *, struct bio___29 *, unsigned int);
	int (*request_merge)(struct request_queue___30 *, struct request___29 **, struct bio___29 *);
	void (*request_merged)(struct request_queue___30 *, struct request___29 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___30 *, struct request___29 *, struct request___29 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___29 *);
	void (*finish_request)(struct request___29 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___28 *, struct list_head *, bool);
	struct request___29 * (*dispatch_request)(struct blk_mq_hw_ctx___28 *);
	bool (*has_work)(struct blk_mq_hw_ctx___28 *);
	void (*completed_request)(struct request___29 *, u64);
	void (*requeue_request)(struct request___29 *);
	struct request___29 * (*former_request)(struct request_queue___30 *, struct request___29 *);
	struct request___29 * (*next_request)(struct request_queue___30 *, struct request___29 *);
	void (*init_icq)(struct io_cq___29 *);
	void (*exit_icq)(struct io_cq___29 *);
};

struct elv_fs_entry___29;

struct elevator_type___29 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___29 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___29 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___63 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___29 {
	struct elevator_type___29 *type;
	void *elevator_data;
	struct kobject___64 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___29 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___29 *, char *);
	ssize_t (*store)(struct elevator_queue___29 *, const char *, size_t);
};

struct blk_mq_queue_data___28;

struct blk_mq_ops___28 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___28 *, const struct blk_mq_queue_data___28 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___28 *);
	int (*get_budget)(struct request_queue___30 *);
	void (*put_budget)(struct request_queue___30 *, int);
	void (*set_rq_budget_token)(struct request___29 *, int);
	int (*get_rq_budget_token)(struct request___29 *);
	enum blk_eh_timer_return (*timeout)(struct request___29 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___28 *);
	void (*complete)(struct request___29 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___28 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___28 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___28 *, struct request___29 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___28 *, struct request___29 *, unsigned int);
	void (*initialize_rq_fn)(struct request___29 *);
	void (*cleanup_rq)(struct request___29 *);
	bool (*busy)(struct request_queue___30 *);
	int (*map_queues)(struct blk_mq_tag_set___28 *);
	void (*show_rq)(struct seq_file___62 *, struct request___29 *);
};

struct blk_mq_tag_set___28 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___28 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___28 {
	struct request___29 *rq;
	bool last;
};

struct blkcg_policy_data___28;

struct blkcg___28 {
	struct cgroup_subsys_state___53 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___28 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___28 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___28 {
	struct blkcg___28 *blkcg;
	int plid;
};

struct blkg_policy_data___28 {
	struct blkcg_gq___28 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___26 {
	struct mem_cgroup___26 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___26 {
	struct lruvec___27 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___26 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___26 *memcg;
};

struct obj_cgroup___26 {
	struct percpu_ref refcnt;
	struct mem_cgroup___26 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___12 {
	spinlock_t *lock;
	struct sk_buff___14 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___12;

struct Qdisc_ops___12 {
	struct Qdisc_ops___12 *next;
	const struct Qdisc_class_ops___12 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___14 *, struct Qdisc___12 *, struct sk_buff___14 **);
	struct sk_buff___14 * (*dequeue)(struct Qdisc___12 *);
	struct sk_buff___14 * (*peek)(struct Qdisc___12 *);
	int (*init)(struct Qdisc___12 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___12 *);
	void (*destroy)(struct Qdisc___12 *);
	int (*change)(struct Qdisc___12 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___12 *);
	int (*change_tx_queue_len)(struct Qdisc___12 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___12 *, unsigned int);
	int (*dump)(struct Qdisc___12 *, struct sk_buff___14 *);
	int (*dump_stats)(struct Qdisc___12 *, struct gnet_dump___12 *);
	void (*ingress_block_set)(struct Qdisc___12 *, u32);
	void (*egress_block_set)(struct Qdisc___12 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___12 *);
	u32 (*egress_block_get)(struct Qdisc___12 *);
	struct module___63 *owner;
};

struct Qdisc_class_ops___12 {
	unsigned int flags;
	struct netdev_queue___12 * (*select_queue)(struct Qdisc___12 *, struct tcmsg *);
	int (*graft)(struct Qdisc___12 *, long unsigned int, struct Qdisc___12 *, struct Qdisc___12 **, struct netlink_ext_ack *);
	struct Qdisc___12 * (*leaf)(struct Qdisc___12 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___12 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___12 *, u32);
	int (*change)(struct Qdisc___12 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___12 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___12 *, struct qdisc_walker *);
	struct tcf_block___12 * (*tcf_block)(struct Qdisc___12 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___12 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___12 *, long unsigned int);
	int (*dump)(struct Qdisc___12 *, long unsigned int, struct sk_buff___14 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___12 *, long unsigned int, struct gnet_dump___12 *);
};

struct tcf_chain___12;

struct tcf_block___12 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___15 *net;
	struct Qdisc___12 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___12 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___12;

struct tcf_proto_ops___12;

struct tcf_proto___12 {
	struct tcf_proto___12 *next;
	void *root;
	int (*classify)(struct sk_buff___14 *, const struct tcf_proto___12 *, struct tcf_result___12 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___12 *ops;
	struct tcf_chain___12 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___12 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___12 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___12 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___14 *, const struct tcf_proto___12 *, struct tcf_result___12 *);
	int (*init)(struct tcf_proto___12 *);
	void (*destroy)(struct tcf_proto___12 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___12 *, u32);
	void (*put)(struct tcf_proto___12 *, void *);
	int (*change)(struct net___15 *, struct sk_buff___14 *, struct tcf_proto___12 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___12 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___12 *);
	void (*walk)(struct tcf_proto___12 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___12 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___12 *, void *);
	void (*hw_del)(struct tcf_proto___12 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___15 *, struct tcf_chain___12 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___15 *, struct tcf_proto___12 *, void *, struct sk_buff___14 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___15 *, struct tcf_proto___12 *, void *, struct sk_buff___14 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___14 *, struct net___15 *, void *);
	struct module___63 *owner;
	int flags;
};

struct tcf_chain___12 {
	struct mutex filter_chain_lock;
	struct tcf_proto___12 *filter_chain;
	struct list_head list;
	struct tcf_block___12 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___12 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___8 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___12 *prog;
};

struct pneigh_entry___8;

struct neigh_hash_table___8;

struct neigh_table___8 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___17 *, __u32 *);
	bool (*key_eq)(const struct neighbour___8 *, const void *);
	int (*constructor)(struct neighbour___8 *);
	int (*pconstructor)(struct pneigh_entry___8 *);
	void (*pdestructor)(struct pneigh_entry___8 *);
	void (*proxy_redo)(struct sk_buff___14 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___17 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___8 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___12 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___8 *nht;
	struct pneigh_entry___8 **phash_buckets;
};

struct neigh_ops___8 {
	int family;
	void (*solicit)(struct neighbour___8 *, struct sk_buff___14 *);
	void (*error_report)(struct neighbour___8 *, struct sk_buff___14 *);
	int (*output)(struct neighbour___8 *, struct sk_buff___14 *);
	int (*connected_output)(struct neighbour___8 *, struct sk_buff___14 *);
};

struct pneigh_entry___8 {
	struct pneigh_entry___8 *next;
	possible_net_t___12 net;
	struct net_device___17 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___8 {
	struct neighbour___8 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___8 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___8 *ctarget;
	struct net___15 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___8 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___8 *rule;
	u32 table;
	int flags;
};

struct proto___8 {
	void (*close)(struct sock___10 *, long int);
	int (*pre_connect)(struct sock___10 *, struct sockaddr *, int);
	int (*connect)(struct sock___10 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___10 *, int);
	struct sock___10 * (*accept)(struct sock___10 *, int, int *, bool);
	int (*ioctl)(struct sock___10 *, int, long unsigned int);
	int (*init)(struct sock___10 *);
	void (*destroy)(struct sock___10 *);
	void (*shutdown)(struct sock___10 *, int);
	int (*setsockopt)(struct sock___10 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___10 *, int, int, char *, int *);
	void (*keepalive)(struct sock___10 *, int);
	int (*compat_ioctl)(struct sock___10 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___10 *, struct msghdr___8 *, size_t);
	int (*recvmsg)(struct sock___10 *, struct msghdr___8 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___10 *, struct page___69 *, int, size_t, int);
	int (*bind)(struct sock___10 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___10 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___10 *, struct sk_buff___14 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___10 *);
	int (*hash)(struct sock___10 *);
	void (*unhash)(struct sock___10 *);
	void (*rehash)(struct sock___10 *);
	int (*get_port)(struct sock___10 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___10 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___10 *, int);
	bool (*sock_is_readable)(struct sock___10 *);
	void (*enter_memory_pressure)(struct sock___10 *);
	void (*leave_memory_pressure)(struct sock___10 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___63 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___10 *, int);
};

struct lsm_blob_sizes {
	int lbs_cred;
	int lbs_file;
	int lbs_inode;
	int lbs_superblock;
	int lbs_sock;
	int lbs_ipc;
	int lbs_msg_msg;
	int lbs_task;
};

struct bpf_storage_blob {
	struct bpf_local_storage___4 *storage;
};

typedef u64 (*btf_bpf_inode_storage_get)(struct bpf_map___13 *, struct inode___65 *, void *, u64);

typedef u64 (*btf_bpf_inode_storage_delete)(struct bpf_map___13 *, struct inode___65 *);

struct bpf_insn___2 {
	__u8 code;
	__u8 dst_reg;
	__u8 src_reg;
	__s16 off;
	__s32 imm;
};

typedef const char * (*bpf_insn_revmap_call_t___2)(void *, const struct bpf_insn___2 *);

typedef const char * (*bpf_insn_print_imm_t___2)(void *, const struct bpf_insn___2 *, __u64);

struct bpf_insn_cbs___2 {
	bpf_insn_print_t cb_print;
	bpf_insn_revmap_call_t___2 cb_call;
	bpf_insn_print_imm_t___2 cb_imm;
	void *private_data;
};

struct bpf_tramp_progs {
	struct bpf_prog___6 *progs[38];
	int nr_progs;
};

struct btf_enum {
	__u32 name_off;
	__s32 val;
};

struct btf_array {
	__u32 type;
	__u32 index_type;
	__u32 nelems;
};

enum {
	BTF_VAR_STATIC = 0,
	BTF_VAR_GLOBAL_ALLOCATED = 1,
	BTF_VAR_GLOBAL_EXTERN = 2,
};

struct btf_var {
	__u32 linkage;
};

struct bpf_flow_keys {
	__u16 nhoff;
	__u16 thoff;
	__u16 addr_proto;
	__u8 is_frag;
	__u8 is_first_frag;
	__u8 is_encap;
	__u8 ip_proto;
	__be16 n_proto;
	__be16 sport;
	__be16 dport;
	union {
		struct {
			__be32 ipv4_src;
			__be32 ipv4_dst;
		};
		struct {
			__u32 ipv6_src[4];
			__u32 ipv6_dst[4];
		};
	};
	__u32 flags;
	__be32 flow_label;
};

struct bpf_sock {
	__u32 bound_dev_if;
	__u32 family;
	__u32 type;
	__u32 protocol;
	__u32 mark;
	__u32 priority;
	__u32 src_ip4;
	__u32 src_ip6[4];
	__u32 src_port;
	__be16 dst_port;
	__u32 dst_ip4;
	__u32 dst_ip6[4];
	__u32 state;
	__s32 rx_queue_mapping;
};

struct __sk_buff {
	__u32 len;
	__u32 pkt_type;
	__u32 mark;
	__u32 queue_mapping;
	__u32 protocol;
	__u32 vlan_present;
	__u32 vlan_tci;
	__u32 vlan_proto;
	__u32 priority;
	__u32 ingress_ifindex;
	__u32 ifindex;
	__u32 tc_index;
	__u32 cb[5];
	__u32 hash;
	__u32 tc_classid;
	__u32 data;
	__u32 data_end;
	__u32 napi_id;
	__u32 family;
	__u32 remote_ip4;
	__u32 local_ip4;
	__u32 remote_ip6[4];
	__u32 local_ip6[4];
	__u32 remote_port;
	__u32 local_port;
	__u32 data_meta;
	union {
		struct bpf_flow_keys *flow_keys;
	};
	__u64 tstamp;
	__u32 wire_len;
	__u32 gso_segs;
	union {
		struct bpf_sock *sk;
	};
	__u32 gso_size;
};

struct xdp_md {
	__u32 data;
	__u32 data_end;
	__u32 data_meta;
	__u32 ingress_ifindex;
	__u32 rx_queue_index;
	__u32 egress_ifindex;
};

struct sk_msg_md {
	union {
		void *data;
	};
	union {
		void *data_end;
	};
	__u32 family;
	__u32 remote_ip4;
	__u32 local_ip4;
	__u32 remote_ip6[4];
	__u32 local_ip6[4];
	__u32 remote_port;
	__u32 local_port;
	__u32 size;
	union {
		struct bpf_sock *sk;
	};
};

struct sk_reuseport_md {
	union {
		void *data;
	};
	union {
		void *data_end;
	};
	__u32 len;
	__u32 eth_protocol;
	__u32 ip_protocol;
	__u32 bind_inany;
	__u32 hash;
	union {
		struct bpf_sock *sk;
	};
	union {
		struct bpf_sock *migrating_sk;
	};
};

struct bpf_sock_addr {
	__u32 user_family;
	__u32 user_ip4;
	__u32 user_ip6[4];
	__u32 user_port;
	__u32 family;
	__u32 type;
	__u32 protocol;
	__u32 msg_src_ip4;
	__u32 msg_src_ip6[4];
	union {
		struct bpf_sock *sk;
	};
};

struct bpf_sock_ops {
	__u32 op;
	union {
		__u32 args[4];
		__u32 reply;
		__u32 replylong[4];
	};
	__u32 family;
	__u32 remote_ip4;
	__u32 local_ip4;
	__u32 remote_ip6[4];
	__u32 local_ip6[4];
	__u32 remote_port;
	__u32 local_port;
	__u32 is_fullsock;
	__u32 snd_cwnd;
	__u32 srtt_us;
	__u32 bpf_sock_ops_cb_flags;
	__u32 state;
	__u32 rtt_min;
	__u32 snd_ssthresh;
	__u32 rcv_nxt;
	__u32 snd_nxt;
	__u32 snd_una;
	__u32 mss_cache;
	__u32 ecn_flags;
	__u32 rate_delivered;
	__u32 rate_interval_us;
	__u32 packets_out;
	__u32 retrans_out;
	__u32 total_retrans;
	__u32 segs_in;
	__u32 data_segs_in;
	__u32 segs_out;
	__u32 data_segs_out;
	__u32 lost_out;
	__u32 sacked_out;
	__u32 sk_txhash;
	__u64 bytes_received;
	__u64 bytes_acked;
	union {
		struct bpf_sock *sk;
	};
	union {
		void *skb_data;
	};
	union {
		void *skb_data_end;
	};
	__u32 skb_len;
	__u32 skb_tcp_flags;
};

struct bpf_cgroup_dev_ctx {
	__u32 access_type;
	__u32 major;
	__u32 minor;
};

struct bpf_sysctl {
	__u32 write;
	__u32 file_pos;
};

struct bpf_sockopt {
	union {
		struct bpf_sock *sk;
	};
	union {
		void *optval;
	};
	union {
		void *optval_end;
	};
	__s32 level;
	__s32 optname;
	__s32 optlen;
	__s32 retval;
};

struct bpf_sk_lookup {
	union {
		union {
			struct bpf_sock *sk;
		};
		__u64 cookie;
	};
	__u32 family;
	__u32 protocol;
	__u32 remote_ip4;
	__u32 remote_ip6[4];
	__be16 remote_port;
	__u32 local_ip4;
	__u32 local_ip6[4];
	__u32 local_port;
};

struct dentry___66;

struct super_block___66;

struct file_system_type___65 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___66 * (*mount)(struct file_system_type___65 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___66 *);
	struct module___3 *owner;
	struct file_system_type___65 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___65;

struct kiocb___65;

struct iov_iter___36;

struct poll_table_struct___49;

struct vm_area_struct___70;

struct inode___66;

struct file_lock___65;

struct page___70;

struct pipe_inode_info___25;

struct seq_file___63;

struct file_operations___65 {
	struct module___3 *owner;
	loff_t (*llseek)(struct file___65 *, loff_t, int);
	ssize_t (*read)(struct file___65 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___65 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___65 *, struct iov_iter___36 *);
	ssize_t (*write_iter)(struct kiocb___65 *, struct iov_iter___36 *);
	int (*iopoll)(struct kiocb___65 *, bool);
	int (*iterate)(struct file___65 *, struct dir_context *);
	int (*iterate_shared)(struct file___65 *, struct dir_context *);
	__poll_t (*poll)(struct file___65 *, struct poll_table_struct___49 *);
	long int (*unlocked_ioctl)(struct file___65 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___65 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___65 *, struct vm_area_struct___70 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___66 *, struct file___65 *);
	int (*flush)(struct file___65 *, fl_owner_t);
	int (*release)(struct inode___66 *, struct file___65 *);
	int (*fsync)(struct file___65 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___65 *, int);
	int (*lock)(struct file___65 *, int, struct file_lock___65 *);
	ssize_t (*sendpage)(struct file___65 *, struct page___70 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___65 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___65 *, long unsigned int);
	int (*flock)(struct file___65 *, int, struct file_lock___65 *);
	ssize_t (*splice_write)(struct pipe_inode_info___25 *, struct file___65 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___65 *, loff_t *, struct pipe_inode_info___25 *, size_t, unsigned int);
	int (*setlease)(struct file___65 *, long int, struct file_lock___65 **, void **);
	long int (*fallocate)(struct file___65 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___63 *, struct file___65 *);
	ssize_t (*copy_file_range)(struct file___65 *, loff_t, struct file___65 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___65 *, loff_t, struct file___65 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___65 *, loff_t, loff_t, int);
};

struct vmacache___70 {
	u64 seqnum;
	struct vm_area_struct___70 *vmas[4];
};

struct page_frag___70 {
	struct page___70 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___43;

struct debug_info___43 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___43 *hbp_break[16];
	struct perf_event___43 *hbp_watch[16];
};

struct thread_struct___43 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___43 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___71;

struct pid___58;

struct nsproxy___63;

struct signal_struct___66;

struct bio_list___30;

struct backing_dev_info___29;

struct io_context___30;

struct css_set___54;

struct perf_event_context___43;

struct mem_cgroup___27;

struct request_queue___31;

struct vm_struct___66;

struct task_struct___72 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___72 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___71 *mm;
	struct mm_struct___71 *active_mm;
	struct vmacache___70 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___72 *real_parent;
	struct task_struct___72 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___72 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___58 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___63 *nsproxy;
	struct signal_struct___66 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___72 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___30 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___29 *backing_dev_info;
	struct io_context___30 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___54 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___43 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___25 *splice_pipe;
	struct page_frag___70 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___27 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___27 *active_memcg;
	struct request_queue___31 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___72 *oom_reaper_list;
	struct vm_struct___66 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___65;

struct kobj_type___65;

struct kernfs_node___65;

struct kobject___65 {
	const char *name;
	struct list_head entry;
	struct kobject___65 *parent;
	struct kset___65 *kset;
	struct kobj_type___65 *ktype;
	struct kernfs_node___65 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___62 {
	struct kobject___65 kobj;
	struct module___3 *mod;
	struct kobject___65 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___62 {
	struct module___3 *mod;
	struct latch_tree_node node;
};

struct module_layout___62 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___62 mtn;
};

struct module_attribute___62;

struct kernel_param___62;

struct module___3 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___62 mkobj;
	struct module_attribute___62 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___65 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___62 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___62 core_layout;
	struct module_layout___62 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___43 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___72 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___43)(struct perf_event___43 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___43;

struct fasync_struct___65;

struct pid_namespace___58;

struct bpf_prog___13;

struct perf_cgroup___43;

struct perf_event___43 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___43 *group_leader;
	struct pmu___43 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___43 hw;
	struct perf_event_context___43 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___43 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___72 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___65 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___43 *aux_event;
	void (*destroy)(struct perf_event___43 *);
	struct callback_head callback_head;
	struct pid_namespace___58 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___43 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___43 orig_overflow_handler;
	struct bpf_prog___13 *prog;
	u64 bpf_cookie;
	struct trace_event_call___5 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___43 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___65;

struct dentry___66 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___66 *d_parent;
	struct qstr d_name;
	struct inode___66 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___65 *d_op;
	struct super_block___66 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___65;

struct address_space___65 {
	struct inode___66 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___65 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___65;

struct bdi_writeback___29;

struct inode___66 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___65 *i_op;
	struct super_block___66 *i_sb;
	struct address_space___65 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___29 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___65 *i_fop;
		void (*free_inode)(struct inode___66 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___65 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___25 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___65;

struct path___65;

struct dentry_operations___65 {
	int (*d_revalidate)(struct dentry___66 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___66 *, unsigned int);
	int (*d_hash)(const struct dentry___66 *, struct qstr *);
	int (*d_compare)(const struct dentry___66 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___66 *);
	int (*d_init)(struct dentry___66 *);
	void (*d_release)(struct dentry___66 *);
	void (*d_prune)(struct dentry___66 *);
	void (*d_iput)(struct dentry___66 *, struct inode___66 *);
	char * (*d_dname)(struct dentry___66 *, char *, int);
	struct vfsmount___65 * (*d_automount)(struct path___65 *);
	int (*d_manage)(const struct path___65 *, bool);
	struct dentry___66 * (*d_real)(struct dentry___66 *, const struct inode___66 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___65;

struct mem_dqinfo___65 {
	struct quota_format_type___65 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___65;

struct quota_info___65 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___66 *files[3];
	struct mem_dqinfo___65 info[3];
	const struct quota_format_ops___65 *ops[3];
};

struct rcuwait___66 {
	struct task_struct___72 *task;
};

struct percpu_rw_semaphore___66 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___66 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___65 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___66 rw_sem[3];
};

struct shrink_control___27;

struct shrinker___27 {
	long unsigned int (*count_objects)(struct shrinker___27 *, struct shrink_control___27 *);
	long unsigned int (*scan_objects)(struct shrinker___27 *, struct shrink_control___27 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___65;

struct dquot_operations___65;

struct quotactl_ops___65;

struct block_device___31;

struct super_block___66 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___65 *s_type;
	const struct super_operations___65 *s_op;
	const struct dquot_operations___65 *dq_op;
	const struct quotactl_ops___65 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___66 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___31 *s_bdev;
	struct backing_dev_info___29 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___65 s_dquot;
	struct sb_writers___65 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___65 *s_d_op;
	int cleancache_poolid;
	struct shrinker___27 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___65 {
	struct dentry___66 *mnt_root;
	struct super_block___66 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct path___65 {
	struct vfsmount___65 *mnt;
	struct dentry___66 *dentry;
};

struct upid___58 {
	int nr;
	struct pid_namespace___58 *ns;
};

struct pid_namespace___58 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___72 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___58 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___58 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___58 numbers[1];
};

typedef struct page___70 *pgtable_t___70;

struct page_pool___22;

struct dev_pagemap___64;

struct page___70 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___65 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___22 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___70 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___70 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___71 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___64 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___64;

struct vm_area_struct___70 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___70 *vm_next;
	struct vm_area_struct___70 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___71 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___64 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___65 *vm_file;
	struct file___65 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___66 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___72 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___72 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___58 *pids[4];
	struct pid___58 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___71 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___70;

struct mm_struct___71 {
	struct {
		struct vm_area_struct___70 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___65 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___70 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___72 *owner;
		struct user_namespace___10 *user_ns;
		struct file___65 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___16;

struct cgroup_namespace___54;

struct nsproxy___63 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___58 *pid_ns_for_children;
	struct net___16 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___54 *cgroup_ns;
};

struct bio___30;

struct bio_list___30 {
	struct bio___30 *head;
	struct bio___30 *tail;
};

struct cgroup_subsys_state___54;

struct bdi_writeback___29 {
	struct backing_dev_info___29 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___54 *memcg_css;
	struct cgroup_subsys_state___54 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___58;

struct backing_dev_info___29 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___29 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___58 *dev;
	char dev_name[64];
	struct device___58 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___66 *debug_dir;
};

struct io_cq___30;

struct io_context___30 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___30 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___54;

struct css_set___54 {
	struct cgroup_subsys_state___54 *subsys[14];
	refcount_t refcount;
	struct css_set___54 *dom_cset;
	struct cgroup___54 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___54 *mg_src_cgrp;
	struct cgroup___54 *mg_dst_cgrp;
	struct css_set___54 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___43 {
	struct pmu___43 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___72 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___43 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___25;

struct pipe_inode_info___25 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___70 *tmp_page;
	struct fasync_struct___65 *fasync_readers;
	struct fasync_struct___65 *fasync_writers;
	struct pipe_buffer___25 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___54;

struct cgroup_subsys_state___54 {
	struct cgroup___54 *cgroup;
	struct cgroup_subsys___54 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___54 *parent;
};

struct cgroup_file___54 {
	struct kernfs_node___65 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___27;

struct mem_cgroup_per_node___27;

struct mem_cgroup___27 {
	struct cgroup_subsys_state___54 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___54 events_file;
	struct cgroup_file___54 events_local_file;
	struct cgroup_file___54 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___27 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___72 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___27 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___30;

struct blk_integrity___30 {
	const struct blk_integrity_profile___30 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___30 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___30 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___30;

struct elevator_queue___30;

struct blk_mq_ops___29;

struct blk_mq_hw_ctx___29;

struct gendisk___30;

struct blkcg_gq___29;

struct blk_mq_tag_set___29;

struct request_queue___31 {
	struct request___30 *last_merge;
	struct elevator_queue___30 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___29 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___29 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___30 *disk;
	struct kobject___65 kobj;
	struct kobject___65 *mq_kobj;
	struct blk_integrity___30 integrity;
	struct device___58 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___29 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___29 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___30 bio_split;
	struct dentry___66 *debugfs_dir;
	struct dentry___66 *sched_debugfs_dir;
	struct dentry___66 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___66 {
	struct vm_struct___66 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___70 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___27 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___27 *memcg;
};

struct page_pool_params___22 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___58 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___22 {
	u32 count;
	struct page___70 *cache[128];
};

struct page_pool___22 {
	struct page_pool_params___22 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___70 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___22 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___64;

struct dev_pagemap___64 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___64 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___58 {
	rwlock_t lock;
	struct pid___58 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___65 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___65 f_path;
	struct inode___66 *f_inode;
	const struct file_operations___65 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___58 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___65 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___64;

struct vm_operations_struct___64 {
	void (*open)(struct vm_area_struct___70 *);
	void (*close)(struct vm_area_struct___70 *);
	int (*may_split)(struct vm_area_struct___70 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___70 *);
	int (*mprotect)(struct vm_area_struct___70 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___64 *);
	vm_fault_t (*huge_fault)(struct vm_fault___64 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___64 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___70 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___64 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___64 *);
	int (*access)(struct vm_area_struct___70 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___70 *);
	int (*set_policy)(struct vm_area_struct___70 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___70 *, long unsigned int);
	struct page___70 * (*find_special_page)(struct vm_area_struct___70 *, long unsigned int);
};

struct core_thread___70 {
	struct task_struct___72 *task;
	struct core_thread___70 *next;
};

struct core_state___70 {
	atomic_t nr_threads;
	struct core_thread___70 dumper;
	struct completion startup;
};

struct vm_fault___64 {
	const struct {
		struct vm_area_struct___70 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___70 *cow_page;
	struct page___70 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___70 prealloc_pte;
};

struct pglist_data___28;

struct lruvec___28 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___28 *pgdat;
};

struct zone___28 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___28 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___28 {
	struct zone___28 *zone;
	int zone_idx;
};

struct zonelist___28 {
	struct zoneref___28 _zonerefs[321];
};

struct pglist_data___28 {
	struct zone___28 node_zones[5];
	struct zonelist___28 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___72 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___72 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___28 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___54 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___72 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___13;

struct cgroup_bpf___13 {
	struct bpf_prog_array___13 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___13 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___54;

struct cgroup_rstat_cpu___54;

struct cgroup___54 {
	struct cgroup_subsys_state___54 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___65 *kn;
	struct cgroup_file___54 procs_file;
	struct cgroup_file___54 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___54 *subsys[14];
	struct cgroup_root___54 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___54 *dom_cgrp;
	struct cgroup___54 *old_dom_cgrp;
	struct cgroup_rstat_cpu___54 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___54 psi;
	struct cgroup_bpf___13 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___30 {
	struct request_queue___31 *q;
	struct io_context___30 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___65 {
	struct file___65 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___65 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___66 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___65 *ia_file;
};

struct dquot___65 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___66 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___65 {
	int qf_fmt_id;
	const struct quota_format_ops___65 *qf_ops;
	struct module___3 *qf_owner;
	struct quota_format_type___65 *qf_next;
};

struct quota_format_ops___65 {
	int (*check_quota_file)(struct super_block___66 *, int);
	int (*read_file_info)(struct super_block___66 *, int);
	int (*write_file_info)(struct super_block___66 *, int);
	int (*free_file_info)(struct super_block___66 *, int);
	int (*read_dqblk)(struct dquot___65 *);
	int (*commit_dqblk)(struct dquot___65 *);
	int (*release_dqblk)(struct dquot___65 *);
	int (*get_next_id)(struct super_block___66 *, struct kqid *);
};

struct dquot_operations___65 {
	int (*write_dquot)(struct dquot___65 *);
	struct dquot___65 * (*alloc_dquot)(struct super_block___66 *, int);
	void (*destroy_dquot)(struct dquot___65 *);
	int (*acquire_dquot)(struct dquot___65 *);
	int (*release_dquot)(struct dquot___65 *);
	int (*mark_dirty)(struct dquot___65 *);
	int (*write_info)(struct super_block___66 *, int);
	qsize_t * (*get_reserved_space)(struct inode___66 *);
	int (*get_projid)(struct inode___66 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___66 *, qsize_t *);
	int (*get_next_id)(struct super_block___66 *, struct kqid *);
};

struct quotactl_ops___65 {
	int (*quota_on)(struct super_block___66 *, int, int, const struct path___65 *);
	int (*quota_off)(struct super_block___66 *, int);
	int (*quota_enable)(struct super_block___66 *, unsigned int);
	int (*quota_disable)(struct super_block___66 *, unsigned int);
	int (*quota_sync)(struct super_block___66 *, int);
	int (*set_info)(struct super_block___66 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___66 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___66 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___66 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___66 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___66 *, unsigned int);
};

struct writeback_control___29;

struct address_space_operations___65 {
	int (*writepage)(struct page___70 *, struct writeback_control___29 *);
	int (*readpage)(struct file___65 *, struct page___70 *);
	int (*writepages)(struct address_space___65 *, struct writeback_control___29 *);
	int (*set_page_dirty)(struct page___70 *);
	int (*readpages)(struct file___65 *, struct address_space___65 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___65 *, struct address_space___65 *, loff_t, unsigned int, unsigned int, struct page___70 **, void **);
	int (*write_end)(struct file___65 *, struct address_space___65 *, loff_t, unsigned int, unsigned int, struct page___70 *, void *);
	sector_t (*bmap)(struct address_space___65 *, sector_t);
	void (*invalidatepage)(struct page___70 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___70 *, gfp_t);
	void (*freepage)(struct page___70 *);
	ssize_t (*direct_IO)(struct kiocb___65 *, struct iov_iter___36 *);
	int (*migratepage)(struct address_space___65 *, struct page___70 *, struct page___70 *, enum migrate_mode);
	bool (*isolate_page)(struct page___70 *, isolate_mode_t);
	void (*putback_page)(struct page___70 *);
	int (*launder_page)(struct page___70 *);
	int (*is_partially_uptodate)(struct page___70 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___70 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___65 *, struct page___70 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___65 *, sector_t *);
	void (*swap_deactivate)(struct file___65 *);
};

struct writeback_control___29 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___29 *wb;
	struct inode___66 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___36;

struct iov_iter___36 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___36 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___25 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___65 {
	struct dentry___66 * (*lookup)(struct inode___66 *, struct dentry___66 *, unsigned int);
	const char * (*get_link)(struct dentry___66 *, struct inode___66 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___66 *, int);
	struct posix_acl * (*get_acl)(struct inode___66 *, int, bool);
	int (*readlink)(struct dentry___66 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___66 *, struct dentry___66 *, umode_t, bool);
	int (*link)(struct dentry___66 *, struct inode___66 *, struct dentry___66 *);
	int (*unlink)(struct inode___66 *, struct dentry___66 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___66 *, struct dentry___66 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___66 *, struct dentry___66 *, umode_t);
	int (*rmdir)(struct inode___66 *, struct dentry___66 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___66 *, struct dentry___66 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___66 *, struct dentry___66 *, struct inode___66 *, struct dentry___66 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___66 *, struct iattr___66 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___65 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___66 *, char *, size_t);
	int (*fiemap)(struct inode___66 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___66 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___66 *, struct dentry___66 *, struct file___65 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___66 *, struct dentry___66 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___66 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___66 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___66 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___65 {
	void (*fl_copy_lock)(struct file_lock___65 *, struct file_lock___65 *);
	void (*fl_release_private)(struct file_lock___65 *);
};

struct lock_manager_operations___65;

struct file_lock___65 {
	struct file_lock___65 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___65 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___65 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___65 *fl_ops;
	const struct lock_manager_operations___65 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___65 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___65 *);
	int (*lm_grant)(struct file_lock___65 *, int);
	bool (*lm_break)(struct file_lock___65 *);
	int (*lm_change)(struct file_lock___65 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___65 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___65 *);
};

struct fasync_struct___65 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___65 *fa_next;
	struct file___65 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___65 {
	struct inode___66 * (*alloc_inode)(struct super_block___66 *);
	void (*destroy_inode)(struct inode___66 *);
	void (*free_inode)(struct inode___66 *);
	void (*dirty_inode)(struct inode___66 *, int);
	int (*write_inode)(struct inode___66 *, struct writeback_control___29 *);
	int (*drop_inode)(struct inode___66 *);
	void (*evict_inode)(struct inode___66 *);
	void (*put_super)(struct super_block___66 *);
	int (*sync_fs)(struct super_block___66 *, int);
	int (*freeze_super)(struct super_block___66 *);
	int (*freeze_fs)(struct super_block___66 *);
	int (*thaw_super)(struct super_block___66 *);
	int (*unfreeze_fs)(struct super_block___66 *);
	int (*statfs)(struct dentry___66 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___66 *, int *, char *);
	void (*umount_begin)(struct super_block___66 *);
	int (*show_options)(struct seq_file___63 *, struct dentry___66 *);
	int (*show_devname)(struct seq_file___63 *, struct dentry___66 *);
	int (*show_path)(struct seq_file___63 *, struct dentry___66 *);
	int (*show_stats)(struct seq_file___63 *, struct dentry___66 *);
	ssize_t (*quota_read)(struct super_block___66 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___66 *, int, const char *, size_t, loff_t);
	struct dquot___65 ** (*get_dquots)(struct inode___66 *);
	long int (*nr_cached_objects)(struct super_block___66 *, struct shrink_control___27 *);
	long int (*free_cached_objects)(struct super_block___66 *, struct shrink_control___27 *);
	struct file___65 * (*real_loop)(struct file___65 *);
};

struct wakeup_source___58;

struct dev_pm_info___58 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___58 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___58 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___58;

struct bus_type___58;

struct device_driver___58;

struct dev_pm_domain___58;

struct fwnode_handle___58;

struct class___58;

struct attribute_group___65;

struct device___58 {
	struct kobject___65 kobj;
	struct device___58 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___58 *type;
	struct bus_type___58 *bus;
	struct device_driver___58 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___58 power;
	struct dev_pm_domain___58 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___58 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___58 *class;
	const struct attribute_group___65 **groups;
	void (*release)(struct device___58 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___31 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___66 *bd_inode;
	struct super_block___66 *bd_super;
	void *bd_claiming;
	struct device___58 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___65 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___30 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___66 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___49)(struct file___65 *, wait_queue_head_t *, struct poll_table_struct___49 *);

struct poll_table_struct___49 {
	poll_queue_proc___49 _qproc;
	__poll_t _key;
};

struct seq_operations___63;

struct seq_file___63 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___63 *op;
	int poll_event;
	const struct file___65 *file;
	void *private;
};

typedef void bio_end_io_t___30(struct bio___30 *);

struct bio_vec___36 {
	struct page___70 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___30;

struct bio___30 {
	struct bio___30 *bi_next;
	struct block_device___31 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___30 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___29 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___30 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___36 *bi_io_vec;
	struct bio_set___30 *bi_pool;
	struct bio_vec___36 bi_inline_vecs[0];
};

struct seq_operations___63 {
	void * (*start)(struct seq_file___63 *, loff_t *);
	void (*stop)(struct seq_file___63 *, void *);
	void * (*next)(struct seq_file___63 *, void *, loff_t *);
	int (*show)(struct seq_file___63 *, void *);
};

struct fd___8 {
	struct file___65 *file;
	unsigned int flags;
};

struct kernfs_root___65;

struct kernfs_elem_dir___65 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___65 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___65;

struct kernfs_root___65 {
	struct kernfs_node___65 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___65 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___65 {
	struct kernfs_node___65 *target_kn;
};

struct kernfs_ops___65;

struct kernfs_elem_attr___65 {
	const struct kernfs_ops___65 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___65 *notify_next;
};

struct kernfs_node___65 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___65 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___65 dir;
		struct kernfs_elem_symlink___65 symlink;
		struct kernfs_elem_attr___65 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___65;

struct kernfs_ops___65 {
	int (*open)(struct kernfs_open_file___65 *);
	void (*release)(struct kernfs_open_file___65 *);
	int (*seq_show)(struct seq_file___63 *, void *);
	void * (*seq_start)(struct seq_file___63 *, loff_t *);
	void * (*seq_next)(struct seq_file___63 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___63 *, void *);
	ssize_t (*read)(struct kernfs_open_file___65 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___65 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___65 *, struct poll_table_struct___49 *);
	int (*mmap)(struct kernfs_open_file___65 *, struct vm_area_struct___70 *);
};

struct kernfs_syscall_ops___65 {
	int (*show_options)(struct seq_file___63 *, struct kernfs_root___65 *);
	int (*mkdir)(struct kernfs_node___65 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___65 *);
	int (*rename)(struct kernfs_node___65 *, struct kernfs_node___65 *, const char *);
	int (*show_path)(struct seq_file___63 *, struct kernfs_node___65 *, struct kernfs_root___65 *);
};

struct kernfs_open_file___65 {
	struct kernfs_node___65 *kn;
	struct file___65 *file;
	struct seq_file___63 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___64 *vm_ops;
};

struct kobj_ns_type_operations___9 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___2 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___16 *net;
} possible_net_t___13;

struct proto___9;

struct sock_common___9 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___9 *skc_prot;
	possible_net_t___13 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___2 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___15;

struct sk_buff_head___13 {
	struct sk_buff___15 *next;
	struct sk_buff___15 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___9 {
	struct cgroup___54 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___9;

struct socket_wq___9;

struct dst_entry___9;

struct socket___9;

struct net_device___18;

struct sock_reuseport___2;

struct sock___2 {
	struct sock_common___9 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___13 sk_error_queue;
	struct sk_buff___15 *sk_rx_skb_cache;
	struct sk_buff_head___13 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___15 *head;
		struct sk_buff___15 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___9 *sk_filter;
	union {
		struct socket_wq___9 *sk_wq;
		struct socket_wq___9 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___9 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___9 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___15 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___15 *sk_tx_skb_cache;
	struct sk_buff_head___13 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___70 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___9 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___58 *sk_peer_pid;
	const struct cred___9 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___9 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___9 sk_cgrp_data;
	struct mem_cgroup___27 *sk_memcg;
	void (*sk_state_change)(struct sock___2 *);
	void (*sk_data_ready)(struct sock___2 *);
	void (*sk_write_space)(struct sock___2 *);
	void (*sk_error_report)(struct sock___2 *);
	int (*sk_backlog_rcv)(struct sock___2 *, struct sk_buff___15 *);
	struct sk_buff___15 * (*sk_validate_xmit_skb)(struct sock___2 *, struct net_device___18 *, struct sk_buff___15 *);
	void (*sk_destruct)(struct sock___2 *);
	struct sock_reuseport___2 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___65;

struct attribute_group___65 {
	const char *name;
	umode_t (*is_visible)(struct kobject___65 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___65 *, struct bin_attribute___65 *, int);
	struct attribute **attrs;
	struct bin_attribute___65 **bin_attrs;
};

struct bin_attribute___65 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___65 * (*f_mapping)();
	ssize_t (*read)(struct file___65 *, struct kobject___65 *, struct bin_attribute___65 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___65 *, struct kobject___65 *, struct bin_attribute___65 *, char *, loff_t, size_t);
	int (*mmap)(struct file___65 *, struct kobject___65 *, struct bin_attribute___65 *, struct vm_area_struct___70 *);
};

struct sysfs_ops___65 {
	ssize_t (*show)(struct kobject___65 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___65 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___65;

struct kset___65 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___65 kobj;
	const struct kset_uevent_ops___65 *uevent_ops;
};

struct kobj_type___65 {
	void (*release)(struct kobject___65 *);
	const struct sysfs_ops___65 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___65 **default_groups;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___65 *);
	const void * (*namespace)(struct kobject___65 *);
	void (*get_ownership)(struct kobject___65 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___65 {
	int (* const filter)(struct kset___65 *, struct kobject___65 *);
	const char * (* const name)(struct kset___65 *, struct kobject___65 *);
	int (* const uevent)(struct kset___65 *, struct kobject___65 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___62 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___62 *);
	int (*get)(char *, const struct kernel_param___62 *);
	void (*free)(void *);
};

struct kparam_array___62;

struct kernel_param___62 {
	const char *name;
	struct module___3 *mod;
	const struct kernel_param_ops___62 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___62 *arr;
	};
};

struct kparam_array___62 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___62 *ops;
	void *elem;
};

struct module_attribute___62 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___62 *, struct module_kobject___62 *, char *);
	ssize_t (*store)(struct module_attribute___62 *, struct module_kobject___62 *, const char *, size_t);
	void (*setup)(struct module___3 *, const char *);
	int (*test)(struct module___3 *);
	void (*free)(struct module___3 *);
};

struct dev_pagemap_ops___64 {
	void (*page_free)(struct page___70 *);
	void (*kill)(struct dev_pagemap___64 *);
	void (*cleanup)(struct dev_pagemap___64 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___64 *);
};

struct bpf_iter_aux_info___14;

typedef int (*bpf_iter_init_seq_priv_t___14)(void *, struct bpf_iter_aux_info___14 *);

struct bpf_map___14;

struct bpf_iter_aux_info___14 {
	struct bpf_map___14 *map;
};

struct bpf_iter_seq_info___14 {
	const struct seq_operations___63 *seq_ops;
	bpf_iter_init_seq_priv_t___14 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___14;

struct bpf_verifier_env___3;

struct bpf_func_state___3;

struct bpf_map_ops___14 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___14 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___14 *, struct file___65 *);
	void (*map_free)(struct bpf_map___14 *);
	int (*map_get_next_key)(struct bpf_map___14 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___14 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___14 *, void *);
	int (*map_lookup_batch)(struct bpf_map___14 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___14 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___14 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___14 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___14 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___14 *, void *);
	int (*map_update_elem)(struct bpf_map___14 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___14 *, void *);
	int (*map_push_elem)(struct bpf_map___14 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___14 *, void *);
	int (*map_peek_elem)(struct bpf_map___14 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___14 *, struct file___65 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___14 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___14 *, void *, struct seq_file___63 *);
	int (*map_check_btf)(const struct bpf_map___14 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___14 *, struct bpf_prog_aux___14 *);
	void (*map_poke_untrack)(struct bpf_map___14 *, struct bpf_prog_aux___14 *);
	void (*map_poke_run)(struct bpf_map___14 *, u32, struct bpf_prog___13 *, struct bpf_prog___13 *);
	int (*map_direct_value_addr)(const struct bpf_map___14 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___14 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___14 *, struct vm_area_struct___70 *);
	__poll_t (*map_poll)(struct bpf_map___14 *, struct file___65 *, struct poll_table_struct___49 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___14 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___14 *, const struct bpf_map___14 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env___3 *, struct bpf_func_state___3 *, struct bpf_func_state___3 *);
	int (*map_for_each_callback)(struct bpf_map___14 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___14 *iter_seq_info;
};

struct bpf_map___14 {
	const struct bpf_map_ops___14 *ops;
	struct bpf_map___14 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___27 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___14;

struct bpf_jit_poke_descriptor___14;

struct bpf_prog_ops___13;

struct btf_mod_pair___14;

struct bpf_prog_offload___13;

struct bpf_prog_aux___14 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___13 *dst_prog;
	struct bpf_trampoline___14 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___13 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___14 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___13 *ops;
	struct bpf_map___14 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___14 *used_btfs;
	struct bpf_prog___13 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___14 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___13 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___13 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___14 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct btf_mod_pair___14 {
	struct btf *btf;
	struct module___3 *module;
};

struct bpf_verifier_ops___4;

struct bpf_verifier_state___3;

struct bpf_verifier_state_list___3;

struct bpf_verifier_env___3 {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___13 *prog;
	const struct bpf_verifier_ops___4 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	bool test_state_freq;
	struct bpf_verifier_state___3 *cur_state;
	struct bpf_verifier_state_list___3 **explored_states;
	struct bpf_verifier_state_list___3 *free_list;
	struct bpf_map___14 *used_maps[64];
	struct btf_mod_pair___14 used_btfs[64];
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 id_gen;
	bool explore_alu_limits;
	bool allow_ptr_leaks;
	bool allow_uninit_stack;
	bool allow_ptr_to_map_access;
	bool bpf_capable;
	bool bypass_spec_v1;
	bool bypass_spec_v4;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	struct bpf_id_pair idmap_scratch[75];
	struct {
		int *insn_state;
		int *insn_stack;
		int cur_stack;
	} cfg;
	u32 pass_cnt;
	u32 subprog_cnt;
	u32 prev_insn_processed;
	u32 insn_processed;
	u32 prev_jmps_processed;
	u32 jmps_processed;
	u64 verification_time;
	u32 max_states_per_insn;
	u32 total_states;
	u32 peak_states;
	u32 longest_mark_read_walk;
	bpfptr_t fd_array;
};

struct bpf_reg_state___3 {
	enum bpf_reg_type type;
	s32 off;
	union {
		int range;
		struct {
			struct bpf_map___14 *map_ptr;
			u32 map_uid;
		};
		struct {
			struct btf *btf;
			u32 btf_id;
		};
		u32 mem_size;
		struct {
			long unsigned int raw1;
			long unsigned int raw2;
		} raw;
		u32 subprogno;
	};
	u32 id;
	u32 ref_obj_id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	s32 s32_min_value;
	s32 s32_max_value;
	u32 u32_min_value;
	u32 u32_max_value;
	struct bpf_reg_state___3 *parent;
	u32 frameno;
	s32 subreg_def;
	enum bpf_reg_liveness live;
	bool precise;
};

struct bpf_stack_state___3;

struct bpf_func_state___3 {
	struct bpf_reg_state___3 regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	u32 async_entry_cnt;
	bool in_callback_fn;
	bool in_async_callback_fn;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state___3 *stack;
};

struct bpf_offloaded_map___13;

struct bpf_map_dev_ops___13 {
	int (*map_get_next_key)(struct bpf_offloaded_map___13 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___13 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___13 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___13 *, void *);
};

struct bpf_offloaded_map___13 {
	struct bpf_map___14 map;
	struct net_device___18 *netdev;
	const struct bpf_map_dev_ops___13 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___13(struct sk_buff___15 **);

struct bpf_xdp_entity___13 {
	struct bpf_prog___13 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___13;

struct net_device_ops___13;

struct l3mdev_ops___9;

struct ndisc_ops___4;

struct xfrmdev_ops___13;

struct header_ops___13;

struct inet6_dev___4;

struct netdev_rx_queue___13;

struct mini_Qdisc___13;

struct netdev_queue___13;

struct Qdisc___13;

struct rtnl_link_ops___13;

struct dcbnl_rtnl_ops___13;

struct net_device___18 {
	char name[16];
	struct netdev_name_node___13 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___13 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___9 *l3mdev_ops;
	const struct ndisc_ops___4 *ndisc_ops;
	const struct xfrmdev_ops___13 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___13 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___65 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___4 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___13 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___13 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___13 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___13 *miniq_ingress;
	struct netdev_queue___13 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___13 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___13 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___13 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___13 = 0,
		NETREG_REGISTERED___13 = 1,
		NETREG_UNREGISTERING___13 = 2,
		NETREG_UNREGISTERED___13 = 3,
		NETREG_RELEASED___13 = 4,
		NETREG_DUMMY___13 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___13 = 0,
		RTNL_LINK_INITIALIZING___13 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___18 *);
	struct netpoll_info *npinfo;
	possible_net_t___13 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___58 dev;
	const struct attribute_group___65 *sysfs_groups[4];
	const struct attribute_group___65 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___13 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___13 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___13 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___8 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___13 *);
};

struct bpf_prog_ops___13 {
	int (*test_run)(struct bpf_prog___13 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___4 {
	const struct bpf_func_proto___8 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___13 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___13 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___13 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___13 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___13 {
	struct bpf_prog___13 *prog;
	struct net_device___18 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___14 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___13 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___3 *mod;
};

struct bpf_jit_poke_descriptor___14 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___14 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct bpf_prog_array_item___13 {
	struct bpf_prog___13 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___13 {
	struct callback_head rcu;
	struct bpf_prog_array_item___13 items[0];
};

struct sk_reuseport_kern {
	struct sk_buff___15 *skb;
	struct sock___2 *sk;
	struct sock___2 *selected_sk;
	struct sock___2 *migrating_sk;
	void *data_end;
	u32 hash;
	u32 reuseport_id;
	bool bind_inany;
};

struct sk_buff___15 {
	union {
		struct {
			struct sk_buff___15 *next;
			struct sk_buff___15 *prev;
			union {
				struct net_device___18 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___2 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___15 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct msghdr___9 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___36 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___65 *msg_iocb;
};

struct fwnode_operations___58;

struct fwnode_handle___58 {
	struct fwnode_handle___58 *secondary;
	const struct fwnode_operations___58 *ops;
	struct device___58 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___58;

struct fwnode_endpoint___58;

struct fwnode_operations___58 {
	struct fwnode_handle___58 * (*get)(struct fwnode_handle___58 *);
	void (*put)(struct fwnode_handle___58 *);
	bool (*device_is_available)(const struct fwnode_handle___58 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___58 *, const struct device___58 *);
	bool (*property_present)(const struct fwnode_handle___58 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___58 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___58 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___58 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*get_parent)(const struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*get_next_child_node)(const struct fwnode_handle___58 *, struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*get_named_child_node)(const struct fwnode_handle___58 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___58 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___58 *);
	struct fwnode_handle___58 * (*graph_get_next_endpoint)(const struct fwnode_handle___58 *, struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*graph_get_remote_endpoint)(const struct fwnode_handle___58 *);
	struct fwnode_handle___58 * (*graph_get_port_parent)(struct fwnode_handle___58 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___58 *, struct fwnode_endpoint___58 *);
	int (*add_links)(struct fwnode_handle___58 *);
};

struct fwnode_endpoint___58 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___58 *local_fwnode;
};

struct fwnode_reference_args___58 {
	struct fwnode_handle___58 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___9;

struct fqdir___15;

struct fib_notifier_ops___9;

struct netns_ipv4___15 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___9 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___2 *fibnl;
	struct sock___2 **icmp_sk;
	struct sock___2 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___2 **tcp_sk;
	struct fqdir___15 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___9 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___9 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___9 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___9;

struct dst_ops___15 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___15 *);
	struct dst_entry___9 * (*check)(struct dst_entry___9 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___9 *);
	unsigned int (*mtu)(const struct dst_entry___9 *);
	u32 * (*cow_metrics)(struct dst_entry___9 *, long unsigned int);
	void (*destroy)(struct dst_entry___9 *);
	void (*ifdown)(struct dst_entry___9 *, struct net_device___18 *, int);
	struct dst_entry___9 * (*negative_advice)(struct dst_entry___9 *);
	void (*link_failure)(struct sk_buff___15 *);
	void (*update_pmtu)(struct dst_entry___9 *, struct sock___2 *, struct sk_buff___15 *, u32, bool);
	void (*redirect)(struct dst_entry___9 *, struct sock___2 *, struct sk_buff___15 *);
	int (*local_out)(struct net___16 *, struct sock___2 *, struct sk_buff___15 *);
	struct neighbour___9 * (*neigh_lookup)(const struct dst_entry___9 *, struct sk_buff___15 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___9 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___15 {
	struct dst_ops___15 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___15 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___9 *fib6_rules_ops;
	struct sock___2 **icmp_sk;
	struct sock___2 *ndisc_sk;
	struct sock___2 *tcp_sk;
	struct sock___2 *igmp_sk;
	struct sock___2 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___9 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___9 *notifier_ops;
	struct fib_notifier_ops___9 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___15 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___15 *fqdir;
};

struct netns_sctp___9 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___2 *ctl_sock;
	struct sock___2 *udp4_sock;
	struct sock___2 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___13 {
	struct bpf_prog_array___13 *run_array[2];
	struct bpf_prog___13 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___15 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___2 *nlsk;
	struct sock___2 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___15 xfrm4_dst_ops;
	struct dst_ops___15 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___16 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___2 *rtnl;
	struct sock___2 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___18 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___15 ipv4;
	struct netns_ipv6___15 ipv6;
	struct netns_ieee802154_lowpan___15 ieee802154_lowpan;
	struct netns_sctp___9 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___13 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___13 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___15 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___2 *crypto_nlsk;
	struct sock___2 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___54 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___54 *root_cset;
};

struct socket_wq___9 {
	wait_queue_head_t wait;
	struct fasync_struct___65 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___9;

struct socket___9 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___65 *file;
	struct sock___2 *sk;
	const struct proto_ops___9 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___9 wq;
};

typedef int (*sk_read_actor_t___9)(read_descriptor_t *, struct sk_buff___15 *, unsigned int, size_t);

struct proto_ops___9 {
	int family;
	struct module___3 *owner;
	int (*release)(struct socket___9 *);
	int (*bind)(struct socket___9 *, struct sockaddr *, int);
	int (*connect)(struct socket___9 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___9 *, struct socket___9 *);
	int (*accept)(struct socket___9 *, struct socket___9 *, int, bool);
	int (*getname)(struct socket___9 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___65 *, struct socket___9 *, struct poll_table_struct___49 *);
	int (*ioctl)(struct socket___9 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___9 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___9 *, void *, bool, bool);
	int (*listen)(struct socket___9 *, int);
	int (*shutdown)(struct socket___9 *, int);
	int (*setsockopt)(struct socket___9 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___9 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___63 *, struct socket___9 *);
	int (*sendmsg)(struct socket___9 *, struct msghdr___9 *, size_t);
	int (*recvmsg)(struct socket___9 *, struct msghdr___9 *, size_t, int);
	int (*mmap)(struct file___65 *, struct socket___9 *, struct vm_area_struct___70 *);
	ssize_t (*sendpage)(struct socket___9 *, struct page___70 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___9 *, loff_t *, struct pipe_inode_info___25 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___2 *, int);
	int (*peek_len)(struct socket___9 *);
	int (*read_sock)(struct sock___2 *, read_descriptor_t *, sk_read_actor_t___9);
	int (*sendpage_locked)(struct sock___2 *, struct page___70 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___2 *, struct msghdr___9 *, size_t);
	int (*set_rcvlowat)(struct sock___2 *, int);
};

struct dev_pm_ops___58 {
	int (*prepare)(struct device___58 *);
	void (*complete)(struct device___58 *);
	int (*suspend)(struct device___58 *);
	int (*resume)(struct device___58 *);
	int (*freeze)(struct device___58 *);
	int (*thaw)(struct device___58 *);
	int (*poweroff)(struct device___58 *);
	int (*restore)(struct device___58 *);
	int (*suspend_late)(struct device___58 *);
	int (*resume_early)(struct device___58 *);
	int (*freeze_late)(struct device___58 *);
	int (*thaw_early)(struct device___58 *);
	int (*poweroff_late)(struct device___58 *);
	int (*restore_early)(struct device___58 *);
	int (*suspend_noirq)(struct device___58 *);
	int (*resume_noirq)(struct device___58 *);
	int (*freeze_noirq)(struct device___58 *);
	int (*thaw_noirq)(struct device___58 *);
	int (*poweroff_noirq)(struct device___58 *);
	int (*restore_noirq)(struct device___58 *);
	int (*runtime_suspend)(struct device___58 *);
	int (*runtime_resume)(struct device___58 *);
	int (*runtime_idle)(struct device___58 *);
};

struct wakeup_source___58 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___58 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___58 {
	struct dev_pm_ops___58 ops;
	int (*start)(struct device___58 *);
	void (*detach)(struct device___58 *, bool);
	int (*activate)(struct device___58 *);
	void (*sync)(struct device___58 *);
	void (*dismiss)(struct device___58 *);
};

struct bus_type___58 {
	const char *name;
	const char *dev_name;
	struct device___58 *dev_root;
	const struct attribute_group___65 **bus_groups;
	const struct attribute_group___65 **dev_groups;
	const struct attribute_group___65 **drv_groups;
	int (*match)(struct device___58 *, struct device_driver___58 *);
	int (*uevent)(struct device___58 *, struct kobj_uevent_env *);
	int (*probe)(struct device___58 *);
	void (*sync_state)(struct device___58 *);
	void (*remove)(struct device___58 *);
	void (*shutdown)(struct device___58 *);
	int (*online)(struct device___58 *);
	int (*offline)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	int (*num_vf)(struct device___58 *);
	int (*dma_configure)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___58 {
	const char *name;
	struct bus_type___58 *bus;
	struct module___3 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___58 *);
	void (*sync_state)(struct device___58 *);
	int (*remove)(struct device___58 *);
	void (*shutdown)(struct device___58 *);
	int (*suspend)(struct device___58 *, pm_message_t);
	int (*resume)(struct device___58 *);
	const struct attribute_group___65 **groups;
	const struct attribute_group___65 **dev_groups;
	const struct dev_pm_ops___58 *pm;
	void (*coredump)(struct device___58 *);
	struct driver_private *p;
};

struct device_type___58 {
	const char *name;
	const struct attribute_group___65 **groups;
	int (*uevent)(struct device___58 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___58 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___58 *);
	const struct dev_pm_ops___58 *pm;
};

struct class___58 {
	const char *name;
	struct module___3 *owner;
	const struct attribute_group___65 **class_groups;
	const struct attribute_group___65 **dev_groups;
	struct kobject___65 *dev_kobj;
	int (*dev_uevent)(struct device___58 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___58 *, umode_t *);
	void (*class_release)(struct class___58 *);
	void (*dev_release)(struct device___58 *);
	int (*shutdown_pre)(struct device___58 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___58 *);
	void (*get_ownership)(struct device___58 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___58 *pm;
	struct subsys_private *p;
};

struct bpf_flow_dissector {
	struct bpf_flow_keys *flow_keys;
	const struct sk_buff___15 *skb;
	const void *data;
	const void *data_end;
};

struct pipe_buf_operations___25;

struct pipe_buffer___25 {
	struct page___70 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___25 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___25 {
	int (*confirm)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
	void (*release)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
	bool (*try_steal)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
	bool (*get)(struct pipe_inode_info___25 *, struct pipe_buffer___25 *);
};

struct inet_frags___15;

struct fqdir___15 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___15 *f;
	struct net___16 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___15;

struct inet_frags___15 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___15 *, const void *);
	void (*destructor)(struct inet_frag_queue___15 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___15 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___15 *fragments_tail;
	struct sk_buff___15 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___15 *fqdir;
	struct callback_head rcu;
};

struct inet_listen_hashbucket {
	spinlock_t lock;
	unsigned int count;
	union {
		struct hlist_head head;
		struct hlist_nulls_head nulls_head;
	};
};

struct inet_ehash_bucket;

struct inet_bind_hashbucket;

struct inet_hashinfo {
	struct inet_ehash_bucket *ehash;
	spinlock_t *ehash_locks;
	unsigned int ehash_mask;
	unsigned int ehash_locks_mask;
	struct kmem_cache *bind_bucket_cachep;
	struct inet_bind_hashbucket *bhash;
	unsigned int bhash_size;
	unsigned int lhash2_mask;
	struct inet_listen_hashbucket *lhash2;
	long: 64;
	struct inet_listen_hashbucket listening_hash[32];
};

struct ip_ra_chain {
	struct ip_ra_chain *next;
	struct sock___2 *sk;
	union {
		void (*destructor)(struct sock___2 *);
		struct sock___2 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___9;

struct fib_lookup_arg___9;

struct fib_rules_ops___9 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___9 *, struct flowi *, int, struct fib_lookup_arg___9 *);
	bool (*suppress)(struct fib_rule___9 *, int, struct fib_lookup_arg___9 *);
	int (*match)(struct fib_rule___9 *, struct flowi *, int);
	int (*configure)(struct fib_rule___9 *, struct sk_buff___15 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___9 *);
	int (*compare)(struct fib_rule___9 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___9 *, struct sk_buff___15 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___9 *);
	void (*flush_cache)(struct fib_rules_ops___9 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___3 *owner;
	struct net___16 *fro_net;
	struct callback_head rcu;
};

struct fib_table {
	struct hlist_node tb_hlist;
	u32 tb_id;
	int tb_num_default;
	struct callback_head rcu;
	long unsigned int *tb_data;
	long unsigned int __data[0];
};

struct inet_peer_base {
	struct rb_root rb_root;
	seqlock_t lock;
	int total;
};

struct tcp_fastopen_context {
	siphash_key_t___2 key[2];
	int num;
	struct callback_head rcu;
};

struct fib_notifier_ops___9 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___16 *);
	int (*fib_dump)(struct net___16 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___3 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___2;

struct dst_entry___9 {
	struct net_device___18 *dev;
	struct dst_ops___15 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___15 *);
	int (*output)(struct net___16 *, struct sock___2 *, struct sk_buff___15 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___2 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___9;

struct neigh_parms___9;

struct neigh_ops___9;

struct neighbour___9 {
	struct neighbour___9 *next;
	struct neigh_table___9 *tbl;
	struct neigh_parms___9 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___13 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___9 *, struct sk_buff___15 *);
	const struct neigh_ops___9 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___18 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___13 {
	int (*ieee_getets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___18 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___18 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___18 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___18 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___18 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___18 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___18 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___18 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___18 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___18 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___18 *);
	u8 (*setstate)(struct net_device___18 *, u8);
	void (*getpermhwaddr)(struct net_device___18 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___18 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___18 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___18 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___18 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___18 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___18 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___18 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___18 *, int, u8 *);
	void (*setpfccfg)(struct net_device___18 *, int, u8);
	void (*getpfccfg)(struct net_device___18 *, int, u8 *);
	u8 (*setall)(struct net_device___18 *);
	u8 (*getcap)(struct net_device___18 *, int, u8 *);
	int (*getnumtcs)(struct net_device___18 *, int, u8 *);
	int (*setnumtcs)(struct net_device___18 *, int, u8);
	u8 (*getpfcstate)(struct net_device___18 *);
	void (*setpfcstate)(struct net_device___18 *, u8);
	void (*getbcncfg)(struct net_device___18 *, int, u32 *);
	void (*setbcncfg)(struct net_device___18 *, int, u32);
	void (*getbcnrp)(struct net_device___18 *, int, u8 *);
	void (*setbcnrp)(struct net_device___18 *, int, u8);
	int (*setapp)(struct net_device___18 *, u8, u16, u8);
	int (*getapp)(struct net_device___18 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___18 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___18 *, int, u8);
	u8 (*getdcbx)(struct net_device___18 *);
	u8 (*setdcbx)(struct net_device___18 *, u8);
	int (*peer_getappinfo)(struct net_device___18 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___18 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___18 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___18 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___18 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___18 *, struct dcbnl_buffer *);
};

struct cftype___54;

struct cgroup_subsys___54 {
	struct cgroup_subsys_state___54 * (*css_alloc)(struct cgroup_subsys_state___54 *);
	int (*css_online)(struct cgroup_subsys_state___54 *);
	void (*css_offline)(struct cgroup_subsys_state___54 *);
	void (*css_released)(struct cgroup_subsys_state___54 *);
	void (*css_free)(struct cgroup_subsys_state___54 *);
	void (*css_reset)(struct cgroup_subsys_state___54 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___54 *, int);
	int (*css_extra_stat_show)(struct seq_file___63 *, struct cgroup_subsys_state___54 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___72 *, struct css_set___54 *);
	void (*cancel_fork)(struct task_struct___72 *, struct css_set___54 *);
	void (*fork)(struct task_struct___72 *);
	void (*exit)(struct task_struct___72 *);
	void (*release)(struct task_struct___72 *);
	void (*bind)(struct cgroup_subsys_state___54 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___54 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___54 *dfl_cftypes;
	struct cftype___54 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___54 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___54 *updated_children;
	struct cgroup___54 *updated_next;
};

struct cgroup_root___54 {
	struct kernfs_root___65 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___54 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___54 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___54 *ss;
	struct list_head node;
	struct kernfs_ops___65 *kf_ops;
	int (*open)(struct kernfs_open_file___65 *);
	void (*release)(struct kernfs_open_file___65 *);
	u64 (*read_u64)(struct cgroup_subsys_state___54 *, struct cftype___54 *);
	s64 (*read_s64)(struct cgroup_subsys_state___54 *, struct cftype___54 *);
	int (*seq_show)(struct seq_file___63 *, void *);
	void * (*seq_start)(struct seq_file___63 *, loff_t *);
	void * (*seq_next)(struct seq_file___63 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___63 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___54 *, struct cftype___54 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___54 *, struct cftype___54 *, s64);
	ssize_t (*write)(struct kernfs_open_file___65 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___65 *, struct poll_table_struct___49 *);
};

struct xdp_rxq_info___13 {
	struct net_device___18 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___13 {
	struct net_device___18 *dev;
};

struct xdp_buff___13 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___13 *rxq;
	struct xdp_txq_info___13 *txq;
	u32 frame_sz;
};

struct xdp_frame___13 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___18 *dev_rx;
};

struct netlink_callback___13 {
	struct sk_buff___15 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___15 *, struct netlink_callback___13 *);
	int (*done)(struct netlink_callback___13 *);
	void *data;
	struct module___3 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___13 {
	int (*create)(struct sk_buff___15 *, struct net_device___18 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___15 *, unsigned char *);
	int (*cache)(const struct neighbour___9 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___18 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___15 *);
};

struct netdev_queue___13 {
	struct net_device___18 *dev;
	struct Qdisc___13 *qdisc;
	struct Qdisc___13 *qdisc_sleeping;
	struct kobject___65 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___18 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___13 {
	struct sk_buff___15 *head;
	struct sk_buff___15 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___13;

struct Qdisc___13 {
	int (*enqueue)(struct sk_buff___15 *, struct Qdisc___13 *, struct sk_buff___15 **);
	struct sk_buff___15 * (*dequeue)(struct Qdisc___13 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___13 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___13 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___13 gso_skb;
	struct qdisc_skb_head___13 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___13 *next_sched;
	struct sk_buff_head___13 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___13 {
	struct xdp_rxq_info___13 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___65 kobj;
	struct net_device___18 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___13 {
	enum net_device_path_type type;
	const struct net_device___18 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___13 = 0,
				DEV_PATH_BR_VLAN_TAG___13 = 1,
				DEV_PATH_BR_VLAN_UNTAG___13 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___13 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___13 {
	const struct net_device___18 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___13 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___13 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___13 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___13 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___15 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___13 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___18 *dev;
	const char *name;
};

struct net_device_ops___13 {
	int (*ndo_init)(struct net_device___18 *);
	void (*ndo_uninit)(struct net_device___18 *);
	int (*ndo_open)(struct net_device___18 *);
	int (*ndo_stop)(struct net_device___18 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___15 *, struct net_device___18 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___15 *, struct net_device___18 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___18 *, struct sk_buff___15 *, struct net_device___18 *);
	void (*ndo_change_rx_flags)(struct net_device___18 *, int);
	void (*ndo_set_rx_mode)(struct net_device___18 *);
	int (*ndo_set_mac_address)(struct net_device___18 *, void *);
	int (*ndo_validate_addr)(struct net_device___18 *);
	int (*ndo_do_ioctl)(struct net_device___18 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___18 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___18 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___18 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___18 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___18 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___18 *, int);
	int (*ndo_neigh_setup)(struct net_device___18 *, struct neigh_parms___9 *);
	void (*ndo_tx_timeout)(struct net_device___18 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___18 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___18 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___18 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___18 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___18 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___18 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___18 *);
	int (*ndo_netpoll_setup)(struct net_device___18 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___18 *);
	int (*ndo_set_vf_mac)(struct net_device___18 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___18 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___18 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___18 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___18 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___18 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___18 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___18 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___18 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___18 *, int, struct sk_buff___15 *);
	int (*ndo_get_vf_guid)(struct net_device___18 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___18 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___18 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___18 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___18 *);
	int (*ndo_fcoe_disable)(struct net_device___18 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___18 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___18 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___18 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___18 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___18 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___18 *, const struct sk_buff___15 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___18 *, struct net_device___18 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___18 *, struct net_device___18 *);
	struct net_device___18 * (*ndo_get_xmit_slave)(struct net_device___18 *, struct sk_buff___15 *, bool);
	struct net_device___18 * (*ndo_sk_get_lower_dev)(struct net_device___18 *, struct sock___2 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___18 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___18 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___18 *, struct neighbour___9 *);
	void (*ndo_neigh_destroy)(struct net_device___18 *, struct neighbour___9 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___15 *, struct netlink_callback___13 *, struct net_device___18 *, struct net_device___18 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___15 *, struct nlattr **, struct net_device___18 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___18 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___15 *, u32, u32, struct net_device___18 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___18 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___18 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___18 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___18 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___18 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___18 *, struct net_device___18 *);
	void (*ndo_dfwd_del_station)(struct net_device___18 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___18 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___18 *);
	int (*ndo_change_proto_down)(struct net_device___18 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___18 *, struct sk_buff___15 *);
	void (*ndo_set_rx_headroom)(struct net_device___18 *, int);
	int (*ndo_bpf)(struct net_device___18 *, struct netdev_bpf___13 *);
	int (*ndo_xdp_xmit)(struct net_device___18 *, int, struct xdp_frame___13 **, u32);
	struct net_device___18 * (*ndo_xdp_get_xmit_slave)(struct net_device___18 *, struct xdp_buff___13 *);
	int (*ndo_xsk_wakeup)(struct net_device___18 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___18 *);
	int (*ndo_tunnel_ctl)(struct net_device___18 *, struct ip_tunnel_parm *, int);
	struct net_device___18 * (*ndo_get_peer_dev)(struct net_device___18 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___13 *, struct net_device_path___13 *);
};

struct neigh_parms___9 {
	possible_net_t___13 net;
	struct net_device___18 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___9 *);
	struct neigh_table___9 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___9 {
	u32 (*l3mdev_fib_table)(const struct net_device___18 *);
	struct sk_buff___15 * (*l3mdev_l3_rcv)(struct net_device___18 *, struct sk_buff___15 *, u16);
	struct sk_buff___15 * (*l3mdev_l3_out)(struct net_device___18 *, struct sock___2 *, struct sk_buff___15 *, u16);
	struct dst_entry___9 * (*l3mdev_link_scope_lookup)(const struct net_device___18 *, struct flowi6 *);
};

struct ndisc_ops___4 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___18 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___18 *, struct neighbour___9 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___18 *, u8, struct neighbour___9 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___18 *, struct sk_buff___15 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___16 *, struct net_device___18 *, const struct prefix_info *, struct inet6_dev___4 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___4;

struct inet6_dev___4 {
	struct net_device___18 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___4 *mc_list;
	struct ifmcaddr6___4 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___13 mc_query_queue;
	struct sk_buff_head___13 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___9 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___13;

struct tcf_block___13;

struct mini_Qdisc___13 {
	struct tcf_proto___13 *filter_list;
	struct tcf_block___13 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___13 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___18 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___18 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___16 *, struct net_device___18 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___18 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___18 *, struct list_head *);
	size_t (*get_size)(const struct net_device___18 *);
	int (*fill_info)(struct sk_buff___15 *, const struct net_device___18 *);
	size_t (*get_xstats_size)(const struct net_device___18 *);
	int (*fill_xstats)(struct sk_buff___15 *, const struct net_device___18 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___18 *, struct net_device___18 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___18 *, const struct net_device___18 *);
	int (*fill_slave_info)(struct sk_buff___15 *, const struct net_device___18 *, const struct net_device___18 *);
	struct net___16 * (*get_link_net)(const struct net_device___18 *);
	size_t (*get_linkxstats_size)(const struct net_device___18 *, int);
	int (*fill_linkxstats)(struct sk_buff___15 *, const struct net_device___18 *, int *, int);
};

struct gnet_dump___13 {
	spinlock_t *lock;
	struct sk_buff___15 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___13;

struct Qdisc_ops___13 {
	struct Qdisc_ops___13 *next;
	const struct Qdisc_class_ops___13 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___15 *, struct Qdisc___13 *, struct sk_buff___15 **);
	struct sk_buff___15 * (*dequeue)(struct Qdisc___13 *);
	struct sk_buff___15 * (*peek)(struct Qdisc___13 *);
	int (*init)(struct Qdisc___13 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___13 *);
	void (*destroy)(struct Qdisc___13 *);
	int (*change)(struct Qdisc___13 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___13 *);
	int (*change_tx_queue_len)(struct Qdisc___13 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___13 *, unsigned int);
	int (*dump)(struct Qdisc___13 *, struct sk_buff___15 *);
	int (*dump_stats)(struct Qdisc___13 *, struct gnet_dump___13 *);
	void (*ingress_block_set)(struct Qdisc___13 *, u32);
	void (*egress_block_set)(struct Qdisc___13 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___13 *);
	u32 (*egress_block_get)(struct Qdisc___13 *);
	struct module___3 *owner;
};

struct Qdisc_class_ops___13 {
	unsigned int flags;
	struct netdev_queue___13 * (*select_queue)(struct Qdisc___13 *, struct tcmsg *);
	int (*graft)(struct Qdisc___13 *, long unsigned int, struct Qdisc___13 *, struct Qdisc___13 **, struct netlink_ext_ack *);
	struct Qdisc___13 * (*leaf)(struct Qdisc___13 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___13 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___13 *, u32);
	int (*change)(struct Qdisc___13 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___13 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___13 *, struct qdisc_walker *);
	struct tcf_block___13 * (*tcf_block)(struct Qdisc___13 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___13 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___13 *, long unsigned int);
	int (*dump)(struct Qdisc___13 *, long unsigned int, struct sk_buff___15 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___13 *, long unsigned int, struct gnet_dump___13 *);
};

struct tcf_chain___13;

struct tcf_block___13 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___16 *net;
	struct Qdisc___13 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___13 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___13;

struct tcf_proto_ops___13;

struct tcf_proto___13 {
	struct tcf_proto___13 *next;
	void *root;
	int (*classify)(struct sk_buff___15 *, const struct tcf_proto___13 *, struct tcf_result___13 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___13 *ops;
	struct tcf_chain___13 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___13 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___13 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___13 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___15 *, const struct tcf_proto___13 *, struct tcf_result___13 *);
	int (*init)(struct tcf_proto___13 *);
	void (*destroy)(struct tcf_proto___13 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___13 *, u32);
	void (*put)(struct tcf_proto___13 *, void *);
	int (*change)(struct net___16 *, struct sk_buff___15 *, struct tcf_proto___13 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___13 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___13 *);
	void (*walk)(struct tcf_proto___13 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___13 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___13 *, void *);
	void (*hw_del)(struct tcf_proto___13 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___16 *, struct tcf_chain___13 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___16 *, struct tcf_proto___13 *, void *, struct sk_buff___15 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___16 *, struct tcf_proto___13 *, void *, struct sk_buff___15 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___15 *, struct net___16 *, void *);
	struct module___3 *owner;
	int flags;
};

struct tcf_chain___13 {
	struct mutex filter_chain_lock;
	struct tcf_proto___13 *filter_chain;
	struct list_head list;
	struct tcf_block___13 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___13 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___9 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___13 *prog;
};

struct bpf_sock_addr_kern {
	struct sock___2 *sk;
	struct sockaddr *uaddr;
	u64 tmp_reg;
	void *t_ctx;
};

struct bpf_sock_ops_kern {
	struct sock___2 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___15 *syn_skb;
	struct sk_buff___15 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct bpf_sysctl_kern {
	struct ctl_table_header *head;
	struct ctl_table *table;
	void *cur_val;
	size_t cur_len;
	void *new_val;
	size_t new_len;
	int new_updated;
	int write;
	loff_t *ppos;
	u64 tmp_reg;
};

struct bpf_sockopt_kern {
	struct sock___2 *sk;
	u8 *optval;
	u8 *optval_end;
	s32 level;
	s32 optname;
	s32 optlen;
	s32 retval;
};

struct bpf_sk_lookup_kern {
	u16 family;
	u16 protocol;
	__be16 sport;
	u16 dport;
	struct {
		__be32 saddr;
		__be32 daddr;
	} v4;
	struct {
		const struct in6_addr *saddr;
		const struct in6_addr *daddr;
	} v6;
	struct sock___2 *selected_sk;
	bool no_reuseport;
};

struct bpf_stack_state___3 {
	struct bpf_reg_state___3 spilled_ptr;
	u8 slot_type[8];
};

struct bpf_verifier_state___3 {
	struct bpf_func_state___3 *frame[8];
	struct bpf_verifier_state___3 *parent;
	u32 branches;
	u32 insn_idx;
	u32 curframe;
	u32 active_spin_lock;
	bool speculative;
	u32 first_insn_idx;
	u32 last_insn_idx;
	struct bpf_idx_pair *jmp_history;
	u32 jmp_history_cnt;
};

struct bpf_verifier_state_list___3 {
	struct bpf_verifier_state___3 state;
	struct bpf_verifier_state_list___3 *next;
	int miss_cnt;
	int hit_cnt;
};

struct block_device_operations___30;

struct gendisk___30 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___31 *part0;
	const struct block_device_operations___30 *fops;
	struct request_queue___31 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___29 *bdi;
	struct kobject___65 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___65 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___30 {
	struct bio___30 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___36 *bip_vec;
	struct bio_vec___36 bip_inline_vecs[0];
};

struct blkcg___29;

struct blkg_policy_data___29;

struct blkcg_gq___29 {
	struct request_queue___31 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___29 *blkcg;
	struct blkcg_gq___29 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___29 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___30 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___30(struct request___30 *);

typedef void integrity_complete_fn___30(struct request___30 *, unsigned int);

struct blk_integrity_profile___30 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___30 *prepare_fn;
	integrity_complete_fn___30 *complete_fn;
	const char *name;
};

struct block_device_operations___30 {
	blk_qc_t (*submit_bio)(struct bio___30 *);
	int (*open)(struct block_device___31 *, fmode_t);
	void (*release)(struct gendisk___30 *, fmode_t);
	int (*rw_page)(struct block_device___31 *, sector_t, struct page___70 *, unsigned int);
	int (*ioctl)(struct block_device___31 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___31 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___30 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___30 *);
	int (*getgeo)(struct block_device___31 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___31 *, bool);
	void (*swap_slot_free_notify)(struct block_device___31 *, long unsigned int);
	int (*report_zones)(struct gendisk___30 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___30 *, umode_t *);
	struct module___3 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___30 *, sector_t *);
};

typedef void rq_end_io_fn___30(struct request___30 *, blk_status_t);

struct request___30 {
	struct request_queue___31 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___29 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___30 *bio;
	struct bio___30 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___36 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___30 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___30 *saved_end_io;
		} flush;
	};
	struct gendisk___30 *rq_disk;
	struct block_device___31 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___30 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___29 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___31 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___65 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___66 *debugfs_dir;
	struct dentry___66 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___30;

struct elevator_mq_ops___30 {
	int (*init_sched)(struct request_queue___31 *, struct elevator_type___30 *);
	void (*exit_sched)(struct elevator_queue___30 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___29 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___29 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___29 *);
	bool (*allow_merge)(struct request_queue___31 *, struct request___30 *, struct bio___30 *);
	bool (*bio_merge)(struct request_queue___31 *, struct bio___30 *, unsigned int);
	int (*request_merge)(struct request_queue___31 *, struct request___30 **, struct bio___30 *);
	void (*request_merged)(struct request_queue___31 *, struct request___30 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___31 *, struct request___30 *, struct request___30 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___30 *);
	void (*finish_request)(struct request___30 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___29 *, struct list_head *, bool);
	struct request___30 * (*dispatch_request)(struct blk_mq_hw_ctx___29 *);
	bool (*has_work)(struct blk_mq_hw_ctx___29 *);
	void (*completed_request)(struct request___30 *, u64);
	void (*requeue_request)(struct request___30 *);
	struct request___30 * (*former_request)(struct request_queue___31 *, struct request___30 *);
	struct request___30 * (*next_request)(struct request_queue___31 *, struct request___30 *);
	void (*init_icq)(struct io_cq___30 *);
	void (*exit_icq)(struct io_cq___30 *);
};

struct elv_fs_entry___30;

struct elevator_type___30 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___30 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___30 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___3 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___30 {
	struct elevator_type___30 *type;
	void *elevator_data;
	struct kobject___65 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___30 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___30 *, char *);
	ssize_t (*store)(struct elevator_queue___30 *, const char *, size_t);
};

struct blk_mq_queue_data___29;

struct blk_mq_ops___29 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___29 *, const struct blk_mq_queue_data___29 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___29 *);
	int (*get_budget)(struct request_queue___31 *);
	void (*put_budget)(struct request_queue___31 *, int);
	void (*set_rq_budget_token)(struct request___30 *, int);
	int (*get_rq_budget_token)(struct request___30 *);
	enum blk_eh_timer_return (*timeout)(struct request___30 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___29 *);
	void (*complete)(struct request___30 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___29 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___29 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___29 *, struct request___30 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___29 *, struct request___30 *, unsigned int);
	void (*initialize_rq_fn)(struct request___30 *);
	void (*cleanup_rq)(struct request___30 *);
	bool (*busy)(struct request_queue___31 *);
	int (*map_queues)(struct blk_mq_tag_set___29 *);
	void (*show_rq)(struct seq_file___63 *, struct request___30 *);
};

struct blk_mq_tag_set___29 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___29 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___29 {
	struct request___30 *rq;
	bool last;
};

struct blkcg_policy_data___29;

struct blkcg___29 {
	struct cgroup_subsys_state___54 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___29 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___29 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___29 {
	struct blkcg___29 *blkcg;
	int plid;
};

struct blkg_policy_data___29 {
	struct blkcg_gq___29 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___27 {
	struct mem_cgroup___27 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___27 {
	struct lruvec___28 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___27 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___27 *memcg;
};

struct obj_cgroup___27 {
	struct percpu_ref refcnt;
	struct mem_cgroup___27 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___9;

struct neigh_hash_table___9;

struct neigh_table___9 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___18 *, __u32 *);
	bool (*key_eq)(const struct neighbour___9 *, const void *);
	int (*constructor)(struct neighbour___9 *);
	int (*pconstructor)(struct pneigh_entry___9 *);
	void (*pdestructor)(struct pneigh_entry___9 *);
	void (*proxy_redo)(struct sk_buff___15 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___18 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___9 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___13 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___9 *nht;
	struct pneigh_entry___9 **phash_buckets;
};

struct neigh_ops___9 {
	int family;
	void (*solicit)(struct neighbour___9 *, struct sk_buff___15 *);
	void (*error_report)(struct neighbour___9 *, struct sk_buff___15 *);
	int (*output)(struct neighbour___9 *, struct sk_buff___15 *);
	int (*connected_output)(struct neighbour___9 *, struct sk_buff___15 *);
};

struct pneigh_entry___9 {
	struct pneigh_entry___9 *next;
	possible_net_t___13 net;
	struct net_device___18 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___9 {
	struct neighbour___9 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___2 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___16 *, struct sock___2 *, struct sk_buff___15 *);
	int (*orig_input)(struct sk_buff___15 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___9 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___9 *ctarget;
	struct net___16 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___9 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___9 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___5;

struct timewait_sock_ops___5;

struct proto___9 {
	void (*close)(struct sock___2 *, long int);
	int (*pre_connect)(struct sock___2 *, struct sockaddr *, int);
	int (*connect)(struct sock___2 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___2 *, int);
	struct sock___2 * (*accept)(struct sock___2 *, int, int *, bool);
	int (*ioctl)(struct sock___2 *, int, long unsigned int);
	int (*init)(struct sock___2 *);
	void (*destroy)(struct sock___2 *);
	void (*shutdown)(struct sock___2 *, int);
	int (*setsockopt)(struct sock___2 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___2 *, int, int, char *, int *);
	void (*keepalive)(struct sock___2 *, int);
	int (*compat_ioctl)(struct sock___2 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___2 *, struct msghdr___9 *, size_t);
	int (*recvmsg)(struct sock___2 *, struct msghdr___9 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___2 *, struct page___70 *, int, size_t, int);
	int (*bind)(struct sock___2 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___2 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___2 *, struct sk_buff___15 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___2 *);
	int (*hash)(struct sock___2 *);
	void (*unhash)(struct sock___2 *);
	void (*rehash)(struct sock___2 *);
	int (*get_port)(struct sock___2 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___2 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___2 *, int);
	bool (*sock_is_readable)(struct sock___2 *);
	void (*enter_memory_pressure)(struct sock___2 *);
	void (*leave_memory_pressure)(struct sock___2 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___5 *rsk_prot;
	struct timewait_sock_ops___5 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___3 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___2 *, int);
};

struct sock_reuseport___2 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___13 *prog;
	struct sock___2 *socks[0];
};

struct sk_psock_progs {
	struct bpf_prog___13 *msg_parser;
	struct bpf_prog___13 *stream_parser;
	struct bpf_prog___13 *stream_verdict;
	struct bpf_prog___13 *skb_verdict;
};

struct strp_stats {
	long long unsigned int msgs;
	long long unsigned int bytes;
	unsigned int mem_fail;
	unsigned int need_more_hdr;
	unsigned int msg_too_big;
	unsigned int msg_timeouts;
	unsigned int bad_hdr_len;
};

struct strparser;

struct strp_callbacks {
	int (*parse_msg)(struct strparser *, struct sk_buff___15 *);
	void (*rcv_msg)(struct strparser *, struct sk_buff___15 *);
	int (*read_sock_done)(struct strparser *, int);
	void (*abort_parser)(struct strparser *, int);
	void (*lock)(struct strparser *);
	void (*unlock)(struct strparser *);
};

struct strparser {
	struct sock___2 *sk;
	u32 stopped: 1;
	u32 paused: 1;
	u32 aborted: 1;
	u32 interrupted: 1;
	u32 unrecov_intr: 1;
	long: 63;
	long: 64;
	struct sk_buff___15 **skb_nextp;
	struct sk_buff___15 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks cb;
};

struct sk_psock_work_state {
	struct sk_buff___15 *skb;
	u32 len;
	u32 off;
};

struct sk_msg;

struct sk_psock {
	struct sock___2 *sk;
	struct sock___2 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg *cork;
	struct sk_psock_progs progs;
	struct strparser strp;
	struct sk_buff_head___13 ingress_skb;
	struct list_head ingress_msg;
	spinlock_t ingress_lock;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___2 *);
	void (*saved_close)(struct sock___2 *, long int);
	void (*saved_write_space)(struct sock___2 *);
	void (*saved_data_ready)(struct sock___2 *);
	int (*psock_update_sk_prot)(struct sock___2 *, struct sk_psock *, bool);
	struct proto___9 *sk_proto;
	struct mutex work_mutex;
	struct sk_psock_work_state work_state;
	struct work_struct work;
	struct rcu_work rwork;
};

struct request_sock___4;

struct request_sock_ops___5 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___2 *, struct request_sock___4 *);
	void (*send_ack)(const struct sock___2 *, struct sk_buff___15 *, struct request_sock___4 *);
	void (*send_reset)(const struct sock___2 *, struct sk_buff___15 *);
	void (*destructor)(struct request_sock___4 *);
	void (*syn_ack_timeout)(const struct request_sock___4 *);
};

struct timewait_sock_ops___5 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___2 *, struct sock___2 *, void *);
	void (*twsk_destructor)(struct sock___2 *);
};

struct request_sock___4 {
	struct sock_common___9 __req_common;
	struct request_sock___4 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___5 *rsk_ops;
	struct sock___2 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___4 {
	struct in6_addr mca_addr;
	struct inet6_dev___4 *idev;
	struct ifmcaddr6___4 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct inet_ehash_bucket {
	struct hlist_nulls_head chain;
};

struct inet_bind_hashbucket {
	spinlock_t lock;
	struct hlist_head chain;
};

struct ack_sample {
	u32 pkts_acked;
	s32 rtt_us;
	u32 in_flight;
};

struct rate_sample {
	u64 prior_mstamp;
	u32 prior_delivered;
	s32 delivered;
	long int interval_us;
	u32 snd_interval_us;
	u32 rcv_interval_us;
	long int rtt_us;
	int losses;
	u32 acked_sacked;
	u32 prior_in_flight;
	bool is_app_limited;
	bool is_retrans;
	bool is_ack_delayed;
};

struct sk_msg_sg {
	u32 start;
	u32 curr;
	u32 end;
	u32 size;
	u32 copybreak;
	long unsigned int copy;
	struct scatterlist data[19];
};

struct sk_msg {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___15 *skb;
	struct sock___2 *sk_redir;
	struct sock___2 *sk;
	struct list_head list;
};

struct perf_cpu_context___43;

struct perf_output_handle___43;

struct pmu___43 {
	struct list_head entry;
	struct module___3 *module;
	struct device___58 *dev;
	const struct attribute_group___65 **attr_groups;
	const struct attribute_group___65 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___43 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___43 *);
	void (*pmu_disable)(struct pmu___43 *);
	int (*event_init)(struct perf_event___43 *);
	void (*event_mapped)(struct perf_event___43 *, struct mm_struct___71 *);
	void (*event_unmapped)(struct perf_event___43 *, struct mm_struct___71 *);
	int (*add)(struct perf_event___43 *, int);
	void (*del)(struct perf_event___43 *, int);
	void (*start)(struct perf_event___43 *, int);
	void (*stop)(struct perf_event___43 *, int);
	void (*read)(struct perf_event___43 *);
	void (*start_txn)(struct pmu___43 *, unsigned int);
	int (*commit_txn)(struct pmu___43 *);
	void (*cancel_txn)(struct pmu___43 *);
	int (*event_idx)(struct perf_event___43 *);
	void (*sched_task)(struct perf_event_context___43 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___43 *, struct perf_event_context___43 *);
	void * (*setup_aux)(struct perf_event___43 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___43 *, struct perf_output_handle___43 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___43 *);
	int (*aux_output_match)(struct perf_event___43 *);
	int (*filter_match)(struct perf_event___43 *);
	int (*check_period)(struct perf_event___43 *, u64);
};

struct perf_cpu_context___43 {
	struct perf_event_context___43 ctx;
	struct perf_event_context___43 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___43 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___43 **heap;
	struct perf_event___43 *heap_default[2];
};

struct perf_output_handle___43 {
	struct perf_event___43 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___43 {
	struct cgroup_subsys_state___54 css;
	struct perf_cgroup_info *info;
};

struct bpf_perf_event_data_kern___2 {
	bpf_user_pt_regs_t *regs;
	struct perf_sample_data___2 *data;
	struct perf_event___43 *event;
};

enum verifier_phase {
	CHECK_META = 0,
	CHECK_TYPE = 1,
};

struct resolve_vertex {
	const struct btf_type *t;
	u32 type_id;
	u16 next_member;
};

enum visit_state {
	NOT_VISITED = 0,
	VISITED = 1,
	RESOLVED = 2,
};

enum resolve_mode {
	RESOLVE_TBD = 0,
	RESOLVE_PTR = 1,
	RESOLVE_STRUCT_OR_ARRAY = 2,
};

struct btf_sec_info {
	u32 off;
	u32 len;
};

struct btf_verifier_env {
	struct btf *btf;
	u8 *visit_states;
	struct resolve_vertex stack[32];
	struct bpf_verifier_log log;
	u32 log_type_id;
	u32 top_stack;
	enum verifier_phase phase;
	enum resolve_mode resolve_mode;
};

struct btf_show {
	u64 flags;
	void *target;
	void (*showfn)(struct btf_show *, const char *, va_list);
	const struct btf *btf;
	struct {
		u8 depth;
		u8 depth_to_show;
		u8 depth_check;
		u8 array_member: 1;
		u8 array_terminated: 1;
		int: 31;
		u16 array_encoding;
		u32 type_id;
		int status;
		const struct btf_type *type;
		const struct btf_member *member;
		char name[80];
	} state;
	struct {
		u32 size;
		void *head;
		void *data;
		u8 safe[32];
	} obj;
};

struct btf_kind_operations {
	s32 (*check_meta)(struct btf_verifier_env *, const struct btf_type *, u32);
	int (*resolve)(struct btf_verifier_env *, const struct resolve_vertex *);
	int (*check_member)(struct btf_verifier_env *, const struct btf_type *, const struct btf_member *, const struct btf_type *);
	int (*check_kflag_member)(struct btf_verifier_env *, const struct btf_type *, const struct btf_member *, const struct btf_type *);
	void (*log_details)(struct btf_verifier_env *, const struct btf_type *);
	void (*show)(const struct btf *, const struct btf_type *, u32, void *, u8, struct btf_show *);
};

struct bpf_ctx_convert {
	struct __sk_buff BPF_PROG_TYPE_SOCKET_FILTER_prog;
	struct sk_buff___15 BPF_PROG_TYPE_SOCKET_FILTER_kern;
	struct __sk_buff BPF_PROG_TYPE_SCHED_CLS_prog;
	struct sk_buff___15 BPF_PROG_TYPE_SCHED_CLS_kern;
	struct __sk_buff BPF_PROG_TYPE_SCHED_ACT_prog;
	struct sk_buff___15 BPF_PROG_TYPE_SCHED_ACT_kern;
	struct xdp_md BPF_PROG_TYPE_XDP_prog;
	struct xdp_buff___13 BPF_PROG_TYPE_XDP_kern;
	struct __sk_buff BPF_PROG_TYPE_CGROUP_SKB_prog;
	struct sk_buff___15 BPF_PROG_TYPE_CGROUP_SKB_kern;
	struct bpf_sock BPF_PROG_TYPE_CGROUP_SOCK_prog;
	struct sock___2 BPF_PROG_TYPE_CGROUP_SOCK_kern;
	struct bpf_sock_addr BPF_PROG_TYPE_CGROUP_SOCK_ADDR_prog;
	struct bpf_sock_addr_kern BPF_PROG_TYPE_CGROUP_SOCK_ADDR_kern;
	struct __sk_buff BPF_PROG_TYPE_LWT_IN_prog;
	struct sk_buff___15 BPF_PROG_TYPE_LWT_IN_kern;
	struct __sk_buff BPF_PROG_TYPE_LWT_OUT_prog;
	struct sk_buff___15 BPF_PROG_TYPE_LWT_OUT_kern;
	struct __sk_buff BPF_PROG_TYPE_LWT_XMIT_prog;
	struct sk_buff___15 BPF_PROG_TYPE_LWT_XMIT_kern;
	struct __sk_buff BPF_PROG_TYPE_LWT_SEG6LOCAL_prog;
	struct sk_buff___15 BPF_PROG_TYPE_LWT_SEG6LOCAL_kern;
	struct bpf_sock_ops BPF_PROG_TYPE_SOCK_OPS_prog;
	struct bpf_sock_ops_kern BPF_PROG_TYPE_SOCK_OPS_kern;
	struct __sk_buff BPF_PROG_TYPE_SK_SKB_prog;
	struct sk_buff___15 BPF_PROG_TYPE_SK_SKB_kern;
	struct sk_msg_md BPF_PROG_TYPE_SK_MSG_prog;
	struct sk_msg BPF_PROG_TYPE_SK_MSG_kern;
	struct __sk_buff BPF_PROG_TYPE_FLOW_DISSECTOR_prog;
	struct bpf_flow_dissector BPF_PROG_TYPE_FLOW_DISSECTOR_kern;
	bpf_user_pt_regs_t BPF_PROG_TYPE_KPROBE_prog;
	struct pt_regs BPF_PROG_TYPE_KPROBE_kern;
	__u64 BPF_PROG_TYPE_TRACEPOINT_prog;
	u64 BPF_PROG_TYPE_TRACEPOINT_kern;
	struct bpf_perf_event_data BPF_PROG_TYPE_PERF_EVENT_prog;
	struct bpf_perf_event_data_kern___2 BPF_PROG_TYPE_PERF_EVENT_kern;
	struct bpf_raw_tracepoint_args BPF_PROG_TYPE_RAW_TRACEPOINT_prog;
	u64 BPF_PROG_TYPE_RAW_TRACEPOINT_kern;
	struct bpf_raw_tracepoint_args BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE_prog;
	u64 BPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE_kern;
	void *BPF_PROG_TYPE_TRACING_prog;
	void *BPF_PROG_TYPE_TRACING_kern;
	struct bpf_cgroup_dev_ctx BPF_PROG_TYPE_CGROUP_DEVICE_prog;
	struct bpf_cgroup_dev_ctx BPF_PROG_TYPE_CGROUP_DEVICE_kern;
	struct bpf_sysctl BPF_PROG_TYPE_CGROUP_SYSCTL_prog;
	struct bpf_sysctl_kern BPF_PROG_TYPE_CGROUP_SYSCTL_kern;
	struct bpf_sockopt BPF_PROG_TYPE_CGROUP_SOCKOPT_prog;
	struct bpf_sockopt_kern BPF_PROG_TYPE_CGROUP_SOCKOPT_kern;
	struct sk_reuseport_md BPF_PROG_TYPE_SK_REUSEPORT_prog;
	struct sk_reuseport_kern BPF_PROG_TYPE_SK_REUSEPORT_kern;
	struct bpf_sk_lookup BPF_PROG_TYPE_SK_LOOKUP_prog;
	struct bpf_sk_lookup_kern BPF_PROG_TYPE_SK_LOOKUP_kern;
	void *BPF_PROG_TYPE_STRUCT_OPS_prog;
	void *BPF_PROG_TYPE_STRUCT_OPS_kern;
	void *BPF_PROG_TYPE_EXT_prog;
	void *BPF_PROG_TYPE_EXT_kern;
	void *BPF_PROG_TYPE_LSM_prog;
	void *BPF_PROG_TYPE_LSM_kern;
	void *BPF_PROG_TYPE_SYSCALL_prog;
	void *BPF_PROG_TYPE_SYSCALL_kern;
};

enum {
	__ctx_convertBPF_PROG_TYPE_SOCKET_FILTER = 0,
	__ctx_convertBPF_PROG_TYPE_SCHED_CLS = 1,
	__ctx_convertBPF_PROG_TYPE_SCHED_ACT = 2,
	__ctx_convertBPF_PROG_TYPE_XDP = 3,
	__ctx_convertBPF_PROG_TYPE_CGROUP_SKB = 4,
	__ctx_convertBPF_PROG_TYPE_CGROUP_SOCK = 5,
	__ctx_convertBPF_PROG_TYPE_CGROUP_SOCK_ADDR = 6,
	__ctx_convertBPF_PROG_TYPE_LWT_IN = 7,
	__ctx_convertBPF_PROG_TYPE_LWT_OUT = 8,
	__ctx_convertBPF_PROG_TYPE_LWT_XMIT = 9,
	__ctx_convertBPF_PROG_TYPE_LWT_SEG6LOCAL = 10,
	__ctx_convertBPF_PROG_TYPE_SOCK_OPS = 11,
	__ctx_convertBPF_PROG_TYPE_SK_SKB = 12,
	__ctx_convertBPF_PROG_TYPE_SK_MSG = 13,
	__ctx_convertBPF_PROG_TYPE_FLOW_DISSECTOR = 14,
	__ctx_convertBPF_PROG_TYPE_KPROBE = 15,
	__ctx_convertBPF_PROG_TYPE_TRACEPOINT = 16,
	__ctx_convertBPF_PROG_TYPE_PERF_EVENT = 17,
	__ctx_convertBPF_PROG_TYPE_RAW_TRACEPOINT = 18,
	__ctx_convertBPF_PROG_TYPE_RAW_TRACEPOINT_WRITABLE = 19,
	__ctx_convertBPF_PROG_TYPE_TRACING = 20,
	__ctx_convertBPF_PROG_TYPE_CGROUP_DEVICE = 21,
	__ctx_convertBPF_PROG_TYPE_CGROUP_SYSCTL = 22,
	__ctx_convertBPF_PROG_TYPE_CGROUP_SOCKOPT = 23,
	__ctx_convertBPF_PROG_TYPE_SK_REUSEPORT = 24,
	__ctx_convertBPF_PROG_TYPE_SK_LOOKUP = 25,
	__ctx_convertBPF_PROG_TYPE_STRUCT_OPS = 26,
	__ctx_convertBPF_PROG_TYPE_EXT = 27,
	__ctx_convertBPF_PROG_TYPE_LSM = 28,
	__ctx_convertBPF_PROG_TYPE_SYSCALL = 29,
	__ctx_convert_unused = 30,
};

enum bpf_struct_walk_result {
	WALK_SCALAR = 0,
	WALK_PTR = 1,
	WALK_STRUCT = 2,
};

struct btf_show_snprintf {
	struct btf_show show;
	int len_left;
	int len;
};

enum {
	BTF_MODULE_F_LIVE = 1,
};

struct btf_module {
	struct list_head list;
	struct module___3 *module;
	struct btf *btf;
	struct bin_attribute___65 *sysfs_attr;
	int flags;
};

typedef u64 (*btf_bpf_btf_find_by_name_kind)(char *, int, u32, int);

struct bpf_dispatcher_prog {
	struct bpf_prog___13 *prog;
	refcount_t users;
};

struct bpf_dispatcher {
	struct mutex mutex;
	void *func;
	struct bpf_dispatcher_prog progs[48];
	int num_progs;
	void *image;
	u32 image_off;
	struct bpf_ksym ksym;
};

enum {
	BPF_F_BROADCAST = 8,
	BPF_F_EXCLUDE_INGRESS = 16,
};

struct bpf_devmap_val {
	__u32 ifindex;
	union {
		int fd;
		__u32 id;
	} bpf_prog;
};

struct dentry___67;

struct super_block___67;

struct module___64;

struct file_system_type___66 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___67 * (*mount)(struct file_system_type___66 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___67 *);
	struct module___64 *owner;
	struct file_system_type___66 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___66;

struct kiocb___66;

struct iov_iter___37;

struct vm_area_struct___71;

struct inode___67;

struct file_lock___66;

struct page___71;

struct pipe_inode_info___26;

struct seq_file___64;

struct file_operations___66 {
	struct module___64 *owner;
	loff_t (*llseek)(struct file___66 *, loff_t, int);
	ssize_t (*read)(struct file___66 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___66 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___66 *, struct iov_iter___37 *);
	ssize_t (*write_iter)(struct kiocb___66 *, struct iov_iter___37 *);
	int (*iopoll)(struct kiocb___66 *, bool);
	int (*iterate)(struct file___66 *, struct dir_context *);
	int (*iterate_shared)(struct file___66 *, struct dir_context *);
	__poll_t (*poll)(struct file___66 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___66 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___66 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___66 *, struct vm_area_struct___71 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___67 *, struct file___66 *);
	int (*flush)(struct file___66 *, fl_owner_t);
	int (*release)(struct inode___67 *, struct file___66 *);
	int (*fsync)(struct file___66 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___66 *, int);
	int (*lock)(struct file___66 *, int, struct file_lock___66 *);
	ssize_t (*sendpage)(struct file___66 *, struct page___71 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___66 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___66 *, long unsigned int);
	int (*flock)(struct file___66 *, int, struct file_lock___66 *);
	ssize_t (*splice_write)(struct pipe_inode_info___26 *, struct file___66 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___66 *, loff_t *, struct pipe_inode_info___26 *, size_t, unsigned int);
	int (*setlease)(struct file___66 *, long int, struct file_lock___66 **, void **);
	long int (*fallocate)(struct file___66 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___64 *, struct file___66 *);
	ssize_t (*copy_file_range)(struct file___66 *, loff_t, struct file___66 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___66 *, loff_t, struct file___66 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___66 *, loff_t, loff_t, int);
};

struct vmacache___71 {
	u64 seqnum;
	struct vm_area_struct___71 *vmas[4];
};

struct page_frag___71 {
	struct page___71 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___72;

struct pid___59;

struct nsproxy___64;

struct signal_struct___67;

struct css_set___55;

struct vm_struct___67;

struct task_struct___73 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___73 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___72 *mm;
	struct mm_struct___72 *active_mm;
	struct vmacache___71 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___73 *real_parent;
	struct task_struct___73 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___73 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___59 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___9 *ptracer_cred;
	const struct cred___9 *real_cred;
	const struct cred___9 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___64 *nsproxy;
	struct signal_struct___67 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___73 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___30 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___55 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___26 *splice_pipe;
	struct page_frag___71 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___73 *oom_reaper_list;
	struct vm_struct___67 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___66;

struct kobj_type___66;

struct kernfs_node___66;

struct kobject___66 {
	const char *name;
	struct list_head entry;
	struct kobject___66 *parent;
	struct kset___66 *kset;
	struct kobj_type___66 *ktype;
	struct kernfs_node___66 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___63 {
	struct kobject___66 kobj;
	struct module___64 *mod;
	struct kobject___66 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___63 {
	struct module___64 *mod;
	struct latch_tree_node node;
};

struct module_layout___63 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___63 mtn;
};

struct module_attribute___63;

struct kernel_param___63;

struct module___64 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___63 mkobj;
	struct module_attribute___63 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___66 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___63 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___63 core_layout;
	struct module_layout___63 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___66;

struct path___66 {
	struct vfsmount___66 *mnt;
	struct dentry___67 *dentry;
};

struct fown_struct___59 {
	rwlock_t lock;
	struct pid___59 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___66;

struct file___66 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___66 f_path;
	struct inode___67 *f_inode;
	const struct file_operations___66 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___59 f_owner;
	const struct cred___9 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___66 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___71 *pgtable_t___71;

struct page_pool___23;

struct dev_pagemap___65;

struct page___71 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___66 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___23 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___71 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___71 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___72 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___65 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___65;

struct vm_area_struct___71 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___71 *vm_next;
	struct vm_area_struct___71 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___72 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___65 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___66 *vm_file;
	struct file___66 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___71;

struct mm_struct___72 {
	struct {
		struct vm_area_struct___71 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___66 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___71 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___73 *owner;
		struct user_namespace___10 *user_ns;
		struct file___66 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___66;

struct address_space___66 {
	struct inode___67 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___66 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___59;

struct page_pool_params___23 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___59 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___23 {
	u32 count;
	struct page___71 *cache[128];
};

struct page_pool___23 {
	struct page_pool_params___23 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___71 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___23 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___65;

struct dev_pagemap___65 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___65 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___65;

struct vm_operations_struct___65 {
	void (*open)(struct vm_area_struct___71 *);
	void (*close)(struct vm_area_struct___71 *);
	int (*may_split)(struct vm_area_struct___71 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___71 *);
	int (*mprotect)(struct vm_area_struct___71 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___65 *);
	vm_fault_t (*huge_fault)(struct vm_fault___65 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___65 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___71 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___65 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___65 *);
	int (*access)(struct vm_area_struct___71 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___71 *);
	int (*set_policy)(struct vm_area_struct___71 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___71 *, long unsigned int);
	struct page___71 * (*find_special_page)(struct vm_area_struct___71 *, long unsigned int);
};

struct core_thread___71 {
	struct task_struct___73 *task;
	struct core_thread___71 *next;
};

struct core_state___71 {
	atomic_t nr_threads;
	struct core_thread___71 dumper;
	struct completion startup;
};

struct vm_fault___65 {
	const struct {
		struct vm_area_struct___71 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___71 *cow_page;
	struct page___71 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___71 prealloc_pte;
};

struct pid_namespace___59;

struct upid___59 {
	int nr;
	struct pid_namespace___59 *ns;
};

struct pid_namespace___59 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___73 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___59 *parent;
	struct fs_pin *bacct;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	int reboot;
	struct ns_common___11 ns;
};

struct pid___59 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___59 numbers[1];
};

struct signal_struct___67 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___73 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___73 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___59 *pids[4];
	struct pid___59 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___72 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___17;

struct cgroup_namespace___55;

struct nsproxy___64 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___59 *pid_ns_for_children;
	struct net___17 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___55 *cgroup_ns;
};

struct cgroup_subsys_state___55;

struct cgroup___55;

struct css_set___55 {
	struct cgroup_subsys_state___55 *subsys[14];
	refcount_t refcount;
	struct css_set___55 *dom_cset;
	struct cgroup___55 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___55 *mg_src_cgrp;
	struct cgroup___55 *mg_dst_cgrp;
	struct css_set___55 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___66;

struct pipe_buffer___26;

struct pipe_inode_info___26 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___71 *tmp_page;
	struct fasync_struct___66 *fasync_readers;
	struct fasync_struct___66 *fasync_writers;
	struct pipe_buffer___26 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___67 {
	struct vm_struct___67 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___71 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___66;

struct dentry___67 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___67 *d_parent;
	struct qstr d_name;
	struct inode___67 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___66 *d_op;
	struct super_block___67 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___66;

struct inode___67 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___66 *i_op;
	struct super_block___67 *i_sb;
	struct address_space___66 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___66 *i_fop;
		void (*free_inode)(struct inode___67 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___66 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___26 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___66 {
	int (*d_revalidate)(struct dentry___67 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___67 *, unsigned int);
	int (*d_hash)(const struct dentry___67 *, struct qstr *);
	int (*d_compare)(const struct dentry___67 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___67 *);
	int (*d_init)(struct dentry___67 *);
	void (*d_release)(struct dentry___67 *);
	void (*d_prune)(struct dentry___67 *);
	void (*d_iput)(struct dentry___67 *, struct inode___67 *);
	char * (*d_dname)(struct dentry___67 *, char *, int);
	struct vfsmount___66 * (*d_automount)(struct path___66 *);
	int (*d_manage)(const struct path___66 *, bool);
	struct dentry___67 * (*d_real)(struct dentry___67 *, const struct inode___67 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___66;

struct mem_dqinfo___66 {
	struct quota_format_type___66 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___66;

struct quota_info___66 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___67 *files[3];
	struct mem_dqinfo___66 info[3];
	const struct quota_format_ops___66 *ops[3];
};

struct rcuwait___67 {
	struct task_struct___73 *task;
};

struct percpu_rw_semaphore___67 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___67 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___66 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___67 rw_sem[3];
};

struct super_operations___66;

struct dquot_operations___66;

struct quotactl_ops___66;

struct super_block___67 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___66 *s_type;
	const struct super_operations___66 *s_op;
	const struct dquot_operations___66 *dq_op;
	const struct quotactl_ops___66 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___67 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___66 s_dquot;
	struct sb_writers___66 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___66 *s_d_op;
	int cleancache_poolid;
	struct shrinker___27 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___10 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___66 {
	struct dentry___67 *mnt_root;
	struct super_block___67 *mnt_sb;
	int mnt_flags;
	struct user_namespace___10 *mnt_userns;
};

struct cgroup_subsys___55;

struct cgroup_subsys_state___55 {
	struct cgroup___55 *cgroup;
	struct cgroup_subsys___55 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___55 *parent;
};

struct cgroup_file___55 {
	struct kernfs_node___66 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___55 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___73 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___14;

struct cgroup_bpf___14 {
	struct bpf_prog_array___14 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___14 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___55;

struct cgroup_rstat_cpu___55;

struct cgroup___55 {
	struct cgroup_subsys_state___55 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___66 *kn;
	struct cgroup_file___55 procs_file;
	struct cgroup_file___55 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___55 *subsys[14];
	struct cgroup_root___55 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___55 *dom_cgrp;
	struct cgroup___55 *old_dom_cgrp;
	struct cgroup_rstat_cpu___55 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___55 psi;
	struct cgroup_bpf___14 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___66 {
	struct file___66 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___66 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___67 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___66 *ia_file;
};

struct dquot___66 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___67 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___66 {
	int qf_fmt_id;
	const struct quota_format_ops___66 *qf_ops;
	struct module___64 *qf_owner;
	struct quota_format_type___66 *qf_next;
};

struct quota_format_ops___66 {
	int (*check_quota_file)(struct super_block___67 *, int);
	int (*read_file_info)(struct super_block___67 *, int);
	int (*write_file_info)(struct super_block___67 *, int);
	int (*free_file_info)(struct super_block___67 *, int);
	int (*read_dqblk)(struct dquot___66 *);
	int (*commit_dqblk)(struct dquot___66 *);
	int (*release_dqblk)(struct dquot___66 *);
	int (*get_next_id)(struct super_block___67 *, struct kqid *);
};

struct dquot_operations___66 {
	int (*write_dquot)(struct dquot___66 *);
	struct dquot___66 * (*alloc_dquot)(struct super_block___67 *, int);
	void (*destroy_dquot)(struct dquot___66 *);
	int (*acquire_dquot)(struct dquot___66 *);
	int (*release_dquot)(struct dquot___66 *);
	int (*mark_dirty)(struct dquot___66 *);
	int (*write_info)(struct super_block___67 *, int);
	qsize_t * (*get_reserved_space)(struct inode___67 *);
	int (*get_projid)(struct inode___67 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___67 *, qsize_t *);
	int (*get_next_id)(struct super_block___67 *, struct kqid *);
};

struct quotactl_ops___66 {
	int (*quota_on)(struct super_block___67 *, int, int, const struct path___66 *);
	int (*quota_off)(struct super_block___67 *, int);
	int (*quota_enable)(struct super_block___67 *, unsigned int);
	int (*quota_disable)(struct super_block___67 *, unsigned int);
	int (*quota_sync)(struct super_block___67 *, int);
	int (*set_info)(struct super_block___67 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___67 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___67 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___67 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___67 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___67 *, unsigned int);
};

struct address_space_operations___66 {
	int (*writepage)(struct page___71 *, struct writeback_control___3 *);
	int (*readpage)(struct file___66 *, struct page___71 *);
	int (*writepages)(struct address_space___66 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___71 *);
	int (*readpages)(struct file___66 *, struct address_space___66 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___66 *, struct address_space___66 *, loff_t, unsigned int, unsigned int, struct page___71 **, void **);
	int (*write_end)(struct file___66 *, struct address_space___66 *, loff_t, unsigned int, unsigned int, struct page___71 *, void *);
	sector_t (*bmap)(struct address_space___66 *, sector_t);
	void (*invalidatepage)(struct page___71 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___71 *, gfp_t);
	void (*freepage)(struct page___71 *);
	ssize_t (*direct_IO)(struct kiocb___66 *, struct iov_iter___37 *);
	int (*migratepage)(struct address_space___66 *, struct page___71 *, struct page___71 *, enum migrate_mode);
	bool (*isolate_page)(struct page___71 *, isolate_mode_t);
	void (*putback_page)(struct page___71 *);
	int (*launder_page)(struct page___71 *);
	int (*is_partially_uptodate)(struct page___71 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___71 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___66 *, struct page___71 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___66 *, sector_t *);
	void (*swap_deactivate)(struct file___66 *);
};

struct bio_vec___37;

struct iov_iter___37 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___37 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___26 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___66 {
	struct dentry___67 * (*lookup)(struct inode___67 *, struct dentry___67 *, unsigned int);
	const char * (*get_link)(struct dentry___67 *, struct inode___67 *, struct delayed_call *);
	int (*permission)(struct user_namespace___10 *, struct inode___67 *, int);
	struct posix_acl * (*get_acl)(struct inode___67 *, int, bool);
	int (*readlink)(struct dentry___67 *, char *, int);
	int (*create)(struct user_namespace___10 *, struct inode___67 *, struct dentry___67 *, umode_t, bool);
	int (*link)(struct dentry___67 *, struct inode___67 *, struct dentry___67 *);
	int (*unlink)(struct inode___67 *, struct dentry___67 *);
	int (*symlink)(struct user_namespace___10 *, struct inode___67 *, struct dentry___67 *, const char *);
	int (*mkdir)(struct user_namespace___10 *, struct inode___67 *, struct dentry___67 *, umode_t);
	int (*rmdir)(struct inode___67 *, struct dentry___67 *);
	int (*mknod)(struct user_namespace___10 *, struct inode___67 *, struct dentry___67 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___10 *, struct inode___67 *, struct dentry___67 *, struct inode___67 *, struct dentry___67 *, unsigned int);
	int (*setattr)(struct user_namespace___10 *, struct dentry___67 *, struct iattr___67 *);
	int (*getattr)(struct user_namespace___10 *, const struct path___66 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___67 *, char *, size_t);
	int (*fiemap)(struct inode___67 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___67 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___67 *, struct dentry___67 *, struct file___66 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___10 *, struct inode___67 *, struct dentry___67 *, umode_t);
	int (*set_acl)(struct user_namespace___10 *, struct inode___67 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___10 *, struct dentry___67 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___67 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___66 {
	void (*fl_copy_lock)(struct file_lock___66 *, struct file_lock___66 *);
	void (*fl_release_private)(struct file_lock___66 *);
};

struct lock_manager_operations___66;

struct file_lock___66 {
	struct file_lock___66 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___66 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___66 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___66 *fl_ops;
	const struct lock_manager_operations___66 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___66 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___66 *);
	int (*lm_grant)(struct file_lock___66 *, int);
	bool (*lm_break)(struct file_lock___66 *);
	int (*lm_change)(struct file_lock___66 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___66 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___66 *);
};

struct fasync_struct___66 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___66 *fa_next;
	struct file___66 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___66 {
	struct inode___67 * (*alloc_inode)(struct super_block___67 *);
	void (*destroy_inode)(struct inode___67 *);
	void (*free_inode)(struct inode___67 *);
	void (*dirty_inode)(struct inode___67 *, int);
	int (*write_inode)(struct inode___67 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___67 *);
	void (*evict_inode)(struct inode___67 *);
	void (*put_super)(struct super_block___67 *);
	int (*sync_fs)(struct super_block___67 *, int);
	int (*freeze_super)(struct super_block___67 *);
	int (*freeze_fs)(struct super_block___67 *);
	int (*thaw_super)(struct super_block___67 *);
	int (*unfreeze_fs)(struct super_block___67 *);
	int (*statfs)(struct dentry___67 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___67 *, int *, char *);
	void (*umount_begin)(struct super_block___67 *);
	int (*show_options)(struct seq_file___64 *, struct dentry___67 *);
	int (*show_devname)(struct seq_file___64 *, struct dentry___67 *);
	int (*show_path)(struct seq_file___64 *, struct dentry___67 *);
	int (*show_stats)(struct seq_file___64 *, struct dentry___67 *);
	ssize_t (*quota_read)(struct super_block___67 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___67 *, int, const char *, size_t, loff_t);
	struct dquot___66 ** (*get_dquots)(struct inode___67 *);
	long int (*nr_cached_objects)(struct super_block___67 *, struct shrink_control___27 *);
	long int (*free_cached_objects)(struct super_block___67 *, struct shrink_control___27 *);
	struct file___66 * (*real_loop)(struct file___66 *);
};

struct seq_operations___64;

struct seq_file___64 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___64 *op;
	int poll_event;
	const struct file___66 *file;
	void *private;
};

struct kernfs_root___66;

struct kernfs_elem_dir___66 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___66 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___66;

struct kernfs_root___66 {
	struct kernfs_node___66 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___66 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___66 {
	struct kernfs_node___66 *target_kn;
};

struct kernfs_ops___66;

struct kernfs_elem_attr___66 {
	const struct kernfs_ops___66 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___66 *notify_next;
};

struct kernfs_node___66 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___66 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___66 dir;
		struct kernfs_elem_symlink___66 symlink;
		struct kernfs_elem_attr___66 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___66;

struct kernfs_ops___66 {
	int (*open)(struct kernfs_open_file___66 *);
	void (*release)(struct kernfs_open_file___66 *);
	int (*seq_show)(struct seq_file___64 *, void *);
	void * (*seq_start)(struct seq_file___64 *, loff_t *);
	void * (*seq_next)(struct seq_file___64 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___64 *, void *);
	ssize_t (*read)(struct kernfs_open_file___66 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___66 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___66 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___66 *, struct vm_area_struct___71 *);
};

struct kernfs_syscall_ops___66 {
	int (*show_options)(struct seq_file___64 *, struct kernfs_root___66 *);
	int (*mkdir)(struct kernfs_node___66 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___66 *);
	int (*rename)(struct kernfs_node___66 *, struct kernfs_node___66 *, const char *);
	int (*show_path)(struct seq_file___64 *, struct kernfs_node___66 *, struct kernfs_root___66 *);
};

struct kernfs_open_file___66 {
	struct kernfs_node___66 *kn;
	struct file___66 *file;
	struct seq_file___64 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___65 *vm_ops;
};

struct bin_attribute___66;

struct attribute_group___66 {
	const char *name;
	umode_t (*is_visible)(struct kobject___66 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___66 *, struct bin_attribute___66 *, int);
	struct attribute **attrs;
	struct bin_attribute___66 **bin_attrs;
};

struct bin_attribute___66 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___66 * (*f_mapping)();
	ssize_t (*read)(struct file___66 *, struct kobject___66 *, struct bin_attribute___66 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___66 *, struct kobject___66 *, struct bin_attribute___66 *, char *, loff_t, size_t);
	int (*mmap)(struct file___66 *, struct kobject___66 *, struct bin_attribute___66 *, struct vm_area_struct___71 *);
};

struct sysfs_ops___66 {
	ssize_t (*show)(struct kobject___66 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___66 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___66;

struct kset___66 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___66 kobj;
	const struct kset_uevent_ops___66 *uevent_ops;
};

struct kobj_type___66 {
	void (*release)(struct kobject___66 *);
	const struct sysfs_ops___66 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___66 **default_groups;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___66 *);
	const void * (*namespace)(struct kobject___66 *);
	void (*get_ownership)(struct kobject___66 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___66 {
	int (* const filter)(struct kset___66 *, struct kobject___66 *);
	const char * (* const name)(struct kset___66 *, struct kobject___66 *);
	int (* const uevent)(struct kset___66 *, struct kobject___66 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___63 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___63 *);
	int (*get)(char *, const struct kernel_param___63 *);
	void (*free)(void *);
};

struct kparam_array___63;

struct kernel_param___63 {
	const char *name;
	struct module___64 *mod;
	const struct kernel_param_ops___63 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___63 *arr;
	};
};

struct kparam_array___63 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___63 *ops;
	void *elem;
};

struct module_attribute___63 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___63 *, struct module_kobject___63 *, char *);
	ssize_t (*store)(struct module_attribute___63 *, struct module_kobject___63 *, const char *, size_t);
	void (*setup)(struct module___64 *, const char *);
	int (*test)(struct module___64 *);
	void (*free)(struct module___64 *);
};

struct dev_pagemap_ops___65 {
	void (*page_free)(struct page___71 *);
	void (*kill)(struct dev_pagemap___65 *);
	void (*cleanup)(struct dev_pagemap___65 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___65 *);
};

struct bpf_iter_aux_info___15;

typedef int (*bpf_iter_init_seq_priv_t___15)(void *, struct bpf_iter_aux_info___15 *);

struct bpf_map___15;

struct bpf_iter_aux_info___15 {
	struct bpf_map___15 *map;
};

struct bpf_iter_seq_info___15 {
	const struct seq_operations___64 *seq_ops;
	bpf_iter_init_seq_priv_t___15 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___64 {
	void * (*start)(struct seq_file___64 *, loff_t *);
	void (*stop)(struct seq_file___64 *, void *);
	void * (*next)(struct seq_file___64 *, void *, loff_t *);
	int (*show)(struct seq_file___64 *, void *);
};

struct bpf_prog_aux___15;

struct bpf_prog___14;

struct bpf_map_ops___15 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___15 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___15 *, struct file___66 *);
	void (*map_free)(struct bpf_map___15 *);
	int (*map_get_next_key)(struct bpf_map___15 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___15 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___15 *, void *);
	int (*map_lookup_batch)(struct bpf_map___15 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___15 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___15 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___15 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___15 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___15 *, void *);
	int (*map_update_elem)(struct bpf_map___15 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___15 *, void *);
	int (*map_push_elem)(struct bpf_map___15 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___15 *, void *);
	int (*map_peek_elem)(struct bpf_map___15 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___15 *, struct file___66 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___15 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___15 *, void *, struct seq_file___64 *);
	int (*map_check_btf)(const struct bpf_map___15 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___15 *, struct bpf_prog_aux___15 *);
	void (*map_poke_untrack)(struct bpf_map___15 *, struct bpf_prog_aux___15 *);
	void (*map_poke_run)(struct bpf_map___15 *, u32, struct bpf_prog___14 *, struct bpf_prog___14 *);
	int (*map_direct_value_addr)(const struct bpf_map___15 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___15 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___15 *, struct vm_area_struct___71 *);
	__poll_t (*map_poll)(struct bpf_map___15 *, struct file___66 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___15 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___15 *, const struct bpf_map___15 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___15 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___15 *iter_seq_info;
};

struct bpf_map___15 {
	const struct bpf_map_ops___15 *ops;
	struct bpf_map___15 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___15;

struct bpf_jit_poke_descriptor___15;

struct bpf_prog_ops___14;

struct btf_mod_pair___15;

struct bpf_prog_offload___14;

struct bpf_prog_aux___15 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___14 *dst_prog;
	struct bpf_trampoline___15 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___14 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___15 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___14 *ops;
	struct bpf_map___15 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___15 *used_btfs;
	struct bpf_prog___14 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___15 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___14 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___14 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___15 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___14;

struct bpf_map_dev_ops___14 {
	int (*map_get_next_key)(struct bpf_offloaded_map___14 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___14 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___14 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___14 *, void *);
};

struct net_device___19;

struct bpf_offloaded_map___14 {
	struct bpf_map___15 map;
	struct net_device___19 *netdev;
	const struct bpf_map_dev_ops___14 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___16;

typedef rx_handler_result_t rx_handler_func_t___14(struct sk_buff___16 **);

typedef struct {
	struct net___17 *net;
} possible_net_t___14;

struct wakeup_source___59;

struct dev_pm_info___59 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___59 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___59 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___59;

struct bus_type___59;

struct device_driver___59;

struct dev_pm_domain___59;

struct fwnode_handle___59;

struct class___59;

struct device___59 {
	struct kobject___66 kobj;
	struct device___59 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___59 *type;
	struct bus_type___59 *bus;
	struct device_driver___59 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___59 power;
	struct dev_pm_domain___59 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___59 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___59 *class;
	const struct attribute_group___66 **groups;
	void (*release)(struct device___59 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___14 {
	struct bpf_prog___14 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___14;

struct net_device_ops___14;

struct xfrmdev_ops___14;

struct header_ops___14;

struct netdev_rx_queue___14;

struct mini_Qdisc___14;

struct netdev_queue___14;

struct Qdisc___14;

struct xdp_dev_bulk_queue___2;

struct rtnl_link_ops___14;

struct dcbnl_rtnl_ops___14;

struct net_device___19 {
	char name[16];
	struct netdev_name_node___14 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___14 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___14 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___14 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___66 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___14 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___14 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___14 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___14 *miniq_ingress;
	struct netdev_queue___14 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___14 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___14 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue___2 *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___14 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___14 = 0,
		NETREG_REGISTERED___14 = 1,
		NETREG_UNREGISTERING___14 = 2,
		NETREG_UNREGISTERED___14 = 3,
		NETREG_RELEASED___14 = 4,
		NETREG_DUMMY___14 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___14 = 0,
		RTNL_LINK_INITIALIZING___14 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___19 *);
	struct netpoll_info *npinfo;
	possible_net_t___14 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___59 dev;
	const struct attribute_group___66 *sysfs_groups[4];
	const struct attribute_group___66 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___14 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___14 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___14 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___14 {
	int (*test_run)(struct bpf_prog___14 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___14 {
	struct bpf_prog___14 *prog;
	struct net_device___19 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___15 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___14 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___64 *mod;
};

struct bpf_jit_poke_descriptor___15 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___15 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___15 {
	struct btf *btf;
	struct module___64 *module;
};

struct bpf_prog_array_item___14 {
	struct bpf_prog___14 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___14 {
	struct callback_head rcu;
	struct bpf_prog_array_item___14 items[0];
};

struct sk_buff___16 {
	union {
		struct {
			struct sk_buff___16 *next;
			struct sk_buff___16 *prev;
			union {
				struct net_device___19 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___2 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___16 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct fwnode_operations___59;

struct fwnode_handle___59 {
	struct fwnode_handle___59 *secondary;
	const struct fwnode_operations___59 *ops;
	struct device___59 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___59;

struct fwnode_endpoint___59;

struct fwnode_operations___59 {
	struct fwnode_handle___59 * (*get)(struct fwnode_handle___59 *);
	void (*put)(struct fwnode_handle___59 *);
	bool (*device_is_available)(const struct fwnode_handle___59 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___59 *, const struct device___59 *);
	bool (*property_present)(const struct fwnode_handle___59 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___59 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___59 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___59 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*get_parent)(const struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*get_next_child_node)(const struct fwnode_handle___59 *, struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*get_named_child_node)(const struct fwnode_handle___59 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___59 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___59 *);
	struct fwnode_handle___59 * (*graph_get_next_endpoint)(const struct fwnode_handle___59 *, struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*graph_get_remote_endpoint)(const struct fwnode_handle___59 *);
	struct fwnode_handle___59 * (*graph_get_port_parent)(struct fwnode_handle___59 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___59 *, struct fwnode_endpoint___59 *);
	int (*add_links)(struct fwnode_handle___59 *);
};

struct fwnode_endpoint___59 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___59 *local_fwnode;
};

struct fwnode_reference_args___59 {
	struct fwnode_handle___59 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fqdir___16;

struct netns_ipv4___16 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___16 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___16 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___16 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___19 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___16 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___16 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___16 *);
	int (*local_out)(struct net___17 *, struct sock *, struct sk_buff___16 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___16 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___16 {
	struct dst_ops___16 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___16 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___16 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___16 *fqdir;
};

struct sk_buff_head___14 {
	struct sk_buff___16 *next;
	struct sk_buff___16 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___14 {
	struct bpf_prog_array___14 *run_array[2];
	struct bpf_prog___14 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___16 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___16 xfrm4_dst_ops;
	struct dst_ops___16 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___17 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct idr netns_ids;
	struct ns_common___11 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___19 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___16 ipv4;
	struct netns_ipv6___16 ipv6;
	struct netns_ieee802154_lowpan___16 ieee802154_lowpan;
	struct netns_sctp___9 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___14 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___14 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___16 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___55 {
	struct ns_common___11 ns;
	struct user_namespace___10 *user_ns;
	struct ucounts___10 *ucounts;
	struct css_set___55 *root_cset;
};

struct bio_vec___37 {
	struct page___71 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

enum net_device_flags {
	IFF_UP = 1,
	IFF_BROADCAST = 2,
	IFF_DEBUG = 4,
	IFF_LOOPBACK = 8,
	IFF_POINTOPOINT = 16,
	IFF_NOTRAILERS = 32,
	IFF_RUNNING = 64,
	IFF_NOARP = 128,
	IFF_PROMISC = 256,
	IFF_ALLMULTI = 512,
	IFF_MASTER = 1024,
	IFF_SLAVE = 2048,
	IFF_MULTICAST = 4096,
	IFF_PORTSEL = 8192,
	IFF_AUTOMEDIA = 16384,
	IFF_DYNAMIC = 32768,
	IFF_LOWER_UP = 65536,
	IFF_DORMANT = 131072,
	IFF_ECHO = 262144,
};

struct dev_pm_ops___59 {
	int (*prepare)(struct device___59 *);
	void (*complete)(struct device___59 *);
	int (*suspend)(struct device___59 *);
	int (*resume)(struct device___59 *);
	int (*freeze)(struct device___59 *);
	int (*thaw)(struct device___59 *);
	int (*poweroff)(struct device___59 *);
	int (*restore)(struct device___59 *);
	int (*suspend_late)(struct device___59 *);
	int (*resume_early)(struct device___59 *);
	int (*freeze_late)(struct device___59 *);
	int (*thaw_early)(struct device___59 *);
	int (*poweroff_late)(struct device___59 *);
	int (*restore_early)(struct device___59 *);
	int (*suspend_noirq)(struct device___59 *);
	int (*resume_noirq)(struct device___59 *);
	int (*freeze_noirq)(struct device___59 *);
	int (*thaw_noirq)(struct device___59 *);
	int (*poweroff_noirq)(struct device___59 *);
	int (*restore_noirq)(struct device___59 *);
	int (*runtime_suspend)(struct device___59 *);
	int (*runtime_resume)(struct device___59 *);
	int (*runtime_idle)(struct device___59 *);
};

struct wakeup_source___59 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___59 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___59 {
	struct dev_pm_ops___59 ops;
	int (*start)(struct device___59 *);
	void (*detach)(struct device___59 *, bool);
	int (*activate)(struct device___59 *);
	void (*sync)(struct device___59 *);
	void (*dismiss)(struct device___59 *);
};

struct bus_type___59 {
	const char *name;
	const char *dev_name;
	struct device___59 *dev_root;
	const struct attribute_group___66 **bus_groups;
	const struct attribute_group___66 **dev_groups;
	const struct attribute_group___66 **drv_groups;
	int (*match)(struct device___59 *, struct device_driver___59 *);
	int (*uevent)(struct device___59 *, struct kobj_uevent_env *);
	int (*probe)(struct device___59 *);
	void (*sync_state)(struct device___59 *);
	void (*remove)(struct device___59 *);
	void (*shutdown)(struct device___59 *);
	int (*online)(struct device___59 *);
	int (*offline)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	int (*num_vf)(struct device___59 *);
	int (*dma_configure)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___59 {
	const char *name;
	struct bus_type___59 *bus;
	struct module___64 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___59 *);
	void (*sync_state)(struct device___59 *);
	int (*remove)(struct device___59 *);
	void (*shutdown)(struct device___59 *);
	int (*suspend)(struct device___59 *, pm_message_t);
	int (*resume)(struct device___59 *);
	const struct attribute_group___66 **groups;
	const struct attribute_group___66 **dev_groups;
	const struct dev_pm_ops___59 *pm;
	void (*coredump)(struct device___59 *);
	struct driver_private *p;
};

struct device_type___59 {
	const char *name;
	const struct attribute_group___66 **groups;
	int (*uevent)(struct device___59 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___59 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___59 *);
	const struct dev_pm_ops___59 *pm;
};

struct class___59 {
	const char *name;
	struct module___64 *owner;
	const struct attribute_group___66 **class_groups;
	const struct attribute_group___66 **dev_groups;
	struct kobject___66 *dev_kobj;
	int (*dev_uevent)(struct device___59 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___59 *, umode_t *);
	void (*class_release)(struct class___59 *);
	void (*dev_release)(struct device___59 *);
	int (*shutdown_pre)(struct device___59 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___59 *);
	void (*get_ownership)(struct device___59 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___59 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___26;

struct pipe_buffer___26 {
	struct page___71 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___26 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___26 {
	int (*confirm)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
	void (*release)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
	bool (*try_steal)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
	bool (*get)(struct pipe_inode_info___26 *, struct pipe_buffer___26 *);
};

struct xdp_rxq_info___14 {
	struct net_device___19 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___14 {
	struct net_device___19 *dev;
};

struct xdp_buff___14 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___14 *rxq;
	struct xdp_txq_info___14 *txq;
	u32 frame_sz;
};

struct xdp_frame___14 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___19 *dev_rx;
};

struct inet_frags___16;

struct fqdir___16 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___16 *f;
	struct net___17 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___16;

struct inet_frags___16 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___16 *, const void *);
	void (*destructor)(struct inet_frag_queue___16 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___16 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___16 *fragments_tail;
	struct sk_buff___16 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___16 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___14 {
	int (*ieee_getets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___19 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___19 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___19 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___19 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___19 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___19 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___19 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___19 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___19 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___19 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___19 *);
	u8 (*setstate)(struct net_device___19 *, u8);
	void (*getpermhwaddr)(struct net_device___19 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___19 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___19 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___19 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___19 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___19 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___19 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___19 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___19 *, int, u8 *);
	void (*setpfccfg)(struct net_device___19 *, int, u8);
	void (*getpfccfg)(struct net_device___19 *, int, u8 *);
	u8 (*setall)(struct net_device___19 *);
	u8 (*getcap)(struct net_device___19 *, int, u8 *);
	int (*getnumtcs)(struct net_device___19 *, int, u8 *);
	int (*setnumtcs)(struct net_device___19 *, int, u8);
	u8 (*getpfcstate)(struct net_device___19 *);
	void (*setpfcstate)(struct net_device___19 *, u8);
	void (*getbcncfg)(struct net_device___19 *, int, u32 *);
	void (*setbcncfg)(struct net_device___19 *, int, u32);
	void (*getbcnrp)(struct net_device___19 *, int, u8 *);
	void (*setbcnrp)(struct net_device___19 *, int, u8);
	int (*setapp)(struct net_device___19 *, u8, u16, u8);
	int (*getapp)(struct net_device___19 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___19 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___19 *, int, u8);
	u8 (*getdcbx)(struct net_device___19 *);
	u8 (*setdcbx)(struct net_device___19 *, u8);
	int (*peer_getappinfo)(struct net_device___19 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___19 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___19 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___19 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___19 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___19 *, struct dcbnl_buffer *);
};

struct cftype___55;

struct cgroup_subsys___55 {
	struct cgroup_subsys_state___55 * (*css_alloc)(struct cgroup_subsys_state___55 *);
	int (*css_online)(struct cgroup_subsys_state___55 *);
	void (*css_offline)(struct cgroup_subsys_state___55 *);
	void (*css_released)(struct cgroup_subsys_state___55 *);
	void (*css_free)(struct cgroup_subsys_state___55 *);
	void (*css_reset)(struct cgroup_subsys_state___55 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___55 *, int);
	int (*css_extra_stat_show)(struct seq_file___64 *, struct cgroup_subsys_state___55 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___73 *, struct css_set___55 *);
	void (*cancel_fork)(struct task_struct___73 *, struct css_set___55 *);
	void (*fork)(struct task_struct___73 *);
	void (*exit)(struct task_struct___73 *);
	void (*release)(struct task_struct___73 *);
	void (*bind)(struct cgroup_subsys_state___55 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___55 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___55 *dfl_cftypes;
	struct cftype___55 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___55 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___55 *updated_children;
	struct cgroup___55 *updated_next;
};

struct cgroup_root___55 {
	struct kernfs_root___66 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___55 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___55 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___55 *ss;
	struct list_head node;
	struct kernfs_ops___66 *kf_ops;
	int (*open)(struct kernfs_open_file___66 *);
	void (*release)(struct kernfs_open_file___66 *);
	u64 (*read_u64)(struct cgroup_subsys_state___55 *, struct cftype___55 *);
	s64 (*read_s64)(struct cgroup_subsys_state___55 *, struct cftype___55 *);
	int (*seq_show)(struct seq_file___64 *, void *);
	void * (*seq_start)(struct seq_file___64 *, loff_t *);
	void * (*seq_next)(struct seq_file___64 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___64 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___55 *, struct cftype___55 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___55 *, struct cftype___55 *, s64);
	ssize_t (*write)(struct kernfs_open_file___66 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___66 *, struct poll_table_struct___5 *);
};

struct netlink_callback___14 {
	struct sk_buff___16 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___16 *, struct netlink_callback___14 *);
	int (*done)(struct netlink_callback___14 *);
	void *data;
	struct module___64 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum netdev_tx___2 {
	__NETDEV_TX_MIN___2 = 0,
	NETDEV_TX_OK___2 = 0,
	NETDEV_TX_BUSY___2 = 16,
};

typedef enum netdev_tx___2 netdev_tx_t___2;

struct header_ops___14 {
	int (*create)(struct sk_buff___16 *, struct net_device___19 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___16 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___19 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___16 *);
};

struct netdev_queue___14 {
	struct net_device___19 *dev;
	struct Qdisc___14 *qdisc;
	struct Qdisc___14 *qdisc_sleeping;
	struct kobject___66 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___19 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___14 {
	struct sk_buff___16 *head;
	struct sk_buff___16 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___14;

struct Qdisc___14 {
	int (*enqueue)(struct sk_buff___16 *, struct Qdisc___14 *, struct sk_buff___16 **);
	struct sk_buff___16 * (*dequeue)(struct Qdisc___14 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___14 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___14 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___14 gso_skb;
	struct qdisc_skb_head___14 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___14 *next_sched;
	struct sk_buff_head___14 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___14 {
	struct xdp_rxq_info___14 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___66 kobj;
	struct net_device___19 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___14 {
	enum net_device_path_type type;
	const struct net_device___19 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___14 = 0,
				DEV_PATH_BR_VLAN_TAG___14 = 1,
				DEV_PATH_BR_VLAN_UNTAG___14 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___14 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___14 {
	const struct net_device___19 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___14 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___14 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___14 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___14 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___16 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___14 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___19 *dev;
	const char *name;
};

struct net_device_ops___14 {
	int (*ndo_init)(struct net_device___19 *);
	void (*ndo_uninit)(struct net_device___19 *);
	int (*ndo_open)(struct net_device___19 *);
	int (*ndo_stop)(struct net_device___19 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___16 *, struct net_device___19 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___16 *, struct net_device___19 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___19 *, struct sk_buff___16 *, struct net_device___19 *);
	void (*ndo_change_rx_flags)(struct net_device___19 *, int);
	void (*ndo_set_rx_mode)(struct net_device___19 *);
	int (*ndo_set_mac_address)(struct net_device___19 *, void *);
	int (*ndo_validate_addr)(struct net_device___19 *);
	int (*ndo_do_ioctl)(struct net_device___19 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___19 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___19 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___19 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___19 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___19 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___19 *, int);
	int (*ndo_neigh_setup)(struct net_device___19 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___19 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___19 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___19 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___19 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___19 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___19 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___19 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___19 *);
	int (*ndo_netpoll_setup)(struct net_device___19 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___19 *);
	int (*ndo_set_vf_mac)(struct net_device___19 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___19 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___19 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___19 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___19 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___19 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___19 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___19 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___19 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___19 *, int, struct sk_buff___16 *);
	int (*ndo_get_vf_guid)(struct net_device___19 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___19 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___19 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___19 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___19 *);
	int (*ndo_fcoe_disable)(struct net_device___19 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___19 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___19 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___19 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___19 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___19 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___19 *, const struct sk_buff___16 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___19 *, struct net_device___19 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___19 *, struct net_device___19 *);
	struct net_device___19 * (*ndo_get_xmit_slave)(struct net_device___19 *, struct sk_buff___16 *, bool);
	struct net_device___19 * (*ndo_sk_get_lower_dev)(struct net_device___19 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___19 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___19 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___19 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___19 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___16 *, struct netlink_callback___14 *, struct net_device___19 *, struct net_device___19 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___16 *, struct nlattr **, struct net_device___19 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___19 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___16 *, u32, u32, struct net_device___19 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___19 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___19 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___19 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___19 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___19 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___19 *, struct net_device___19 *);
	void (*ndo_dfwd_del_station)(struct net_device___19 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___19 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___19 *);
	int (*ndo_change_proto_down)(struct net_device___19 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___19 *, struct sk_buff___16 *);
	void (*ndo_set_rx_headroom)(struct net_device___19 *, int);
	int (*ndo_bpf)(struct net_device___19 *, struct netdev_bpf___14 *);
	int (*ndo_xdp_xmit)(struct net_device___19 *, int, struct xdp_frame___14 **, u32);
	struct net_device___19 * (*ndo_xdp_get_xmit_slave)(struct net_device___19 *, struct xdp_buff___14 *);
	int (*ndo_xsk_wakeup)(struct net_device___19 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___19 *);
	int (*ndo_tunnel_ctl)(struct net_device___19 *, struct ip_tunnel_parm *, int);
	struct net_device___19 * (*ndo_get_peer_dev)(struct net_device___19 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___14 *, struct net_device_path___14 *);
};

enum netdev_priv_flags {
	IFF_802_1Q_VLAN = 1,
	IFF_EBRIDGE = 2,
	IFF_BONDING = 4,
	IFF_ISATAP = 8,
	IFF_WAN_HDLC = 16,
	IFF_XMIT_DST_RELEASE = 32,
	IFF_DONT_BRIDGE = 64,
	IFF_DISABLE_NETPOLL = 128,
	IFF_MACVLAN_PORT = 256,
	IFF_BRIDGE_PORT = 512,
	IFF_OVS_DATAPATH = 1024,
	IFF_TX_SKB_SHARING = 2048,
	IFF_UNICAST_FLT = 4096,
	IFF_TEAM_PORT = 8192,
	IFF_SUPP_NOFCS = 16384,
	IFF_LIVE_ADDR_CHANGE = 32768,
	IFF_MACVLAN = 65536,
	IFF_XMIT_DST_RELEASE_PERM = 131072,
	IFF_L3MDEV_MASTER = 262144,
	IFF_NO_QUEUE = 524288,
	IFF_OPENVSWITCH = 1048576,
	IFF_L3MDEV_SLAVE = 2097152,
	IFF_TEAM = 4194304,
	IFF_RXFH_CONFIGURED = 8388608,
	IFF_PHONY_HEADROOM = 16777216,
	IFF_MACSEC = 33554432,
	IFF_NO_RX_HANDLER = 67108864,
	IFF_FAILOVER = 134217728,
	IFF_FAILOVER_SLAVE = 268435456,
	IFF_L3MDEV_RX_HANDLER = 536870912,
	IFF_LIVE_RENAME_OK = 1073741824,
	IFF_TX_SKB_NO_LINEAR = 0,
};

struct tcf_proto___14;

struct tcf_block___14;

struct mini_Qdisc___14 {
	struct tcf_proto___14 *filter_list;
	struct tcf_block___14 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct xdp_dev_bulk_queue___2 {
	struct xdp_frame___14 *q[16];
	struct list_head flush_node;
	struct net_device___19 *dev;
	struct net_device___19 *dev_rx;
	struct bpf_prog___14 *xdp_prog;
	unsigned int count;
};

struct rtnl_link_ops___14 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___19 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___19 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___17 *, struct net_device___19 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___19 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___19 *, struct list_head *);
	size_t (*get_size)(const struct net_device___19 *);
	int (*fill_info)(struct sk_buff___16 *, const struct net_device___19 *);
	size_t (*get_xstats_size)(const struct net_device___19 *);
	int (*fill_xstats)(struct sk_buff___16 *, const struct net_device___19 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___19 *, struct net_device___19 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___19 *, const struct net_device___19 *);
	int (*fill_slave_info)(struct sk_buff___16 *, const struct net_device___19 *, const struct net_device___19 *);
	struct net___17 * (*get_link_net)(const struct net_device___19 *);
	size_t (*get_linkxstats_size)(const struct net_device___19 *, int);
	int (*fill_linkxstats)(struct sk_buff___16 *, const struct net_device___19 *, int *, int);
};

enum netdev_cmd {
	NETDEV_UP = 1,
	NETDEV_DOWN = 2,
	NETDEV_REBOOT = 3,
	NETDEV_CHANGE = 4,
	NETDEV_REGISTER = 5,
	NETDEV_UNREGISTER = 6,
	NETDEV_CHANGEMTU = 7,
	NETDEV_CHANGEADDR = 8,
	NETDEV_PRE_CHANGEADDR = 9,
	NETDEV_GOING_DOWN = 10,
	NETDEV_CHANGENAME = 11,
	NETDEV_FEAT_CHANGE = 12,
	NETDEV_BONDING_FAILOVER = 13,
	NETDEV_PRE_UP = 14,
	NETDEV_PRE_TYPE_CHANGE = 15,
	NETDEV_POST_TYPE_CHANGE = 16,
	NETDEV_POST_INIT = 17,
	NETDEV_RELEASE = 18,
	NETDEV_NOTIFY_PEERS = 19,
	NETDEV_JOIN = 20,
	NETDEV_CHANGEUPPER = 21,
	NETDEV_RESEND_IGMP = 22,
	NETDEV_PRECHANGEMTU = 23,
	NETDEV_CHANGEINFODATA = 24,
	NETDEV_BONDING_INFO = 25,
	NETDEV_PRECHANGEUPPER = 26,
	NETDEV_CHANGELOWERSTATE = 27,
	NETDEV_UDP_TUNNEL_PUSH_INFO = 28,
	NETDEV_UDP_TUNNEL_DROP_INFO = 29,
	NETDEV_CHANGE_TX_QUEUE_LEN = 30,
	NETDEV_CVLAN_FILTER_PUSH_INFO = 31,
	NETDEV_CVLAN_FILTER_DROP_INFO = 32,
	NETDEV_SVLAN_FILTER_PUSH_INFO = 33,
	NETDEV_SVLAN_FILTER_DROP_INFO = 34,
};

struct netdev_notifier_info {
	struct net_device___19 *dev;
	struct netlink_ext_ack *extack;
};

struct gnet_dump___14 {
	spinlock_t *lock;
	struct sk_buff___16 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___14;

struct Qdisc_ops___14 {
	struct Qdisc_ops___14 *next;
	const struct Qdisc_class_ops___14 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___16 *, struct Qdisc___14 *, struct sk_buff___16 **);
	struct sk_buff___16 * (*dequeue)(struct Qdisc___14 *);
	struct sk_buff___16 * (*peek)(struct Qdisc___14 *);
	int (*init)(struct Qdisc___14 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___14 *);
	void (*destroy)(struct Qdisc___14 *);
	int (*change)(struct Qdisc___14 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___14 *);
	int (*change_tx_queue_len)(struct Qdisc___14 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___14 *, unsigned int);
	int (*dump)(struct Qdisc___14 *, struct sk_buff___16 *);
	int (*dump_stats)(struct Qdisc___14 *, struct gnet_dump___14 *);
	void (*ingress_block_set)(struct Qdisc___14 *, u32);
	void (*egress_block_set)(struct Qdisc___14 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___14 *);
	u32 (*egress_block_get)(struct Qdisc___14 *);
	struct module___64 *owner;
};

struct Qdisc_class_ops___14 {
	unsigned int flags;
	struct netdev_queue___14 * (*select_queue)(struct Qdisc___14 *, struct tcmsg *);
	int (*graft)(struct Qdisc___14 *, long unsigned int, struct Qdisc___14 *, struct Qdisc___14 **, struct netlink_ext_ack *);
	struct Qdisc___14 * (*leaf)(struct Qdisc___14 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___14 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___14 *, u32);
	int (*change)(struct Qdisc___14 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___14 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___14 *, struct qdisc_walker *);
	struct tcf_block___14 * (*tcf_block)(struct Qdisc___14 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___14 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___14 *, long unsigned int);
	int (*dump)(struct Qdisc___14 *, long unsigned int, struct sk_buff___16 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___14 *, long unsigned int, struct gnet_dump___14 *);
};

struct tcf_chain___14;

struct tcf_block___14 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___17 *net;
	struct Qdisc___14 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___14 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___14;

struct tcf_proto_ops___14;

struct tcf_proto___14 {
	struct tcf_proto___14 *next;
	void *root;
	int (*classify)(struct sk_buff___16 *, const struct tcf_proto___14 *, struct tcf_result___14 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___14 *ops;
	struct tcf_chain___14 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___14 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___14 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___14 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___16 *, const struct tcf_proto___14 *, struct tcf_result___14 *);
	int (*init)(struct tcf_proto___14 *);
	void (*destroy)(struct tcf_proto___14 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___14 *, u32);
	void (*put)(struct tcf_proto___14 *, void *);
	int (*change)(struct net___17 *, struct sk_buff___16 *, struct tcf_proto___14 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___14 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___14 *);
	void (*walk)(struct tcf_proto___14 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___14 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___14 *, void *);
	void (*hw_del)(struct tcf_proto___14 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___17 *, struct tcf_chain___14 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___17 *, struct tcf_proto___14 *, void *, struct sk_buff___16 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___17 *, struct tcf_proto___14 *, void *, struct sk_buff___16 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___16 *, struct net___17 *, void *);
	struct module___64 *owner;
	int flags;
};

struct tcf_chain___14 {
	struct mutex filter_chain_lock;
	struct tcf_proto___14 *filter_chain;
	struct list_head list;
	struct tcf_block___14 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___14 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_nh_params {
	u32 nh_family;
	union {
		u32 ipv4_nh;
		struct in6_addr ipv6_nh;
	};
};

struct bpf_redirect_info {
	u32 flags;
	u32 tgt_index;
	void *tgt_value;
	struct bpf_map___15 *map;
	u32 map_id;
	enum bpf_map_type map_type;
	u32 kern_flags;
	struct bpf_nh_params nh;
};

struct bpf_dtab;

struct bpf_dtab_netdev {
	struct net_device___19 *dev;
	struct hlist_node index_hlist;
	struct bpf_dtab *dtab;
	struct bpf_prog___14 *xdp_prog;
	struct callback_head rcu;
	unsigned int idx;
	struct bpf_devmap_val val;
};

struct bpf_dtab {
	struct bpf_map___15 map;
	struct bpf_dtab_netdev **netdev_map;
	struct list_head list;
	struct hlist_head *dev_index_head;
	spinlock_t index_lock;
	unsigned int items;
	u32 n_buckets;
	long: 32;
	long: 64;
	long: 64;
};

struct bpf_cpumap_val {
	__u32 qsize;
	union {
		int fd;
		__u32 id;
	} bpf_prog;
};

enum netdev_priv_flags___2 {
	IFF_802_1Q_VLAN___2 = 1,
	IFF_EBRIDGE___2 = 2,
	IFF_BONDING___2 = 4,
	IFF_ISATAP___2 = 8,
	IFF_WAN_HDLC___2 = 16,
	IFF_XMIT_DST_RELEASE___2 = 32,
	IFF_DONT_BRIDGE___2 = 64,
	IFF_DISABLE_NETPOLL___2 = 128,
	IFF_MACVLAN_PORT___2 = 256,
	IFF_BRIDGE_PORT___2 = 512,
	IFF_OVS_DATAPATH___2 = 1024,
	IFF_TX_SKB_SHARING___2 = 2048,
	IFF_UNICAST_FLT___2 = 4096,
	IFF_TEAM_PORT___2 = 8192,
	IFF_SUPP_NOFCS___2 = 16384,
	IFF_LIVE_ADDR_CHANGE___2 = 32768,
	IFF_MACVLAN___2 = 65536,
	IFF_XMIT_DST_RELEASE_PERM___2 = 131072,
	IFF_L3MDEV_MASTER___2 = 262144,
	IFF_NO_QUEUE___2 = 524288,
	IFF_OPENVSWITCH___2 = 1048576,
	IFF_L3MDEV_SLAVE___2 = 2097152,
	IFF_TEAM___2 = 4194304,
	IFF_RXFH_CONFIGURED___2 = 8388608,
	IFF_PHONY_HEADROOM___2 = 16777216,
	IFF_MACSEC___2 = 33554432,
	IFF_NO_RX_HANDLER___2 = 67108864,
	IFF_FAILOVER___2 = 134217728,
	IFF_FAILOVER_SLAVE___2 = 268435456,
	IFF_L3MDEV_RX_HANDLER___2 = 536870912,
	IFF_LIVE_RENAME_OK___2 = 1073741824,
	IFF_TX_SKB_NO_LINEAR___2 = 2147483648,
};

struct bpf_redirect_info___2 {
	u32 flags;
	u32 tgt_index;
	void *tgt_value;
	struct bpf_map___14 *map;
	u32 map_id;
	enum bpf_map_type map_type;
	u32 kern_flags;
	struct bpf_nh_params nh;
};

struct bpf_cpu_map_entry;

struct xdp_bulk_queue {
	void *q[8];
	struct list_head flush_node;
	struct bpf_cpu_map_entry *obj;
	unsigned int count;
};

struct bpf_cpu_map;

struct bpf_cpu_map_entry {
	u32 cpu;
	int map_id;
	struct xdp_bulk_queue *bulkq;
	struct bpf_cpu_map *cmap;
	struct ptr_ring *queue;
	struct task_struct___72 *kthread;
	struct bpf_cpumap_val value;
	struct bpf_prog___13 *prog;
	atomic_t refcnt;
	struct callback_head rcu;
	struct work_struct kthread_stop_wq;
};

struct bpf_cpu_map {
	struct bpf_map___14 map;
	struct bpf_cpu_map_entry **cpu_map;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___68;

struct super_block___68;

struct module___65;

struct file_system_type___67 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___68 * (*mount)(struct file_system_type___67 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___68 *);
	struct module___65 *owner;
	struct file_system_type___67 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___67;

struct kiocb___67;

struct iov_iter___38;

struct vm_area_struct___72;

struct inode___68;

struct file_lock___67;

struct page___72;

struct pipe_inode_info___27;

struct seq_file___65;

struct file_operations___67 {
	struct module___65 *owner;
	loff_t (*llseek)(struct file___67 *, loff_t, int);
	ssize_t (*read)(struct file___67 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___67 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___67 *, struct iov_iter___38 *);
	ssize_t (*write_iter)(struct kiocb___67 *, struct iov_iter___38 *);
	int (*iopoll)(struct kiocb___67 *, bool);
	int (*iterate)(struct file___67 *, struct dir_context *);
	int (*iterate_shared)(struct file___67 *, struct dir_context *);
	__poll_t (*poll)(struct file___67 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___67 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___67 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___67 *, struct vm_area_struct___72 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___68 *, struct file___67 *);
	int (*flush)(struct file___67 *, fl_owner_t);
	int (*release)(struct inode___68 *, struct file___67 *);
	int (*fsync)(struct file___67 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___67 *, int);
	int (*lock)(struct file___67 *, int, struct file_lock___67 *);
	ssize_t (*sendpage)(struct file___67 *, struct page___72 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___67 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___67 *, long unsigned int);
	int (*flock)(struct file___67 *, int, struct file_lock___67 *);
	ssize_t (*splice_write)(struct pipe_inode_info___27 *, struct file___67 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___67 *, loff_t *, struct pipe_inode_info___27 *, size_t, unsigned int);
	int (*setlease)(struct file___67 *, long int, struct file_lock___67 **, void **);
	long int (*fallocate)(struct file___67 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___65 *, struct file___67 *);
	ssize_t (*copy_file_range)(struct file___67 *, loff_t, struct file___67 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___67 *, loff_t, struct file___67 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___67 *, loff_t, loff_t, int);
};

struct vmacache___72 {
	u64 seqnum;
	struct vm_area_struct___72 *vmas[4];
};

struct page_frag___72 {
	struct page___72 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___73;

struct pid___60;

struct cred___10;

struct nsproxy___65;

struct signal_struct___68;

struct css_set___56;

struct vm_struct___68;

struct task_struct___74 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___74 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___73 *mm;
	struct mm_struct___73 *active_mm;
	struct vmacache___72 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___74 *real_parent;
	struct task_struct___74 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___74 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___60 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___10 *ptracer_cred;
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___65 *nsproxy;
	struct signal_struct___68 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___74 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___30 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___56 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___27 *splice_pipe;
	struct page_frag___72 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___74 *oom_reaper_list;
	struct vm_struct___68 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___67;

struct kobj_type___67;

struct kernfs_node___67;

struct kobject___67 {
	const char *name;
	struct list_head entry;
	struct kobject___67 *parent;
	struct kset___67 *kset;
	struct kobj_type___67 *ktype;
	struct kernfs_node___67 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___64 {
	struct kobject___67 kobj;
	struct module___65 *mod;
	struct kobject___67 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___64 {
	struct module___65 *mod;
	struct latch_tree_node node;
};

struct module_layout___64 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___64 mtn;
};

struct module_attribute___64;

struct kernel_param___64;

struct module___65 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___64 mkobj;
	struct module_attribute___64 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___67 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___64 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___64 core_layout;
	struct module_layout___64 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___67;

struct path___67 {
	struct vfsmount___67 *mnt;
	struct dentry___68 *dentry;
};

struct fown_struct___60 {
	rwlock_t lock;
	struct pid___60 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___67;

struct file___67 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___67 f_path;
	struct inode___68 *f_inode;
	const struct file_operations___67 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___60 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___67 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___72 *pgtable_t___72;

struct page_pool___24;

struct dev_pagemap___66;

struct page___72 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___67 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___24 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___72 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___72 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___73 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___66 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___66;

struct vm_area_struct___72 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___72 *vm_next;
	struct vm_area_struct___72 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___73 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___66 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___67 *vm_file;
	struct file___67 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___72;

struct user_namespace___11;

struct mm_struct___73 {
	struct {
		struct vm_area_struct___72 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___67 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___72 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___74 *owner;
		struct user_namespace___11 *user_ns;
		struct file___67 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___67;

struct address_space___67 {
	struct inode___68 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___67 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___60;

struct page_pool_params___24 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___60 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___24 {
	u32 count;
	struct page___72 *cache[128];
};

struct page_pool___24 {
	struct page_pool_params___24 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___72 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___24 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___66;

struct dev_pagemap___66 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___66 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___66;

struct vm_operations_struct___66 {
	void (*open)(struct vm_area_struct___72 *);
	void (*close)(struct vm_area_struct___72 *);
	int (*may_split)(struct vm_area_struct___72 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___72 *);
	int (*mprotect)(struct vm_area_struct___72 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___66 *);
	vm_fault_t (*huge_fault)(struct vm_fault___66 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___66 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___72 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___66 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___66 *);
	int (*access)(struct vm_area_struct___72 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___72 *);
	int (*set_policy)(struct vm_area_struct___72 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___72 *, long unsigned int);
	struct page___72 * (*find_special_page)(struct vm_area_struct___72 *, long unsigned int);
};

struct core_thread___72 {
	struct task_struct___74 *task;
	struct core_thread___72 *next;
};

struct core_state___72 {
	atomic_t nr_threads;
	struct core_thread___72 dumper;
	struct completion startup;
};

struct proc_ns_operations___12;

struct ns_common___12 {
	atomic_long_t stashed;
	const struct proc_ns_operations___12 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___11;

struct user_namespace___11 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___11 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___12 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___11 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___66 {
	const struct {
		struct vm_area_struct___72 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___72 *cow_page;
	struct page___72 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___72 prealloc_pte;
};

struct pid_namespace___60;

struct upid___60 {
	int nr;
	struct pid_namespace___60 *ns;
};

struct pid_namespace___60 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___74 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___60 *parent;
	struct fs_pin *bacct;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	int reboot;
	struct ns_common___12 ns;
};

struct pid___60 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___60 numbers[1];
};

struct rhlist_head {
	struct rhash_head rhead;
	struct rhlist_head *next;
};

struct ucounts___11 {
	struct hlist_node node;
	struct user_namespace___11 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___68 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___74 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___74 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___60 *pids[4];
	struct pid___60 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___73 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___10 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct net___18;

struct cgroup_namespace___56;

struct nsproxy___65 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___60 *pid_ns_for_children;
	struct net___18 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___56 *cgroup_ns;
};

struct cgroup_subsys_state___56;

struct cgroup___56;

struct css_set___56 {
	struct cgroup_subsys_state___56 *subsys[14];
	refcount_t refcount;
	struct css_set___56 *dom_cset;
	struct cgroup___56 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___56 *mg_src_cgrp;
	struct cgroup___56 *mg_dst_cgrp;
	struct css_set___56 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___67;

struct pipe_buffer___27;

struct pipe_inode_info___27 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___72 *tmp_page;
	struct fasync_struct___67 *fasync_readers;
	struct fasync_struct___67 *fasync_writers;
	struct pipe_buffer___27 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___68 {
	struct vm_struct___68 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___72 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___67;

struct dentry___68 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___68 *d_parent;
	struct qstr d_name;
	struct inode___68 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___67 *d_op;
	struct super_block___68 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___67;

struct inode___68 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___67 *i_op;
	struct super_block___68 *i_sb;
	struct address_space___67 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___67 *i_fop;
		void (*free_inode)(struct inode___68 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___67 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___27 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___67 {
	int (*d_revalidate)(struct dentry___68 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___68 *, unsigned int);
	int (*d_hash)(const struct dentry___68 *, struct qstr *);
	int (*d_compare)(const struct dentry___68 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___68 *);
	int (*d_init)(struct dentry___68 *);
	void (*d_release)(struct dentry___68 *);
	void (*d_prune)(struct dentry___68 *);
	void (*d_iput)(struct dentry___68 *, struct inode___68 *);
	char * (*d_dname)(struct dentry___68 *, char *, int);
	struct vfsmount___67 * (*d_automount)(struct path___67 *);
	int (*d_manage)(const struct path___67 *, bool);
	struct dentry___68 * (*d_real)(struct dentry___68 *, const struct inode___68 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___67;

struct mem_dqinfo___67 {
	struct quota_format_type___67 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___67;

struct quota_info___67 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___68 *files[3];
	struct mem_dqinfo___67 info[3];
	const struct quota_format_ops___67 *ops[3];
};

struct rcuwait___68 {
	struct task_struct___74 *task;
};

struct percpu_rw_semaphore___68 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___68 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___67 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___68 rw_sem[3];
};

struct super_operations___67;

struct dquot_operations___67;

struct quotactl_ops___67;

struct super_block___68 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___67 *s_type;
	const struct super_operations___67 *s_op;
	const struct dquot_operations___67 *dq_op;
	const struct quotactl_ops___67 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___68 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___67 s_dquot;
	struct sb_writers___67 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___67 *s_d_op;
	int cleancache_poolid;
	struct shrinker___27 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___11 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___67 {
	struct dentry___68 *mnt_root;
	struct super_block___68 *mnt_sb;
	int mnt_flags;
	struct user_namespace___11 *mnt_userns;
};

struct cgroup_subsys___56;

struct cgroup_subsys_state___56 {
	struct cgroup___56 *cgroup;
	struct cgroup_subsys___56 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___56 *parent;
};

struct cgroup_file___56 {
	struct kernfs_node___67 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___56 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___74 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___15;

struct cgroup_bpf___15 {
	struct bpf_prog_array___15 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___15 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___56;

struct cgroup_rstat_cpu___56;

struct cgroup___56 {
	struct cgroup_subsys_state___56 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___67 *kn;
	struct cgroup_file___56 procs_file;
	struct cgroup_file___56 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___56 *subsys[14];
	struct cgroup_root___56 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___56 *dom_cgrp;
	struct cgroup___56 *old_dom_cgrp;
	struct cgroup_rstat_cpu___56 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___56 psi;
	struct cgroup_bpf___15 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___67 {
	struct file___67 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___67 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___68 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___67 *ia_file;
};

struct dquot___67 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___68 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___67 {
	int qf_fmt_id;
	const struct quota_format_ops___67 *qf_ops;
	struct module___65 *qf_owner;
	struct quota_format_type___67 *qf_next;
};

struct quota_format_ops___67 {
	int (*check_quota_file)(struct super_block___68 *, int);
	int (*read_file_info)(struct super_block___68 *, int);
	int (*write_file_info)(struct super_block___68 *, int);
	int (*free_file_info)(struct super_block___68 *, int);
	int (*read_dqblk)(struct dquot___67 *);
	int (*commit_dqblk)(struct dquot___67 *);
	int (*release_dqblk)(struct dquot___67 *);
	int (*get_next_id)(struct super_block___68 *, struct kqid *);
};

struct dquot_operations___67 {
	int (*write_dquot)(struct dquot___67 *);
	struct dquot___67 * (*alloc_dquot)(struct super_block___68 *, int);
	void (*destroy_dquot)(struct dquot___67 *);
	int (*acquire_dquot)(struct dquot___67 *);
	int (*release_dquot)(struct dquot___67 *);
	int (*mark_dirty)(struct dquot___67 *);
	int (*write_info)(struct super_block___68 *, int);
	qsize_t * (*get_reserved_space)(struct inode___68 *);
	int (*get_projid)(struct inode___68 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___68 *, qsize_t *);
	int (*get_next_id)(struct super_block___68 *, struct kqid *);
};

struct quotactl_ops___67 {
	int (*quota_on)(struct super_block___68 *, int, int, const struct path___67 *);
	int (*quota_off)(struct super_block___68 *, int);
	int (*quota_enable)(struct super_block___68 *, unsigned int);
	int (*quota_disable)(struct super_block___68 *, unsigned int);
	int (*quota_sync)(struct super_block___68 *, int);
	int (*set_info)(struct super_block___68 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___68 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___68 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___68 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___68 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___68 *, unsigned int);
};

struct address_space_operations___67 {
	int (*writepage)(struct page___72 *, struct writeback_control___3 *);
	int (*readpage)(struct file___67 *, struct page___72 *);
	int (*writepages)(struct address_space___67 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___72 *);
	int (*readpages)(struct file___67 *, struct address_space___67 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___67 *, struct address_space___67 *, loff_t, unsigned int, unsigned int, struct page___72 **, void **);
	int (*write_end)(struct file___67 *, struct address_space___67 *, loff_t, unsigned int, unsigned int, struct page___72 *, void *);
	sector_t (*bmap)(struct address_space___67 *, sector_t);
	void (*invalidatepage)(struct page___72 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___72 *, gfp_t);
	void (*freepage)(struct page___72 *);
	ssize_t (*direct_IO)(struct kiocb___67 *, struct iov_iter___38 *);
	int (*migratepage)(struct address_space___67 *, struct page___72 *, struct page___72 *, enum migrate_mode);
	bool (*isolate_page)(struct page___72 *, isolate_mode_t);
	void (*putback_page)(struct page___72 *);
	int (*launder_page)(struct page___72 *);
	int (*is_partially_uptodate)(struct page___72 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___72 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___67 *, struct page___72 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___67 *, sector_t *);
	void (*swap_deactivate)(struct file___67 *);
};

struct bio_vec___38;

struct iov_iter___38 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___38 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___27 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___67 {
	struct dentry___68 * (*lookup)(struct inode___68 *, struct dentry___68 *, unsigned int);
	const char * (*get_link)(struct dentry___68 *, struct inode___68 *, struct delayed_call *);
	int (*permission)(struct user_namespace___11 *, struct inode___68 *, int);
	struct posix_acl * (*get_acl)(struct inode___68 *, int, bool);
	int (*readlink)(struct dentry___68 *, char *, int);
	int (*create)(struct user_namespace___11 *, struct inode___68 *, struct dentry___68 *, umode_t, bool);
	int (*link)(struct dentry___68 *, struct inode___68 *, struct dentry___68 *);
	int (*unlink)(struct inode___68 *, struct dentry___68 *);
	int (*symlink)(struct user_namespace___11 *, struct inode___68 *, struct dentry___68 *, const char *);
	int (*mkdir)(struct user_namespace___11 *, struct inode___68 *, struct dentry___68 *, umode_t);
	int (*rmdir)(struct inode___68 *, struct dentry___68 *);
	int (*mknod)(struct user_namespace___11 *, struct inode___68 *, struct dentry___68 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___11 *, struct inode___68 *, struct dentry___68 *, struct inode___68 *, struct dentry___68 *, unsigned int);
	int (*setattr)(struct user_namespace___11 *, struct dentry___68 *, struct iattr___68 *);
	int (*getattr)(struct user_namespace___11 *, const struct path___67 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___68 *, char *, size_t);
	int (*fiemap)(struct inode___68 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___68 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___68 *, struct dentry___68 *, struct file___67 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___11 *, struct inode___68 *, struct dentry___68 *, umode_t);
	int (*set_acl)(struct user_namespace___11 *, struct inode___68 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___11 *, struct dentry___68 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___68 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___67 {
	void (*fl_copy_lock)(struct file_lock___67 *, struct file_lock___67 *);
	void (*fl_release_private)(struct file_lock___67 *);
};

struct lock_manager_operations___67;

struct file_lock___67 {
	struct file_lock___67 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___67 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___67 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___67 *fl_ops;
	const struct lock_manager_operations___67 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___67 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___67 *);
	int (*lm_grant)(struct file_lock___67 *, int);
	bool (*lm_break)(struct file_lock___67 *);
	int (*lm_change)(struct file_lock___67 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___67 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___67 *);
};

struct fasync_struct___67 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___67 *fa_next;
	struct file___67 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___67 {
	struct inode___68 * (*alloc_inode)(struct super_block___68 *);
	void (*destroy_inode)(struct inode___68 *);
	void (*free_inode)(struct inode___68 *);
	void (*dirty_inode)(struct inode___68 *, int);
	int (*write_inode)(struct inode___68 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___68 *);
	void (*evict_inode)(struct inode___68 *);
	void (*put_super)(struct super_block___68 *);
	int (*sync_fs)(struct super_block___68 *, int);
	int (*freeze_super)(struct super_block___68 *);
	int (*freeze_fs)(struct super_block___68 *);
	int (*thaw_super)(struct super_block___68 *);
	int (*unfreeze_fs)(struct super_block___68 *);
	int (*statfs)(struct dentry___68 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___68 *, int *, char *);
	void (*umount_begin)(struct super_block___68 *);
	int (*show_options)(struct seq_file___65 *, struct dentry___68 *);
	int (*show_devname)(struct seq_file___65 *, struct dentry___68 *);
	int (*show_path)(struct seq_file___65 *, struct dentry___68 *);
	int (*show_stats)(struct seq_file___65 *, struct dentry___68 *);
	ssize_t (*quota_read)(struct super_block___68 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___68 *, int, const char *, size_t, loff_t);
	struct dquot___67 ** (*get_dquots)(struct inode___68 *);
	long int (*nr_cached_objects)(struct super_block___68 *, struct shrink_control___27 *);
	long int (*free_cached_objects)(struct super_block___68 *, struct shrink_control___27 *);
	struct file___67 * (*real_loop)(struct file___67 *);
};

struct seq_operations___65;

struct seq_file___65 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___65 *op;
	int poll_event;
	const struct file___67 *file;
	void *private;
};

struct kernfs_root___67;

struct kernfs_elem_dir___67 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___67 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___67;

struct kernfs_root___67 {
	struct kernfs_node___67 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___67 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___67 {
	struct kernfs_node___67 *target_kn;
};

struct kernfs_ops___67;

struct kernfs_elem_attr___67 {
	const struct kernfs_ops___67 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___67 *notify_next;
};

struct kernfs_node___67 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___67 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___67 dir;
		struct kernfs_elem_symlink___67 symlink;
		struct kernfs_elem_attr___67 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___67;

struct kernfs_ops___67 {
	int (*open)(struct kernfs_open_file___67 *);
	void (*release)(struct kernfs_open_file___67 *);
	int (*seq_show)(struct seq_file___65 *, void *);
	void * (*seq_start)(struct seq_file___65 *, loff_t *);
	void * (*seq_next)(struct seq_file___65 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___65 *, void *);
	ssize_t (*read)(struct kernfs_open_file___67 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___67 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___67 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___67 *, struct vm_area_struct___72 *);
};

struct kernfs_syscall_ops___67 {
	int (*show_options)(struct seq_file___65 *, struct kernfs_root___67 *);
	int (*mkdir)(struct kernfs_node___67 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___67 *);
	int (*rename)(struct kernfs_node___67 *, struct kernfs_node___67 *, const char *);
	int (*show_path)(struct seq_file___65 *, struct kernfs_node___67 *, struct kernfs_root___67 *);
};

struct kernfs_open_file___67 {
	struct kernfs_node___67 *kn;
	struct file___67 *file;
	struct seq_file___65 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___66 *vm_ops;
};

struct bin_attribute___67;

struct attribute_group___67 {
	const char *name;
	umode_t (*is_visible)(struct kobject___67 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___67 *, struct bin_attribute___67 *, int);
	struct attribute **attrs;
	struct bin_attribute___67 **bin_attrs;
};

struct bin_attribute___67 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___67 * (*f_mapping)();
	ssize_t (*read)(struct file___67 *, struct kobject___67 *, struct bin_attribute___67 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___67 *, struct kobject___67 *, struct bin_attribute___67 *, char *, loff_t, size_t);
	int (*mmap)(struct file___67 *, struct kobject___67 *, struct bin_attribute___67 *, struct vm_area_struct___72 *);
};

struct sysfs_ops___67 {
	ssize_t (*show)(struct kobject___67 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___67 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___67;

struct kset___67 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___67 kobj;
	const struct kset_uevent_ops___67 *uevent_ops;
};

struct kobj_type___67 {
	void (*release)(struct kobject___67 *);
	const struct sysfs_ops___67 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___67 **default_groups;
	const struct kobj_ns_type_operations___9 * (*child_ns_type)(struct kobject___67 *);
	const void * (*namespace)(struct kobject___67 *);
	void (*get_ownership)(struct kobject___67 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___67 {
	int (* const filter)(struct kset___67 *, struct kobject___67 *);
	const char * (* const name)(struct kset___67 *, struct kobject___67 *);
	int (* const uevent)(struct kset___67 *, struct kobject___67 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___64 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___64 *);
	int (*get)(char *, const struct kernel_param___64 *);
	void (*free)(void *);
};

struct kparam_array___64;

struct kernel_param___64 {
	const char *name;
	struct module___65 *mod;
	const struct kernel_param_ops___64 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___64 *arr;
	};
};

struct kparam_array___64 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___64 *ops;
	void *elem;
};

struct module_attribute___64 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___64 *, struct module_kobject___64 *, char *);
	ssize_t (*store)(struct module_attribute___64 *, struct module_kobject___64 *, const char *, size_t);
	void (*setup)(struct module___65 *, const char *);
	int (*test)(struct module___65 *);
	void (*free)(struct module___65 *);
};

struct dev_pagemap_ops___66 {
	void (*page_free)(struct page___72 *);
	void (*kill)(struct dev_pagemap___66 *);
	void (*cleanup)(struct dev_pagemap___66 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___66 *);
};

struct bpf_iter_aux_info___16;

typedef int (*bpf_iter_init_seq_priv_t___16)(void *, struct bpf_iter_aux_info___16 *);

struct bpf_map___16;

struct bpf_iter_aux_info___16 {
	struct bpf_map___16 *map;
};

struct bpf_iter_seq_info___16 {
	const struct seq_operations___65 *seq_ops;
	bpf_iter_init_seq_priv_t___16 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___65 {
	void * (*start)(struct seq_file___65 *, loff_t *);
	void (*stop)(struct seq_file___65 *, void *);
	void * (*next)(struct seq_file___65 *, void *, loff_t *);
	int (*show)(struct seq_file___65 *, void *);
};

struct bpf_prog_aux___16;

struct bpf_prog___15;

struct bpf_verifier_env___4;

struct bpf_func_state___4;

struct bpf_map_ops___16 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___16 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___16 *, struct file___67 *);
	void (*map_free)(struct bpf_map___16 *);
	int (*map_get_next_key)(struct bpf_map___16 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___16 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___16 *, void *);
	int (*map_lookup_batch)(struct bpf_map___16 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___16 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___16 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___16 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___16 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___16 *, void *);
	int (*map_update_elem)(struct bpf_map___16 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___16 *, void *);
	int (*map_push_elem)(struct bpf_map___16 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___16 *, void *);
	int (*map_peek_elem)(struct bpf_map___16 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___16 *, struct file___67 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___16 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___16 *, void *, struct seq_file___65 *);
	int (*map_check_btf)(const struct bpf_map___16 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___16 *, struct bpf_prog_aux___16 *);
	void (*map_poke_untrack)(struct bpf_map___16 *, struct bpf_prog_aux___16 *);
	void (*map_poke_run)(struct bpf_map___16 *, u32, struct bpf_prog___15 *, struct bpf_prog___15 *);
	int (*map_direct_value_addr)(const struct bpf_map___16 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___16 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___16 *, struct vm_area_struct___72 *);
	__poll_t (*map_poll)(struct bpf_map___16 *, struct file___67 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___16 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___16 *, const struct bpf_map___16 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env___4 *, struct bpf_func_state___4 *, struct bpf_func_state___4 *);
	int (*map_for_each_callback)(struct bpf_map___16 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___16 *iter_seq_info;
};

struct bpf_map___16 {
	const struct bpf_map_ops___16 *ops;
	struct bpf_map___16 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___16;

struct bpf_jit_poke_descriptor___16;

struct bpf_prog_ops___15;

struct btf_mod_pair___16;

struct bpf_prog_offload___15;

struct bpf_prog_aux___16 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___15 *dst_prog;
	struct bpf_trampoline___16 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___15 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___16 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___15 *ops;
	struct bpf_map___16 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___16 *used_btfs;
	struct bpf_prog___15 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___16 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___15 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___15 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___16 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct btf_mod_pair___16 {
	struct btf *btf;
	struct module___65 *module;
};

struct bpf_verifier_ops___5;

struct bpf_verifier_state___4;

struct bpf_verifier_state_list___4;

struct bpf_verifier_env___4 {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___15 *prog;
	const struct bpf_verifier_ops___5 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	bool test_state_freq;
	struct bpf_verifier_state___4 *cur_state;
	struct bpf_verifier_state_list___4 **explored_states;
	struct bpf_verifier_state_list___4 *free_list;
	struct bpf_map___16 *used_maps[64];
	struct btf_mod_pair___16 used_btfs[64];
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 id_gen;
	bool explore_alu_limits;
	bool allow_ptr_leaks;
	bool allow_uninit_stack;
	bool allow_ptr_to_map_access;
	bool bpf_capable;
	bool bypass_spec_v1;
	bool bypass_spec_v4;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	struct bpf_id_pair idmap_scratch[75];
	struct {
		int *insn_state;
		int *insn_stack;
		int cur_stack;
	} cfg;
	u32 pass_cnt;
	u32 subprog_cnt;
	u32 prev_insn_processed;
	u32 insn_processed;
	u32 prev_jmps_processed;
	u32 jmps_processed;
	u64 verification_time;
	u32 max_states_per_insn;
	u32 total_states;
	u32 peak_states;
	u32 longest_mark_read_walk;
	bpfptr_t fd_array;
};

struct bpf_reg_state___4 {
	enum bpf_reg_type type;
	s32 off;
	union {
		int range;
		struct {
			struct bpf_map___16 *map_ptr;
			u32 map_uid;
		};
		struct {
			struct btf *btf;
			u32 btf_id;
		};
		u32 mem_size;
		struct {
			long unsigned int raw1;
			long unsigned int raw2;
		} raw;
		u32 subprogno;
	};
	u32 id;
	u32 ref_obj_id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	s32 s32_min_value;
	s32 s32_max_value;
	u32 u32_min_value;
	u32 u32_max_value;
	struct bpf_reg_state___4 *parent;
	u32 frameno;
	s32 subreg_def;
	enum bpf_reg_liveness live;
	bool precise;
};

struct bpf_stack_state___4;

struct bpf_func_state___4 {
	struct bpf_reg_state___4 regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	u32 async_entry_cnt;
	bool in_callback_fn;
	bool in_async_callback_fn;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state___4 *stack;
};

struct bpf_offloaded_map___15;

struct bpf_map_dev_ops___15 {
	int (*map_get_next_key)(struct bpf_offloaded_map___15 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___15 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___15 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___15 *, void *);
};

struct net_device___20;

struct bpf_offloaded_map___15 {
	struct bpf_map___16 map;
	struct net_device___20 *netdev;
	const struct bpf_map_dev_ops___15 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_buff___17;

typedef rx_handler_result_t rx_handler_func_t___15(struct sk_buff___17 **);

typedef struct {
	struct net___18 *net;
} possible_net_t___15;

struct wakeup_source___60;

struct dev_pm_info___60 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___60 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___60 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___60;

struct bus_type___60;

struct device_driver___60;

struct dev_pm_domain___60;

struct fwnode_handle___60;

struct class___60;

struct device___60 {
	struct kobject___67 kobj;
	struct device___60 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___60 *type;
	struct bus_type___60 *bus;
	struct device_driver___60 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___60 power;
	struct dev_pm_domain___60 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___60 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___60 *class;
	const struct attribute_group___67 **groups;
	void (*release)(struct device___60 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___15 {
	struct bpf_prog___15 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___15;

struct net_device_ops___15;

struct xfrmdev_ops___15;

struct header_ops___15;

struct netdev_rx_queue___15;

struct mini_Qdisc___15;

struct netdev_queue___15;

struct Qdisc___15;

struct rtnl_link_ops___15;

struct dcbnl_rtnl_ops___15;

struct net_device___20 {
	char name[16];
	struct netdev_name_node___15 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___15 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___15 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___15 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___67 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___15 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___15 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___15 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___15 *miniq_ingress;
	struct netdev_queue___15 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___15 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___15 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___15 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___15 = 0,
		NETREG_REGISTERED___15 = 1,
		NETREG_UNREGISTERING___15 = 2,
		NETREG_UNREGISTERED___15 = 3,
		NETREG_RELEASED___15 = 4,
		NETREG_DUMMY___15 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___15 = 0,
		RTNL_LINK_INITIALIZING___15 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___20 *);
	struct netpoll_info *npinfo;
	possible_net_t___15 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___60 dev;
	const struct attribute_group___67 *sysfs_groups[4];
	const struct attribute_group___67 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___15 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___15 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___15 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___9 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___15 *);
};

struct bpf_prog_ops___15 {
	int (*test_run)(struct bpf_prog___15 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___5 {
	const struct bpf_func_proto___9 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___15 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___15 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___15 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___15 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload_ops {
	int (*insn_hook)(struct bpf_verifier_env___4 *, int, int);
	int (*finalize)(struct bpf_verifier_env___4 *);
	int (*replace_insn)(struct bpf_verifier_env___4 *, u32, struct bpf_insn *);
	int (*remove_insns)(struct bpf_verifier_env___4 *, u32, u32);
	int (*prepare)(struct bpf_prog___15 *);
	int (*translate)(struct bpf_prog___15 *);
	void (*destroy)(struct bpf_prog___15 *);
};

struct bpf_prog_offload___15 {
	struct bpf_prog___15 *prog;
	struct net_device___20 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_offload_dev {
	const struct bpf_prog_offload_ops *ops;
	struct list_head netdevs;
	void *priv;
};

struct bpf_trampoline___16 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___15 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___65 *mod;
};

struct bpf_jit_poke_descriptor___16 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___16 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct bpf_prog_array_item___15 {
	struct bpf_prog___15 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___15 {
	struct callback_head rcu;
	struct bpf_prog_array_item___15 items[0];
};

struct sk_buff___17 {
	union {
		struct {
			struct sk_buff___17 *next;
			struct sk_buff___17 *prev;
			union {
				struct net_device___20 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___2 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___17 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bio_vec___38 {
	struct page___72 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fwnode_operations___60;

struct fwnode_handle___60 {
	struct fwnode_handle___60 *secondary;
	const struct fwnode_operations___60 *ops;
	struct device___60 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___60;

struct fwnode_endpoint___60;

struct fwnode_operations___60 {
	struct fwnode_handle___60 * (*get)(struct fwnode_handle___60 *);
	void (*put)(struct fwnode_handle___60 *);
	bool (*device_is_available)(const struct fwnode_handle___60 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___60 *, const struct device___60 *);
	bool (*property_present)(const struct fwnode_handle___60 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___60 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___60 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___60 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*get_parent)(const struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*get_next_child_node)(const struct fwnode_handle___60 *, struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*get_named_child_node)(const struct fwnode_handle___60 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___60 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___60 *);
	struct fwnode_handle___60 * (*graph_get_next_endpoint)(const struct fwnode_handle___60 *, struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*graph_get_remote_endpoint)(const struct fwnode_handle___60 *);
	struct fwnode_handle___60 * (*graph_get_port_parent)(struct fwnode_handle___60 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___60 *, struct fwnode_endpoint___60 *);
	int (*add_links)(struct fwnode_handle___60 *);
};

struct fwnode_endpoint___60 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___60 *local_fwnode;
};

struct fwnode_reference_args___60 {
	struct fwnode_handle___60 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fqdir___17;

struct netns_ipv4___17 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___17 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___17 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___17 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___20 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___17 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___17 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___17 *);
	int (*local_out)(struct net___18 *, struct sock *, struct sk_buff___17 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___17 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___17 {
	struct dst_ops___17 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___17 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___17 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___17 *fqdir;
};

struct sk_buff_head___15 {
	struct sk_buff___17 *next;
	struct sk_buff___17 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___15 {
	struct bpf_prog_array___15 *run_array[2];
	struct bpf_prog___15 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___17 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___17 xfrm4_dst_ops;
	struct dst_ops___17 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___18 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct idr netns_ids;
	struct ns_common___12 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___20 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___17 ipv4;
	struct netns_ipv6___17 ipv6;
	struct netns_ieee802154_lowpan___17 ieee802154_lowpan;
	struct netns_sctp___9 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___15 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___15 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___17 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___56 {
	struct ns_common___12 ns;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct css_set___56 *root_cset;
};

struct nsset___11 {
	unsigned int flags;
	struct nsproxy___65 *nsproxy;
	struct fs_struct *fs;
	const struct cred___10 *cred;
};

struct proc_ns_operations___12 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___12 * (*get)(struct task_struct___74 *);
	void (*put)(struct ns_common___12 *);
	int (*install)(struct nsset___11 *, struct ns_common___12 *);
	struct user_namespace___11 * (*owner)(struct ns_common___12 *);
	struct ns_common___12 * (*get_parent)(struct ns_common___12 *);
};

struct dev_pm_ops___60 {
	int (*prepare)(struct device___60 *);
	void (*complete)(struct device___60 *);
	int (*suspend)(struct device___60 *);
	int (*resume)(struct device___60 *);
	int (*freeze)(struct device___60 *);
	int (*thaw)(struct device___60 *);
	int (*poweroff)(struct device___60 *);
	int (*restore)(struct device___60 *);
	int (*suspend_late)(struct device___60 *);
	int (*resume_early)(struct device___60 *);
	int (*freeze_late)(struct device___60 *);
	int (*thaw_early)(struct device___60 *);
	int (*poweroff_late)(struct device___60 *);
	int (*restore_early)(struct device___60 *);
	int (*suspend_noirq)(struct device___60 *);
	int (*resume_noirq)(struct device___60 *);
	int (*freeze_noirq)(struct device___60 *);
	int (*thaw_noirq)(struct device___60 *);
	int (*poweroff_noirq)(struct device___60 *);
	int (*restore_noirq)(struct device___60 *);
	int (*runtime_suspend)(struct device___60 *);
	int (*runtime_resume)(struct device___60 *);
	int (*runtime_idle)(struct device___60 *);
};

struct wakeup_source___60 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___60 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___60 {
	struct dev_pm_ops___60 ops;
	int (*start)(struct device___60 *);
	void (*detach)(struct device___60 *, bool);
	int (*activate)(struct device___60 *);
	void (*sync)(struct device___60 *);
	void (*dismiss)(struct device___60 *);
};

struct bus_type___60 {
	const char *name;
	const char *dev_name;
	struct device___60 *dev_root;
	const struct attribute_group___67 **bus_groups;
	const struct attribute_group___67 **dev_groups;
	const struct attribute_group___67 **drv_groups;
	int (*match)(struct device___60 *, struct device_driver___60 *);
	int (*uevent)(struct device___60 *, struct kobj_uevent_env *);
	int (*probe)(struct device___60 *);
	void (*sync_state)(struct device___60 *);
	void (*remove)(struct device___60 *);
	void (*shutdown)(struct device___60 *);
	int (*online)(struct device___60 *);
	int (*offline)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	int (*num_vf)(struct device___60 *);
	int (*dma_configure)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___60 {
	const char *name;
	struct bus_type___60 *bus;
	struct module___65 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___60 *);
	void (*sync_state)(struct device___60 *);
	int (*remove)(struct device___60 *);
	void (*shutdown)(struct device___60 *);
	int (*suspend)(struct device___60 *, pm_message_t);
	int (*resume)(struct device___60 *);
	const struct attribute_group___67 **groups;
	const struct attribute_group___67 **dev_groups;
	const struct dev_pm_ops___60 *pm;
	void (*coredump)(struct device___60 *);
	struct driver_private *p;
};

struct device_type___60 {
	const char *name;
	const struct attribute_group___67 **groups;
	int (*uevent)(struct device___60 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___60 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___60 *);
	const struct dev_pm_ops___60 *pm;
};

struct class___60 {
	const char *name;
	struct module___65 *owner;
	const struct attribute_group___67 **class_groups;
	const struct attribute_group___67 **dev_groups;
	struct kobject___67 *dev_kobj;
	int (*dev_uevent)(struct device___60 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___60 *, umode_t *);
	void (*class_release)(struct class___60 *);
	void (*dev_release)(struct device___60 *);
	int (*shutdown_pre)(struct device___60 *);
	const struct kobj_ns_type_operations___9 *ns_type;
	const void * (*namespace)(struct device___60 *);
	void (*get_ownership)(struct device___60 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___60 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___27;

struct pipe_buffer___27 {
	struct page___72 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___27 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___27 {
	int (*confirm)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
	void (*release)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
	bool (*try_steal)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
	bool (*get)(struct pipe_inode_info___27 *, struct pipe_buffer___27 *);
};

struct inet_frags___17;

struct fqdir___17 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___17 *f;
	struct net___18 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___17;

struct inet_frags___17 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___17 *, const void *);
	void (*destructor)(struct inet_frag_queue___17 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___17 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___17 *fragments_tail;
	struct sk_buff___17 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___17 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___15 {
	int (*ieee_getets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___20 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___20 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___20 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___20 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___20 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___20 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___20 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___20 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___20 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___20 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___20 *);
	u8 (*setstate)(struct net_device___20 *, u8);
	void (*getpermhwaddr)(struct net_device___20 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___20 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___20 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___20 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___20 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___20 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___20 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___20 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___20 *, int, u8 *);
	void (*setpfccfg)(struct net_device___20 *, int, u8);
	void (*getpfccfg)(struct net_device___20 *, int, u8 *);
	u8 (*setall)(struct net_device___20 *);
	u8 (*getcap)(struct net_device___20 *, int, u8 *);
	int (*getnumtcs)(struct net_device___20 *, int, u8 *);
	int (*setnumtcs)(struct net_device___20 *, int, u8);
	u8 (*getpfcstate)(struct net_device___20 *);
	void (*setpfcstate)(struct net_device___20 *, u8);
	void (*getbcncfg)(struct net_device___20 *, int, u32 *);
	void (*setbcncfg)(struct net_device___20 *, int, u32);
	void (*getbcnrp)(struct net_device___20 *, int, u8 *);
	void (*setbcnrp)(struct net_device___20 *, int, u8);
	int (*setapp)(struct net_device___20 *, u8, u16, u8);
	int (*getapp)(struct net_device___20 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___20 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___20 *, int, u8);
	u8 (*getdcbx)(struct net_device___20 *);
	u8 (*setdcbx)(struct net_device___20 *, u8);
	int (*peer_getappinfo)(struct net_device___20 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___20 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___20 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___20 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___20 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___20 *, struct dcbnl_buffer *);
};

struct cftype___56;

struct cgroup_subsys___56 {
	struct cgroup_subsys_state___56 * (*css_alloc)(struct cgroup_subsys_state___56 *);
	int (*css_online)(struct cgroup_subsys_state___56 *);
	void (*css_offline)(struct cgroup_subsys_state___56 *);
	void (*css_released)(struct cgroup_subsys_state___56 *);
	void (*css_free)(struct cgroup_subsys_state___56 *);
	void (*css_reset)(struct cgroup_subsys_state___56 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___56 *, int);
	int (*css_extra_stat_show)(struct seq_file___65 *, struct cgroup_subsys_state___56 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___74 *, struct css_set___56 *);
	void (*cancel_fork)(struct task_struct___74 *, struct css_set___56 *);
	void (*fork)(struct task_struct___74 *);
	void (*exit)(struct task_struct___74 *);
	void (*release)(struct task_struct___74 *);
	void (*bind)(struct cgroup_subsys_state___56 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___56 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___56 *dfl_cftypes;
	struct cftype___56 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___56 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___56 *updated_children;
	struct cgroup___56 *updated_next;
};

struct cgroup_root___56 {
	struct kernfs_root___67 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___56 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___56 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___56 *ss;
	struct list_head node;
	struct kernfs_ops___67 *kf_ops;
	int (*open)(struct kernfs_open_file___67 *);
	void (*release)(struct kernfs_open_file___67 *);
	u64 (*read_u64)(struct cgroup_subsys_state___56 *, struct cftype___56 *);
	s64 (*read_s64)(struct cgroup_subsys_state___56 *, struct cftype___56 *);
	int (*seq_show)(struct seq_file___65 *, void *);
	void * (*seq_start)(struct seq_file___65 *, loff_t *);
	void * (*seq_next)(struct seq_file___65 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___65 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___56 *, struct cftype___56 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___56 *, struct cftype___56 *, s64);
	ssize_t (*write)(struct kernfs_open_file___67 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___67 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___15 {
	struct net_device___20 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___15 {
	struct net_device___20 *dev;
};

struct xdp_buff___15 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___15 *rxq;
	struct xdp_txq_info___15 *txq;
	u32 frame_sz;
};

struct xdp_frame___15 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___20 *dev_rx;
};

struct netlink_callback___15 {
	struct sk_buff___17 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___17 *, struct netlink_callback___15 *);
	int (*done)(struct netlink_callback___15 *);
	void *data;
	struct module___65 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___15 {
	int (*create)(struct sk_buff___17 *, struct net_device___20 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___17 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___20 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___17 *);
};

struct netdev_queue___15 {
	struct net_device___20 *dev;
	struct Qdisc___15 *qdisc;
	struct Qdisc___15 *qdisc_sleeping;
	struct kobject___67 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___20 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___15 {
	struct sk_buff___17 *head;
	struct sk_buff___17 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___15;

struct Qdisc___15 {
	int (*enqueue)(struct sk_buff___17 *, struct Qdisc___15 *, struct sk_buff___17 **);
	struct sk_buff___17 * (*dequeue)(struct Qdisc___15 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___15 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___15 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___15 gso_skb;
	struct qdisc_skb_head___15 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___15 *next_sched;
	struct sk_buff_head___15 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___15 {
	struct xdp_rxq_info___15 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___67 kobj;
	struct net_device___20 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___15 {
	enum net_device_path_type type;
	const struct net_device___20 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___15 = 0,
				DEV_PATH_BR_VLAN_TAG___15 = 1,
				DEV_PATH_BR_VLAN_UNTAG___15 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___15 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___15 {
	const struct net_device___20 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___15 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___15 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___15 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___15 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___17 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___15 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___20 *dev;
	const char *name;
};

struct net_device_ops___15 {
	int (*ndo_init)(struct net_device___20 *);
	void (*ndo_uninit)(struct net_device___20 *);
	int (*ndo_open)(struct net_device___20 *);
	int (*ndo_stop)(struct net_device___20 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___17 *, struct net_device___20 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___17 *, struct net_device___20 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___20 *, struct sk_buff___17 *, struct net_device___20 *);
	void (*ndo_change_rx_flags)(struct net_device___20 *, int);
	void (*ndo_set_rx_mode)(struct net_device___20 *);
	int (*ndo_set_mac_address)(struct net_device___20 *, void *);
	int (*ndo_validate_addr)(struct net_device___20 *);
	int (*ndo_do_ioctl)(struct net_device___20 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___20 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___20 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___20 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___20 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___20 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___20 *, int);
	int (*ndo_neigh_setup)(struct net_device___20 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___20 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___20 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___20 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___20 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___20 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___20 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___20 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___20 *);
	int (*ndo_netpoll_setup)(struct net_device___20 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___20 *);
	int (*ndo_set_vf_mac)(struct net_device___20 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___20 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___20 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___20 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___20 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___20 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___20 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___20 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___20 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___20 *, int, struct sk_buff___17 *);
	int (*ndo_get_vf_guid)(struct net_device___20 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___20 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___20 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___20 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___20 *);
	int (*ndo_fcoe_disable)(struct net_device___20 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___20 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___20 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___20 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___20 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___20 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___20 *, const struct sk_buff___17 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___20 *, struct net_device___20 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___20 *, struct net_device___20 *);
	struct net_device___20 * (*ndo_get_xmit_slave)(struct net_device___20 *, struct sk_buff___17 *, bool);
	struct net_device___20 * (*ndo_sk_get_lower_dev)(struct net_device___20 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___20 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___20 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___20 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___20 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___17 *, struct netlink_callback___15 *, struct net_device___20 *, struct net_device___20 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___17 *, struct nlattr **, struct net_device___20 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___20 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___17 *, u32, u32, struct net_device___20 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___20 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___20 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___20 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___20 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___20 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___20 *, struct net_device___20 *);
	void (*ndo_dfwd_del_station)(struct net_device___20 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___20 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___20 *);
	int (*ndo_change_proto_down)(struct net_device___20 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___20 *, struct sk_buff___17 *);
	void (*ndo_set_rx_headroom)(struct net_device___20 *, int);
	int (*ndo_bpf)(struct net_device___20 *, struct netdev_bpf___15 *);
	int (*ndo_xdp_xmit)(struct net_device___20 *, int, struct xdp_frame___15 **, u32);
	struct net_device___20 * (*ndo_xdp_get_xmit_slave)(struct net_device___20 *, struct xdp_buff___15 *);
	int (*ndo_xsk_wakeup)(struct net_device___20 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___20 *);
	int (*ndo_tunnel_ctl)(struct net_device___20 *, struct ip_tunnel_parm *, int);
	struct net_device___20 * (*ndo_get_peer_dev)(struct net_device___20 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___15 *, struct net_device_path___15 *);
};

struct tcf_proto___15;

struct tcf_block___15;

struct mini_Qdisc___15 {
	struct tcf_proto___15 *filter_list;
	struct tcf_block___15 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___15 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___20 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___20 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___18 *, struct net_device___20 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___20 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___20 *, struct list_head *);
	size_t (*get_size)(const struct net_device___20 *);
	int (*fill_info)(struct sk_buff___17 *, const struct net_device___20 *);
	size_t (*get_xstats_size)(const struct net_device___20 *);
	int (*fill_xstats)(struct sk_buff___17 *, const struct net_device___20 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___20 *, struct net_device___20 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___20 *, const struct net_device___20 *);
	int (*fill_slave_info)(struct sk_buff___17 *, const struct net_device___20 *, const struct net_device___20 *);
	struct net___18 * (*get_link_net)(const struct net_device___20 *);
	size_t (*get_linkxstats_size)(const struct net_device___20 *, int);
	int (*fill_linkxstats)(struct sk_buff___17 *, const struct net_device___20 *, int *, int);
};

struct gnet_dump___15 {
	spinlock_t *lock;
	struct sk_buff___17 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___15;

struct Qdisc_ops___15 {
	struct Qdisc_ops___15 *next;
	const struct Qdisc_class_ops___15 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___17 *, struct Qdisc___15 *, struct sk_buff___17 **);
	struct sk_buff___17 * (*dequeue)(struct Qdisc___15 *);
	struct sk_buff___17 * (*peek)(struct Qdisc___15 *);
	int (*init)(struct Qdisc___15 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___15 *);
	void (*destroy)(struct Qdisc___15 *);
	int (*change)(struct Qdisc___15 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___15 *);
	int (*change_tx_queue_len)(struct Qdisc___15 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___15 *, unsigned int);
	int (*dump)(struct Qdisc___15 *, struct sk_buff___17 *);
	int (*dump_stats)(struct Qdisc___15 *, struct gnet_dump___15 *);
	void (*ingress_block_set)(struct Qdisc___15 *, u32);
	void (*egress_block_set)(struct Qdisc___15 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___15 *);
	u32 (*egress_block_get)(struct Qdisc___15 *);
	struct module___65 *owner;
};

struct Qdisc_class_ops___15 {
	unsigned int flags;
	struct netdev_queue___15 * (*select_queue)(struct Qdisc___15 *, struct tcmsg *);
	int (*graft)(struct Qdisc___15 *, long unsigned int, struct Qdisc___15 *, struct Qdisc___15 **, struct netlink_ext_ack *);
	struct Qdisc___15 * (*leaf)(struct Qdisc___15 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___15 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___15 *, u32);
	int (*change)(struct Qdisc___15 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___15 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___15 *, struct qdisc_walker *);
	struct tcf_block___15 * (*tcf_block)(struct Qdisc___15 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___15 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___15 *, long unsigned int);
	int (*dump)(struct Qdisc___15 *, long unsigned int, struct sk_buff___17 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___15 *, long unsigned int, struct gnet_dump___15 *);
};

struct tcf_chain___15;

struct tcf_block___15 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___18 *net;
	struct Qdisc___15 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___15 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___15;

struct tcf_proto_ops___15;

struct tcf_proto___15 {
	struct tcf_proto___15 *next;
	void *root;
	int (*classify)(struct sk_buff___17 *, const struct tcf_proto___15 *, struct tcf_result___15 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___15 *ops;
	struct tcf_chain___15 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___15 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___15 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___15 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___17 *, const struct tcf_proto___15 *, struct tcf_result___15 *);
	int (*init)(struct tcf_proto___15 *);
	void (*destroy)(struct tcf_proto___15 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___15 *, u32);
	void (*put)(struct tcf_proto___15 *, void *);
	int (*change)(struct net___18 *, struct sk_buff___17 *, struct tcf_proto___15 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___15 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___15 *);
	void (*walk)(struct tcf_proto___15 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___15 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___15 *, void *);
	void (*hw_del)(struct tcf_proto___15 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___18 *, struct tcf_chain___15 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___18 *, struct tcf_proto___15 *, void *, struct sk_buff___17 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___18 *, struct tcf_proto___15 *, void *, struct sk_buff___17 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___17 *, struct net___18 *, void *);
	struct module___65 *owner;
	int flags;
};

struct tcf_chain___15 {
	struct mutex filter_chain_lock;
	struct tcf_proto___15 *filter_chain;
	struct list_head list;
	struct tcf_block___15 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___15 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct bpf_stack_state___4 {
	struct bpf_reg_state___4 spilled_ptr;
	u8 slot_type[8];
};

struct bpf_verifier_state___4 {
	struct bpf_func_state___4 *frame[8];
	struct bpf_verifier_state___4 *parent;
	u32 branches;
	u32 insn_idx;
	u32 curframe;
	u32 active_spin_lock;
	bool speculative;
	u32 first_insn_idx;
	u32 last_insn_idx;
	struct bpf_idx_pair *jmp_history;
	u32 jmp_history_cnt;
};

struct bpf_verifier_state_list___4 {
	struct bpf_verifier_state___4 state;
	struct bpf_verifier_state_list___4 *next;
	int miss_cnt;
	int hit_cnt;
};

typedef struct ns_common___12 *ns_get_path_helper_t(void *);

struct bpf_offload_netdev {
	struct rhash_head l;
	struct net_device___20 *netdev;
	struct bpf_offload_dev *offdev;
	struct list_head progs;
	struct list_head maps;
	struct list_head offdev_netdevs;
};

struct ns_get_path_bpf_prog_args {
	struct bpf_prog___15 *prog;
	struct bpf_prog_info *info;
};

struct ns_get_path_bpf_map_args {
	struct bpf_offloaded_map___15 *offmap;
	struct bpf_map_info *info;
};

struct bpf_netns_link {
	struct bpf_link___2 link;
	enum bpf_attach_type type;
	enum netns_bpf_attach_type netns_type;
	struct net___18 *net;
	struct list_head node;
};

enum bpf_stack_build_id_status {
	BPF_STACK_BUILD_ID_EMPTY = 0,
	BPF_STACK_BUILD_ID_VALID = 1,
	BPF_STACK_BUILD_ID_IP = 2,
};

struct bpf_stack_build_id {
	__s32 status;
	unsigned char build_id[20];
	union {
		__u64 offset;
		__u64 ip;
	};
};

enum {
	BPF_F_SKIP_FIELD_MASK = 255,
	BPF_F_USER_STACK = 256,
	BPF_F_FAST_STACK_CMP = 512,
	BPF_F_REUSE_STACKID = 1024,
	BPF_F_USER_BUILD_ID = 2048,
};

enum perf_callchain_context {
	PERF_CONTEXT_HV = 4294967264,
	PERF_CONTEXT_KERNEL = 4294967168,
	PERF_CONTEXT_USER = 4294966784,
	PERF_CONTEXT_GUEST = 4294965248,
	PERF_CONTEXT_GUEST_KERNEL = 4294965120,
	PERF_CONTEXT_GUEST_USER = 4294964736,
	PERF_CONTEXT_MAX = 4294963201,
};

struct bpf_perf_event_data_kern___3 {
	bpf_user_pt_regs_t *regs;
	struct perf_sample_data *data;
	struct perf_event___35 *event;
};

struct stack_map_bucket {
	struct pcpu_freelist_node fnode;
	u32 hash;
	u32 nr;
	u64 data[0];
};

struct bpf_stack_map {
	struct bpf_map___6 map;
	void *elems;
	struct pcpu_freelist freelist;
	u32 n_buckets;
	struct stack_map_bucket *buckets[0];
	long: 64;
	long: 64;
	long: 64;
};

struct stack_map_irq_work {
	struct irq_work irq_work;
	struct mm_struct___58 *mm;
};

typedef u64 (*btf_bpf_get_stackid)(struct pt_regs *, struct bpf_map___6 *, u64);

typedef u64 (*btf_bpf_get_stackid_pe)(struct bpf_perf_event_data_kern___3 *, struct bpf_map___6 *, u64);

typedef u64 (*btf_bpf_get_stack)(struct pt_regs *, void *, u32, u64);

typedef u64 (*btf_bpf_get_task_stack)(struct task_struct___58 *, void *, u32, u64);

typedef u64 (*btf_bpf_get_stack_pe)(struct bpf_perf_event_data_kern___3 *, void *, u32, u64);

struct fs_context___10;

struct fs_parameter_spec___9;

struct dentry___69;

struct super_block___69;

struct module___66;

struct file_system_type___68 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___10 *);
	const struct fs_parameter_spec___9 *parameters;
	struct dentry___69 * (*mount)(struct file_system_type___68 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___69 *);
	struct module___66 *owner;
	struct file_system_type___68 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___68;

struct kiocb___68;

struct iov_iter___39;

struct poll_table_struct___50;

struct vm_area_struct___73;

struct inode___69;

struct file_lock___68;

struct page___73;

struct pipe_inode_info___28;

struct seq_file___66;

struct file_operations___68 {
	struct module___66 *owner;
	loff_t (*llseek)(struct file___68 *, loff_t, int);
	ssize_t (*read)(struct file___68 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___68 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___68 *, struct iov_iter___39 *);
	ssize_t (*write_iter)(struct kiocb___68 *, struct iov_iter___39 *);
	int (*iopoll)(struct kiocb___68 *, bool);
	int (*iterate)(struct file___68 *, struct dir_context *);
	int (*iterate_shared)(struct file___68 *, struct dir_context *);
	__poll_t (*poll)(struct file___68 *, struct poll_table_struct___50 *);
	long int (*unlocked_ioctl)(struct file___68 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___68 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___68 *, struct vm_area_struct___73 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___69 *, struct file___68 *);
	int (*flush)(struct file___68 *, fl_owner_t);
	int (*release)(struct inode___69 *, struct file___68 *);
	int (*fsync)(struct file___68 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___68 *, int);
	int (*lock)(struct file___68 *, int, struct file_lock___68 *);
	ssize_t (*sendpage)(struct file___68 *, struct page___73 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___68 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___68 *, long unsigned int);
	int (*flock)(struct file___68 *, int, struct file_lock___68 *);
	ssize_t (*splice_write)(struct pipe_inode_info___28 *, struct file___68 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___68 *, loff_t *, struct pipe_inode_info___28 *, size_t, unsigned int);
	int (*setlease)(struct file___68 *, long int, struct file_lock___68 **, void **);
	long int (*fallocate)(struct file___68 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___66 *, struct file___68 *);
	ssize_t (*copy_file_range)(struct file___68 *, loff_t, struct file___68 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___68 *, loff_t, struct file___68 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___68 *, loff_t, loff_t, int);
};

struct vmacache___73 {
	u64 seqnum;
	struct vm_area_struct___73 *vmas[4];
};

struct page_frag___73 {
	struct page___73 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___74;

struct pid___61;

struct nsproxy___66;

struct signal_struct___69;

struct bio_list___31;

struct backing_dev_info___30;

struct io_context___31;

struct css_set___57;

struct mem_cgroup___28;

struct request_queue___32;

struct vm_struct___69;

struct bpf_local_storage___5;

struct task_struct___75 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___75 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___74 *mm;
	struct mm_struct___74 *active_mm;
	struct vmacache___73 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___75 *real_parent;
	struct task_struct___75 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___75 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___61 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___10 *ptracer_cred;
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___66 *nsproxy;
	struct signal_struct___69 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___75 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___31 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___30 *backing_dev_info;
	struct io_context___31 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___57 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___28 *splice_pipe;
	struct page_frag___73 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___28 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___28 *active_memcg;
	struct request_queue___32 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___75 *oom_reaper_list;
	struct vm_struct___69 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___5 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___68;

struct kobj_type___68;

struct kernfs_node___68;

struct kobject___68 {
	const char *name;
	struct list_head entry;
	struct kobject___68 *parent;
	struct kset___68 *kset;
	struct kobj_type___68 *ktype;
	struct kernfs_node___68 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___65 {
	struct kobject___68 kobj;
	struct module___66 *mod;
	struct kobject___68 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___65 {
	struct module___66 *mod;
	struct latch_tree_node node;
};

struct module_layout___65 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___65 mtn;
};

struct module_attribute___65;

struct kernel_param___65;

struct module___66 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___65 mkobj;
	struct module_attribute___65 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___68 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___65 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___65 core_layout;
	struct module_layout___65 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___61;

struct upid___61 {
	int nr;
	struct pid_namespace___61 *ns;
};

struct pid_namespace___61 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___75 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___61 *parent;
	struct fs_pin *bacct;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	int reboot;
	struct ns_common___12 ns;
};

struct pid___61 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___61 numbers[1];
};

typedef struct page___73 *pgtable_t___73;

struct address_space___68;

struct page_pool___25;

struct dev_pagemap___67;

struct page___73 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___68 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___25 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___73 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___73 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___74 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___67 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___67;

struct vm_area_struct___73 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___73 *vm_next;
	struct vm_area_struct___73 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___74 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___67 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___68 *vm_file;
	struct file___68 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___69 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___75 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___75 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___61 *pids[4];
	struct pid___61 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___74 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___73;

struct mm_struct___74 {
	struct {
		struct vm_area_struct___73 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___68 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___73 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___75 *owner;
		struct user_namespace___11 *user_ns;
		struct file___68 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___19;

struct cgroup_namespace___57;

struct nsproxy___66 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___61 *pid_ns_for_children;
	struct net___19 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___57 *cgroup_ns;
};

struct bio___31;

struct bio_list___31 {
	struct bio___31 *head;
	struct bio___31 *tail;
};

struct cgroup_subsys_state___57;

struct bdi_writeback___30 {
	struct backing_dev_info___30 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___57 *memcg_css;
	struct cgroup_subsys_state___57 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___61;

struct backing_dev_info___30 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___30 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___61 *dev;
	char dev_name[64];
	struct device___61 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___69 *debug_dir;
};

struct io_cq___31;

struct io_context___31 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___31 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___57;

struct css_set___57 {
	struct cgroup_subsys_state___57 *subsys[14];
	refcount_t refcount;
	struct css_set___57 *dom_cset;
	struct cgroup___57 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___57 *mg_src_cgrp;
	struct cgroup___57 *mg_dst_cgrp;
	struct css_set___57 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___68;

struct pipe_buffer___28;

struct pipe_inode_info___28 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___73 *tmp_page;
	struct fasync_struct___68 *fasync_readers;
	struct fasync_struct___68 *fasync_writers;
	struct pipe_buffer___28 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___57;

struct cgroup_subsys_state___57 {
	struct cgroup___57 *cgroup;
	struct cgroup_subsys___57 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___57 *parent;
};

struct cgroup_file___57 {
	struct kernfs_node___68 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___28;

struct mem_cgroup_per_node___28;

struct mem_cgroup___28 {
	struct cgroup_subsys_state___57 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___57 events_file;
	struct cgroup_file___57 events_local_file;
	struct cgroup_file___57 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___28 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___75 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___28 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___31;

struct blk_integrity___31 {
	const struct blk_integrity_profile___31 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___31 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___31 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___31;

struct elevator_queue___31;

struct blk_mq_ops___30;

struct blk_mq_hw_ctx___30;

struct gendisk___31;

struct blkcg_gq___30;

struct blk_mq_tag_set___30;

struct request_queue___32 {
	struct request___31 *last_merge;
	struct elevator_queue___31 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___30 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___30 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___31 *disk;
	struct kobject___68 kobj;
	struct kobject___68 *mq_kobj;
	struct blk_integrity___31 integrity;
	struct device___61 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___30 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___30 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___31 bio_split;
	struct dentry___69 *debugfs_dir;
	struct dentry___69 *sched_debugfs_dir;
	struct dentry___69 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___69 {
	struct vm_struct___69 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___73 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___5;

struct bpf_local_storage___5 {
	struct bpf_local_storage_data___5 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct dentry_operations___68;

struct dentry___69 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___69 *d_parent;
	struct qstr d_name;
	struct inode___69 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___68 *d_op;
	struct super_block___69 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___68;

struct address_space___68 {
	struct inode___69 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___68 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___68;

struct inode___69 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___68 *i_op;
	struct super_block___69 *i_sb;
	struct address_space___68 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___30 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___68 *i_fop;
		void (*free_inode)(struct inode___69 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___68 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___28 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___68;

struct path___68;

struct dentry_operations___68 {
	int (*d_revalidate)(struct dentry___69 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___69 *, unsigned int);
	int (*d_hash)(const struct dentry___69 *, struct qstr *);
	int (*d_compare)(const struct dentry___69 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___69 *);
	int (*d_init)(struct dentry___69 *);
	void (*d_release)(struct dentry___69 *);
	void (*d_prune)(struct dentry___69 *);
	void (*d_iput)(struct dentry___69 *, struct inode___69 *);
	char * (*d_dname)(struct dentry___69 *, char *, int);
	struct vfsmount___68 * (*d_automount)(struct path___68 *);
	int (*d_manage)(const struct path___68 *, bool);
	struct dentry___69 * (*d_real)(struct dentry___69 *, const struct inode___69 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___68;

struct mem_dqinfo___68 {
	struct quota_format_type___68 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___68;

struct quota_info___68 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___69 *files[3];
	struct mem_dqinfo___68 info[3];
	const struct quota_format_ops___68 *ops[3];
};

struct rcuwait___69 {
	struct task_struct___75 *task;
};

struct percpu_rw_semaphore___69 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___69 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___68 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___69 rw_sem[3];
};

struct shrink_control___28;

struct shrinker___28 {
	long unsigned int (*count_objects)(struct shrinker___28 *, struct shrink_control___28 *);
	long unsigned int (*scan_objects)(struct shrinker___28 *, struct shrink_control___28 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___68;

struct dquot_operations___68;

struct quotactl_ops___68;

struct block_device___32;

struct super_block___69 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___68 *s_type;
	const struct super_operations___68 *s_op;
	const struct dquot_operations___68 *dq_op;
	const struct quotactl_ops___68 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___69 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___32 *s_bdev;
	struct backing_dev_info___30 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___68 s_dquot;
	struct sb_writers___68 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___68 *s_d_op;
	int cleancache_poolid;
	struct shrinker___28 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___11 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___68 {
	struct dentry___69 *mnt_root;
	struct super_block___69 *mnt_sb;
	int mnt_flags;
	struct user_namespace___11 *mnt_userns;
};

struct path___68 {
	struct vfsmount___68 *mnt;
	struct dentry___69 *dentry;
};

struct shrink_control___28 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___28 *memcg;
};

struct page_pool_params___25 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___61 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___25 {
	u32 count;
	struct page___73 *cache[128];
};

struct page_pool___25 {
	struct page_pool_params___25 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___73 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___25 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___67;

struct dev_pagemap___67 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___67 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___61 {
	rwlock_t lock;
	struct pid___61 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___68 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___68 f_path;
	struct inode___69 *f_inode;
	const struct file_operations___68 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___61 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___68 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___67;

struct vm_operations_struct___67 {
	void (*open)(struct vm_area_struct___73 *);
	void (*close)(struct vm_area_struct___73 *);
	int (*may_split)(struct vm_area_struct___73 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___73 *);
	int (*mprotect)(struct vm_area_struct___73 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___67 *);
	vm_fault_t (*huge_fault)(struct vm_fault___67 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___67 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___73 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___67 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___67 *);
	int (*access)(struct vm_area_struct___73 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___73 *);
	int (*set_policy)(struct vm_area_struct___73 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___73 *, long unsigned int);
	struct page___73 * (*find_special_page)(struct vm_area_struct___73 *, long unsigned int);
};

struct core_thread___73 {
	struct task_struct___75 *task;
	struct core_thread___73 *next;
};

struct core_state___73 {
	atomic_t nr_threads;
	struct core_thread___73 dumper;
	struct completion startup;
};

struct vm_fault___67 {
	const struct {
		struct vm_area_struct___73 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___73 *cow_page;
	struct page___73 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___73 prealloc_pte;
};

struct pglist_data___29;

struct lruvec___29 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___29 *pgdat;
};

struct zone___29 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___29 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___29 {
	struct zone___29 *zone;
	int zone_idx;
};

struct zonelist___29 {
	struct zoneref___29 _zonerefs[321];
};

struct pglist_data___29 {
	struct zone___29 node_zones[5];
	struct zonelist___29 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___75 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___75 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___29 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___57 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___75 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___16;

struct cgroup_bpf___16 {
	struct bpf_prog_array___16 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___16 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___57;

struct cgroup_rstat_cpu___57;

struct cgroup___57 {
	struct cgroup_subsys_state___57 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___68 *kn;
	struct cgroup_file___57 procs_file;
	struct cgroup_file___57 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___57 *subsys[14];
	struct cgroup_root___57 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___57 *dom_cgrp;
	struct cgroup___57 *old_dom_cgrp;
	struct cgroup_rstat_cpu___57 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___57 psi;
	struct cgroup_bpf___16 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___31 {
	struct request_queue___32 *q;
	struct io_context___31 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___68 {
	struct file___68 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___68 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct iattr___69 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___68 *ia_file;
};

struct dquot___68 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___69 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___68 {
	int qf_fmt_id;
	const struct quota_format_ops___68 *qf_ops;
	struct module___66 *qf_owner;
	struct quota_format_type___68 *qf_next;
};

struct quota_format_ops___68 {
	int (*check_quota_file)(struct super_block___69 *, int);
	int (*read_file_info)(struct super_block___69 *, int);
	int (*write_file_info)(struct super_block___69 *, int);
	int (*free_file_info)(struct super_block___69 *, int);
	int (*read_dqblk)(struct dquot___68 *);
	int (*commit_dqblk)(struct dquot___68 *);
	int (*release_dqblk)(struct dquot___68 *);
	int (*get_next_id)(struct super_block___69 *, struct kqid *);
};

struct dquot_operations___68 {
	int (*write_dquot)(struct dquot___68 *);
	struct dquot___68 * (*alloc_dquot)(struct super_block___69 *, int);
	void (*destroy_dquot)(struct dquot___68 *);
	int (*acquire_dquot)(struct dquot___68 *);
	int (*release_dquot)(struct dquot___68 *);
	int (*mark_dirty)(struct dquot___68 *);
	int (*write_info)(struct super_block___69 *, int);
	qsize_t * (*get_reserved_space)(struct inode___69 *);
	int (*get_projid)(struct inode___69 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___69 *, qsize_t *);
	int (*get_next_id)(struct super_block___69 *, struct kqid *);
};

struct quotactl_ops___68 {
	int (*quota_on)(struct super_block___69 *, int, int, const struct path___68 *);
	int (*quota_off)(struct super_block___69 *, int);
	int (*quota_enable)(struct super_block___69 *, unsigned int);
	int (*quota_disable)(struct super_block___69 *, unsigned int);
	int (*quota_sync)(struct super_block___69 *, int);
	int (*set_info)(struct super_block___69 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___69 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___69 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___69 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___69 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___69 *, unsigned int);
};

struct writeback_control___30;

struct address_space_operations___68 {
	int (*writepage)(struct page___73 *, struct writeback_control___30 *);
	int (*readpage)(struct file___68 *, struct page___73 *);
	int (*writepages)(struct address_space___68 *, struct writeback_control___30 *);
	int (*set_page_dirty)(struct page___73 *);
	int (*readpages)(struct file___68 *, struct address_space___68 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___68 *, struct address_space___68 *, loff_t, unsigned int, unsigned int, struct page___73 **, void **);
	int (*write_end)(struct file___68 *, struct address_space___68 *, loff_t, unsigned int, unsigned int, struct page___73 *, void *);
	sector_t (*bmap)(struct address_space___68 *, sector_t);
	void (*invalidatepage)(struct page___73 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___73 *, gfp_t);
	void (*freepage)(struct page___73 *);
	ssize_t (*direct_IO)(struct kiocb___68 *, struct iov_iter___39 *);
	int (*migratepage)(struct address_space___68 *, struct page___73 *, struct page___73 *, enum migrate_mode);
	bool (*isolate_page)(struct page___73 *, isolate_mode_t);
	void (*putback_page)(struct page___73 *);
	int (*launder_page)(struct page___73 *);
	int (*is_partially_uptodate)(struct page___73 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___73 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___68 *, struct page___73 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___68 *, sector_t *);
	void (*swap_deactivate)(struct file___68 *);
};

struct writeback_control___30 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___30 *wb;
	struct inode___69 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___39;

struct iov_iter___39 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___39 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___28 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___68 {
	struct dentry___69 * (*lookup)(struct inode___69 *, struct dentry___69 *, unsigned int);
	const char * (*get_link)(struct dentry___69 *, struct inode___69 *, struct delayed_call *);
	int (*permission)(struct user_namespace___11 *, struct inode___69 *, int);
	struct posix_acl * (*get_acl)(struct inode___69 *, int, bool);
	int (*readlink)(struct dentry___69 *, char *, int);
	int (*create)(struct user_namespace___11 *, struct inode___69 *, struct dentry___69 *, umode_t, bool);
	int (*link)(struct dentry___69 *, struct inode___69 *, struct dentry___69 *);
	int (*unlink)(struct inode___69 *, struct dentry___69 *);
	int (*symlink)(struct user_namespace___11 *, struct inode___69 *, struct dentry___69 *, const char *);
	int (*mkdir)(struct user_namespace___11 *, struct inode___69 *, struct dentry___69 *, umode_t);
	int (*rmdir)(struct inode___69 *, struct dentry___69 *);
	int (*mknod)(struct user_namespace___11 *, struct inode___69 *, struct dentry___69 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___11 *, struct inode___69 *, struct dentry___69 *, struct inode___69 *, struct dentry___69 *, unsigned int);
	int (*setattr)(struct user_namespace___11 *, struct dentry___69 *, struct iattr___69 *);
	int (*getattr)(struct user_namespace___11 *, const struct path___68 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___69 *, char *, size_t);
	int (*fiemap)(struct inode___69 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___69 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___69 *, struct dentry___69 *, struct file___68 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___11 *, struct inode___69 *, struct dentry___69 *, umode_t);
	int (*set_acl)(struct user_namespace___11 *, struct inode___69 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___11 *, struct dentry___69 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___69 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___68 {
	void (*fl_copy_lock)(struct file_lock___68 *, struct file_lock___68 *);
	void (*fl_release_private)(struct file_lock___68 *);
};

struct lock_manager_operations___68;

struct file_lock___68 {
	struct file_lock___68 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___68 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___68 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___68 *fl_ops;
	const struct lock_manager_operations___68 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___68 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___68 *);
	int (*lm_grant)(struct file_lock___68 *, int);
	bool (*lm_break)(struct file_lock___68 *);
	int (*lm_change)(struct file_lock___68 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___68 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___68 *);
};

struct fasync_struct___68 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___68 *fa_next;
	struct file___68 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___68 {
	struct inode___69 * (*alloc_inode)(struct super_block___69 *);
	void (*destroy_inode)(struct inode___69 *);
	void (*free_inode)(struct inode___69 *);
	void (*dirty_inode)(struct inode___69 *, int);
	int (*write_inode)(struct inode___69 *, struct writeback_control___30 *);
	int (*drop_inode)(struct inode___69 *);
	void (*evict_inode)(struct inode___69 *);
	void (*put_super)(struct super_block___69 *);
	int (*sync_fs)(struct super_block___69 *, int);
	int (*freeze_super)(struct super_block___69 *);
	int (*freeze_fs)(struct super_block___69 *);
	int (*thaw_super)(struct super_block___69 *);
	int (*unfreeze_fs)(struct super_block___69 *);
	int (*statfs)(struct dentry___69 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___69 *, int *, char *);
	void (*umount_begin)(struct super_block___69 *);
	int (*show_options)(struct seq_file___66 *, struct dentry___69 *);
	int (*show_devname)(struct seq_file___66 *, struct dentry___69 *);
	int (*show_path)(struct seq_file___66 *, struct dentry___69 *);
	int (*show_stats)(struct seq_file___66 *, struct dentry___69 *);
	ssize_t (*quota_read)(struct super_block___69 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___69 *, int, const char *, size_t, loff_t);
	struct dquot___68 ** (*get_dquots)(struct inode___69 *);
	long int (*nr_cached_objects)(struct super_block___69 *, struct shrink_control___28 *);
	long int (*free_cached_objects)(struct super_block___69 *, struct shrink_control___28 *);
	struct file___68 * (*real_loop)(struct file___68 *);
};

struct wakeup_source___61;

struct dev_pm_info___61 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___61 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___61 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___61;

struct bus_type___61;

struct device_driver___61;

struct dev_pm_domain___61;

struct fwnode_handle___61;

struct class___61;

struct attribute_group___68;

struct device___61 {
	struct kobject___68 kobj;
	struct device___61 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___61 *type;
	struct bus_type___61 *bus;
	struct device_driver___61 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___61 power;
	struct dev_pm_domain___61 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___61 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___61 *class;
	const struct attribute_group___68 **groups;
	void (*release)(struct device___61 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___32 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___69 *bd_inode;
	struct super_block___69 *bd_super;
	void *bd_claiming;
	struct device___61 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___68 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___31 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___69 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___50)(struct file___68 *, wait_queue_head_t *, struct poll_table_struct___50 *);

struct poll_table_struct___50 {
	poll_queue_proc___50 _qproc;
	__poll_t _key;
};

struct seq_operations___66;

struct seq_file___66 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___66 *op;
	int poll_event;
	const struct file___68 *file;
	void *private;
};

struct fc_log___10;

struct p_log___10 {
	const char *prefix;
	struct fc_log___10 *log;
};

struct fs_context_operations___10;

struct fs_context___10 {
	const struct fs_context_operations___10 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___68 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___69 *root;
	struct user_namespace___11 *user_ns;
	struct net___19 *net_ns;
	const struct cred___10 *cred;
	struct p_log___10 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___10;

typedef int fs_param_type___9(struct p_log___10 *, const struct fs_parameter_spec___9 *, struct fs_parameter___10 *, struct fs_parse_result *);

struct fs_parameter_spec___9 {
	const char *name;
	fs_param_type___9 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___31(struct bio___31 *);

struct bio_vec___39 {
	struct page___73 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___31;

struct bio___31 {
	struct bio___31 *bi_next;
	struct block_device___32 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___31 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___30 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___31 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___39 *bi_io_vec;
	struct bio_set___31 *bi_pool;
	struct bio_vec___39 bi_inline_vecs[0];
};

struct seq_operations___66 {
	void * (*start)(struct seq_file___66 *, loff_t *);
	void (*stop)(struct seq_file___66 *, void *);
	void * (*next)(struct seq_file___66 *, void *, loff_t *);
	int (*show)(struct seq_file___66 *, void *);
};

struct kernfs_root___68;

struct kernfs_elem_dir___68 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___68 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___68;

struct kernfs_root___68 {
	struct kernfs_node___68 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___68 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___68 {
	struct kernfs_node___68 *target_kn;
};

struct kernfs_ops___68;

struct kernfs_elem_attr___68 {
	const struct kernfs_ops___68 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___68 *notify_next;
};

struct kernfs_node___68 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___68 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___68 dir;
		struct kernfs_elem_symlink___68 symlink;
		struct kernfs_elem_attr___68 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___68;

struct kernfs_ops___68 {
	int (*open)(struct kernfs_open_file___68 *);
	void (*release)(struct kernfs_open_file___68 *);
	int (*seq_show)(struct seq_file___66 *, void *);
	void * (*seq_start)(struct seq_file___66 *, loff_t *);
	void * (*seq_next)(struct seq_file___66 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___66 *, void *);
	ssize_t (*read)(struct kernfs_open_file___68 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___68 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___68 *, struct poll_table_struct___50 *);
	int (*mmap)(struct kernfs_open_file___68 *, struct vm_area_struct___73 *);
};

struct kernfs_syscall_ops___68 {
	int (*show_options)(struct seq_file___66 *, struct kernfs_root___68 *);
	int (*mkdir)(struct kernfs_node___68 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___68 *);
	int (*rename)(struct kernfs_node___68 *, struct kernfs_node___68 *, const char *);
	int (*show_path)(struct seq_file___66 *, struct kernfs_node___68 *, struct kernfs_root___68 *);
};

struct kernfs_open_file___68 {
	struct kernfs_node___68 *kn;
	struct file___68 *file;
	struct seq_file___66 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___67 *vm_ops;
};

struct fib_rules_ops___10;

struct sock___11;

struct fqdir___18;

struct fib_notifier_ops___10;

struct netns_ipv4___18 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___10 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___11 *fibnl;
	struct sock___11 **icmp_sk;
	struct sock___11 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___11 **tcp_sk;
	struct fqdir___18 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___10 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___10 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___10 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___10;

struct net_device___21;

struct sk_buff___18;

struct neighbour___10;

struct dst_ops___18 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___18 *);
	struct dst_entry___10 * (*check)(struct dst_entry___10 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___10 *);
	unsigned int (*mtu)(const struct dst_entry___10 *);
	u32 * (*cow_metrics)(struct dst_entry___10 *, long unsigned int);
	void (*destroy)(struct dst_entry___10 *);
	void (*ifdown)(struct dst_entry___10 *, struct net_device___21 *, int);
	struct dst_entry___10 * (*negative_advice)(struct dst_entry___10 *);
	void (*link_failure)(struct sk_buff___18 *);
	void (*update_pmtu)(struct dst_entry___10 *, struct sock___11 *, struct sk_buff___18 *, u32, bool);
	void (*redirect)(struct dst_entry___10 *, struct sock___11 *, struct sk_buff___18 *);
	int (*local_out)(struct net___19 *, struct sock___11 *, struct sk_buff___18 *);
	struct neighbour___10 * (*neigh_lookup)(const struct dst_entry___10 *, struct sk_buff___18 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___10 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___18 {
	struct dst_ops___18 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___18 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___10 *fib6_rules_ops;
	struct sock___11 **icmp_sk;
	struct sock___11 *ndisc_sk;
	struct sock___11 *tcp_sk;
	struct sock___11 *igmp_sk;
	struct sock___11 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___10 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___10 *notifier_ops;
	struct fib_notifier_ops___10 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___18 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___18 *fqdir;
};

struct netns_sctp___10 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___11 *ctl_sock;
	struct sock___11 *udp4_sock;
	struct sock___11 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___16 {
	struct sk_buff___18 *next;
	struct sk_buff___18 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___16;

struct netns_bpf___16 {
	struct bpf_prog_array___16 *run_array[2];
	struct bpf_prog___16 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___18 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___11 *nlsk;
	struct sock___11 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___18 xfrm4_dst_ops;
	struct dst_ops___18 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___19 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct idr netns_ids;
	struct ns_common___12 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___11 *rtnl;
	struct sock___11 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___21 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___18 ipv4;
	struct netns_ipv6___18 ipv6;
	struct netns_ieee802154_lowpan___18 ieee802154_lowpan;
	struct netns_sctp___10 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___16 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___16 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___18 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___11 *crypto_nlsk;
	struct sock___11 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___57 {
	struct ns_common___12 ns;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct css_set___57 *root_cset;
};

struct fwnode_operations___61;

struct fwnode_handle___61 {
	struct fwnode_handle___61 *secondary;
	const struct fwnode_operations___61 *ops;
	struct device___61 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___61;

struct fwnode_endpoint___61;

struct fwnode_operations___61 {
	struct fwnode_handle___61 * (*get)(struct fwnode_handle___61 *);
	void (*put)(struct fwnode_handle___61 *);
	bool (*device_is_available)(const struct fwnode_handle___61 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___61 *, const struct device___61 *);
	bool (*property_present)(const struct fwnode_handle___61 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___61 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___61 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___61 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*get_parent)(const struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*get_next_child_node)(const struct fwnode_handle___61 *, struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*get_named_child_node)(const struct fwnode_handle___61 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___61 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___61 *);
	struct fwnode_handle___61 * (*graph_get_next_endpoint)(const struct fwnode_handle___61 *, struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*graph_get_remote_endpoint)(const struct fwnode_handle___61 *);
	struct fwnode_handle___61 * (*graph_get_port_parent)(struct fwnode_handle___61 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___61 *, struct fwnode_endpoint___61 *);
	int (*add_links)(struct fwnode_handle___61 *);
};

struct fwnode_endpoint___61 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___61 *local_fwnode;
};

struct fwnode_reference_args___61 {
	struct fwnode_handle___61 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kobj_ns_type_operations___10 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___11 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___19 *net;
} possible_net_t___16;

struct proto___10;

struct sock_common___10 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___10 *skc_prot;
	possible_net_t___16 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___11 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___10 {
	struct cgroup___57 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___10;

struct socket_wq___10;

struct socket___10;

struct sock___11 {
	struct sock_common___10 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___16 sk_error_queue;
	struct sk_buff___18 *sk_rx_skb_cache;
	struct sk_buff_head___16 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___18 *head;
		struct sk_buff___18 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___10 *sk_filter;
	union {
		struct socket_wq___10 *sk_wq;
		struct socket_wq___10 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___10 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___10 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___18 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___18 *sk_tx_skb_cache;
	struct sk_buff_head___16 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___73 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___10 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___61 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___10 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___10 sk_cgrp_data;
	struct mem_cgroup___28 *sk_memcg;
	void (*sk_state_change)(struct sock___11 *);
	void (*sk_data_ready)(struct sock___11 *);
	void (*sk_write_space)(struct sock___11 *);
	void (*sk_error_report)(struct sock___11 *);
	int (*sk_backlog_rcv)(struct sock___11 *, struct sk_buff___18 *);
	struct sk_buff___18 * (*sk_validate_xmit_skb)(struct sock___11 *, struct net_device___21 *, struct sk_buff___18 *);
	void (*sk_destruct)(struct sock___11 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage___5 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___68;

struct attribute_group___68 {
	const char *name;
	umode_t (*is_visible)(struct kobject___68 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___68 *, struct bin_attribute___68 *, int);
	struct attribute **attrs;
	struct bin_attribute___68 **bin_attrs;
};

struct bin_attribute___68 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___68 * (*f_mapping)();
	ssize_t (*read)(struct file___68 *, struct kobject___68 *, struct bin_attribute___68 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___68 *, struct kobject___68 *, struct bin_attribute___68 *, char *, loff_t, size_t);
	int (*mmap)(struct file___68 *, struct kobject___68 *, struct bin_attribute___68 *, struct vm_area_struct___73 *);
};

struct sysfs_ops___68 {
	ssize_t (*show)(struct kobject___68 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___68 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___68;

struct kset___68 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___68 kobj;
	const struct kset_uevent_ops___68 *uevent_ops;
};

struct kobj_type___68 {
	void (*release)(struct kobject___68 *);
	const struct sysfs_ops___68 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___68 **default_groups;
	const struct kobj_ns_type_operations___10 * (*child_ns_type)(struct kobject___68 *);
	const void * (*namespace)(struct kobject___68 *);
	void (*get_ownership)(struct kobject___68 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___68 {
	int (* const filter)(struct kset___68 *, struct kobject___68 *);
	const char * (* const name)(struct kset___68 *, struct kobject___68 *);
	int (* const uevent)(struct kset___68 *, struct kobject___68 *, struct kobj_uevent_env *);
};

enum {
	BPF_F_SYSCTL_BASE_NAME = 1,
};

struct kernel_param_ops___65 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___65 *);
	int (*get)(char *, const struct kernel_param___65 *);
	void (*free)(void *);
};

struct kparam_array___65;

struct kernel_param___65 {
	const char *name;
	struct module___66 *mod;
	const struct kernel_param_ops___65 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___65 *arr;
	};
};

struct kparam_array___65 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___65 *ops;
	void *elem;
};

struct module_attribute___65 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___65 *, struct module_kobject___65 *, char *);
	ssize_t (*store)(struct module_attribute___65 *, struct module_kobject___65 *, const char *, size_t);
	void (*setup)(struct module___66 *, const char *);
	int (*test)(struct module___66 *);
	void (*free)(struct module___66 *);
};

struct dev_pagemap_ops___67 {
	void (*page_free)(struct page___73 *);
	void (*kill)(struct dev_pagemap___67 *);
	void (*cleanup)(struct dev_pagemap___67 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___67 *);
};

struct bpf_iter_aux_info___17;

typedef int (*bpf_iter_init_seq_priv_t___17)(void *, struct bpf_iter_aux_info___17 *);

struct bpf_map___17;

struct bpf_iter_aux_info___17 {
	struct bpf_map___17 *map;
};

struct bpf_iter_seq_info___17 {
	const struct seq_operations___66 *seq_ops;
	bpf_iter_init_seq_priv_t___17 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___17;

struct bpf_local_storage_map___5;

struct bpf_map_ops___17 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___17 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___17 *, struct file___68 *);
	void (*map_free)(struct bpf_map___17 *);
	int (*map_get_next_key)(struct bpf_map___17 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___17 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___17 *, void *);
	int (*map_lookup_batch)(struct bpf_map___17 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___17 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___17 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___17 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___17 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___17 *, void *);
	int (*map_update_elem)(struct bpf_map___17 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___17 *, void *);
	int (*map_push_elem)(struct bpf_map___17 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___17 *, void *);
	int (*map_peek_elem)(struct bpf_map___17 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___17 *, struct file___68 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___17 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___17 *, void *, struct seq_file___66 *);
	int (*map_check_btf)(const struct bpf_map___17 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___17 *, struct bpf_prog_aux___17 *);
	void (*map_poke_untrack)(struct bpf_map___17 *, struct bpf_prog_aux___17 *);
	void (*map_poke_run)(struct bpf_map___17 *, u32, struct bpf_prog___16 *, struct bpf_prog___16 *);
	int (*map_direct_value_addr)(const struct bpf_map___17 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___17 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___17 *, struct vm_area_struct___73 *);
	__poll_t (*map_poll)(struct bpf_map___17 *, struct file___68 *, struct poll_table_struct___50 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___5 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___5 *, void *, u32);
	struct bpf_local_storage___5 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___17 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___17 *, const struct bpf_map___17 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___17 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___17 *iter_seq_info;
};

struct bpf_map___17 {
	const struct bpf_map_ops___17 *ops;
	struct bpf_map___17 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___28 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___17;

struct bpf_jit_poke_descriptor___17;

struct bpf_prog_ops___16;

struct btf_mod_pair___17;

struct bpf_prog_offload___16;

struct bpf_prog_aux___17 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___16 *dst_prog;
	struct bpf_trampoline___17 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___16 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___17 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___16 *ops;
	struct bpf_map___17 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___17 *used_btfs;
	struct bpf_prog___16 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___17 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___16 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___16 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___17 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_local_storage_map___5 {
	struct bpf_map___17 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___16;

struct bpf_map_dev_ops___16 {
	int (*map_get_next_key)(struct bpf_offloaded_map___16 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___16 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___16 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___16 *, void *);
};

struct bpf_offloaded_map___16 {
	struct bpf_map___17 map;
	struct net_device___21 *netdev;
	const struct bpf_map_dev_ops___16 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___16(struct sk_buff___18 **);

struct bpf_xdp_entity___16 {
	struct bpf_prog___16 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___16;

struct net_device_ops___16;

struct l3mdev_ops___10;

struct xfrmdev_ops___16;

struct header_ops___16;

struct netdev_rx_queue___16;

struct mini_Qdisc___16;

struct netdev_queue___16;

struct Qdisc___16;

struct rtnl_link_ops___16;

struct dcbnl_rtnl_ops___16;

struct net_device___21 {
	char name[16];
	struct netdev_name_node___16 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___16 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___10 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___16 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___16 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___68 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___16 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___16 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___16 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___16 *miniq_ingress;
	struct netdev_queue___16 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___16 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___16 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___16 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___16 = 0,
		NETREG_REGISTERED___16 = 1,
		NETREG_UNREGISTERING___16 = 2,
		NETREG_UNREGISTERED___16 = 3,
		NETREG_RELEASED___16 = 4,
		NETREG_DUMMY___16 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___16 = 0,
		RTNL_LINK_INITIALIZING___16 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___21 *);
	struct netpoll_info *npinfo;
	possible_net_t___16 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___61 dev;
	const struct attribute_group___68 *sysfs_groups[4];
	const struct attribute_group___68 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___16 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___16 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___16 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___10 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___16 *);
};

struct bpf_prog_ops___16 {
	int (*test_run)(struct bpf_prog___16 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___6 {
	const struct bpf_func_proto___10 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___16 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___16 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___16 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___16 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___16 {
	struct bpf_prog___16 *prog;
	struct net_device___21 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___17 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___16 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___66 *mod;
};

struct bpf_jit_poke_descriptor___17 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___17 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___17 {
	struct btf *btf;
	struct module___66 *module;
};

struct bpf_link_ops___4;

struct bpf_link___4 {
	atomic64_t refcnt;
	u32 id;
	enum bpf_link_type type;
	const struct bpf_link_ops___4 *ops;
	struct bpf_prog___16 *prog;
	struct work_struct work;
};

struct bpf_link_ops___4 {
	void (*release)(struct bpf_link___4 *);
	void (*dealloc)(struct bpf_link___4 *);
	int (*detach)(struct bpf_link___4 *);
	int (*update_prog)(struct bpf_link___4 *, struct bpf_prog___16 *, struct bpf_prog___16 *);
	void (*show_fdinfo)(const struct bpf_link___4 *, struct seq_file___66 *);
	int (*fill_link_info)(const struct bpf_link___4 *, struct bpf_link_info *);
};

struct bpf_link_primer___2 {
	struct bpf_link___4 *link;
	struct file___68 *file;
	int fd;
	u32 id;
};

struct bpf_prog_array_item___16 {
	struct bpf_prog___16 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___16 {
	struct callback_head rcu;
	struct bpf_prog_array_item___16 items[0];
};

struct bpf_cg_run_ctx___2 {
	struct bpf_run_ctx run_ctx;
	const struct bpf_prog_array_item___16 *prog_item;
};

typedef u32 (*bpf_prog_run_fn___2)(const struct bpf_prog___16 *, const void *);

struct sk_buff___18 {
	union {
		struct {
			struct sk_buff___18 *next;
			struct sk_buff___18 *prev;
			union {
				struct net_device___21 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___11 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___18 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct bpf_cgroup_link___2 {
	struct bpf_link___4 link;
	struct cgroup___57 *cgroup;
	enum bpf_attach_type type;
};

struct bpf_prog_list {
	struct list_head node;
	struct bpf_prog___16 *prog;
	struct bpf_cgroup_link___2 *link;
	struct bpf_cgroup_storage *storage[2];
};

struct cgroup_taskset___6;

struct cftype___57;

struct cgroup_subsys___57 {
	struct cgroup_subsys_state___57 * (*css_alloc)(struct cgroup_subsys_state___57 *);
	int (*css_online)(struct cgroup_subsys_state___57 *);
	void (*css_offline)(struct cgroup_subsys_state___57 *);
	void (*css_released)(struct cgroup_subsys_state___57 *);
	void (*css_free)(struct cgroup_subsys_state___57 *);
	void (*css_reset)(struct cgroup_subsys_state___57 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___57 *, int);
	int (*css_extra_stat_show)(struct seq_file___66 *, struct cgroup_subsys_state___57 *);
	int (*can_attach)(struct cgroup_taskset___6 *);
	void (*cancel_attach)(struct cgroup_taskset___6 *);
	void (*attach)(struct cgroup_taskset___6 *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___75 *, struct css_set___57 *);
	void (*cancel_fork)(struct task_struct___75 *, struct css_set___57 *);
	void (*fork)(struct task_struct___75 *);
	void (*exit)(struct task_struct___75 *);
	void (*release)(struct task_struct___75 *);
	void (*bind)(struct cgroup_subsys_state___57 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___57 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___57 *dfl_cftypes;
	struct cftype___57 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___57 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___57 *updated_children;
	struct cgroup___57 *updated_next;
};

struct cgroup_root___57 {
	struct kernfs_root___68 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___57 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___57 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___57 *ss;
	struct list_head node;
	struct kernfs_ops___68 *kf_ops;
	int (*open)(struct kernfs_open_file___68 *);
	void (*release)(struct kernfs_open_file___68 *);
	u64 (*read_u64)(struct cgroup_subsys_state___57 *, struct cftype___57 *);
	s64 (*read_s64)(struct cgroup_subsys_state___57 *, struct cftype___57 *);
	int (*seq_show)(struct seq_file___66 *, void *);
	void * (*seq_start)(struct seq_file___66 *, loff_t *);
	void * (*seq_next)(struct seq_file___66 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___66 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___57 *, struct cftype___57 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___57 *, struct cftype___57 *, s64);
	ssize_t (*write)(struct kernfs_open_file___68 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___68 *, struct poll_table_struct___50 *);
};

struct cgroup_taskset___6 {
	struct list_head src_csets;
	struct list_head dst_csets;
	int nr_tasks;
	int ssid;
	struct list_head *csets;
	struct css_set___57 *cur_cset;
	struct task_struct___75 *cur_task;
};

struct msghdr___10 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___39 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___68 *msg_iocb;
};

struct socket_wq___10 {
	wait_queue_head_t wait;
	struct fasync_struct___68 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___10;

struct socket___10 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___68 *file;
	struct sock___11 *sk;
	const struct proto_ops___10 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___10 wq;
};

typedef int (*sk_read_actor_t___10)(read_descriptor_t *, struct sk_buff___18 *, unsigned int, size_t);

struct proto_ops___10 {
	int family;
	struct module___66 *owner;
	int (*release)(struct socket___10 *);
	int (*bind)(struct socket___10 *, struct sockaddr *, int);
	int (*connect)(struct socket___10 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___10 *, struct socket___10 *);
	int (*accept)(struct socket___10 *, struct socket___10 *, int, bool);
	int (*getname)(struct socket___10 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___68 *, struct socket___10 *, struct poll_table_struct___50 *);
	int (*ioctl)(struct socket___10 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___10 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___10 *, void *, bool, bool);
	int (*listen)(struct socket___10 *, int);
	int (*shutdown)(struct socket___10 *, int);
	int (*setsockopt)(struct socket___10 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___10 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___66 *, struct socket___10 *);
	int (*sendmsg)(struct socket___10 *, struct msghdr___10 *, size_t);
	int (*recvmsg)(struct socket___10 *, struct msghdr___10 *, size_t, int);
	int (*mmap)(struct file___68 *, struct socket___10 *, struct vm_area_struct___73 *);
	ssize_t (*sendpage)(struct socket___10 *, struct page___73 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___10 *, loff_t *, struct pipe_inode_info___28 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___11 *, int);
	int (*peek_len)(struct socket___10 *);
	int (*read_sock)(struct sock___11 *, read_descriptor_t *, sk_read_actor_t___10);
	int (*sendpage_locked)(struct sock___11 *, struct page___73 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___11 *, struct msghdr___10 *, size_t);
	int (*set_rcvlowat)(struct sock___11 *, int);
};

struct dev_pm_ops___61 {
	int (*prepare)(struct device___61 *);
	void (*complete)(struct device___61 *);
	int (*suspend)(struct device___61 *);
	int (*resume)(struct device___61 *);
	int (*freeze)(struct device___61 *);
	int (*thaw)(struct device___61 *);
	int (*poweroff)(struct device___61 *);
	int (*restore)(struct device___61 *);
	int (*suspend_late)(struct device___61 *);
	int (*resume_early)(struct device___61 *);
	int (*freeze_late)(struct device___61 *);
	int (*thaw_early)(struct device___61 *);
	int (*poweroff_late)(struct device___61 *);
	int (*restore_early)(struct device___61 *);
	int (*suspend_noirq)(struct device___61 *);
	int (*resume_noirq)(struct device___61 *);
	int (*freeze_noirq)(struct device___61 *);
	int (*thaw_noirq)(struct device___61 *);
	int (*poweroff_noirq)(struct device___61 *);
	int (*restore_noirq)(struct device___61 *);
	int (*runtime_suspend)(struct device___61 *);
	int (*runtime_resume)(struct device___61 *);
	int (*runtime_idle)(struct device___61 *);
};

struct wakeup_source___61 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___61 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___61 {
	struct dev_pm_ops___61 ops;
	int (*start)(struct device___61 *);
	void (*detach)(struct device___61 *, bool);
	int (*activate)(struct device___61 *);
	void (*sync)(struct device___61 *);
	void (*dismiss)(struct device___61 *);
};

struct bus_type___61 {
	const char *name;
	const char *dev_name;
	struct device___61 *dev_root;
	const struct attribute_group___68 **bus_groups;
	const struct attribute_group___68 **dev_groups;
	const struct attribute_group___68 **drv_groups;
	int (*match)(struct device___61 *, struct device_driver___61 *);
	int (*uevent)(struct device___61 *, struct kobj_uevent_env *);
	int (*probe)(struct device___61 *);
	void (*sync_state)(struct device___61 *);
	void (*remove)(struct device___61 *);
	void (*shutdown)(struct device___61 *);
	int (*online)(struct device___61 *);
	int (*offline)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	int (*num_vf)(struct device___61 *);
	int (*dma_configure)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___61 {
	const char *name;
	struct bus_type___61 *bus;
	struct module___66 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___61 *);
	void (*sync_state)(struct device___61 *);
	int (*remove)(struct device___61 *);
	void (*shutdown)(struct device___61 *);
	int (*suspend)(struct device___61 *, pm_message_t);
	int (*resume)(struct device___61 *);
	const struct attribute_group___68 **groups;
	const struct attribute_group___68 **dev_groups;
	const struct dev_pm_ops___61 *pm;
	void (*coredump)(struct device___61 *);
	struct driver_private *p;
};

struct device_type___61 {
	const char *name;
	const struct attribute_group___68 **groups;
	int (*uevent)(struct device___61 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___61 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___61 *);
	const struct dev_pm_ops___61 *pm;
};

struct class___61 {
	const char *name;
	struct module___66 *owner;
	const struct attribute_group___68 **class_groups;
	const struct attribute_group___68 **dev_groups;
	struct kobject___68 *dev_kobj;
	int (*dev_uevent)(struct device___61 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___61 *, umode_t *);
	void (*class_release)(struct class___61 *);
	void (*dev_release)(struct device___61 *);
	int (*shutdown_pre)(struct device___61 *);
	const struct kobj_ns_type_operations___10 *ns_type;
	const void * (*namespace)(struct device___61 *);
	void (*get_ownership)(struct device___61 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___61 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___28;

struct pipe_buffer___28 {
	struct page___73 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___28 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___28 {
	int (*confirm)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
	void (*release)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
	bool (*try_steal)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
	bool (*get)(struct pipe_inode_info___28 *, struct pipe_buffer___28 *);
};

struct inet_frags___18;

struct fqdir___18 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___18 *f;
	struct net___19 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___18;

struct inet_frags___18 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___18 *, const void *);
	void (*destructor)(struct inet_frag_queue___18 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___18 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___18 *fragments_tail;
	struct sk_buff___18 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___18 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___10;

struct fib_lookup_arg___10;

struct fib_rules_ops___10 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___10 *, struct flowi *, int, struct fib_lookup_arg___10 *);
	bool (*suppress)(struct fib_rule___10 *, int, struct fib_lookup_arg___10 *);
	int (*match)(struct fib_rule___10 *, struct flowi *, int);
	int (*configure)(struct fib_rule___10 *, struct sk_buff___18 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___10 *);
	int (*compare)(struct fib_rule___10 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___10 *, struct sk_buff___18 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___10 *);
	void (*flush_cache)(struct fib_rules_ops___10 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___66 *owner;
	struct net___19 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___10 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___19 *);
	int (*fib_dump)(struct net___19 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___66 *owner;
	struct callback_head rcu;
};

struct dst_entry___10 {
	struct net_device___21 *dev;
	struct dst_ops___18 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___18 *);
	int (*output)(struct net___19 *, struct sock___11 *, struct sk_buff___18 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___10;

struct neigh_parms___10;

struct neigh_ops___10;

struct neighbour___10 {
	struct neighbour___10 *next;
	struct neigh_table___10 *tbl;
	struct neigh_parms___10 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___16 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___10 *, struct sk_buff___18 *);
	const struct neigh_ops___10 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___21 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___16 {
	int (*ieee_getets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___21 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___21 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___21 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___21 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___21 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___21 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___21 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___21 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___21 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___21 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___21 *);
	u8 (*setstate)(struct net_device___21 *, u8);
	void (*getpermhwaddr)(struct net_device___21 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___21 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___21 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___21 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___21 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___21 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___21 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___21 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___21 *, int, u8 *);
	void (*setpfccfg)(struct net_device___21 *, int, u8);
	void (*getpfccfg)(struct net_device___21 *, int, u8 *);
	u8 (*setall)(struct net_device___21 *);
	u8 (*getcap)(struct net_device___21 *, int, u8 *);
	int (*getnumtcs)(struct net_device___21 *, int, u8 *);
	int (*setnumtcs)(struct net_device___21 *, int, u8);
	u8 (*getpfcstate)(struct net_device___21 *);
	void (*setpfcstate)(struct net_device___21 *, u8);
	void (*getbcncfg)(struct net_device___21 *, int, u32 *);
	void (*setbcncfg)(struct net_device___21 *, int, u32);
	void (*getbcnrp)(struct net_device___21 *, int, u8 *);
	void (*setbcnrp)(struct net_device___21 *, int, u8);
	int (*setapp)(struct net_device___21 *, u8, u16, u8);
	int (*getapp)(struct net_device___21 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___21 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___21 *, int, u8);
	u8 (*getdcbx)(struct net_device___21 *);
	u8 (*setdcbx)(struct net_device___21 *, u8);
	int (*peer_getappinfo)(struct net_device___21 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___21 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___21 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___21 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___21 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___21 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___16 {
	struct net_device___21 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___16 {
	struct net_device___21 *dev;
};

struct xdp_buff___16 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___16 *rxq;
	struct xdp_txq_info___16 *txq;
	u32 frame_sz;
};

struct xdp_frame___16 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___21 *dev_rx;
};

struct netlink_callback___16 {
	struct sk_buff___18 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___18 *, struct netlink_callback___16 *);
	int (*done)(struct netlink_callback___16 *);
	void *data;
	struct module___66 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___16 {
	int (*create)(struct sk_buff___18 *, struct net_device___21 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___18 *, unsigned char *);
	int (*cache)(const struct neighbour___10 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___21 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___18 *);
};

struct netdev_queue___16 {
	struct net_device___21 *dev;
	struct Qdisc___16 *qdisc;
	struct Qdisc___16 *qdisc_sleeping;
	struct kobject___68 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___21 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___16 {
	struct sk_buff___18 *head;
	struct sk_buff___18 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___16;

struct Qdisc___16 {
	int (*enqueue)(struct sk_buff___18 *, struct Qdisc___16 *, struct sk_buff___18 **);
	struct sk_buff___18 * (*dequeue)(struct Qdisc___16 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___16 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___16 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___16 gso_skb;
	struct qdisc_skb_head___16 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___16 *next_sched;
	struct sk_buff_head___16 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___16 {
	struct xdp_rxq_info___16 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___68 kobj;
	struct net_device___21 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___16 {
	enum net_device_path_type type;
	const struct net_device___21 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___16 = 0,
				DEV_PATH_BR_VLAN_TAG___16 = 1,
				DEV_PATH_BR_VLAN_UNTAG___16 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___16 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___16 {
	const struct net_device___21 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___16 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___16 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___16 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___16 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___18 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___16 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___21 *dev;
	const char *name;
};

struct net_device_ops___16 {
	int (*ndo_init)(struct net_device___21 *);
	void (*ndo_uninit)(struct net_device___21 *);
	int (*ndo_open)(struct net_device___21 *);
	int (*ndo_stop)(struct net_device___21 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___18 *, struct net_device___21 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___18 *, struct net_device___21 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___21 *, struct sk_buff___18 *, struct net_device___21 *);
	void (*ndo_change_rx_flags)(struct net_device___21 *, int);
	void (*ndo_set_rx_mode)(struct net_device___21 *);
	int (*ndo_set_mac_address)(struct net_device___21 *, void *);
	int (*ndo_validate_addr)(struct net_device___21 *);
	int (*ndo_do_ioctl)(struct net_device___21 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___21 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___21 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___21 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___21 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___21 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___21 *, int);
	int (*ndo_neigh_setup)(struct net_device___21 *, struct neigh_parms___10 *);
	void (*ndo_tx_timeout)(struct net_device___21 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___21 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___21 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___21 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___21 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___21 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___21 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___21 *);
	int (*ndo_netpoll_setup)(struct net_device___21 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___21 *);
	int (*ndo_set_vf_mac)(struct net_device___21 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___21 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___21 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___21 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___21 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___21 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___21 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___21 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___21 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___21 *, int, struct sk_buff___18 *);
	int (*ndo_get_vf_guid)(struct net_device___21 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___21 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___21 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___21 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___21 *);
	int (*ndo_fcoe_disable)(struct net_device___21 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___21 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___21 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___21 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___21 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___21 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___21 *, const struct sk_buff___18 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___21 *, struct net_device___21 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___21 *, struct net_device___21 *);
	struct net_device___21 * (*ndo_get_xmit_slave)(struct net_device___21 *, struct sk_buff___18 *, bool);
	struct net_device___21 * (*ndo_sk_get_lower_dev)(struct net_device___21 *, struct sock___11 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___21 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___21 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___21 *, struct neighbour___10 *);
	void (*ndo_neigh_destroy)(struct net_device___21 *, struct neighbour___10 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___18 *, struct netlink_callback___16 *, struct net_device___21 *, struct net_device___21 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___18 *, struct nlattr **, struct net_device___21 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___21 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___18 *, u32, u32, struct net_device___21 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___21 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___21 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___21 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___21 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___21 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___21 *, struct net_device___21 *);
	void (*ndo_dfwd_del_station)(struct net_device___21 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___21 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___21 *);
	int (*ndo_change_proto_down)(struct net_device___21 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___21 *, struct sk_buff___18 *);
	void (*ndo_set_rx_headroom)(struct net_device___21 *, int);
	int (*ndo_bpf)(struct net_device___21 *, struct netdev_bpf___16 *);
	int (*ndo_xdp_xmit)(struct net_device___21 *, int, struct xdp_frame___16 **, u32);
	struct net_device___21 * (*ndo_xdp_get_xmit_slave)(struct net_device___21 *, struct xdp_buff___16 *);
	int (*ndo_xsk_wakeup)(struct net_device___21 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___21 *);
	int (*ndo_tunnel_ctl)(struct net_device___21 *, struct ip_tunnel_parm *, int);
	struct net_device___21 * (*ndo_get_peer_dev)(struct net_device___21 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___16 *, struct net_device_path___16 *);
};

struct neigh_parms___10 {
	possible_net_t___16 net;
	struct net_device___21 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___10 *);
	struct neigh_table___10 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___10 {
	u32 (*l3mdev_fib_table)(const struct net_device___21 *);
	struct sk_buff___18 * (*l3mdev_l3_rcv)(struct net_device___21 *, struct sk_buff___18 *, u16);
	struct sk_buff___18 * (*l3mdev_l3_out)(struct net_device___21 *, struct sock___11 *, struct sk_buff___18 *, u16);
	struct dst_entry___10 * (*l3mdev_link_scope_lookup)(const struct net_device___21 *, struct flowi6 *);
};

struct tcf_proto___16;

struct tcf_block___16;

struct mini_Qdisc___16 {
	struct tcf_proto___16 *filter_list;
	struct tcf_block___16 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___16 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___21 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___21 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___19 *, struct net_device___21 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___21 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___21 *, struct list_head *);
	size_t (*get_size)(const struct net_device___21 *);
	int (*fill_info)(struct sk_buff___18 *, const struct net_device___21 *);
	size_t (*get_xstats_size)(const struct net_device___21 *);
	int (*fill_xstats)(struct sk_buff___18 *, const struct net_device___21 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___21 *, struct net_device___21 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___21 *, const struct net_device___21 *);
	int (*fill_slave_info)(struct sk_buff___18 *, const struct net_device___21 *, const struct net_device___21 *);
	struct net___19 * (*get_link_net)(const struct net_device___21 *);
	size_t (*get_linkxstats_size)(const struct net_device___21 *, int);
	int (*fill_linkxstats)(struct sk_buff___18 *, const struct net_device___21 *, int *, int);
};

struct gnet_dump___16 {
	spinlock_t *lock;
	struct sk_buff___18 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___16;

struct Qdisc_ops___16 {
	struct Qdisc_ops___16 *next;
	const struct Qdisc_class_ops___16 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___18 *, struct Qdisc___16 *, struct sk_buff___18 **);
	struct sk_buff___18 * (*dequeue)(struct Qdisc___16 *);
	struct sk_buff___18 * (*peek)(struct Qdisc___16 *);
	int (*init)(struct Qdisc___16 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___16 *);
	void (*destroy)(struct Qdisc___16 *);
	int (*change)(struct Qdisc___16 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___16 *);
	int (*change_tx_queue_len)(struct Qdisc___16 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___16 *, unsigned int);
	int (*dump)(struct Qdisc___16 *, struct sk_buff___18 *);
	int (*dump_stats)(struct Qdisc___16 *, struct gnet_dump___16 *);
	void (*ingress_block_set)(struct Qdisc___16 *, u32);
	void (*egress_block_set)(struct Qdisc___16 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___16 *);
	u32 (*egress_block_get)(struct Qdisc___16 *);
	struct module___66 *owner;
};

struct Qdisc_class_ops___16 {
	unsigned int flags;
	struct netdev_queue___16 * (*select_queue)(struct Qdisc___16 *, struct tcmsg *);
	int (*graft)(struct Qdisc___16 *, long unsigned int, struct Qdisc___16 *, struct Qdisc___16 **, struct netlink_ext_ack *);
	struct Qdisc___16 * (*leaf)(struct Qdisc___16 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___16 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___16 *, u32);
	int (*change)(struct Qdisc___16 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___16 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___16 *, struct qdisc_walker *);
	struct tcf_block___16 * (*tcf_block)(struct Qdisc___16 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___16 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___16 *, long unsigned int);
	int (*dump)(struct Qdisc___16 *, long unsigned int, struct sk_buff___18 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___16 *, long unsigned int, struct gnet_dump___16 *);
};

struct tcf_chain___16;

struct tcf_block___16 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___19 *net;
	struct Qdisc___16 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___16 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___16;

struct tcf_proto_ops___16;

struct tcf_proto___16 {
	struct tcf_proto___16 *next;
	void *root;
	int (*classify)(struct sk_buff___18 *, const struct tcf_proto___16 *, struct tcf_result___16 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___16 *ops;
	struct tcf_chain___16 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___16 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___16 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___16 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___18 *, const struct tcf_proto___16 *, struct tcf_result___16 *);
	int (*init)(struct tcf_proto___16 *);
	void (*destroy)(struct tcf_proto___16 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___16 *, u32);
	void (*put)(struct tcf_proto___16 *, void *);
	int (*change)(struct net___19 *, struct sk_buff___18 *, struct tcf_proto___16 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___16 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___16 *);
	void (*walk)(struct tcf_proto___16 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___16 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___16 *, void *);
	void (*hw_del)(struct tcf_proto___16 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___19 *, struct tcf_chain___16 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___19 *, struct tcf_proto___16 *, void *, struct sk_buff___18 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___19 *, struct tcf_proto___16 *, void *, struct sk_buff___18 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___18 *, struct net___19 *, void *);
	struct module___66 *owner;
	int flags;
};

struct tcf_chain___16 {
	struct mutex filter_chain_lock;
	struct tcf_proto___16 *filter_chain;
	struct list_head list;
	struct tcf_block___16 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___16 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct qdisc_skb_cb {
	struct {
		unsigned int pkt_len;
		u16 slave_dev_queue_mapping;
		u16 tc_classid;
	};
	unsigned char data[20];
};

struct sk_filter___10 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___16 *prog;
};

struct bpf_skb_data_end {
	struct qdisc_skb_cb qdisc_cb;
	void *data_meta;
	void *data_end;
};

struct bpf_sock_addr_kern___2 {
	struct sock___11 *sk;
	struct sockaddr *uaddr;
	u64 tmp_reg;
	void *t_ctx;
};

struct bpf_sock_ops_kern___2 {
	struct sock___11 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___18 *syn_skb;
	struct sk_buff___18 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct bpf_sockopt_buf {
	u8 data[32];
};

struct bpf_sockopt_kern___2 {
	struct sock___11 *sk;
	u8 *optval;
	u8 *optval_end;
	s32 level;
	s32 optname;
	s32 optlen;
	s32 retval;
};

struct block_device_operations___31;

struct gendisk___31 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___32 *part0;
	const struct block_device_operations___31 *fops;
	struct request_queue___32 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___30 *bdi;
	struct kobject___68 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___68 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___31 {
	struct bio___31 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___39 *bip_vec;
	struct bio_vec___39 bip_inline_vecs[0];
};

struct blkcg___30;

struct blkg_policy_data___30;

struct blkcg_gq___30 {
	struct request_queue___32 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___30 *blkcg;
	struct blkcg_gq___30 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___30 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___31 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___31(struct request___31 *);

typedef void integrity_complete_fn___31(struct request___31 *, unsigned int);

struct blk_integrity_profile___31 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___31 *prepare_fn;
	integrity_complete_fn___31 *complete_fn;
	const char *name;
};

struct block_device_operations___31 {
	blk_qc_t (*submit_bio)(struct bio___31 *);
	int (*open)(struct block_device___32 *, fmode_t);
	void (*release)(struct gendisk___31 *, fmode_t);
	int (*rw_page)(struct block_device___32 *, sector_t, struct page___73 *, unsigned int);
	int (*ioctl)(struct block_device___32 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___32 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___31 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___31 *);
	int (*getgeo)(struct block_device___32 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___32 *, bool);
	void (*swap_slot_free_notify)(struct block_device___32 *, long unsigned int);
	int (*report_zones)(struct gendisk___31 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___31 *, umode_t *);
	struct module___66 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___31 *, sector_t *);
};

typedef void rq_end_io_fn___31(struct request___31 *, blk_status_t);

struct request___31 {
	struct request_queue___32 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___30 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___31 *bio;
	struct bio___31 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___39 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___31 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___31 *saved_end_io;
		} flush;
	};
	struct gendisk___31 *rq_disk;
	struct block_device___32 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___31 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___30 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___32 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___68 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___69 *debugfs_dir;
	struct dentry___69 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___31;

struct elevator_mq_ops___31 {
	int (*init_sched)(struct request_queue___32 *, struct elevator_type___31 *);
	void (*exit_sched)(struct elevator_queue___31 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___30 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___30 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___30 *);
	bool (*allow_merge)(struct request_queue___32 *, struct request___31 *, struct bio___31 *);
	bool (*bio_merge)(struct request_queue___32 *, struct bio___31 *, unsigned int);
	int (*request_merge)(struct request_queue___32 *, struct request___31 **, struct bio___31 *);
	void (*request_merged)(struct request_queue___32 *, struct request___31 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___32 *, struct request___31 *, struct request___31 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___31 *);
	void (*finish_request)(struct request___31 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___30 *, struct list_head *, bool);
	struct request___31 * (*dispatch_request)(struct blk_mq_hw_ctx___30 *);
	bool (*has_work)(struct blk_mq_hw_ctx___30 *);
	void (*completed_request)(struct request___31 *, u64);
	void (*requeue_request)(struct request___31 *);
	struct request___31 * (*former_request)(struct request_queue___32 *, struct request___31 *);
	struct request___31 * (*next_request)(struct request_queue___32 *, struct request___31 *);
	void (*init_icq)(struct io_cq___31 *);
	void (*exit_icq)(struct io_cq___31 *);
};

struct elv_fs_entry___31;

struct elevator_type___31 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___31 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___31 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___66 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___31 {
	struct elevator_type___31 *type;
	void *elevator_data;
	struct kobject___68 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___31 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___31 *, char *);
	ssize_t (*store)(struct elevator_queue___31 *, const char *, size_t);
};

struct blk_mq_queue_data___30;

struct blk_mq_ops___30 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___30 *, const struct blk_mq_queue_data___30 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___30 *);
	int (*get_budget)(struct request_queue___32 *);
	void (*put_budget)(struct request_queue___32 *, int);
	void (*set_rq_budget_token)(struct request___31 *, int);
	int (*get_rq_budget_token)(struct request___31 *);
	enum blk_eh_timer_return (*timeout)(struct request___31 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___30 *);
	void (*complete)(struct request___31 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___30 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___30 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___30 *, struct request___31 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___30 *, struct request___31 *, unsigned int);
	void (*initialize_rq_fn)(struct request___31 *);
	void (*cleanup_rq)(struct request___31 *);
	bool (*busy)(struct request_queue___32 *);
	int (*map_queues)(struct blk_mq_tag_set___30 *);
	void (*show_rq)(struct seq_file___66 *, struct request___31 *);
};

struct blk_mq_tag_set___30 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___30 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___30 {
	struct request___31 *rq;
	bool last;
};

struct blkcg_policy_data___30;

struct blkcg___30 {
	struct cgroup_subsys_state___57 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___30 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___30 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___30 {
	struct blkcg___30 *blkcg;
	int plid;
};

struct blkg_policy_data___30 {
	struct blkcg_gq___30 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___28 {
	struct mem_cgroup___28 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___28 {
	struct lruvec___29 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___28 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___28 *memcg;
};

struct obj_cgroup___28 {
	struct percpu_ref refcnt;
	struct mem_cgroup___28 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___10;

struct neigh_hash_table___10;

struct neigh_table___10 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___21 *, __u32 *);
	bool (*key_eq)(const struct neighbour___10 *, const void *);
	int (*constructor)(struct neighbour___10 *);
	int (*pconstructor)(struct pneigh_entry___10 *);
	void (*pdestructor)(struct pneigh_entry___10 *);
	void (*proxy_redo)(struct sk_buff___18 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___21 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___10 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___16 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___10 *nht;
	struct pneigh_entry___10 **phash_buckets;
};

struct neigh_ops___10 {
	int family;
	void (*solicit)(struct neighbour___10 *, struct sk_buff___18 *);
	void (*error_report)(struct neighbour___10 *, struct sk_buff___18 *);
	int (*output)(struct neighbour___10 *, struct sk_buff___18 *);
	int (*connected_output)(struct neighbour___10 *, struct sk_buff___18 *);
};

struct pneigh_entry___10 {
	struct pneigh_entry___10 *next;
	possible_net_t___16 net;
	struct net_device___21 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___10 {
	struct neighbour___10 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

enum {
	TCPF_ESTABLISHED = 2,
	TCPF_SYN_SENT = 4,
	TCPF_SYN_RECV = 8,
	TCPF_FIN_WAIT1 = 16,
	TCPF_FIN_WAIT2 = 32,
	TCPF_TIME_WAIT = 64,
	TCPF_CLOSE = 128,
	TCPF_CLOSE_WAIT = 256,
	TCPF_LAST_ACK = 512,
	TCPF_LISTEN = 1024,
	TCPF_CLOSING = 2048,
	TCPF_NEW_SYN_RECV = 4096,
};

struct fib_rule___10 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___10 *ctarget;
	struct net___19 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___10 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___10 *rule;
	u32 table;
	int flags;
};

struct proto___10 {
	void (*close)(struct sock___11 *, long int);
	int (*pre_connect)(struct sock___11 *, struct sockaddr *, int);
	int (*connect)(struct sock___11 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___11 *, int);
	struct sock___11 * (*accept)(struct sock___11 *, int, int *, bool);
	int (*ioctl)(struct sock___11 *, int, long unsigned int);
	int (*init)(struct sock___11 *);
	void (*destroy)(struct sock___11 *);
	void (*shutdown)(struct sock___11 *, int);
	int (*setsockopt)(struct sock___11 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___11 *, int, int, char *, int *);
	void (*keepalive)(struct sock___11 *, int);
	int (*compat_ioctl)(struct sock___11 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___11 *, struct msghdr___10 *, size_t);
	int (*recvmsg)(struct sock___11 *, struct msghdr___10 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___11 *, struct page___73 *, int, size_t, int);
	int (*bind)(struct sock___11 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___11 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___11 *, struct sk_buff___18 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___11 *);
	int (*hash)(struct sock___11 *);
	void (*unhash)(struct sock___11 *);
	void (*rehash)(struct sock___11 *);
	int (*get_port)(struct sock___11 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___11 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___11 *, int);
	bool (*sock_is_readable)(struct sock___11 *);
	void (*enter_memory_pressure)(struct sock___11 *);
	void (*leave_memory_pressure)(struct sock___11 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___66 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___11 *, int);
};

struct bpf_local_storage_data___5 {
	struct bpf_local_storage_map___5 *smap;
	u8 data[0];
};

struct fs_parameter___10 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___68 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___10 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___66 *owner;
	char *buffer[8];
};

struct fs_context_operations___10 {
	void (*free)(struct fs_context___10 *);
	int (*dup)(struct fs_context___10 *, struct fs_context___10 *);
	int (*parse_param)(struct fs_context___10 *, struct fs_parameter___10 *);
	int (*parse_monolithic)(struct fs_context___10 *, void *);
	int (*get_tree)(struct fs_context___10 *);
	int (*reconfigure)(struct fs_context___10 *);
};

typedef u64 (*btf_bpf_sysctl_get_name)(struct bpf_sysctl_kern *, char *, size_t, u64);

typedef u64 (*btf_bpf_sysctl_get_current_value)(struct bpf_sysctl_kern *, char *, size_t);

typedef u64 (*btf_bpf_sysctl_get_new_value)(struct bpf_sysctl_kern *, char *, size_t);

typedef u64 (*btf_bpf_sysctl_set_new_value)(struct bpf_sysctl_kern *, const char *, size_t);

typedef u64 (*btf_bpf_get_netns_cookie_sockopt)(struct bpf_sockopt_kern___2 *);

enum sock_type {
	SOCK_STREAM = 1,
	SOCK_DGRAM = 2,
	SOCK_RAW = 3,
	SOCK_RDM = 4,
	SOCK_SEQPACKET = 5,
	SOCK_DCCP = 6,
	SOCK_PACKET = 10,
};

enum {
	IPPROTO_IP = 0,
	IPPROTO_ICMP = 1,
	IPPROTO_IGMP = 2,
	IPPROTO_IPIP = 4,
	IPPROTO_TCP = 6,
	IPPROTO_EGP = 8,
	IPPROTO_PUP = 12,
	IPPROTO_UDP = 17,
	IPPROTO_IDP = 22,
	IPPROTO_TP = 29,
	IPPROTO_DCCP = 33,
	IPPROTO_IPV6 = 41,
	IPPROTO_RSVP = 46,
	IPPROTO_GRE = 47,
	IPPROTO_ESP = 50,
	IPPROTO_AH = 51,
	IPPROTO_MTP = 92,
	IPPROTO_BEETPH = 94,
	IPPROTO_ENCAP = 98,
	IPPROTO_PIM = 103,
	IPPROTO_COMP = 108,
	IPPROTO_SCTP = 132,
	IPPROTO_UDPLITE = 136,
	IPPROTO_MPLS = 137,
	IPPROTO_ETHERNET = 143,
	IPPROTO_RAW = 255,
	IPPROTO_MPTCP = 262,
	IPPROTO_MAX = 263,
};

struct sock_reuseport {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany;
	unsigned int has_conns;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___6 *prog;
	struct sock___7 *socks[0];
};

enum sock_flags {
	SOCK_DEAD = 0,
	SOCK_DONE = 1,
	SOCK_URGINLINE = 2,
	SOCK_KEEPOPEN = 3,
	SOCK_LINGER = 4,
	SOCK_DESTROY = 5,
	SOCK_BROADCAST = 6,
	SOCK_TIMESTAMP = 7,
	SOCK_ZAPPED = 8,
	SOCK_USE_WRITE_QUEUE = 9,
	SOCK_DBG = 10,
	SOCK_RCVTSTAMP = 11,
	SOCK_RCVTSTAMPNS = 12,
	SOCK_LOCALROUTE = 13,
	SOCK_MEMALLOC = 14,
	SOCK_TIMESTAMPING_RX_SOFTWARE = 15,
	SOCK_FASYNC = 16,
	SOCK_RXQ_OVFL = 17,
	SOCK_ZEROCOPY = 18,
	SOCK_WIFI_STATUS = 19,
	SOCK_NOFCS = 20,
	SOCK_FILTER_LOCKED = 21,
	SOCK_SELECT_ERR_QUEUE = 22,
	SOCK_RCU_FREE = 23,
	SOCK_TXTIME = 24,
	SOCK_XDP = 25,
	SOCK_TSTAMP_NEW = 26,
};

struct reuseport_array {
	struct bpf_map___6 map;
	struct sock___7 *ptrs[0];
};

struct bpf_tramp_progs___2 {
	struct bpf_prog___13 *progs[38];
	int nr_progs;
};

struct bpf_struct_ops___2 {
	const struct bpf_verifier_ops___4 *verifier_ops;
	int (*init)(struct btf *);
	int (*check_member)(const struct btf_type *, const struct btf_member *);
	int (*init_member)(const struct btf_type *, const struct btf_member *, void *, const void *);
	int (*reg)(void *);
	void (*unreg)(void *);
	const struct btf_type *type;
	const struct btf_type *value_type;
	const char *name;
	struct btf_func_model func_models[64];
	u32 type_id;
	u32 value_id;
};

enum bpf_struct_ops_state {
	BPF_STRUCT_OPS_STATE_INIT = 0,
	BPF_STRUCT_OPS_STATE_INUSE = 1,
	BPF_STRUCT_OPS_STATE_TOBEFREE = 2,
};

struct bpf_struct_ops_value {
	refcount_t refcnt;
	enum bpf_struct_ops_state state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char data[0];
};

struct bpf_struct_ops_map {
	struct bpf_map___14 map;
	struct callback_head rcu;
	const struct bpf_struct_ops___2 *st_ops;
	struct mutex lock;
	struct bpf_prog___13 **progs;
	void *image;
	struct bpf_struct_ops_value *uvalue;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_struct_ops_value kvalue;
};

struct bpf_struct_ops_tcp_congestion_ops {
	refcount_t refcnt;
	enum bpf_struct_ops_state state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct tcp_congestion_ops data;
};

struct dentry___70;

struct super_block___70;

struct module___67;

struct file_system_type___69 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___70 * (*mount)(struct file_system_type___69 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___70 *);
	struct module___67 *owner;
	struct file_system_type___69 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___69;

struct kiocb___69;

struct iov_iter___40;

struct poll_table_struct___51;

struct vm_area_struct___74;

struct inode___70;

struct file_lock___69;

struct page___74;

struct pipe_inode_info___29;

struct seq_file___67;

struct file_operations___69 {
	struct module___67 *owner;
	loff_t (*llseek)(struct file___69 *, loff_t, int);
	ssize_t (*read)(struct file___69 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___69 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___69 *, struct iov_iter___40 *);
	ssize_t (*write_iter)(struct kiocb___69 *, struct iov_iter___40 *);
	int (*iopoll)(struct kiocb___69 *, bool);
	int (*iterate)(struct file___69 *, struct dir_context *);
	int (*iterate_shared)(struct file___69 *, struct dir_context *);
	__poll_t (*poll)(struct file___69 *, struct poll_table_struct___51 *);
	long int (*unlocked_ioctl)(struct file___69 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___69 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___69 *, struct vm_area_struct___74 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___70 *, struct file___69 *);
	int (*flush)(struct file___69 *, fl_owner_t);
	int (*release)(struct inode___70 *, struct file___69 *);
	int (*fsync)(struct file___69 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___69 *, int);
	int (*lock)(struct file___69 *, int, struct file_lock___69 *);
	ssize_t (*sendpage)(struct file___69 *, struct page___74 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___69 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___69 *, long unsigned int);
	int (*flock)(struct file___69 *, int, struct file_lock___69 *);
	ssize_t (*splice_write)(struct pipe_inode_info___29 *, struct file___69 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___69 *, loff_t *, struct pipe_inode_info___29 *, size_t, unsigned int);
	int (*setlease)(struct file___69 *, long int, struct file_lock___69 **, void **);
	long int (*fallocate)(struct file___69 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___67 *, struct file___69 *);
	ssize_t (*copy_file_range)(struct file___69 *, loff_t, struct file___69 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___69 *, loff_t, struct file___69 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___69 *, loff_t, loff_t, int);
};

struct vmacache___74 {
	u64 seqnum;
	struct vm_area_struct___74 *vmas[4];
};

struct page_frag___74 {
	struct page___74 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___75;

struct pid___62;

struct nsproxy___67;

struct signal_struct___70;

struct bio_list___32;

struct backing_dev_info___31;

struct io_context___32;

struct css_set___58;

struct mem_cgroup___29;

struct request_queue___33;

struct vm_struct___70;

struct bpf_local_storage___6;

struct task_struct___76 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___76 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___75 *mm;
	struct mm_struct___75 *active_mm;
	struct vmacache___74 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___76 *real_parent;
	struct task_struct___76 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___76 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___62 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___10 *ptracer_cred;
	const struct cred___10 *real_cred;
	const struct cred___10 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___67 *nsproxy;
	struct signal_struct___70 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___76 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___32 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___31 *backing_dev_info;
	struct io_context___32 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___58 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___29 *splice_pipe;
	struct page_frag___74 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___29 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___29 *active_memcg;
	struct request_queue___33 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___76 *oom_reaper_list;
	struct vm_struct___70 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___6 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___43 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___69;

struct kobj_type___69;

struct kernfs_node___69;

struct kobject___69 {
	const char *name;
	struct list_head entry;
	struct kobject___69 *parent;
	struct kset___69 *kset;
	struct kobj_type___69 *ktype;
	struct kernfs_node___69 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___66 {
	struct kobject___69 kobj;
	struct module___67 *mod;
	struct kobject___69 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___66 {
	struct module___67 *mod;
	struct latch_tree_node node;
};

struct module_layout___66 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___66 mtn;
};

struct module_attribute___66;

struct kernel_param___66;

struct module___67 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___66 mkobj;
	struct module_attribute___66 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___69 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___66 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___66 core_layout;
	struct module_layout___66 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___62;

struct upid___62 {
	int nr;
	struct pid_namespace___62 *ns;
};

struct pid_namespace___62 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___76 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___62 *parent;
	struct fs_pin *bacct;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	int reboot;
	struct ns_common___12 ns;
};

struct pid___62 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___62 numbers[1];
};

struct sembuf {
	short unsigned int sem_num;
	short int sem_op;
	short int sem_flg;
};

typedef struct page___74 *pgtable_t___74;

struct address_space___69;

struct page_pool___26;

struct dev_pagemap___68;

struct page___74 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___69 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___26 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___74 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___74 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___75 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___68 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___68;

struct vm_area_struct___74 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___74 *vm_next;
	struct vm_area_struct___74 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___75 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___68 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___69 *vm_file;
	struct file___69 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___70 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___76 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___76 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___62 *pids[4];
	struct pid___62 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___75 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___14;

struct core_state___74;

struct mm_struct___75 {
	struct {
		struct vm_area_struct___74 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___69 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___14 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___74 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___76 *owner;
		struct user_namespace___11 *user_ns;
		struct file___69 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___20;

struct cgroup_namespace___58;

struct nsproxy___67 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___62 *pid_ns_for_children;
	struct net___20 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___58 *cgroup_ns;
};

struct bio___32;

struct bio_list___32 {
	struct bio___32 *head;
	struct bio___32 *tail;
};

struct cgroup_subsys_state___58;

struct bdi_writeback___31 {
	struct backing_dev_info___31 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___58 *memcg_css;
	struct cgroup_subsys_state___58 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___62;

struct backing_dev_info___31 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___31 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___62 *dev;
	char dev_name[64];
	struct device___62 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___70 *debug_dir;
};

struct io_cq___32;

struct io_context___32 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___32 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___58;

struct css_set___58 {
	struct cgroup_subsys_state___58 *subsys[14];
	refcount_t refcount;
	struct css_set___58 *dom_cset;
	struct cgroup___58 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___58 *mg_src_cgrp;
	struct cgroup___58 *mg_dst_cgrp;
	struct css_set___58 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___69;

struct pipe_buffer___29;

struct pipe_inode_info___29 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___74 *tmp_page;
	struct fasync_struct___69 *fasync_readers;
	struct fasync_struct___69 *fasync_writers;
	struct pipe_buffer___29 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___58;

struct cgroup_subsys_state___58 {
	struct cgroup___58 *cgroup;
	struct cgroup_subsys___58 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___58 *parent;
};

struct cgroup_file___58 {
	struct kernfs_node___69 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___29;

struct mem_cgroup_per_node___29;

struct mem_cgroup___29 {
	struct cgroup_subsys_state___58 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___58 events_file;
	struct cgroup_file___58 events_local_file;
	struct cgroup_file___58 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___29 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___76 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___29 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___32;

struct blk_integrity___32 {
	const struct blk_integrity_profile___32 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___32 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___32 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___32;

struct elevator_queue___32;

struct blk_mq_ops___31;

struct blk_mq_hw_ctx___31;

struct gendisk___32;

struct blkcg_gq___31;

struct blk_mq_tag_set___31;

struct request_queue___33 {
	struct request___32 *last_merge;
	struct elevator_queue___32 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___31 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___31 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___32 *disk;
	struct kobject___69 kobj;
	struct kobject___69 *mq_kobj;
	struct blk_integrity___32 integrity;
	struct device___62 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___31 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___31 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___32 bio_split;
	struct dentry___70 *debugfs_dir;
	struct dentry___70 *sched_debugfs_dir;
	struct dentry___70 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___70 {
	struct vm_struct___70 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___74 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___6;

struct bpf_local_storage___6 {
	struct bpf_local_storage_data___6 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct bio_vec___40 {
	struct page___74 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___40 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___40 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___29 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___11 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___40 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___69 *msg_iocb;
};

struct kiocb___69 {
	struct file___69 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___69 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___27 *ki_waitq;
	};
};

struct dentry_operations___69;

struct dentry___70 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___70 *d_parent;
	struct qstr d_name;
	struct inode___70 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___69 *d_op;
	struct super_block___70 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___69;

struct address_space___69 {
	struct inode___70 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___69 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___69;

struct inode___70 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___69 *i_op;
	struct super_block___70 *i_sb;
	struct address_space___69 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___31 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___69 *i_fop;
		void (*free_inode)(struct inode___70 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___69 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___29 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___69;

struct path___69;

struct dentry_operations___69 {
	int (*d_revalidate)(struct dentry___70 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___70 *, unsigned int);
	int (*d_hash)(const struct dentry___70 *, struct qstr *);
	int (*d_compare)(const struct dentry___70 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___70 *);
	int (*d_init)(struct dentry___70 *);
	void (*d_release)(struct dentry___70 *);
	void (*d_prune)(struct dentry___70 *);
	void (*d_iput)(struct dentry___70 *, struct inode___70 *);
	char * (*d_dname)(struct dentry___70 *, char *, int);
	struct vfsmount___69 * (*d_automount)(struct path___69 *);
	int (*d_manage)(const struct path___69 *, bool);
	struct dentry___70 * (*d_real)(struct dentry___70 *, const struct inode___70 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___69;

struct mem_dqinfo___69 {
	struct quota_format_type___69 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___69;

struct quota_info___69 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___70 *files[3];
	struct mem_dqinfo___69 info[3];
	const struct quota_format_ops___69 *ops[3];
};

struct rcuwait___70 {
	struct task_struct___76 *task;
};

struct percpu_rw_semaphore___70 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___70 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___69 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___70 rw_sem[3];
};

struct shrink_control___29;

struct shrinker___29 {
	long unsigned int (*count_objects)(struct shrinker___29 *, struct shrink_control___29 *);
	long unsigned int (*scan_objects)(struct shrinker___29 *, struct shrink_control___29 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___69;

struct dquot_operations___69;

struct quotactl_ops___69;

struct block_device___33;

struct super_block___70 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___69 *s_type;
	const struct super_operations___69 *s_op;
	const struct dquot_operations___69 *dq_op;
	const struct quotactl_ops___69 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___70 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___33 *s_bdev;
	struct backing_dev_info___31 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___69 s_dquot;
	struct sb_writers___69 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___69 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___11 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___69 {
	struct dentry___70 *mnt_root;
	struct super_block___70 *mnt_sb;
	int mnt_flags;
	struct user_namespace___11 *mnt_userns;
};

struct path___69 {
	struct vfsmount___69 *mnt;
	struct dentry___70 *dentry;
};

struct shrink_control___29 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___29 *memcg;
};

struct page_pool_params___26 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___62 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___26 {
	u32 count;
	struct page___74 *cache[128];
};

struct page_pool___26 {
	struct page_pool_params___26 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___74 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___26 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___68;

struct dev_pagemap___68 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___68 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___62 {
	rwlock_t lock;
	struct pid___62 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___69 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___69 f_path;
	struct inode___70 *f_inode;
	const struct file_operations___69 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___62 f_owner;
	const struct cred___10 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___69 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___68;

struct vm_operations_struct___68 {
	void (*open)(struct vm_area_struct___74 *);
	void (*close)(struct vm_area_struct___74 *);
	int (*may_split)(struct vm_area_struct___74 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___74 *);
	int (*mprotect)(struct vm_area_struct___74 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___68 *);
	vm_fault_t (*huge_fault)(struct vm_fault___68 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___68 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___74 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___68 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___68 *);
	int (*access)(struct vm_area_struct___74 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___74 *);
	int (*set_policy)(struct vm_area_struct___74 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___74 *, long unsigned int);
	struct page___74 * (*find_special_page)(struct vm_area_struct___74 *, long unsigned int);
};

struct core_thread___74 {
	struct task_struct___76 *task;
	struct core_thread___74 *next;
};

struct core_state___74 {
	atomic_t nr_threads;
	struct core_thread___74 dumper;
	struct completion startup;
};

struct linux_binprm___15;

struct coredump_params___14;

struct linux_binfmt___14 {
	struct list_head lh;
	struct module___67 *module;
	int (*load_binary)(struct linux_binprm___15 *);
	int (*load_shlib)(struct file___69 *);
	int (*core_dump)(struct coredump_params___14 *);
	long unsigned int min_coredump;
};

struct vm_fault___68 {
	const struct {
		struct vm_area_struct___74 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___74 *cow_page;
	struct page___74 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___74 prealloc_pte;
};

struct pglist_data___30;

struct lruvec___30 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___30 *pgdat;
};

struct zone___30 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___30 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___30 {
	struct zone___30 *zone;
	int zone_idx;
};

struct zonelist___30 {
	struct zoneref___30 _zonerefs[321];
};

struct pglist_data___30 {
	struct zone___30 node_zones[5];
	struct zonelist___30 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___76 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___76 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___30 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___58 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___76 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___17;

struct cgroup_bpf___17 {
	struct bpf_prog_array___17 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___17 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___58;

struct cgroup_rstat_cpu___58;

struct cgroup___58 {
	struct cgroup_subsys_state___58 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___69 *kn;
	struct cgroup_file___58 procs_file;
	struct cgroup_file___58 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___58 *subsys[14];
	struct cgroup_root___58 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___58 *dom_cgrp;
	struct cgroup___58 *old_dom_cgrp;
	struct cgroup_rstat_cpu___58 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___58 psi;
	struct cgroup_bpf___17 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

enum key_need_perm {
	KEY_NEED_UNSPECIFIED = 0,
	KEY_NEED_VIEW = 1,
	KEY_NEED_READ = 2,
	KEY_NEED_WRITE = 3,
	KEY_NEED_SEARCH = 4,
	KEY_NEED_LINK = 5,
	KEY_NEED_SETATTR = 6,
	KEY_NEED_UNLINK = 7,
	KEY_SYSADMIN_OVERRIDE = 8,
	KEY_AUTHTOKEN_OVERRIDE = 9,
	KEY_DEFER_PERM_CHECK = 10,
};

struct __key_reference_with_attributes;

typedef struct __key_reference_with_attributes *key_ref_t;

struct io_cq___32 {
	struct request_queue___33 *q;
	struct io_context___32 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___70 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___69 *ia_file;
};

struct dquot___69 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___70 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___69 {
	int qf_fmt_id;
	const struct quota_format_ops___69 *qf_ops;
	struct module___67 *qf_owner;
	struct quota_format_type___69 *qf_next;
};

struct quota_format_ops___69 {
	int (*check_quota_file)(struct super_block___70 *, int);
	int (*read_file_info)(struct super_block___70 *, int);
	int (*write_file_info)(struct super_block___70 *, int);
	int (*free_file_info)(struct super_block___70 *, int);
	int (*read_dqblk)(struct dquot___69 *);
	int (*commit_dqblk)(struct dquot___69 *);
	int (*release_dqblk)(struct dquot___69 *);
	int (*get_next_id)(struct super_block___70 *, struct kqid *);
};

struct dquot_operations___69 {
	int (*write_dquot)(struct dquot___69 *);
	struct dquot___69 * (*alloc_dquot)(struct super_block___70 *, int);
	void (*destroy_dquot)(struct dquot___69 *);
	int (*acquire_dquot)(struct dquot___69 *);
	int (*release_dquot)(struct dquot___69 *);
	int (*mark_dirty)(struct dquot___69 *);
	int (*write_info)(struct super_block___70 *, int);
	qsize_t * (*get_reserved_space)(struct inode___70 *);
	int (*get_projid)(struct inode___70 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___70 *, qsize_t *);
	int (*get_next_id)(struct super_block___70 *, struct kqid *);
};

struct quotactl_ops___69 {
	int (*quota_on)(struct super_block___70 *, int, int, const struct path___69 *);
	int (*quota_off)(struct super_block___70 *, int);
	int (*quota_enable)(struct super_block___70 *, unsigned int);
	int (*quota_disable)(struct super_block___70 *, unsigned int);
	int (*quota_sync)(struct super_block___70 *, int);
	int (*set_info)(struct super_block___70 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___70 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___70 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___70 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___70 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___70 *, unsigned int);
};

struct writeback_control___31;

struct address_space_operations___69 {
	int (*writepage)(struct page___74 *, struct writeback_control___31 *);
	int (*readpage)(struct file___69 *, struct page___74 *);
	int (*writepages)(struct address_space___69 *, struct writeback_control___31 *);
	int (*set_page_dirty)(struct page___74 *);
	int (*readpages)(struct file___69 *, struct address_space___69 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___69 *, struct address_space___69 *, loff_t, unsigned int, unsigned int, struct page___74 **, void **);
	int (*write_end)(struct file___69 *, struct address_space___69 *, loff_t, unsigned int, unsigned int, struct page___74 *, void *);
	sector_t (*bmap)(struct address_space___69 *, sector_t);
	void (*invalidatepage)(struct page___74 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___74 *, gfp_t);
	void (*freepage)(struct page___74 *);
	ssize_t (*direct_IO)(struct kiocb___69 *, struct iov_iter___40 *);
	int (*migratepage)(struct address_space___69 *, struct page___74 *, struct page___74 *, enum migrate_mode);
	bool (*isolate_page)(struct page___74 *, isolate_mode_t);
	void (*putback_page)(struct page___74 *);
	int (*launder_page)(struct page___74 *);
	int (*is_partially_uptodate)(struct page___74 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___74 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___69 *, struct page___74 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___69 *, sector_t *);
	void (*swap_deactivate)(struct file___69 *);
};

struct writeback_control___31 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___31 *wb;
	struct inode___70 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___69 {
	struct dentry___70 * (*lookup)(struct inode___70 *, struct dentry___70 *, unsigned int);
	const char * (*get_link)(struct dentry___70 *, struct inode___70 *, struct delayed_call *);
	int (*permission)(struct user_namespace___11 *, struct inode___70 *, int);
	struct posix_acl * (*get_acl)(struct inode___70 *, int, bool);
	int (*readlink)(struct dentry___70 *, char *, int);
	int (*create)(struct user_namespace___11 *, struct inode___70 *, struct dentry___70 *, umode_t, bool);
	int (*link)(struct dentry___70 *, struct inode___70 *, struct dentry___70 *);
	int (*unlink)(struct inode___70 *, struct dentry___70 *);
	int (*symlink)(struct user_namespace___11 *, struct inode___70 *, struct dentry___70 *, const char *);
	int (*mkdir)(struct user_namespace___11 *, struct inode___70 *, struct dentry___70 *, umode_t);
	int (*rmdir)(struct inode___70 *, struct dentry___70 *);
	int (*mknod)(struct user_namespace___11 *, struct inode___70 *, struct dentry___70 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___11 *, struct inode___70 *, struct dentry___70 *, struct inode___70 *, struct dentry___70 *, unsigned int);
	int (*setattr)(struct user_namespace___11 *, struct dentry___70 *, struct iattr___70 *);
	int (*getattr)(struct user_namespace___11 *, const struct path___69 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___70 *, char *, size_t);
	int (*fiemap)(struct inode___70 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___70 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___70 *, struct dentry___70 *, struct file___69 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___11 *, struct inode___70 *, struct dentry___70 *, umode_t);
	int (*set_acl)(struct user_namespace___11 *, struct inode___70 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___11 *, struct dentry___70 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___70 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___69 {
	void (*fl_copy_lock)(struct file_lock___69 *, struct file_lock___69 *);
	void (*fl_release_private)(struct file_lock___69 *);
};

struct lock_manager_operations___69;

struct file_lock___69 {
	struct file_lock___69 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___69 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___69 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___69 *fl_ops;
	const struct lock_manager_operations___69 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___69 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___69 *);
	int (*lm_grant)(struct file_lock___69 *, int);
	bool (*lm_break)(struct file_lock___69 *);
	int (*lm_change)(struct file_lock___69 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___69 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___69 *);
};

struct fasync_struct___69 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___69 *fa_next;
	struct file___69 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___69 {
	struct inode___70 * (*alloc_inode)(struct super_block___70 *);
	void (*destroy_inode)(struct inode___70 *);
	void (*free_inode)(struct inode___70 *);
	void (*dirty_inode)(struct inode___70 *, int);
	int (*write_inode)(struct inode___70 *, struct writeback_control___31 *);
	int (*drop_inode)(struct inode___70 *);
	void (*evict_inode)(struct inode___70 *);
	void (*put_super)(struct super_block___70 *);
	int (*sync_fs)(struct super_block___70 *, int);
	int (*freeze_super)(struct super_block___70 *);
	int (*freeze_fs)(struct super_block___70 *);
	int (*thaw_super)(struct super_block___70 *);
	int (*unfreeze_fs)(struct super_block___70 *);
	int (*statfs)(struct dentry___70 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___70 *, int *, char *);
	void (*umount_begin)(struct super_block___70 *);
	int (*show_options)(struct seq_file___67 *, struct dentry___70 *);
	int (*show_devname)(struct seq_file___67 *, struct dentry___70 *);
	int (*show_path)(struct seq_file___67 *, struct dentry___70 *);
	int (*show_stats)(struct seq_file___67 *, struct dentry___70 *);
	ssize_t (*quota_read)(struct super_block___70 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___70 *, int, const char *, size_t, loff_t);
	struct dquot___69 ** (*get_dquots)(struct inode___70 *);
	long int (*nr_cached_objects)(struct super_block___70 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___70 *, struct shrink_control___29 *);
	struct file___69 * (*real_loop)(struct file___69 *);
};

struct wakeup_source___62;

struct dev_pm_info___62 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___62 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___62 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___62;

struct bus_type___62;

struct device_driver___62;

struct dev_pm_domain___62;

struct fwnode_handle___62;

struct class___62;

struct attribute_group___69;

struct device___62 {
	struct kobject___69 kobj;
	struct device___62 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___62 *type;
	struct bus_type___62 *bus;
	struct device_driver___62 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___62 power;
	struct dev_pm_domain___62 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___62 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___62 *class;
	const struct attribute_group___69 **groups;
	void (*release)(struct device___62 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___33 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___70 *bd_inode;
	struct super_block___70 *bd_super;
	void *bd_claiming;
	struct device___62 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___69 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___32 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___70 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___51)(struct file___69 *, wait_queue_head_t *, struct poll_table_struct___51 *);

struct poll_table_struct___51 {
	poll_queue_proc___51 _qproc;
	__poll_t _key;
};

struct seq_operations___67;

struct seq_file___67 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___67 *op;
	int poll_event;
	const struct file___69 *file;
	void *private;
};

typedef void bio_end_io_t___32(struct bio___32 *);

struct bio_integrity_payload___32;

struct bio___32 {
	struct bio___32 *bi_next;
	struct block_device___33 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___32 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___31 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___32 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___40 *bi_io_vec;
	struct bio_set___32 *bi_pool;
	struct bio_vec___40 bi_inline_vecs[0];
};

struct dev_pagemap_ops___68 {
	void (*page_free)(struct page___74 *);
	void (*kill)(struct dev_pagemap___68 *);
	void (*cleanup)(struct dev_pagemap___68 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___68 *);
};

struct fwnode_operations___62;

struct fwnode_handle___62 {
	struct fwnode_handle___62 *secondary;
	const struct fwnode_operations___62 *ops;
	struct device___62 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___62;

struct fwnode_endpoint___62;

struct fwnode_operations___62 {
	struct fwnode_handle___62 * (*get)(struct fwnode_handle___62 *);
	void (*put)(struct fwnode_handle___62 *);
	bool (*device_is_available)(const struct fwnode_handle___62 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___62 *, const struct device___62 *);
	bool (*property_present)(const struct fwnode_handle___62 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___62 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___62 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___62 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*get_parent)(const struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*get_next_child_node)(const struct fwnode_handle___62 *, struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*get_named_child_node)(const struct fwnode_handle___62 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___62 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___62 *);
	struct fwnode_handle___62 * (*graph_get_next_endpoint)(const struct fwnode_handle___62 *, struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*graph_get_remote_endpoint)(const struct fwnode_handle___62 *);
	struct fwnode_handle___62 * (*graph_get_port_parent)(struct fwnode_handle___62 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___62 *, struct fwnode_endpoint___62 *);
	int (*add_links)(struct fwnode_handle___62 *);
};

struct fwnode_endpoint___62 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___62 *local_fwnode;
};

struct fwnode_reference_args___62 {
	struct fwnode_handle___62 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___69;

struct kernfs_elem_dir___69 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___69 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___69;

struct kernfs_root___69 {
	struct kernfs_node___69 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___69 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___69 {
	struct kernfs_node___69 *target_kn;
};

struct kernfs_ops___69;

struct kernfs_elem_attr___69 {
	const struct kernfs_ops___69 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___69 *notify_next;
};

struct kernfs_node___69 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___69 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___69 dir;
		struct kernfs_elem_symlink___69 symlink;
		struct kernfs_elem_attr___69 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___69;

struct kernfs_ops___69 {
	int (*open)(struct kernfs_open_file___69 *);
	void (*release)(struct kernfs_open_file___69 *);
	int (*seq_show)(struct seq_file___67 *, void *);
	void * (*seq_start)(struct seq_file___67 *, loff_t *);
	void * (*seq_next)(struct seq_file___67 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___67 *, void *);
	ssize_t (*read)(struct kernfs_open_file___69 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___69 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___69 *, struct poll_table_struct___51 *);
	int (*mmap)(struct kernfs_open_file___69 *, struct vm_area_struct___74 *);
};

struct kernfs_syscall_ops___69 {
	int (*show_options)(struct seq_file___67 *, struct kernfs_root___69 *);
	int (*mkdir)(struct kernfs_node___69 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___69 *);
	int (*rename)(struct kernfs_node___69 *, struct kernfs_node___69 *, const char *);
	int (*show_path)(struct seq_file___67 *, struct kernfs_node___69 *, struct kernfs_root___69 *);
};

struct kernfs_open_file___69 {
	struct kernfs_node___69 *kn;
	struct file___69 *file;
	struct seq_file___67 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___68 *vm_ops;
};

struct sock___12;

struct kobj_ns_type_operations___11 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___12 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___20 *net;
} possible_net_t___17;

struct proto___11;

struct sock_common___11 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___11 *skc_prot;
	possible_net_t___17 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___12 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___19;

struct sk_buff_head___17 {
	struct sk_buff___19 *next;
	struct sk_buff___19 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___11 {
	struct cgroup___58 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___11;

struct socket_wq___11;

struct dst_entry___11;

struct socket___11;

struct net_device___22;

struct sock___12 {
	struct sock_common___11 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___17 sk_error_queue;
	struct sk_buff___19 *sk_rx_skb_cache;
	struct sk_buff_head___17 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___19 *head;
		struct sk_buff___19 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___11 *sk_filter;
	union {
		struct socket_wq___11 *sk_wq;
		struct socket_wq___11 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___11 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___11 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___19 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___19 *sk_tx_skb_cache;
	struct sk_buff_head___17 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___74 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___11 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___62 *sk_peer_pid;
	const struct cred___10 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___11 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___11 sk_cgrp_data;
	struct mem_cgroup___29 *sk_memcg;
	void (*sk_state_change)(struct sock___12 *);
	void (*sk_data_ready)(struct sock___12 *);
	void (*sk_write_space)(struct sock___12 *);
	void (*sk_error_report)(struct sock___12 *);
	int (*sk_backlog_rcv)(struct sock___12 *, struct sk_buff___19 *);
	struct sk_buff___19 * (*sk_validate_xmit_skb)(struct sock___12 *, struct net_device___22 *, struct sk_buff___19 *);
	void (*sk_destruct)(struct sock___12 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage___6 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___69;

struct attribute_group___69 {
	const char *name;
	umode_t (*is_visible)(struct kobject___69 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___69 *, struct bin_attribute___69 *, int);
	struct attribute **attrs;
	struct bin_attribute___69 **bin_attrs;
};

struct bin_attribute___69 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___69 * (*f_mapping)();
	ssize_t (*read)(struct file___69 *, struct kobject___69 *, struct bin_attribute___69 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___69 *, struct kobject___69 *, struct bin_attribute___69 *, char *, loff_t, size_t);
	int (*mmap)(struct file___69 *, struct kobject___69 *, struct bin_attribute___69 *, struct vm_area_struct___74 *);
};

struct sysfs_ops___69 {
	ssize_t (*show)(struct kobject___69 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___69 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___69;

struct kset___69 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___69 kobj;
	const struct kset_uevent_ops___69 *uevent_ops;
};

struct kobj_type___69 {
	void (*release)(struct kobject___69 *);
	const struct sysfs_ops___69 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___69 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___69 *);
	const void * (*namespace)(struct kobject___69 *);
	void (*get_ownership)(struct kobject___69 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___69 {
	int (* const filter)(struct kset___69 *, struct kobject___69 *);
	const char * (* const name)(struct kset___69 *, struct kobject___69 *);
	int (* const uevent)(struct kset___69 *, struct kobject___69 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___66 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___66 *);
	int (*get)(char *, const struct kernel_param___66 *);
	void (*free)(void *);
};

struct kparam_array___66;

struct kernel_param___66 {
	const char *name;
	struct module___67 *mod;
	const struct kernel_param_ops___66 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___66 *arr;
	};
};

struct kparam_array___66 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___66 *ops;
	void *elem;
};

struct module_attribute___66 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___66 *, struct module_kobject___66 *, char *);
	ssize_t (*store)(struct module_attribute___66 *, struct module_kobject___66 *, const char *, size_t);
	void (*setup)(struct module___67 *, const char *);
	int (*test)(struct module___67 *);
	void (*free)(struct module___67 *);
};

struct fib_rules_ops___11;

struct fqdir___19;

struct fib_notifier_ops___11;

struct netns_ipv4___19 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___11 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___12 *fibnl;
	struct sock___12 **icmp_sk;
	struct sock___12 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___12 **tcp_sk;
	struct fqdir___19 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___11 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___11 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___11 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___11;

struct dst_ops___19 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___19 *);
	struct dst_entry___11 * (*check)(struct dst_entry___11 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___11 *);
	unsigned int (*mtu)(const struct dst_entry___11 *);
	u32 * (*cow_metrics)(struct dst_entry___11 *, long unsigned int);
	void (*destroy)(struct dst_entry___11 *);
	void (*ifdown)(struct dst_entry___11 *, struct net_device___22 *, int);
	struct dst_entry___11 * (*negative_advice)(struct dst_entry___11 *);
	void (*link_failure)(struct sk_buff___19 *);
	void (*update_pmtu)(struct dst_entry___11 *, struct sock___12 *, struct sk_buff___19 *, u32, bool);
	void (*redirect)(struct dst_entry___11 *, struct sock___12 *, struct sk_buff___19 *);
	int (*local_out)(struct net___20 *, struct sock___12 *, struct sk_buff___19 *);
	struct neighbour___11 * (*neigh_lookup)(const struct dst_entry___11 *, struct sk_buff___19 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___11 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___19 {
	struct dst_ops___19 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___19 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___11 *fib6_rules_ops;
	struct sock___12 **icmp_sk;
	struct sock___12 *ndisc_sk;
	struct sock___12 *tcp_sk;
	struct sock___12 *igmp_sk;
	struct sock___12 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___11 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___11 *notifier_ops;
	struct fib_notifier_ops___11 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___19 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___19 *fqdir;
};

struct netns_sctp___11 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___12 *ctl_sock;
	struct sock___12 *udp4_sock;
	struct sock___12 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___17;

struct netns_bpf___17 {
	struct bpf_prog_array___17 *run_array[2];
	struct bpf_prog___17 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___19 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___12 *nlsk;
	struct sock___12 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___19 xfrm4_dst_ops;
	struct dst_ops___19 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___20 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct idr netns_ids;
	struct ns_common___12 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___12 *rtnl;
	struct sock___12 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___22 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___19 ipv4;
	struct netns_ipv6___19 ipv6;
	struct netns_ieee802154_lowpan___19 ieee802154_lowpan;
	struct netns_sctp___11 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___17 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___17 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___19 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___12 *crypto_nlsk;
	struct sock___12 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___58 {
	struct ns_common___12 ns;
	struct user_namespace___11 *user_ns;
	struct ucounts___11 *ucounts;
	struct css_set___58 *root_cset;
};

struct socket_wq___11 {
	wait_queue_head_t wait;
	struct fasync_struct___69 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___11;

struct socket___11 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___69 *file;
	struct sock___12 *sk;
	const struct proto_ops___11 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___11 wq;
};

typedef int (*sk_read_actor_t___11)(read_descriptor_t *, struct sk_buff___19 *, unsigned int, size_t);

struct proto_ops___11 {
	int family;
	struct module___67 *owner;
	int (*release)(struct socket___11 *);
	int (*bind)(struct socket___11 *, struct sockaddr *, int);
	int (*connect)(struct socket___11 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___11 *, struct socket___11 *);
	int (*accept)(struct socket___11 *, struct socket___11 *, int, bool);
	int (*getname)(struct socket___11 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___69 *, struct socket___11 *, struct poll_table_struct___51 *);
	int (*ioctl)(struct socket___11 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___11 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___11 *, void *, bool, bool);
	int (*listen)(struct socket___11 *, int);
	int (*shutdown)(struct socket___11 *, int);
	int (*setsockopt)(struct socket___11 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___11 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___67 *, struct socket___11 *);
	int (*sendmsg)(struct socket___11 *, struct msghdr___11 *, size_t);
	int (*recvmsg)(struct socket___11 *, struct msghdr___11 *, size_t, int);
	int (*mmap)(struct file___69 *, struct socket___11 *, struct vm_area_struct___74 *);
	ssize_t (*sendpage)(struct socket___11 *, struct page___74 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___11 *, loff_t *, struct pipe_inode_info___29 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___12 *, int);
	int (*peek_len)(struct socket___11 *);
	int (*read_sock)(struct sock___12 *, read_descriptor_t *, sk_read_actor_t___11);
	int (*sendpage_locked)(struct sock___12 *, struct page___74 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___12 *, struct msghdr___11 *, size_t);
	int (*set_rcvlowat)(struct sock___12 *, int);
};

struct sk_buff___19 {
	union {
		struct {
			struct sk_buff___19 *next;
			struct sk_buff___19 *prev;
			union {
				struct net_device___22 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___12 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___19 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___62 {
	int (*prepare)(struct device___62 *);
	void (*complete)(struct device___62 *);
	int (*suspend)(struct device___62 *);
	int (*resume)(struct device___62 *);
	int (*freeze)(struct device___62 *);
	int (*thaw)(struct device___62 *);
	int (*poweroff)(struct device___62 *);
	int (*restore)(struct device___62 *);
	int (*suspend_late)(struct device___62 *);
	int (*resume_early)(struct device___62 *);
	int (*freeze_late)(struct device___62 *);
	int (*thaw_early)(struct device___62 *);
	int (*poweroff_late)(struct device___62 *);
	int (*restore_early)(struct device___62 *);
	int (*suspend_noirq)(struct device___62 *);
	int (*resume_noirq)(struct device___62 *);
	int (*freeze_noirq)(struct device___62 *);
	int (*thaw_noirq)(struct device___62 *);
	int (*poweroff_noirq)(struct device___62 *);
	int (*restore_noirq)(struct device___62 *);
	int (*runtime_suspend)(struct device___62 *);
	int (*runtime_resume)(struct device___62 *);
	int (*runtime_idle)(struct device___62 *);
};

struct wakeup_source___62 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___62 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___62 {
	struct dev_pm_ops___62 ops;
	int (*start)(struct device___62 *);
	void (*detach)(struct device___62 *, bool);
	int (*activate)(struct device___62 *);
	void (*sync)(struct device___62 *);
	void (*dismiss)(struct device___62 *);
};

struct bus_type___62 {
	const char *name;
	const char *dev_name;
	struct device___62 *dev_root;
	const struct attribute_group___69 **bus_groups;
	const struct attribute_group___69 **dev_groups;
	const struct attribute_group___69 **drv_groups;
	int (*match)(struct device___62 *, struct device_driver___62 *);
	int (*uevent)(struct device___62 *, struct kobj_uevent_env *);
	int (*probe)(struct device___62 *);
	void (*sync_state)(struct device___62 *);
	void (*remove)(struct device___62 *);
	void (*shutdown)(struct device___62 *);
	int (*online)(struct device___62 *);
	int (*offline)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	int (*num_vf)(struct device___62 *);
	int (*dma_configure)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___62 {
	const char *name;
	struct bus_type___62 *bus;
	struct module___67 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___62 *);
	void (*sync_state)(struct device___62 *);
	int (*remove)(struct device___62 *);
	void (*shutdown)(struct device___62 *);
	int (*suspend)(struct device___62 *, pm_message_t);
	int (*resume)(struct device___62 *);
	const struct attribute_group___69 **groups;
	const struct attribute_group___69 **dev_groups;
	const struct dev_pm_ops___62 *pm;
	void (*coredump)(struct device___62 *);
	struct driver_private *p;
};

struct device_type___62 {
	const char *name;
	const struct attribute_group___69 **groups;
	int (*uevent)(struct device___62 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___62 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___62 *);
	const struct dev_pm_ops___62 *pm;
};

struct class___62 {
	const char *name;
	struct module___67 *owner;
	const struct attribute_group___69 **class_groups;
	const struct attribute_group___69 **dev_groups;
	struct kobject___69 *dev_kobj;
	int (*dev_uevent)(struct device___62 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___62 *, umode_t *);
	void (*class_release)(struct class___62 *);
	void (*dev_release)(struct device___62 *);
	int (*shutdown_pre)(struct device___62 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___62 *);
	void (*get_ownership)(struct device___62 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___62 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___29;

struct pipe_buffer___29 {
	struct page___74 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___29 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___29 {
	int (*confirm)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
	void (*release)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
	bool (*try_steal)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
	bool (*get)(struct pipe_inode_info___29 *, struct pipe_buffer___29 *);
};

typedef rx_handler_result_t rx_handler_func_t___17(struct sk_buff___19 **);

struct bpf_xdp_entity___17 {
	struct bpf_prog___17 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___17;

struct net_device_ops___17;

struct l3mdev_ops___11;

struct xfrmdev_ops___17;

struct header_ops___17;

struct netdev_rx_queue___17;

struct mini_Qdisc___17;

struct netdev_queue___17;

struct Qdisc___17;

struct rtnl_link_ops___17;

struct dcbnl_rtnl_ops___17;

struct net_device___22 {
	char name[16];
	struct netdev_name_node___17 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___17 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___11 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___17 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___17 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___69 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___17 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___17 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___17 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___17 *miniq_ingress;
	struct netdev_queue___17 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___17 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___17 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___17 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___17 = 0,
		NETREG_REGISTERED___17 = 1,
		NETREG_UNREGISTERING___17 = 2,
		NETREG_UNREGISTERED___17 = 3,
		NETREG_RELEASED___17 = 4,
		NETREG_DUMMY___17 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___17 = 0,
		RTNL_LINK_INITIALIZING___17 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___22 *);
	struct netpoll_info *npinfo;
	possible_net_t___17 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___62 dev;
	const struct attribute_group___69 *sysfs_groups[4];
	const struct attribute_group___69 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___17 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___17 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___17 xdp_state[3];
	long: 64;
};

struct inet_frags___19;

struct fqdir___19 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___19 *f;
	struct net___20 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___19;

struct inet_frags___19 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___19 *, const void *);
	void (*destructor)(struct inet_frag_queue___19 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___19 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___19 *fragments_tail;
	struct sk_buff___19 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___19 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___11;

struct fib_lookup_arg___11;

struct fib_rules_ops___11 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___11 *, struct flowi *, int, struct fib_lookup_arg___11 *);
	bool (*suppress)(struct fib_rule___11 *, int, struct fib_lookup_arg___11 *);
	int (*match)(struct fib_rule___11 *, struct flowi *, int);
	int (*configure)(struct fib_rule___11 *, struct sk_buff___19 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___11 *);
	int (*compare)(struct fib_rule___11 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___11 *, struct sk_buff___19 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___11 *);
	void (*flush_cache)(struct fib_rules_ops___11 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___67 *owner;
	struct net___20 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___11 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___20 *);
	int (*fib_dump)(struct net___20 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___67 *owner;
	struct callback_head rcu;
};

struct dst_entry___11 {
	struct net_device___22 *dev;
	struct dst_ops___19 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___19 *);
	int (*output)(struct net___20 *, struct sock___12 *, struct sk_buff___19 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___11;

struct neigh_parms___11;

struct neigh_ops___11;

struct neighbour___11 {
	struct neighbour___11 *next;
	struct neigh_table___11 *tbl;
	struct neigh_parms___11 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___17 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___11 *, struct sk_buff___19 *);
	const struct neigh_ops___11 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___22 *dev;
	u8 primary_key[0];
};

struct xfrm_sec_ctx {
	__u8 ctx_doi;
	__u8 ctx_alg;
	__u16 ctx_len;
	__u32 ctx_sid;
	char ctx_str[0];
};

struct xfrm_user_sec_ctx {
	__u16 len;
	__u16 exttype;
	__u8 ctx_alg;
	__u8 ctx_doi;
	__u16 ctx_len;
};

enum {
	BPF_F_BPRM_SECUREEXEC = 1,
};

struct bpf_prog_array_item___17 {
	struct bpf_prog___17 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___17 {
	struct callback_head rcu;
	struct bpf_prog_array_item___17 items[0];
};

struct bpf_prog_aux___18;

struct bpf_prog___17 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___18 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___67 {
	void * (*start)(struct seq_file___67 *, loff_t *);
	void (*stop)(struct seq_file___67 *, void *);
	void * (*next)(struct seq_file___67 *, void *, loff_t *);
	int (*show)(struct seq_file___67 *, void *);
};

struct dcbnl_rtnl_ops___17 {
	int (*ieee_getets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___22 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___22 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___22 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___22 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___22 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___22 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___22 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___22 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___22 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___22 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___22 *);
	u8 (*setstate)(struct net_device___22 *, u8);
	void (*getpermhwaddr)(struct net_device___22 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___22 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___22 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___22 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___22 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___22 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___22 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___22 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___22 *, int, u8 *);
	void (*setpfccfg)(struct net_device___22 *, int, u8);
	void (*getpfccfg)(struct net_device___22 *, int, u8 *);
	u8 (*setall)(struct net_device___22 *);
	u8 (*getcap)(struct net_device___22 *, int, u8 *);
	int (*getnumtcs)(struct net_device___22 *, int, u8 *);
	int (*setnumtcs)(struct net_device___22 *, int, u8);
	u8 (*getpfcstate)(struct net_device___22 *);
	void (*setpfcstate)(struct net_device___22 *, u8);
	void (*getbcncfg)(struct net_device___22 *, int, u32 *);
	void (*setbcncfg)(struct net_device___22 *, int, u32);
	void (*getbcnrp)(struct net_device___22 *, int, u8 *);
	void (*setbcnrp)(struct net_device___22 *, int, u8);
	int (*setapp)(struct net_device___22 *, u8, u16, u8);
	int (*getapp)(struct net_device___22 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___22 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___22 *, int, u8);
	u8 (*getdcbx)(struct net_device___22 *);
	u8 (*setdcbx)(struct net_device___22 *, u8);
	int (*peer_getappinfo)(struct net_device___22 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___22 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___22 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___22 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___22 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___22 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___18;

typedef int (*bpf_iter_init_seq_priv_t___18)(void *, struct bpf_iter_aux_info___18 *);

struct bpf_map___18;

struct bpf_iter_aux_info___18 {
	struct bpf_map___18 *map;
};

struct bpf_iter_seq_info___18 {
	const struct seq_operations___67 *seq_ops;
	bpf_iter_init_seq_priv_t___18 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_local_storage_map___6;

struct bpf_verifier_env___5;

struct bpf_func_state___5;

struct bpf_map_ops___18 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___18 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___18 *, struct file___69 *);
	void (*map_free)(struct bpf_map___18 *);
	int (*map_get_next_key)(struct bpf_map___18 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___18 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___18 *, void *);
	int (*map_lookup_batch)(struct bpf_map___18 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___18 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___18 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___18 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___18 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___18 *, void *);
	int (*map_update_elem)(struct bpf_map___18 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___18 *, void *);
	int (*map_push_elem)(struct bpf_map___18 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___18 *, void *);
	int (*map_peek_elem)(struct bpf_map___18 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___18 *, struct file___69 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___18 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___18 *, void *, struct seq_file___67 *);
	int (*map_check_btf)(const struct bpf_map___18 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___18 *, struct bpf_prog_aux___18 *);
	void (*map_poke_untrack)(struct bpf_map___18 *, struct bpf_prog_aux___18 *);
	void (*map_poke_run)(struct bpf_map___18 *, u32, struct bpf_prog___17 *, struct bpf_prog___17 *);
	int (*map_direct_value_addr)(const struct bpf_map___18 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___18 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___18 *, struct vm_area_struct___74 *);
	__poll_t (*map_poll)(struct bpf_map___18 *, struct file___69 *, struct poll_table_struct___51 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___6 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___6 *, void *, u32);
	struct bpf_local_storage___6 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___18 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___18 *, const struct bpf_map___18 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env___5 *, struct bpf_func_state___5 *, struct bpf_func_state___5 *);
	int (*map_for_each_callback)(struct bpf_map___18 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___18 *iter_seq_info;
};

struct bpf_map___18 {
	const struct bpf_map_ops___18 *ops;
	struct bpf_map___18 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___29 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___18;

struct bpf_jit_poke_descriptor___18;

struct bpf_prog_ops___17;

struct btf_mod_pair___18;

struct bpf_prog_offload___17;

struct bpf_prog_aux___18 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___17 *dst_prog;
	struct bpf_trampoline___18 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___17 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___18 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___17 *ops;
	struct bpf_map___18 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___18 *used_btfs;
	struct bpf_prog___17 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___18 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___17 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_local_storage_map___6 {
	struct bpf_map___18 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct btf_mod_pair___18 {
	struct btf *btf;
	struct module___67 *module;
};

struct bpf_verifier_ops___7;

struct bpf_verifier_state___5;

struct bpf_verifier_state_list___5;

struct bpf_verifier_env___5 {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___17 *prog;
	const struct bpf_verifier_ops___7 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	bool test_state_freq;
	struct bpf_verifier_state___5 *cur_state;
	struct bpf_verifier_state_list___5 **explored_states;
	struct bpf_verifier_state_list___5 *free_list;
	struct bpf_map___18 *used_maps[64];
	struct btf_mod_pair___18 used_btfs[64];
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 id_gen;
	bool explore_alu_limits;
	bool allow_ptr_leaks;
	bool allow_uninit_stack;
	bool allow_ptr_to_map_access;
	bool bpf_capable;
	bool bypass_spec_v1;
	bool bypass_spec_v4;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	struct bpf_id_pair idmap_scratch[75];
	struct {
		int *insn_state;
		int *insn_stack;
		int cur_stack;
	} cfg;
	u32 pass_cnt;
	u32 subprog_cnt;
	u32 prev_insn_processed;
	u32 insn_processed;
	u32 prev_jmps_processed;
	u32 jmps_processed;
	u64 verification_time;
	u32 max_states_per_insn;
	u32 total_states;
	u32 peak_states;
	u32 longest_mark_read_walk;
	bpfptr_t fd_array;
};

struct bpf_reg_state___5 {
	enum bpf_reg_type type;
	s32 off;
	union {
		int range;
		struct {
			struct bpf_map___18 *map_ptr;
			u32 map_uid;
		};
		struct {
			struct btf *btf;
			u32 btf_id;
		};
		u32 mem_size;
		struct {
			long unsigned int raw1;
			long unsigned int raw2;
		} raw;
		u32 subprogno;
	};
	u32 id;
	u32 ref_obj_id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	s32 s32_min_value;
	s32 s32_max_value;
	u32 u32_min_value;
	u32 u32_max_value;
	struct bpf_reg_state___5 *parent;
	u32 frameno;
	s32 subreg_def;
	enum bpf_reg_liveness live;
	bool precise;
};

struct bpf_stack_state___5;

struct bpf_func_state___5 {
	struct bpf_reg_state___5 regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	u32 async_entry_cnt;
	bool in_callback_fn;
	bool in_async_callback_fn;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state___5 *stack;
};

struct bpf_offloaded_map___17;

struct bpf_map_dev_ops___17 {
	int (*map_get_next_key)(struct bpf_offloaded_map___17 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___17 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___17 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___17 *, void *);
};

struct bpf_offloaded_map___17 {
	struct bpf_map___18 map;
	struct net_device___22 *netdev;
	const struct bpf_map_dev_ops___17 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_func_proto___11 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___17 *);
};

struct bpf_prog_ops___17 {
	int (*test_run)(struct bpf_prog___17 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___7 {
	const struct bpf_func_proto___11 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___17 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___17 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___17 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___17 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___17 {
	struct bpf_prog___17 *prog;
	struct net_device___22 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___18 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___17 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___67 *mod;
};

struct bpf_jit_poke_descriptor___18 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___18 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct cftype___58;

struct cgroup_subsys___58 {
	struct cgroup_subsys_state___58 * (*css_alloc)(struct cgroup_subsys_state___58 *);
	int (*css_online)(struct cgroup_subsys_state___58 *);
	void (*css_offline)(struct cgroup_subsys_state___58 *);
	void (*css_released)(struct cgroup_subsys_state___58 *);
	void (*css_free)(struct cgroup_subsys_state___58 *);
	void (*css_reset)(struct cgroup_subsys_state___58 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___58 *, int);
	int (*css_extra_stat_show)(struct seq_file___67 *, struct cgroup_subsys_state___58 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___76 *, struct css_set___58 *);
	void (*cancel_fork)(struct task_struct___76 *, struct css_set___58 *);
	void (*fork)(struct task_struct___76 *);
	void (*exit)(struct task_struct___76 *);
	void (*release)(struct task_struct___76 *);
	void (*bind)(struct cgroup_subsys_state___58 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___58 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___58 *dfl_cftypes;
	struct cftype___58 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___58 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___58 *updated_children;
	struct cgroup___58 *updated_next;
};

struct cgroup_root___58 {
	struct kernfs_root___69 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___58 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___58 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___58 *ss;
	struct list_head node;
	struct kernfs_ops___69 *kf_ops;
	int (*open)(struct kernfs_open_file___69 *);
	void (*release)(struct kernfs_open_file___69 *);
	u64 (*read_u64)(struct cgroup_subsys_state___58 *, struct cftype___58 *);
	s64 (*read_s64)(struct cgroup_subsys_state___58 *, struct cftype___58 *);
	int (*seq_show)(struct seq_file___67 *, void *);
	void * (*seq_start)(struct seq_file___67 *, loff_t *);
	void * (*seq_next)(struct seq_file___67 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___67 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___58 *, struct cftype___58 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___58 *, struct cftype___58 *, s64);
	ssize_t (*write)(struct kernfs_open_file___69 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___69 *, struct poll_table_struct___51 *);
};

struct xdp_rxq_info___17 {
	struct net_device___22 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___17 {
	struct net_device___22 *dev;
};

struct xdp_buff___17 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___17 *rxq;
	struct xdp_txq_info___17 *txq;
	u32 frame_sz;
};

struct xdp_frame___17 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___22 *dev_rx;
};

struct netlink_callback___17 {
	struct sk_buff___19 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___19 *, struct netlink_callback___17 *);
	int (*done)(struct netlink_callback___17 *);
	void *data;
	struct module___67 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___17 {
	int (*create)(struct sk_buff___19 *, struct net_device___22 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___19 *, unsigned char *);
	int (*cache)(const struct neighbour___11 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___22 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___19 *);
};

struct netdev_queue___17 {
	struct net_device___22 *dev;
	struct Qdisc___17 *qdisc;
	struct Qdisc___17 *qdisc_sleeping;
	struct kobject___69 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___22 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___17 {
	struct sk_buff___19 *head;
	struct sk_buff___19 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___17;

struct Qdisc___17 {
	int (*enqueue)(struct sk_buff___19 *, struct Qdisc___17 *, struct sk_buff___19 **);
	struct sk_buff___19 * (*dequeue)(struct Qdisc___17 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___17 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___17 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___17 gso_skb;
	struct qdisc_skb_head___17 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___17 *next_sched;
	struct sk_buff_head___17 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___17 {
	struct xdp_rxq_info___17 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___69 kobj;
	struct net_device___22 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___17 {
	enum net_device_path_type type;
	const struct net_device___22 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___17 = 0,
				DEV_PATH_BR_VLAN_TAG___17 = 1,
				DEV_PATH_BR_VLAN_UNTAG___17 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___17 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___17 {
	const struct net_device___22 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___17 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___17 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___17 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___17 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___19 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___17 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___22 *dev;
	const char *name;
};

struct net_device_ops___17 {
	int (*ndo_init)(struct net_device___22 *);
	void (*ndo_uninit)(struct net_device___22 *);
	int (*ndo_open)(struct net_device___22 *);
	int (*ndo_stop)(struct net_device___22 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___19 *, struct net_device___22 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___19 *, struct net_device___22 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___22 *, struct sk_buff___19 *, struct net_device___22 *);
	void (*ndo_change_rx_flags)(struct net_device___22 *, int);
	void (*ndo_set_rx_mode)(struct net_device___22 *);
	int (*ndo_set_mac_address)(struct net_device___22 *, void *);
	int (*ndo_validate_addr)(struct net_device___22 *);
	int (*ndo_do_ioctl)(struct net_device___22 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___22 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___22 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___22 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___22 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___22 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___22 *, int);
	int (*ndo_neigh_setup)(struct net_device___22 *, struct neigh_parms___11 *);
	void (*ndo_tx_timeout)(struct net_device___22 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___22 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___22 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___22 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___22 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___22 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___22 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___22 *);
	int (*ndo_netpoll_setup)(struct net_device___22 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___22 *);
	int (*ndo_set_vf_mac)(struct net_device___22 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___22 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___22 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___22 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___22 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___22 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___22 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___22 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___22 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___22 *, int, struct sk_buff___19 *);
	int (*ndo_get_vf_guid)(struct net_device___22 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___22 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___22 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___22 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___22 *);
	int (*ndo_fcoe_disable)(struct net_device___22 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___22 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___22 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___22 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___22 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___22 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___22 *, const struct sk_buff___19 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___22 *, struct net_device___22 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___22 *, struct net_device___22 *);
	struct net_device___22 * (*ndo_get_xmit_slave)(struct net_device___22 *, struct sk_buff___19 *, bool);
	struct net_device___22 * (*ndo_sk_get_lower_dev)(struct net_device___22 *, struct sock___12 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___22 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___22 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___22 *, struct neighbour___11 *);
	void (*ndo_neigh_destroy)(struct net_device___22 *, struct neighbour___11 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___19 *, struct netlink_callback___17 *, struct net_device___22 *, struct net_device___22 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___19 *, struct nlattr **, struct net_device___22 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___22 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___19 *, u32, u32, struct net_device___22 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___22 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___22 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___22 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___22 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___22 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___22 *, struct net_device___22 *);
	void (*ndo_dfwd_del_station)(struct net_device___22 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___22 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___22 *);
	int (*ndo_change_proto_down)(struct net_device___22 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___22 *, struct sk_buff___19 *);
	void (*ndo_set_rx_headroom)(struct net_device___22 *, int);
	int (*ndo_bpf)(struct net_device___22 *, struct netdev_bpf___17 *);
	int (*ndo_xdp_xmit)(struct net_device___22 *, int, struct xdp_frame___17 **, u32);
	struct net_device___22 * (*ndo_xdp_get_xmit_slave)(struct net_device___22 *, struct xdp_buff___17 *);
	int (*ndo_xsk_wakeup)(struct net_device___22 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___22 *);
	int (*ndo_tunnel_ctl)(struct net_device___22 *, struct ip_tunnel_parm *, int);
	struct net_device___22 * (*ndo_get_peer_dev)(struct net_device___22 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___17 *, struct net_device_path___17 *);
};

struct neigh_parms___11 {
	possible_net_t___17 net;
	struct net_device___22 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___11 *);
	struct neigh_table___11 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___11 {
	u32 (*l3mdev_fib_table)(const struct net_device___22 *);
	struct sk_buff___19 * (*l3mdev_l3_rcv)(struct net_device___22 *, struct sk_buff___19 *, u16);
	struct sk_buff___19 * (*l3mdev_l3_out)(struct net_device___22 *, struct sock___12 *, struct sk_buff___19 *, u16);
	struct dst_entry___11 * (*l3mdev_link_scope_lookup)(const struct net_device___22 *, struct flowi6 *);
};

struct tcf_proto___17;

struct tcf_block___17;

struct mini_Qdisc___17 {
	struct tcf_proto___17 *filter_list;
	struct tcf_block___17 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___17 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___22 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___22 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___20 *, struct net_device___22 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___22 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___22 *, struct list_head *);
	size_t (*get_size)(const struct net_device___22 *);
	int (*fill_info)(struct sk_buff___19 *, const struct net_device___22 *);
	size_t (*get_xstats_size)(const struct net_device___22 *);
	int (*fill_xstats)(struct sk_buff___19 *, const struct net_device___22 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___22 *, struct net_device___22 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___22 *, const struct net_device___22 *);
	int (*fill_slave_info)(struct sk_buff___19 *, const struct net_device___22 *, const struct net_device___22 *);
	struct net___20 * (*get_link_net)(const struct net_device___22 *);
	size_t (*get_linkxstats_size)(const struct net_device___22 *, int);
	int (*fill_linkxstats)(struct sk_buff___19 *, const struct net_device___22 *, int *, int);
};

struct gnet_dump___17 {
	spinlock_t *lock;
	struct sk_buff___19 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___17;

struct Qdisc_ops___17 {
	struct Qdisc_ops___17 *next;
	const struct Qdisc_class_ops___17 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___19 *, struct Qdisc___17 *, struct sk_buff___19 **);
	struct sk_buff___19 * (*dequeue)(struct Qdisc___17 *);
	struct sk_buff___19 * (*peek)(struct Qdisc___17 *);
	int (*init)(struct Qdisc___17 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___17 *);
	void (*destroy)(struct Qdisc___17 *);
	int (*change)(struct Qdisc___17 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___17 *);
	int (*change_tx_queue_len)(struct Qdisc___17 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___17 *, unsigned int);
	int (*dump)(struct Qdisc___17 *, struct sk_buff___19 *);
	int (*dump_stats)(struct Qdisc___17 *, struct gnet_dump___17 *);
	void (*ingress_block_set)(struct Qdisc___17 *, u32);
	void (*egress_block_set)(struct Qdisc___17 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___17 *);
	u32 (*egress_block_get)(struct Qdisc___17 *);
	struct module___67 *owner;
};

struct Qdisc_class_ops___17 {
	unsigned int flags;
	struct netdev_queue___17 * (*select_queue)(struct Qdisc___17 *, struct tcmsg *);
	int (*graft)(struct Qdisc___17 *, long unsigned int, struct Qdisc___17 *, struct Qdisc___17 **, struct netlink_ext_ack *);
	struct Qdisc___17 * (*leaf)(struct Qdisc___17 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___17 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___17 *, u32);
	int (*change)(struct Qdisc___17 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___17 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___17 *, struct qdisc_walker *);
	struct tcf_block___17 * (*tcf_block)(struct Qdisc___17 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___17 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___17 *, long unsigned int);
	int (*dump)(struct Qdisc___17 *, long unsigned int, struct sk_buff___19 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___17 *, long unsigned int, struct gnet_dump___17 *);
};

struct tcf_chain___17;

struct tcf_block___17 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___20 *net;
	struct Qdisc___17 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___17 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___17;

struct tcf_proto_ops___17;

struct tcf_proto___17 {
	struct tcf_proto___17 *next;
	void *root;
	int (*classify)(struct sk_buff___19 *, const struct tcf_proto___17 *, struct tcf_result___17 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___17 *ops;
	struct tcf_chain___17 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___17 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___17 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___17 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___19 *, const struct tcf_proto___17 *, struct tcf_result___17 *);
	int (*init)(struct tcf_proto___17 *);
	void (*destroy)(struct tcf_proto___17 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___17 *, u32);
	void (*put)(struct tcf_proto___17 *, void *);
	int (*change)(struct net___20 *, struct sk_buff___19 *, struct tcf_proto___17 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___17 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___17 *);
	void (*walk)(struct tcf_proto___17 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___17 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___17 *, void *);
	void (*hw_del)(struct tcf_proto___17 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___20 *, struct tcf_chain___17 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___20 *, struct tcf_proto___17 *, void *, struct sk_buff___19 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___20 *, struct tcf_proto___17 *, void *, struct sk_buff___19 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___19 *, struct net___20 *, void *);
	struct module___67 *owner;
	int flags;
};

struct tcf_chain___17 {
	struct mutex filter_chain_lock;
	struct tcf_proto___17 *filter_chain;
	struct list_head list;
	struct tcf_block___17 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___17 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___11 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___17 *prog;
};

struct linux_binprm___15 {
	struct vm_area_struct___74 *vma;
	long unsigned int vma_pages;
	struct mm_struct___75 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___69 *executable;
	struct file___69 *interpreter;
	struct file___69 *file;
	struct cred___10 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___14 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___69 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct watch_notification;

struct request_sock___5;

struct bpf_stack_state___5 {
	struct bpf_reg_state___5 spilled_ptr;
	u8 slot_type[8];
};

struct bpf_verifier_state___5 {
	struct bpf_func_state___5 *frame[8];
	struct bpf_verifier_state___5 *parent;
	u32 branches;
	u32 insn_idx;
	u32 curframe;
	u32 active_spin_lock;
	bool speculative;
	u32 first_insn_idx;
	u32 last_insn_idx;
	struct bpf_idx_pair *jmp_history;
	u32 jmp_history_cnt;
};

struct bpf_verifier_state_list___5 {
	struct bpf_verifier_state___5 state;
	struct bpf_verifier_state_list___5 *next;
	int miss_cnt;
	int hit_cnt;
};

struct block_device_operations___32;

struct gendisk___32 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___33 *part0;
	const struct block_device_operations___32 *fops;
	struct request_queue___33 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___31 *bdi;
	struct kobject___69 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___69 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___32 {
	struct bio___32 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___40 *bip_vec;
	struct bio_vec___40 bip_inline_vecs[0];
};

struct blkcg___31;

struct blkg_policy_data___31;

struct blkcg_gq___31 {
	struct request_queue___33 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___31 *blkcg;
	struct blkcg_gq___31 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___31 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___32 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___32(struct request___32 *);

typedef void integrity_complete_fn___32(struct request___32 *, unsigned int);

struct blk_integrity_profile___32 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___32 *prepare_fn;
	integrity_complete_fn___32 *complete_fn;
	const char *name;
};

struct block_device_operations___32 {
	blk_qc_t (*submit_bio)(struct bio___32 *);
	int (*open)(struct block_device___33 *, fmode_t);
	void (*release)(struct gendisk___32 *, fmode_t);
	int (*rw_page)(struct block_device___33 *, sector_t, struct page___74 *, unsigned int);
	int (*ioctl)(struct block_device___33 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___33 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___32 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___32 *);
	int (*getgeo)(struct block_device___33 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___33 *, bool);
	void (*swap_slot_free_notify)(struct block_device___33 *, long unsigned int);
	int (*report_zones)(struct gendisk___32 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___32 *, umode_t *);
	struct module___67 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___32 *, sector_t *);
};

typedef void rq_end_io_fn___32(struct request___32 *, blk_status_t);

struct request___32 {
	struct request_queue___33 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___31 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___32 *bio;
	struct bio___32 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___40 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___32 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___32 *saved_end_io;
		} flush;
	};
	struct gendisk___32 *rq_disk;
	struct block_device___33 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___32 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___31 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___33 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___69 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___70 *debugfs_dir;
	struct dentry___70 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___32;

struct elevator_mq_ops___32 {
	int (*init_sched)(struct request_queue___33 *, struct elevator_type___32 *);
	void (*exit_sched)(struct elevator_queue___32 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___31 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___31 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___31 *);
	bool (*allow_merge)(struct request_queue___33 *, struct request___32 *, struct bio___32 *);
	bool (*bio_merge)(struct request_queue___33 *, struct bio___32 *, unsigned int);
	int (*request_merge)(struct request_queue___33 *, struct request___32 **, struct bio___32 *);
	void (*request_merged)(struct request_queue___33 *, struct request___32 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___33 *, struct request___32 *, struct request___32 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___32 *);
	void (*finish_request)(struct request___32 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___31 *, struct list_head *, bool);
	struct request___32 * (*dispatch_request)(struct blk_mq_hw_ctx___31 *);
	bool (*has_work)(struct blk_mq_hw_ctx___31 *);
	void (*completed_request)(struct request___32 *, u64);
	void (*requeue_request)(struct request___32 *);
	struct request___32 * (*former_request)(struct request_queue___33 *, struct request___32 *);
	struct request___32 * (*next_request)(struct request_queue___33 *, struct request___32 *);
	void (*init_icq)(struct io_cq___32 *);
	void (*exit_icq)(struct io_cq___32 *);
};

struct elv_fs_entry___32;

struct elevator_type___32 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___32 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___32 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___67 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___32 {
	struct elevator_type___32 *type;
	void *elevator_data;
	struct kobject___69 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___32 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___32 *, char *);
	ssize_t (*store)(struct elevator_queue___32 *, const char *, size_t);
};

struct blk_mq_queue_data___31;

struct blk_mq_ops___31 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___31 *, const struct blk_mq_queue_data___31 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___31 *);
	int (*get_budget)(struct request_queue___33 *);
	void (*put_budget)(struct request_queue___33 *, int);
	void (*set_rq_budget_token)(struct request___32 *, int);
	int (*get_rq_budget_token)(struct request___32 *);
	enum blk_eh_timer_return (*timeout)(struct request___32 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___31 *);
	void (*complete)(struct request___32 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___31 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___31 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___31 *, struct request___32 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___31 *, struct request___32 *, unsigned int);
	void (*initialize_rq_fn)(struct request___32 *);
	void (*cleanup_rq)(struct request___32 *);
	bool (*busy)(struct request_queue___33 *);
	int (*map_queues)(struct blk_mq_tag_set___31 *);
	void (*show_rq)(struct seq_file___67 *, struct request___32 *);
};

struct blk_mq_tag_set___31 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___31 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___31 {
	struct request___32 *rq;
	bool last;
};

struct blkcg_policy_data___31;

struct blkcg___31 {
	struct cgroup_subsys_state___58 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___31 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___31 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___31 {
	struct blkcg___31 *blkcg;
	int plid;
};

struct blkg_policy_data___31 {
	struct blkcg_gq___31 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___29 {
	struct mem_cgroup___29 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___29 {
	struct lruvec___30 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___29 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___29 *memcg;
};

struct obj_cgroup___29 {
	struct percpu_ref refcnt;
	struct mem_cgroup___29 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___11;

struct neigh_hash_table___11;

struct neigh_table___11 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___22 *, __u32 *);
	bool (*key_eq)(const struct neighbour___11 *, const void *);
	int (*constructor)(struct neighbour___11 *);
	int (*pconstructor)(struct pneigh_entry___11 *);
	void (*pdestructor)(struct pneigh_entry___11 *);
	void (*proxy_redo)(struct sk_buff___19 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___22 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___11 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___17 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___11 *nht;
	struct pneigh_entry___11 **phash_buckets;
};

struct neigh_ops___11 {
	int family;
	void (*solicit)(struct neighbour___11 *, struct sk_buff___19 *);
	void (*error_report)(struct neighbour___11 *, struct sk_buff___19 *);
	int (*output)(struct neighbour___11 *, struct sk_buff___19 *);
	int (*connected_output)(struct neighbour___11 *, struct sk_buff___19 *);
};

struct pneigh_entry___11 {
	struct pneigh_entry___11 *next;
	possible_net_t___17 net;
	struct net_device___22 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___11 {
	struct neighbour___11 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___11 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___11 *ctarget;
	struct net___20 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___11 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___11 *rule;
	u32 table;
	int flags;
};

struct proto___11 {
	void (*close)(struct sock___12 *, long int);
	int (*pre_connect)(struct sock___12 *, struct sockaddr *, int);
	int (*connect)(struct sock___12 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___12 *, int);
	struct sock___12 * (*accept)(struct sock___12 *, int, int *, bool);
	int (*ioctl)(struct sock___12 *, int, long unsigned int);
	int (*init)(struct sock___12 *);
	void (*destroy)(struct sock___12 *);
	void (*shutdown)(struct sock___12 *, int);
	int (*setsockopt)(struct sock___12 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___12 *, int, int, char *, int *);
	void (*keepalive)(struct sock___12 *, int);
	int (*compat_ioctl)(struct sock___12 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___12 *, struct msghdr___11 *, size_t);
	int (*recvmsg)(struct sock___12 *, struct msghdr___11 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___12 *, struct page___74 *, int, size_t, int);
	int (*bind)(struct sock___12 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___12 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___12 *, struct sk_buff___19 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___12 *);
	int (*hash)(struct sock___12 *);
	void (*unhash)(struct sock___12 *);
	void (*rehash)(struct sock___12 *);
	int (*get_port)(struct sock___12 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___12 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___12 *, int);
	bool (*sock_is_readable)(struct sock___12 *);
	void (*enter_memory_pressure)(struct sock___12 *);
	void (*leave_memory_pressure)(struct sock___12 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___67 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___12 *, int);
};

struct bpf_local_storage_data___6 {
	struct bpf_local_storage_map___6 *smap;
	u8 data[0];
};

typedef u64 (*btf_bpf_bprm_opts_set)(struct linux_binprm___15 *, u64);

typedef u64 (*btf_bpf_ima_inode_hash)(struct inode___70 *, void *, u32);

struct dentry___71;

struct super_block___71;

struct module___68;

struct file_system_type___70 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___71 * (*mount)(struct file_system_type___70 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___71 *);
	struct module___68 *owner;
	struct file_system_type___70 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___70;

struct kiocb___70;

struct iov_iter___41;

struct poll_table_struct___52;

struct vm_area_struct___75;

struct inode___71;

struct file_lock___70;

struct page___75;

struct pipe_inode_info___30;

struct seq_file___68;

struct file_operations___70 {
	struct module___68 *owner;
	loff_t (*llseek)(struct file___70 *, loff_t, int);
	ssize_t (*read)(struct file___70 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___70 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___70 *, struct iov_iter___41 *);
	ssize_t (*write_iter)(struct kiocb___70 *, struct iov_iter___41 *);
	int (*iopoll)(struct kiocb___70 *, bool);
	int (*iterate)(struct file___70 *, struct dir_context *);
	int (*iterate_shared)(struct file___70 *, struct dir_context *);
	__poll_t (*poll)(struct file___70 *, struct poll_table_struct___52 *);
	long int (*unlocked_ioctl)(struct file___70 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___70 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___70 *, struct vm_area_struct___75 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___71 *, struct file___70 *);
	int (*flush)(struct file___70 *, fl_owner_t);
	int (*release)(struct inode___71 *, struct file___70 *);
	int (*fsync)(struct file___70 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___70 *, int);
	int (*lock)(struct file___70 *, int, struct file_lock___70 *);
	ssize_t (*sendpage)(struct file___70 *, struct page___75 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___70 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___70 *, long unsigned int);
	int (*flock)(struct file___70 *, int, struct file_lock___70 *);
	ssize_t (*splice_write)(struct pipe_inode_info___30 *, struct file___70 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___70 *, loff_t *, struct pipe_inode_info___30 *, size_t, unsigned int);
	int (*setlease)(struct file___70 *, long int, struct file_lock___70 **, void **);
	long int (*fallocate)(struct file___70 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___68 *, struct file___70 *);
	ssize_t (*copy_file_range)(struct file___70 *, loff_t, struct file___70 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___70 *, loff_t, struct file___70 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___70 *, loff_t, loff_t, int);
};

struct vmacache___75 {
	u64 seqnum;
	struct vm_area_struct___75 *vmas[4];
};

struct page_frag___75 {
	struct page___75 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___44;

struct debug_info___44 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___44 *hbp_break[16];
	struct perf_event___44 *hbp_watch[16];
};

struct thread_struct___44 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___44 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___76;

struct pid___63;

struct cred___11;

struct nsproxy___68;

struct signal_struct___71;

struct css_set___59;

struct perf_event_context___44;

struct vm_struct___71;

struct task_struct___77 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___77 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___76 *mm;
	struct mm_struct___76 *active_mm;
	struct vmacache___75 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___77 *real_parent;
	struct task_struct___77 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___77 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___63 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___68 *nsproxy;
	struct signal_struct___71 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___77 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___32 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___59 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___44 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___30 *splice_pipe;
	struct page_frag___75 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___77 *oom_reaper_list;
	struct vm_struct___71 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___44 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___70;

struct kobj_type___70;

struct kernfs_node___70;

struct kobject___70 {
	const char *name;
	struct list_head entry;
	struct kobject___70 *parent;
	struct kset___70 *kset;
	struct kobj_type___70 *ktype;
	struct kernfs_node___70 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___67 {
	struct kobject___70 kobj;
	struct module___68 *mod;
	struct kobject___70 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___67 {
	struct module___68 *mod;
	struct latch_tree_node node;
};

struct module_layout___67 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___67 mtn;
};

struct module_attribute___67;

struct kernel_param___67;

struct trace_event_call___38;

struct module___68 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___67 mkobj;
	struct module_attribute___67 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___70 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___67 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___67 core_layout;
	struct module_layout___67 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___38 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___44 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___77 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___44)(struct perf_event___44 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___44;

struct fasync_struct___70;

struct pid_namespace___63;

struct bpf_prog___18;

struct perf_cgroup___44;

struct perf_event___44 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___44 *group_leader;
	struct pmu___44 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___44 hw;
	struct perf_event_context___44 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___44 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___77 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___70 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___44 *aux_event;
	void (*destroy)(struct perf_event___44 *);
	struct callback_head callback_head;
	struct pid_namespace___63 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___44 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___44 orig_overflow_handler;
	struct bpf_prog___18 *prog;
	u64 bpf_cookie;
	struct trace_event_call___38 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___44 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___70;

struct dentry___71 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___71 *d_parent;
	struct qstr d_name;
	struct inode___71 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___70 *d_op;
	struct super_block___71 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___70;

struct address_space___70 {
	struct inode___71 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___70 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___70;

struct inode___71 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___70 *i_op;
	struct super_block___71 *i_sb;
	struct address_space___70 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___70 *i_fop;
		void (*free_inode)(struct inode___71 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___70 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___30 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___70;

struct path___70;

struct dentry_operations___70 {
	int (*d_revalidate)(struct dentry___71 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___71 *, unsigned int);
	int (*d_hash)(const struct dentry___71 *, struct qstr *);
	int (*d_compare)(const struct dentry___71 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___71 *);
	int (*d_init)(struct dentry___71 *);
	void (*d_release)(struct dentry___71 *);
	void (*d_prune)(struct dentry___71 *);
	void (*d_iput)(struct dentry___71 *, struct inode___71 *);
	char * (*d_dname)(struct dentry___71 *, char *, int);
	struct vfsmount___70 * (*d_automount)(struct path___70 *);
	int (*d_manage)(const struct path___70 *, bool);
	struct dentry___71 * (*d_real)(struct dentry___71 *, const struct inode___71 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___70;

struct mem_dqinfo___70 {
	struct quota_format_type___70 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___70;

struct quota_info___70 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___71 *files[3];
	struct mem_dqinfo___70 info[3];
	const struct quota_format_ops___70 *ops[3];
};

struct rcuwait___71 {
	struct task_struct___77 *task;
};

struct percpu_rw_semaphore___71 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___71 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___70 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___71 rw_sem[3];
};

struct super_operations___70;

struct dquot_operations___70;

struct quotactl_ops___70;

struct user_namespace___12;

struct super_block___71 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___70 *s_type;
	const struct super_operations___70 *s_op;
	const struct dquot_operations___70 *dq_op;
	const struct quotactl_ops___70 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___71 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___70 s_dquot;
	struct sb_writers___70 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___70 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___70 {
	struct dentry___71 *mnt_root;
	struct super_block___71 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct path___70 {
	struct vfsmount___70 *mnt;
	struct dentry___71 *dentry;
};

struct upid___63 {
	int nr;
	struct pid_namespace___63 *ns;
};

struct proc_ns_operations___13;

struct ns_common___13 {
	atomic_long_t stashed;
	const struct proc_ns_operations___13 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___12;

struct pid_namespace___63 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___77 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___63 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___63 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___63 numbers[1];
};

struct user_namespace___12 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___12 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___13 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___12 *ucounts;
	long int ucount_max[16];
};

typedef struct page___75 *pgtable_t___75;

struct page_pool___27;

struct dev_pagemap___69;

struct page___75 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___70 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___75 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___75 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___76 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___69 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___12 {
	struct hlist_node node;
	struct user_namespace___12 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___69;

struct vm_area_struct___75 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___75 *vm_next;
	struct vm_area_struct___75 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___76 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___69 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___70 *vm_file;
	struct file___70 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___71 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___77 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___77 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___63 *pids[4];
	struct pid___63 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___76 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___75;

struct mm_struct___76 {
	struct {
		struct vm_area_struct___75 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___70 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___75 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___77 *owner;
		struct user_namespace___12 *user_ns;
		struct file___70 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___11 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key *session_keyring;
	struct key *process_keyring;
	struct key *thread_keyring;
	struct key *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct net___21;

struct cgroup_namespace___59;

struct nsproxy___68 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___63 *pid_ns_for_children;
	struct net___21 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___59 *cgroup_ns;
};

struct cgroup_subsys_state___59;

struct cgroup___59;

struct css_set___59 {
	struct cgroup_subsys_state___59 *subsys[14];
	refcount_t refcount;
	struct css_set___59 *dom_cset;
	struct cgroup___59 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___59 *mg_src_cgrp;
	struct cgroup___59 *mg_dst_cgrp;
	struct css_set___59 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___44 {
	struct pmu___44 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___77 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___44 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___30;

struct pipe_inode_info___30 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___75 *tmp_page;
	struct fasync_struct___70 *fasync_readers;
	struct fasync_struct___70 *fasync_writers;
	struct pipe_buffer___30 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___71 {
	struct vm_struct___71 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___75 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct device___63;

struct page_pool_params___27 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___63 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___27 {
	u32 count;
	struct page___75 *cache[128];
};

struct page_pool___27 {
	struct page_pool_params___27 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___75 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___27 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___69;

struct dev_pagemap___69 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___69 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___63 {
	rwlock_t lock;
	struct pid___63 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___70 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___70 f_path;
	struct inode___71 *f_inode;
	const struct file_operations___70 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___63 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___70 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___69;

struct vm_operations_struct___69 {
	void (*open)(struct vm_area_struct___75 *);
	void (*close)(struct vm_area_struct___75 *);
	int (*may_split)(struct vm_area_struct___75 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___75 *);
	int (*mprotect)(struct vm_area_struct___75 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___69 *);
	vm_fault_t (*huge_fault)(struct vm_fault___69 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___69 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___75 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___69 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___69 *);
	int (*access)(struct vm_area_struct___75 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___75 *);
	int (*set_policy)(struct vm_area_struct___75 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___75 *, long unsigned int);
	struct page___75 * (*find_special_page)(struct vm_area_struct___75 *, long unsigned int);
};

struct core_thread___75 {
	struct task_struct___77 *task;
	struct core_thread___75 *next;
};

struct core_state___75 {
	atomic_t nr_threads;
	struct core_thread___75 dumper;
	struct completion startup;
};

struct vm_fault___69 {
	const struct {
		struct vm_area_struct___75 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___75 *cow_page;
	struct page___75 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___75 prealloc_pte;
};

struct cgroup_subsys___59;

struct cgroup_subsys_state___59 {
	struct cgroup___59 *cgroup;
	struct cgroup_subsys___59 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___59 *parent;
};

struct cgroup_file___59 {
	struct kernfs_node___70 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___59 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___77 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___18;

struct cgroup_bpf___18 {
	struct bpf_prog_array___18 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___18 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___59;

struct cgroup_rstat_cpu___59;

struct cgroup___59 {
	struct cgroup_subsys_state___59 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___70 *kn;
	struct cgroup_file___59 procs_file;
	struct cgroup_file___59 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___59 *subsys[14];
	struct cgroup_root___59 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___59 *dom_cgrp;
	struct cgroup___59 *old_dom_cgrp;
	struct cgroup_rstat_cpu___59 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___59 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___28;

struct kiocb___70 {
	struct file___70 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___70 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___28 *ki_waitq;
	};
};

struct iattr___71 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___70 *ia_file;
};

struct dquot___70 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___71 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___70 {
	int qf_fmt_id;
	const struct quota_format_ops___70 *qf_ops;
	struct module___68 *qf_owner;
	struct quota_format_type___70 *qf_next;
};

struct quota_format_ops___70 {
	int (*check_quota_file)(struct super_block___71 *, int);
	int (*read_file_info)(struct super_block___71 *, int);
	int (*write_file_info)(struct super_block___71 *, int);
	int (*free_file_info)(struct super_block___71 *, int);
	int (*read_dqblk)(struct dquot___70 *);
	int (*commit_dqblk)(struct dquot___70 *);
	int (*release_dqblk)(struct dquot___70 *);
	int (*get_next_id)(struct super_block___71 *, struct kqid *);
};

struct dquot_operations___70 {
	int (*write_dquot)(struct dquot___70 *);
	struct dquot___70 * (*alloc_dquot)(struct super_block___71 *, int);
	void (*destroy_dquot)(struct dquot___70 *);
	int (*acquire_dquot)(struct dquot___70 *);
	int (*release_dquot)(struct dquot___70 *);
	int (*mark_dirty)(struct dquot___70 *);
	int (*write_info)(struct super_block___71 *, int);
	qsize_t * (*get_reserved_space)(struct inode___71 *);
	int (*get_projid)(struct inode___71 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___71 *, qsize_t *);
	int (*get_next_id)(struct super_block___71 *, struct kqid *);
};

struct quotactl_ops___70 {
	int (*quota_on)(struct super_block___71 *, int, int, const struct path___70 *);
	int (*quota_off)(struct super_block___71 *, int);
	int (*quota_enable)(struct super_block___71 *, unsigned int);
	int (*quota_disable)(struct super_block___71 *, unsigned int);
	int (*quota_sync)(struct super_block___71 *, int);
	int (*set_info)(struct super_block___71 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___71 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___71 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___71 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___71 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___71 *, unsigned int);
};

struct wait_page_queue___28 {
	struct page___75 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___28;

struct address_space_operations___70 {
	int (*writepage)(struct page___75 *, struct writeback_control___3 *);
	int (*readpage)(struct file___70 *, struct page___75 *);
	int (*writepages)(struct address_space___70 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___75 *);
	int (*readpages)(struct file___70 *, struct address_space___70 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___28 *);
	int (*write_begin)(struct file___70 *, struct address_space___70 *, loff_t, unsigned int, unsigned int, struct page___75 **, void **);
	int (*write_end)(struct file___70 *, struct address_space___70 *, loff_t, unsigned int, unsigned int, struct page___75 *, void *);
	sector_t (*bmap)(struct address_space___70 *, sector_t);
	void (*invalidatepage)(struct page___75 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___75 *, gfp_t);
	void (*freepage)(struct page___75 *);
	ssize_t (*direct_IO)(struct kiocb___70 *, struct iov_iter___41 *);
	int (*migratepage)(struct address_space___70 *, struct page___75 *, struct page___75 *, enum migrate_mode);
	bool (*isolate_page)(struct page___75 *, isolate_mode_t);
	void (*putback_page)(struct page___75 *);
	int (*launder_page)(struct page___75 *);
	int (*is_partially_uptodate)(struct page___75 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___75 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___70 *, struct page___75 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___70 *, sector_t *);
	void (*swap_deactivate)(struct file___70 *);
};

struct readahead_control___28 {
	struct file___70 *file;
	struct address_space___70 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___41;

struct iov_iter___41 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___41 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___30 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___70 {
	struct dentry___71 * (*lookup)(struct inode___71 *, struct dentry___71 *, unsigned int);
	const char * (*get_link)(struct dentry___71 *, struct inode___71 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___71 *, int);
	struct posix_acl * (*get_acl)(struct inode___71 *, int, bool);
	int (*readlink)(struct dentry___71 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___71 *, struct dentry___71 *, umode_t, bool);
	int (*link)(struct dentry___71 *, struct inode___71 *, struct dentry___71 *);
	int (*unlink)(struct inode___71 *, struct dentry___71 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___71 *, struct dentry___71 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___71 *, struct dentry___71 *, umode_t);
	int (*rmdir)(struct inode___71 *, struct dentry___71 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___71 *, struct dentry___71 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___71 *, struct dentry___71 *, struct inode___71 *, struct dentry___71 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___71 *, struct iattr___71 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___70 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___71 *, char *, size_t);
	int (*fiemap)(struct inode___71 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___71 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___71 *, struct dentry___71 *, struct file___70 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___71 *, struct dentry___71 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___71 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___71 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___71 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___70 {
	void (*fl_copy_lock)(struct file_lock___70 *, struct file_lock___70 *);
	void (*fl_release_private)(struct file_lock___70 *);
};

struct lock_manager_operations___70;

struct file_lock___70 {
	struct file_lock___70 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___70 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___70 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___70 *fl_ops;
	const struct lock_manager_operations___70 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___70 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___70 *);
	int (*lm_grant)(struct file_lock___70 *, int);
	bool (*lm_break)(struct file_lock___70 *);
	int (*lm_change)(struct file_lock___70 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___70 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___70 *);
};

struct fasync_struct___70 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___70 *fa_next;
	struct file___70 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___70 {
	struct inode___71 * (*alloc_inode)(struct super_block___71 *);
	void (*destroy_inode)(struct inode___71 *);
	void (*free_inode)(struct inode___71 *);
	void (*dirty_inode)(struct inode___71 *, int);
	int (*write_inode)(struct inode___71 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___71 *);
	void (*evict_inode)(struct inode___71 *);
	void (*put_super)(struct super_block___71 *);
	int (*sync_fs)(struct super_block___71 *, int);
	int (*freeze_super)(struct super_block___71 *);
	int (*freeze_fs)(struct super_block___71 *);
	int (*thaw_super)(struct super_block___71 *);
	int (*unfreeze_fs)(struct super_block___71 *);
	int (*statfs)(struct dentry___71 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___71 *, int *, char *);
	void (*umount_begin)(struct super_block___71 *);
	int (*show_options)(struct seq_file___68 *, struct dentry___71 *);
	int (*show_devname)(struct seq_file___68 *, struct dentry___71 *);
	int (*show_path)(struct seq_file___68 *, struct dentry___71 *);
	int (*show_stats)(struct seq_file___68 *, struct dentry___71 *);
	ssize_t (*quota_read)(struct super_block___71 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___71 *, int, const char *, size_t, loff_t);
	struct dquot___70 ** (*get_dquots)(struct inode___71 *);
	long int (*nr_cached_objects)(struct super_block___71 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___71 *, struct shrink_control___29 *);
	struct file___70 * (*real_loop)(struct file___70 *);
};

typedef void (*poll_queue_proc___52)(struct file___70 *, wait_queue_head_t *, struct poll_table_struct___52 *);

struct poll_table_struct___52 {
	poll_queue_proc___52 _qproc;
	__poll_t _key;
};

struct seq_operations___68;

struct seq_file___68 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___68 *op;
	int poll_event;
	const struct file___70 *file;
	void *private;
};

struct dev_pagemap_ops___69 {
	void (*page_free)(struct page___75 *);
	void (*kill)(struct dev_pagemap___69 *);
	void (*cleanup)(struct dev_pagemap___69 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___69 *);
};

struct kernfs_root___70;

struct kernfs_elem_dir___70 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___70 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___70;

struct kernfs_root___70 {
	struct kernfs_node___70 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___70 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___70 {
	struct kernfs_node___70 *target_kn;
};

struct kernfs_ops___70;

struct kernfs_elem_attr___70 {
	const struct kernfs_ops___70 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___70 *notify_next;
};

struct kernfs_node___70 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___70 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___70 dir;
		struct kernfs_elem_symlink___70 symlink;
		struct kernfs_elem_attr___70 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___70;

struct kernfs_ops___70 {
	int (*open)(struct kernfs_open_file___70 *);
	void (*release)(struct kernfs_open_file___70 *);
	int (*seq_show)(struct seq_file___68 *, void *);
	void * (*seq_start)(struct seq_file___68 *, loff_t *);
	void * (*seq_next)(struct seq_file___68 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___68 *, void *);
	ssize_t (*read)(struct kernfs_open_file___70 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___70 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___70 *, struct poll_table_struct___52 *);
	int (*mmap)(struct kernfs_open_file___70 *, struct vm_area_struct___75 *);
};

struct kernfs_syscall_ops___70 {
	int (*show_options)(struct seq_file___68 *, struct kernfs_root___70 *);
	int (*mkdir)(struct kernfs_node___70 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___70 *);
	int (*rename)(struct kernfs_node___70 *, struct kernfs_node___70 *, const char *);
	int (*show_path)(struct seq_file___68 *, struct kernfs_node___70 *, struct kernfs_root___70 *);
};

struct kernfs_open_file___70 {
	struct kernfs_node___70 *kn;
	struct file___70 *file;
	struct seq_file___68 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___69 *vm_ops;
};

struct bin_attribute___70;

struct attribute_group___70 {
	const char *name;
	umode_t (*is_visible)(struct kobject___70 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___70 *, struct bin_attribute___70 *, int);
	struct attribute **attrs;
	struct bin_attribute___70 **bin_attrs;
};

struct bin_attribute___70 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___70 * (*f_mapping)();
	ssize_t (*read)(struct file___70 *, struct kobject___70 *, struct bin_attribute___70 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___70 *, struct kobject___70 *, struct bin_attribute___70 *, char *, loff_t, size_t);
	int (*mmap)(struct file___70 *, struct kobject___70 *, struct bin_attribute___70 *, struct vm_area_struct___75 *);
};

struct sysfs_ops___70 {
	ssize_t (*show)(struct kobject___70 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___70 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___70;

struct kset___70 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___70 kobj;
	const struct kset_uevent_ops___70 *uevent_ops;
};

struct kobj_type___70 {
	void (*release)(struct kobject___70 *);
	const struct sysfs_ops___70 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___70 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___70 *);
	const void * (*namespace)(struct kobject___70 *);
	void (*get_ownership)(struct kobject___70 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___70 {
	int (* const filter)(struct kset___70 *, struct kobject___70 *);
	const char * (* const name)(struct kset___70 *, struct kobject___70 *);
	int (* const uevent)(struct kset___70 *, struct kobject___70 *, struct kobj_uevent_env *);
};

struct wakeup_source___63;

struct dev_pm_info___63 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___63 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___63 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___63;

struct bus_type___63;

struct device_driver___63;

struct dev_pm_domain___63;

struct device_node___33;

struct fwnode_handle___63;

struct class___63;

struct device___63 {
	struct kobject___70 kobj;
	struct device___63 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___63 *type;
	struct bus_type___63 *bus;
	struct device_driver___63 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___63 power;
	struct dev_pm_domain___63 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___33 *of_node;
	struct fwnode_handle___63 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___63 *class;
	const struct attribute_group___70 **groups;
	void (*release)(struct device___63 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___63 {
	int (*prepare)(struct device___63 *);
	void (*complete)(struct device___63 *);
	int (*suspend)(struct device___63 *);
	int (*resume)(struct device___63 *);
	int (*freeze)(struct device___63 *);
	int (*thaw)(struct device___63 *);
	int (*poweroff)(struct device___63 *);
	int (*restore)(struct device___63 *);
	int (*suspend_late)(struct device___63 *);
	int (*resume_early)(struct device___63 *);
	int (*freeze_late)(struct device___63 *);
	int (*thaw_early)(struct device___63 *);
	int (*poweroff_late)(struct device___63 *);
	int (*restore_early)(struct device___63 *);
	int (*suspend_noirq)(struct device___63 *);
	int (*resume_noirq)(struct device___63 *);
	int (*freeze_noirq)(struct device___63 *);
	int (*thaw_noirq)(struct device___63 *);
	int (*poweroff_noirq)(struct device___63 *);
	int (*restore_noirq)(struct device___63 *);
	int (*runtime_suspend)(struct device___63 *);
	int (*runtime_resume)(struct device___63 *);
	int (*runtime_idle)(struct device___63 *);
};

struct wakeup_source___63 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___63 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___63 {
	struct dev_pm_ops___63 ops;
	int (*start)(struct device___63 *);
	void (*detach)(struct device___63 *, bool);
	int (*activate)(struct device___63 *);
	void (*sync)(struct device___63 *);
	void (*dismiss)(struct device___63 *);
};

struct bus_type___63 {
	const char *name;
	const char *dev_name;
	struct device___63 *dev_root;
	const struct attribute_group___70 **bus_groups;
	const struct attribute_group___70 **dev_groups;
	const struct attribute_group___70 **drv_groups;
	int (*match)(struct device___63 *, struct device_driver___63 *);
	int (*uevent)(struct device___63 *, struct kobj_uevent_env *);
	int (*probe)(struct device___63 *);
	void (*sync_state)(struct device___63 *);
	void (*remove)(struct device___63 *);
	void (*shutdown)(struct device___63 *);
	int (*online)(struct device___63 *);
	int (*offline)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	int (*num_vf)(struct device___63 *);
	int (*dma_configure)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___63 {
	const char *name;
	struct bus_type___63 *bus;
	struct module___68 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___63 *);
	void (*sync_state)(struct device___63 *);
	int (*remove)(struct device___63 *);
	void (*shutdown)(struct device___63 *);
	int (*suspend)(struct device___63 *, pm_message_t);
	int (*resume)(struct device___63 *);
	const struct attribute_group___70 **groups;
	const struct attribute_group___70 **dev_groups;
	const struct dev_pm_ops___63 *pm;
	void (*coredump)(struct device___63 *);
	struct driver_private *p;
};

struct device_type___63 {
	const char *name;
	const struct attribute_group___70 **groups;
	int (*uevent)(struct device___63 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___63 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___63 *);
	const struct dev_pm_ops___63 *pm;
};

struct class___63 {
	const char *name;
	struct module___68 *owner;
	const struct attribute_group___70 **class_groups;
	const struct attribute_group___70 **dev_groups;
	struct kobject___70 *dev_kobj;
	int (*dev_uevent)(struct device___63 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___63 *, umode_t *);
	void (*class_release)(struct class___63 *);
	void (*dev_release)(struct device___63 *);
	int (*shutdown_pre)(struct device___63 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___63 *);
	void (*get_ownership)(struct device___63 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___63 *pm;
	struct subsys_private *p;
};

struct device_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct device___63 *, struct device_attribute___8 *, char *);
	ssize_t (*store)(struct device___63 *, struct device_attribute___8 *, const char *, size_t);
};

struct fwnode_operations___63;

struct fwnode_handle___63 {
	struct fwnode_handle___63 *secondary;
	const struct fwnode_operations___63 *ops;
	struct device___63 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___29;

struct device_node___33 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___63 fwnode;
	struct property___29 *properties;
	struct property___29 *deadprops;
	struct device_node___33 *parent;
	struct device_node___33 *child;
	struct device_node___33 *sibling;
	struct kobject___70 kobj;
	long unsigned int _flags;
	void *data;
};

struct fd___9 {
	struct file___70 *file;
	unsigned int flags;
};

typedef struct poll_table_struct___52 poll_table___13;

struct fwnode_reference_args___63;

struct fwnode_endpoint___63;

struct fwnode_operations___63 {
	struct fwnode_handle___63 * (*get)(struct fwnode_handle___63 *);
	void (*put)(struct fwnode_handle___63 *);
	bool (*device_is_available)(const struct fwnode_handle___63 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___63 *, const struct device___63 *);
	bool (*property_present)(const struct fwnode_handle___63 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___63 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___63 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___63 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*get_parent)(const struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*get_next_child_node)(const struct fwnode_handle___63 *, struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*get_named_child_node)(const struct fwnode_handle___63 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___63 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___63 *);
	struct fwnode_handle___63 * (*graph_get_next_endpoint)(const struct fwnode_handle___63 *, struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*graph_get_remote_endpoint)(const struct fwnode_handle___63 *);
	struct fwnode_handle___63 * (*graph_get_port_parent)(struct fwnode_handle___63 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___63 *, struct fwnode_endpoint___63 *);
	int (*add_links)(struct fwnode_handle___63 *);
};

struct fwnode_endpoint___63 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___63 *local_fwnode;
};

struct fwnode_reference_args___63 {
	struct fwnode_handle___63 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___29 {
	char *name;
	int length;
	void *value;
	struct property___29 *next;
	long unsigned int _flags;
	struct bin_attribute___70 attr;
};

struct fqdir___20;

struct netns_ipv4___20 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___20 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___23;

struct sk_buff___20;

struct dst_ops___20 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___20 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___23 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___20 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___20 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___20 *);
	int (*local_out)(struct net___21 *, struct sock *, struct sk_buff___20 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___20 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___20 {
	struct dst_ops___20 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___20 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	long: 64;
	long: 64;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___20 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___20 *fqdir;
};

struct sk_buff_head___18 {
	struct sk_buff___20 *next;
	struct sk_buff___20 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___18 {
	struct bpf_prog_array___18 *run_array[2];
	struct bpf_prog___18 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___20 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___20 xfrm4_dst_ops;
	struct dst_ops___20 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___21 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct idr netns_ids;
	struct ns_common___13 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___23 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___20 ipv4;
	struct netns_ipv6___20 ipv6;
	struct netns_ieee802154_lowpan___20 ieee802154_lowpan;
	struct netns_sctp___11 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___18 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___18 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___20 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___59 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___59 *root_cset;
};

struct nsset___12 {
	unsigned int flags;
	struct nsproxy___68 *nsproxy;
	struct fs_struct *fs;
	const struct cred___11 *cred;
};

struct proc_ns_operations___13 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___13 * (*get)(struct task_struct___77 *);
	void (*put)(struct ns_common___13 *);
	int (*install)(struct nsset___12 *, struct ns_common___13 *);
	struct user_namespace___12 * (*owner)(struct ns_common___13 *);
	struct ns_common___13 * (*get_parent)(struct ns_common___13 *);
};

struct seq_operations___68 {
	void * (*start)(struct seq_file___68 *, loff_t *);
	void (*stop)(struct seq_file___68 *, void *);
	void * (*next)(struct seq_file___68 *, void *, loff_t *);
	int (*show)(struct seq_file___68 *, void *);
};

struct kernel_param_ops___67 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___67 *);
	int (*get)(char *, const struct kernel_param___67 *);
	void (*free)(void *);
};

struct kparam_array___67;

struct kernel_param___67 {
	const char *name;
	struct module___68 *mod;
	const struct kernel_param_ops___67 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___67 *arr;
	};
};

struct kparam_array___67 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___67 *ops;
	void *elem;
};

struct module_attribute___67 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___67 *, struct module_kobject___67 *, char *);
	ssize_t (*store)(struct module_attribute___67 *, struct module_kobject___67 *, const char *, size_t);
	void (*setup)(struct module___68 *, const char *);
	int (*test)(struct module___68 *);
	void (*free)(struct module___68 *);
};

struct trace_event_class___38;

struct trace_event_call___38 {
	struct list_head list;
	struct trace_event_class___38 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___38 *, struct perf_event___44 *);
};

struct bpf_iter_aux_info___19;

typedef int (*bpf_iter_init_seq_priv_t___19)(void *, struct bpf_iter_aux_info___19 *);

struct bpf_map___19;

struct bpf_iter_aux_info___19 {
	struct bpf_map___19 *map;
};

struct bpf_iter_seq_info___19 {
	const struct seq_operations___68 *seq_ops;
	bpf_iter_init_seq_priv_t___19 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___19;

struct bpf_map_ops___19 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___19 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___19 *, struct file___70 *);
	void (*map_free)(struct bpf_map___19 *);
	int (*map_get_next_key)(struct bpf_map___19 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___19 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___19 *, void *);
	int (*map_lookup_batch)(struct bpf_map___19 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___19 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___19 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___19 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___19 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___19 *, void *);
	int (*map_update_elem)(struct bpf_map___19 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___19 *, void *);
	int (*map_push_elem)(struct bpf_map___19 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___19 *, void *);
	int (*map_peek_elem)(struct bpf_map___19 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___19 *, struct file___70 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___19 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___19 *, void *, struct seq_file___68 *);
	int (*map_check_btf)(const struct bpf_map___19 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___19 *, struct bpf_prog_aux___19 *);
	void (*map_poke_untrack)(struct bpf_map___19 *, struct bpf_prog_aux___19 *);
	void (*map_poke_run)(struct bpf_map___19 *, u32, struct bpf_prog___18 *, struct bpf_prog___18 *);
	int (*map_direct_value_addr)(const struct bpf_map___19 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___19 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___19 *, struct vm_area_struct___75 *);
	__poll_t (*map_poll)(struct bpf_map___19 *, struct file___70 *, struct poll_table_struct___52 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___19 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___19 *, const struct bpf_map___19 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___19 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___19 *iter_seq_info;
};

struct bpf_map___19 {
	const struct bpf_map_ops___19 *ops;
	struct bpf_map___19 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___19;

struct bpf_jit_poke_descriptor___19;

struct bpf_prog_ops___18;

struct btf_mod_pair___19;

struct bpf_prog_offload___18;

struct bpf_prog_aux___19 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___18 *dst_prog;
	struct bpf_trampoline___19 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___18 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___19 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___18 *ops;
	struct bpf_map___19 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___19 *used_btfs;
	struct bpf_prog___18 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___19 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___18 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___18 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___19 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___18;

struct bpf_map_dev_ops___18 {
	int (*map_get_next_key)(struct bpf_offloaded_map___18 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___18 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___18 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___18 *, void *);
};

struct bpf_offloaded_map___18 {
	struct bpf_map___19 map;
	struct net_device___23 *netdev;
	const struct bpf_map_dev_ops___18 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___18(struct sk_buff___20 **);

typedef struct {
	struct net___21 *net;
} possible_net_t___18;

struct bpf_xdp_entity___18 {
	struct bpf_prog___18 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___18;

struct net_device_ops___18;

struct xfrmdev_ops___18;

struct header_ops___18;

struct netdev_rx_queue___18;

struct mini_Qdisc___18;

struct netdev_queue___18;

struct Qdisc___18;

struct rtnl_link_ops___18;

struct dcbnl_rtnl_ops___18;

struct net_device___23 {
	char name[16];
	struct netdev_name_node___18 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___18 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___18 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___18 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___70 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___18 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___18 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___18 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___18 *miniq_ingress;
	struct netdev_queue___18 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___18 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___18 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___18 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___18 = 0,
		NETREG_REGISTERED___18 = 1,
		NETREG_UNREGISTERING___18 = 2,
		NETREG_UNREGISTERED___18 = 3,
		NETREG_RELEASED___18 = 4,
		NETREG_DUMMY___18 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___18 = 0,
		RTNL_LINK_INITIALIZING___18 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___23 *);
	struct netpoll_info *npinfo;
	possible_net_t___18 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___63 dev;
	const struct attribute_group___70 *sysfs_groups[4];
	const struct attribute_group___70 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___18 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___18 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___18 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___18 {
	int (*test_run)(struct bpf_prog___18 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___18 {
	struct bpf_prog___18 *prog;
	struct net_device___23 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___19 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___18 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___68 *mod;
};

struct bpf_jit_poke_descriptor___19 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___19 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___19 {
	struct btf *btf;
	struct module___68 *module;
};

struct bpf_prog_array_item___18 {
	struct bpf_prog___18 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___18 {
	struct callback_head rcu;
	struct bpf_prog_array_item___18 items[0];
};

struct sk_buff___20 {
	union {
		struct {
			struct sk_buff___20 *next;
			struct sk_buff___20 *prev;
			union {
				struct net_device___23 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___12 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___20 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___59;

struct cgroup_subsys___59 {
	struct cgroup_subsys_state___59 * (*css_alloc)(struct cgroup_subsys_state___59 *);
	int (*css_online)(struct cgroup_subsys_state___59 *);
	void (*css_offline)(struct cgroup_subsys_state___59 *);
	void (*css_released)(struct cgroup_subsys_state___59 *);
	void (*css_free)(struct cgroup_subsys_state___59 *);
	void (*css_reset)(struct cgroup_subsys_state___59 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___59 *, int);
	int (*css_extra_stat_show)(struct seq_file___68 *, struct cgroup_subsys_state___59 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___77 *, struct css_set___59 *);
	void (*cancel_fork)(struct task_struct___77 *, struct css_set___59 *);
	void (*fork)(struct task_struct___77 *);
	void (*exit)(struct task_struct___77 *);
	void (*release)(struct task_struct___77 *);
	void (*bind)(struct cgroup_subsys_state___59 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___59 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___59 *dfl_cftypes;
	struct cftype___59 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___59 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___59 *updated_children;
	struct cgroup___59 *updated_next;
};

struct cgroup_root___59 {
	struct kernfs_root___70 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___59 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___59 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___59 *ss;
	struct list_head node;
	struct kernfs_ops___70 *kf_ops;
	int (*open)(struct kernfs_open_file___70 *);
	void (*release)(struct kernfs_open_file___70 *);
	u64 (*read_u64)(struct cgroup_subsys_state___59 *, struct cftype___59 *);
	s64 (*read_s64)(struct cgroup_subsys_state___59 *, struct cftype___59 *);
	int (*seq_show)(struct seq_file___68 *, void *);
	void * (*seq_start)(struct seq_file___68 *, loff_t *);
	void * (*seq_next)(struct seq_file___68 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___68 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___59 *, struct cftype___59 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___59 *, struct cftype___59 *, s64);
	ssize_t (*write)(struct kernfs_open_file___70 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___70 *, struct poll_table_struct___52 *);
};

struct bio_vec___41 {
	struct page___75 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

enum perf_branch_sample_type {
	PERF_SAMPLE_BRANCH_USER = 1,
	PERF_SAMPLE_BRANCH_KERNEL = 2,
	PERF_SAMPLE_BRANCH_HV = 4,
	PERF_SAMPLE_BRANCH_ANY = 8,
	PERF_SAMPLE_BRANCH_ANY_CALL = 16,
	PERF_SAMPLE_BRANCH_ANY_RETURN = 32,
	PERF_SAMPLE_BRANCH_IND_CALL = 64,
	PERF_SAMPLE_BRANCH_ABORT_TX = 128,
	PERF_SAMPLE_BRANCH_IN_TX = 256,
	PERF_SAMPLE_BRANCH_NO_TX = 512,
	PERF_SAMPLE_BRANCH_COND = 1024,
	PERF_SAMPLE_BRANCH_CALL_STACK = 2048,
	PERF_SAMPLE_BRANCH_IND_JUMP = 4096,
	PERF_SAMPLE_BRANCH_CALL = 8192,
	PERF_SAMPLE_BRANCH_NO_FLAGS = 16384,
	PERF_SAMPLE_BRANCH_NO_CYCLES = 32768,
	PERF_SAMPLE_BRANCH_TYPE_SAVE = 65536,
	PERF_SAMPLE_BRANCH_HW_INDEX = 131072,
	PERF_SAMPLE_BRANCH_MAX = 262144,
};

enum perf_event_read_format {
	PERF_FORMAT_TOTAL_TIME_ENABLED = 1,
	PERF_FORMAT_TOTAL_TIME_RUNNING = 2,
	PERF_FORMAT_ID = 4,
	PERF_FORMAT_GROUP = 8,
	PERF_FORMAT_MAX = 16,
};

enum perf_event_ioc_flags {
	PERF_IOC_FLAG_GROUP = 1,
};

struct perf_event_header {
	__u32 type;
	__u16 misc;
	__u16 size;
};

struct perf_ns_link_info {
	__u64 dev;
	__u64 ino;
};

enum {
	NET_NS_INDEX = 0,
	UTS_NS_INDEX = 1,
	IPC_NS_INDEX = 2,
	PID_NS_INDEX = 3,
	USER_NS_INDEX = 4,
	MNT_NS_INDEX = 5,
	CGROUP_NS_INDEX = 6,
	NR_NAMESPACES = 7,
};

enum perf_event_type {
	PERF_RECORD_MMAP = 1,
	PERF_RECORD_LOST = 2,
	PERF_RECORD_COMM = 3,
	PERF_RECORD_EXIT = 4,
	PERF_RECORD_THROTTLE = 5,
	PERF_RECORD_UNTHROTTLE = 6,
	PERF_RECORD_FORK = 7,
	PERF_RECORD_READ = 8,
	PERF_RECORD_SAMPLE = 9,
	PERF_RECORD_MMAP2 = 10,
	PERF_RECORD_AUX = 11,
	PERF_RECORD_ITRACE_START = 12,
	PERF_RECORD_LOST_SAMPLES = 13,
	PERF_RECORD_SWITCH = 14,
	PERF_RECORD_SWITCH_CPU_WIDE = 15,
	PERF_RECORD_NAMESPACES = 16,
	PERF_RECORD_KSYMBOL = 17,
	PERF_RECORD_BPF_EVENT = 18,
	PERF_RECORD_CGROUP = 19,
	PERF_RECORD_TEXT_POKE = 20,
	PERF_RECORD_MAX = 21,
};

struct perf_cpu_context___44;

struct perf_output_handle___44;

struct pmu___44 {
	struct list_head entry;
	struct module___68 *module;
	struct device___63 *dev;
	const struct attribute_group___70 **attr_groups;
	const struct attribute_group___70 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___44 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___44 *);
	void (*pmu_disable)(struct pmu___44 *);
	int (*event_init)(struct perf_event___44 *);
	void (*event_mapped)(struct perf_event___44 *, struct mm_struct___76 *);
	void (*event_unmapped)(struct perf_event___44 *, struct mm_struct___76 *);
	int (*add)(struct perf_event___44 *, int);
	void (*del)(struct perf_event___44 *, int);
	void (*start)(struct perf_event___44 *, int);
	void (*stop)(struct perf_event___44 *, int);
	void (*read)(struct perf_event___44 *);
	void (*start_txn)(struct pmu___44 *, unsigned int);
	int (*commit_txn)(struct pmu___44 *);
	void (*cancel_txn)(struct pmu___44 *);
	int (*event_idx)(struct perf_event___44 *);
	void (*sched_task)(struct perf_event_context___44 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___44 *, struct perf_event_context___44 *);
	void * (*setup_aux)(struct perf_event___44 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___44 *, struct perf_output_handle___44 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___44 *);
	int (*aux_output_match)(struct perf_event___44 *);
	int (*filter_match)(struct perf_event___44 *);
	int (*check_period)(struct perf_event___44 *, u64);
};

struct perf_cpu_context___44 {
	struct perf_event_context___44 ctx;
	struct perf_event_context___44 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___44 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___44 **heap;
	struct perf_event___44 *heap_default[2];
};

struct perf_output_handle___44 {
	struct perf_event___44 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

enum perf_addr_filter_action_t {
	PERF_ADDR_FILTER_ACTION_STOP = 0,
	PERF_ADDR_FILTER_ACTION_START = 1,
	PERF_ADDR_FILTER_ACTION_FILTER = 2,
};

struct perf_addr_filter {
	struct list_head entry;
	struct path___70 path;
	long unsigned int offset;
	long unsigned int size;
	enum perf_addr_filter_action_t action;
};

struct swevent_hlist {
	struct hlist_head heads[256];
	struct callback_head callback_head;
};

struct pmu_event_list {
	raw_spinlock_t lock;
	struct list_head list;
};

struct perf_buffer {
	refcount_t refcount;
	struct callback_head callback_head;
	int nr_pages;
	int overwrite;
	int paused;
	atomic_t poll;
	local_t head;
	unsigned int nest;
	local_t events;
	local_t wakeup;
	local_t lost;
	long int watermark;
	long int aux_watermark;
	spinlock_t event_lock;
	struct list_head event_list;
	atomic_t mmap_count;
	long unsigned int mmap_locked;
	struct user_struct *mmap_user;
	long int aux_head;
	unsigned int aux_nest;
	long int aux_wakeup;
	long unsigned int aux_pgoff;
	int aux_nr_pages;
	int aux_overwrite;
	atomic_t aux_mmap_count;
	long unsigned int aux_mmap_locked;
	void (*free_aux)(void *);
	refcount_t aux_refcount;
	int aux_in_sampling;
	void **aux_pages;
	void *aux_priv;
	struct perf_event_mmap_page *user_page;
	void *data_pages[0];
};

struct perf_cgroup___44 {
	struct cgroup_subsys_state___59 css;
	struct perf_cgroup_info *info;
};

struct bpf_perf_event_data_kern___4 {
	bpf_user_pt_regs_t *regs;
	struct perf_sample_data *data;
	struct perf_event___44 *event;
};

struct perf_pmu_events_attr___2 {
	struct device_attribute___8 attr;
	u64 id;
	const char *event_str;
};

struct trace_event_fields___38 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___38 *);
	};
};

struct trace_event_class___38 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___38 *, enum trace_reg, void *);
	struct trace_event_fields___38 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___38 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___38 *);
};

struct syscall_metadata___16 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___38 *enter_event;
	struct trace_event_call___38 *exit_event;
};

struct pipe_buf_operations___30;

struct pipe_buffer___30 {
	struct page___75 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___30 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___30 {
	int (*confirm)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
	void (*release)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
	bool (*try_steal)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
	bool (*get)(struct pipe_inode_info___30 *, struct pipe_buffer___30 *);
};

struct inet_frags___20;

struct fqdir___20 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___20 *f;
	struct net___21 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___20;

struct inet_frags___20 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___20 *, const void *);
	void (*destructor)(struct inet_frag_queue___20 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___20 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___20 *fragments_tail;
	struct sk_buff___20 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___20 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___18 {
	int (*ieee_getets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___23 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___23 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___23 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___23 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___23 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___23 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___23 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___23 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___23 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___23 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___23 *);
	u8 (*setstate)(struct net_device___23 *, u8);
	void (*getpermhwaddr)(struct net_device___23 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___23 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___23 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___23 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___23 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___23 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___23 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___23 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___23 *, int, u8 *);
	void (*setpfccfg)(struct net_device___23 *, int, u8);
	void (*getpfccfg)(struct net_device___23 *, int, u8 *);
	u8 (*setall)(struct net_device___23 *);
	u8 (*getcap)(struct net_device___23 *, int, u8 *);
	int (*getnumtcs)(struct net_device___23 *, int, u8 *);
	int (*setnumtcs)(struct net_device___23 *, int, u8);
	u8 (*getpfcstate)(struct net_device___23 *);
	void (*setpfcstate)(struct net_device___23 *, u8);
	void (*getbcncfg)(struct net_device___23 *, int, u32 *);
	void (*setbcncfg)(struct net_device___23 *, int, u32);
	void (*getbcnrp)(struct net_device___23 *, int, u8 *);
	void (*setbcnrp)(struct net_device___23 *, int, u8);
	int (*setapp)(struct net_device___23 *, u8, u16, u8);
	int (*getapp)(struct net_device___23 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___23 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___23 *, int, u8);
	u8 (*getdcbx)(struct net_device___23 *);
	u8 (*setdcbx)(struct net_device___23 *, u8);
	int (*peer_getappinfo)(struct net_device___23 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___23 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___23 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___23 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___23 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___23 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___18 {
	struct net_device___23 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___18 {
	struct net_device___23 *dev;
};

struct xdp_buff___18 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___18 *rxq;
	struct xdp_txq_info___18 *txq;
	u32 frame_sz;
};

struct xdp_frame___18 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___23 *dev_rx;
};

struct netlink_callback___18 {
	struct sk_buff___20 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___20 *, struct netlink_callback___18 *);
	int (*done)(struct netlink_callback___18 *);
	void *data;
	struct module___68 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___18 {
	int (*create)(struct sk_buff___20 *, struct net_device___23 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___20 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___23 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___20 *);
};

struct netdev_queue___18 {
	struct net_device___23 *dev;
	struct Qdisc___18 *qdisc;
	struct Qdisc___18 *qdisc_sleeping;
	struct kobject___70 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___23 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___18 {
	struct sk_buff___20 *head;
	struct sk_buff___20 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___18;

struct Qdisc___18 {
	int (*enqueue)(struct sk_buff___20 *, struct Qdisc___18 *, struct sk_buff___20 **);
	struct sk_buff___20 * (*dequeue)(struct Qdisc___18 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___18 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___18 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___18 gso_skb;
	struct qdisc_skb_head___18 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___18 *next_sched;
	struct sk_buff_head___18 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___18 {
	struct xdp_rxq_info___18 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___70 kobj;
	struct net_device___23 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___18 {
	enum net_device_path_type type;
	const struct net_device___23 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___18 = 0,
				DEV_PATH_BR_VLAN_TAG___18 = 1,
				DEV_PATH_BR_VLAN_UNTAG___18 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___18 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___18 {
	const struct net_device___23 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___18 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___18 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___18 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___18 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___20 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___18 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___23 *dev;
	const char *name;
};

struct net_device_ops___18 {
	int (*ndo_init)(struct net_device___23 *);
	void (*ndo_uninit)(struct net_device___23 *);
	int (*ndo_open)(struct net_device___23 *);
	int (*ndo_stop)(struct net_device___23 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___20 *, struct net_device___23 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___20 *, struct net_device___23 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___23 *, struct sk_buff___20 *, struct net_device___23 *);
	void (*ndo_change_rx_flags)(struct net_device___23 *, int);
	void (*ndo_set_rx_mode)(struct net_device___23 *);
	int (*ndo_set_mac_address)(struct net_device___23 *, void *);
	int (*ndo_validate_addr)(struct net_device___23 *);
	int (*ndo_do_ioctl)(struct net_device___23 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___23 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___23 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___23 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___23 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___23 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___23 *, int);
	int (*ndo_neigh_setup)(struct net_device___23 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___23 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___23 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___23 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___23 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___23 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___23 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___23 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___23 *);
	int (*ndo_netpoll_setup)(struct net_device___23 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___23 *);
	int (*ndo_set_vf_mac)(struct net_device___23 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___23 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___23 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___23 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___23 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___23 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___23 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___23 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___23 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___23 *, int, struct sk_buff___20 *);
	int (*ndo_get_vf_guid)(struct net_device___23 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___23 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___23 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___23 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___23 *);
	int (*ndo_fcoe_disable)(struct net_device___23 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___23 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___23 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___23 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___23 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___23 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___23 *, const struct sk_buff___20 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___23 *, struct net_device___23 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___23 *, struct net_device___23 *);
	struct net_device___23 * (*ndo_get_xmit_slave)(struct net_device___23 *, struct sk_buff___20 *, bool);
	struct net_device___23 * (*ndo_sk_get_lower_dev)(struct net_device___23 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___23 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___23 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___23 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___23 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___20 *, struct netlink_callback___18 *, struct net_device___23 *, struct net_device___23 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___20 *, struct nlattr **, struct net_device___23 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___23 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___20 *, u32, u32, struct net_device___23 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___23 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___23 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___23 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___23 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___23 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___23 *, struct net_device___23 *);
	void (*ndo_dfwd_del_station)(struct net_device___23 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___23 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___23 *);
	int (*ndo_change_proto_down)(struct net_device___23 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___23 *, struct sk_buff___20 *);
	void (*ndo_set_rx_headroom)(struct net_device___23 *, int);
	int (*ndo_bpf)(struct net_device___23 *, struct netdev_bpf___18 *);
	int (*ndo_xdp_xmit)(struct net_device___23 *, int, struct xdp_frame___18 **, u32);
	struct net_device___23 * (*ndo_xdp_get_xmit_slave)(struct net_device___23 *, struct xdp_buff___18 *);
	int (*ndo_xsk_wakeup)(struct net_device___23 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___23 *);
	int (*ndo_tunnel_ctl)(struct net_device___23 *, struct ip_tunnel_parm *, int);
	struct net_device___23 * (*ndo_get_peer_dev)(struct net_device___23 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___18 *, struct net_device_path___18 *);
};

struct tcf_proto___18;

struct tcf_block___18;

struct mini_Qdisc___18 {
	struct tcf_proto___18 *filter_list;
	struct tcf_block___18 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___18 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___23 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___23 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___21 *, struct net_device___23 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___23 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___23 *, struct list_head *);
	size_t (*get_size)(const struct net_device___23 *);
	int (*fill_info)(struct sk_buff___20 *, const struct net_device___23 *);
	size_t (*get_xstats_size)(const struct net_device___23 *);
	int (*fill_xstats)(struct sk_buff___20 *, const struct net_device___23 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___23 *, struct net_device___23 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___23 *, const struct net_device___23 *);
	int (*fill_slave_info)(struct sk_buff___20 *, const struct net_device___23 *, const struct net_device___23 *);
	struct net___21 * (*get_link_net)(const struct net_device___23 *);
	size_t (*get_linkxstats_size)(const struct net_device___23 *, int);
	int (*fill_linkxstats)(struct sk_buff___20 *, const struct net_device___23 *, int *, int);
};

struct gnet_dump___18 {
	spinlock_t *lock;
	struct sk_buff___20 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___18;

struct Qdisc_ops___18 {
	struct Qdisc_ops___18 *next;
	const struct Qdisc_class_ops___18 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___20 *, struct Qdisc___18 *, struct sk_buff___20 **);
	struct sk_buff___20 * (*dequeue)(struct Qdisc___18 *);
	struct sk_buff___20 * (*peek)(struct Qdisc___18 *);
	int (*init)(struct Qdisc___18 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___18 *);
	void (*destroy)(struct Qdisc___18 *);
	int (*change)(struct Qdisc___18 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___18 *);
	int (*change_tx_queue_len)(struct Qdisc___18 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___18 *, unsigned int);
	int (*dump)(struct Qdisc___18 *, struct sk_buff___20 *);
	int (*dump_stats)(struct Qdisc___18 *, struct gnet_dump___18 *);
	void (*ingress_block_set)(struct Qdisc___18 *, u32);
	void (*egress_block_set)(struct Qdisc___18 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___18 *);
	u32 (*egress_block_get)(struct Qdisc___18 *);
	struct module___68 *owner;
};

struct Qdisc_class_ops___18 {
	unsigned int flags;
	struct netdev_queue___18 * (*select_queue)(struct Qdisc___18 *, struct tcmsg *);
	int (*graft)(struct Qdisc___18 *, long unsigned int, struct Qdisc___18 *, struct Qdisc___18 **, struct netlink_ext_ack *);
	struct Qdisc___18 * (*leaf)(struct Qdisc___18 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___18 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___18 *, u32);
	int (*change)(struct Qdisc___18 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___18 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___18 *, struct qdisc_walker *);
	struct tcf_block___18 * (*tcf_block)(struct Qdisc___18 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___18 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___18 *, long unsigned int);
	int (*dump)(struct Qdisc___18 *, long unsigned int, struct sk_buff___20 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___18 *, long unsigned int, struct gnet_dump___18 *);
};

struct tcf_chain___18;

struct tcf_block___18 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___21 *net;
	struct Qdisc___18 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___18 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___18;

struct tcf_proto_ops___18;

struct tcf_proto___18 {
	struct tcf_proto___18 *next;
	void *root;
	int (*classify)(struct sk_buff___20 *, const struct tcf_proto___18 *, struct tcf_result___18 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___18 *ops;
	struct tcf_chain___18 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___18 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___18 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___18 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___20 *, const struct tcf_proto___18 *, struct tcf_result___18 *);
	int (*init)(struct tcf_proto___18 *);
	void (*destroy)(struct tcf_proto___18 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___18 *, u32);
	void (*put)(struct tcf_proto___18 *, void *);
	int (*change)(struct net___21 *, struct sk_buff___20 *, struct tcf_proto___18 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___18 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___18 *);
	void (*walk)(struct tcf_proto___18 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___18 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___18 *, void *);
	void (*hw_del)(struct tcf_proto___18 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___21 *, struct tcf_chain___18 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___21 *, struct tcf_proto___18 *, void *, struct sk_buff___20 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___21 *, struct tcf_proto___18 *, void *, struct sk_buff___20 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___20 *, struct net___21 *, void *);
	struct module___68 *owner;
	int flags;
};

struct tcf_chain___18 {
	struct mutex filter_chain_lock;
	struct tcf_proto___18 *filter_chain;
	struct list_head list;
	struct tcf_block___18 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___18 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct match_token {
	int token;
	const char *pattern;
};

enum {
	MAX_OPT_ARGS = 3,
};

typedef struct {
	char *from;
	char *to;
} substring_t___2;

struct min_heap {
	void *data;
	int nr;
	int size;
};

struct min_heap_callbacks {
	int elem_size;
	bool (*less)(const void *, const void *);
	void (*swp)(void *, void *);
};

typedef int (*remote_function_f)(void *);

struct remote_function_call {
	struct task_struct___77 *p;
	remote_function_f func;
	void *info;
	int ret;
};

typedef void (*event_f)(struct perf_event___44 *, struct perf_cpu_context___44 *, struct perf_event_context___44 *, void *);

struct event_function_struct {
	struct perf_event___44 *event;
	event_f func;
	void *data;
};

enum event_type_t {
	EVENT_FLEXIBLE = 1,
	EVENT_PINNED = 2,
	EVENT_TIME = 4,
	EVENT_CPU = 8,
	EVENT_ALL = 3,
};

struct __group_key {
	int cpu;
	struct cgroup___59 *cgroup;
};

struct stop_event_data {
	struct perf_event___44 *event;
	unsigned int restart;
};

struct perf_read_data {
	struct perf_event___44 *event;
	bool group;
	int ret;
};

struct perf_read_event {
	struct perf_event_header header;
	u32 pid;
	u32 tid;
};

typedef void perf_iterate_f(struct perf_event___44 *, void *);

struct remote_output {
	struct perf_buffer *rb;
	int err;
};

struct perf_task_event {
	struct task_struct___77 *task;
	struct perf_event_context___44 *task_ctx;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 ppid;
		u32 tid;
		u32 ptid;
		u64 time;
	} event_id;
};

struct perf_comm_event {
	struct task_struct___77 *task;
	char *comm;
	int comm_size;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
	} event_id;
};

struct perf_namespaces_event {
	struct task_struct___77 *task;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
		u64 nr_namespaces;
		struct perf_ns_link_info link_info[7];
	} event_id;
};

struct perf_cgroup_event {
	char *path;
	int path_size;
	struct {
		struct perf_event_header header;
		u64 id;
		char path[0];
	} event_id;
};

struct perf_mmap_event {
	struct vm_area_struct___75 *vma;
	const char *file_name;
	int file_size;
	int maj;
	int min;
	u64 ino;
	u64 ino_generation;
	u32 prot;
	u32 flags;
	u8 build_id[20];
	u32 build_id_size;
	struct {
		struct perf_event_header header;
		u32 pid;
		u32 tid;
		u64 start;
		u64 len;
		u64 pgoff;
	} event_id;
};

struct perf_switch_event {
	struct task_struct___77 *task;
	struct task_struct___77 *next_prev;
	struct {
		struct perf_event_header header;
		u32 next_prev_pid;
		u32 next_prev_tid;
	} event_id;
};

struct perf_ksymbol_event {
	const char *name;
	int name_len;
	struct {
		struct perf_event_header header;
		u64 addr;
		u32 len;
		u16 ksym_type;
		u16 flags;
	} event_id;
};

struct perf_bpf_event {
	struct bpf_prog___18 *prog;
	struct {
		struct perf_event_header header;
		u16 type;
		u16 flags;
		u32 id;
		u8 tag[8];
	} event_id;
};

struct perf_text_poke_event {
	const void *old_bytes;
	const void *new_bytes;
	size_t pad;
	u16 old_len;
	u16 new_len;
	struct {
		struct perf_event_header header;
		u64 addr;
	} event_id;
};

struct swevent_htable {
	struct swevent_hlist *swevent_hlist;
	struct mutex hlist_mutex;
	int hlist_refcount;
	int recursion[4];
};

enum perf_probe_config {
	PERF_PROBE_CONFIG_IS_RETPROBE = 1,
	PERF_UPROBE_REF_CTR_OFFSET_BITS = 32,
	PERF_UPROBE_REF_CTR_OFFSET_SHIFT = 32,
};

enum {
	IF_ACT_NONE = 4294967295,
	IF_ACT_FILTER = 0,
	IF_ACT_START = 1,
	IF_ACT_STOP = 2,
	IF_SRC_FILE = 3,
	IF_SRC_KERNEL = 4,
	IF_SRC_FILEADDR = 5,
	IF_SRC_KERNELADDR = 6,
};

enum {
	IF_STATE_ACTION = 0,
	IF_STATE_SOURCE = 1,
	IF_STATE_END = 2,
};

struct perf_aux_event {
	struct perf_event_header header;
	u32 pid;
	u32 tid;
};

struct perf_aux_event___2 {
	struct perf_event_header header;
	u64 offset;
	u64 size;
	u64 flags;
};

struct callchain_cpus_entries {
	struct callback_head callback_head;
	struct perf_callchain_entry *cpu_entries[0];
};

struct bp_cpuinfo {
	unsigned int cpu_pinned;
	unsigned int *tsk_pinned;
	unsigned int flexible;
};

struct bp_busy_slots {
	unsigned int pinned;
	unsigned int flexible;
};

struct compact_control;

struct capture_control {
	struct compact_control *cc;
	struct page___2 *page;
};

struct uprobe_consumer___2 {
	int (*handler)(struct uprobe_consumer___2 *, struct pt_regs *);
	int (*ret_handler)(struct uprobe_consumer___2 *, long unsigned int, struct pt_regs *);
	bool (*filter)(struct uprobe_consumer___2 *, enum uprobe_filter_ctx, struct mm_struct___38 *);
	struct uprobe_consumer___2 *next;
};

typedef u32 uprobe_opcode_t;

struct uprobe {
	struct rb_node rb_node;
	refcount_t ref;
	struct rw_semaphore register_rwsem;
	struct rw_semaphore consumer_rwsem;
	struct list_head pending_list;
	struct uprobe_consumer___2 *consumers;
	struct inode___3 *inode;
	loff_t offset;
	loff_t ref_ctr_offset;
	long unsigned int flags;
	struct arch_uprobe arch;
};

struct vm_special_mapping___2 {
	const char *name;
	struct page___2 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping___2 *, struct vm_area_struct___37 *, struct vm_fault___35 *);
	int (*mremap)(const struct vm_special_mapping___2 *, struct vm_area_struct___37 *);
};

struct xol_area {
	wait_queue_head_t wq;
	atomic_t slot_count;
	long unsigned int *bitmap;
	struct vm_special_mapping___2 xol_mapping;
	struct page___2 *pages[2];
	long unsigned int vaddr;
};

typedef int filler_t(void *, struct page___2 *);

struct page_vma_mapped_walk {
	struct page___2 *page;
	struct vm_area_struct___37 *vma;
	long unsigned int address;
	pmd_t *pmd;
	pte_t *pte;
	spinlock_t *ptl;
	unsigned int flags;
};

struct mmu_notifier_range___7 {
	struct vm_area_struct___37 *vma;
	struct mm_struct___38 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct compact_control {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___16 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct delayed_uprobe {
	struct list_head list;
	struct uprobe *uprobe;
	struct mm_struct___38 *mm;
};

struct __uprobe_key {
	struct inode___3 *inode;
	loff_t offset;
};

struct map_info {
	struct map_info *next;
	struct mm_struct___38 *mm;
	long unsigned int vaddr;
};

struct parallel_data;

struct padata_priv {
	struct list_head list;
	struct parallel_data *pd;
	int cb_cpu;
	unsigned int seq_nr;
	int info;
	void (*parallel)(struct padata_priv *);
	void (*serial)(struct padata_priv *);
};

struct padata_cpumask {
	cpumask_var_t pcpu;
	cpumask_var_t cbcpu;
};

struct padata_shell;

struct padata_list;

struct padata_serial_queue;

struct parallel_data {
	struct padata_shell *ps;
	struct padata_list *reorder_list;
	struct padata_serial_queue *squeue;
	refcount_t refcnt;
	unsigned int seq_nr;
	unsigned int processed;
	int cpu;
	struct padata_cpumask cpumask;
	struct work_struct reorder_work;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct padata_list {
	struct list_head list;
	spinlock_t lock;
};

struct padata_serial_queue {
	struct padata_list serial;
	struct work_struct work;
	struct parallel_data *pd;
};

struct padata_instance;

struct padata_shell {
	struct padata_instance *pinst;
	struct parallel_data *pd;
	struct parallel_data *opd;
	struct list_head list;
};

struct padata_instance {
	struct hlist_node cpu_online_node;
	struct hlist_node cpu_dead_node;
	struct workqueue_struct *parallel_wq;
	struct workqueue_struct *serial_wq;
	struct list_head pslist;
	struct padata_cpumask cpumask;
	struct kobject___43 kobj;
	struct mutex lock;
	u8 flags;
};

struct padata_mt_job {
	void (*thread_fn)(long unsigned int, long unsigned int, void *);
	void *fn_arg;
	long unsigned int start;
	long unsigned int size;
	long unsigned int align;
	long unsigned int min_chunk;
	int max_threads;
};

struct padata_work {
	struct work_struct pw_work;
	struct list_head pw_list;
	void *pw_data;
};

struct padata_mt_job_state {
	spinlock_t lock;
	struct completion completion;
	struct padata_mt_job *job;
	int nworks;
	int nworks_fini;
	long unsigned int chunk_size;
};

struct padata_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct padata_instance *, struct attribute *, char *);
	ssize_t (*store)(struct padata_instance *, struct attribute *, const char *, size_t);
};

struct static_key_mod {
	struct static_key_mod *next;
	struct jump_entry *entries;
	struct module___8 *mod;
};

struct static_key_deferred {
	struct static_key key;
	long unsigned int timeout;
	struct delayed_work work;
};

typedef void (*dr_release_t___4)(struct device___50 *, void *);

typedef int (*dr_match_t___3)(struct device___50 *, void *, void *);

enum rseq_cpu_id_state {
	RSEQ_CPU_ID_UNINITIALIZED = 4294967295,
	RSEQ_CPU_ID_REGISTRATION_FAILED = 4294967294,
};

enum rseq_flags {
	RSEQ_FLAG_UNREGISTER = 1,
};

enum rseq_cs_flags {
	RSEQ_CS_FLAG_NO_RESTART_ON_PREEMPT = 1,
	RSEQ_CS_FLAG_NO_RESTART_ON_SIGNAL = 2,
	RSEQ_CS_FLAG_NO_RESTART_ON_MIGRATE = 4,
};

struct rseq_cs {
	__u32 version;
	__u32 flags;
	__u64 start_ip;
	__u64 post_commit_offset;
	__u64 abort_ip;
};

struct trace_event_raw_rseq_update {
	struct trace_entry ent;
	s32 cpu_id;
	char __data[0];
};

struct trace_event_raw_rseq_ip_fixup {
	struct trace_entry ent;
	long unsigned int regs_ip;
	long unsigned int start_ip;
	long unsigned int post_commit_offset;
	long unsigned int abort_ip;
	char __data[0];
};

struct trace_event_data_offsets_rseq_update {};

struct trace_event_data_offsets_rseq_ip_fixup {};

typedef void (*btf_trace_rseq_update)(void *, struct task_struct___62 *);

typedef void (*btf_trace_rseq_ip_fixup)(void *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);

struct dentry___72;

struct super_block___72;

struct module___69;

struct file_system_type___71 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___72 * (*mount)(struct file_system_type___71 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___72 *);
	struct module___69 *owner;
	struct file_system_type___71 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___71;

struct kiocb___71;

struct iov_iter___42;

struct poll_table_struct___53;

struct vm_area_struct___76;

struct inode___72;

struct file_lock___71;

struct page___76;

struct pipe_inode_info___31;

struct file_operations___71 {
	struct module___69 *owner;
	loff_t (*llseek)(struct file___71 *, loff_t, int);
	ssize_t (*read)(struct file___71 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___71 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___71 *, struct iov_iter___42 *);
	ssize_t (*write_iter)(struct kiocb___71 *, struct iov_iter___42 *);
	int (*iopoll)(struct kiocb___71 *, bool);
	int (*iterate)(struct file___71 *, struct dir_context *);
	int (*iterate_shared)(struct file___71 *, struct dir_context *);
	__poll_t (*poll)(struct file___71 *, struct poll_table_struct___53 *);
	long int (*unlocked_ioctl)(struct file___71 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___71 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___71 *, struct vm_area_struct___76 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___72 *, struct file___71 *);
	int (*flush)(struct file___71 *, fl_owner_t);
	int (*release)(struct inode___72 *, struct file___71 *);
	int (*fsync)(struct file___71 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___71 *, int);
	int (*lock)(struct file___71 *, int, struct file_lock___71 *);
	ssize_t (*sendpage)(struct file___71 *, struct page___76 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___71 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___71 *, long unsigned int);
	int (*flock)(struct file___71 *, int, struct file_lock___71 *);
	ssize_t (*splice_write)(struct pipe_inode_info___31 *, struct file___71 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___71 *, loff_t *, struct pipe_inode_info___31 *, size_t, unsigned int);
	int (*setlease)(struct file___71 *, long int, struct file_lock___71 **, void **);
	long int (*fallocate)(struct file___71 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___71 *);
	ssize_t (*copy_file_range)(struct file___71 *, loff_t, struct file___71 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___71 *, loff_t, struct file___71 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___71 *, loff_t, loff_t, int);
};

struct vmacache___76 {
	u64 seqnum;
	struct vm_area_struct___76 *vmas[4];
};

struct page_frag___76 {
	struct page___76 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___77;

struct pid___64;

struct nsproxy___69;

struct signal_struct___72;

struct vm_struct___72;

struct task_struct___78 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___78 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___77 *mm;
	struct mm_struct___77 *active_mm;
	struct vmacache___76 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___78 *real_parent;
	struct task_struct___78 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___78 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___64 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___69 *nsproxy;
	struct signal_struct___72 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___78 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___32 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___31 *splice_pipe;
	struct page_frag___76 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___78 *oom_reaper_list;
	struct vm_struct___72 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___44 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___71;

struct kobj_type___71;

struct kernfs_node___71;

struct kobject___71 {
	const char *name;
	struct list_head entry;
	struct kobject___71 *parent;
	struct kset___71 *kset;
	struct kobj_type___71 *ktype;
	struct kernfs_node___71 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___68 {
	struct kobject___71 kobj;
	struct module___69 *mod;
	struct kobject___71 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___68 {
	struct module___69 *mod;
	struct latch_tree_node node;
};

struct module_layout___68 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___68 mtn;
};

struct module_attribute___68;

struct kernel_param___68;

struct module___69 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___68 mkobj;
	struct module_attribute___68 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___71 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___68 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___68 core_layout;
	struct module_layout___68 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___64;

struct upid___64 {
	int nr;
	struct pid_namespace___64 *ns;
};

struct pid_namespace___64 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___78 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___64 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___64 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___64 numbers[1];
};

typedef struct page___76 *pgtable_t___76;

struct address_space___71;

struct dev_pagemap___70;

struct page___76 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___71 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___76 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___76 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___77 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___70 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___70;

struct vm_area_struct___76 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___76 *vm_next;
	struct vm_area_struct___76 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___77 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___70 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___71 *vm_file;
	struct file___71 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___72 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___78 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___78 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___64 *pids[4];
	struct pid___64 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___77 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___76;

struct mm_struct___77 {
	struct {
		struct vm_area_struct___76 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___71 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___76 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___78 *owner;
		struct user_namespace *user_ns;
		struct file___71 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___69 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___64 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___71;

struct pipe_buffer___31;

struct watch_queue___2;

struct pipe_inode_info___31 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___76 *tmp_page;
	struct fasync_struct___71 *fasync_readers;
	struct fasync_struct___71 *fasync_writers;
	struct pipe_buffer___31 *bufs;
	struct user_struct *user;
	struct watch_queue___2 *watch_queue;
};

struct vm_struct___72 {
	struct vm_struct___72 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___76 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___71;

struct address_space___71 {
	struct inode___72 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___71 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___70;

struct dev_pagemap___70 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___70 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___71;

struct path___71 {
	struct vfsmount___71 *mnt;
	struct dentry___72 *dentry;
};

struct fown_struct___64 {
	rwlock_t lock;
	struct pid___64 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___71 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___71 f_path;
	struct inode___72 *f_inode;
	const struct file_operations___71 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___64 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___71 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___70;

struct vm_operations_struct___70 {
	void (*open)(struct vm_area_struct___76 *);
	void (*close)(struct vm_area_struct___76 *);
	int (*may_split)(struct vm_area_struct___76 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___76 *);
	int (*mprotect)(struct vm_area_struct___76 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___70 *);
	vm_fault_t (*huge_fault)(struct vm_fault___70 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___70 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___76 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___70 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___70 *);
	int (*access)(struct vm_area_struct___76 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___76 *);
	int (*set_policy)(struct vm_area_struct___76 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___76 *, long unsigned int);
	struct page___76 * (*find_special_page)(struct vm_area_struct___76 *, long unsigned int);
};

struct core_thread___76 {
	struct task_struct___78 *task;
	struct core_thread___76 *next;
};

struct core_state___76 {
	atomic_t nr_threads;
	struct core_thread___76 dumper;
	struct completion startup;
};

struct vm_fault___70 {
	const struct {
		struct vm_area_struct___76 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___76 *cow_page;
	struct page___76 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___76 prealloc_pte;
};

struct dentry_operations___71;

struct dentry___72 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___72 *d_parent;
	struct qstr d_name;
	struct inode___72 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___71 *d_op;
	struct super_block___72 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___71;

struct inode___72 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___71 *i_op;
	struct super_block___72 *i_sb;
	struct address_space___71 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___71 *i_fop;
		void (*free_inode)(struct inode___72 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___71 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___31 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___71 {
	int (*d_revalidate)(struct dentry___72 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___72 *, unsigned int);
	int (*d_hash)(const struct dentry___72 *, struct qstr *);
	int (*d_compare)(const struct dentry___72 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___72 *);
	int (*d_init)(struct dentry___72 *);
	void (*d_release)(struct dentry___72 *);
	void (*d_prune)(struct dentry___72 *);
	void (*d_iput)(struct dentry___72 *, struct inode___72 *);
	char * (*d_dname)(struct dentry___72 *, char *, int);
	struct vfsmount___71 * (*d_automount)(struct path___71 *);
	int (*d_manage)(const struct path___71 *, bool);
	struct dentry___72 * (*d_real)(struct dentry___72 *, const struct inode___72 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___71;

struct mem_dqinfo___71 {
	struct quota_format_type___71 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___71;

struct quota_info___71 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___72 *files[3];
	struct mem_dqinfo___71 info[3];
	const struct quota_format_ops___71 *ops[3];
};

struct rcuwait___72 {
	struct task_struct___78 *task;
};

struct percpu_rw_semaphore___72 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___72 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___71 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___72 rw_sem[3];
};

struct super_operations___71;

struct dquot_operations___71;

struct quotactl_ops___71;

struct super_block___72 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___71 *s_type;
	const struct super_operations___71 *s_op;
	const struct dquot_operations___71 *dq_op;
	const struct quotactl_ops___71 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___72 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___71 s_dquot;
	struct sb_writers___71 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___71 *s_d_op;
	int cleancache_poolid;
	struct shrinker___29 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___71 {
	struct dentry___72 *mnt_root;
	struct super_block___72 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct watch;

struct watch_list {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch *);
	spinlock_t lock;
};

struct wait_page_queue___29;

struct kiocb___71 {
	struct file___71 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___71 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___29 *ki_waitq;
	};
};

struct iattr___72 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___71 *ia_file;
};

struct dquot___71 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___72 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___71 {
	int qf_fmt_id;
	const struct quota_format_ops___71 *qf_ops;
	struct module___69 *qf_owner;
	struct quota_format_type___71 *qf_next;
};

struct quota_format_ops___71 {
	int (*check_quota_file)(struct super_block___72 *, int);
	int (*read_file_info)(struct super_block___72 *, int);
	int (*write_file_info)(struct super_block___72 *, int);
	int (*free_file_info)(struct super_block___72 *, int);
	int (*read_dqblk)(struct dquot___71 *);
	int (*commit_dqblk)(struct dquot___71 *);
	int (*release_dqblk)(struct dquot___71 *);
	int (*get_next_id)(struct super_block___72 *, struct kqid *);
};

struct dquot_operations___71 {
	int (*write_dquot)(struct dquot___71 *);
	struct dquot___71 * (*alloc_dquot)(struct super_block___72 *, int);
	void (*destroy_dquot)(struct dquot___71 *);
	int (*acquire_dquot)(struct dquot___71 *);
	int (*release_dquot)(struct dquot___71 *);
	int (*mark_dirty)(struct dquot___71 *);
	int (*write_info)(struct super_block___72 *, int);
	qsize_t * (*get_reserved_space)(struct inode___72 *);
	int (*get_projid)(struct inode___72 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___72 *, qsize_t *);
	int (*get_next_id)(struct super_block___72 *, struct kqid *);
};

struct quotactl_ops___71 {
	int (*quota_on)(struct super_block___72 *, int, int, const struct path___71 *);
	int (*quota_off)(struct super_block___72 *, int);
	int (*quota_enable)(struct super_block___72 *, unsigned int);
	int (*quota_disable)(struct super_block___72 *, unsigned int);
	int (*quota_sync)(struct super_block___72 *, int);
	int (*set_info)(struct super_block___72 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___72 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___72 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___72 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___72 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___72 *, unsigned int);
};

struct wait_page_queue___29 {
	struct page___76 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___29;

struct address_space_operations___71 {
	int (*writepage)(struct page___76 *, struct writeback_control___3 *);
	int (*readpage)(struct file___71 *, struct page___76 *);
	int (*writepages)(struct address_space___71 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___76 *);
	int (*readpages)(struct file___71 *, struct address_space___71 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___29 *);
	int (*write_begin)(struct file___71 *, struct address_space___71 *, loff_t, unsigned int, unsigned int, struct page___76 **, void **);
	int (*write_end)(struct file___71 *, struct address_space___71 *, loff_t, unsigned int, unsigned int, struct page___76 *, void *);
	sector_t (*bmap)(struct address_space___71 *, sector_t);
	void (*invalidatepage)(struct page___76 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___76 *, gfp_t);
	void (*freepage)(struct page___76 *);
	ssize_t (*direct_IO)(struct kiocb___71 *, struct iov_iter___42 *);
	int (*migratepage)(struct address_space___71 *, struct page___76 *, struct page___76 *, enum migrate_mode);
	bool (*isolate_page)(struct page___76 *, isolate_mode_t);
	void (*putback_page)(struct page___76 *);
	int (*launder_page)(struct page___76 *);
	int (*is_partially_uptodate)(struct page___76 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___76 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___71 *, struct page___76 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___71 *, sector_t *);
	void (*swap_deactivate)(struct file___71 *);
};

struct readahead_control___29 {
	struct file___71 *file;
	struct address_space___71 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct iov_iter___42 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___31 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___71 {
	struct dentry___72 * (*lookup)(struct inode___72 *, struct dentry___72 *, unsigned int);
	const char * (*get_link)(struct dentry___72 *, struct inode___72 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___72 *, int);
	struct posix_acl * (*get_acl)(struct inode___72 *, int, bool);
	int (*readlink)(struct dentry___72 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___72 *, struct dentry___72 *, umode_t, bool);
	int (*link)(struct dentry___72 *, struct inode___72 *, struct dentry___72 *);
	int (*unlink)(struct inode___72 *, struct dentry___72 *);
	int (*symlink)(struct user_namespace *, struct inode___72 *, struct dentry___72 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___72 *, struct dentry___72 *, umode_t);
	int (*rmdir)(struct inode___72 *, struct dentry___72 *);
	int (*mknod)(struct user_namespace *, struct inode___72 *, struct dentry___72 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___72 *, struct dentry___72 *, struct inode___72 *, struct dentry___72 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___72 *, struct iattr___72 *);
	int (*getattr)(struct user_namespace *, const struct path___71 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___72 *, char *, size_t);
	int (*fiemap)(struct inode___72 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___72 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___72 *, struct dentry___72 *, struct file___71 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___72 *, struct dentry___72 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___72 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___72 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___72 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___71 {
	void (*fl_copy_lock)(struct file_lock___71 *, struct file_lock___71 *);
	void (*fl_release_private)(struct file_lock___71 *);
};

struct lock_manager_operations___71;

struct file_lock___71 {
	struct file_lock___71 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___71 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___71 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___71 *fl_ops;
	const struct lock_manager_operations___71 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___71 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___71 *);
	int (*lm_grant)(struct file_lock___71 *, int);
	bool (*lm_break)(struct file_lock___71 *);
	int (*lm_change)(struct file_lock___71 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___71 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___71 *);
};

struct fasync_struct___71 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___71 *fa_next;
	struct file___71 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___71 {
	struct inode___72 * (*alloc_inode)(struct super_block___72 *);
	void (*destroy_inode)(struct inode___72 *);
	void (*free_inode)(struct inode___72 *);
	void (*dirty_inode)(struct inode___72 *, int);
	int (*write_inode)(struct inode___72 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___72 *);
	void (*evict_inode)(struct inode___72 *);
	void (*put_super)(struct super_block___72 *);
	int (*sync_fs)(struct super_block___72 *, int);
	int (*freeze_super)(struct super_block___72 *);
	int (*freeze_fs)(struct super_block___72 *);
	int (*thaw_super)(struct super_block___72 *);
	int (*unfreeze_fs)(struct super_block___72 *);
	int (*statfs)(struct dentry___72 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___72 *, int *, char *);
	void (*umount_begin)(struct super_block___72 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___72 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___72 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___72 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___72 *);
	ssize_t (*quota_read)(struct super_block___72 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___72 *, int, const char *, size_t, loff_t);
	struct dquot___71 ** (*get_dquots)(struct inode___72 *);
	long int (*nr_cached_objects)(struct super_block___72 *, struct shrink_control___29 *);
	long int (*free_cached_objects)(struct super_block___72 *, struct shrink_control___29 *);
	struct file___71 * (*real_loop)(struct file___71 *);
};

typedef void (*poll_queue_proc___53)(struct file___71 *, wait_queue_head_t *, struct poll_table_struct___53 *);

struct poll_table_struct___53 {
	poll_queue_proc___53 _qproc;
	__poll_t _key;
};

struct kernfs_root___71;

struct kernfs_elem_dir___71 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___71 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___71;

struct kernfs_root___71 {
	struct kernfs_node___71 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___71 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___71 {
	struct kernfs_node___71 *target_kn;
};

struct kernfs_ops___71;

struct kernfs_elem_attr___71 {
	const struct kernfs_ops___71 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___71 *notify_next;
};

struct kernfs_node___71 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___71 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___71 dir;
		struct kernfs_elem_symlink___71 symlink;
		struct kernfs_elem_attr___71 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___71;

struct kernfs_ops___71 {
	int (*open)(struct kernfs_open_file___71 *);
	void (*release)(struct kernfs_open_file___71 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___71 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___71 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___71 *, struct poll_table_struct___53 *);
	int (*mmap)(struct kernfs_open_file___71 *, struct vm_area_struct___76 *);
};

struct kernfs_syscall_ops___71 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___71 *);
	int (*mkdir)(struct kernfs_node___71 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___71 *);
	int (*rename)(struct kernfs_node___71 *, struct kernfs_node___71 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___71 *, struct kernfs_root___71 *);
};

struct kernfs_open_file___71 {
	struct kernfs_node___71 *kn;
	struct file___71 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___70 *vm_ops;
};

struct bin_attribute___71;

struct attribute_group___71 {
	const char *name;
	umode_t (*is_visible)(struct kobject___71 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___71 *, struct bin_attribute___71 *, int);
	struct attribute **attrs;
	struct bin_attribute___71 **bin_attrs;
};

struct bin_attribute___71 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___71 * (*f_mapping)();
	ssize_t (*read)(struct file___71 *, struct kobject___71 *, struct bin_attribute___71 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___71 *, struct kobject___71 *, struct bin_attribute___71 *, char *, loff_t, size_t);
	int (*mmap)(struct file___71 *, struct kobject___71 *, struct bin_attribute___71 *, struct vm_area_struct___76 *);
};

struct sysfs_ops___71 {
	ssize_t (*show)(struct kobject___71 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___71 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___71;

struct kset___71 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___71 kobj;
	const struct kset_uevent_ops___71 *uevent_ops;
};

struct kobj_type___71 {
	void (*release)(struct kobject___71 *);
	const struct sysfs_ops___71 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___71 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___71 *);
	const void * (*namespace)(struct kobject___71 *);
	void (*get_ownership)(struct kobject___71 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___71 {
	int (* const filter)(struct kset___71 *, struct kobject___71 *);
	const char * (* const name)(struct kset___71 *, struct kobject___71 *);
	int (* const uevent)(struct kset___71 *, struct kobject___71 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___68 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___68 *);
	int (*get)(char *, const struct kernel_param___68 *);
	void (*free)(void *);
};

struct kparam_array___68;

struct kernel_param___68 {
	const char *name;
	struct module___69 *mod;
	const struct kernel_param_ops___68 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___68 *arr;
	};
};

struct kparam_array___68 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___68 *ops;
	void *elem;
};

struct module_attribute___68 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___68 *, struct module_kobject___68 *, char *);
	ssize_t (*store)(struct module_attribute___68 *, struct module_kobject___68 *, const char *, size_t);
	void (*setup)(struct module___69 *, const char *);
	int (*test)(struct module___69 *);
	void (*free)(struct module___69 *);
};

struct dev_pagemap_ops___70 {
	void (*page_free)(struct page___76 *);
	void (*kill)(struct dev_pagemap___70 *);
	void (*cleanup)(struct dev_pagemap___70 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___70 *);
};

struct fd___10 {
	struct file___71 *file;
	unsigned int flags;
};

enum watch_notification_type {
	WATCH_TYPE_META = 0,
	WATCH_TYPE_KEY_NOTIFY = 1,
	WATCH_TYPE__NR = 2,
};

enum watch_meta_notification_subtype {
	WATCH_META_REMOVAL_NOTIFICATION = 0,
	WATCH_META_LOSS_NOTIFICATION = 1,
};

struct watch_notification___2 {
	__u32 type: 24;
	__u32 subtype: 8;
	__u32 info;
};

struct watch_notification_type_filter {
	__u32 type;
	__u32 info_filter;
	__u32 info_mask;
	__u32 subtype_filter[8];
};

struct watch_notification_filter {
	__u32 nr_filters;
	__u32 __reserved;
	struct watch_notification_type_filter filters[0];
};

struct watch_notification_removal {
	struct watch_notification___2 watch;
	__u64 id;
};

struct watch_type_filter {
	enum watch_notification_type type;
	__u32 subtype_filter[1];
	__u32 info_filter;
	__u32 info_mask;
};

struct watch_filter {
	union {
		struct callback_head rcu;
		long unsigned int type_filter[1];
	};
	u32 nr_filters;
	struct watch_type_filter filters[0];
};

struct watch_queue___2 {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___31 *pipe;
	struct hlist_head watches;
	struct page___76 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

struct watch {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue___2 *queue;
	struct hlist_node queue_node;
	struct watch_list *watch_list;
	struct hlist_node list_node;
	const struct cred___11 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

struct pipe_buf_operations___31;

struct pipe_buffer___31 {
	struct page___76 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___31 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___31 {
	int (*confirm)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
	void (*release)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
	bool (*try_steal)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
	bool (*get)(struct pipe_inode_info___31 *, struct pipe_buffer___31 *);
};

struct pkcs7_message;

struct fs_context___11;

struct fs_parameter_spec___10;

struct dentry___73;

struct super_block___73;

struct module___70;

struct file_system_type___72 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___11 *);
	const struct fs_parameter_spec___10 *parameters;
	struct dentry___73 * (*mount)(struct file_system_type___72 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___73 *);
	struct module___70 *owner;
	struct file_system_type___72 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___72;

struct kiocb___72;

struct iov_iter___43;

struct poll_table_struct___54;

struct vm_area_struct___77;

struct inode___73;

struct file_lock___72;

struct page___77;

struct seq_file___69;

struct file_operations___72 {
	struct module___70 *owner;
	loff_t (*llseek)(struct file___72 *, loff_t, int);
	ssize_t (*read)(struct file___72 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___72 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___72 *, struct iov_iter___43 *);
	ssize_t (*write_iter)(struct kiocb___72 *, struct iov_iter___43 *);
	int (*iopoll)(struct kiocb___72 *, bool);
	int (*iterate)(struct file___72 *, struct dir_context *);
	int (*iterate_shared)(struct file___72 *, struct dir_context *);
	__poll_t (*poll)(struct file___72 *, struct poll_table_struct___54 *);
	long int (*unlocked_ioctl)(struct file___72 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___72 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___72 *, struct vm_area_struct___77 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___73 *, struct file___72 *);
	int (*flush)(struct file___72 *, fl_owner_t);
	int (*release)(struct inode___73 *, struct file___72 *);
	int (*fsync)(struct file___72 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___72 *, int);
	int (*lock)(struct file___72 *, int, struct file_lock___72 *);
	ssize_t (*sendpage)(struct file___72 *, struct page___77 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___72 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___72 *, long unsigned int);
	int (*flock)(struct file___72 *, int, struct file_lock___72 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___72 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___72 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___72 *, long int, struct file_lock___72 **, void **);
	long int (*fallocate)(struct file___72 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___69 *, struct file___72 *);
	ssize_t (*copy_file_range)(struct file___72 *, loff_t, struct file___72 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___72 *, loff_t, struct file___72 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___72 *, loff_t, loff_t, int);
};

struct vmacache___77 {
	u64 seqnum;
	struct vm_area_struct___77 *vmas[4];
};

struct page_frag___77 {
	struct page___77 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___45;

struct debug_info___45 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___45 *hbp_break[16];
	struct perf_event___45 *hbp_watch[16];
};

struct thread_struct___45 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___45 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___78;

struct pid___65;

struct nsproxy___70;

struct signal_struct___73;

struct bio_list___33;

struct backing_dev_info___32;

struct io_context___33;

struct capture_control___2;

struct css_set___60;

struct perf_event_context___45;

struct mem_cgroup___30;

struct request_queue___34;

struct vm_struct___73;

struct task_struct___79 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___79 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___78 *mm;
	struct mm_struct___78 *active_mm;
	struct vmacache___77 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___79 *real_parent;
	struct task_struct___79 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___79 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___65 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___70 *nsproxy;
	struct signal_struct___73 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___79 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___33 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___32 *backing_dev_info;
	struct io_context___33 *io_context;
	struct capture_control___2 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___60 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___45 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___77 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___30 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___30 *active_memcg;
	struct request_queue___34 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___79 *oom_reaper_list;
	struct vm_struct___73 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___45 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___72;

struct kobj_type___72;

struct kernfs_node___72;

struct kobject___72 {
	const char *name;
	struct list_head entry;
	struct kobject___72 *parent;
	struct kset___72 *kset;
	struct kobj_type___72 *ktype;
	struct kernfs_node___72 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___69 {
	struct kobject___72 kobj;
	struct module___70 *mod;
	struct kobject___72 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___69 {
	struct module___70 *mod;
	struct latch_tree_node node;
};

struct module_layout___69 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___69 mtn;
};

struct module_attribute___69;

struct kernel_param___69;

struct trace_event_call___39;

struct module___70 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___69 mkobj;
	struct module_attribute___69 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___72 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___69 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___69 core_layout;
	struct module_layout___69 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___39 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___45 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___79 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___45)(struct perf_event___45 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___45;

struct fasync_struct___72;

struct pid_namespace___65;

struct perf_cgroup___45;

struct perf_event___45 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___45 *group_leader;
	struct pmu___45 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___45 hw;
	struct perf_event_context___45 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___45 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___79 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___72 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___45 *aux_event;
	void (*destroy)(struct perf_event___45 *);
	struct callback_head callback_head;
	struct pid_namespace___65 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___45 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___45 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___39 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___45 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___72;

struct dentry___73 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___73 *d_parent;
	struct qstr d_name;
	struct inode___73 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___72 *d_op;
	struct super_block___73 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___72;

struct address_space___72 {
	struct inode___73 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___72 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___72;

struct bdi_writeback___32;

struct inode___73 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___72 *i_op;
	struct super_block___73 *i_sb;
	struct address_space___72 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___32 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___72 *i_fop;
		void (*free_inode)(struct inode___73 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___72 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___31 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___72;

struct path___72;

struct dentry_operations___72 {
	int (*d_revalidate)(struct dentry___73 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___73 *, unsigned int);
	int (*d_hash)(const struct dentry___73 *, struct qstr *);
	int (*d_compare)(const struct dentry___73 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___73 *);
	int (*d_init)(struct dentry___73 *);
	void (*d_release)(struct dentry___73 *);
	void (*d_prune)(struct dentry___73 *);
	void (*d_iput)(struct dentry___73 *, struct inode___73 *);
	char * (*d_dname)(struct dentry___73 *, char *, int);
	struct vfsmount___72 * (*d_automount)(struct path___72 *);
	int (*d_manage)(const struct path___72 *, bool);
	struct dentry___73 * (*d_real)(struct dentry___73 *, const struct inode___73 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___72;

struct mem_dqinfo___72 {
	struct quota_format_type___72 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___72;

struct quota_info___72 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___73 *files[3];
	struct mem_dqinfo___72 info[3];
	const struct quota_format_ops___72 *ops[3];
};

struct rcuwait___73 {
	struct task_struct___79 *task;
};

struct percpu_rw_semaphore___73 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___73 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___72 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___73 rw_sem[3];
};

struct shrink_control___30;

struct shrinker___30 {
	long unsigned int (*count_objects)(struct shrinker___30 *, struct shrink_control___30 *);
	long unsigned int (*scan_objects)(struct shrinker___30 *, struct shrink_control___30 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___72;

struct dquot_operations___72;

struct quotactl_ops___72;

struct export_operations___2;

struct xattr_handler___5;

struct block_device___34;

struct super_block___73 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___72 *s_type;
	const struct super_operations___72 *s_op;
	const struct dquot_operations___72 *dq_op;
	const struct quotactl_ops___72 *s_qcop;
	const struct export_operations___2 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___73 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___5 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___34 *s_bdev;
	struct backing_dev_info___32 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___72 s_dquot;
	struct sb_writers___72 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___72 *s_d_op;
	int cleancache_poolid;
	struct shrinker___30 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___72 {
	struct dentry___73 *mnt_root;
	struct super_block___73 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct path___72 {
	struct vfsmount___72 *mnt;
	struct dentry___73 *dentry;
};

struct upid___65 {
	int nr;
	struct pid_namespace___65 *ns;
};

struct pid_namespace___65 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___79 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___65 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___65 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___65 numbers[1];
};

typedef struct page___77 *pgtable_t___77;

struct dev_pagemap___71;

struct page___77 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___72 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___77 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___77 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___78 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___71 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___71;

struct vm_area_struct___77 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___77 *vm_next;
	struct vm_area_struct___77 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___78 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___71 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___72 *vm_file;
	struct file___72 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___73 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___79 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___79 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___65 *pids[4];
	struct pid___65 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___78 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___77;

struct mm_struct___78 {
	struct {
		struct vm_area_struct___77 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___72 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___77 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___79 *owner;
		struct user_namespace___12 *user_ns;
		struct file___72 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___60;

struct nsproxy___70 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___65 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___60 *cgroup_ns;
};

struct bio___33;

struct bio_list___33 {
	struct bio___33 *head;
	struct bio___33 *tail;
};

struct cgroup_subsys_state___60;

struct bdi_writeback___32 {
	struct backing_dev_info___32 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___60 *memcg_css;
	struct cgroup_subsys_state___60 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___64;

struct backing_dev_info___32 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___32 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___64 *dev;
	char dev_name[64];
	struct device___64 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___73 *debug_dir;
};

struct io_cq___33;

struct io_context___33 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___33 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___2;

struct capture_control___2 {
	struct compact_control___2 *cc;
	struct page___77 *page;
};

struct cgroup___60;

struct css_set___60 {
	struct cgroup_subsys_state___60 *subsys[14];
	refcount_t refcount;
	struct css_set___60 *dom_cset;
	struct cgroup___60 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___60 *mg_src_cgrp;
	struct cgroup___60 *mg_dst_cgrp;
	struct css_set___60 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___45 {
	struct pmu___45 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___79 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___45 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___60;

struct cgroup_subsys_state___60 {
	struct cgroup___60 *cgroup;
	struct cgroup_subsys___60 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___60 *parent;
};

struct cgroup_file___60 {
	struct kernfs_node___72 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___30;

struct mem_cgroup_per_node___30;

struct mem_cgroup___30 {
	struct cgroup_subsys_state___60 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___60 events_file;
	struct cgroup_file___60 events_local_file;
	struct cgroup_file___60 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___30 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___79 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___30 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___33;

struct blk_integrity___33 {
	const struct blk_integrity_profile___33 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___33 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___33 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___33;

struct elevator_queue___33;

struct blk_mq_ops___32;

struct blk_mq_hw_ctx___32;

struct gendisk___33;

struct blkcg_gq___32;

struct blk_mq_tag_set___32;

struct request_queue___34 {
	struct request___33 *last_merge;
	struct elevator_queue___33 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___32 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___32 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___33 *disk;
	struct kobject___72 kobj;
	struct kobject___72 *mq_kobj;
	struct blk_integrity___33 integrity;
	struct device___64 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___32 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___32 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___33 bio_split;
	struct dentry___73 *debugfs_dir;
	struct dentry___73 *sched_debugfs_dir;
	struct dentry___73 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___73 {
	struct vm_struct___73 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___77 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___30 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___30 *memcg;
};

struct dev_pagemap_ops___71;

struct dev_pagemap___71 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___71 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___65 {
	rwlock_t lock;
	struct pid___65 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___72 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___72 f_path;
	struct inode___73 *f_inode;
	const struct file_operations___72 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___65 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___72 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___71;

struct vm_operations_struct___71 {
	void (*open)(struct vm_area_struct___77 *);
	void (*close)(struct vm_area_struct___77 *);
	int (*may_split)(struct vm_area_struct___77 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___77 *);
	int (*mprotect)(struct vm_area_struct___77 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___71 *);
	vm_fault_t (*huge_fault)(struct vm_fault___71 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___71 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___77 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___71 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___71 *);
	int (*access)(struct vm_area_struct___77 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___77 *);
	int (*set_policy)(struct vm_area_struct___77 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___77 *, long unsigned int);
	struct page___77 * (*find_special_page)(struct vm_area_struct___77 *, long unsigned int);
};

struct core_thread___77 {
	struct task_struct___79 *task;
	struct core_thread___77 *next;
};

struct core_state___77 {
	atomic_t nr_threads;
	struct core_thread___77 dumper;
	struct completion startup;
};

struct vm_fault___71 {
	const struct {
		struct vm_area_struct___77 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___77 *cow_page;
	struct page___77 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___77 prealloc_pte;
};

struct pglist_data___31;

struct lruvec___31 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___31 *pgdat;
};

struct zone___31 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___31 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___31 {
	struct zone___31 *zone;
	int zone_idx;
};

struct zonelist___31 {
	struct zoneref___31 _zonerefs[321];
};

struct pglist_data___31 {
	struct zone___31 node_zones[5];
	struct zonelist___31 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___79 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___79 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___31 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___60 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___79 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___60;

struct cgroup_rstat_cpu___60;

struct cgroup___60 {
	struct cgroup_subsys_state___60 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___72 *kn;
	struct cgroup_file___60 procs_file;
	struct cgroup_file___60 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___60 *subsys[14];
	struct cgroup_root___60 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___60 *dom_cgrp;
	struct cgroup___60 *old_dom_cgrp;
	struct cgroup_rstat_cpu___60 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___60 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___33 {
	struct request_queue___34 *q;
	struct io_context___33 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

typedef int __kernel_rwf_t;

struct wait_page_queue___30;

struct kiocb___72 {
	struct file___72 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___72 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___30 *ki_waitq;
	};
};

struct iattr___73 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___72 *ia_file;
};

struct dquot___72 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___73 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___72 {
	int qf_fmt_id;
	const struct quota_format_ops___72 *qf_ops;
	struct module___70 *qf_owner;
	struct quota_format_type___72 *qf_next;
};

struct quota_format_ops___72 {
	int (*check_quota_file)(struct super_block___73 *, int);
	int (*read_file_info)(struct super_block___73 *, int);
	int (*write_file_info)(struct super_block___73 *, int);
	int (*free_file_info)(struct super_block___73 *, int);
	int (*read_dqblk)(struct dquot___72 *);
	int (*commit_dqblk)(struct dquot___72 *);
	int (*release_dqblk)(struct dquot___72 *);
	int (*get_next_id)(struct super_block___73 *, struct kqid *);
};

struct dquot_operations___72 {
	int (*write_dquot)(struct dquot___72 *);
	struct dquot___72 * (*alloc_dquot)(struct super_block___73 *, int);
	void (*destroy_dquot)(struct dquot___72 *);
	int (*acquire_dquot)(struct dquot___72 *);
	int (*release_dquot)(struct dquot___72 *);
	int (*mark_dirty)(struct dquot___72 *);
	int (*write_info)(struct super_block___73 *, int);
	qsize_t * (*get_reserved_space)(struct inode___73 *);
	int (*get_projid)(struct inode___73 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___73 *, qsize_t *);
	int (*get_next_id)(struct super_block___73 *, struct kqid *);
};

struct quotactl_ops___72 {
	int (*quota_on)(struct super_block___73 *, int, int, const struct path___72 *);
	int (*quota_off)(struct super_block___73 *, int);
	int (*quota_enable)(struct super_block___73 *, unsigned int);
	int (*quota_disable)(struct super_block___73 *, unsigned int);
	int (*quota_sync)(struct super_block___73 *, int);
	int (*set_info)(struct super_block___73 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___73 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___73 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___73 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___73 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___73 *, unsigned int);
};

enum positive_aop_returns {
	AOP_WRITEPAGE_ACTIVATE = 524288,
	AOP_TRUNCATED_PAGE = 524289,
};

struct wait_page_queue___30 {
	struct page___77 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___32;

struct readahead_control___30;

struct swap_info_struct___18;

struct address_space_operations___72 {
	int (*writepage)(struct page___77 *, struct writeback_control___32 *);
	int (*readpage)(struct file___72 *, struct page___77 *);
	int (*writepages)(struct address_space___72 *, struct writeback_control___32 *);
	int (*set_page_dirty)(struct page___77 *);
	int (*readpages)(struct file___72 *, struct address_space___72 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___30 *);
	int (*write_begin)(struct file___72 *, struct address_space___72 *, loff_t, unsigned int, unsigned int, struct page___77 **, void **);
	int (*write_end)(struct file___72 *, struct address_space___72 *, loff_t, unsigned int, unsigned int, struct page___77 *, void *);
	sector_t (*bmap)(struct address_space___72 *, sector_t);
	void (*invalidatepage)(struct page___77 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___77 *, gfp_t);
	void (*freepage)(struct page___77 *);
	ssize_t (*direct_IO)(struct kiocb___72 *, struct iov_iter___43 *);
	int (*migratepage)(struct address_space___72 *, struct page___77 *, struct page___77 *, enum migrate_mode);
	bool (*isolate_page)(struct page___77 *, isolate_mode_t);
	void (*putback_page)(struct page___77 *);
	int (*launder_page)(struct page___77 *);
	int (*is_partially_uptodate)(struct page___77 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___77 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___72 *, struct page___77 *);
	int (*swap_activate)(struct swap_info_struct___18 *, struct file___72 *, sector_t *);
	void (*swap_deactivate)(struct file___72 *);
};

struct writeback_control___32 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___32 *wb;
	struct inode___73 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___30 {
	struct file___72 *file;
	struct address_space___72 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___42;

struct iov_iter___43 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___42 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___18 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___34 *bdev;
	struct file___72 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___72 {
	struct dentry___73 * (*lookup)(struct inode___73 *, struct dentry___73 *, unsigned int);
	const char * (*get_link)(struct dentry___73 *, struct inode___73 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___73 *, int);
	struct posix_acl * (*get_acl)(struct inode___73 *, int, bool);
	int (*readlink)(struct dentry___73 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___73 *, struct dentry___73 *, umode_t, bool);
	int (*link)(struct dentry___73 *, struct inode___73 *, struct dentry___73 *);
	int (*unlink)(struct inode___73 *, struct dentry___73 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___73 *, struct dentry___73 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___73 *, struct dentry___73 *, umode_t);
	int (*rmdir)(struct inode___73 *, struct dentry___73 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___73 *, struct dentry___73 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___73 *, struct dentry___73 *, struct inode___73 *, struct dentry___73 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___73 *, struct iattr___73 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___72 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___73 *, char *, size_t);
	int (*fiemap)(struct inode___73 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___73 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___73 *, struct dentry___73 *, struct file___72 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___73 *, struct dentry___73 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___73 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___73 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___73 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___72 {
	void (*fl_copy_lock)(struct file_lock___72 *, struct file_lock___72 *);
	void (*fl_release_private)(struct file_lock___72 *);
};

struct lock_manager_operations___72;

struct file_lock___72 {
	struct file_lock___72 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___72 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___72 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___72 *fl_ops;
	const struct lock_manager_operations___72 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___72 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___72 *);
	int (*lm_grant)(struct file_lock___72 *, int);
	bool (*lm_break)(struct file_lock___72 *);
	int (*lm_change)(struct file_lock___72 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___72 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___72 *);
};

struct fasync_struct___72 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___72 *fa_next;
	struct file___72 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___72 {
	struct inode___73 * (*alloc_inode)(struct super_block___73 *);
	void (*destroy_inode)(struct inode___73 *);
	void (*free_inode)(struct inode___73 *);
	void (*dirty_inode)(struct inode___73 *, int);
	int (*write_inode)(struct inode___73 *, struct writeback_control___32 *);
	int (*drop_inode)(struct inode___73 *);
	void (*evict_inode)(struct inode___73 *);
	void (*put_super)(struct super_block___73 *);
	int (*sync_fs)(struct super_block___73 *, int);
	int (*freeze_super)(struct super_block___73 *);
	int (*freeze_fs)(struct super_block___73 *);
	int (*thaw_super)(struct super_block___73 *);
	int (*unfreeze_fs)(struct super_block___73 *);
	int (*statfs)(struct dentry___73 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___73 *, int *, char *);
	void (*umount_begin)(struct super_block___73 *);
	int (*show_options)(struct seq_file___69 *, struct dentry___73 *);
	int (*show_devname)(struct seq_file___69 *, struct dentry___73 *);
	int (*show_path)(struct seq_file___69 *, struct dentry___73 *);
	int (*show_stats)(struct seq_file___69 *, struct dentry___73 *);
	ssize_t (*quota_read)(struct super_block___73 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___73 *, int, const char *, size_t, loff_t);
	struct dquot___72 ** (*get_dquots)(struct inode___73 *);
	long int (*nr_cached_objects)(struct super_block___73 *, struct shrink_control___30 *);
	long int (*free_cached_objects)(struct super_block___73 *, struct shrink_control___30 *);
	struct file___72 * (*real_loop)(struct file___72 *);
};

struct export_operations___2 {
	int (*encode_fh)(struct inode___73 *, __u32 *, int *, struct inode___73 *);
	struct dentry___73 * (*fh_to_dentry)(struct super_block___73 *, struct fid *, int, int);
	struct dentry___73 * (*fh_to_parent)(struct super_block___73 *, struct fid *, int, int);
	int (*get_name)(struct dentry___73 *, char *, struct dentry___73 *);
	struct dentry___73 * (*get_parent)(struct dentry___73 *);
	int (*commit_metadata)(struct inode___73 *);
	int (*get_uuid)(struct super_block___73 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___73 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___73 *, struct iomap *, int, struct iattr___73 *);
	u64 (*fetch_iversion)(struct inode___73 *);
	long unsigned int flags;
};

struct xattr_handler___5 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___73 *);
	int (*get)(const struct xattr_handler___5 *, struct dentry___73 *, struct inode___73 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___5 *, struct user_namespace___12 *, struct dentry___73 *, struct inode___73 *, const char *, const void *, size_t, int);
};

struct wakeup_source___64;

struct dev_pm_info___64 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___64 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___64 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___64;

struct bus_type___64;

struct device_driver___64;

struct dev_pm_domain___64;

struct fwnode_handle___64;

struct class___64;

struct attribute_group___72;

struct device___64 {
	struct kobject___72 kobj;
	struct device___64 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___64 *type;
	struct bus_type___64 *bus;
	struct device_driver___64 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___64 power;
	struct dev_pm_domain___64 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___64 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___64 *class;
	const struct attribute_group___72 **groups;
	void (*release)(struct device___64 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___34 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___73 *bd_inode;
	struct super_block___73 *bd_super;
	void *bd_claiming;
	struct device___64 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___72 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___33 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___73 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___54)(struct file___72 *, wait_queue_head_t *, struct poll_table_struct___54 *);

struct poll_table_struct___54 {
	poll_queue_proc___54 _qproc;
	__poll_t _key;
};

struct seq_operations___69;

struct seq_file___69 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___69 *op;
	int poll_event;
	const struct file___72 *file;
	void *private;
};

struct fc_log___11;

struct p_log___11 {
	const char *prefix;
	struct fc_log___11 *log;
};

struct fs_context_operations___11;

struct fs_context___11 {
	const struct fs_context_operations___11 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___72 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___73 *root;
	struct user_namespace___12 *user_ns;
	struct net *net_ns;
	const struct cred___11 *cred;
	struct p_log___11 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___11;

typedef int fs_param_type___10(struct p_log___11 *, const struct fs_parameter_spec___10 *, struct fs_parameter___11 *, struct fs_parse_result *);

struct fs_parameter_spec___10 {
	const char *name;
	fs_param_type___10 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___33(struct bio___33 *);

struct bio_vec___42 {
	struct page___77 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___33;

struct bio___33 {
	struct bio___33 *bi_next;
	struct block_device___34 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___33 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___32 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___33 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___42 *bi_io_vec;
	struct bio_set___33 *bi_pool;
	struct bio_vec___42 bi_inline_vecs[0];
};

struct dev_pagemap_ops___71 {
	void (*page_free)(struct page___77 *);
	void (*kill)(struct dev_pagemap___71 *);
	void (*cleanup)(struct dev_pagemap___71 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___71 *);
};

struct vm_event_state {
	long unsigned int event[99];
};

struct bin_attribute___72;

struct attribute_group___72 {
	const char *name;
	umode_t (*is_visible)(struct kobject___72 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___72 *, struct bin_attribute___72 *, int);
	struct attribute **attrs;
	struct bin_attribute___72 **bin_attrs;
};

struct fwnode_operations___64;

struct fwnode_handle___64 {
	struct fwnode_handle___64 *secondary;
	const struct fwnode_operations___64 *ops;
	struct device___64 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___64;

struct fwnode_endpoint___64;

struct fwnode_operations___64 {
	struct fwnode_handle___64 * (*get)(struct fwnode_handle___64 *);
	void (*put)(struct fwnode_handle___64 *);
	bool (*device_is_available)(const struct fwnode_handle___64 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___64 *, const struct device___64 *);
	bool (*property_present)(const struct fwnode_handle___64 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___64 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___64 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___64 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*get_parent)(const struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*get_next_child_node)(const struct fwnode_handle___64 *, struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*get_named_child_node)(const struct fwnode_handle___64 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___64 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___64 *);
	struct fwnode_handle___64 * (*graph_get_next_endpoint)(const struct fwnode_handle___64 *, struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*graph_get_remote_endpoint)(const struct fwnode_handle___64 *);
	struct fwnode_handle___64 * (*graph_get_port_parent)(struct fwnode_handle___64 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___64 *, struct fwnode_endpoint___64 *);
	int (*add_links)(struct fwnode_handle___64 *);
};

struct fwnode_endpoint___64 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___64 *local_fwnode;
};

struct fwnode_reference_args___64 {
	struct fwnode_handle___64 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___72;

struct kernfs_elem_dir___72 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___72 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___72;

struct kernfs_root___72 {
	struct kernfs_node___72 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___72 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___72 {
	struct kernfs_node___72 *target_kn;
};

struct kernfs_ops___72;

struct kernfs_elem_attr___72 {
	const struct kernfs_ops___72 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___72 *notify_next;
};

struct kernfs_node___72 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___72 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___72 dir;
		struct kernfs_elem_symlink___72 symlink;
		struct kernfs_elem_attr___72 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___72;

struct kernfs_ops___72 {
	int (*open)(struct kernfs_open_file___72 *);
	void (*release)(struct kernfs_open_file___72 *);
	int (*seq_show)(struct seq_file___69 *, void *);
	void * (*seq_start)(struct seq_file___69 *, loff_t *);
	void * (*seq_next)(struct seq_file___69 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___69 *, void *);
	ssize_t (*read)(struct kernfs_open_file___72 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___72 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___72 *, struct poll_table_struct___54 *);
	int (*mmap)(struct kernfs_open_file___72 *, struct vm_area_struct___77 *);
};

struct kernfs_syscall_ops___72 {
	int (*show_options)(struct seq_file___69 *, struct kernfs_root___72 *);
	int (*mkdir)(struct kernfs_node___72 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___72 *);
	int (*rename)(struct kernfs_node___72 *, struct kernfs_node___72 *, const char *);
	int (*show_path)(struct seq_file___69 *, struct kernfs_node___72 *, struct kernfs_root___72 *);
};

struct kernfs_open_file___72 {
	struct kernfs_node___72 *kn;
	struct file___72 *file;
	struct seq_file___69 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___71 *vm_ops;
};

struct bin_attribute___72 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___72 * (*f_mapping)();
	ssize_t (*read)(struct file___72 *, struct kobject___72 *, struct bin_attribute___72 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___72 *, struct kobject___72 *, struct bin_attribute___72 *, char *, loff_t, size_t);
	int (*mmap)(struct file___72 *, struct kobject___72 *, struct bin_attribute___72 *, struct vm_area_struct___77 *);
};

struct sysfs_ops___72 {
	ssize_t (*show)(struct kobject___72 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___72 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___72;

struct kset___72 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___72 kobj;
	const struct kset_uevent_ops___72 *uevent_ops;
};

struct kobj_type___72 {
	void (*release)(struct kobject___72 *);
	const struct sysfs_ops___72 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___72 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___72 *);
	const void * (*namespace)(struct kobject___72 *);
	void (*get_ownership)(struct kobject___72 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___72 {
	int (* const filter)(struct kset___72 *, struct kobject___72 *);
	const char * (* const name)(struct kset___72 *, struct kobject___72 *);
	int (* const uevent)(struct kset___72 *, struct kobject___72 *, struct kobj_uevent_env *);
};

struct seq_operations___69 {
	void * (*start)(struct seq_file___69 *, loff_t *);
	void (*stop)(struct seq_file___69 *, void *);
	void * (*next)(struct seq_file___69 *, void *, loff_t *);
	int (*show)(struct seq_file___69 *, void *);
};

struct cgroup_namespace___60 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___60 *root_cset;
};

struct kernel_param_ops___69 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___69 *);
	int (*get)(char *, const struct kernel_param___69 *);
	void (*free)(void *);
};

struct kparam_array___69;

struct kernel_param___69 {
	const char *name;
	struct module___70 *mod;
	const struct kernel_param_ops___69 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___69 *arr;
	};
};

struct kparam_array___69 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___69 *ops;
	void *elem;
};

struct module_attribute___69 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___69 *, struct module_kobject___69 *, char *);
	ssize_t (*store)(struct module_attribute___69 *, struct module_kobject___69 *, const char *, size_t);
	void (*setup)(struct module___70 *, const char *);
	int (*test)(struct module___70 *);
	void (*free)(struct module___70 *);
};

struct trace_event_class___39;

struct trace_event_call___39 {
	struct list_head list;
	struct trace_event_class___39 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___39 *, struct perf_event___45 *);
};

struct cftype___60;

struct cgroup_subsys___60 {
	struct cgroup_subsys_state___60 * (*css_alloc)(struct cgroup_subsys_state___60 *);
	int (*css_online)(struct cgroup_subsys_state___60 *);
	void (*css_offline)(struct cgroup_subsys_state___60 *);
	void (*css_released)(struct cgroup_subsys_state___60 *);
	void (*css_free)(struct cgroup_subsys_state___60 *);
	void (*css_reset)(struct cgroup_subsys_state___60 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___60 *, int);
	int (*css_extra_stat_show)(struct seq_file___69 *, struct cgroup_subsys_state___60 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___79 *, struct css_set___60 *);
	void (*cancel_fork)(struct task_struct___79 *, struct css_set___60 *);
	void (*fork)(struct task_struct___79 *);
	void (*exit)(struct task_struct___79 *);
	void (*release)(struct task_struct___79 *);
	void (*bind)(struct cgroup_subsys_state___60 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___60 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___60 *dfl_cftypes;
	struct cftype___60 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___60 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___60 *updated_children;
	struct cgroup___60 *updated_next;
};

struct cgroup_root___60 {
	struct kernfs_root___72 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___60 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___60 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___60 *ss;
	struct list_head node;
	struct kernfs_ops___72 *kf_ops;
	int (*open)(struct kernfs_open_file___72 *);
	void (*release)(struct kernfs_open_file___72 *);
	u64 (*read_u64)(struct cgroup_subsys_state___60 *, struct cftype___60 *);
	s64 (*read_s64)(struct cgroup_subsys_state___60 *, struct cftype___60 *);
	int (*seq_show)(struct seq_file___69 *, void *);
	void * (*seq_start)(struct seq_file___69 *, loff_t *);
	void * (*seq_next)(struct seq_file___69 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___69 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___60 *, struct cftype___60 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___60 *, struct cftype___60 *, s64);
	ssize_t (*write)(struct kernfs_open_file___72 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___72 *, struct poll_table_struct___54 *);
};

enum iter_type {
	ITER_IOVEC = 0,
	ITER_KVEC = 1,
	ITER_BVEC = 2,
	ITER_PIPE = 3,
	ITER_XARRAY = 4,
	ITER_DISCARD = 5,
};

struct dev_pm_ops___64 {
	int (*prepare)(struct device___64 *);
	void (*complete)(struct device___64 *);
	int (*suspend)(struct device___64 *);
	int (*resume)(struct device___64 *);
	int (*freeze)(struct device___64 *);
	int (*thaw)(struct device___64 *);
	int (*poweroff)(struct device___64 *);
	int (*restore)(struct device___64 *);
	int (*suspend_late)(struct device___64 *);
	int (*resume_early)(struct device___64 *);
	int (*freeze_late)(struct device___64 *);
	int (*thaw_early)(struct device___64 *);
	int (*poweroff_late)(struct device___64 *);
	int (*restore_early)(struct device___64 *);
	int (*suspend_noirq)(struct device___64 *);
	int (*resume_noirq)(struct device___64 *);
	int (*freeze_noirq)(struct device___64 *);
	int (*thaw_noirq)(struct device___64 *);
	int (*poweroff_noirq)(struct device___64 *);
	int (*restore_noirq)(struct device___64 *);
	int (*runtime_suspend)(struct device___64 *);
	int (*runtime_resume)(struct device___64 *);
	int (*runtime_idle)(struct device___64 *);
};

struct wakeup_source___64 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___64 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___64 {
	struct dev_pm_ops___64 ops;
	int (*start)(struct device___64 *);
	void (*detach)(struct device___64 *, bool);
	int (*activate)(struct device___64 *);
	void (*sync)(struct device___64 *);
	void (*dismiss)(struct device___64 *);
};

struct bus_type___64 {
	const char *name;
	const char *dev_name;
	struct device___64 *dev_root;
	const struct attribute_group___72 **bus_groups;
	const struct attribute_group___72 **dev_groups;
	const struct attribute_group___72 **drv_groups;
	int (*match)(struct device___64 *, struct device_driver___64 *);
	int (*uevent)(struct device___64 *, struct kobj_uevent_env *);
	int (*probe)(struct device___64 *);
	void (*sync_state)(struct device___64 *);
	void (*remove)(struct device___64 *);
	void (*shutdown)(struct device___64 *);
	int (*online)(struct device___64 *);
	int (*offline)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	int (*num_vf)(struct device___64 *);
	int (*dma_configure)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___64 {
	const char *name;
	struct bus_type___64 *bus;
	struct module___70 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___64 *);
	void (*sync_state)(struct device___64 *);
	int (*remove)(struct device___64 *);
	void (*shutdown)(struct device___64 *);
	int (*suspend)(struct device___64 *, pm_message_t);
	int (*resume)(struct device___64 *);
	const struct attribute_group___72 **groups;
	const struct attribute_group___72 **dev_groups;
	const struct dev_pm_ops___64 *pm;
	void (*coredump)(struct device___64 *);
	struct driver_private *p;
};

struct device_type___64 {
	const char *name;
	const struct attribute_group___72 **groups;
	int (*uevent)(struct device___64 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___64 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___64 *);
	const struct dev_pm_ops___64 *pm;
};

struct class___64 {
	const char *name;
	struct module___70 *owner;
	const struct attribute_group___72 **class_groups;
	const struct attribute_group___72 **dev_groups;
	struct kobject___72 *dev_kobj;
	int (*dev_uevent)(struct device___64 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___64 *, umode_t *);
	void (*class_release)(struct class___64 *);
	void (*dev_release)(struct device___64 *);
	int (*shutdown_pre)(struct device___64 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___64 *);
	void (*get_ownership)(struct device___64 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___64 *pm;
	struct subsys_private *p;
};

struct block_device_operations___33;

struct gendisk___33 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___34 *part0;
	const struct block_device_operations___33 *fops;
	struct request_queue___34 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___32 *bdi;
	struct kobject___72 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___72 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___33 {
	struct bio___33 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___42 *bip_vec;
	struct bio_vec___42 bip_inline_vecs[0];
};

struct blkcg___32;

struct blkg_policy_data___32;

struct blkcg_gq___32 {
	struct request_queue___34 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___32 *blkcg;
	struct blkcg_gq___32 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___32 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___33 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___33(struct request___33 *);

typedef void integrity_complete_fn___33(struct request___33 *, unsigned int);

struct blk_integrity_profile___33 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___33 *prepare_fn;
	integrity_complete_fn___33 *complete_fn;
	const char *name;
};

struct block_device_operations___33 {
	blk_qc_t (*submit_bio)(struct bio___33 *);
	int (*open)(struct block_device___34 *, fmode_t);
	void (*release)(struct gendisk___33 *, fmode_t);
	int (*rw_page)(struct block_device___34 *, sector_t, struct page___77 *, unsigned int);
	int (*ioctl)(struct block_device___34 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___34 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___33 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___33 *);
	int (*getgeo)(struct block_device___34 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___34 *, bool);
	void (*swap_slot_free_notify)(struct block_device___34 *, long unsigned int);
	int (*report_zones)(struct gendisk___33 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___33 *, umode_t *);
	struct module___70 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___33 *, sector_t *);
};

typedef void rq_end_io_fn___33(struct request___33 *, blk_status_t);

struct request___33 {
	struct request_queue___34 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___32 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___33 *bio;
	struct bio___33 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___42 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___33 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___33 *saved_end_io;
		} flush;
	};
	struct gendisk___33 *rq_disk;
	struct block_device___34 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___33 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___32 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___34 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___72 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___73 *debugfs_dir;
	struct dentry___73 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___33;

struct elevator_mq_ops___33 {
	int (*init_sched)(struct request_queue___34 *, struct elevator_type___33 *);
	void (*exit_sched)(struct elevator_queue___33 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___32 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___32 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___32 *);
	bool (*allow_merge)(struct request_queue___34 *, struct request___33 *, struct bio___33 *);
	bool (*bio_merge)(struct request_queue___34 *, struct bio___33 *, unsigned int);
	int (*request_merge)(struct request_queue___34 *, struct request___33 **, struct bio___33 *);
	void (*request_merged)(struct request_queue___34 *, struct request___33 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___34 *, struct request___33 *, struct request___33 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___33 *);
	void (*finish_request)(struct request___33 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___32 *, struct list_head *, bool);
	struct request___33 * (*dispatch_request)(struct blk_mq_hw_ctx___32 *);
	bool (*has_work)(struct blk_mq_hw_ctx___32 *);
	void (*completed_request)(struct request___33 *, u64);
	void (*requeue_request)(struct request___33 *);
	struct request___33 * (*former_request)(struct request_queue___34 *, struct request___33 *);
	struct request___33 * (*next_request)(struct request_queue___34 *, struct request___33 *);
	void (*init_icq)(struct io_cq___33 *);
	void (*exit_icq)(struct io_cq___33 *);
};

struct elv_fs_entry___33;

struct elevator_type___33 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___33 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___33 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___70 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___33 {
	struct elevator_type___33 *type;
	void *elevator_data;
	struct kobject___72 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___33 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___33 *, char *);
	ssize_t (*store)(struct elevator_queue___33 *, const char *, size_t);
};

struct blk_mq_queue_data___32;

struct blk_mq_ops___32 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___32 *, const struct blk_mq_queue_data___32 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___32 *);
	int (*get_budget)(struct request_queue___34 *);
	void (*put_budget)(struct request_queue___34 *, int);
	void (*set_rq_budget_token)(struct request___33 *, int);
	int (*get_rq_budget_token)(struct request___33 *);
	enum blk_eh_timer_return (*timeout)(struct request___33 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___32 *);
	void (*complete)(struct request___33 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___32 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___32 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___32 *, struct request___33 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___32 *, struct request___33 *, unsigned int);
	void (*initialize_rq_fn)(struct request___33 *);
	void (*cleanup_rq)(struct request___33 *);
	bool (*busy)(struct request_queue___34 *);
	int (*map_queues)(struct blk_mq_tag_set___32 *);
	void (*show_rq)(struct seq_file___69 *, struct request___33 *);
};

struct blk_mq_tag_set___32 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___32 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___32 {
	struct request___33 *rq;
	bool last;
};

struct blkcg_policy_data___32;

struct blkcg___32 {
	struct cgroup_subsys_state___60 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___32 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___32 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___32 {
	struct blkcg___32 *blkcg;
	int plid;
};

struct blkg_policy_data___32 {
	struct blkcg_gq___32 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___30 {
	struct mem_cgroup___30 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___30 {
	struct lruvec___31 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___30 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___30 *memcg;
};

struct obj_cgroup___30 {
	struct percpu_ref refcnt;
	struct mem_cgroup___30 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum mapping_flags {
	AS_EIO = 0,
	AS_ENOSPC = 1,
	AS_MM_ALL_LOCKS = 2,
	AS_UNEVICTABLE = 3,
	AS_EXITING = 4,
	AS_NO_WRITEBACK_TAGS = 5,
	AS_THP_SUPPORT = 6,
};

struct wait_page_key {
	struct page___77 *page;
	int bit_nr;
	int page_match;
};

struct pagevec {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___77 *pages[15];
};

struct fid {
	union {
		struct {
			u32 ino;
			u32 gen;
			u32 parent_ino;
			u32 parent_gen;
		} i32;
		struct {
			u32 block;
			u16 partref;
			u16 parent_partref;
			u32 generation;
			u32 parent_block;
			u32 parent_generation;
		} udf;
		__u32 raw[0];
	};
};

struct fs_parameter___11 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___72 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___11 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___70 *owner;
	char *buffer[8];
};

struct fs_context_operations___11 {
	void (*free)(struct fs_context___11 *);
	int (*dup)(struct fs_context___11 *, struct fs_context___11 *);
	int (*parse_param)(struct fs_context___11 *, struct fs_parameter___11 *);
	int (*parse_monolithic)(struct fs_context___11 *, void *);
	int (*get_tree)(struct fs_context___11 *);
	int (*reconfigure)(struct fs_context___11 *);
};

struct compact_control___2 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___31 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct perf_cpu_context___45;

struct perf_output_handle___45;

struct pmu___45 {
	struct list_head entry;
	struct module___70 *module;
	struct device___64 *dev;
	const struct attribute_group___72 **attr_groups;
	const struct attribute_group___72 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___45 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___45 *);
	void (*pmu_disable)(struct pmu___45 *);
	int (*event_init)(struct perf_event___45 *);
	void (*event_mapped)(struct perf_event___45 *, struct mm_struct___78 *);
	void (*event_unmapped)(struct perf_event___45 *, struct mm_struct___78 *);
	int (*add)(struct perf_event___45 *, int);
	void (*del)(struct perf_event___45 *, int);
	void (*start)(struct perf_event___45 *, int);
	void (*stop)(struct perf_event___45 *, int);
	void (*read)(struct perf_event___45 *);
	void (*start_txn)(struct pmu___45 *, unsigned int);
	int (*commit_txn)(struct pmu___45 *);
	void (*cancel_txn)(struct pmu___45 *);
	int (*event_idx)(struct perf_event___45 *);
	void (*sched_task)(struct perf_event_context___45 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___45 *, struct perf_event_context___45 *);
	void * (*setup_aux)(struct perf_event___45 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___45 *, struct perf_output_handle___45 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___45 *);
	int (*aux_output_match)(struct perf_event___45 *);
	int (*filter_match)(struct perf_event___45 *);
	int (*check_period)(struct perf_event___45 *, u64);
};

struct perf_cpu_context___45 {
	struct perf_event_context___45 ctx;
	struct perf_event_context___45 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___45 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___45 **heap;
	struct perf_event___45 *heap_default[2];
};

struct perf_output_handle___45 {
	struct perf_event___45 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___45 {
	struct cgroup_subsys_state___60 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___39 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___39 *);
	};
};

struct trace_event_class___39 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___39 *, enum trace_reg, void *);
	struct trace_event_fields___39 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___39 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___39 *);
};

struct trace_event_file___19;

struct trace_event_buffer___18 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___19 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___19 {
	struct list_head list;
	struct trace_event_call___39 *event_call;
	struct event_filter *filter;
	struct dentry___73 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_filemap_op_page_cache {
	struct trace_entry ent;
	long unsigned int pfn;
	long unsigned int i_ino;
	long unsigned int index;
	dev_t s_dev;
	char __data[0];
};

struct trace_event_raw_filemap_set_wb_err {
	struct trace_entry ent;
	long unsigned int i_ino;
	dev_t s_dev;
	errseq_t errseq;
	char __data[0];
};

struct trace_event_raw_file_check_and_advance_wb_err {
	struct trace_entry ent;
	struct file___72 *file;
	long unsigned int i_ino;
	dev_t s_dev;
	errseq_t old;
	errseq_t new;
	char __data[0];
};

struct trace_event_data_offsets_mm_filemap_op_page_cache {};

struct trace_event_data_offsets_filemap_set_wb_err {};

struct trace_event_data_offsets_file_check_and_advance_wb_err {};

typedef void (*btf_trace_mm_filemap_delete_from_page_cache)(void *, struct page___77 *);

typedef void (*btf_trace_mm_filemap_add_to_page_cache)(void *, struct page___77 *);

typedef void (*btf_trace_filemap_set_wb_err)(void *, struct address_space___72 *, errseq_t);

typedef void (*btf_trace_file_check_and_advance_wb_err)(void *, struct file___72 *, errseq_t);

enum behavior {
	EXCLUSIVE = 0,
	SHARED = 1,
	DROP = 2,
};

struct reciprocal_value {
	u32 m;
	u8 sh1;
	u8 sh2;
};

struct kmem_cache_order_objects {
	unsigned int x;
};

struct kmem_cache_cpu;

struct kmem_cache_node;

struct kmem_cache {
	struct kmem_cache_cpu *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	struct reciprocal_value reciprocal_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___15 kobj;
	long unsigned int random;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[64];
};

typedef struct {} local_lock_t;

struct kmem_cache_cpu {
	void **freelist;
	long unsigned int tid;
	struct page___16 *page;
	struct page___16 *partial;
	local_lock_t lock;
};

struct kmem_cache_node {
	spinlock_t list_lock;
	long unsigned int nr_partial;
	struct list_head partial;
	atomic_long_t nr_slabs;
	atomic_long_t total_objects;
	struct list_head full;
};

struct dentry___74;

struct super_block___74;

struct module___71;

struct file_system_type___73 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___74 * (*mount)(struct file_system_type___73 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___74 *);
	struct module___71 *owner;
	struct file_system_type___73 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___73;

struct kiocb___73;

struct iov_iter___44;

struct poll_table_struct___55;

struct vm_area_struct___78;

struct inode___74;

struct file_lock___73;

struct page___78;

struct seq_file___70;

struct file_operations___73 {
	struct module___71 *owner;
	loff_t (*llseek)(struct file___73 *, loff_t, int);
	ssize_t (*read)(struct file___73 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___73 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___73 *, struct iov_iter___44 *);
	ssize_t (*write_iter)(struct kiocb___73 *, struct iov_iter___44 *);
	int (*iopoll)(struct kiocb___73 *, bool);
	int (*iterate)(struct file___73 *, struct dir_context *);
	int (*iterate_shared)(struct file___73 *, struct dir_context *);
	__poll_t (*poll)(struct file___73 *, struct poll_table_struct___55 *);
	long int (*unlocked_ioctl)(struct file___73 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___73 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___73 *, struct vm_area_struct___78 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___74 *, struct file___73 *);
	int (*flush)(struct file___73 *, fl_owner_t);
	int (*release)(struct inode___74 *, struct file___73 *);
	int (*fsync)(struct file___73 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___73 *, int);
	int (*lock)(struct file___73 *, int, struct file_lock___73 *);
	ssize_t (*sendpage)(struct file___73 *, struct page___78 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___73 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___73 *, long unsigned int);
	int (*flock)(struct file___73 *, int, struct file_lock___73 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___73 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___73 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___73 *, long int, struct file_lock___73 **, void **);
	long int (*fallocate)(struct file___73 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___70 *, struct file___73 *);
	ssize_t (*copy_file_range)(struct file___73 *, loff_t, struct file___73 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___73 *, loff_t, struct file___73 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___73 *, loff_t, loff_t, int);
};

struct vmacache___78 {
	u64 seqnum;
	struct vm_area_struct___78 *vmas[4];
};

struct page_frag___78 {
	struct page___78 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___46;

struct debug_info___46 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___46 *hbp_break[16];
	struct perf_event___46 *hbp_watch[16];
};

struct thread_struct___46 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___46 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___79;

struct pid___66;

struct nsproxy___71;

struct signal_struct___74;

struct bio_list___34;

struct backing_dev_info___33;

struct io_context___34;

struct capture_control___3;

struct css_set___61;

struct perf_event_context___46;

struct mem_cgroup___31;

struct request_queue___35;

struct vm_struct___74;

struct task_struct___80 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___80 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___79 *mm;
	struct mm_struct___79 *active_mm;
	struct vmacache___78 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___80 *real_parent;
	struct task_struct___80 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___80 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___66 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___71 *nsproxy;
	struct signal_struct___74 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___80 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___34 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___33 *backing_dev_info;
	struct io_context___34 *io_context;
	struct capture_control___3 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___61 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___46 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___78 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___31 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___31 *active_memcg;
	struct request_queue___35 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___80 *oom_reaper_list;
	struct vm_struct___74 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___46 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___73;

struct kobj_type___73;

struct kernfs_node___73;

struct kobject___73 {
	const char *name;
	struct list_head entry;
	struct kobject___73 *parent;
	struct kset___73 *kset;
	struct kobj_type___73 *ktype;
	struct kernfs_node___73 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___70 {
	struct kobject___73 kobj;
	struct module___71 *mod;
	struct kobject___73 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___70 {
	struct module___71 *mod;
	struct latch_tree_node node;
};

struct module_layout___70 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___70 mtn;
};

struct module_attribute___70;

struct kernel_param___70;

struct trace_event_call___40;

struct module___71 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___70 mkobj;
	struct module_attribute___70 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___73 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___70 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___70 core_layout;
	struct module_layout___70 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___40 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___46 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___80 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___46)(struct perf_event___46 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___46;

struct fasync_struct___73;

struct pid_namespace___66;

struct perf_cgroup___46;

struct perf_event___46 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___46 *group_leader;
	struct pmu___46 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___46 hw;
	struct perf_event_context___46 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___46 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___80 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___73 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___46 *aux_event;
	void (*destroy)(struct perf_event___46 *);
	struct callback_head callback_head;
	struct pid_namespace___66 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___46 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___46 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___40 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___46 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct kmem_cache_cpu___2;

struct kmem_cache___2 {
	struct kmem_cache_cpu___2 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	struct reciprocal_value reciprocal_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___73 kobj;
	long unsigned int random;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[64];
};

struct upid___66 {
	int nr;
	struct pid_namespace___66 *ns;
};

struct pid_namespace___66 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___80 *child_reaper;
	struct kmem_cache___2 *pid_cachep;
	unsigned int level;
	struct pid_namespace___66 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___66 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___66 numbers[1];
};

typedef struct page___78 *pgtable_t___78;

struct address_space___73;

struct dev_pagemap___72;

struct page___78 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___73 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___78 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___2 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___78 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___79 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___72 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___72;

struct vm_area_struct___78 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___78 *vm_next;
	struct vm_area_struct___78 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___79 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___72 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___73 *vm_file;
	struct file___73 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___74 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___80 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___80 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___66 *pids[4];
	struct pid___66 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___79 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___78;

struct mm_struct___79 {
	struct {
		struct vm_area_struct___78 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___73 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___78 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___80 *owner;
		struct user_namespace___12 *user_ns;
		struct file___73 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___61;

struct nsproxy___71 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___66 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___61 *cgroup_ns;
};

struct bio___34;

struct bio_list___34 {
	struct bio___34 *head;
	struct bio___34 *tail;
};

struct cgroup_subsys_state___61;

struct bdi_writeback___33 {
	struct backing_dev_info___33 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___61 *memcg_css;
	struct cgroup_subsys_state___61 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___65;

struct backing_dev_info___33 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___33 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___65 *dev;
	char dev_name[64];
	struct device___65 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___74 *debug_dir;
};

struct io_cq___34;

struct io_context___34 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___34 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___3;

struct capture_control___3 {
	struct compact_control___3 *cc;
	struct page___78 *page;
};

struct cgroup___61;

struct css_set___61 {
	struct cgroup_subsys_state___61 *subsys[14];
	refcount_t refcount;
	struct css_set___61 *dom_cset;
	struct cgroup___61 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___61 *mg_src_cgrp;
	struct cgroup___61 *mg_dst_cgrp;
	struct css_set___61 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___46 {
	struct pmu___46 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___80 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___46 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___61;

struct cgroup_subsys_state___61 {
	struct cgroup___61 *cgroup;
	struct cgroup_subsys___61 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___61 *parent;
};

struct cgroup_file___61 {
	struct kernfs_node___73 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___31;

struct mem_cgroup_per_node___31;

struct mem_cgroup___31 {
	struct cgroup_subsys_state___61 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___61 events_file;
	struct cgroup_file___61 events_local_file;
	struct cgroup_file___61 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___31 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___80 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___31 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___34;

struct blk_integrity___34 {
	const struct blk_integrity_profile___34 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___34 {
	struct kmem_cache___2 *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___34 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___34;

struct elevator_queue___34;

struct blk_mq_ops___33;

struct blk_mq_hw_ctx___33;

struct gendisk___34;

struct blkcg_gq___33;

struct blk_mq_tag_set___33;

struct request_queue___35 {
	struct request___34 *last_merge;
	struct elevator_queue___34 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___33 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___33 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___34 *disk;
	struct kobject___73 kobj;
	struct kobject___73 *mq_kobj;
	struct blk_integrity___34 integrity;
	struct device___65 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___33 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___33 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___34 bio_split;
	struct dentry___74 *debugfs_dir;
	struct dentry___74 *sched_debugfs_dir;
	struct dentry___74 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___74 {
	struct vm_struct___74 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___78 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___73;

struct address_space___73 {
	struct inode___74 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___73 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___72;

struct dev_pagemap___72 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___72 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___73;

struct path___73 {
	struct vfsmount___73 *mnt;
	struct dentry___74 *dentry;
};

struct fown_struct___66 {
	rwlock_t lock;
	struct pid___66 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___73 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___73 f_path;
	struct inode___74 *f_inode;
	const struct file_operations___73 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___66 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___73 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___72;

struct vm_operations_struct___72 {
	void (*open)(struct vm_area_struct___78 *);
	void (*close)(struct vm_area_struct___78 *);
	int (*may_split)(struct vm_area_struct___78 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___78 *);
	int (*mprotect)(struct vm_area_struct___78 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___72 *);
	vm_fault_t (*huge_fault)(struct vm_fault___72 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___72 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___78 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___72 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___72 *);
	int (*access)(struct vm_area_struct___78 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___78 *);
	int (*set_policy)(struct vm_area_struct___78 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___78 *, long unsigned int);
	struct page___78 * (*find_special_page)(struct vm_area_struct___78 *, long unsigned int);
};

struct core_thread___78 {
	struct task_struct___80 *task;
	struct core_thread___78 *next;
};

struct core_state___78 {
	atomic_t nr_threads;
	struct core_thread___78 dumper;
	struct completion startup;
};

struct vm_fault___72 {
	const struct {
		struct vm_area_struct___78 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___78 *cow_page;
	struct page___78 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___78 prealloc_pte;
};

struct psi_group___61 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___80 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___61;

struct cgroup_rstat_cpu___61;

struct cgroup___61 {
	struct cgroup_subsys_state___61 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___73 *kn;
	struct cgroup_file___61 procs_file;
	struct cgroup_file___61 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___61 *subsys[14];
	struct cgroup_root___61 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___61 *dom_cgrp;
	struct cgroup___61 *old_dom_cgrp;
	struct cgroup_rstat_cpu___61 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___61 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___32;

struct lruvec___32 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___32 *pgdat;
};

struct zone___32 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___32 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___32 {
	struct zone___32 *zone;
	int zone_idx;
};

struct zonelist___32 {
	struct zoneref___32 _zonerefs[321];
};

struct pglist_data___32 {
	struct zone___32 node_zones[5];
	struct zonelist___32 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___80 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___80 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___32 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___32 pg_data_t___3;

struct shrink_control___31 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___31 *memcg;
};

struct shrinker___31 {
	long unsigned int (*count_objects)(struct shrinker___31 *, struct shrink_control___31 *);
	long unsigned int (*scan_objects)(struct shrinker___31 *, struct shrink_control___31 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___72 {
	void (*page_free)(struct page___78 *);
	void (*kill)(struct dev_pagemap___72 *);
	void (*cleanup)(struct dev_pagemap___72 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___72 *);
};

struct dentry_operations___73;

struct dentry___74 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___74 *d_parent;
	struct qstr d_name;
	struct inode___74 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___73 *d_op;
	struct super_block___74 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___73;

struct inode___74 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___73 *i_op;
	struct super_block___74 *i_sb;
	struct address_space___73 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___33 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___73 *i_fop;
		void (*free_inode)(struct inode___74 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___73 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___31 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___73 {
	int (*d_revalidate)(struct dentry___74 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___74 *, unsigned int);
	int (*d_hash)(const struct dentry___74 *, struct qstr *);
	int (*d_compare)(const struct dentry___74 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___74 *);
	int (*d_init)(struct dentry___74 *);
	void (*d_release)(struct dentry___74 *);
	void (*d_prune)(struct dentry___74 *);
	void (*d_iput)(struct dentry___74 *, struct inode___74 *);
	char * (*d_dname)(struct dentry___74 *, char *, int);
	struct vfsmount___73 * (*d_automount)(struct path___73 *);
	int (*d_manage)(const struct path___73 *, bool);
	struct dentry___74 * (*d_real)(struct dentry___74 *, const struct inode___74 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___73;

struct mem_dqinfo___73 {
	struct quota_format_type___73 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___73;

struct quota_info___73 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___74 *files[3];
	struct mem_dqinfo___73 info[3];
	const struct quota_format_ops___73 *ops[3];
};

struct rcuwait___74 {
	struct task_struct___80 *task;
};

struct percpu_rw_semaphore___74 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___74 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___73 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___74 rw_sem[3];
};

struct super_operations___73;

struct dquot_operations___73;

struct quotactl_ops___73;

struct block_device___35;

struct super_block___74 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___73 *s_type;
	const struct super_operations___73 *s_op;
	const struct dquot_operations___73 *dq_op;
	const struct quotactl_ops___73 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___74 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___35 *s_bdev;
	struct backing_dev_info___33 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___73 s_dquot;
	struct sb_writers___73 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___73 *s_d_op;
	int cleancache_poolid;
	struct shrinker___31 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___73 {
	struct dentry___74 *mnt_root;
	struct super_block___74 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct io_cq___34 {
	struct request_queue___35 *q;
	struct io_context___34 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___31;

struct kiocb___73 {
	struct file___73 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___73 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___31 *ki_waitq;
	};
};

struct iattr___74 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___73 *ia_file;
};

struct dquot___73 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___74 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___73 {
	int qf_fmt_id;
	const struct quota_format_ops___73 *qf_ops;
	struct module___71 *qf_owner;
	struct quota_format_type___73 *qf_next;
};

struct quota_format_ops___73 {
	int (*check_quota_file)(struct super_block___74 *, int);
	int (*read_file_info)(struct super_block___74 *, int);
	int (*write_file_info)(struct super_block___74 *, int);
	int (*free_file_info)(struct super_block___74 *, int);
	int (*read_dqblk)(struct dquot___73 *);
	int (*commit_dqblk)(struct dquot___73 *);
	int (*release_dqblk)(struct dquot___73 *);
	int (*get_next_id)(struct super_block___74 *, struct kqid *);
};

struct dquot_operations___73 {
	int (*write_dquot)(struct dquot___73 *);
	struct dquot___73 * (*alloc_dquot)(struct super_block___74 *, int);
	void (*destroy_dquot)(struct dquot___73 *);
	int (*acquire_dquot)(struct dquot___73 *);
	int (*release_dquot)(struct dquot___73 *);
	int (*mark_dirty)(struct dquot___73 *);
	int (*write_info)(struct super_block___74 *, int);
	qsize_t * (*get_reserved_space)(struct inode___74 *);
	int (*get_projid)(struct inode___74 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___74 *, qsize_t *);
	int (*get_next_id)(struct super_block___74 *, struct kqid *);
};

struct quotactl_ops___73 {
	int (*quota_on)(struct super_block___74 *, int, int, const struct path___73 *);
	int (*quota_off)(struct super_block___74 *, int);
	int (*quota_enable)(struct super_block___74 *, unsigned int);
	int (*quota_disable)(struct super_block___74 *, unsigned int);
	int (*quota_sync)(struct super_block___74 *, int);
	int (*set_info)(struct super_block___74 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___74 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___74 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___74 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___74 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___74 *, unsigned int);
};

struct wait_page_queue___31 {
	struct page___78 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___33;

struct readahead_control___31;

struct swap_info_struct___19;

struct address_space_operations___73 {
	int (*writepage)(struct page___78 *, struct writeback_control___33 *);
	int (*readpage)(struct file___73 *, struct page___78 *);
	int (*writepages)(struct address_space___73 *, struct writeback_control___33 *);
	int (*set_page_dirty)(struct page___78 *);
	int (*readpages)(struct file___73 *, struct address_space___73 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___31 *);
	int (*write_begin)(struct file___73 *, struct address_space___73 *, loff_t, unsigned int, unsigned int, struct page___78 **, void **);
	int (*write_end)(struct file___73 *, struct address_space___73 *, loff_t, unsigned int, unsigned int, struct page___78 *, void *);
	sector_t (*bmap)(struct address_space___73 *, sector_t);
	void (*invalidatepage)(struct page___78 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___78 *, gfp_t);
	void (*freepage)(struct page___78 *);
	ssize_t (*direct_IO)(struct kiocb___73 *, struct iov_iter___44 *);
	int (*migratepage)(struct address_space___73 *, struct page___78 *, struct page___78 *, enum migrate_mode);
	bool (*isolate_page)(struct page___78 *, isolate_mode_t);
	void (*putback_page)(struct page___78 *);
	int (*launder_page)(struct page___78 *);
	int (*is_partially_uptodate)(struct page___78 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___78 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___73 *, struct page___78 *);
	int (*swap_activate)(struct swap_info_struct___19 *, struct file___73 *, sector_t *);
	void (*swap_deactivate)(struct file___73 *);
};

struct writeback_control___33 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___33 *wb;
	struct inode___74 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___31 {
	struct file___73 *file;
	struct address_space___73 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___43;

struct iov_iter___44 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___43 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___19 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___35 *bdev;
	struct file___73 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___73 {
	struct dentry___74 * (*lookup)(struct inode___74 *, struct dentry___74 *, unsigned int);
	const char * (*get_link)(struct dentry___74 *, struct inode___74 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___74 *, int);
	struct posix_acl * (*get_acl)(struct inode___74 *, int, bool);
	int (*readlink)(struct dentry___74 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___74 *, struct dentry___74 *, umode_t, bool);
	int (*link)(struct dentry___74 *, struct inode___74 *, struct dentry___74 *);
	int (*unlink)(struct inode___74 *, struct dentry___74 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___74 *, struct dentry___74 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___74 *, struct dentry___74 *, umode_t);
	int (*rmdir)(struct inode___74 *, struct dentry___74 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___74 *, struct dentry___74 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___74 *, struct dentry___74 *, struct inode___74 *, struct dentry___74 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___74 *, struct iattr___74 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___73 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___74 *, char *, size_t);
	int (*fiemap)(struct inode___74 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___74 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___74 *, struct dentry___74 *, struct file___73 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___74 *, struct dentry___74 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___74 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___74 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___74 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___73 {
	void (*fl_copy_lock)(struct file_lock___73 *, struct file_lock___73 *);
	void (*fl_release_private)(struct file_lock___73 *);
};

struct lock_manager_operations___73;

struct file_lock___73 {
	struct file_lock___73 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___73 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___73 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___73 *fl_ops;
	const struct lock_manager_operations___73 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___73 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___73 *);
	int (*lm_grant)(struct file_lock___73 *, int);
	bool (*lm_break)(struct file_lock___73 *);
	int (*lm_change)(struct file_lock___73 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___73 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___73 *);
};

struct fasync_struct___73 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___73 *fa_next;
	struct file___73 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___73 {
	struct inode___74 * (*alloc_inode)(struct super_block___74 *);
	void (*destroy_inode)(struct inode___74 *);
	void (*free_inode)(struct inode___74 *);
	void (*dirty_inode)(struct inode___74 *, int);
	int (*write_inode)(struct inode___74 *, struct writeback_control___33 *);
	int (*drop_inode)(struct inode___74 *);
	void (*evict_inode)(struct inode___74 *);
	void (*put_super)(struct super_block___74 *);
	int (*sync_fs)(struct super_block___74 *, int);
	int (*freeze_super)(struct super_block___74 *);
	int (*freeze_fs)(struct super_block___74 *);
	int (*thaw_super)(struct super_block___74 *);
	int (*unfreeze_fs)(struct super_block___74 *);
	int (*statfs)(struct dentry___74 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___74 *, int *, char *);
	void (*umount_begin)(struct super_block___74 *);
	int (*show_options)(struct seq_file___70 *, struct dentry___74 *);
	int (*show_devname)(struct seq_file___70 *, struct dentry___74 *);
	int (*show_path)(struct seq_file___70 *, struct dentry___74 *);
	int (*show_stats)(struct seq_file___70 *, struct dentry___74 *);
	ssize_t (*quota_read)(struct super_block___74 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___74 *, int, const char *, size_t, loff_t);
	struct dquot___73 ** (*get_dquots)(struct inode___74 *);
	long int (*nr_cached_objects)(struct super_block___74 *, struct shrink_control___31 *);
	long int (*free_cached_objects)(struct super_block___74 *, struct shrink_control___31 *);
	struct file___73 * (*real_loop)(struct file___73 *);
};

struct wakeup_source___65;

struct dev_pm_info___65 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___65 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___65 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___65;

struct bus_type___65;

struct device_driver___65;

struct dev_pm_domain___65;

struct fwnode_handle___65;

struct class___65;

struct attribute_group___73;

struct device___65 {
	struct kobject___73 kobj;
	struct device___65 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___65 *type;
	struct bus_type___65 *bus;
	struct device_driver___65 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___65 power;
	struct dev_pm_domain___65 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___65 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___65 *class;
	const struct attribute_group___73 **groups;
	void (*release)(struct device___65 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___35 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___74 *bd_inode;
	struct super_block___74 *bd_super;
	void *bd_claiming;
	struct device___65 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___73 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___34 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___74 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___55)(struct file___73 *, wait_queue_head_t *, struct poll_table_struct___55 *);

struct poll_table_struct___55 {
	poll_queue_proc___55 _qproc;
	__poll_t _key;
};

struct seq_operations___70;

struct seq_file___70 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___70 *op;
	int poll_event;
	const struct file___73 *file;
	void *private;
};

typedef void bio_end_io_t___34(struct bio___34 *);

struct bio_vec___43 {
	struct page___78 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___34;

struct bio___34 {
	struct bio___34 *bi_next;
	struct block_device___35 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___34 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___33 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___34 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___43 *bi_io_vec;
	struct bio_set___34 *bi_pool;
	struct bio_vec___43 bi_inline_vecs[0];
};

struct zap_details {
	struct address_space___73 *check_mapping;
	long unsigned int first_index;
	long unsigned int last_index;
	struct page___78 *single_page;
};

enum oom_constraint {
	CONSTRAINT_NONE = 0,
	CONSTRAINT_CPUSET = 1,
	CONSTRAINT_MEMORY_POLICY = 2,
	CONSTRAINT_MEMCG = 3,
};

struct oom_control {
	struct zonelist___32 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___31 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___80 *chosen;
	long int chosen_points;
	enum oom_constraint constraint;
};

struct seq_operations___70 {
	void * (*start)(struct seq_file___70 *, loff_t *);
	void (*stop)(struct seq_file___70 *, void *);
	void * (*next)(struct seq_file___70 *, void *, loff_t *);
	int (*show)(struct seq_file___70 *, void *);
};

struct kernfs_root___73;

struct kernfs_elem_dir___73 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___73 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___73;

struct kernfs_root___73 {
	struct kernfs_node___73 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___73 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___73 {
	struct kernfs_node___73 *target_kn;
};

struct kernfs_ops___73;

struct kernfs_elem_attr___73 {
	const struct kernfs_ops___73 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___73 *notify_next;
};

struct kernfs_node___73 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___73 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___73 dir;
		struct kernfs_elem_symlink___73 symlink;
		struct kernfs_elem_attr___73 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___73;

struct kernfs_ops___73 {
	int (*open)(struct kernfs_open_file___73 *);
	void (*release)(struct kernfs_open_file___73 *);
	int (*seq_show)(struct seq_file___70 *, void *);
	void * (*seq_start)(struct seq_file___70 *, loff_t *);
	void * (*seq_next)(struct seq_file___70 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___70 *, void *);
	ssize_t (*read)(struct kernfs_open_file___73 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___73 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___73 *, struct poll_table_struct___55 *);
	int (*mmap)(struct kernfs_open_file___73 *, struct vm_area_struct___78 *);
};

struct kernfs_syscall_ops___73 {
	int (*show_options)(struct seq_file___70 *, struct kernfs_root___73 *);
	int (*mkdir)(struct kernfs_node___73 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___73 *);
	int (*rename)(struct kernfs_node___73 *, struct kernfs_node___73 *, const char *);
	int (*show_path)(struct seq_file___70 *, struct kernfs_node___73 *, struct kernfs_root___73 *);
};

struct kernfs_open_file___73 {
	struct kernfs_node___73 *kn;
	struct file___73 *file;
	struct seq_file___70 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___72 *vm_ops;
};

struct cgroup_namespace___61 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___61 *root_cset;
};

struct fwnode_operations___65;

struct fwnode_handle___65 {
	struct fwnode_handle___65 *secondary;
	const struct fwnode_operations___65 *ops;
	struct device___65 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___65;

struct fwnode_endpoint___65;

struct fwnode_operations___65 {
	struct fwnode_handle___65 * (*get)(struct fwnode_handle___65 *);
	void (*put)(struct fwnode_handle___65 *);
	bool (*device_is_available)(const struct fwnode_handle___65 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___65 *, const struct device___65 *);
	bool (*property_present)(const struct fwnode_handle___65 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___65 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___65 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___65 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*get_parent)(const struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*get_next_child_node)(const struct fwnode_handle___65 *, struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*get_named_child_node)(const struct fwnode_handle___65 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___65 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___65 *);
	struct fwnode_handle___65 * (*graph_get_next_endpoint)(const struct fwnode_handle___65 *, struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*graph_get_remote_endpoint)(const struct fwnode_handle___65 *);
	struct fwnode_handle___65 * (*graph_get_port_parent)(struct fwnode_handle___65 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___65 *, struct fwnode_endpoint___65 *);
	int (*add_links)(struct fwnode_handle___65 *);
};

struct fwnode_endpoint___65 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___65 *local_fwnode;
};

struct fwnode_reference_args___65 {
	struct fwnode_handle___65 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___73;

struct attribute_group___73 {
	const char *name;
	umode_t (*is_visible)(struct kobject___73 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___73 *, struct bin_attribute___73 *, int);
	struct attribute **attrs;
	struct bin_attribute___73 **bin_attrs;
};

struct bin_attribute___73 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___73 * (*f_mapping)();
	ssize_t (*read)(struct file___73 *, struct kobject___73 *, struct bin_attribute___73 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___73 *, struct kobject___73 *, struct bin_attribute___73 *, char *, loff_t, size_t);
	int (*mmap)(struct file___73 *, struct kobject___73 *, struct bin_attribute___73 *, struct vm_area_struct___78 *);
};

struct sysfs_ops___73 {
	ssize_t (*show)(struct kobject___73 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___73 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___73;

struct kset___73 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___73 kobj;
	const struct kset_uevent_ops___73 *uevent_ops;
};

struct kobj_type___73 {
	void (*release)(struct kobject___73 *);
	const struct sysfs_ops___73 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___73 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___73 *);
	const void * (*namespace)(struct kobject___73 *);
	void (*get_ownership)(struct kobject___73 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___73 {
	int (* const filter)(struct kset___73 *, struct kobject___73 *);
	const char * (* const name)(struct kset___73 *, struct kobject___73 *);
	int (* const uevent)(struct kset___73 *, struct kobject___73 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___70 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___70 *);
	int (*get)(char *, const struct kernel_param___70 *);
	void (*free)(void *);
};

struct kparam_array___70;

struct kernel_param___70 {
	const char *name;
	struct module___71 *mod;
	const struct kernel_param_ops___70 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___70 *arr;
	};
};

struct kparam_array___70 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___70 *ops;
	void *elem;
};

struct module_attribute___70 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___70 *, struct module_kobject___70 *, char *);
	ssize_t (*store)(struct module_attribute___70 *, struct module_kobject___70 *, const char *, size_t);
	void (*setup)(struct module___71 *, const char *);
	int (*test)(struct module___71 *);
	void (*free)(struct module___71 *);
};

struct trace_event_class___40;

struct trace_event_call___40 {
	struct list_head list;
	struct trace_event_class___40 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___40 *, struct perf_event___46 *);
};

struct cftype___61;

struct cgroup_subsys___61 {
	struct cgroup_subsys_state___61 * (*css_alloc)(struct cgroup_subsys_state___61 *);
	int (*css_online)(struct cgroup_subsys_state___61 *);
	void (*css_offline)(struct cgroup_subsys_state___61 *);
	void (*css_released)(struct cgroup_subsys_state___61 *);
	void (*css_free)(struct cgroup_subsys_state___61 *);
	void (*css_reset)(struct cgroup_subsys_state___61 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___61 *, int);
	int (*css_extra_stat_show)(struct seq_file___70 *, struct cgroup_subsys_state___61 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___80 *, struct css_set___61 *);
	void (*cancel_fork)(struct task_struct___80 *, struct css_set___61 *);
	void (*fork)(struct task_struct___80 *);
	void (*exit)(struct task_struct___80 *);
	void (*release)(struct task_struct___80 *);
	void (*bind)(struct cgroup_subsys_state___61 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___61 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___61 *dfl_cftypes;
	struct cftype___61 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___61 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___61 *updated_children;
	struct cgroup___61 *updated_next;
};

struct cgroup_root___61 {
	struct kernfs_root___73 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___61 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___61 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___61 *ss;
	struct list_head node;
	struct kernfs_ops___73 *kf_ops;
	int (*open)(struct kernfs_open_file___73 *);
	void (*release)(struct kernfs_open_file___73 *);
	u64 (*read_u64)(struct cgroup_subsys_state___61 *, struct cftype___61 *);
	s64 (*read_s64)(struct cgroup_subsys_state___61 *, struct cftype___61 *);
	int (*seq_show)(struct seq_file___70 *, void *);
	void * (*seq_start)(struct seq_file___70 *, loff_t *);
	void * (*seq_next)(struct seq_file___70 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___70 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___61 *, struct cftype___61 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___61 *, struct cftype___61 *, s64);
	ssize_t (*write)(struct kernfs_open_file___73 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___73 *, struct poll_table_struct___55 *);
};

struct dev_pm_ops___65 {
	int (*prepare)(struct device___65 *);
	void (*complete)(struct device___65 *);
	int (*suspend)(struct device___65 *);
	int (*resume)(struct device___65 *);
	int (*freeze)(struct device___65 *);
	int (*thaw)(struct device___65 *);
	int (*poweroff)(struct device___65 *);
	int (*restore)(struct device___65 *);
	int (*suspend_late)(struct device___65 *);
	int (*resume_early)(struct device___65 *);
	int (*freeze_late)(struct device___65 *);
	int (*thaw_early)(struct device___65 *);
	int (*poweroff_late)(struct device___65 *);
	int (*restore_early)(struct device___65 *);
	int (*suspend_noirq)(struct device___65 *);
	int (*resume_noirq)(struct device___65 *);
	int (*freeze_noirq)(struct device___65 *);
	int (*thaw_noirq)(struct device___65 *);
	int (*poweroff_noirq)(struct device___65 *);
	int (*restore_noirq)(struct device___65 *);
	int (*runtime_suspend)(struct device___65 *);
	int (*runtime_resume)(struct device___65 *);
	int (*runtime_idle)(struct device___65 *);
};

struct wakeup_source___65 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___65 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___65 {
	struct dev_pm_ops___65 ops;
	int (*start)(struct device___65 *);
	void (*detach)(struct device___65 *, bool);
	int (*activate)(struct device___65 *);
	void (*sync)(struct device___65 *);
	void (*dismiss)(struct device___65 *);
};

struct bus_type___65 {
	const char *name;
	const char *dev_name;
	struct device___65 *dev_root;
	const struct attribute_group___73 **bus_groups;
	const struct attribute_group___73 **dev_groups;
	const struct attribute_group___73 **drv_groups;
	int (*match)(struct device___65 *, struct device_driver___65 *);
	int (*uevent)(struct device___65 *, struct kobj_uevent_env *);
	int (*probe)(struct device___65 *);
	void (*sync_state)(struct device___65 *);
	void (*remove)(struct device___65 *);
	void (*shutdown)(struct device___65 *);
	int (*online)(struct device___65 *);
	int (*offline)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	int (*num_vf)(struct device___65 *);
	int (*dma_configure)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___65 {
	const char *name;
	struct bus_type___65 *bus;
	struct module___71 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___65 *);
	void (*sync_state)(struct device___65 *);
	int (*remove)(struct device___65 *);
	void (*shutdown)(struct device___65 *);
	int (*suspend)(struct device___65 *, pm_message_t);
	int (*resume)(struct device___65 *);
	const struct attribute_group___73 **groups;
	const struct attribute_group___73 **dev_groups;
	const struct dev_pm_ops___65 *pm;
	void (*coredump)(struct device___65 *);
	struct driver_private *p;
};

struct device_type___65 {
	const char *name;
	const struct attribute_group___73 **groups;
	int (*uevent)(struct device___65 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___65 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___65 *);
	const struct dev_pm_ops___65 *pm;
};

struct class___65 {
	const char *name;
	struct module___71 *owner;
	const struct attribute_group___73 **class_groups;
	const struct attribute_group___73 **dev_groups;
	struct kobject___73 *dev_kobj;
	int (*dev_uevent)(struct device___65 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___65 *, umode_t *);
	void (*class_release)(struct class___65 *);
	void (*dev_release)(struct device___65 *);
	int (*shutdown_pre)(struct device___65 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___65 *);
	void (*get_ownership)(struct device___65 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___65 *pm;
	struct subsys_private *p;
};

struct block_device_operations___34;

struct gendisk___34 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___35 *part0;
	const struct block_device_operations___34 *fops;
	struct request_queue___35 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___33 *bdi;
	struct kobject___73 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___73 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___34 {
	struct bio___34 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___43 *bip_vec;
	struct bio_vec___43 bip_inline_vecs[0];
};

struct blkcg___33;

struct blkg_policy_data___33;

struct blkcg_gq___33 {
	struct request_queue___35 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___33 *blkcg;
	struct blkcg_gq___33 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___33 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___34 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___34(struct request___34 *);

typedef void integrity_complete_fn___34(struct request___34 *, unsigned int);

struct blk_integrity_profile___34 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___34 *prepare_fn;
	integrity_complete_fn___34 *complete_fn;
	const char *name;
};

struct block_device_operations___34 {
	blk_qc_t (*submit_bio)(struct bio___34 *);
	int (*open)(struct block_device___35 *, fmode_t);
	void (*release)(struct gendisk___34 *, fmode_t);
	int (*rw_page)(struct block_device___35 *, sector_t, struct page___78 *, unsigned int);
	int (*ioctl)(struct block_device___35 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___35 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___34 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___34 *);
	int (*getgeo)(struct block_device___35 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___35 *, bool);
	void (*swap_slot_free_notify)(struct block_device___35 *, long unsigned int);
	int (*report_zones)(struct gendisk___34 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___34 *, umode_t *);
	struct module___71 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___34 *, sector_t *);
};

typedef void rq_end_io_fn___34(struct request___34 *, blk_status_t);

struct request___34 {
	struct request_queue___35 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___33 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___34 *bio;
	struct bio___34 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___43 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___34 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___34 *saved_end_io;
		} flush;
	};
	struct gendisk___34 *rq_disk;
	struct block_device___35 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___34 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___33 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___35 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___73 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___74 *debugfs_dir;
	struct dentry___74 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___34;

struct elevator_mq_ops___34 {
	int (*init_sched)(struct request_queue___35 *, struct elevator_type___34 *);
	void (*exit_sched)(struct elevator_queue___34 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___33 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___33 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___33 *);
	bool (*allow_merge)(struct request_queue___35 *, struct request___34 *, struct bio___34 *);
	bool (*bio_merge)(struct request_queue___35 *, struct bio___34 *, unsigned int);
	int (*request_merge)(struct request_queue___35 *, struct request___34 **, struct bio___34 *);
	void (*request_merged)(struct request_queue___35 *, struct request___34 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___35 *, struct request___34 *, struct request___34 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___34 *);
	void (*finish_request)(struct request___34 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___33 *, struct list_head *, bool);
	struct request___34 * (*dispatch_request)(struct blk_mq_hw_ctx___33 *);
	bool (*has_work)(struct blk_mq_hw_ctx___33 *);
	void (*completed_request)(struct request___34 *, u64);
	void (*requeue_request)(struct request___34 *);
	struct request___34 * (*former_request)(struct request_queue___35 *, struct request___34 *);
	struct request___34 * (*next_request)(struct request_queue___35 *, struct request___34 *);
	void (*init_icq)(struct io_cq___34 *);
	void (*exit_icq)(struct io_cq___34 *);
};

struct elv_fs_entry___34;

struct elevator_type___34 {
	struct kmem_cache___2 *icq_cache;
	struct elevator_mq_ops___34 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___34 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___71 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___34 {
	struct elevator_type___34 *type;
	void *elevator_data;
	struct kobject___73 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___34 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___34 *, char *);
	ssize_t (*store)(struct elevator_queue___34 *, const char *, size_t);
};

struct blk_mq_queue_data___33;

struct blk_mq_ops___33 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___33 *, const struct blk_mq_queue_data___33 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___33 *);
	int (*get_budget)(struct request_queue___35 *);
	void (*put_budget)(struct request_queue___35 *, int);
	void (*set_rq_budget_token)(struct request___34 *, int);
	int (*get_rq_budget_token)(struct request___34 *);
	enum blk_eh_timer_return (*timeout)(struct request___34 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___33 *);
	void (*complete)(struct request___34 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___33 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___33 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___33 *, struct request___34 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___33 *, struct request___34 *, unsigned int);
	void (*initialize_rq_fn)(struct request___34 *);
	void (*cleanup_rq)(struct request___34 *);
	bool (*busy)(struct request_queue___35 *);
	int (*map_queues)(struct blk_mq_tag_set___33 *);
	void (*show_rq)(struct seq_file___70 *, struct request___34 *);
};

struct blk_mq_tag_set___33 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___33 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___33 {
	struct request___34 *rq;
	bool last;
};

struct blkcg_policy_data___33;

struct blkcg___33 {
	struct cgroup_subsys_state___61 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___33 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___33 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___33 {
	struct blkcg___33 *blkcg;
	int plid;
};

struct blkg_policy_data___33 {
	struct blkcg_gq___33 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___31 {
	struct mem_cgroup___31 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___31 {
	struct lruvec___32 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___31 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___31 *memcg;
};

struct obj_cgroup___31 {
	struct percpu_ref refcnt;
	struct mem_cgroup___31 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___46;

struct perf_output_handle___46;

struct pmu___46 {
	struct list_head entry;
	struct module___71 *module;
	struct device___65 *dev;
	const struct attribute_group___73 **attr_groups;
	const struct attribute_group___73 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___46 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___46 *);
	void (*pmu_disable)(struct pmu___46 *);
	int (*event_init)(struct perf_event___46 *);
	void (*event_mapped)(struct perf_event___46 *, struct mm_struct___79 *);
	void (*event_unmapped)(struct perf_event___46 *, struct mm_struct___79 *);
	int (*add)(struct perf_event___46 *, int);
	void (*del)(struct perf_event___46 *, int);
	void (*start)(struct perf_event___46 *, int);
	void (*stop)(struct perf_event___46 *, int);
	void (*read)(struct perf_event___46 *);
	void (*start_txn)(struct pmu___46 *, unsigned int);
	int (*commit_txn)(struct pmu___46 *);
	void (*cancel_txn)(struct pmu___46 *);
	int (*event_idx)(struct perf_event___46 *);
	void (*sched_task)(struct perf_event_context___46 *, bool);
	struct kmem_cache___2 *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___46 *, struct perf_event_context___46 *);
	void * (*setup_aux)(struct perf_event___46 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___46 *, struct perf_output_handle___46 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___46 *);
	int (*aux_output_match)(struct perf_event___46 *);
	int (*filter_match)(struct perf_event___46 *);
	int (*check_period)(struct perf_event___46 *, u64);
};

struct perf_cpu_context___46 {
	struct perf_event_context___46 ctx;
	struct perf_event_context___46 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___46 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___46 **heap;
	struct perf_event___46 *heap_default[2];
};

struct perf_output_handle___46 {
	struct perf_event___46 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___46 {
	struct cgroup_subsys_state___61 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___40 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___40 *);
	};
};

struct trace_event_class___40 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___40 *, enum trace_reg, void *);
	struct trace_event_fields___40 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___40 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___40 *);
};

struct trace_event_file___20;

struct trace_event_buffer___19 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___20 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___20 {
	struct list_head list;
	struct trace_event_call___40 *event_call;
	struct event_filter *filter;
	struct dentry___74 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___17 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___40 *enter_event;
	struct trace_event_call___40 *exit_event;
};

struct mmu_notifier_range___8 {
	struct vm_area_struct___78 *vma;
	struct mm_struct___79 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct mmu_table_batch {
	struct callback_head rcu;
	unsigned int nr;
	void *tables[0];
};

struct mmu_gather_batch {
	struct mmu_gather_batch *next;
	unsigned int nr;
	unsigned int max;
	struct page___78 *pages[0];
};

struct mmu_gather {
	struct mm_struct___79 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch *active;
	struct mmu_gather_batch local;
	struct page___78 *__pages[8];
};

struct compact_control___3 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___32 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct kmem_cache_cpu___2 {
	void **freelist;
	long unsigned int tid;
	struct page___78 *page;
	struct page___78 *partial;
	local_lock_t lock;
};

enum compact_priority {
	COMPACT_PRIO_SYNC_FULL = 0,
	MIN_COMPACT_PRIORITY = 0,
	COMPACT_PRIO_SYNC_LIGHT = 1,
	MIN_COMPACT_COSTLY_PRIORITY = 1,
	DEF_COMPACT_PRIORITY = 1,
	COMPACT_PRIO_ASYNC = 2,
	INIT_COMPACT_PRIORITY = 2,
};

enum compact_result {
	COMPACT_NOT_SUITABLE_ZONE = 0,
	COMPACT_SKIPPED = 1,
	COMPACT_DEFERRED = 2,
	COMPACT_NO_SUITABLE_PAGE = 3,
	COMPACT_CONTINUE = 4,
	COMPACT_COMPLETE = 5,
	COMPACT_PARTIAL_SKIPPED = 6,
	COMPACT_CONTENDED = 7,
	COMPACT_SUCCESS = 8,
};

struct trace_event_raw_oom_score_adj_update {
	struct trace_entry ent;
	pid_t pid;
	char comm[16];
	short int oom_score_adj;
	char __data[0];
};

struct trace_event_raw_reclaim_retry_zone {
	struct trace_entry ent;
	int node;
	int zone_idx;
	int order;
	long unsigned int reclaimable;
	long unsigned int available;
	long unsigned int min_wmark;
	int no_progress_loops;
	bool wmark_check;
	char __data[0];
};

struct trace_event_raw_mark_victim {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_wake_reaper {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_start_task_reaping {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_finish_task_reaping {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_skip_task_reaping {
	struct trace_entry ent;
	int pid;
	char __data[0];
};

struct trace_event_raw_compact_retry {
	struct trace_entry ent;
	int order;
	int priority;
	int result;
	int retries;
	int max_retries;
	bool ret;
	char __data[0];
};

struct trace_event_data_offsets_oom_score_adj_update {};

struct trace_event_data_offsets_reclaim_retry_zone {};

struct trace_event_data_offsets_mark_victim {};

struct trace_event_data_offsets_wake_reaper {};

struct trace_event_data_offsets_start_task_reaping {};

struct trace_event_data_offsets_finish_task_reaping {};

struct trace_event_data_offsets_skip_task_reaping {};

struct trace_event_data_offsets_compact_retry {};

typedef void (*btf_trace_oom_score_adj_update)(void *, struct task_struct___80 *);

typedef void (*btf_trace_reclaim_retry_zone)(void *, struct zoneref___32 *, int, long unsigned int, long unsigned int, long unsigned int, int, bool);

typedef void (*btf_trace_mark_victim)(void *, int);

typedef void (*btf_trace_wake_reaper)(void *, int);

typedef void (*btf_trace_start_task_reaping)(void *, int);

typedef void (*btf_trace_finish_task_reaping)(void *, int);

typedef void (*btf_trace_skip_task_reaping)(void *, int);

typedef void (*btf_trace_compact_retry)(void *, int, enum compact_priority, enum compact_result, int, int, bool);

struct fd___11 {
	struct file___73 *file;
	unsigned int flags;
};

enum wb_congested_state {
	WB_async_congested = 0,
	WB_sync_congested = 1,
};

enum {
	XA_CHECK_SCHED = 4096,
};

enum wb_state {
	WB_registered = 0,
	WB_writeback_running = 1,
	WB_has_dirty_io = 2,
	WB_start_all = 3,
};

enum {
	BLK_RW_ASYNC = 0,
	BLK_RW_SYNC = 1,
};

struct wb_lock_cookie {
	bool locked;
	long unsigned int flags;
};

typedef int (*writepage_t)(struct page___78 *, struct writeback_control___33 *, void *);

enum page_memcg_data_flags {
	MEMCG_DATA_OBJCGS = 1,
	MEMCG_DATA_KMEM = 2,
	__NR_MEMCG_DATA_FLAGS = 4,
};

struct pagevec___2 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___78 *pages[15];
};

struct dirty_throttle_control {
	struct wb_domain *dom;
	struct dirty_throttle_control *gdtc;
	struct bdi_writeback___33 *wb;
	struct fprop_local_percpu *wb_completions;
	long unsigned int avail;
	long unsigned int dirty;
	long unsigned int thresh;
	long unsigned int bg_thresh;
	long unsigned int wb_dirty;
	long unsigned int wb_thresh;
	long unsigned int wb_bg_thresh;
	long unsigned int pos_ratio;
};

typedef void compound_page_dtor(struct page___78 *);

struct trace_event_raw_mm_lru_insertion {
	struct trace_entry ent;
	struct page___78 *page;
	long unsigned int pfn;
	enum lru_list lru;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_mm_lru_activate {
	struct trace_entry ent;
	struct page___78 *page;
	long unsigned int pfn;
	char __data[0];
};

struct trace_event_data_offsets_mm_lru_insertion {};

struct trace_event_data_offsets_mm_lru_activate {};

typedef void (*btf_trace_mm_lru_insertion)(void *, struct page___78 *);

typedef void (*btf_trace_mm_lru_activate)(void *, struct page___78 *);

struct lru_rotate {
	local_lock_t lock;
	struct pagevec___2 pvec;
};

struct lru_pvecs {
	local_lock_t lock;
	struct pagevec___2 lru_add;
	struct pagevec___2 lru_deactivate_file;
	struct pagevec___2 lru_deactivate;
	struct pagevec___2 lru_lazyfree;
	struct pagevec___2 activate_page;
};

struct dentry___75;

struct super_block___75;

struct module___72;

struct file_system_type___74 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___75 * (*mount)(struct file_system_type___74 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___75 *);
	struct module___72 *owner;
	struct file_system_type___74 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___74;

struct kiocb___74;

struct iov_iter___45;

struct poll_table_struct___56;

struct vm_area_struct___79;

struct inode___75;

struct file_lock___74;

struct page___79;

struct seq_file___71;

struct file_operations___74 {
	struct module___72 *owner;
	loff_t (*llseek)(struct file___74 *, loff_t, int);
	ssize_t (*read)(struct file___74 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___74 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___74 *, struct iov_iter___45 *);
	ssize_t (*write_iter)(struct kiocb___74 *, struct iov_iter___45 *);
	int (*iopoll)(struct kiocb___74 *, bool);
	int (*iterate)(struct file___74 *, struct dir_context *);
	int (*iterate_shared)(struct file___74 *, struct dir_context *);
	__poll_t (*poll)(struct file___74 *, struct poll_table_struct___56 *);
	long int (*unlocked_ioctl)(struct file___74 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___74 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___74 *, struct vm_area_struct___79 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___75 *, struct file___74 *);
	int (*flush)(struct file___74 *, fl_owner_t);
	int (*release)(struct inode___75 *, struct file___74 *);
	int (*fsync)(struct file___74 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___74 *, int);
	int (*lock)(struct file___74 *, int, struct file_lock___74 *);
	ssize_t (*sendpage)(struct file___74 *, struct page___79 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___74 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___74 *, long unsigned int);
	int (*flock)(struct file___74 *, int, struct file_lock___74 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___74 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___74 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___74 *, long int, struct file_lock___74 **, void **);
	long int (*fallocate)(struct file___74 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___71 *, struct file___74 *);
	ssize_t (*copy_file_range)(struct file___74 *, loff_t, struct file___74 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___74 *, loff_t, struct file___74 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___74 *, loff_t, loff_t, int);
};

struct vmacache___79 {
	u64 seqnum;
	struct vm_area_struct___79 *vmas[4];
};

struct page_frag___79 {
	struct page___79 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___47;

struct debug_info___47 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___47 *hbp_break[16];
	struct perf_event___47 *hbp_watch[16];
};

struct thread_struct___47 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___47 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___80;

struct pid___67;

struct nsproxy___72;

struct signal_struct___75;

struct bio_list___35;

struct backing_dev_info___34;

struct io_context___35;

struct capture_control___4;

struct css_set___62;

struct perf_event_context___47;

struct mem_cgroup___32;

struct request_queue___36;

struct vm_struct___75;

struct task_struct___81 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___81 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___80 *mm;
	struct mm_struct___80 *active_mm;
	struct vmacache___79 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___81 *real_parent;
	struct task_struct___81 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___81 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___67 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___72 *nsproxy;
	struct signal_struct___75 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___81 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___35 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___34 *backing_dev_info;
	struct io_context___35 *io_context;
	struct capture_control___4 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___62 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___47 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___79 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___32 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___32 *active_memcg;
	struct request_queue___36 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___81 *oom_reaper_list;
	struct vm_struct___75 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___47 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___74;

struct kobj_type___74;

struct kernfs_node___74;

struct kobject___74 {
	const char *name;
	struct list_head entry;
	struct kobject___74 *parent;
	struct kset___74 *kset;
	struct kobj_type___74 *ktype;
	struct kernfs_node___74 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___71 {
	struct kobject___74 kobj;
	struct module___72 *mod;
	struct kobject___74 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___71 {
	struct module___72 *mod;
	struct latch_tree_node node;
};

struct module_layout___71 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___71 mtn;
};

struct module_attribute___71;

struct kernel_param___71;

struct trace_event_call___41;

struct module___72 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___71 mkobj;
	struct module_attribute___71 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___74 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___71 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___71 core_layout;
	struct module_layout___71 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___41 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___47 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___81 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___47)(struct perf_event___47 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___47;

struct fasync_struct___74;

struct pid_namespace___67;

struct perf_cgroup___47;

struct perf_event___47 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___47 *group_leader;
	struct pmu___47 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___47 hw;
	struct perf_event_context___47 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___47 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___81 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___74 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___47 *aux_event;
	void (*destroy)(struct perf_event___47 *);
	struct callback_head callback_head;
	struct pid_namespace___67 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___47 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___47 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___41 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___47 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___79 *pgtable_t___79;

struct address_space___74;

struct dev_pagemap___73;

struct page___79 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___74 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___79 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___79 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___80 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___73 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___73;

struct vm_area_struct___79 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___79 *vm_next;
	struct vm_area_struct___79 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___80 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___73 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___74 *vm_file;
	struct file___74 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___79;

struct mm_struct___80 {
	struct {
		struct vm_area_struct___79 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___74 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___79 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___81 *owner;
		struct user_namespace___12 *user_ns;
		struct file___74 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___74;

struct address_space___74 {
	struct inode___75 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___74 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___73;

struct dev_pagemap___73 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___73 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___74;

struct path___74 {
	struct vfsmount___74 *mnt;
	struct dentry___75 *dentry;
};

struct fown_struct___67 {
	rwlock_t lock;
	struct pid___67 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___74 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___74 f_path;
	struct inode___75 *f_inode;
	const struct file_operations___74 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___67 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___74 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___73;

struct vm_operations_struct___73 {
	void (*open)(struct vm_area_struct___79 *);
	void (*close)(struct vm_area_struct___79 *);
	int (*may_split)(struct vm_area_struct___79 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___79 *);
	int (*mprotect)(struct vm_area_struct___79 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___73 *);
	vm_fault_t (*huge_fault)(struct vm_fault___73 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___73 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___79 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___73 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___73 *);
	int (*access)(struct vm_area_struct___79 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___79 *);
	int (*set_policy)(struct vm_area_struct___79 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___79 *, long unsigned int);
	struct page___79 * (*find_special_page)(struct vm_area_struct___79 *, long unsigned int);
};

struct core_thread___79 {
	struct task_struct___81 *task;
	struct core_thread___79 *next;
};

struct core_state___79 {
	atomic_t nr_threads;
	struct core_thread___79 dumper;
	struct completion startup;
};

struct vm_fault___73 {
	const struct {
		struct vm_area_struct___79 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___79 *cow_page;
	struct page___79 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___79 prealloc_pte;
};

enum lruvec_flags {
	LRUVEC_CONGESTED = 0,
};

struct pglist_data___33;

struct lruvec___33 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___33 *pgdat;
};

struct zone___33 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___33 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___33 {
	struct zone___33 *zone;
	int zone_idx;
};

struct zonelist___33 {
	struct zoneref___33 _zonerefs[321];
};

struct pglist_data___33 {
	struct zone___33 node_zones[5];
	struct zonelist___33 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___81 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___81 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___33 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

enum pgdat_flags {
	PGDAT_DIRTY = 0,
	PGDAT_WRITEBACK = 1,
	PGDAT_RECLAIM_LOCKED = 2,
};

enum zone_flags {
	ZONE_BOOSTED_WATERMARK = 0,
	ZONE_RECLAIM_ACTIVE = 1,
};

typedef struct pglist_data___33 pg_data_t___4;

struct shrink_control___32 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___32 *memcg;
};

struct cgroup___62;

struct cgroup_subsys___62;

struct cgroup_subsys_state___62 {
	struct cgroup___62 *cgroup;
	struct cgroup_subsys___62 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___62 *parent;
};

struct cgroup_file___62 {
	struct kernfs_node___74 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___32;

struct mem_cgroup_per_node___32;

struct mem_cgroup___32 {
	struct cgroup_subsys_state___62 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___62 events_file;
	struct cgroup_file___62 events_local_file;
	struct cgroup_file___62 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___32 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___81 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___32 *nodeinfo[0];
	long: 64;
};

struct shrinker___32 {
	long unsigned int (*count_objects)(struct shrinker___32 *, struct shrink_control___32 *);
	long unsigned int (*scan_objects)(struct shrinker___32 *, struct shrink_control___32 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___73 {
	void (*page_free)(struct page___79 *);
	void (*kill)(struct dev_pagemap___73 *);
	void (*cleanup)(struct dev_pagemap___73 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___73 *);
};

struct upid___67 {
	int nr;
	struct pid_namespace___67 *ns;
};

struct pid_namespace___67 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___81 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___67 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___67 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___67 numbers[1];
};

struct signal_struct___75 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___81 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___81 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___67 *pids[4];
	struct pid___67 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___80 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___62;

struct nsproxy___72 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___67 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___62 *cgroup_ns;
};

struct bio___35;

struct bio_list___35 {
	struct bio___35 *head;
	struct bio___35 *tail;
};

struct bdi_writeback___34 {
	struct backing_dev_info___34 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___62 *memcg_css;
	struct cgroup_subsys_state___62 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___66;

struct backing_dev_info___34 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___34 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___66 *dev;
	char dev_name[64];
	struct device___66 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___75 *debug_dir;
};

struct io_cq___35;

struct io_context___35 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___35 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___4;

struct capture_control___4 {
	struct compact_control___4 *cc;
	struct page___79 *page;
};

struct css_set___62 {
	struct cgroup_subsys_state___62 *subsys[14];
	refcount_t refcount;
	struct css_set___62 *dom_cset;
	struct cgroup___62 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___62 *mg_src_cgrp;
	struct cgroup___62 *mg_dst_cgrp;
	struct css_set___62 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___47 {
	struct pmu___47 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___81 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___47 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___35;

struct blk_integrity___35 {
	const struct blk_integrity_profile___35 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___35 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___35 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___35;

struct elevator_queue___35;

struct blk_mq_ops___34;

struct blk_mq_hw_ctx___34;

struct gendisk___35;

struct blkcg_gq___34;

struct blk_mq_tag_set___34;

struct request_queue___36 {
	struct request___35 *last_merge;
	struct elevator_queue___35 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___34 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___34 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___35 *disk;
	struct kobject___74 kobj;
	struct kobject___74 *mq_kobj;
	struct blk_integrity___35 integrity;
	struct device___66 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___34 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___34 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___35 bio_split;
	struct dentry___75 *debugfs_dir;
	struct dentry___75 *sched_debugfs_dir;
	struct dentry___75 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___75 {
	struct vm_struct___75 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___79 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___74;

struct dentry___75 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___75 *d_parent;
	struct qstr d_name;
	struct inode___75 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___74 *d_op;
	struct super_block___75 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___74;

struct inode___75 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___74 *i_op;
	struct super_block___75 *i_sb;
	struct address_space___74 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___34 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___74 *i_fop;
		void (*free_inode)(struct inode___75 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___74 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___31 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___74 {
	int (*d_revalidate)(struct dentry___75 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___75 *, unsigned int);
	int (*d_hash)(const struct dentry___75 *, struct qstr *);
	int (*d_compare)(const struct dentry___75 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___75 *);
	int (*d_init)(struct dentry___75 *);
	void (*d_release)(struct dentry___75 *);
	void (*d_prune)(struct dentry___75 *);
	void (*d_iput)(struct dentry___75 *, struct inode___75 *);
	char * (*d_dname)(struct dentry___75 *, char *, int);
	struct vfsmount___74 * (*d_automount)(struct path___74 *);
	int (*d_manage)(const struct path___74 *, bool);
	struct dentry___75 * (*d_real)(struct dentry___75 *, const struct inode___75 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___74;

struct mem_dqinfo___74 {
	struct quota_format_type___74 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___74;

struct quota_info___74 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___75 *files[3];
	struct mem_dqinfo___74 info[3];
	const struct quota_format_ops___74 *ops[3];
};

struct rcuwait___75 {
	struct task_struct___81 *task;
};

struct percpu_rw_semaphore___75 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___75 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___74 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___75 rw_sem[3];
};

struct super_operations___74;

struct dquot_operations___74;

struct quotactl_ops___74;

struct block_device___36;

struct super_block___75 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___74 *s_type;
	const struct super_operations___74 *s_op;
	const struct dquot_operations___74 *dq_op;
	const struct quotactl_ops___74 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___75 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___36 *s_bdev;
	struct backing_dev_info___34 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___74 s_dquot;
	struct sb_writers___74 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___74 *s_d_op;
	int cleancache_poolid;
	struct shrinker___32 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___74 {
	struct dentry___75 *mnt_root;
	struct super_block___75 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct psi_group___62 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___81 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___62;

struct cgroup_rstat_cpu___62;

struct cgroup___62 {
	struct cgroup_subsys_state___62 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___74 *kn;
	struct cgroup_file___62 procs_file;
	struct cgroup_file___62 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___62 *subsys[14];
	struct cgroup_root___62 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___62 *dom_cgrp;
	struct cgroup___62 *old_dom_cgrp;
	struct cgroup_rstat_cpu___62 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___62 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___35 {
	struct request_queue___36 *q;
	struct io_context___35 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___32;

struct kiocb___74 {
	struct file___74 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___74 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___32 *ki_waitq;
	};
};

struct iattr___75 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___74 *ia_file;
};

struct dquot___74 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___75 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___74 {
	int qf_fmt_id;
	const struct quota_format_ops___74 *qf_ops;
	struct module___72 *qf_owner;
	struct quota_format_type___74 *qf_next;
};

struct quota_format_ops___74 {
	int (*check_quota_file)(struct super_block___75 *, int);
	int (*read_file_info)(struct super_block___75 *, int);
	int (*write_file_info)(struct super_block___75 *, int);
	int (*free_file_info)(struct super_block___75 *, int);
	int (*read_dqblk)(struct dquot___74 *);
	int (*commit_dqblk)(struct dquot___74 *);
	int (*release_dqblk)(struct dquot___74 *);
	int (*get_next_id)(struct super_block___75 *, struct kqid *);
};

struct dquot_operations___74 {
	int (*write_dquot)(struct dquot___74 *);
	struct dquot___74 * (*alloc_dquot)(struct super_block___75 *, int);
	void (*destroy_dquot)(struct dquot___74 *);
	int (*acquire_dquot)(struct dquot___74 *);
	int (*release_dquot)(struct dquot___74 *);
	int (*mark_dirty)(struct dquot___74 *);
	int (*write_info)(struct super_block___75 *, int);
	qsize_t * (*get_reserved_space)(struct inode___75 *);
	int (*get_projid)(struct inode___75 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___75 *, qsize_t *);
	int (*get_next_id)(struct super_block___75 *, struct kqid *);
};

struct quotactl_ops___74 {
	int (*quota_on)(struct super_block___75 *, int, int, const struct path___74 *);
	int (*quota_off)(struct super_block___75 *, int);
	int (*quota_enable)(struct super_block___75 *, unsigned int);
	int (*quota_disable)(struct super_block___75 *, unsigned int);
	int (*quota_sync)(struct super_block___75 *, int);
	int (*set_info)(struct super_block___75 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___75 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___75 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___75 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___75 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___75 *, unsigned int);
};

struct wait_page_queue___32 {
	struct page___79 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___34;

struct readahead_control___32;

struct swap_info_struct___20;

struct address_space_operations___74 {
	int (*writepage)(struct page___79 *, struct writeback_control___34 *);
	int (*readpage)(struct file___74 *, struct page___79 *);
	int (*writepages)(struct address_space___74 *, struct writeback_control___34 *);
	int (*set_page_dirty)(struct page___79 *);
	int (*readpages)(struct file___74 *, struct address_space___74 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___32 *);
	int (*write_begin)(struct file___74 *, struct address_space___74 *, loff_t, unsigned int, unsigned int, struct page___79 **, void **);
	int (*write_end)(struct file___74 *, struct address_space___74 *, loff_t, unsigned int, unsigned int, struct page___79 *, void *);
	sector_t (*bmap)(struct address_space___74 *, sector_t);
	void (*invalidatepage)(struct page___79 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___79 *, gfp_t);
	void (*freepage)(struct page___79 *);
	ssize_t (*direct_IO)(struct kiocb___74 *, struct iov_iter___45 *);
	int (*migratepage)(struct address_space___74 *, struct page___79 *, struct page___79 *, enum migrate_mode);
	bool (*isolate_page)(struct page___79 *, isolate_mode_t);
	void (*putback_page)(struct page___79 *);
	int (*launder_page)(struct page___79 *);
	int (*is_partially_uptodate)(struct page___79 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___79 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___74 *, struct page___79 *);
	int (*swap_activate)(struct swap_info_struct___20 *, struct file___74 *, sector_t *);
	void (*swap_deactivate)(struct file___74 *);
};

struct writeback_control___34 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___34 *wb;
	struct inode___75 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___32 {
	struct file___74 *file;
	struct address_space___74 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___44;

struct iov_iter___45 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___44 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___20 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___36 *bdev;
	struct file___74 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___74 {
	struct dentry___75 * (*lookup)(struct inode___75 *, struct dentry___75 *, unsigned int);
	const char * (*get_link)(struct dentry___75 *, struct inode___75 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___75 *, int);
	struct posix_acl * (*get_acl)(struct inode___75 *, int, bool);
	int (*readlink)(struct dentry___75 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___75 *, struct dentry___75 *, umode_t, bool);
	int (*link)(struct dentry___75 *, struct inode___75 *, struct dentry___75 *);
	int (*unlink)(struct inode___75 *, struct dentry___75 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___75 *, struct dentry___75 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___75 *, struct dentry___75 *, umode_t);
	int (*rmdir)(struct inode___75 *, struct dentry___75 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___75 *, struct dentry___75 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___75 *, struct dentry___75 *, struct inode___75 *, struct dentry___75 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___75 *, struct iattr___75 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___74 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___75 *, char *, size_t);
	int (*fiemap)(struct inode___75 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___75 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___75 *, struct dentry___75 *, struct file___74 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___75 *, struct dentry___75 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___75 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___75 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___75 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___74 {
	void (*fl_copy_lock)(struct file_lock___74 *, struct file_lock___74 *);
	void (*fl_release_private)(struct file_lock___74 *);
};

struct lock_manager_operations___74;

struct file_lock___74 {
	struct file_lock___74 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___74 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___74 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___74 *fl_ops;
	const struct lock_manager_operations___74 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___74 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___74 *);
	int (*lm_grant)(struct file_lock___74 *, int);
	bool (*lm_break)(struct file_lock___74 *);
	int (*lm_change)(struct file_lock___74 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___74 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___74 *);
};

struct fasync_struct___74 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___74 *fa_next;
	struct file___74 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___74 {
	struct inode___75 * (*alloc_inode)(struct super_block___75 *);
	void (*destroy_inode)(struct inode___75 *);
	void (*free_inode)(struct inode___75 *);
	void (*dirty_inode)(struct inode___75 *, int);
	int (*write_inode)(struct inode___75 *, struct writeback_control___34 *);
	int (*drop_inode)(struct inode___75 *);
	void (*evict_inode)(struct inode___75 *);
	void (*put_super)(struct super_block___75 *);
	int (*sync_fs)(struct super_block___75 *, int);
	int (*freeze_super)(struct super_block___75 *);
	int (*freeze_fs)(struct super_block___75 *);
	int (*thaw_super)(struct super_block___75 *);
	int (*unfreeze_fs)(struct super_block___75 *);
	int (*statfs)(struct dentry___75 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___75 *, int *, char *);
	void (*umount_begin)(struct super_block___75 *);
	int (*show_options)(struct seq_file___71 *, struct dentry___75 *);
	int (*show_devname)(struct seq_file___71 *, struct dentry___75 *);
	int (*show_path)(struct seq_file___71 *, struct dentry___75 *);
	int (*show_stats)(struct seq_file___71 *, struct dentry___75 *);
	ssize_t (*quota_read)(struct super_block___75 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___75 *, int, const char *, size_t, loff_t);
	struct dquot___74 ** (*get_dquots)(struct inode___75 *);
	long int (*nr_cached_objects)(struct super_block___75 *, struct shrink_control___32 *);
	long int (*free_cached_objects)(struct super_block___75 *, struct shrink_control___32 *);
	struct file___74 * (*real_loop)(struct file___74 *);
};

struct wakeup_source___66;

struct dev_pm_info___66 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___66 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___66 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___66;

struct bus_type___66;

struct device_driver___66;

struct dev_pm_domain___66;

struct fwnode_handle___66;

struct class___66;

struct attribute_group___74;

struct device___66 {
	struct kobject___74 kobj;
	struct device___66 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___66 *type;
	struct bus_type___66 *bus;
	struct device_driver___66 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___66 power;
	struct dev_pm_domain___66 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___66 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___66 *class;
	const struct attribute_group___74 **groups;
	void (*release)(struct device___66 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___36 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___75 *bd_inode;
	struct super_block___75 *bd_super;
	void *bd_claiming;
	struct device___66 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___74 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___35 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___75 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___56)(struct file___74 *, wait_queue_head_t *, struct poll_table_struct___56 *);

struct poll_table_struct___56 {
	poll_queue_proc___56 _qproc;
	__poll_t _key;
};

struct seq_operations___71;

struct seq_file___71 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___71 *op;
	int poll_event;
	const struct file___74 *file;
	void *private;
};

typedef void bio_end_io_t___35(struct bio___35 *);

struct bio_vec___44 {
	struct page___79 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___35;

struct bio___35 {
	struct bio___35 *bi_next;
	struct block_device___36 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___35 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___34 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___35 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___44 *bi_io_vec;
	struct bio_set___35 *bi_pool;
	struct bio_vec___44 bi_inline_vecs[0];
};

typedef void compound_page_dtor___2(struct page___79 *);

struct reclaim_stat {
	unsigned int nr_dirty;
	unsigned int nr_unqueued_dirty;
	unsigned int nr_congested;
	unsigned int nr_writeback;
	unsigned int nr_immediate;
	unsigned int nr_pageout;
	unsigned int nr_activate[2];
	unsigned int nr_ref_keep;
	unsigned int nr_unmap_fail;
	unsigned int nr_lazyfree_fail;
};

struct kernfs_root___74;

struct kernfs_elem_dir___74 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___74 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___74;

struct kernfs_root___74 {
	struct kernfs_node___74 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___74 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___74 {
	struct kernfs_node___74 *target_kn;
};

struct kernfs_ops___74;

struct kernfs_elem_attr___74 {
	const struct kernfs_ops___74 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___74 *notify_next;
};

struct kernfs_node___74 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___74 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___74 dir;
		struct kernfs_elem_symlink___74 symlink;
		struct kernfs_elem_attr___74 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___74;

struct kernfs_ops___74 {
	int (*open)(struct kernfs_open_file___74 *);
	void (*release)(struct kernfs_open_file___74 *);
	int (*seq_show)(struct seq_file___71 *, void *);
	void * (*seq_start)(struct seq_file___71 *, loff_t *);
	void * (*seq_next)(struct seq_file___71 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___71 *, void *);
	ssize_t (*read)(struct kernfs_open_file___74 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___74 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___74 *, struct poll_table_struct___56 *);
	int (*mmap)(struct kernfs_open_file___74 *, struct vm_area_struct___79 *);
};

struct kernfs_syscall_ops___74 {
	int (*show_options)(struct seq_file___71 *, struct kernfs_root___74 *);
	int (*mkdir)(struct kernfs_node___74 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___74 *);
	int (*rename)(struct kernfs_node___74 *, struct kernfs_node___74 *, const char *);
	int (*show_path)(struct seq_file___71 *, struct kernfs_node___74 *, struct kernfs_root___74 *);
};

struct kernfs_open_file___74 {
	struct kernfs_node___74 *kn;
	struct file___74 *file;
	struct seq_file___71 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___73 *vm_ops;
};

struct bin_attribute___74;

struct attribute_group___74 {
	const char *name;
	umode_t (*is_visible)(struct kobject___74 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___74 *, struct bin_attribute___74 *, int);
	struct attribute **attrs;
	struct bin_attribute___74 **bin_attrs;
};

struct bin_attribute___74 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___74 * (*f_mapping)();
	ssize_t (*read)(struct file___74 *, struct kobject___74 *, struct bin_attribute___74 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___74 *, struct kobject___74 *, struct bin_attribute___74 *, char *, loff_t, size_t);
	int (*mmap)(struct file___74 *, struct kobject___74 *, struct bin_attribute___74 *, struct vm_area_struct___79 *);
};

struct sysfs_ops___74 {
	ssize_t (*show)(struct kobject___74 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___74 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___74;

struct kset___74 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___74 kobj;
	const struct kset_uevent_ops___74 *uevent_ops;
};

struct kobj_type___74 {
	void (*release)(struct kobject___74 *);
	const struct sysfs_ops___74 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___74 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___74 *);
	const void * (*namespace)(struct kobject___74 *);
	void (*get_ownership)(struct kobject___74 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___74 {
	int (* const filter)(struct kset___74 *, struct kobject___74 *);
	const char * (* const name)(struct kset___74 *, struct kobject___74 *);
	int (* const uevent)(struct kset___74 *, struct kobject___74 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___71 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___71 *);
	int (*get)(char *, const struct kernel_param___71 *);
	void (*free)(void *);
};

struct kparam_array___71;

struct kernel_param___71 {
	const char *name;
	struct module___72 *mod;
	const struct kernel_param_ops___71 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___71 *arr;
	};
};

struct kparam_array___71 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___71 *ops;
	void *elem;
};

struct module_attribute___71 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___71 *, struct module_kobject___71 *, char *);
	ssize_t (*store)(struct module_attribute___71 *, struct module_kobject___71 *, const char *, size_t);
	void (*setup)(struct module___72 *, const char *);
	int (*test)(struct module___72 *);
	void (*free)(struct module___72 *);
};

struct trace_event_class___41;

struct trace_event_call___41 {
	struct list_head list;
	struct trace_event_class___41 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___41 *, struct perf_event___47 *);
};

struct fwnode_operations___66;

struct fwnode_handle___66 {
	struct fwnode_handle___66 *secondary;
	const struct fwnode_operations___66 *ops;
	struct device___66 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___66;

struct fwnode_endpoint___66;

struct fwnode_operations___66 {
	struct fwnode_handle___66 * (*get)(struct fwnode_handle___66 *);
	void (*put)(struct fwnode_handle___66 *);
	bool (*device_is_available)(const struct fwnode_handle___66 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___66 *, const struct device___66 *);
	bool (*property_present)(const struct fwnode_handle___66 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___66 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___66 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___66 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*get_parent)(const struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*get_next_child_node)(const struct fwnode_handle___66 *, struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*get_named_child_node)(const struct fwnode_handle___66 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___66 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___66 *);
	struct fwnode_handle___66 * (*graph_get_next_endpoint)(const struct fwnode_handle___66 *, struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*graph_get_remote_endpoint)(const struct fwnode_handle___66 *);
	struct fwnode_handle___66 * (*graph_get_port_parent)(struct fwnode_handle___66 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___66 *, struct fwnode_endpoint___66 *);
	int (*add_links)(struct fwnode_handle___66 *);
};

struct fwnode_endpoint___66 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___66 *local_fwnode;
};

struct fwnode_reference_args___66 {
	struct fwnode_handle___66 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___71 {
	void * (*start)(struct seq_file___71 *, loff_t *);
	void (*stop)(struct seq_file___71 *, void *);
	void * (*next)(struct seq_file___71 *, void *, loff_t *);
	int (*show)(struct seq_file___71 *, void *);
};

struct cgroup_namespace___62 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___62 *root_cset;
};

struct cftype___62;

struct cgroup_subsys___62 {
	struct cgroup_subsys_state___62 * (*css_alloc)(struct cgroup_subsys_state___62 *);
	int (*css_online)(struct cgroup_subsys_state___62 *);
	void (*css_offline)(struct cgroup_subsys_state___62 *);
	void (*css_released)(struct cgroup_subsys_state___62 *);
	void (*css_free)(struct cgroup_subsys_state___62 *);
	void (*css_reset)(struct cgroup_subsys_state___62 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___62 *, int);
	int (*css_extra_stat_show)(struct seq_file___71 *, struct cgroup_subsys_state___62 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___81 *, struct css_set___62 *);
	void (*cancel_fork)(struct task_struct___81 *, struct css_set___62 *);
	void (*fork)(struct task_struct___81 *);
	void (*exit)(struct task_struct___81 *);
	void (*release)(struct task_struct___81 *);
	void (*bind)(struct cgroup_subsys_state___62 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___62 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___62 *dfl_cftypes;
	struct cftype___62 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___62 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___62 *updated_children;
	struct cgroup___62 *updated_next;
};

struct cgroup_root___62 {
	struct kernfs_root___74 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___62 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___62 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___62 *ss;
	struct list_head node;
	struct kernfs_ops___74 *kf_ops;
	int (*open)(struct kernfs_open_file___74 *);
	void (*release)(struct kernfs_open_file___74 *);
	u64 (*read_u64)(struct cgroup_subsys_state___62 *, struct cftype___62 *);
	s64 (*read_s64)(struct cgroup_subsys_state___62 *, struct cftype___62 *);
	int (*seq_show)(struct seq_file___71 *, void *);
	void * (*seq_start)(struct seq_file___71 *, loff_t *);
	void * (*seq_next)(struct seq_file___71 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___71 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___62 *, struct cftype___62 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___62 *, struct cftype___62 *, s64);
	ssize_t (*write)(struct kernfs_open_file___74 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___74 *, struct poll_table_struct___56 *);
};

struct dev_pm_ops___66 {
	int (*prepare)(struct device___66 *);
	void (*complete)(struct device___66 *);
	int (*suspend)(struct device___66 *);
	int (*resume)(struct device___66 *);
	int (*freeze)(struct device___66 *);
	int (*thaw)(struct device___66 *);
	int (*poweroff)(struct device___66 *);
	int (*restore)(struct device___66 *);
	int (*suspend_late)(struct device___66 *);
	int (*resume_early)(struct device___66 *);
	int (*freeze_late)(struct device___66 *);
	int (*thaw_early)(struct device___66 *);
	int (*poweroff_late)(struct device___66 *);
	int (*restore_early)(struct device___66 *);
	int (*suspend_noirq)(struct device___66 *);
	int (*resume_noirq)(struct device___66 *);
	int (*freeze_noirq)(struct device___66 *);
	int (*thaw_noirq)(struct device___66 *);
	int (*poweroff_noirq)(struct device___66 *);
	int (*restore_noirq)(struct device___66 *);
	int (*runtime_suspend)(struct device___66 *);
	int (*runtime_resume)(struct device___66 *);
	int (*runtime_idle)(struct device___66 *);
};

struct wakeup_source___66 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___66 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___66 {
	struct dev_pm_ops___66 ops;
	int (*start)(struct device___66 *);
	void (*detach)(struct device___66 *, bool);
	int (*activate)(struct device___66 *);
	void (*sync)(struct device___66 *);
	void (*dismiss)(struct device___66 *);
};

struct bus_type___66 {
	const char *name;
	const char *dev_name;
	struct device___66 *dev_root;
	const struct attribute_group___74 **bus_groups;
	const struct attribute_group___74 **dev_groups;
	const struct attribute_group___74 **drv_groups;
	int (*match)(struct device___66 *, struct device_driver___66 *);
	int (*uevent)(struct device___66 *, struct kobj_uevent_env *);
	int (*probe)(struct device___66 *);
	void (*sync_state)(struct device___66 *);
	void (*remove)(struct device___66 *);
	void (*shutdown)(struct device___66 *);
	int (*online)(struct device___66 *);
	int (*offline)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	int (*num_vf)(struct device___66 *);
	int (*dma_configure)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___66 {
	const char *name;
	struct bus_type___66 *bus;
	struct module___72 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___66 *);
	void (*sync_state)(struct device___66 *);
	int (*remove)(struct device___66 *);
	void (*shutdown)(struct device___66 *);
	int (*suspend)(struct device___66 *, pm_message_t);
	int (*resume)(struct device___66 *);
	const struct attribute_group___74 **groups;
	const struct attribute_group___74 **dev_groups;
	const struct dev_pm_ops___66 *pm;
	void (*coredump)(struct device___66 *);
	struct driver_private *p;
};

struct device_type___66 {
	const char *name;
	const struct attribute_group___74 **groups;
	int (*uevent)(struct device___66 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___66 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___66 *);
	const struct dev_pm_ops___66 *pm;
};

struct class___66 {
	const char *name;
	struct module___72 *owner;
	const struct attribute_group___74 **class_groups;
	const struct attribute_group___74 **dev_groups;
	struct kobject___74 *dev_kobj;
	int (*dev_uevent)(struct device___66 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___66 *, umode_t *);
	void (*class_release)(struct class___66 *);
	void (*dev_release)(struct device___66 *);
	int (*shutdown_pre)(struct device___66 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___66 *);
	void (*get_ownership)(struct device___66 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___66 *pm;
	struct subsys_private *p;
};

struct block_device_operations___35;

struct gendisk___35 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___36 *part0;
	const struct block_device_operations___35 *fops;
	struct request_queue___36 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___34 *bdi;
	struct kobject___74 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___74 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___35 {
	struct bio___35 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___44 *bip_vec;
	struct bio_vec___44 bip_inline_vecs[0];
};

struct blkcg___34;

struct blkg_policy_data___34;

struct blkcg_gq___34 {
	struct request_queue___36 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___34 *blkcg;
	struct blkcg_gq___34 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___34 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___35 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___35(struct request___35 *);

typedef void integrity_complete_fn___35(struct request___35 *, unsigned int);

struct blk_integrity_profile___35 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___35 *prepare_fn;
	integrity_complete_fn___35 *complete_fn;
	const char *name;
};

struct block_device_operations___35 {
	blk_qc_t (*submit_bio)(struct bio___35 *);
	int (*open)(struct block_device___36 *, fmode_t);
	void (*release)(struct gendisk___35 *, fmode_t);
	int (*rw_page)(struct block_device___36 *, sector_t, struct page___79 *, unsigned int);
	int (*ioctl)(struct block_device___36 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___36 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___35 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___35 *);
	int (*getgeo)(struct block_device___36 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___36 *, bool);
	void (*swap_slot_free_notify)(struct block_device___36 *, long unsigned int);
	int (*report_zones)(struct gendisk___35 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___35 *, umode_t *);
	struct module___72 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___35 *, sector_t *);
};

typedef void rq_end_io_fn___35(struct request___35 *, blk_status_t);

struct request___35 {
	struct request_queue___36 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___34 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___35 *bio;
	struct bio___35 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___44 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___35 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___35 *saved_end_io;
		} flush;
	};
	struct gendisk___35 *rq_disk;
	struct block_device___36 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___35 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___34 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___36 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___74 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___75 *debugfs_dir;
	struct dentry___75 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___35;

struct elevator_mq_ops___35 {
	int (*init_sched)(struct request_queue___36 *, struct elevator_type___35 *);
	void (*exit_sched)(struct elevator_queue___35 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___34 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___34 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___34 *);
	bool (*allow_merge)(struct request_queue___36 *, struct request___35 *, struct bio___35 *);
	bool (*bio_merge)(struct request_queue___36 *, struct bio___35 *, unsigned int);
	int (*request_merge)(struct request_queue___36 *, struct request___35 **, struct bio___35 *);
	void (*request_merged)(struct request_queue___36 *, struct request___35 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___36 *, struct request___35 *, struct request___35 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___35 *);
	void (*finish_request)(struct request___35 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___34 *, struct list_head *, bool);
	struct request___35 * (*dispatch_request)(struct blk_mq_hw_ctx___34 *);
	bool (*has_work)(struct blk_mq_hw_ctx___34 *);
	void (*completed_request)(struct request___35 *, u64);
	void (*requeue_request)(struct request___35 *);
	struct request___35 * (*former_request)(struct request_queue___36 *, struct request___35 *);
	struct request___35 * (*next_request)(struct request_queue___36 *, struct request___35 *);
	void (*init_icq)(struct io_cq___35 *);
	void (*exit_icq)(struct io_cq___35 *);
};

struct elv_fs_entry___35;

struct elevator_type___35 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___35 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___35 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___72 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___35 {
	struct elevator_type___35 *type;
	void *elevator_data;
	struct kobject___74 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___35 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___35 *, char *);
	ssize_t (*store)(struct elevator_queue___35 *, const char *, size_t);
};

struct blk_mq_queue_data___34;

struct blk_mq_ops___34 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___34 *, const struct blk_mq_queue_data___34 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___34 *);
	int (*get_budget)(struct request_queue___36 *);
	void (*put_budget)(struct request_queue___36 *, int);
	void (*set_rq_budget_token)(struct request___35 *, int);
	int (*get_rq_budget_token)(struct request___35 *);
	enum blk_eh_timer_return (*timeout)(struct request___35 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___34 *);
	void (*complete)(struct request___35 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___34 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___34 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___34 *, struct request___35 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___34 *, struct request___35 *, unsigned int);
	void (*initialize_rq_fn)(struct request___35 *);
	void (*cleanup_rq)(struct request___35 *);
	bool (*busy)(struct request_queue___36 *);
	int (*map_queues)(struct blk_mq_tag_set___34 *);
	void (*show_rq)(struct seq_file___71 *, struct request___35 *);
};

struct blk_mq_tag_set___34 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___34 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___34 {
	struct request___35 *rq;
	bool last;
};

struct blkcg_policy_data___34;

struct blkcg___34 {
	struct cgroup_subsys_state___62 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___34 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___34 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___34 {
	struct blkcg___34 *blkcg;
	int plid;
};

struct blkg_policy_data___34 {
	struct blkcg_gq___34 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_cookie {
	pg_data_t___4 *pgdat;
	unsigned int generation;
};

struct mem_cgroup_reclaim_iter___32 {
	struct mem_cgroup___32 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___32 {
	struct lruvec___33 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___32 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___32 *memcg;
};

struct obj_cgroup___32 {
	struct percpu_ref refcnt;
	struct mem_cgroup___32 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum ttu_flags {
	TTU_SPLIT_HUGE_PMD = 4,
	TTU_IGNORE_MLOCK = 8,
	TTU_SYNC = 16,
	TTU_IGNORE_HWPOISON = 32,
	TTU_BATCH_FLUSH = 64,
	TTU_RMAP_LOCKED = 128,
};

typedef struct page___79 *new_page_t(struct page___79 *, long unsigned int);

typedef void free_page_t(struct page___79 *, long unsigned int);

struct pagevec___3 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___79 *pages[15];
};

struct compact_control___4 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___33 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct migration_target_control {
	int nid;
	nodemask_t *nmask;
	gfp_t gfp_mask;
};

struct perf_cpu_context___47;

struct perf_output_handle___47;

struct pmu___47 {
	struct list_head entry;
	struct module___72 *module;
	struct device___66 *dev;
	const struct attribute_group___74 **attr_groups;
	const struct attribute_group___74 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___47 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___47 *);
	void (*pmu_disable)(struct pmu___47 *);
	int (*event_init)(struct perf_event___47 *);
	void (*event_mapped)(struct perf_event___47 *, struct mm_struct___80 *);
	void (*event_unmapped)(struct perf_event___47 *, struct mm_struct___80 *);
	int (*add)(struct perf_event___47 *, int);
	void (*del)(struct perf_event___47 *, int);
	void (*start)(struct perf_event___47 *, int);
	void (*stop)(struct perf_event___47 *, int);
	void (*read)(struct perf_event___47 *);
	void (*start_txn)(struct pmu___47 *, unsigned int);
	int (*commit_txn)(struct pmu___47 *);
	void (*cancel_txn)(struct pmu___47 *);
	int (*event_idx)(struct perf_event___47 *);
	void (*sched_task)(struct perf_event_context___47 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___47 *, struct perf_event_context___47 *);
	void * (*setup_aux)(struct perf_event___47 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___47 *, struct perf_output_handle___47 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___47 *);
	int (*aux_output_match)(struct perf_event___47 *);
	int (*filter_match)(struct perf_event___47 *);
	int (*check_period)(struct perf_event___47 *, u64);
};

struct perf_cpu_context___47 {
	struct perf_event_context___47 ctx;
	struct perf_event_context___47 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___47 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___47 **heap;
	struct perf_event___47 *heap_default[2];
};

struct perf_output_handle___47 {
	struct perf_event___47 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___47 {
	struct cgroup_subsys_state___62 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___41 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___41 *);
	};
};

struct trace_event_class___41 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___41 *, enum trace_reg, void *);
	struct trace_event_fields___41 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___41 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___41 *);
};

struct trace_event_file___21;

struct trace_event_buffer___20 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___21 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___21 {
	struct list_head list;
	struct trace_event_call___41 *event_call;
	struct event_filter *filter;
	struct dentry___75 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_vmscan_kswapd_sleep {
	struct trace_entry ent;
	int nid;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_kswapd_wake {
	struct trace_entry ent;
	int nid;
	int zid;
	int order;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_wakeup_kswapd {
	struct trace_entry ent;
	int nid;
	int zid;
	int order;
	gfp_t gfp_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_direct_reclaim_begin_template {
	struct trace_entry ent;
	int order;
	gfp_t gfp_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_direct_reclaim_end_template {
	struct trace_entry ent;
	long unsigned int nr_reclaimed;
	char __data[0];
};

struct trace_event_raw_mm_shrink_slab_start {
	struct trace_entry ent;
	struct shrinker___32 *shr;
	void *shrink;
	int nid;
	long int nr_objects_to_shrink;
	gfp_t gfp_flags;
	long unsigned int cache_items;
	long long unsigned int delta;
	long unsigned int total_scan;
	int priority;
	char __data[0];
};

struct trace_event_raw_mm_shrink_slab_end {
	struct trace_entry ent;
	struct shrinker___32 *shr;
	int nid;
	void *shrink;
	long int unused_scan;
	long int new_scan;
	int retval;
	long int total_scan;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_lru_isolate {
	struct trace_entry ent;
	int highest_zoneidx;
	int order;
	long unsigned int nr_requested;
	long unsigned int nr_scanned;
	long unsigned int nr_skipped;
	long unsigned int nr_taken;
	isolate_mode_t isolate_mode;
	int lru;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_writepage {
	struct trace_entry ent;
	long unsigned int pfn;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_lru_shrink_inactive {
	struct trace_entry ent;
	int nid;
	long unsigned int nr_scanned;
	long unsigned int nr_reclaimed;
	long unsigned int nr_dirty;
	long unsigned int nr_writeback;
	long unsigned int nr_congested;
	long unsigned int nr_immediate;
	unsigned int nr_activate0;
	unsigned int nr_activate1;
	long unsigned int nr_ref_keep;
	long unsigned int nr_unmap_fail;
	int priority;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_lru_shrink_active {
	struct trace_entry ent;
	int nid;
	long unsigned int nr_taken;
	long unsigned int nr_active;
	long unsigned int nr_deactivated;
	long unsigned int nr_referenced;
	int priority;
	int reclaim_flags;
	char __data[0];
};

struct trace_event_raw_mm_vmscan_node_reclaim_begin {
	struct trace_entry ent;
	int nid;
	int order;
	gfp_t gfp_flags;
	char __data[0];
};

struct trace_event_data_offsets_mm_vmscan_kswapd_sleep {};

struct trace_event_data_offsets_mm_vmscan_kswapd_wake {};

struct trace_event_data_offsets_mm_vmscan_wakeup_kswapd {};

struct trace_event_data_offsets_mm_vmscan_direct_reclaim_begin_template {};

struct trace_event_data_offsets_mm_vmscan_direct_reclaim_end_template {};

struct trace_event_data_offsets_mm_shrink_slab_start {};

struct trace_event_data_offsets_mm_shrink_slab_end {};

struct trace_event_data_offsets_mm_vmscan_lru_isolate {};

struct trace_event_data_offsets_mm_vmscan_writepage {};

struct trace_event_data_offsets_mm_vmscan_lru_shrink_inactive {};

struct trace_event_data_offsets_mm_vmscan_lru_shrink_active {};

struct trace_event_data_offsets_mm_vmscan_node_reclaim_begin {};

typedef void (*btf_trace_mm_vmscan_kswapd_sleep)(void *, int);

typedef void (*btf_trace_mm_vmscan_kswapd_wake)(void *, int, int, int);

typedef void (*btf_trace_mm_vmscan_wakeup_kswapd)(void *, int, int, int, gfp_t);

typedef void (*btf_trace_mm_vmscan_direct_reclaim_begin)(void *, int, gfp_t);

typedef void (*btf_trace_mm_vmscan_memcg_reclaim_begin)(void *, int, gfp_t);

typedef void (*btf_trace_mm_vmscan_memcg_softlimit_reclaim_begin)(void *, int, gfp_t);

typedef void (*btf_trace_mm_vmscan_direct_reclaim_end)(void *, long unsigned int);

typedef void (*btf_trace_mm_vmscan_memcg_reclaim_end)(void *, long unsigned int);

typedef void (*btf_trace_mm_vmscan_memcg_softlimit_reclaim_end)(void *, long unsigned int);

typedef void (*btf_trace_mm_shrink_slab_start)(void *, struct shrinker___32 *, struct shrink_control___32 *, long int, long unsigned int, long long unsigned int, long unsigned int, int);

typedef void (*btf_trace_mm_shrink_slab_end)(void *, struct shrinker___32 *, int, int, long int, long int, long int);

typedef void (*btf_trace_mm_vmscan_lru_isolate)(void *, int, int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, isolate_mode_t, int);

typedef void (*btf_trace_mm_vmscan_writepage)(void *, struct page___79 *);

typedef void (*btf_trace_mm_vmscan_lru_shrink_inactive)(void *, int, long unsigned int, long unsigned int, struct reclaim_stat *, int, int);

typedef void (*btf_trace_mm_vmscan_lru_shrink_active)(void *, int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, int, int);

typedef void (*btf_trace_mm_vmscan_node_reclaim_begin)(void *, int, int, gfp_t);

typedef void (*btf_trace_mm_vmscan_node_reclaim_end)(void *, long unsigned int);

struct scan_control {
	long unsigned int nr_to_reclaim;
	nodemask_t *nodemask;
	struct mem_cgroup___32 *target_mem_cgroup;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	unsigned int may_deactivate: 2;
	unsigned int force_deactivate: 1;
	unsigned int skipped_deactivate: 1;
	unsigned int may_writepage: 1;
	unsigned int may_unmap: 1;
	unsigned int may_swap: 1;
	unsigned int memcg_low_reclaim: 1;
	unsigned int memcg_low_skipped: 1;
	unsigned int hibernation_mode: 1;
	unsigned int compaction_ready: 1;
	unsigned int cache_trim_mode: 1;
	unsigned int file_is_tiny: 1;
	unsigned int no_demotion: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	s8 order;
	s8 priority;
	s8 reclaim_idx;
	gfp_t gfp_mask;
	long unsigned int nr_scanned;
	long unsigned int nr_reclaimed;
	struct {
		unsigned int dirty;
		unsigned int unqueued_dirty;
		unsigned int congested;
		unsigned int writeback;
		unsigned int immediate;
		unsigned int file_taken;
		unsigned int taken;
	} nr;
	struct reclaim_state reclaim_state;
};

typedef enum {
	PAGE_KEEP = 0,
	PAGE_ACTIVATE = 1,
	PAGE_SUCCESS = 2,
	PAGE_CLEAN = 3,
} pageout_t;

enum page_references {
	PAGEREF_RECLAIM = 0,
	PAGEREF_RECLAIM_CLEAN = 1,
	PAGEREF_KEEP = 2,
	PAGEREF_ACTIVATE = 3,
};

enum scan_balance {
	SCAN_EQUAL = 0,
	SCAN_FRACT = 1,
	SCAN_ANON = 2,
	SCAN_FILE = 3,
};

struct fs_context___12;

struct fs_parameter_spec___11;

struct module___73;

struct file_system_type___75 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___12 *);
	const struct fs_parameter_spec___11 *parameters;
	struct dentry___2 * (*mount)(struct file_system_type___75 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___2 *);
	struct module___73 *owner;
	struct file_system_type___75 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___75;

struct kiocb___75;

struct iov_iter___46;

struct poll_table_struct___57;

struct vm_area_struct___80;

struct file_lock___75;

struct page___80;

struct pipe_inode_info___32;

struct seq_file___72;

struct file_operations___75 {
	struct module___73 *owner;
	loff_t (*llseek)(struct file___75 *, loff_t, int);
	ssize_t (*read)(struct file___75 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___75 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___75 *, struct iov_iter___46 *);
	ssize_t (*write_iter)(struct kiocb___75 *, struct iov_iter___46 *);
	int (*iopoll)(struct kiocb___75 *, bool);
	int (*iterate)(struct file___75 *, struct dir_context *);
	int (*iterate_shared)(struct file___75 *, struct dir_context *);
	__poll_t (*poll)(struct file___75 *, struct poll_table_struct___57 *);
	long int (*unlocked_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___75 *, struct vm_area_struct___80 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___2 *, struct file___75 *);
	int (*flush)(struct file___75 *, fl_owner_t);
	int (*release)(struct inode___2 *, struct file___75 *);
	int (*fsync)(struct file___75 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___75 *, int);
	int (*lock)(struct file___75 *, int, struct file_lock___75 *);
	ssize_t (*sendpage)(struct file___75 *, struct page___80 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___75 *, long unsigned int);
	int (*flock)(struct file___75 *, int, struct file_lock___75 *);
	ssize_t (*splice_write)(struct pipe_inode_info___32 *, struct file___75 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___75 *, loff_t *, struct pipe_inode_info___32 *, size_t, unsigned int);
	int (*setlease)(struct file___75 *, long int, struct file_lock___75 **, void **);
	long int (*fallocate)(struct file___75 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___72 *, struct file___75 *);
	ssize_t (*copy_file_range)(struct file___75 *, loff_t, struct file___75 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___75 *, loff_t, struct file___75 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___75 *, loff_t, loff_t, int);
};

struct vmacache___80 {
	u64 seqnum;
	struct vm_area_struct___80 *vmas[4];
};

struct page_frag___80 {
	struct page___80 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___48;

struct debug_info___48 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___48 *hbp_break[16];
	struct perf_event___48 *hbp_watch[16];
};

struct thread_struct___48 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___48 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___81;

struct pid___68;

struct nsproxy___73;

struct signal_struct___76;

struct bio_list___36;

struct backing_dev_info___35;

struct io_context___36;

struct capture_control___5;

struct css_set___63;

struct perf_event_context___48;

struct mem_cgroup___33;

struct vm_struct___76;

struct task_struct___82 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___82 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___81 *mm;
	struct mm_struct___81 *active_mm;
	struct vmacache___80 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___82 *real_parent;
	struct task_struct___82 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___82 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___68 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___73 *nsproxy;
	struct signal_struct___76 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___82 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___36 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___35 *backing_dev_info;
	struct io_context___36 *io_context;
	struct capture_control___5 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___63 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___48 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___32 *splice_pipe;
	struct page_frag___80 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___33 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___33 *active_memcg;
	struct request_queue___2 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___82 *oom_reaper_list;
	struct vm_struct___76 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___48 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___75;

struct kobj_type___75;

struct kernfs_node___75;

struct kobject___75 {
	const char *name;
	struct list_head entry;
	struct kobject___75 *parent;
	struct kset___75 *kset;
	struct kobj_type___75 *ktype;
	struct kernfs_node___75 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___72 {
	struct kobject___75 kobj;
	struct module___73 *mod;
	struct kobject___75 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___72 {
	struct module___73 *mod;
	struct latch_tree_node node;
};

struct module_layout___72 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___72 mtn;
};

struct module_attribute___72;

struct kernel_param___72;

struct trace_event_call___42;

struct module___73 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___72 mkobj;
	struct module_attribute___72 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___75 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___72 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___72 core_layout;
	struct module_layout___72 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___42 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___48 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___82 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___48)(struct perf_event___48 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___48;

struct fasync_struct___75;

struct pid_namespace___68;

struct perf_cgroup___48;

struct perf_event___48 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___48 *group_leader;
	struct pmu___48 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___48 hw;
	struct perf_event_context___48 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___48 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___82 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___75 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___48 *aux_event;
	void (*destroy)(struct perf_event___48 *);
	struct callback_head callback_head;
	struct pid_namespace___68 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___48 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___48 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___42 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___48 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___75;

struct dentry___2 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___2 *d_parent;
	struct qstr d_name;
	struct inode___2 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___75 *d_op;
	struct super_block___2 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___75;

struct address_space___75 {
	struct inode___2 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___75 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___75;

struct bdi_writeback___35;

struct inode___2 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___75 *i_op;
	struct super_block___2 *i_sb;
	struct address_space___75 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___35 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___75 *i_fop;
		void (*free_inode)(struct inode___2 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___75 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___75;

struct path___75;

struct dentry_operations___75 {
	int (*d_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___2 *, unsigned int);
	int (*d_hash)(const struct dentry___2 *, struct qstr *);
	int (*d_compare)(const struct dentry___2 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___2 *);
	int (*d_init)(struct dentry___2 *);
	void (*d_release)(struct dentry___2 *);
	void (*d_prune)(struct dentry___2 *);
	void (*d_iput)(struct dentry___2 *, struct inode___2 *);
	char * (*d_dname)(struct dentry___2 *, char *, int);
	struct vfsmount___75 * (*d_automount)(struct path___75 *);
	int (*d_manage)(const struct path___75 *, bool);
	struct dentry___2 * (*d_real)(struct dentry___2 *, const struct inode___2 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___75;

struct mem_dqinfo___75 {
	struct quota_format_type___75 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___75;

struct quota_info___75 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___2 *files[3];
	struct mem_dqinfo___75 info[3];
	const struct quota_format_ops___75 *ops[3];
};

struct rcuwait___76 {
	struct task_struct___82 *task;
};

struct percpu_rw_semaphore___76 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___76 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___75 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___76 rw_sem[3];
};

struct shrink_control___33;

struct shrinker___33 {
	long unsigned int (*count_objects)(struct shrinker___33 *, struct shrink_control___33 *);
	long unsigned int (*scan_objects)(struct shrinker___33 *, struct shrink_control___33 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___75;

struct dquot_operations___75;

struct quotactl_ops___75;

struct xattr_handler___6;

struct block_device___37;

struct super_block___2 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___75 *s_type;
	const struct super_operations___75 *s_op;
	const struct dquot_operations___75 *dq_op;
	const struct quotactl_ops___75 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___2 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___6 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___37 *s_bdev;
	struct backing_dev_info___35 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___75 s_dquot;
	struct sb_writers___75 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___75 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___75 {
	struct dentry___2 *mnt_root;
	struct super_block___2 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct path___75 {
	struct vfsmount___75 *mnt;
	struct dentry___2 *dentry;
};

struct upid___68 {
	int nr;
	struct pid_namespace___68 *ns;
};

struct pid_namespace___68 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___82 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___68 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___68 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___68 numbers[1];
};

typedef struct page___80 *pgtable_t___80;

struct dev_pagemap___74;

struct page___80 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___75 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___80 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___80 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___81 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___74 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___74;

struct vm_area_struct___80 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___80 *vm_next;
	struct vm_area_struct___80 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___81 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___74 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___75 *vm_file;
	struct file___75 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___76 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___82 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___82 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___68 *pids[4];
	struct pid___68 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___81 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___80;

struct mm_struct___81 {
	struct {
		struct vm_area_struct___80 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___80 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___82 *owner;
		struct user_namespace___12 *user_ns;
		struct file___75 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___63;

struct nsproxy___73 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___68 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___63 *cgroup_ns;
};

struct bio___36;

struct bio_list___36 {
	struct bio___36 *head;
	struct bio___36 *tail;
};

struct cgroup_subsys_state___63;

struct bdi_writeback___35 {
	struct backing_dev_info___35 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___63 *memcg_css;
	struct cgroup_subsys_state___63 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___67;

struct backing_dev_info___35 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___35 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___67 *dev;
	char dev_name[64];
	struct device___67 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___2 *debug_dir;
};

struct io_cq___36;

struct io_context___36 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___36 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___5;

struct capture_control___5 {
	struct compact_control___5 *cc;
	struct page___80 *page;
};

struct cgroup___63;

struct css_set___63 {
	struct cgroup_subsys_state___63 *subsys[14];
	refcount_t refcount;
	struct css_set___63 *dom_cset;
	struct cgroup___63 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___63 *mg_src_cgrp;
	struct cgroup___63 *mg_dst_cgrp;
	struct css_set___63 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___48 {
	struct pmu___48 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___82 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___48 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___32;

struct pipe_inode_info___32 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___80 *tmp_page;
	struct fasync_struct___75 *fasync_readers;
	struct fasync_struct___75 *fasync_writers;
	struct pipe_buffer___32 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___63;

struct cgroup_subsys_state___63 {
	struct cgroup___63 *cgroup;
	struct cgroup_subsys___63 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___63 *parent;
};

struct cgroup_file___63 {
	struct kernfs_node___75 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___33;

struct mem_cgroup_per_node___33;

struct mem_cgroup___33 {
	struct cgroup_subsys_state___63 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___63 events_file;
	struct cgroup_file___63 events_local_file;
	struct cgroup_file___63 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___33 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___82 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___33 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___36;

struct blk_integrity___36 {
	const struct blk_integrity_profile___36 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___36 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___36 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___36;

struct elevator_queue___36;

struct blk_mq_ops___35;

struct blk_mq_hw_ctx___35;

struct gendisk___36;

struct blkcg_gq___35;

struct blk_mq_tag_set___35;

struct request_queue___2 {
	struct request___36 *last_merge;
	struct elevator_queue___36 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___35 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___35 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___36 *disk;
	struct kobject___75 kobj;
	struct kobject___75 *mq_kobj;
	struct blk_integrity___36 integrity;
	struct device___67 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___35 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___35 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___36 bio_split;
	struct dentry___2 *debugfs_dir;
	struct dentry___2 *sched_debugfs_dir;
	struct dentry___2 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___76 {
	struct vm_struct___76 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___80 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___33 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___33 *memcg;
};

struct dev_pagemap_ops___74;

struct dev_pagemap___74 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___74 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___68 {
	rwlock_t lock;
	struct pid___68 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___75 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___75 f_path;
	struct inode___2 *f_inode;
	const struct file_operations___75 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___68 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___75 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___74;

struct vm_operations_struct___74 {
	void (*open)(struct vm_area_struct___80 *);
	void (*close)(struct vm_area_struct___80 *);
	int (*may_split)(struct vm_area_struct___80 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___80 *);
	int (*mprotect)(struct vm_area_struct___80 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___74 *);
	vm_fault_t (*huge_fault)(struct vm_fault___74 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___74 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___80 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___74 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___74 *);
	int (*access)(struct vm_area_struct___80 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___80 *);
	int (*set_policy)(struct vm_area_struct___80 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___80 *, long unsigned int);
	struct page___80 * (*find_special_page)(struct vm_area_struct___80 *, long unsigned int);
};

struct core_thread___80 {
	struct task_struct___82 *task;
	struct core_thread___80 *next;
};

struct core_state___80 {
	atomic_t nr_threads;
	struct core_thread___80 dumper;
	struct completion startup;
};

struct vm_fault___74 {
	const struct {
		struct vm_area_struct___80 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___80 *cow_page;
	struct page___80 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___80 prealloc_pte;
};

struct pglist_data___34;

struct lruvec___34 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___34 *pgdat;
};

struct zone___34 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___34 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___34 {
	struct zone___34 *zone;
	int zone_idx;
};

struct zonelist___34 {
	struct zoneref___34 _zonerefs[321];
};

struct pglist_data___34 {
	struct zone___34 node_zones[5];
	struct zonelist___34 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___82 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___82 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___34 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___63 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___82 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___63;

struct cgroup_rstat_cpu___63;

struct cgroup___63 {
	struct cgroup_subsys_state___63 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___75 *kn;
	struct cgroup_file___63 procs_file;
	struct cgroup_file___63 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___63 *subsys[14];
	struct cgroup_root___63 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___63 *dom_cgrp;
	struct cgroup___63 *old_dom_cgrp;
	struct cgroup_rstat_cpu___63 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___63 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___36 {
	struct request_queue___2 *q;
	struct io_context___36 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___2 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___33;

struct kiocb___75 {
	struct file___75 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___75 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___33 *ki_waitq;
	};
};

struct iattr___2 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___75 *ia_file;
};

struct dquot___75 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___2 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___75 {
	int qf_fmt_id;
	const struct quota_format_ops___75 *qf_ops;
	struct module___73 *qf_owner;
	struct quota_format_type___75 *qf_next;
};

struct quota_format_ops___75 {
	int (*check_quota_file)(struct super_block___2 *, int);
	int (*read_file_info)(struct super_block___2 *, int);
	int (*write_file_info)(struct super_block___2 *, int);
	int (*free_file_info)(struct super_block___2 *, int);
	int (*read_dqblk)(struct dquot___75 *);
	int (*commit_dqblk)(struct dquot___75 *);
	int (*release_dqblk)(struct dquot___75 *);
	int (*get_next_id)(struct super_block___2 *, struct kqid *);
};

struct dquot_operations___75 {
	int (*write_dquot)(struct dquot___75 *);
	struct dquot___75 * (*alloc_dquot)(struct super_block___2 *, int);
	void (*destroy_dquot)(struct dquot___75 *);
	int (*acquire_dquot)(struct dquot___75 *);
	int (*release_dquot)(struct dquot___75 *);
	int (*mark_dirty)(struct dquot___75 *);
	int (*write_info)(struct super_block___2 *, int);
	qsize_t * (*get_reserved_space)(struct inode___2 *);
	int (*get_projid)(struct inode___2 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___2 *, qsize_t *);
	int (*get_next_id)(struct super_block___2 *, struct kqid *);
};

struct quotactl_ops___75 {
	int (*quota_on)(struct super_block___2 *, int, int, const struct path___75 *);
	int (*quota_off)(struct super_block___2 *, int);
	int (*quota_enable)(struct super_block___2 *, unsigned int);
	int (*quota_disable)(struct super_block___2 *, unsigned int);
	int (*quota_sync)(struct super_block___2 *, int);
	int (*set_info)(struct super_block___2 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___2 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___2 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___2 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___2 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___2 *, unsigned int);
};

struct wait_page_queue___33 {
	struct page___80 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___35;

struct readahead_control___33;

struct swap_info_struct___21;

struct address_space_operations___75 {
	int (*writepage)(struct page___80 *, struct writeback_control___35 *);
	int (*readpage)(struct file___75 *, struct page___80 *);
	int (*writepages)(struct address_space___75 *, struct writeback_control___35 *);
	int (*set_page_dirty)(struct page___80 *);
	int (*readpages)(struct file___75 *, struct address_space___75 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___33 *);
	int (*write_begin)(struct file___75 *, struct address_space___75 *, loff_t, unsigned int, unsigned int, struct page___80 **, void **);
	int (*write_end)(struct file___75 *, struct address_space___75 *, loff_t, unsigned int, unsigned int, struct page___80 *, void *);
	sector_t (*bmap)(struct address_space___75 *, sector_t);
	void (*invalidatepage)(struct page___80 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___80 *, gfp_t);
	void (*freepage)(struct page___80 *);
	ssize_t (*direct_IO)(struct kiocb___75 *, struct iov_iter___46 *);
	int (*migratepage)(struct address_space___75 *, struct page___80 *, struct page___80 *, enum migrate_mode);
	bool (*isolate_page)(struct page___80 *, isolate_mode_t);
	void (*putback_page)(struct page___80 *);
	int (*launder_page)(struct page___80 *);
	int (*is_partially_uptodate)(struct page___80 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___80 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___75 *, struct page___80 *);
	int (*swap_activate)(struct swap_info_struct___21 *, struct file___75 *, sector_t *);
	void (*swap_deactivate)(struct file___75 *);
};

struct writeback_control___35 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___35 *wb;
	struct inode___2 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___33 {
	struct file___75 *file;
	struct address_space___75 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___45;

struct iov_iter___46 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___45 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___32 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___21 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___37 *bdev;
	struct file___75 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___75 {
	struct dentry___2 * (*lookup)(struct inode___2 *, struct dentry___2 *, unsigned int);
	const char * (*get_link)(struct dentry___2 *, struct inode___2 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___2 *, int);
	struct posix_acl * (*get_acl)(struct inode___2 *, int, bool);
	int (*readlink)(struct dentry___2 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___2 *, struct dentry___2 *, umode_t, bool);
	int (*link)(struct dentry___2 *, struct inode___2 *, struct dentry___2 *);
	int (*unlink)(struct inode___2 *, struct dentry___2 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___2 *, struct dentry___2 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___2 *, struct dentry___2 *, umode_t);
	int (*rmdir)(struct inode___2 *, struct dentry___2 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___2 *, struct dentry___2 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___2 *, struct dentry___2 *, struct inode___2 *, struct dentry___2 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___2 *, struct iattr___2 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___75 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___2 *, char *, size_t);
	int (*fiemap)(struct inode___2 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___2 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___2 *, struct dentry___2 *, struct file___75 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___2 *, struct dentry___2 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___2 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___2 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___2 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___75 {
	void (*fl_copy_lock)(struct file_lock___75 *, struct file_lock___75 *);
	void (*fl_release_private)(struct file_lock___75 *);
};

struct lock_manager_operations___75;

struct file_lock___75 {
	struct file_lock___75 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___75 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___75 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___75 *fl_ops;
	const struct lock_manager_operations___75 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___75 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___75 *);
	int (*lm_grant)(struct file_lock___75 *, int);
	bool (*lm_break)(struct file_lock___75 *);
	int (*lm_change)(struct file_lock___75 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___75 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___75 *);
};

struct fasync_struct___75 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___75 *fa_next;
	struct file___75 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___75 {
	struct inode___2 * (*alloc_inode)(struct super_block___2 *);
	void (*destroy_inode)(struct inode___2 *);
	void (*free_inode)(struct inode___2 *);
	void (*dirty_inode)(struct inode___2 *, int);
	int (*write_inode)(struct inode___2 *, struct writeback_control___35 *);
	int (*drop_inode)(struct inode___2 *);
	void (*evict_inode)(struct inode___2 *);
	void (*put_super)(struct super_block___2 *);
	int (*sync_fs)(struct super_block___2 *, int);
	int (*freeze_super)(struct super_block___2 *);
	int (*freeze_fs)(struct super_block___2 *);
	int (*thaw_super)(struct super_block___2 *);
	int (*unfreeze_fs)(struct super_block___2 *);
	int (*statfs)(struct dentry___2 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___2 *, int *, char *);
	void (*umount_begin)(struct super_block___2 *);
	int (*show_options)(struct seq_file___72 *, struct dentry___2 *);
	int (*show_devname)(struct seq_file___72 *, struct dentry___2 *);
	int (*show_path)(struct seq_file___72 *, struct dentry___2 *);
	int (*show_stats)(struct seq_file___72 *, struct dentry___2 *);
	ssize_t (*quota_read)(struct super_block___2 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___2 *, int, const char *, size_t, loff_t);
	struct dquot___75 ** (*get_dquots)(struct inode___2 *);
	long int (*nr_cached_objects)(struct super_block___2 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___2 *, struct shrink_control___33 *);
	struct file___75 * (*real_loop)(struct file___75 *);
};

struct xattr_handler___6 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___2 *);
	int (*get)(const struct xattr_handler___6 *, struct dentry___2 *, struct inode___2 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___6 *, struct user_namespace___12 *, struct dentry___2 *, struct inode___2 *, const char *, const void *, size_t, int);
};

struct wakeup_source___67;

struct dev_pm_info___67 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___67 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___67 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___67;

struct bus_type___67;

struct device_driver___67;

struct dev_pm_domain___67;

struct fwnode_handle___67;

struct class___67;

struct attribute_group___75;

struct device___67 {
	struct kobject___75 kobj;
	struct device___67 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___67 *type;
	struct bus_type___67 *bus;
	struct device_driver___67 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___67 power;
	struct dev_pm_domain___67 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___67 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___67 *class;
	const struct attribute_group___75 **groups;
	void (*release)(struct device___67 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___37 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___2 *bd_inode;
	struct super_block___2 *bd_super;
	void *bd_claiming;
	struct device___67 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___75 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___36 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___2 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___57)(struct file___75 *, wait_queue_head_t *, struct poll_table_struct___57 *);

struct poll_table_struct___57 {
	poll_queue_proc___57 _qproc;
	__poll_t _key;
};

struct seq_operations___72;

struct seq_file___72 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___72 *op;
	int poll_event;
	const struct file___75 *file;
	void *private;
};

struct fc_log___12;

struct p_log___12 {
	const char *prefix;
	struct fc_log___12 *log;
};

struct fs_context_operations___12;

struct fs_context___12 {
	const struct fs_context_operations___12 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___75 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___2 *root;
	struct user_namespace___12 *user_ns;
	struct net *net_ns;
	const struct cred___11 *cred;
	struct p_log___12 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___12;

typedef int fs_param_type___11(struct p_log___12 *, const struct fs_parameter_spec___11 *, struct fs_parameter___12 *, struct fs_parse_result *);

struct fs_parameter_spec___11 {
	const char *name;
	fs_param_type___11 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___36(struct bio___36 *);

struct bio_vec___45 {
	struct page___80 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___36;

struct bio___36 {
	struct bio___36 *bi_next;
	struct block_device___37 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___36 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___35 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___36 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___45 *bi_io_vec;
	struct bio_set___36 *bi_pool;
	struct bio_vec___45 bi_inline_vecs[0];
};

struct dev_pagemap_ops___74 {
	void (*page_free)(struct page___80 *);
	void (*kill)(struct dev_pagemap___74 *);
	void (*cleanup)(struct dev_pagemap___74 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___74 *);
};

enum transparent_hugepage_flag {
	TRANSPARENT_HUGEPAGE_NEVER_DAX = 0,
	TRANSPARENT_HUGEPAGE_FLAG = 1,
	TRANSPARENT_HUGEPAGE_REQ_MADV_FLAG = 2,
	TRANSPARENT_HUGEPAGE_DEFRAG_DIRECT_FLAG = 3,
	TRANSPARENT_HUGEPAGE_DEFRAG_KSWAPD_FLAG = 4,
	TRANSPARENT_HUGEPAGE_DEFRAG_KSWAPD_OR_MADV_FLAG = 5,
	TRANSPARENT_HUGEPAGE_DEFRAG_REQ_MADV_FLAG = 6,
	TRANSPARENT_HUGEPAGE_DEFRAG_KHUGEPAGED_FLAG = 7,
	TRANSPARENT_HUGEPAGE_USE_ZERO_PAGE_FLAG = 8,
};

struct kobj_attribute___6 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___75 *, struct kobj_attribute___6 *, char *);
	ssize_t (*store)(struct kobject___75 *, struct kobj_attribute___6 *, const char *, size_t);
};

struct xattr;

typedef int (*initxattrs)(struct inode___2 *, const struct xattr *, void *);

struct xattr {
	const char *name;
	void *value;
	size_t value_len;
};

struct fs_parameter___12 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___75 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___12 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___73 *owner;
	char *buffer[8];
};

struct fs_context_operations___12 {
	void (*free)(struct fs_context___12 *);
	int (*dup)(struct fs_context___12 *, struct fs_context___12 *);
	int (*parse_param)(struct fs_context___12 *, struct fs_parameter___12 *);
	int (*parse_monolithic)(struct fs_context___12 *, void *);
	int (*get_tree)(struct fs_context___12 *);
	int (*reconfigure)(struct fs_context___12 *);
};

struct constant_table {
	const char *name;
	int value;
};

struct fwnode_operations___67;

struct fwnode_handle___67 {
	struct fwnode_handle___67 *secondary;
	const struct fwnode_operations___67 *ops;
	struct device___67 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___67;

struct fwnode_endpoint___67;

struct fwnode_operations___67 {
	struct fwnode_handle___67 * (*get)(struct fwnode_handle___67 *);
	void (*put)(struct fwnode_handle___67 *);
	bool (*device_is_available)(const struct fwnode_handle___67 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___67 *, const struct device___67 *);
	bool (*property_present)(const struct fwnode_handle___67 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___67 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___67 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___67 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*get_parent)(const struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*get_next_child_node)(const struct fwnode_handle___67 *, struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*get_named_child_node)(const struct fwnode_handle___67 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___67 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___67 *);
	struct fwnode_handle___67 * (*graph_get_next_endpoint)(const struct fwnode_handle___67 *, struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*graph_get_remote_endpoint)(const struct fwnode_handle___67 *);
	struct fwnode_handle___67 * (*graph_get_port_parent)(struct fwnode_handle___67 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___67 *, struct fwnode_endpoint___67 *);
	int (*add_links)(struct fwnode_handle___67 *);
};

struct fwnode_endpoint___67 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___67 *local_fwnode;
};

struct fwnode_reference_args___67 {
	struct fwnode_handle___67 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___75;

struct kernfs_elem_dir___75 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___75 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___75;

struct kernfs_root___75 {
	struct kernfs_node___75 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___75 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___75 {
	struct kernfs_node___75 *target_kn;
};

struct kernfs_ops___75;

struct kernfs_elem_attr___75 {
	const struct kernfs_ops___75 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___75 *notify_next;
};

struct kernfs_node___75 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___75 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___75 dir;
		struct kernfs_elem_symlink___75 symlink;
		struct kernfs_elem_attr___75 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___75;

struct kernfs_ops___75 {
	int (*open)(struct kernfs_open_file___75 *);
	void (*release)(struct kernfs_open_file___75 *);
	int (*seq_show)(struct seq_file___72 *, void *);
	void * (*seq_start)(struct seq_file___72 *, loff_t *);
	void * (*seq_next)(struct seq_file___72 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___72 *, void *);
	ssize_t (*read)(struct kernfs_open_file___75 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___75 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___75 *, struct poll_table_struct___57 *);
	int (*mmap)(struct kernfs_open_file___75 *, struct vm_area_struct___80 *);
};

struct kernfs_syscall_ops___75 {
	int (*show_options)(struct seq_file___72 *, struct kernfs_root___75 *);
	int (*mkdir)(struct kernfs_node___75 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___75 *);
	int (*rename)(struct kernfs_node___75 *, struct kernfs_node___75 *, const char *);
	int (*show_path)(struct seq_file___72 *, struct kernfs_node___75 *, struct kernfs_root___75 *);
};

struct kernfs_open_file___75 {
	struct kernfs_node___75 *kn;
	struct file___75 *file;
	struct seq_file___72 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___74 *vm_ops;
};

struct bin_attribute___75;

struct attribute_group___75 {
	const char *name;
	umode_t (*is_visible)(struct kobject___75 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___75 *, struct bin_attribute___75 *, int);
	struct attribute **attrs;
	struct bin_attribute___75 **bin_attrs;
};

struct bin_attribute___75 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___75 * (*f_mapping)();
	ssize_t (*read)(struct file___75 *, struct kobject___75 *, struct bin_attribute___75 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___75 *, struct kobject___75 *, struct bin_attribute___75 *, char *, loff_t, size_t);
	int (*mmap)(struct file___75 *, struct kobject___75 *, struct bin_attribute___75 *, struct vm_area_struct___80 *);
};

struct sysfs_ops___75 {
	ssize_t (*show)(struct kobject___75 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___75 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___75;

struct kset___75 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___75 kobj;
	const struct kset_uevent_ops___75 *uevent_ops;
};

struct kobj_type___75 {
	void (*release)(struct kobject___75 *);
	const struct sysfs_ops___75 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___75 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___75 *);
	const void * (*namespace)(struct kobject___75 *);
	void (*get_ownership)(struct kobject___75 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___75 {
	int (* const filter)(struct kset___75 *, struct kobject___75 *);
	const char * (* const name)(struct kset___75 *, struct kobject___75 *);
	int (* const uevent)(struct kset___75 *, struct kobject___75 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___72 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___72 *);
	int (*get)(char *, const struct kernel_param___72 *);
	void (*free)(void *);
};

struct kparam_array___72;

struct kernel_param___72 {
	const char *name;
	struct module___73 *mod;
	const struct kernel_param_ops___72 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___72 *arr;
	};
};

struct kparam_array___72 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___72 *ops;
	void *elem;
};

struct module_attribute___72 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___72 *, struct module_kobject___72 *, char *);
	ssize_t (*store)(struct module_attribute___72 *, struct module_kobject___72 *, const char *, size_t);
	void (*setup)(struct module___73 *, const char *);
	int (*test)(struct module___73 *);
	void (*free)(struct module___73 *);
};

struct trace_event_class___42;

struct trace_event_call___42 {
	struct list_head list;
	struct trace_event_class___42 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___42 *, struct perf_event___48 *);
};

struct cgroup_namespace___63 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___63 *root_cset;
};

struct seq_operations___72 {
	void * (*start)(struct seq_file___72 *, loff_t *);
	void (*stop)(struct seq_file___72 *, void *);
	void * (*next)(struct seq_file___72 *, void *, loff_t *);
	int (*show)(struct seq_file___72 *, void *);
};

struct cftype___63;

struct cgroup_subsys___63 {
	struct cgroup_subsys_state___63 * (*css_alloc)(struct cgroup_subsys_state___63 *);
	int (*css_online)(struct cgroup_subsys_state___63 *);
	void (*css_offline)(struct cgroup_subsys_state___63 *);
	void (*css_released)(struct cgroup_subsys_state___63 *);
	void (*css_free)(struct cgroup_subsys_state___63 *);
	void (*css_reset)(struct cgroup_subsys_state___63 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___63 *, int);
	int (*css_extra_stat_show)(struct seq_file___72 *, struct cgroup_subsys_state___63 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___82 *, struct css_set___63 *);
	void (*cancel_fork)(struct task_struct___82 *, struct css_set___63 *);
	void (*fork)(struct task_struct___82 *);
	void (*exit)(struct task_struct___82 *);
	void (*release)(struct task_struct___82 *);
	void (*bind)(struct cgroup_subsys_state___63 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___63 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___63 *dfl_cftypes;
	struct cftype___63 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___63 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___63 *updated_children;
	struct cgroup___63 *updated_next;
};

struct cgroup_root___63 {
	struct kernfs_root___75 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___63 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___63 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___63 *ss;
	struct list_head node;
	struct kernfs_ops___75 *kf_ops;
	int (*open)(struct kernfs_open_file___75 *);
	void (*release)(struct kernfs_open_file___75 *);
	u64 (*read_u64)(struct cgroup_subsys_state___63 *, struct cftype___63 *);
	s64 (*read_s64)(struct cgroup_subsys_state___63 *, struct cftype___63 *);
	int (*seq_show)(struct seq_file___72 *, void *);
	void * (*seq_start)(struct seq_file___72 *, loff_t *);
	void * (*seq_next)(struct seq_file___72 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___72 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___63 *, struct cftype___63 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___63 *, struct cftype___63 *, s64);
	ssize_t (*write)(struct kernfs_open_file___75 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___75 *, struct poll_table_struct___57 *);
};

struct dev_pm_ops___67 {
	int (*prepare)(struct device___67 *);
	void (*complete)(struct device___67 *);
	int (*suspend)(struct device___67 *);
	int (*resume)(struct device___67 *);
	int (*freeze)(struct device___67 *);
	int (*thaw)(struct device___67 *);
	int (*poweroff)(struct device___67 *);
	int (*restore)(struct device___67 *);
	int (*suspend_late)(struct device___67 *);
	int (*resume_early)(struct device___67 *);
	int (*freeze_late)(struct device___67 *);
	int (*thaw_early)(struct device___67 *);
	int (*poweroff_late)(struct device___67 *);
	int (*restore_early)(struct device___67 *);
	int (*suspend_noirq)(struct device___67 *);
	int (*resume_noirq)(struct device___67 *);
	int (*freeze_noirq)(struct device___67 *);
	int (*thaw_noirq)(struct device___67 *);
	int (*poweroff_noirq)(struct device___67 *);
	int (*restore_noirq)(struct device___67 *);
	int (*runtime_suspend)(struct device___67 *);
	int (*runtime_resume)(struct device___67 *);
	int (*runtime_idle)(struct device___67 *);
};

struct wakeup_source___67 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___67 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___67 {
	struct dev_pm_ops___67 ops;
	int (*start)(struct device___67 *);
	void (*detach)(struct device___67 *, bool);
	int (*activate)(struct device___67 *);
	void (*sync)(struct device___67 *);
	void (*dismiss)(struct device___67 *);
};

struct bus_type___67 {
	const char *name;
	const char *dev_name;
	struct device___67 *dev_root;
	const struct attribute_group___75 **bus_groups;
	const struct attribute_group___75 **dev_groups;
	const struct attribute_group___75 **drv_groups;
	int (*match)(struct device___67 *, struct device_driver___67 *);
	int (*uevent)(struct device___67 *, struct kobj_uevent_env *);
	int (*probe)(struct device___67 *);
	void (*sync_state)(struct device___67 *);
	void (*remove)(struct device___67 *);
	void (*shutdown)(struct device___67 *);
	int (*online)(struct device___67 *);
	int (*offline)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	int (*num_vf)(struct device___67 *);
	int (*dma_configure)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___67 {
	const char *name;
	struct bus_type___67 *bus;
	struct module___73 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___67 *);
	void (*sync_state)(struct device___67 *);
	int (*remove)(struct device___67 *);
	void (*shutdown)(struct device___67 *);
	int (*suspend)(struct device___67 *, pm_message_t);
	int (*resume)(struct device___67 *);
	const struct attribute_group___75 **groups;
	const struct attribute_group___75 **dev_groups;
	const struct dev_pm_ops___67 *pm;
	void (*coredump)(struct device___67 *);
	struct driver_private *p;
};

struct device_type___67 {
	const char *name;
	const struct attribute_group___75 **groups;
	int (*uevent)(struct device___67 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___67 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___67 *);
	const struct dev_pm_ops___67 *pm;
};

struct class___67 {
	const char *name;
	struct module___73 *owner;
	const struct attribute_group___75 **class_groups;
	const struct attribute_group___75 **dev_groups;
	struct kobject___75 *dev_kobj;
	int (*dev_uevent)(struct device___67 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___67 *, umode_t *);
	void (*class_release)(struct class___67 *);
	void (*dev_release)(struct device___67 *);
	int (*shutdown_pre)(struct device___67 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___67 *);
	void (*get_ownership)(struct device___67 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___67 *pm;
	struct subsys_private *p;
};

struct block_device_operations___36;

struct gendisk___36 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___37 *part0;
	const struct block_device_operations___36 *fops;
	struct request_queue___2 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___35 *bdi;
	struct kobject___75 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___75 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___36 {
	struct bio___36 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___45 *bip_vec;
	struct bio_vec___45 bip_inline_vecs[0];
};

struct blkcg___35;

struct blkg_policy_data___35;

struct blkcg_gq___35 {
	struct request_queue___2 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___35 *blkcg;
	struct blkcg_gq___35 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___35 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___36 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___36(struct request___36 *);

typedef void integrity_complete_fn___36(struct request___36 *, unsigned int);

struct blk_integrity_profile___36 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___36 *prepare_fn;
	integrity_complete_fn___36 *complete_fn;
	const char *name;
};

struct block_device_operations___36 {
	blk_qc_t (*submit_bio)(struct bio___36 *);
	int (*open)(struct block_device___37 *, fmode_t);
	void (*release)(struct gendisk___36 *, fmode_t);
	int (*rw_page)(struct block_device___37 *, sector_t, struct page___80 *, unsigned int);
	int (*ioctl)(struct block_device___37 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___37 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___36 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___36 *);
	int (*getgeo)(struct block_device___37 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___37 *, bool);
	void (*swap_slot_free_notify)(struct block_device___37 *, long unsigned int);
	int (*report_zones)(struct gendisk___36 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___36 *, umode_t *);
	struct module___73 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___36 *, sector_t *);
};

typedef void rq_end_io_fn___36(struct request___36 *, blk_status_t);

struct request___36 {
	struct request_queue___2 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___35 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___36 *bio;
	struct bio___36 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___45 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___36 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___36 *saved_end_io;
		} flush;
	};
	struct gendisk___36 *rq_disk;
	struct block_device___37 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___36 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___35 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___2 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___75 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___2 *debugfs_dir;
	struct dentry___2 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___36;

struct elevator_mq_ops___36 {
	int (*init_sched)(struct request_queue___2 *, struct elevator_type___36 *);
	void (*exit_sched)(struct elevator_queue___36 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___35 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___35 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___35 *);
	bool (*allow_merge)(struct request_queue___2 *, struct request___36 *, struct bio___36 *);
	bool (*bio_merge)(struct request_queue___2 *, struct bio___36 *, unsigned int);
	int (*request_merge)(struct request_queue___2 *, struct request___36 **, struct bio___36 *);
	void (*request_merged)(struct request_queue___2 *, struct request___36 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___2 *, struct request___36 *, struct request___36 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___36 *);
	void (*finish_request)(struct request___36 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___35 *, struct list_head *, bool);
	struct request___36 * (*dispatch_request)(struct blk_mq_hw_ctx___35 *);
	bool (*has_work)(struct blk_mq_hw_ctx___35 *);
	void (*completed_request)(struct request___36 *, u64);
	void (*requeue_request)(struct request___36 *);
	struct request___36 * (*former_request)(struct request_queue___2 *, struct request___36 *);
	struct request___36 * (*next_request)(struct request_queue___2 *, struct request___36 *);
	void (*init_icq)(struct io_cq___36 *);
	void (*exit_icq)(struct io_cq___36 *);
};

struct elv_fs_entry___36;

struct elevator_type___36 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___36 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___36 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___73 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___36 {
	struct elevator_type___36 *type;
	void *elevator_data;
	struct kobject___75 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___36 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___36 *, char *);
	ssize_t (*store)(struct elevator_queue___36 *, const char *, size_t);
};

struct blk_mq_queue_data___35;

struct blk_mq_ops___35 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___35 *, const struct blk_mq_queue_data___35 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___35 *);
	int (*get_budget)(struct request_queue___2 *);
	void (*put_budget)(struct request_queue___2 *, int);
	void (*set_rq_budget_token)(struct request___36 *, int);
	int (*get_rq_budget_token)(struct request___36 *);
	enum blk_eh_timer_return (*timeout)(struct request___36 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___35 *);
	void (*complete)(struct request___36 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___35 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___35 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___35 *, struct request___36 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___35 *, struct request___36 *, unsigned int);
	void (*initialize_rq_fn)(struct request___36 *);
	void (*cleanup_rq)(struct request___36 *);
	bool (*busy)(struct request_queue___2 *);
	int (*map_queues)(struct blk_mq_tag_set___35 *);
	void (*show_rq)(struct seq_file___72 *, struct request___36 *);
};

struct blk_mq_tag_set___35 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___35 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___35 {
	struct request___36 *rq;
	bool last;
};

struct blkcg_policy_data___35;

struct blkcg___35 {
	struct cgroup_subsys_state___63 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___35 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___35 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___35 {
	struct blkcg___35 *blkcg;
	int plid;
};

struct blkg_policy_data___35 {
	struct blkcg_gq___35 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___33 {
	struct mem_cgroup___33 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___33 {
	struct lruvec___34 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___33 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___33 *memcg;
};

struct obj_cgroup___33 {
	struct percpu_ref refcnt;
	struct mem_cgroup___33 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum {
	MPOL_DEFAULT = 0,
	MPOL_PREFERRED = 1,
	MPOL_BIND = 2,
	MPOL_INTERLEAVE = 3,
	MPOL_LOCAL = 4,
	MPOL_PREFERRED_MANY = 5,
	MPOL_MAX = 6,
};

struct shared_policy {
	struct rb_root root;
	rwlock_t lock;
};

struct simple_xattrs {
	struct list_head head;
	spinlock_t lock;
};

struct simple_xattr {
	struct list_head list;
	char *name;
	size_t size;
	char value[0];
};

struct shmem_inode_info {
	spinlock_t lock;
	unsigned int seals;
	long unsigned int flags;
	long unsigned int alloced;
	long unsigned int swapped;
	long unsigned int fallocend;
	struct list_head shrinklist;
	struct list_head swaplist;
	struct shared_policy policy;
	struct simple_xattrs xattrs;
	atomic_t stop_eviction;
	struct inode___2 vfs_inode;
};

struct shmem_sb_info {
	long unsigned int max_blocks;
	struct percpu_counter used_blocks;
	long unsigned int max_inodes;
	long unsigned int free_inodes;
	raw_spinlock_t stat_lock;
	umode_t mode;
	unsigned char huge;
	kuid_t uid;
	kgid_t gid;
	bool full_inums;
	ino_t next_ino;
	ino_t *ino_batch;
	struct mempolicy *mpol;
	spinlock_t shrinklist_lock;
	struct list_head shrinklist;
	long unsigned int shrinklist_len;
};

enum sgp_type {
	SGP_READ = 0,
	SGP_NOALLOC = 1,
	SGP_CACHE = 2,
	SGP_WRITE = 3,
	SGP_FALLOC = 4,
};

enum fid_type {
	FILEID_ROOT = 0,
	FILEID_INO32_GEN = 1,
	FILEID_INO32_GEN_PARENT = 2,
	FILEID_BTRFS_WITHOUT_PARENT = 77,
	FILEID_BTRFS_WITH_PARENT = 78,
	FILEID_BTRFS_WITH_PARENT_ROOT = 79,
	FILEID_UDF_WITHOUT_PARENT = 81,
	FILEID_UDF_WITH_PARENT = 82,
	FILEID_NILFS_WITHOUT_PARENT = 97,
	FILEID_NILFS_WITH_PARENT = 98,
	FILEID_FAT_WITHOUT_PARENT = 113,
	FILEID_FAT_WITH_PARENT = 114,
	FILEID_LUSTRE = 151,
	FILEID_KERNFS = 254,
	FILEID_INVALID = 255,
};

struct pagevec___4 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___80 *pages[15];
};

struct pipe_buf_operations___32;

struct pipe_buffer___32 {
	struct page___80 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___32 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___32 {
	int (*confirm)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
	void (*release)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
	bool (*try_steal)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
	bool (*get)(struct pipe_inode_info___32 *, struct pipe_buffer___32 *);
};

struct perf_cpu_context___48;

struct perf_output_handle___48;

struct pmu___48 {
	struct list_head entry;
	struct module___73 *module;
	struct device___67 *dev;
	const struct attribute_group___75 **attr_groups;
	const struct attribute_group___75 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___48 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___48 *);
	void (*pmu_disable)(struct pmu___48 *);
	int (*event_init)(struct perf_event___48 *);
	void (*event_mapped)(struct perf_event___48 *, struct mm_struct___81 *);
	void (*event_unmapped)(struct perf_event___48 *, struct mm_struct___81 *);
	int (*add)(struct perf_event___48 *, int);
	void (*del)(struct perf_event___48 *, int);
	void (*start)(struct perf_event___48 *, int);
	void (*stop)(struct perf_event___48 *, int);
	void (*read)(struct perf_event___48 *);
	void (*start_txn)(struct pmu___48 *, unsigned int);
	int (*commit_txn)(struct pmu___48 *);
	void (*cancel_txn)(struct pmu___48 *);
	int (*event_idx)(struct perf_event___48 *);
	void (*sched_task)(struct perf_event_context___48 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___48 *, struct perf_event_context___48 *);
	void * (*setup_aux)(struct perf_event___48 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___48 *, struct perf_output_handle___48 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___48 *);
	int (*aux_output_match)(struct perf_event___48 *);
	int (*filter_match)(struct perf_event___48 *);
	int (*check_period)(struct perf_event___48 *, u64);
};

struct perf_cpu_context___48 {
	struct perf_event_context___48 ctx;
	struct perf_event_context___48 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___48 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___48 **heap;
	struct perf_event___48 *heap_default[2];
};

struct perf_output_handle___48 {
	struct perf_event___48 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___48 {
	struct cgroup_subsys_state___63 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___42 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___42 *);
	};
};

struct trace_event_class___42 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___42 *, enum trace_reg, void *);
	struct trace_event_fields___42 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___42 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___42 *);
};

struct compact_control___5 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___34 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct shmem_falloc {
	wait_queue_head_t *waitq;
	long unsigned int start;
	long unsigned int next;
	long unsigned int nr_falloced;
	long unsigned int nr_unswapped;
};

struct shmem_options {
	long long unsigned int blocks;
	long long unsigned int inodes;
	struct mempolicy *mpol;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
	bool full_inums;
	int huge;
	int seen;
};

enum shmem_param {
	Opt_gid = 0,
	Opt_huge = 1,
	Opt_mode = 2,
	Opt_mpol = 3,
	Opt_nr_blocks = 4,
	Opt_nr_inodes = 5,
	Opt_size = 6,
	Opt_uid = 7,
	Opt_inode32 = 8,
	Opt_inode64 = 9,
};

struct pglist_data___35;

struct lruvec___35 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___35 *pgdat;
};

struct zone___35 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___35 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___35 {
	struct zone___35 *zone;
	int zone_idx;
};

struct zonelist___35 {
	struct zoneref___35 _zonerefs[321];
};

struct pglist_data___35 {
	struct zone___35 node_zones[5];
	struct zonelist___35 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___78 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___78 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___35 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___35 pg_data_t___5;

enum writeback_stat_item {
	NR_DIRTY_THRESHOLD = 0,
	NR_DIRTY_BG_THRESHOLD = 1,
	NR_VM_WRITEBACK_STAT_ITEMS = 2,
};

struct contig_page_info {
	long unsigned int free_pages;
	long unsigned int free_blocks_total;
	long unsigned int free_blocks_suitable;
};

struct radix_tree_iter {
	long unsigned int index;
	long unsigned int next_index;
	long unsigned int tags;
	struct xa_node *node;
};

enum {
	RADIX_TREE_ITER_TAG_MASK = 15,
	RADIX_TREE_ITER_TAGGED = 16,
	RADIX_TREE_ITER_CONTIG = 32,
};

struct dentry___76;

struct super_block___76;

struct module___74;

struct file_system_type___76 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___76 * (*mount)(struct file_system_type___76 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___76 *);
	struct module___74 *owner;
	struct file_system_type___76 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___76;

struct kiocb___76;

struct vm_area_struct___81;

struct inode___76;

struct file_lock___76;

struct page___81;

struct file_operations___76 {
	struct module___74 *owner;
	loff_t (*llseek)(struct file___76 *, loff_t, int);
	ssize_t (*read)(struct file___76 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___76 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___76 *, struct iov_iter___46 *);
	ssize_t (*write_iter)(struct kiocb___76 *, struct iov_iter___46 *);
	int (*iopoll)(struct kiocb___76 *, bool);
	int (*iterate)(struct file___76 *, struct dir_context *);
	int (*iterate_shared)(struct file___76 *, struct dir_context *);
	__poll_t (*poll)(struct file___76 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___76 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___76 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___76 *, struct vm_area_struct___81 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___76 *, struct file___76 *);
	int (*flush)(struct file___76 *, fl_owner_t);
	int (*release)(struct inode___76 *, struct file___76 *);
	int (*fsync)(struct file___76 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___76 *, int);
	int (*lock)(struct file___76 *, int, struct file_lock___76 *);
	ssize_t (*sendpage)(struct file___76 *, struct page___81 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___76 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___76 *, long unsigned int);
	int (*flock)(struct file___76 *, int, struct file_lock___76 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___76 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___76 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___76 *, long int, struct file_lock___76 **, void **);
	long int (*fallocate)(struct file___76 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___76 *);
	ssize_t (*copy_file_range)(struct file___76 *, loff_t, struct file___76 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___76 *, loff_t, struct file___76 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___76 *, loff_t, loff_t, int);
};

struct vmacache___81 {
	u64 seqnum;
	struct vm_area_struct___81 *vmas[4];
};

struct page_frag___81 {
	struct page___81 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___82;

struct pid___69;

struct nsproxy___74;

struct signal_struct___77;

struct capture_control___6;

struct vm_struct___77;

struct task_struct___83 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___83 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___82 *mm;
	struct mm_struct___82 *active_mm;
	struct vmacache___81 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___83 *real_parent;
	struct task_struct___83 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___83 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___69 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___74 *nsproxy;
	struct signal_struct___77 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___83 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___36 *io_context;
	struct capture_control___6 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___81 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___83 *oom_reaper_list;
	struct vm_struct___77 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___48 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___76;

struct kobj_type___76;

struct kernfs_node___76;

struct kobject___76 {
	const char *name;
	struct list_head entry;
	struct kobject___76 *parent;
	struct kset___76 *kset;
	struct kobj_type___76 *ktype;
	struct kernfs_node___76 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___73 {
	struct kobject___76 kobj;
	struct module___74 *mod;
	struct kobject___76 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___73 {
	struct module___74 *mod;
	struct latch_tree_node node;
};

struct module_layout___73 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___73 mtn;
};

struct module_attribute___73;

struct kernel_param___73;

struct module___74 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___73 mkobj;
	struct module_attribute___73 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___76 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___73 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___73 core_layout;
	struct module_layout___73 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___81 *pgtable_t___81;

struct address_space___76;

struct dev_pagemap___75;

struct page___81 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___76 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___81 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___81 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___82 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___75 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___75;

struct vm_area_struct___81 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___81 *vm_next;
	struct vm_area_struct___81 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___82 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___75 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___76 *vm_file;
	struct file___76 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___81;

struct mm_struct___82 {
	struct {
		struct vm_area_struct___81 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___76 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___81 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___83 *owner;
		struct user_namespace *user_ns;
		struct file___76 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___76;

struct address_space___76 {
	struct inode___76 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___76 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___75;

struct dev_pagemap___75 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___75 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___76;

struct path___76 {
	struct vfsmount___76 *mnt;
	struct dentry___76 *dentry;
};

struct fown_struct___69 {
	rwlock_t lock;
	struct pid___69 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___76 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___76 f_path;
	struct inode___76 *f_inode;
	const struct file_operations___76 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___69 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___76 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___75;

struct vm_operations_struct___75 {
	void (*open)(struct vm_area_struct___81 *);
	void (*close)(struct vm_area_struct___81 *);
	int (*may_split)(struct vm_area_struct___81 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___81 *);
	int (*mprotect)(struct vm_area_struct___81 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___75 *);
	vm_fault_t (*huge_fault)(struct vm_fault___75 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___75 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___81 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___75 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___75 *);
	int (*access)(struct vm_area_struct___81 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___81 *);
	int (*set_policy)(struct vm_area_struct___81 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___81 *, long unsigned int);
	struct page___81 * (*find_special_page)(struct vm_area_struct___81 *, long unsigned int);
};

struct core_thread___81 {
	struct task_struct___83 *task;
	struct core_thread___81 *next;
};

struct core_state___81 {
	atomic_t nr_threads;
	struct core_thread___81 dumper;
	struct completion startup;
};

struct vm_fault___75 {
	const struct {
		struct vm_area_struct___81 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___81 *cow_page;
	struct page___81 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___81 prealloc_pte;
};

struct pglist_data___36;

struct lruvec___36 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___36 *pgdat;
};

struct zone___36 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___36 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___36 {
	struct zone___36 *zone;
	int zone_idx;
};

struct zonelist___36 {
	struct zoneref___36 _zonerefs[321];
};

struct pglist_data___36 {
	struct zone___36 node_zones[5];
	struct zonelist___36 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___83 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___83 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___36 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___76;

struct kernfs_elem_dir___76 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___76 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___76;

struct kernfs_root___76 {
	struct kernfs_node___76 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___76 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___76 {
	struct kernfs_node___76 *target_kn;
};

struct kernfs_ops___76;

struct kernfs_elem_attr___76 {
	const struct kernfs_ops___76 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___76 *notify_next;
};

struct kernfs_node___76 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___76 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___76 dir;
		struct kernfs_elem_symlink___76 symlink;
		struct kernfs_elem_attr___76 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___76;

struct kernfs_ops___76 {
	int (*open)(struct kernfs_open_file___76 *);
	void (*release)(struct kernfs_open_file___76 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___76 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___76 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___76 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___76 *, struct vm_area_struct___81 *);
};

struct kernfs_syscall_ops___76 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___76 *);
	int (*mkdir)(struct kernfs_node___76 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___76 *);
	int (*rename)(struct kernfs_node___76 *, struct kernfs_node___76 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___76 *, struct kernfs_root___76 *);
};

struct kernfs_open_file___76 {
	struct kernfs_node___76 *kn;
	struct file___76 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___75 *vm_ops;
};

struct pid_namespace___69;

struct upid___69 {
	int nr;
	struct pid_namespace___69 *ns;
};

struct pid_namespace___69 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___83 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___69 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___69 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___69 numbers[1];
};

struct signal_struct___77 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___83 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___83 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___69 *pids[4];
	struct pid___69 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___82 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___74 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___69 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct compact_control___6;

struct capture_control___6 {
	struct compact_control___6 *cc;
	struct page___81 *page;
};

struct vm_struct___77 {
	struct vm_struct___77 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___81 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___76;

struct attribute_group___76 {
	const char *name;
	umode_t (*is_visible)(struct kobject___76 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___76 *, struct bin_attribute___76 *, int);
	struct attribute **attrs;
	struct bin_attribute___76 **bin_attrs;
};

struct bin_attribute___76 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___76 * (*f_mapping)();
	ssize_t (*read)(struct file___76 *, struct kobject___76 *, struct bin_attribute___76 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___76 *, struct kobject___76 *, struct bin_attribute___76 *, char *, loff_t, size_t);
	int (*mmap)(struct file___76 *, struct kobject___76 *, struct bin_attribute___76 *, struct vm_area_struct___81 *);
};

struct sysfs_ops___76 {
	ssize_t (*show)(struct kobject___76 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___76 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___76;

struct kset___76 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___76 kobj;
	const struct kset_uevent_ops___76 *uevent_ops;
};

struct kobj_type___76 {
	void (*release)(struct kobject___76 *);
	const struct sysfs_ops___76 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___76 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___76 *);
	const void * (*namespace)(struct kobject___76 *);
	void (*get_ownership)(struct kobject___76 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___76 {
	int (* const filter)(struct kset___76 *, struct kobject___76 *);
	const char * (* const name)(struct kset___76 *, struct kobject___76 *);
	int (* const uevent)(struct kset___76 *, struct kobject___76 *, struct kobj_uevent_env *);
};

struct dev_pagemap_ops___75 {
	void (*page_free)(struct page___81 *);
	void (*kill)(struct dev_pagemap___75 *);
	void (*cleanup)(struct dev_pagemap___75 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___75 *);
};

struct dentry_operations___76;

struct dentry___76 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___76 *d_parent;
	struct qstr d_name;
	struct inode___76 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___76 *d_op;
	struct super_block___76 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___76;

struct inode___76 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___76 *i_op;
	struct super_block___76 *i_sb;
	struct address_space___76 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___76 *i_fop;
		void (*free_inode)(struct inode___76 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___76 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___76 {
	int (*d_revalidate)(struct dentry___76 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___76 *, unsigned int);
	int (*d_hash)(const struct dentry___76 *, struct qstr *);
	int (*d_compare)(const struct dentry___76 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___76 *);
	int (*d_init)(struct dentry___76 *);
	void (*d_release)(struct dentry___76 *);
	void (*d_prune)(struct dentry___76 *);
	void (*d_iput)(struct dentry___76 *, struct inode___76 *);
	char * (*d_dname)(struct dentry___76 *, char *, int);
	struct vfsmount___76 * (*d_automount)(struct path___76 *);
	int (*d_manage)(const struct path___76 *, bool);
	struct dentry___76 * (*d_real)(struct dentry___76 *, const struct inode___76 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___76;

struct mem_dqinfo___76 {
	struct quota_format_type___76 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___76;

struct quota_info___76 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___76 *files[3];
	struct mem_dqinfo___76 info[3];
	const struct quota_format_ops___76 *ops[3];
};

struct rcuwait___77 {
	struct task_struct___83 *task;
};

struct percpu_rw_semaphore___77 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___77 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___76 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___77 rw_sem[3];
};

struct super_operations___76;

struct dquot_operations___76;

struct quotactl_ops___76;

struct super_block___76 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___76 *s_type;
	const struct super_operations___76 *s_op;
	const struct dquot_operations___76 *dq_op;
	const struct quotactl_ops___76 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___76 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___76 s_dquot;
	struct sb_writers___76 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___76 *s_d_op;
	int cleancache_poolid;
	struct shrinker___33 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___76 {
	struct dentry___76 *mnt_root;
	struct super_block___76 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___34;

struct kiocb___76 {
	struct file___76 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___76 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___34 *ki_waitq;
	};
};

struct iattr___76 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___76 *ia_file;
};

struct dquot___76 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___76 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___76 {
	int qf_fmt_id;
	const struct quota_format_ops___76 *qf_ops;
	struct module___74 *qf_owner;
	struct quota_format_type___76 *qf_next;
};

struct quota_format_ops___76 {
	int (*check_quota_file)(struct super_block___76 *, int);
	int (*read_file_info)(struct super_block___76 *, int);
	int (*write_file_info)(struct super_block___76 *, int);
	int (*free_file_info)(struct super_block___76 *, int);
	int (*read_dqblk)(struct dquot___76 *);
	int (*commit_dqblk)(struct dquot___76 *);
	int (*release_dqblk)(struct dquot___76 *);
	int (*get_next_id)(struct super_block___76 *, struct kqid *);
};

struct dquot_operations___76 {
	int (*write_dquot)(struct dquot___76 *);
	struct dquot___76 * (*alloc_dquot)(struct super_block___76 *, int);
	void (*destroy_dquot)(struct dquot___76 *);
	int (*acquire_dquot)(struct dquot___76 *);
	int (*release_dquot)(struct dquot___76 *);
	int (*mark_dirty)(struct dquot___76 *);
	int (*write_info)(struct super_block___76 *, int);
	qsize_t * (*get_reserved_space)(struct inode___76 *);
	int (*get_projid)(struct inode___76 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___76 *, qsize_t *);
	int (*get_next_id)(struct super_block___76 *, struct kqid *);
};

struct quotactl_ops___76 {
	int (*quota_on)(struct super_block___76 *, int, int, const struct path___76 *);
	int (*quota_off)(struct super_block___76 *, int);
	int (*quota_enable)(struct super_block___76 *, unsigned int);
	int (*quota_disable)(struct super_block___76 *, unsigned int);
	int (*quota_sync)(struct super_block___76 *, int);
	int (*set_info)(struct super_block___76 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___76 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___76 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___76 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___76 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___76 *, unsigned int);
};

struct wait_page_queue___34 {
	struct page___81 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___34;

struct address_space_operations___76 {
	int (*writepage)(struct page___81 *, struct writeback_control___3 *);
	int (*readpage)(struct file___76 *, struct page___81 *);
	int (*writepages)(struct address_space___76 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___81 *);
	int (*readpages)(struct file___76 *, struct address_space___76 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___34 *);
	int (*write_begin)(struct file___76 *, struct address_space___76 *, loff_t, unsigned int, unsigned int, struct page___81 **, void **);
	int (*write_end)(struct file___76 *, struct address_space___76 *, loff_t, unsigned int, unsigned int, struct page___81 *, void *);
	sector_t (*bmap)(struct address_space___76 *, sector_t);
	void (*invalidatepage)(struct page___81 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___81 *, gfp_t);
	void (*freepage)(struct page___81 *);
	ssize_t (*direct_IO)(struct kiocb___76 *, struct iov_iter___46 *);
	int (*migratepage)(struct address_space___76 *, struct page___81 *, struct page___81 *, enum migrate_mode);
	bool (*isolate_page)(struct page___81 *, isolate_mode_t);
	void (*putback_page)(struct page___81 *);
	int (*launder_page)(struct page___81 *);
	int (*is_partially_uptodate)(struct page___81 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___81 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___76 *, struct page___81 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___76 *, sector_t *);
	void (*swap_deactivate)(struct file___76 *);
};

struct readahead_control___34 {
	struct file___76 *file;
	struct address_space___76 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___76 {
	struct dentry___76 * (*lookup)(struct inode___76 *, struct dentry___76 *, unsigned int);
	const char * (*get_link)(struct dentry___76 *, struct inode___76 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___76 *, int);
	struct posix_acl * (*get_acl)(struct inode___76 *, int, bool);
	int (*readlink)(struct dentry___76 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___76 *, struct dentry___76 *, umode_t, bool);
	int (*link)(struct dentry___76 *, struct inode___76 *, struct dentry___76 *);
	int (*unlink)(struct inode___76 *, struct dentry___76 *);
	int (*symlink)(struct user_namespace *, struct inode___76 *, struct dentry___76 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___76 *, struct dentry___76 *, umode_t);
	int (*rmdir)(struct inode___76 *, struct dentry___76 *);
	int (*mknod)(struct user_namespace *, struct inode___76 *, struct dentry___76 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___76 *, struct dentry___76 *, struct inode___76 *, struct dentry___76 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___76 *, struct iattr___76 *);
	int (*getattr)(struct user_namespace *, const struct path___76 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___76 *, char *, size_t);
	int (*fiemap)(struct inode___76 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___76 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___76 *, struct dentry___76 *, struct file___76 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___76 *, struct dentry___76 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___76 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___76 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___76 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___76 {
	void (*fl_copy_lock)(struct file_lock___76 *, struct file_lock___76 *);
	void (*fl_release_private)(struct file_lock___76 *);
};

struct fasync_struct___76;

struct lock_manager_operations___76;

struct file_lock___76 {
	struct file_lock___76 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___76 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___76 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___76 *fl_ops;
	const struct lock_manager_operations___76 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___76 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___76 *);
	int (*lm_grant)(struct file_lock___76 *, int);
	bool (*lm_break)(struct file_lock___76 *);
	int (*lm_change)(struct file_lock___76 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___76 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___76 *);
};

struct fasync_struct___76 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___76 *fa_next;
	struct file___76 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___76 {
	struct inode___76 * (*alloc_inode)(struct super_block___76 *);
	void (*destroy_inode)(struct inode___76 *);
	void (*free_inode)(struct inode___76 *);
	void (*dirty_inode)(struct inode___76 *, int);
	int (*write_inode)(struct inode___76 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___76 *);
	void (*evict_inode)(struct inode___76 *);
	void (*put_super)(struct super_block___76 *);
	int (*sync_fs)(struct super_block___76 *, int);
	int (*freeze_super)(struct super_block___76 *);
	int (*freeze_fs)(struct super_block___76 *);
	int (*thaw_super)(struct super_block___76 *);
	int (*unfreeze_fs)(struct super_block___76 *);
	int (*statfs)(struct dentry___76 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___76 *, int *, char *);
	void (*umount_begin)(struct super_block___76 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___76 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___76 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___76 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___76 *);
	ssize_t (*quota_read)(struct super_block___76 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___76 *, int, const char *, size_t, loff_t);
	struct dquot___76 ** (*get_dquots)(struct inode___76 *);
	long int (*nr_cached_objects)(struct super_block___76 *, struct shrink_control___33 *);
	long int (*free_cached_objects)(struct super_block___76 *, struct shrink_control___33 *);
	struct file___76 * (*real_loop)(struct file___76 *);
};

struct kernel_param_ops___73 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___73 *);
	int (*get)(char *, const struct kernel_param___73 *);
	void (*free)(void *);
};

struct kparam_array___73;

struct kernel_param___73 {
	const char *name;
	struct module___74 *mod;
	const struct kernel_param_ops___73 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___73 *arr;
	};
};

struct kparam_array___73 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___73 *ops;
	void *elem;
};

struct module_attribute___73 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___73 *, struct module_kobject___73 *, char *);
	ssize_t (*store)(struct module_attribute___73 *, struct module_kobject___73 *, const char *, size_t);
	void (*setup)(struct module___74 *, const char *);
	int (*test)(struct module___74 *);
	void (*free)(struct module___74 *);
};

struct compact_control___6 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___36 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct pcpu_group_info {
	int nr_units;
	long unsigned int base_offset;
	unsigned int *cpu_map;
};

struct pcpu_alloc_info {
	size_t static_size;
	size_t reserved_size;
	size_t dyn_size;
	size_t unit_size;
	size_t atom_size;
	size_t alloc_size;
	size_t __ai_size;
	int nr_groups;
	struct pcpu_group_info groups[0];
};

typedef void * (*pcpu_fc_alloc_fn_t)(unsigned int, size_t, size_t);

typedef void (*pcpu_fc_free_fn_t)(void *, size_t);

typedef int pcpu_fc_cpu_distance_fn_t(unsigned int, unsigned int);

struct trace_event_raw_percpu_alloc_percpu {
	struct trace_entry ent;
	bool reserved;
	bool is_atomic;
	size_t size;
	size_t align;
	void *base_addr;
	int off;
	void *ptr;
	char __data[0];
};

struct trace_event_raw_percpu_free_percpu {
	struct trace_entry ent;
	void *base_addr;
	int off;
	void *ptr;
	char __data[0];
};

struct trace_event_raw_percpu_alloc_percpu_fail {
	struct trace_entry ent;
	bool reserved;
	bool is_atomic;
	size_t size;
	size_t align;
	char __data[0];
};

struct trace_event_raw_percpu_create_chunk {
	struct trace_entry ent;
	void *base_addr;
	char __data[0];
};

struct trace_event_raw_percpu_destroy_chunk {
	struct trace_entry ent;
	void *base_addr;
	char __data[0];
};

struct trace_event_data_offsets_percpu_alloc_percpu {};

struct trace_event_data_offsets_percpu_free_percpu {};

struct trace_event_data_offsets_percpu_alloc_percpu_fail {};

struct trace_event_data_offsets_percpu_create_chunk {};

struct trace_event_data_offsets_percpu_destroy_chunk {};

typedef void (*btf_trace_percpu_alloc_percpu)(void *, bool, bool, size_t, size_t, void *, int, void *);

typedef void (*btf_trace_percpu_free_percpu)(void *, void *, int, void *);

typedef void (*btf_trace_percpu_alloc_percpu_fail)(void *, bool, bool, size_t, size_t);

typedef void (*btf_trace_percpu_create_chunk)(void *, void *);

typedef void (*btf_trace_percpu_destroy_chunk)(void *, void *);

struct pcpu_block_md {
	int scan_hint;
	int scan_hint_start;
	int contig_hint;
	int contig_hint_start;
	int left_free;
	int right_free;
	int first_free;
	int nr_bits;
};

struct pcpu_chunk {
	struct list_head list;
	int free_bytes;
	struct pcpu_block_md chunk_md;
	void *base_addr;
	long unsigned int *alloc_map;
	long unsigned int *bound_map;
	struct pcpu_block_md *md_blocks;
	void *data;
	bool immutable;
	bool isolated;
	int start_offset;
	int end_offset;
	struct obj_cgroup___31 **obj_cgroups;
	int nr_pages;
	int nr_populated;
	int nr_empty_pop_pages;
	long unsigned int populated[0];
};

struct dentry___77;

struct super_block___77;

struct module___75;

struct file_system_type___77 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___77 * (*mount)(struct file_system_type___77 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___77 *);
	struct module___75 *owner;
	struct file_system_type___77 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___77;

struct kiocb___77;

struct iov_iter___47;

struct poll_table_struct___58;

struct vm_area_struct___82;

struct inode___77;

struct file_lock___77;

struct page___82;

struct seq_file___73;

struct file_operations___77 {
	struct module___75 *owner;
	loff_t (*llseek)(struct file___77 *, loff_t, int);
	ssize_t (*read)(struct file___77 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___77 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___77 *, struct iov_iter___47 *);
	ssize_t (*write_iter)(struct kiocb___77 *, struct iov_iter___47 *);
	int (*iopoll)(struct kiocb___77 *, bool);
	int (*iterate)(struct file___77 *, struct dir_context *);
	int (*iterate_shared)(struct file___77 *, struct dir_context *);
	__poll_t (*poll)(struct file___77 *, struct poll_table_struct___58 *);
	long int (*unlocked_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___77 *, struct vm_area_struct___82 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___77 *, struct file___77 *);
	int (*flush)(struct file___77 *, fl_owner_t);
	int (*release)(struct inode___77 *, struct file___77 *);
	int (*fsync)(struct file___77 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___77 *, int);
	int (*lock)(struct file___77 *, int, struct file_lock___77 *);
	ssize_t (*sendpage)(struct file___77 *, struct page___82 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___77 *, long unsigned int);
	int (*flock)(struct file___77 *, int, struct file_lock___77 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___77 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___77 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___77 *, long int, struct file_lock___77 **, void **);
	long int (*fallocate)(struct file___77 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___73 *, struct file___77 *);
	ssize_t (*copy_file_range)(struct file___77 *, loff_t, struct file___77 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___77 *, loff_t, struct file___77 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___77 *, loff_t, loff_t, int);
};

struct vmacache___82 {
	u64 seqnum;
	struct vm_area_struct___82 *vmas[4];
};

struct page_frag___82 {
	struct page___82 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___49;

struct debug_info___49 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___49 *hbp_break[16];
	struct perf_event___49 *hbp_watch[16];
};

struct thread_struct___49 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___49 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___83;

struct pid___70;

struct nsproxy___75;

struct signal_struct___78;

struct bio_list___37;

struct backing_dev_info___36;

struct io_context___37;

struct capture_control___7;

struct css_set___64;

struct perf_event_context___49;

struct mem_cgroup___34;

struct request_queue___37;

struct vm_struct___78;

struct task_struct___84 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___84 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___83 *mm;
	struct mm_struct___83 *active_mm;
	struct vmacache___82 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___84 *real_parent;
	struct task_struct___84 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___84 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___70 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___75 *nsproxy;
	struct signal_struct___78 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___84 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___37 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___36 *backing_dev_info;
	struct io_context___37 *io_context;
	struct capture_control___7 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___64 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___49 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___82 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___34 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___34 *active_memcg;
	struct request_queue___37 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___84 *oom_reaper_list;
	struct vm_struct___78 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___49 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___77;

struct kobj_type___77;

struct kernfs_node___77;

struct kobject___77 {
	const char *name;
	struct list_head entry;
	struct kobject___77 *parent;
	struct kset___77 *kset;
	struct kobj_type___77 *ktype;
	struct kernfs_node___77 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___74 {
	struct kobject___77 kobj;
	struct module___75 *mod;
	struct kobject___77 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___74 {
	struct module___75 *mod;
	struct latch_tree_node node;
};

struct module_layout___74 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___74 mtn;
};

struct module_attribute___74;

struct kernel_param___74;

struct trace_event_call___43;

struct module___75 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___74 mkobj;
	struct module_attribute___74 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___77 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___74 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___74 core_layout;
	struct module_layout___74 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___43 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___49 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___84 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___49)(struct perf_event___49 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___49;

struct fasync_struct___77;

struct pid_namespace___70;

struct perf_cgroup___49;

struct perf_event___49 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___49 *group_leader;
	struct pmu___49 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___49 hw;
	struct perf_event_context___49 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___49 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___84 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___77 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___49 *aux_event;
	void (*destroy)(struct perf_event___49 *);
	struct callback_head callback_head;
	struct pid_namespace___70 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___49 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___49 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___43 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___49 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___82 *pgtable_t___82;

struct address_space___77;

struct kmem_cache___3;

struct dev_pagemap___76;

struct page___82 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___77 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___82 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___3 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___82 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___83 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___76 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___76;

struct vm_area_struct___82 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___82 *vm_next;
	struct vm_area_struct___82 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___83 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___76 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___77 *vm_file;
	struct file___77 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___82;

struct mm_struct___83 {
	struct {
		struct vm_area_struct___82 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___82 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___84 *owner;
		struct user_namespace___12 *user_ns;
		struct file___77 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___77;

struct address_space___77 {
	struct inode___77 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___77 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct kmem_cache_cpu___3;

struct kmem_cache___3 {
	struct kmem_cache_cpu___3 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	struct reciprocal_value reciprocal_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___77 kobj;
	long unsigned int random;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[64];
};

struct dev_pagemap_ops___76;

struct dev_pagemap___76 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___76 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___77;

struct path___77 {
	struct vfsmount___77 *mnt;
	struct dentry___77 *dentry;
};

struct fown_struct___70 {
	rwlock_t lock;
	struct pid___70 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___77 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___77 f_path;
	struct inode___77 *f_inode;
	const struct file_operations___77 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___70 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___77 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___76;

struct vm_operations_struct___76 {
	void (*open)(struct vm_area_struct___82 *);
	void (*close)(struct vm_area_struct___82 *);
	int (*may_split)(struct vm_area_struct___82 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___82 *);
	int (*mprotect)(struct vm_area_struct___82 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___76 *);
	vm_fault_t (*huge_fault)(struct vm_fault___76 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___76 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___82 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___76 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___76 *);
	int (*access)(struct vm_area_struct___82 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___82 *);
	int (*set_policy)(struct vm_area_struct___82 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___82 *, long unsigned int);
	struct page___82 * (*find_special_page)(struct vm_area_struct___82 *, long unsigned int);
};

struct core_thread___82 {
	struct task_struct___84 *task;
	struct core_thread___82 *next;
};

struct core_state___82 {
	atomic_t nr_threads;
	struct core_thread___82 dumper;
	struct completion startup;
};

struct vm_fault___76 {
	const struct {
		struct vm_area_struct___82 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___82 *cow_page;
	struct page___82 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___82 prealloc_pte;
};

struct pglist_data___37;

struct lruvec___37 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___37 *pgdat;
};

struct zone___37 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___37 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___37 {
	struct zone___37 *zone;
	int zone_idx;
};

struct zonelist___37 {
	struct zoneref___37 _zonerefs[321];
};

struct pglist_data___37 {
	struct zone___37 node_zones[5];
	struct zonelist___37 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___84 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___84 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___37 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___34 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___34 *memcg;
};

struct cgroup___64;

struct cgroup_subsys___64;

struct cgroup_subsys_state___64 {
	struct cgroup___64 *cgroup;
	struct cgroup_subsys___64 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___64 *parent;
};

struct cgroup_file___64 {
	struct kernfs_node___77 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___34;

struct mem_cgroup_per_node___34;

struct mem_cgroup___34 {
	struct cgroup_subsys_state___64 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___64 events_file;
	struct cgroup_file___64 events_local_file;
	struct cgroup_file___64 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___34 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___84 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___34 *nodeinfo[0];
	long: 64;
};

struct shrinker___34 {
	long unsigned int (*count_objects)(struct shrinker___34 *, struct shrink_control___34 *);
	long unsigned int (*scan_objects)(struct shrinker___34 *, struct shrink_control___34 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___76 {
	void (*page_free)(struct page___82 *);
	void (*kill)(struct dev_pagemap___76 *);
	void (*cleanup)(struct dev_pagemap___76 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___76 *);
};

struct upid___70 {
	int nr;
	struct pid_namespace___70 *ns;
};

struct pid_namespace___70 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___84 *child_reaper;
	struct kmem_cache___3 *pid_cachep;
	unsigned int level;
	struct pid_namespace___70 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___70 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___70 numbers[1];
};

struct signal_struct___78 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___84 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___84 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___70 *pids[4];
	struct pid___70 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___83 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___64;

struct nsproxy___75 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___70 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___64 *cgroup_ns;
};

struct bio___37;

struct bio_list___37 {
	struct bio___37 *head;
	struct bio___37 *tail;
};

struct bdi_writeback___36 {
	struct backing_dev_info___36 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___64 *memcg_css;
	struct cgroup_subsys_state___64 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___68;

struct backing_dev_info___36 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___36 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___68 *dev;
	char dev_name[64];
	struct device___68 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___77 *debug_dir;
};

struct io_cq___37;

struct io_context___37 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___37 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___7;

struct capture_control___7 {
	struct compact_control___7 *cc;
	struct page___82 *page;
};

struct css_set___64 {
	struct cgroup_subsys_state___64 *subsys[14];
	refcount_t refcount;
	struct css_set___64 *dom_cset;
	struct cgroup___64 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___64 *mg_src_cgrp;
	struct cgroup___64 *mg_dst_cgrp;
	struct css_set___64 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___49 {
	struct pmu___49 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___84 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___49 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___37;

struct blk_integrity___37 {
	const struct blk_integrity_profile___37 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___37 {
	struct kmem_cache___3 *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___37 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___37;

struct elevator_queue___37;

struct blk_mq_ops___36;

struct blk_mq_hw_ctx___36;

struct gendisk___37;

struct blkcg_gq___36;

struct blk_mq_tag_set___36;

struct request_queue___37 {
	struct request___37 *last_merge;
	struct elevator_queue___37 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___36 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___36 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___37 *disk;
	struct kobject___77 kobj;
	struct kobject___77 *mq_kobj;
	struct blk_integrity___37 integrity;
	struct device___68 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___36 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___36 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___37 bio_split;
	struct dentry___77 *debugfs_dir;
	struct dentry___77 *sched_debugfs_dir;
	struct dentry___77 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___78 {
	struct vm_struct___78 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___82 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___77;

struct dentry___77 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___77 *d_parent;
	struct qstr d_name;
	struct inode___77 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___77 *d_op;
	struct super_block___77 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___77;

struct inode___77 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___77 *i_op;
	struct super_block___77 *i_sb;
	struct address_space___77 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___36 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___77 *i_fop;
		void (*free_inode)(struct inode___77 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___77 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___77 {
	int (*d_revalidate)(struct dentry___77 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___77 *, unsigned int);
	int (*d_hash)(const struct dentry___77 *, struct qstr *);
	int (*d_compare)(const struct dentry___77 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___77 *);
	int (*d_init)(struct dentry___77 *);
	void (*d_release)(struct dentry___77 *);
	void (*d_prune)(struct dentry___77 *);
	void (*d_iput)(struct dentry___77 *, struct inode___77 *);
	char * (*d_dname)(struct dentry___77 *, char *, int);
	struct vfsmount___77 * (*d_automount)(struct path___77 *);
	int (*d_manage)(const struct path___77 *, bool);
	struct dentry___77 * (*d_real)(struct dentry___77 *, const struct inode___77 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___77;

struct mem_dqinfo___77 {
	struct quota_format_type___77 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___77;

struct quota_info___77 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___77 *files[3];
	struct mem_dqinfo___77 info[3];
	const struct quota_format_ops___77 *ops[3];
};

struct rcuwait___78 {
	struct task_struct___84 *task;
};

struct percpu_rw_semaphore___78 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___78 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___77 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___78 rw_sem[3];
};

struct super_operations___77;

struct dquot_operations___77;

struct quotactl_ops___77;

struct block_device___38;

struct super_block___77 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___77 *s_type;
	const struct super_operations___77 *s_op;
	const struct dquot_operations___77 *dq_op;
	const struct quotactl_ops___77 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___77 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___38 *s_bdev;
	struct backing_dev_info___36 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___77 s_dquot;
	struct sb_writers___77 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___77 *s_d_op;
	int cleancache_poolid;
	struct shrinker___34 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___77 {
	struct dentry___77 *mnt_root;
	struct super_block___77 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct psi_group___64 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___84 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___64;

struct cgroup_rstat_cpu___64;

struct cgroup___64 {
	struct cgroup_subsys_state___64 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___77 *kn;
	struct cgroup_file___64 procs_file;
	struct cgroup_file___64 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___64 *subsys[14];
	struct cgroup_root___64 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___64 *dom_cgrp;
	struct cgroup___64 *old_dom_cgrp;
	struct cgroup_rstat_cpu___64 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___64 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___37 {
	struct request_queue___37 *q;
	struct io_context___37 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___3 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___35;

struct kiocb___77 {
	struct file___77 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___77 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___35 *ki_waitq;
	};
};

struct iattr___77 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___77 *ia_file;
};

struct dquot___77 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___77 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___77 {
	int qf_fmt_id;
	const struct quota_format_ops___77 *qf_ops;
	struct module___75 *qf_owner;
	struct quota_format_type___77 *qf_next;
};

struct quota_format_ops___77 {
	int (*check_quota_file)(struct super_block___77 *, int);
	int (*read_file_info)(struct super_block___77 *, int);
	int (*write_file_info)(struct super_block___77 *, int);
	int (*free_file_info)(struct super_block___77 *, int);
	int (*read_dqblk)(struct dquot___77 *);
	int (*commit_dqblk)(struct dquot___77 *);
	int (*release_dqblk)(struct dquot___77 *);
	int (*get_next_id)(struct super_block___77 *, struct kqid *);
};

struct dquot_operations___77 {
	int (*write_dquot)(struct dquot___77 *);
	struct dquot___77 * (*alloc_dquot)(struct super_block___77 *, int);
	void (*destroy_dquot)(struct dquot___77 *);
	int (*acquire_dquot)(struct dquot___77 *);
	int (*release_dquot)(struct dquot___77 *);
	int (*mark_dirty)(struct dquot___77 *);
	int (*write_info)(struct super_block___77 *, int);
	qsize_t * (*get_reserved_space)(struct inode___77 *);
	int (*get_projid)(struct inode___77 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___77 *, qsize_t *);
	int (*get_next_id)(struct super_block___77 *, struct kqid *);
};

struct quotactl_ops___77 {
	int (*quota_on)(struct super_block___77 *, int, int, const struct path___77 *);
	int (*quota_off)(struct super_block___77 *, int);
	int (*quota_enable)(struct super_block___77 *, unsigned int);
	int (*quota_disable)(struct super_block___77 *, unsigned int);
	int (*quota_sync)(struct super_block___77 *, int);
	int (*set_info)(struct super_block___77 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___77 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___77 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___77 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___77 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___77 *, unsigned int);
};

struct wait_page_queue___35 {
	struct page___82 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___36;

struct readahead_control___35;

struct address_space_operations___77 {
	int (*writepage)(struct page___82 *, struct writeback_control___36 *);
	int (*readpage)(struct file___77 *, struct page___82 *);
	int (*writepages)(struct address_space___77 *, struct writeback_control___36 *);
	int (*set_page_dirty)(struct page___82 *);
	int (*readpages)(struct file___77 *, struct address_space___77 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___35 *);
	int (*write_begin)(struct file___77 *, struct address_space___77 *, loff_t, unsigned int, unsigned int, struct page___82 **, void **);
	int (*write_end)(struct file___77 *, struct address_space___77 *, loff_t, unsigned int, unsigned int, struct page___82 *, void *);
	sector_t (*bmap)(struct address_space___77 *, sector_t);
	void (*invalidatepage)(struct page___82 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___82 *, gfp_t);
	void (*freepage)(struct page___82 *);
	ssize_t (*direct_IO)(struct kiocb___77 *, struct iov_iter___47 *);
	int (*migratepage)(struct address_space___77 *, struct page___82 *, struct page___82 *, enum migrate_mode);
	bool (*isolate_page)(struct page___82 *, isolate_mode_t);
	void (*putback_page)(struct page___82 *);
	int (*launder_page)(struct page___82 *);
	int (*is_partially_uptodate)(struct page___82 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___82 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___77 *, struct page___82 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___77 *, sector_t *);
	void (*swap_deactivate)(struct file___77 *);
};

struct writeback_control___36 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___36 *wb;
	struct inode___77 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___35 {
	struct file___77 *file;
	struct address_space___77 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___46;

struct iov_iter___47 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___46 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___77 {
	struct dentry___77 * (*lookup)(struct inode___77 *, struct dentry___77 *, unsigned int);
	const char * (*get_link)(struct dentry___77 *, struct inode___77 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___77 *, int);
	struct posix_acl * (*get_acl)(struct inode___77 *, int, bool);
	int (*readlink)(struct dentry___77 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___77 *, struct dentry___77 *, umode_t, bool);
	int (*link)(struct dentry___77 *, struct inode___77 *, struct dentry___77 *);
	int (*unlink)(struct inode___77 *, struct dentry___77 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___77 *, struct dentry___77 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___77 *, struct dentry___77 *, umode_t);
	int (*rmdir)(struct inode___77 *, struct dentry___77 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___77 *, struct dentry___77 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___77 *, struct dentry___77 *, struct inode___77 *, struct dentry___77 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___77 *, struct iattr___77 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___77 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___77 *, char *, size_t);
	int (*fiemap)(struct inode___77 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___77 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___77 *, struct dentry___77 *, struct file___77 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___77 *, struct dentry___77 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___77 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___77 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___77 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___77 {
	void (*fl_copy_lock)(struct file_lock___77 *, struct file_lock___77 *);
	void (*fl_release_private)(struct file_lock___77 *);
};

struct lock_manager_operations___77;

struct file_lock___77 {
	struct file_lock___77 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___77 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___77 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___77 *fl_ops;
	const struct lock_manager_operations___77 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___77 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___77 *);
	int (*lm_grant)(struct file_lock___77 *, int);
	bool (*lm_break)(struct file_lock___77 *);
	int (*lm_change)(struct file_lock___77 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___77 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___77 *);
};

struct fasync_struct___77 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___77 *fa_next;
	struct file___77 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___77 {
	struct inode___77 * (*alloc_inode)(struct super_block___77 *);
	void (*destroy_inode)(struct inode___77 *);
	void (*free_inode)(struct inode___77 *);
	void (*dirty_inode)(struct inode___77 *, int);
	int (*write_inode)(struct inode___77 *, struct writeback_control___36 *);
	int (*drop_inode)(struct inode___77 *);
	void (*evict_inode)(struct inode___77 *);
	void (*put_super)(struct super_block___77 *);
	int (*sync_fs)(struct super_block___77 *, int);
	int (*freeze_super)(struct super_block___77 *);
	int (*freeze_fs)(struct super_block___77 *);
	int (*thaw_super)(struct super_block___77 *);
	int (*unfreeze_fs)(struct super_block___77 *);
	int (*statfs)(struct dentry___77 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___77 *, int *, char *);
	void (*umount_begin)(struct super_block___77 *);
	int (*show_options)(struct seq_file___73 *, struct dentry___77 *);
	int (*show_devname)(struct seq_file___73 *, struct dentry___77 *);
	int (*show_path)(struct seq_file___73 *, struct dentry___77 *);
	int (*show_stats)(struct seq_file___73 *, struct dentry___77 *);
	ssize_t (*quota_read)(struct super_block___77 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___77 *, int, const char *, size_t, loff_t);
	struct dquot___77 ** (*get_dquots)(struct inode___77 *);
	long int (*nr_cached_objects)(struct super_block___77 *, struct shrink_control___34 *);
	long int (*free_cached_objects)(struct super_block___77 *, struct shrink_control___34 *);
	struct file___77 * (*real_loop)(struct file___77 *);
};

struct wakeup_source___68;

struct dev_pm_info___68 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___68 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___68 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___68;

struct bus_type___68;

struct device_driver___68;

struct dev_pm_domain___68;

struct fwnode_handle___68;

struct class___68;

struct attribute_group___77;

struct device___68 {
	struct kobject___77 kobj;
	struct device___68 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___68 *type;
	struct bus_type___68 *bus;
	struct device_driver___68 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___68 power;
	struct dev_pm_domain___68 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___68 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___68 *class;
	const struct attribute_group___77 **groups;
	void (*release)(struct device___68 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___38 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___77 *bd_inode;
	struct super_block___77 *bd_super;
	void *bd_claiming;
	struct device___68 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___77 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___37 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___77 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___58)(struct file___77 *, wait_queue_head_t *, struct poll_table_struct___58 *);

struct poll_table_struct___58 {
	poll_queue_proc___58 _qproc;
	__poll_t _key;
};

struct seq_operations___73;

struct seq_file___73 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___73 *op;
	int poll_event;
	const struct file___77 *file;
	void *private;
};

typedef void bio_end_io_t___37(struct bio___37 *);

struct bio_vec___46 {
	struct page___82 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___37;

struct bio___37 {
	struct bio___37 *bi_next;
	struct block_device___38 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___37 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___36 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___37 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___46 *bi_io_vec;
	struct bio_set___37 *bi_pool;
	struct bio_vec___46 bi_inline_vecs[0];
};

struct fwnode_operations___68;

struct fwnode_handle___68 {
	struct fwnode_handle___68 *secondary;
	const struct fwnode_operations___68 *ops;
	struct device___68 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___68;

struct fwnode_endpoint___68;

struct fwnode_operations___68 {
	struct fwnode_handle___68 * (*get)(struct fwnode_handle___68 *);
	void (*put)(struct fwnode_handle___68 *);
	bool (*device_is_available)(const struct fwnode_handle___68 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___68 *, const struct device___68 *);
	bool (*property_present)(const struct fwnode_handle___68 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___68 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___68 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___68 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*get_parent)(const struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*get_next_child_node)(const struct fwnode_handle___68 *, struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*get_named_child_node)(const struct fwnode_handle___68 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___68 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___68 *);
	struct fwnode_handle___68 * (*graph_get_next_endpoint)(const struct fwnode_handle___68 *, struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*graph_get_remote_endpoint)(const struct fwnode_handle___68 *);
	struct fwnode_handle___68 * (*graph_get_port_parent)(struct fwnode_handle___68 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___68 *, struct fwnode_endpoint___68 *);
	int (*add_links)(struct fwnode_handle___68 *);
};

struct fwnode_endpoint___68 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___68 *local_fwnode;
};

struct fwnode_reference_args___68 {
	struct fwnode_handle___68 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___77;

struct kernfs_elem_dir___77 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___77 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___77;

struct kernfs_root___77 {
	struct kernfs_node___77 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___77 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___77 {
	struct kernfs_node___77 *target_kn;
};

struct kernfs_ops___77;

struct kernfs_elem_attr___77 {
	const struct kernfs_ops___77 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___77 *notify_next;
};

struct kernfs_node___77 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___77 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___77 dir;
		struct kernfs_elem_symlink___77 symlink;
		struct kernfs_elem_attr___77 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___77;

struct kernfs_ops___77 {
	int (*open)(struct kernfs_open_file___77 *);
	void (*release)(struct kernfs_open_file___77 *);
	int (*seq_show)(struct seq_file___73 *, void *);
	void * (*seq_start)(struct seq_file___73 *, loff_t *);
	void * (*seq_next)(struct seq_file___73 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___73 *, void *);
	ssize_t (*read)(struct kernfs_open_file___77 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___77 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___77 *, struct poll_table_struct___58 *);
	int (*mmap)(struct kernfs_open_file___77 *, struct vm_area_struct___82 *);
};

struct kernfs_syscall_ops___77 {
	int (*show_options)(struct seq_file___73 *, struct kernfs_root___77 *);
	int (*mkdir)(struct kernfs_node___77 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___77 *);
	int (*rename)(struct kernfs_node___77 *, struct kernfs_node___77 *, const char *);
	int (*show_path)(struct seq_file___73 *, struct kernfs_node___77 *, struct kernfs_root___77 *);
};

struct kernfs_open_file___77 {
	struct kernfs_node___77 *kn;
	struct file___77 *file;
	struct seq_file___73 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___76 *vm_ops;
};

struct bin_attribute___77;

struct attribute_group___77 {
	const char *name;
	umode_t (*is_visible)(struct kobject___77 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___77 *, struct bin_attribute___77 *, int);
	struct attribute **attrs;
	struct bin_attribute___77 **bin_attrs;
};

struct bin_attribute___77 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___77 * (*f_mapping)();
	ssize_t (*read)(struct file___77 *, struct kobject___77 *, struct bin_attribute___77 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___77 *, struct kobject___77 *, struct bin_attribute___77 *, char *, loff_t, size_t);
	int (*mmap)(struct file___77 *, struct kobject___77 *, struct bin_attribute___77 *, struct vm_area_struct___82 *);
};

struct sysfs_ops___77 {
	ssize_t (*show)(struct kobject___77 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___77 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___77;

struct kset___77 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___77 kobj;
	const struct kset_uevent_ops___77 *uevent_ops;
};

struct kobj_type___77 {
	void (*release)(struct kobject___77 *);
	const struct sysfs_ops___77 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___77 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___77 *);
	const void * (*namespace)(struct kobject___77 *);
	void (*get_ownership)(struct kobject___77 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___77 {
	int (* const filter)(struct kset___77 *, struct kobject___77 *);
	const char * (* const name)(struct kset___77 *, struct kobject___77 *);
	int (* const uevent)(struct kset___77 *, struct kobject___77 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___68 {
	int (*prepare)(struct device___68 *);
	void (*complete)(struct device___68 *);
	int (*suspend)(struct device___68 *);
	int (*resume)(struct device___68 *);
	int (*freeze)(struct device___68 *);
	int (*thaw)(struct device___68 *);
	int (*poweroff)(struct device___68 *);
	int (*restore)(struct device___68 *);
	int (*suspend_late)(struct device___68 *);
	int (*resume_early)(struct device___68 *);
	int (*freeze_late)(struct device___68 *);
	int (*thaw_early)(struct device___68 *);
	int (*poweroff_late)(struct device___68 *);
	int (*restore_early)(struct device___68 *);
	int (*suspend_noirq)(struct device___68 *);
	int (*resume_noirq)(struct device___68 *);
	int (*freeze_noirq)(struct device___68 *);
	int (*thaw_noirq)(struct device___68 *);
	int (*poweroff_noirq)(struct device___68 *);
	int (*restore_noirq)(struct device___68 *);
	int (*runtime_suspend)(struct device___68 *);
	int (*runtime_resume)(struct device___68 *);
	int (*runtime_idle)(struct device___68 *);
};

struct wakeup_source___68 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___68 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___68 {
	struct dev_pm_ops___68 ops;
	int (*start)(struct device___68 *);
	void (*detach)(struct device___68 *, bool);
	int (*activate)(struct device___68 *);
	void (*sync)(struct device___68 *);
	void (*dismiss)(struct device___68 *);
};

struct bus_type___68 {
	const char *name;
	const char *dev_name;
	struct device___68 *dev_root;
	const struct attribute_group___77 **bus_groups;
	const struct attribute_group___77 **dev_groups;
	const struct attribute_group___77 **drv_groups;
	int (*match)(struct device___68 *, struct device_driver___68 *);
	int (*uevent)(struct device___68 *, struct kobj_uevent_env *);
	int (*probe)(struct device___68 *);
	void (*sync_state)(struct device___68 *);
	void (*remove)(struct device___68 *);
	void (*shutdown)(struct device___68 *);
	int (*online)(struct device___68 *);
	int (*offline)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	int (*num_vf)(struct device___68 *);
	int (*dma_configure)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___68 {
	const char *name;
	struct bus_type___68 *bus;
	struct module___75 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___68 *);
	void (*sync_state)(struct device___68 *);
	int (*remove)(struct device___68 *);
	void (*shutdown)(struct device___68 *);
	int (*suspend)(struct device___68 *, pm_message_t);
	int (*resume)(struct device___68 *);
	const struct attribute_group___77 **groups;
	const struct attribute_group___77 **dev_groups;
	const struct dev_pm_ops___68 *pm;
	void (*coredump)(struct device___68 *);
	struct driver_private *p;
};

struct device_type___68 {
	const char *name;
	const struct attribute_group___77 **groups;
	int (*uevent)(struct device___68 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___68 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___68 *);
	const struct dev_pm_ops___68 *pm;
};

struct class___68 {
	const char *name;
	struct module___75 *owner;
	const struct attribute_group___77 **class_groups;
	const struct attribute_group___77 **dev_groups;
	struct kobject___77 *dev_kobj;
	int (*dev_uevent)(struct device___68 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___68 *, umode_t *);
	void (*class_release)(struct class___68 *);
	void (*dev_release)(struct device___68 *);
	int (*shutdown_pre)(struct device___68 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___68 *);
	void (*get_ownership)(struct device___68 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___68 *pm;
	struct subsys_private *p;
};

struct kernel_param_ops___74 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___74 *);
	int (*get)(char *, const struct kernel_param___74 *);
	void (*free)(void *);
};

struct kparam_array___74;

struct kernel_param___74 {
	const char *name;
	struct module___75 *mod;
	const struct kernel_param_ops___74 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___74 *arr;
	};
};

struct kparam_array___74 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___74 *ops;
	void *elem;
};

struct module_attribute___74 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___74 *, struct module_kobject___74 *, char *);
	ssize_t (*store)(struct module_attribute___74 *, struct module_kobject___74 *, const char *, size_t);
	void (*setup)(struct module___75 *, const char *);
	int (*test)(struct module___75 *);
	void (*free)(struct module___75 *);
};

struct trace_event_class___43;

struct trace_event_call___43 {
	struct list_head list;
	struct trace_event_class___43 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___43 *, struct perf_event___49 *);
};

struct seq_operations___73 {
	void * (*start)(struct seq_file___73 *, loff_t *);
	void (*stop)(struct seq_file___73 *, void *);
	void * (*next)(struct seq_file___73 *, void *, loff_t *);
	int (*show)(struct seq_file___73 *, void *);
};

struct proc_ops___6 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___77 *, struct file___77 *);
	ssize_t (*proc_read)(struct file___77 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___77 *, struct iov_iter___47 *);
	ssize_t (*proc_write)(struct file___77 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___77 *, loff_t, int);
	int (*proc_release)(struct inode___77 *, struct file___77 *);
	__poll_t (*proc_poll)(struct file___77 *, struct poll_table_struct___58 *);
	long int (*proc_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___77 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___77 *, struct vm_area_struct___82 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___77 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct cgroup_namespace___64 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___64 *root_cset;
};

struct cftype___64;

struct cgroup_subsys___64 {
	struct cgroup_subsys_state___64 * (*css_alloc)(struct cgroup_subsys_state___64 *);
	int (*css_online)(struct cgroup_subsys_state___64 *);
	void (*css_offline)(struct cgroup_subsys_state___64 *);
	void (*css_released)(struct cgroup_subsys_state___64 *);
	void (*css_free)(struct cgroup_subsys_state___64 *);
	void (*css_reset)(struct cgroup_subsys_state___64 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___64 *, int);
	int (*css_extra_stat_show)(struct seq_file___73 *, struct cgroup_subsys_state___64 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___84 *, struct css_set___64 *);
	void (*cancel_fork)(struct task_struct___84 *, struct css_set___64 *);
	void (*fork)(struct task_struct___84 *);
	void (*exit)(struct task_struct___84 *);
	void (*release)(struct task_struct___84 *);
	void (*bind)(struct cgroup_subsys_state___64 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___64 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___64 *dfl_cftypes;
	struct cftype___64 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___64 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___64 *updated_children;
	struct cgroup___64 *updated_next;
};

struct cgroup_root___64 {
	struct kernfs_root___77 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___64 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___64 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___64 *ss;
	struct list_head node;
	struct kernfs_ops___77 *kf_ops;
	int (*open)(struct kernfs_open_file___77 *);
	void (*release)(struct kernfs_open_file___77 *);
	u64 (*read_u64)(struct cgroup_subsys_state___64 *, struct cftype___64 *);
	s64 (*read_s64)(struct cgroup_subsys_state___64 *, struct cftype___64 *);
	int (*seq_show)(struct seq_file___73 *, void *);
	void * (*seq_start)(struct seq_file___73 *, loff_t *);
	void * (*seq_next)(struct seq_file___73 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___73 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___64 *, struct cftype___64 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___64 *, struct cftype___64 *, s64);
	ssize_t (*write)(struct kernfs_open_file___77 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___77 *, struct poll_table_struct___58 *);
};

struct block_device_operations___37;

struct gendisk___37 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___38 *part0;
	const struct block_device_operations___37 *fops;
	struct request_queue___37 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___36 *bdi;
	struct kobject___77 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___77 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___37 {
	struct bio___37 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___46 *bip_vec;
	struct bio_vec___46 bip_inline_vecs[0];
};

struct blkcg___36;

struct blkg_policy_data___36;

struct blkcg_gq___36 {
	struct request_queue___37 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___36 *blkcg;
	struct blkcg_gq___36 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___36 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___37 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___37(struct request___37 *);

typedef void integrity_complete_fn___37(struct request___37 *, unsigned int);

struct blk_integrity_profile___37 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___37 *prepare_fn;
	integrity_complete_fn___37 *complete_fn;
	const char *name;
};

struct block_device_operations___37 {
	blk_qc_t (*submit_bio)(struct bio___37 *);
	int (*open)(struct block_device___38 *, fmode_t);
	void (*release)(struct gendisk___37 *, fmode_t);
	int (*rw_page)(struct block_device___38 *, sector_t, struct page___82 *, unsigned int);
	int (*ioctl)(struct block_device___38 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___38 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___37 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___37 *);
	int (*getgeo)(struct block_device___38 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___38 *, bool);
	void (*swap_slot_free_notify)(struct block_device___38 *, long unsigned int);
	int (*report_zones)(struct gendisk___37 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___37 *, umode_t *);
	struct module___75 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___37 *, sector_t *);
};

typedef void rq_end_io_fn___37(struct request___37 *, blk_status_t);

struct request___37 {
	struct request_queue___37 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___36 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___37 *bio;
	struct bio___37 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___46 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___37 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___37 *saved_end_io;
		} flush;
	};
	struct gendisk___37 *rq_disk;
	struct block_device___38 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___37 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___36 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___37 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___77 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___77 *debugfs_dir;
	struct dentry___77 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___37;

struct elevator_mq_ops___37 {
	int (*init_sched)(struct request_queue___37 *, struct elevator_type___37 *);
	void (*exit_sched)(struct elevator_queue___37 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___36 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___36 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___36 *);
	bool (*allow_merge)(struct request_queue___37 *, struct request___37 *, struct bio___37 *);
	bool (*bio_merge)(struct request_queue___37 *, struct bio___37 *, unsigned int);
	int (*request_merge)(struct request_queue___37 *, struct request___37 **, struct bio___37 *);
	void (*request_merged)(struct request_queue___37 *, struct request___37 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___37 *, struct request___37 *, struct request___37 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___37 *);
	void (*finish_request)(struct request___37 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___36 *, struct list_head *, bool);
	struct request___37 * (*dispatch_request)(struct blk_mq_hw_ctx___36 *);
	bool (*has_work)(struct blk_mq_hw_ctx___36 *);
	void (*completed_request)(struct request___37 *, u64);
	void (*requeue_request)(struct request___37 *);
	struct request___37 * (*former_request)(struct request_queue___37 *, struct request___37 *);
	struct request___37 * (*next_request)(struct request_queue___37 *, struct request___37 *);
	void (*init_icq)(struct io_cq___37 *);
	void (*exit_icq)(struct io_cq___37 *);
};

struct elv_fs_entry___37;

struct elevator_type___37 {
	struct kmem_cache___3 *icq_cache;
	struct elevator_mq_ops___37 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___37 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___75 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___37 {
	struct elevator_type___37 *type;
	void *elevator_data;
	struct kobject___77 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___37 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___37 *, char *);
	ssize_t (*store)(struct elevator_queue___37 *, const char *, size_t);
};

struct blk_mq_queue_data___36;

struct blk_mq_ops___36 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___36 *, const struct blk_mq_queue_data___36 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___36 *);
	int (*get_budget)(struct request_queue___37 *);
	void (*put_budget)(struct request_queue___37 *, int);
	void (*set_rq_budget_token)(struct request___37 *, int);
	int (*get_rq_budget_token)(struct request___37 *);
	enum blk_eh_timer_return (*timeout)(struct request___37 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___36 *);
	void (*complete)(struct request___37 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___36 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___36 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___36 *, struct request___37 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___36 *, struct request___37 *, unsigned int);
	void (*initialize_rq_fn)(struct request___37 *);
	void (*cleanup_rq)(struct request___37 *);
	bool (*busy)(struct request_queue___37 *);
	int (*map_queues)(struct blk_mq_tag_set___36 *);
	void (*show_rq)(struct seq_file___73 *, struct request___37 *);
};

struct blk_mq_tag_set___36 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___36 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___36 {
	struct request___37 *rq;
	bool last;
};

struct blkcg_policy_data___36;

struct blkcg___36 {
	struct cgroup_subsys_state___64 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___36 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___36 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___36 {
	struct blkcg___36 *blkcg;
	int plid;
};

struct blkg_policy_data___36 {
	struct blkcg_gq___36 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___34 {
	struct mem_cgroup___34 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___34 {
	struct lruvec___37 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___34 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___34 *memcg;
};

struct obj_cgroup___34 {
	struct percpu_ref refcnt;
	struct mem_cgroup___34 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___49;

struct perf_output_handle___49;

struct pmu___49 {
	struct list_head entry;
	struct module___75 *module;
	struct device___68 *dev;
	const struct attribute_group___77 **attr_groups;
	const struct attribute_group___77 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___49 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___49 *);
	void (*pmu_disable)(struct pmu___49 *);
	int (*event_init)(struct perf_event___49 *);
	void (*event_mapped)(struct perf_event___49 *, struct mm_struct___83 *);
	void (*event_unmapped)(struct perf_event___49 *, struct mm_struct___83 *);
	int (*add)(struct perf_event___49 *, int);
	void (*del)(struct perf_event___49 *, int);
	void (*start)(struct perf_event___49 *, int);
	void (*stop)(struct perf_event___49 *, int);
	void (*read)(struct perf_event___49 *);
	void (*start_txn)(struct pmu___49 *, unsigned int);
	int (*commit_txn)(struct pmu___49 *);
	void (*cancel_txn)(struct pmu___49 *);
	int (*event_idx)(struct perf_event___49 *);
	void (*sched_task)(struct perf_event_context___49 *, bool);
	struct kmem_cache___3 *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___49 *, struct perf_event_context___49 *);
	void * (*setup_aux)(struct perf_event___49 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___49 *, struct perf_output_handle___49 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___49 *);
	int (*aux_output_match)(struct perf_event___49 *);
	int (*filter_match)(struct perf_event___49 *);
	int (*check_period)(struct perf_event___49 *, u64);
};

struct perf_cpu_context___49 {
	struct perf_event_context___49 ctx;
	struct perf_event_context___49 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___49 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___49 **heap;
	struct perf_event___49 *heap_default[2];
};

struct perf_output_handle___49 {
	struct perf_event___49 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___49 {
	struct cgroup_subsys_state___64 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___43 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___43 *);
	};
};

struct trace_event_class___43 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___43 *, enum trace_reg, void *);
	struct trace_event_fields___43 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___43 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___43 *);
};

struct trace_event_file___22;

struct trace_event_buffer___21 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___22 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___22 {
	struct list_head list;
	struct trace_event_call___43 *event_call;
	struct event_filter *filter;
	struct dentry___77 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kmem_alloc {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	size_t bytes_req;
	size_t bytes_alloc;
	gfp_t gfp_flags;
	char __data[0];
};

struct trace_event_raw_kmem_alloc_node {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	size_t bytes_req;
	size_t bytes_alloc;
	gfp_t gfp_flags;
	int node;
	char __data[0];
};

struct trace_event_raw_kfree {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	char __data[0];
};

struct trace_event_raw_kmem_cache_free {
	struct trace_entry ent;
	long unsigned int call_site;
	const void *ptr;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_mm_page_free {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	char __data[0];
};

struct trace_event_raw_mm_page_free_batched {
	struct trace_entry ent;
	long unsigned int pfn;
	char __data[0];
};

struct trace_event_raw_mm_page_alloc {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	gfp_t gfp_flags;
	int migratetype;
	char __data[0];
};

struct trace_event_raw_mm_page {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	int migratetype;
	char __data[0];
};

struct trace_event_raw_mm_page_pcpu_drain {
	struct trace_entry ent;
	long unsigned int pfn;
	unsigned int order;
	int migratetype;
	char __data[0];
};

struct trace_event_raw_mm_page_alloc_extfrag {
	struct trace_entry ent;
	long unsigned int pfn;
	int alloc_order;
	int fallback_order;
	int alloc_migratetype;
	int fallback_migratetype;
	int change_ownership;
	char __data[0];
};

struct trace_event_raw_rss_stat {
	struct trace_entry ent;
	unsigned int mm_id;
	unsigned int curr;
	int member;
	long int size;
	char __data[0];
};

struct trace_event_data_offsets_kmem_alloc {};

struct trace_event_data_offsets_kmem_alloc_node {};

struct trace_event_data_offsets_kfree {};

struct trace_event_data_offsets_kmem_cache_free {
	u32 name;
};

struct trace_event_data_offsets_mm_page_free {};

struct trace_event_data_offsets_mm_page_free_batched {};

struct trace_event_data_offsets_mm_page_alloc {};

struct trace_event_data_offsets_mm_page {};

struct trace_event_data_offsets_mm_page_pcpu_drain {};

struct trace_event_data_offsets_mm_page_alloc_extfrag {};

struct trace_event_data_offsets_rss_stat {};

typedef void (*btf_trace_kmalloc)(void *, long unsigned int, const void *, size_t, size_t, gfp_t);

typedef void (*btf_trace_kmem_cache_alloc)(void *, long unsigned int, const void *, size_t, size_t, gfp_t);

typedef void (*btf_trace_kmalloc_node)(void *, long unsigned int, const void *, size_t, size_t, gfp_t, int);

typedef void (*btf_trace_kmem_cache_alloc_node)(void *, long unsigned int, const void *, size_t, size_t, gfp_t, int);

typedef void (*btf_trace_kfree)(void *, long unsigned int, const void *);

typedef void (*btf_trace_kmem_cache_free)(void *, long unsigned int, const void *, const char *);

typedef void (*btf_trace_mm_page_free)(void *, struct page___82 *, unsigned int);

typedef void (*btf_trace_mm_page_free_batched)(void *, struct page___82 *);

typedef void (*btf_trace_mm_page_alloc)(void *, struct page___82 *, unsigned int, gfp_t, int);

typedef void (*btf_trace_mm_page_alloc_zone_locked)(void *, struct page___82 *, unsigned int, int);

typedef void (*btf_trace_mm_page_pcpu_drain)(void *, struct page___82 *, unsigned int, int);

typedef void (*btf_trace_mm_page_alloc_extfrag)(void *, struct page___82 *, int, int, int, int);

typedef void (*btf_trace_rss_stat)(void *, struct mm_struct___83 *, int, long int);

struct compact_control___7 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___37 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct kmem_cache_cpu___3 {
	void **freelist;
	long unsigned int tid;
	struct page___82 *page;
	struct page___82 *partial;
	local_lock_t lock;
};

enum slab_state {
	DOWN = 0,
	PARTIAL = 1,
	PARTIAL_NODE = 2,
	UP = 3,
	FULL = 4,
};

struct kmalloc_info_struct {
	const char *name[4];
	unsigned int size;
};

struct slabinfo {
	long unsigned int active_objs;
	long unsigned int num_objs;
	long unsigned int active_slabs;
	long unsigned int num_slabs;
	long unsigned int shared_avail;
	unsigned int limit;
	unsigned int batchcount;
	unsigned int shared;
	unsigned int objects_per_slab;
	unsigned int cache_order;
};

struct kmem_obj_info {
	void *kp_ptr;
	struct page___82 *kp_page;
	void *kp_objp;
	long unsigned int kp_data_offset;
	struct kmem_cache___3 *kp_slab_cache;
	void *kp_ret;
	void *kp_stack[16];
	void *kp_free_stack[16];
};

struct dentry___78;

struct super_block___78;

struct module___76;

struct file_system_type___78 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___78 * (*mount)(struct file_system_type___78 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___78 *);
	struct module___76 *owner;
	struct file_system_type___78 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___78;

struct kiocb___78;

struct iov_iter___48;

struct poll_table_struct___59;

struct vm_area_struct___83;

struct inode___78;

struct file_lock___78;

struct page___83;

struct seq_file___74;

struct file_operations___78 {
	struct module___76 *owner;
	loff_t (*llseek)(struct file___78 *, loff_t, int);
	ssize_t (*read)(struct file___78 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___78 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___78 *, struct iov_iter___48 *);
	ssize_t (*write_iter)(struct kiocb___78 *, struct iov_iter___48 *);
	int (*iopoll)(struct kiocb___78 *, bool);
	int (*iterate)(struct file___78 *, struct dir_context *);
	int (*iterate_shared)(struct file___78 *, struct dir_context *);
	__poll_t (*poll)(struct file___78 *, struct poll_table_struct___59 *);
	long int (*unlocked_ioctl)(struct file___78 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___78 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___78 *, struct vm_area_struct___83 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___78 *, struct file___78 *);
	int (*flush)(struct file___78 *, fl_owner_t);
	int (*release)(struct inode___78 *, struct file___78 *);
	int (*fsync)(struct file___78 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___78 *, int);
	int (*lock)(struct file___78 *, int, struct file_lock___78 *);
	ssize_t (*sendpage)(struct file___78 *, struct page___83 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___78 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___78 *, long unsigned int);
	int (*flock)(struct file___78 *, int, struct file_lock___78 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___78 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___78 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___78 *, long int, struct file_lock___78 **, void **);
	long int (*fallocate)(struct file___78 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___74 *, struct file___78 *);
	ssize_t (*copy_file_range)(struct file___78 *, loff_t, struct file___78 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___78 *, loff_t, struct file___78 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___78 *, loff_t, loff_t, int);
};

struct vmacache___83 {
	u64 seqnum;
	struct vm_area_struct___83 *vmas[4];
};

struct page_frag___83 {
	struct page___83 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___50;

struct debug_info___50 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___50 *hbp_break[16];
	struct perf_event___50 *hbp_watch[16];
};

struct thread_struct___50 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___50 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___84;

struct pid___71;

struct nsproxy___76;

struct signal_struct___79;

struct bio_list___38;

struct backing_dev_info___37;

struct io_context___38;

struct capture_control___8;

struct css_set___65;

struct perf_event_context___50;

struct mem_cgroup___35;

struct request_queue___38;

struct vm_struct___79;

struct task_struct___85 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___85 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___84 *mm;
	struct mm_struct___84 *active_mm;
	struct vmacache___83 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___85 *real_parent;
	struct task_struct___85 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___85 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___71 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___76 *nsproxy;
	struct signal_struct___79 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___85 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___38 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___37 *backing_dev_info;
	struct io_context___38 *io_context;
	struct capture_control___8 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___65 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___50 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___83 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___35 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___35 *active_memcg;
	struct request_queue___38 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___85 *oom_reaper_list;
	struct vm_struct___79 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___78;

struct kobj_type___78;

struct kernfs_node___78;

struct kobject___78 {
	const char *name;
	struct list_head entry;
	struct kobject___78 *parent;
	struct kset___78 *kset;
	struct kobj_type___78 *ktype;
	struct kernfs_node___78 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___75 {
	struct kobject___78 kobj;
	struct module___76 *mod;
	struct kobject___78 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___75 {
	struct module___76 *mod;
	struct latch_tree_node node;
};

struct module_layout___75 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___75 mtn;
};

struct module_attribute___75;

struct kernel_param___75;

struct trace_event_call___44;

struct module___76 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___75 mkobj;
	struct module_attribute___75 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___78 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___75 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___75 core_layout;
	struct module_layout___75 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___44 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___50 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___85 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___50)(struct perf_event___50 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___50;

struct fasync_struct___78;

struct pid_namespace___71;

struct perf_cgroup___50;

struct perf_event___50 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___50 *group_leader;
	struct pmu___50 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___50 hw;
	struct perf_event_context___50 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___50 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___85 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___78 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___50 *aux_event;
	void (*destroy)(struct perf_event___50 *);
	struct callback_head callback_head;
	struct pid_namespace___71 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___50 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___50 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___44 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___50 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___71 {
	int nr;
	struct pid_namespace___71 *ns;
};

struct pid_namespace___71 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___85 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___71 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___71 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___71 numbers[1];
};

typedef struct page___83 *pgtable_t___83;

struct address_space___78;

struct dev_pagemap___77;

struct page___83 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___78 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___83 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___83 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___84 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___77 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___77;

struct vm_area_struct___83 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___83 *vm_next;
	struct vm_area_struct___83 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___84 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___77 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___78 *vm_file;
	struct file___78 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___79 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___85 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___85 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___71 *pids[4];
	struct pid___71 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___84 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___83;

struct mm_struct___84 {
	struct {
		struct vm_area_struct___83 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___78 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___83 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___85 *owner;
		struct user_namespace___12 *user_ns;
		struct file___78 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___65;

struct nsproxy___76 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___71 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___65 *cgroup_ns;
};

struct bio___38;

struct bio_list___38 {
	struct bio___38 *head;
	struct bio___38 *tail;
};

struct cgroup_subsys_state___65;

struct bdi_writeback___37 {
	struct backing_dev_info___37 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___65 *memcg_css;
	struct cgroup_subsys_state___65 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___69;

struct backing_dev_info___37 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___37 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___69 *dev;
	char dev_name[64];
	struct device___69 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___78 *debug_dir;
};

struct io_cq___38;

struct io_context___38 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___38 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___8;

struct capture_control___8 {
	struct compact_control___8 *cc;
	struct page___83 *page;
};

struct cgroup___65;

struct css_set___65 {
	struct cgroup_subsys_state___65 *subsys[14];
	refcount_t refcount;
	struct css_set___65 *dom_cset;
	struct cgroup___65 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___65 *mg_src_cgrp;
	struct cgroup___65 *mg_dst_cgrp;
	struct css_set___65 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___50 {
	struct pmu___50 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___85 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___50 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___65;

struct cgroup_subsys_state___65 {
	struct cgroup___65 *cgroup;
	struct cgroup_subsys___65 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___65 *parent;
};

struct cgroup_file___65 {
	struct kernfs_node___78 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___35;

struct mem_cgroup_per_node___35;

struct mem_cgroup___35 {
	struct cgroup_subsys_state___65 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___65 events_file;
	struct cgroup_file___65 events_local_file;
	struct cgroup_file___65 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___35 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___85 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___35 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___38;

struct blk_integrity___38 {
	const struct blk_integrity_profile___38 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___38 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___38 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___38;

struct elevator_queue___38;

struct blk_mq_ops___37;

struct blk_mq_hw_ctx___37;

struct gendisk___38;

struct blkcg_gq___37;

struct blk_mq_tag_set___37;

struct request_queue___38 {
	struct request___38 *last_merge;
	struct elevator_queue___38 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___37 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___37 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___38 *disk;
	struct kobject___78 kobj;
	struct kobject___78 *mq_kobj;
	struct blk_integrity___38 integrity;
	struct device___69 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___37 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___37 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___38 bio_split;
	struct dentry___78 *debugfs_dir;
	struct dentry___78 *sched_debugfs_dir;
	struct dentry___78 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___79 {
	struct vm_struct___79 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___83 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

enum pageblock_bits {
	PB_migrate = 0,
	PB_migrate_end = 2,
	PB_migrate_skip = 3,
	NR_PAGEBLOCK_BITS = 4,
};

struct address_space_operations___78;

struct address_space___78 {
	struct inode___78 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___78 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___77;

struct dev_pagemap___77 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___77 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___78;

struct path___78 {
	struct vfsmount___78 *mnt;
	struct dentry___78 *dentry;
};

struct fown_struct___71 {
	rwlock_t lock;
	struct pid___71 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___78 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___78 f_path;
	struct inode___78 *f_inode;
	const struct file_operations___78 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___71 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___78 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___77;

struct vm_operations_struct___77 {
	void (*open)(struct vm_area_struct___83 *);
	void (*close)(struct vm_area_struct___83 *);
	int (*may_split)(struct vm_area_struct___83 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___83 *);
	int (*mprotect)(struct vm_area_struct___83 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___77 *);
	vm_fault_t (*huge_fault)(struct vm_fault___77 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___77 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___83 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___77 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___77 *);
	int (*access)(struct vm_area_struct___83 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___83 *);
	int (*set_policy)(struct vm_area_struct___83 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___83 *, long unsigned int);
	struct page___83 * (*find_special_page)(struct vm_area_struct___83 *, long unsigned int);
};

struct core_thread___83 {
	struct task_struct___85 *task;
	struct core_thread___83 *next;
};

struct core_state___83 {
	atomic_t nr_threads;
	struct core_thread___83 dumper;
	struct completion startup;
};

struct vm_fault___77 {
	const struct {
		struct vm_area_struct___83 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___83 *cow_page;
	struct page___83 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___83 prealloc_pte;
};

struct pglist_data___38;

struct lruvec___38 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___38 *pgdat;
};

struct zone___38 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___38 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___38 {
	struct zone___38 *zone;
	int zone_idx;
};

struct zonelist___38 {
	struct zoneref___38 _zonerefs[321];
};

struct pglist_data___38 {
	struct zone___38 node_zones[5];
	struct zonelist___38 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___85 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___85 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___38 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___38 pg_data_t___6;

struct kernfs_root___78;

struct kernfs_elem_dir___78 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___78 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___78;

struct kernfs_root___78 {
	struct kernfs_node___78 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___78 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___78 {
	struct kernfs_node___78 *target_kn;
};

struct kernfs_ops___78;

struct kernfs_elem_attr___78 {
	const struct kernfs_ops___78 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___78 *notify_next;
};

struct kernfs_node___78 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___78 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___78 dir;
		struct kernfs_elem_symlink___78 symlink;
		struct kernfs_elem_attr___78 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___78;

struct kernfs_ops___78 {
	int (*open)(struct kernfs_open_file___78 *);
	void (*release)(struct kernfs_open_file___78 *);
	int (*seq_show)(struct seq_file___74 *, void *);
	void * (*seq_start)(struct seq_file___74 *, loff_t *);
	void * (*seq_next)(struct seq_file___74 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___74 *, void *);
	ssize_t (*read)(struct kernfs_open_file___78 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___78 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___78 *, struct poll_table_struct___59 *);
	int (*mmap)(struct kernfs_open_file___78 *, struct vm_area_struct___83 *);
};

struct kernfs_syscall_ops___78 {
	int (*show_options)(struct seq_file___74 *, struct kernfs_root___78 *);
	int (*mkdir)(struct kernfs_node___78 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___78 *);
	int (*rename)(struct kernfs_node___78 *, struct kernfs_node___78 *, const char *);
	int (*show_path)(struct seq_file___74 *, struct kernfs_node___78 *, struct kernfs_root___78 *);
};

struct seq_operations___74;

struct seq_file___74 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___74 *op;
	int poll_event;
	const struct file___78 *file;
	void *private;
};

struct kernfs_open_file___78 {
	struct kernfs_node___78 *kn;
	struct file___78 *file;
	struct seq_file___74 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___77 *vm_ops;
};

typedef void (*poll_queue_proc___59)(struct file___78 *, wait_queue_head_t *, struct poll_table_struct___59 *);

struct poll_table_struct___59 {
	poll_queue_proc___59 _qproc;
	__poll_t _key;
};

struct bin_attribute___78;

struct attribute_group___78 {
	const char *name;
	umode_t (*is_visible)(struct kobject___78 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___78 *, struct bin_attribute___78 *, int);
	struct attribute **attrs;
	struct bin_attribute___78 **bin_attrs;
};

struct bin_attribute___78 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___78 * (*f_mapping)();
	ssize_t (*read)(struct file___78 *, struct kobject___78 *, struct bin_attribute___78 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___78 *, struct kobject___78 *, struct bin_attribute___78 *, char *, loff_t, size_t);
	int (*mmap)(struct file___78 *, struct kobject___78 *, struct bin_attribute___78 *, struct vm_area_struct___83 *);
};

struct sysfs_ops___78 {
	ssize_t (*show)(struct kobject___78 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___78 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___78;

struct kset___78 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___78 kobj;
	const struct kset_uevent_ops___78 *uevent_ops;
};

struct kobj_type___78 {
	void (*release)(struct kobject___78 *);
	const struct sysfs_ops___78 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___78 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___78 *);
	const void * (*namespace)(struct kobject___78 *);
	void (*get_ownership)(struct kobject___78 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___78 {
	int (* const filter)(struct kset___78 *, struct kobject___78 *);
	const char * (* const name)(struct kset___78 *, struct kobject___78 *);
	int (* const uevent)(struct kset___78 *, struct kobject___78 *, struct kobj_uevent_env *);
};

struct wakeup_source___69;

struct dev_pm_info___69 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___69 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___69 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___69;

struct bus_type___69;

struct device_driver___69;

struct dev_pm_domain___69;

struct fwnode_handle___69;

struct class___69;

struct device___69 {
	struct kobject___78 kobj;
	struct device___69 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___69 *type;
	struct bus_type___69 *bus;
	struct device_driver___69 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___69 power;
	struct dev_pm_domain___69 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___69 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___69 *class;
	const struct attribute_group___78 **groups;
	void (*release)(struct device___69 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___69 {
	int (*prepare)(struct device___69 *);
	void (*complete)(struct device___69 *);
	int (*suspend)(struct device___69 *);
	int (*resume)(struct device___69 *);
	int (*freeze)(struct device___69 *);
	int (*thaw)(struct device___69 *);
	int (*poweroff)(struct device___69 *);
	int (*restore)(struct device___69 *);
	int (*suspend_late)(struct device___69 *);
	int (*resume_early)(struct device___69 *);
	int (*freeze_late)(struct device___69 *);
	int (*thaw_early)(struct device___69 *);
	int (*poweroff_late)(struct device___69 *);
	int (*restore_early)(struct device___69 *);
	int (*suspend_noirq)(struct device___69 *);
	int (*resume_noirq)(struct device___69 *);
	int (*freeze_noirq)(struct device___69 *);
	int (*thaw_noirq)(struct device___69 *);
	int (*poweroff_noirq)(struct device___69 *);
	int (*restore_noirq)(struct device___69 *);
	int (*runtime_suspend)(struct device___69 *);
	int (*runtime_resume)(struct device___69 *);
	int (*runtime_idle)(struct device___69 *);
};

struct wakeup_source___69 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___69 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___69 {
	struct dev_pm_ops___69 ops;
	int (*start)(struct device___69 *);
	void (*detach)(struct device___69 *, bool);
	int (*activate)(struct device___69 *);
	void (*sync)(struct device___69 *);
	void (*dismiss)(struct device___69 *);
};

struct bus_type___69 {
	const char *name;
	const char *dev_name;
	struct device___69 *dev_root;
	const struct attribute_group___78 **bus_groups;
	const struct attribute_group___78 **dev_groups;
	const struct attribute_group___78 **drv_groups;
	int (*match)(struct device___69 *, struct device_driver___69 *);
	int (*uevent)(struct device___69 *, struct kobj_uevent_env *);
	int (*probe)(struct device___69 *);
	void (*sync_state)(struct device___69 *);
	void (*remove)(struct device___69 *);
	void (*shutdown)(struct device___69 *);
	int (*online)(struct device___69 *);
	int (*offline)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	int (*num_vf)(struct device___69 *);
	int (*dma_configure)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___69 {
	const char *name;
	struct bus_type___69 *bus;
	struct module___76 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___69 *);
	void (*sync_state)(struct device___69 *);
	int (*remove)(struct device___69 *);
	void (*shutdown)(struct device___69 *);
	int (*suspend)(struct device___69 *, pm_message_t);
	int (*resume)(struct device___69 *);
	const struct attribute_group___78 **groups;
	const struct attribute_group___78 **dev_groups;
	const struct dev_pm_ops___69 *pm;
	void (*coredump)(struct device___69 *);
	struct driver_private *p;
};

struct device_type___69 {
	const char *name;
	const struct attribute_group___78 **groups;
	int (*uevent)(struct device___69 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___69 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___69 *);
	const struct dev_pm_ops___69 *pm;
};

struct class___69 {
	const char *name;
	struct module___76 *owner;
	const struct attribute_group___78 **class_groups;
	const struct attribute_group___78 **dev_groups;
	struct kobject___78 *dev_kobj;
	int (*dev_uevent)(struct device___69 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___69 *, umode_t *);
	void (*class_release)(struct class___69 *);
	void (*dev_release)(struct device___69 *);
	int (*shutdown_pre)(struct device___69 *);
	const struct kobj_ns_type_operations___11 *ns_type;
	const void * (*namespace)(struct device___69 *);
	void (*get_ownership)(struct device___69 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___69 *pm;
	struct subsys_private *p;
};

struct device_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct device___69 *, struct device_attribute___9 *, char *);
	ssize_t (*store)(struct device___69 *, struct device_attribute___9 *, const char *, size_t);
};

struct fwnode_operations___69;

struct fwnode_handle___69 {
	struct fwnode_handle___69 *secondary;
	const struct fwnode_operations___69 *ops;
	struct device___69 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct node___2 {
	struct device___69 dev;
	struct list_head access_list;
	struct work_struct node_work;
	struct list_head cache_attrs;
	struct device___69 *cache_dev;
};

struct dentry_operations___78;

struct dentry___78 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___78 *d_parent;
	struct qstr d_name;
	struct inode___78 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___78 *d_op;
	struct super_block___78 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___78;

struct inode___78 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___78 *i_op;
	struct super_block___78 *i_sb;
	struct address_space___78 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___37 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___78 *i_fop;
		void (*free_inode)(struct inode___78 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___78 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___78 {
	int (*d_revalidate)(struct dentry___78 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___78 *, unsigned int);
	int (*d_hash)(const struct dentry___78 *, struct qstr *);
	int (*d_compare)(const struct dentry___78 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___78 *);
	int (*d_init)(struct dentry___78 *);
	void (*d_release)(struct dentry___78 *);
	void (*d_prune)(struct dentry___78 *);
	void (*d_iput)(struct dentry___78 *, struct inode___78 *);
	char * (*d_dname)(struct dentry___78 *, char *, int);
	struct vfsmount___78 * (*d_automount)(struct path___78 *);
	int (*d_manage)(const struct path___78 *, bool);
	struct dentry___78 * (*d_real)(struct dentry___78 *, const struct inode___78 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___78;

struct mem_dqinfo___78 {
	struct quota_format_type___78 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___78;

struct quota_info___78 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___78 *files[3];
	struct mem_dqinfo___78 info[3];
	const struct quota_format_ops___78 *ops[3];
};

struct rcuwait___79 {
	struct task_struct___85 *task;
};

struct percpu_rw_semaphore___79 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___79 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___78 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___79 rw_sem[3];
};

struct shrink_control___35;

struct shrinker___35 {
	long unsigned int (*count_objects)(struct shrinker___35 *, struct shrink_control___35 *);
	long unsigned int (*scan_objects)(struct shrinker___35 *, struct shrink_control___35 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___78;

struct dquot_operations___78;

struct quotactl_ops___78;

struct block_device___39;

struct super_block___78 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___78 *s_type;
	const struct super_operations___78 *s_op;
	const struct dquot_operations___78 *dq_op;
	const struct quotactl_ops___78 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___78 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___39 *s_bdev;
	struct backing_dev_info___37 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___78 s_dquot;
	struct sb_writers___78 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___78 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___78 {
	struct dentry___78 *mnt_root;
	struct super_block___78 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct shrink_control___35 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___35 *memcg;
};

struct psi_group___65 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___85 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___65;

struct cgroup_rstat_cpu___65;

struct cgroup___65 {
	struct cgroup_subsys_state___65 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___78 *kn;
	struct cgroup_file___65 procs_file;
	struct cgroup_file___65 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___65 *subsys[14];
	struct cgroup_root___65 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___65 *dom_cgrp;
	struct cgroup___65 *old_dom_cgrp;
	struct cgroup_rstat_cpu___65 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___65 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___38 {
	struct request_queue___38 *q;
	struct io_context___38 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___3 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___36;

struct kiocb___78 {
	struct file___78 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___78 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___36 *ki_waitq;
	};
};

struct iattr___78 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___78 *ia_file;
};

struct dquot___78 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___78 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___78 {
	int qf_fmt_id;
	const struct quota_format_ops___78 *qf_ops;
	struct module___76 *qf_owner;
	struct quota_format_type___78 *qf_next;
};

struct quota_format_ops___78 {
	int (*check_quota_file)(struct super_block___78 *, int);
	int (*read_file_info)(struct super_block___78 *, int);
	int (*write_file_info)(struct super_block___78 *, int);
	int (*free_file_info)(struct super_block___78 *, int);
	int (*read_dqblk)(struct dquot___78 *);
	int (*commit_dqblk)(struct dquot___78 *);
	int (*release_dqblk)(struct dquot___78 *);
	int (*get_next_id)(struct super_block___78 *, struct kqid *);
};

struct dquot_operations___78 {
	int (*write_dquot)(struct dquot___78 *);
	struct dquot___78 * (*alloc_dquot)(struct super_block___78 *, int);
	void (*destroy_dquot)(struct dquot___78 *);
	int (*acquire_dquot)(struct dquot___78 *);
	int (*release_dquot)(struct dquot___78 *);
	int (*mark_dirty)(struct dquot___78 *);
	int (*write_info)(struct super_block___78 *, int);
	qsize_t * (*get_reserved_space)(struct inode___78 *);
	int (*get_projid)(struct inode___78 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___78 *, qsize_t *);
	int (*get_next_id)(struct super_block___78 *, struct kqid *);
};

struct quotactl_ops___78 {
	int (*quota_on)(struct super_block___78 *, int, int, const struct path___78 *);
	int (*quota_off)(struct super_block___78 *, int);
	int (*quota_enable)(struct super_block___78 *, unsigned int);
	int (*quota_disable)(struct super_block___78 *, unsigned int);
	int (*quota_sync)(struct super_block___78 *, int);
	int (*set_info)(struct super_block___78 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___78 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___78 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___78 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___78 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___78 *, unsigned int);
};

struct wait_page_queue___36 {
	struct page___83 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___37;

struct readahead_control___36;

struct swap_info_struct___22;

struct address_space_operations___78 {
	int (*writepage)(struct page___83 *, struct writeback_control___37 *);
	int (*readpage)(struct file___78 *, struct page___83 *);
	int (*writepages)(struct address_space___78 *, struct writeback_control___37 *);
	int (*set_page_dirty)(struct page___83 *);
	int (*readpages)(struct file___78 *, struct address_space___78 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___36 *);
	int (*write_begin)(struct file___78 *, struct address_space___78 *, loff_t, unsigned int, unsigned int, struct page___83 **, void **);
	int (*write_end)(struct file___78 *, struct address_space___78 *, loff_t, unsigned int, unsigned int, struct page___83 *, void *);
	sector_t (*bmap)(struct address_space___78 *, sector_t);
	void (*invalidatepage)(struct page___83 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___83 *, gfp_t);
	void (*freepage)(struct page___83 *);
	ssize_t (*direct_IO)(struct kiocb___78 *, struct iov_iter___48 *);
	int (*migratepage)(struct address_space___78 *, struct page___83 *, struct page___83 *, enum migrate_mode);
	bool (*isolate_page)(struct page___83 *, isolate_mode_t);
	void (*putback_page)(struct page___83 *);
	int (*launder_page)(struct page___83 *);
	int (*is_partially_uptodate)(struct page___83 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___83 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___78 *, struct page___83 *);
	int (*swap_activate)(struct swap_info_struct___22 *, struct file___78 *, sector_t *);
	void (*swap_deactivate)(struct file___78 *);
};

struct writeback_control___37 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___37 *wb;
	struct inode___78 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___36 {
	struct file___78 *file;
	struct address_space___78 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___47;

struct iov_iter___48 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___47 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___22 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___39 *bdev;
	struct file___78 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___78 {
	struct dentry___78 * (*lookup)(struct inode___78 *, struct dentry___78 *, unsigned int);
	const char * (*get_link)(struct dentry___78 *, struct inode___78 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___78 *, int);
	struct posix_acl * (*get_acl)(struct inode___78 *, int, bool);
	int (*readlink)(struct dentry___78 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___78 *, struct dentry___78 *, umode_t, bool);
	int (*link)(struct dentry___78 *, struct inode___78 *, struct dentry___78 *);
	int (*unlink)(struct inode___78 *, struct dentry___78 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___78 *, struct dentry___78 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___78 *, struct dentry___78 *, umode_t);
	int (*rmdir)(struct inode___78 *, struct dentry___78 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___78 *, struct dentry___78 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___78 *, struct dentry___78 *, struct inode___78 *, struct dentry___78 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___78 *, struct iattr___78 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___78 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___78 *, char *, size_t);
	int (*fiemap)(struct inode___78 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___78 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___78 *, struct dentry___78 *, struct file___78 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___78 *, struct dentry___78 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___78 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___78 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___78 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___78 {
	void (*fl_copy_lock)(struct file_lock___78 *, struct file_lock___78 *);
	void (*fl_release_private)(struct file_lock___78 *);
};

struct lock_manager_operations___78;

struct file_lock___78 {
	struct file_lock___78 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___78 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___78 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___78 *fl_ops;
	const struct lock_manager_operations___78 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___78 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___78 *);
	int (*lm_grant)(struct file_lock___78 *, int);
	bool (*lm_break)(struct file_lock___78 *);
	int (*lm_change)(struct file_lock___78 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___78 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___78 *);
};

struct fasync_struct___78 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___78 *fa_next;
	struct file___78 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___78 {
	struct inode___78 * (*alloc_inode)(struct super_block___78 *);
	void (*destroy_inode)(struct inode___78 *);
	void (*free_inode)(struct inode___78 *);
	void (*dirty_inode)(struct inode___78 *, int);
	int (*write_inode)(struct inode___78 *, struct writeback_control___37 *);
	int (*drop_inode)(struct inode___78 *);
	void (*evict_inode)(struct inode___78 *);
	void (*put_super)(struct super_block___78 *);
	int (*sync_fs)(struct super_block___78 *, int);
	int (*freeze_super)(struct super_block___78 *);
	int (*freeze_fs)(struct super_block___78 *);
	int (*thaw_super)(struct super_block___78 *);
	int (*unfreeze_fs)(struct super_block___78 *);
	int (*statfs)(struct dentry___78 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___78 *, int *, char *);
	void (*umount_begin)(struct super_block___78 *);
	int (*show_options)(struct seq_file___74 *, struct dentry___78 *);
	int (*show_devname)(struct seq_file___74 *, struct dentry___78 *);
	int (*show_path)(struct seq_file___74 *, struct dentry___78 *);
	int (*show_stats)(struct seq_file___74 *, struct dentry___78 *);
	ssize_t (*quota_read)(struct super_block___78 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___78 *, int, const char *, size_t, loff_t);
	struct dquot___78 ** (*get_dquots)(struct inode___78 *);
	long int (*nr_cached_objects)(struct super_block___78 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___78 *, struct shrink_control___35 *);
	struct file___78 * (*real_loop)(struct file___78 *);
};

struct block_device___39 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___78 *bd_inode;
	struct super_block___78 *bd_super;
	void *bd_claiming;
	struct device___69 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___78 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___38 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___78 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___38(struct bio___38 *);

struct bio_vec___47 {
	struct page___83 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___38;

struct bio___38 {
	struct bio___38 *bi_next;
	struct block_device___39 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___38 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___37 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___38 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___47 *bi_io_vec;
	struct bio_set___38 *bi_pool;
	struct bio_vec___47 bi_inline_vecs[0];
};

struct seq_operations___74 {
	void * (*start)(struct seq_file___74 *, loff_t *);
	void (*stop)(struct seq_file___74 *, void *);
	void * (*next)(struct seq_file___74 *, void *, loff_t *);
	int (*show)(struct seq_file___74 *, void *);
};

struct cgroup_namespace___65 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___65 *root_cset;
};

struct fwnode_reference_args___69;

struct fwnode_endpoint___69;

struct fwnode_operations___69 {
	struct fwnode_handle___69 * (*get)(struct fwnode_handle___69 *);
	void (*put)(struct fwnode_handle___69 *);
	bool (*device_is_available)(const struct fwnode_handle___69 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___69 *, const struct device___69 *);
	bool (*property_present)(const struct fwnode_handle___69 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___69 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___69 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___69 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*get_parent)(const struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*get_next_child_node)(const struct fwnode_handle___69 *, struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*get_named_child_node)(const struct fwnode_handle___69 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___69 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___69 *);
	struct fwnode_handle___69 * (*graph_get_next_endpoint)(const struct fwnode_handle___69 *, struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*graph_get_remote_endpoint)(const struct fwnode_handle___69 *);
	struct fwnode_handle___69 * (*graph_get_port_parent)(struct fwnode_handle___69 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___69 *, struct fwnode_endpoint___69 *);
	int (*add_links)(struct fwnode_handle___69 *);
};

struct fwnode_endpoint___69 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___69 *local_fwnode;
};

struct fwnode_reference_args___69 {
	struct fwnode_handle___69 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___75 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___75 *);
	int (*get)(char *, const struct kernel_param___75 *);
	void (*free)(void *);
};

struct kparam_array___75;

struct kernel_param___75 {
	const char *name;
	struct module___76 *mod;
	const struct kernel_param_ops___75 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___75 *arr;
	};
};

struct kparam_array___75 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___75 *ops;
	void *elem;
};

struct module_attribute___75 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___75 *, struct module_kobject___75 *, char *);
	ssize_t (*store)(struct module_attribute___75 *, struct module_kobject___75 *, const char *, size_t);
	void (*setup)(struct module___76 *, const char *);
	int (*test)(struct module___76 *);
	void (*free)(struct module___76 *);
};

struct trace_event_class___44;

struct trace_event_call___44 {
	struct list_head list;
	struct trace_event_class___44 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___18 *prog_array;
	int (*perf_perm)(struct trace_event_call___44 *, struct perf_event___50 *);
};

struct dev_pagemap_ops___77 {
	void (*page_free)(struct page___83 *);
	void (*kill)(struct dev_pagemap___77 *);
	void (*cleanup)(struct dev_pagemap___77 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___77 *);
};

struct cftype___65;

struct cgroup_subsys___65 {
	struct cgroup_subsys_state___65 * (*css_alloc)(struct cgroup_subsys_state___65 *);
	int (*css_online)(struct cgroup_subsys_state___65 *);
	void (*css_offline)(struct cgroup_subsys_state___65 *);
	void (*css_released)(struct cgroup_subsys_state___65 *);
	void (*css_free)(struct cgroup_subsys_state___65 *);
	void (*css_reset)(struct cgroup_subsys_state___65 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___65 *, int);
	int (*css_extra_stat_show)(struct seq_file___74 *, struct cgroup_subsys_state___65 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___85 *, struct css_set___65 *);
	void (*cancel_fork)(struct task_struct___85 *, struct css_set___65 *);
	void (*fork)(struct task_struct___85 *);
	void (*exit)(struct task_struct___85 *);
	void (*release)(struct task_struct___85 *);
	void (*bind)(struct cgroup_subsys_state___65 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___65 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___65 *dfl_cftypes;
	struct cftype___65 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___65 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___65 *updated_children;
	struct cgroup___65 *updated_next;
};

struct cgroup_root___65 {
	struct kernfs_root___78 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___65 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___65 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___65 *ss;
	struct list_head node;
	struct kernfs_ops___78 *kf_ops;
	int (*open)(struct kernfs_open_file___78 *);
	void (*release)(struct kernfs_open_file___78 *);
	u64 (*read_u64)(struct cgroup_subsys_state___65 *, struct cftype___65 *);
	s64 (*read_s64)(struct cgroup_subsys_state___65 *, struct cftype___65 *);
	int (*seq_show)(struct seq_file___74 *, void *);
	void * (*seq_start)(struct seq_file___74 *, loff_t *);
	void * (*seq_next)(struct seq_file___74 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___74 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___65 *, struct cftype___65 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___65 *, struct cftype___65 *, s64);
	ssize_t (*write)(struct kernfs_open_file___78 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___78 *, struct poll_table_struct___59 *);
};

struct block_device_operations___38;

struct gendisk___38 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___39 *part0;
	const struct block_device_operations___38 *fops;
	struct request_queue___38 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___37 *bdi;
	struct kobject___78 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___78 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___38 {
	struct bio___38 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___47 *bip_vec;
	struct bio_vec___47 bip_inline_vecs[0];
};

struct blkcg___37;

struct blkg_policy_data___37;

struct blkcg_gq___37 {
	struct request_queue___38 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___37 *blkcg;
	struct blkcg_gq___37 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___37 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___38 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___38(struct request___38 *);

typedef void integrity_complete_fn___38(struct request___38 *, unsigned int);

struct blk_integrity_profile___38 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___38 *prepare_fn;
	integrity_complete_fn___38 *complete_fn;
	const char *name;
};

struct block_device_operations___38 {
	blk_qc_t (*submit_bio)(struct bio___38 *);
	int (*open)(struct block_device___39 *, fmode_t);
	void (*release)(struct gendisk___38 *, fmode_t);
	int (*rw_page)(struct block_device___39 *, sector_t, struct page___83 *, unsigned int);
	int (*ioctl)(struct block_device___39 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___39 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___38 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___38 *);
	int (*getgeo)(struct block_device___39 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___39 *, bool);
	void (*swap_slot_free_notify)(struct block_device___39 *, long unsigned int);
	int (*report_zones)(struct gendisk___38 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___38 *, umode_t *);
	struct module___76 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___38 *, sector_t *);
};

typedef void rq_end_io_fn___38(struct request___38 *, blk_status_t);

struct request___38 {
	struct request_queue___38 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___37 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___38 *bio;
	struct bio___38 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___47 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___38 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___38 *saved_end_io;
		} flush;
	};
	struct gendisk___38 *rq_disk;
	struct block_device___39 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___38 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___37 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___38 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___78 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___78 *debugfs_dir;
	struct dentry___78 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___38;

struct elevator_mq_ops___38 {
	int (*init_sched)(struct request_queue___38 *, struct elevator_type___38 *);
	void (*exit_sched)(struct elevator_queue___38 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___37 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___37 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___37 *);
	bool (*allow_merge)(struct request_queue___38 *, struct request___38 *, struct bio___38 *);
	bool (*bio_merge)(struct request_queue___38 *, struct bio___38 *, unsigned int);
	int (*request_merge)(struct request_queue___38 *, struct request___38 **, struct bio___38 *);
	void (*request_merged)(struct request_queue___38 *, struct request___38 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___38 *, struct request___38 *, struct request___38 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___38 *);
	void (*finish_request)(struct request___38 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___37 *, struct list_head *, bool);
	struct request___38 * (*dispatch_request)(struct blk_mq_hw_ctx___37 *);
	bool (*has_work)(struct blk_mq_hw_ctx___37 *);
	void (*completed_request)(struct request___38 *, u64);
	void (*requeue_request)(struct request___38 *);
	struct request___38 * (*former_request)(struct request_queue___38 *, struct request___38 *);
	struct request___38 * (*next_request)(struct request_queue___38 *, struct request___38 *);
	void (*init_icq)(struct io_cq___38 *);
	void (*exit_icq)(struct io_cq___38 *);
};

struct elv_fs_entry___38;

struct elevator_type___38 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___38 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___38 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___76 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___38 {
	struct elevator_type___38 *type;
	void *elevator_data;
	struct kobject___78 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___38 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___38 *, char *);
	ssize_t (*store)(struct elevator_queue___38 *, const char *, size_t);
};

struct blk_mq_queue_data___37;

struct blk_mq_ops___37 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___37 *, const struct blk_mq_queue_data___37 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___37 *);
	int (*get_budget)(struct request_queue___38 *);
	void (*put_budget)(struct request_queue___38 *, int);
	void (*set_rq_budget_token)(struct request___38 *, int);
	int (*get_rq_budget_token)(struct request___38 *);
	enum blk_eh_timer_return (*timeout)(struct request___38 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___37 *);
	void (*complete)(struct request___38 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___37 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___37 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___37 *, struct request___38 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___37 *, struct request___38 *, unsigned int);
	void (*initialize_rq_fn)(struct request___38 *);
	void (*cleanup_rq)(struct request___38 *);
	bool (*busy)(struct request_queue___38 *);
	int (*map_queues)(struct blk_mq_tag_set___37 *);
	void (*show_rq)(struct seq_file___74 *, struct request___38 *);
};

struct blk_mq_tag_set___37 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___37 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___37 {
	struct request___38 *rq;
	bool last;
};

struct blkcg_policy_data___37;

struct blkcg___37 {
	struct cgroup_subsys_state___65 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___37 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___37 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___37 {
	struct blkcg___37 *blkcg;
	int plid;
};

struct blkg_policy_data___37 {
	struct blkcg_gq___37 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___35 {
	struct mem_cgroup___35 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___35 {
	struct lruvec___38 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___35 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___35 *memcg;
};

struct obj_cgroup___35 {
	struct percpu_ref refcnt;
	struct mem_cgroup___35 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

typedef struct page___83 *new_page_t___2(struct page___83 *, long unsigned int);

typedef void free_page_t___2(struct page___83 *, long unsigned int);

struct alloc_context {
	struct zonelist___38 *zonelist;
	nodemask_t *nodemask;
	struct zoneref___38 *preferred_zoneref;
	int migratetype;
	enum zone_type highest_zoneidx;
	bool spread_dirty_pages;
};

struct compact_control___8 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___38 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct perf_cpu_context___50;

struct perf_output_handle___50;

struct pmu___50 {
	struct list_head entry;
	struct module___76 *module;
	struct device___69 *dev;
	const struct attribute_group___78 **attr_groups;
	const struct attribute_group___78 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___50 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___50 *);
	void (*pmu_disable)(struct pmu___50 *);
	int (*event_init)(struct perf_event___50 *);
	void (*event_mapped)(struct perf_event___50 *, struct mm_struct___84 *);
	void (*event_unmapped)(struct perf_event___50 *, struct mm_struct___84 *);
	int (*add)(struct perf_event___50 *, int);
	void (*del)(struct perf_event___50 *, int);
	void (*start)(struct perf_event___50 *, int);
	void (*stop)(struct perf_event___50 *, int);
	void (*read)(struct perf_event___50 *);
	void (*start_txn)(struct pmu___50 *, unsigned int);
	int (*commit_txn)(struct pmu___50 *);
	void (*cancel_txn)(struct pmu___50 *);
	int (*event_idx)(struct perf_event___50 *);
	void (*sched_task)(struct perf_event_context___50 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___50 *, struct perf_event_context___50 *);
	void * (*setup_aux)(struct perf_event___50 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___50 *, struct perf_output_handle___50 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___50 *);
	int (*aux_output_match)(struct perf_event___50 *);
	int (*filter_match)(struct perf_event___50 *);
	int (*check_period)(struct perf_event___50 *, u64);
};

struct perf_cpu_context___50 {
	struct perf_event_context___50 ctx;
	struct perf_event_context___50 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___50 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___50 **heap;
	struct perf_event___50 *heap_default[2];
};

struct perf_output_handle___50 {
	struct perf_event___50 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___50 {
	struct cgroup_subsys_state___65 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___44 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___44 *);
	};
};

struct trace_event_class___44 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___44 *, enum trace_reg, void *);
	struct trace_event_fields___44 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___44 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___44 *);
};

struct trace_event_file___23;

struct trace_event_buffer___22 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___23 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___23 {
	struct list_head list;
	struct trace_event_call___44 *event_call;
	struct event_filter *filter;
	struct dentry___78 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mm_compaction_isolate_template {
	struct trace_entry ent;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	long unsigned int nr_scanned;
	long unsigned int nr_taken;
	char __data[0];
};

struct trace_event_raw_mm_compaction_migratepages {
	struct trace_entry ent;
	long unsigned int nr_migrated;
	long unsigned int nr_failed;
	char __data[0];
};

struct trace_event_raw_mm_compaction_begin {
	struct trace_entry ent;
	long unsigned int zone_start;
	long unsigned int migrate_pfn;
	long unsigned int free_pfn;
	long unsigned int zone_end;
	bool sync;
	char __data[0];
};

struct trace_event_raw_mm_compaction_end {
	struct trace_entry ent;
	long unsigned int zone_start;
	long unsigned int migrate_pfn;
	long unsigned int free_pfn;
	long unsigned int zone_end;
	bool sync;
	int status;
	char __data[0];
};

struct trace_event_raw_mm_compaction_try_to_compact_pages {
	struct trace_entry ent;
	int order;
	gfp_t gfp_mask;
	int prio;
	char __data[0];
};

struct trace_event_raw_mm_compaction_suitable_template {
	struct trace_entry ent;
	int nid;
	enum zone_type idx;
	int order;
	int ret;
	char __data[0];
};

struct trace_event_raw_mm_compaction_defer_template {
	struct trace_entry ent;
	int nid;
	enum zone_type idx;
	int order;
	unsigned int considered;
	unsigned int defer_shift;
	int order_failed;
	char __data[0];
};

struct trace_event_raw_mm_compaction_kcompactd_sleep {
	struct trace_entry ent;
	int nid;
	char __data[0];
};

struct trace_event_raw_kcompactd_wake_template {
	struct trace_entry ent;
	int nid;
	int order;
	enum zone_type highest_zoneidx;
	char __data[0];
};

struct trace_event_data_offsets_mm_compaction_isolate_template {};

struct trace_event_data_offsets_mm_compaction_migratepages {};

struct trace_event_data_offsets_mm_compaction_begin {};

struct trace_event_data_offsets_mm_compaction_end {};

struct trace_event_data_offsets_mm_compaction_try_to_compact_pages {};

struct trace_event_data_offsets_mm_compaction_suitable_template {};

struct trace_event_data_offsets_mm_compaction_defer_template {};

struct trace_event_data_offsets_mm_compaction_kcompactd_sleep {};

struct trace_event_data_offsets_kcompactd_wake_template {};

typedef void (*btf_trace_mm_compaction_isolate_migratepages)(void *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);

typedef void (*btf_trace_mm_compaction_isolate_freepages)(void *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);

typedef void (*btf_trace_mm_compaction_migratepages)(void *, long unsigned int, int, struct list_head *);

typedef void (*btf_trace_mm_compaction_begin)(void *, long unsigned int, long unsigned int, long unsigned int, long unsigned int, bool);

typedef void (*btf_trace_mm_compaction_end)(void *, long unsigned int, long unsigned int, long unsigned int, long unsigned int, bool, int);

typedef void (*btf_trace_mm_compaction_try_to_compact_pages)(void *, int, gfp_t, int);

typedef void (*btf_trace_mm_compaction_finished)(void *, struct zone___38 *, int, int);

typedef void (*btf_trace_mm_compaction_suitable)(void *, struct zone___38 *, int, int);

typedef void (*btf_trace_mm_compaction_deferred)(void *, struct zone___38 *, int);

typedef void (*btf_trace_mm_compaction_defer_compaction)(void *, struct zone___38 *, int);

typedef void (*btf_trace_mm_compaction_defer_reset)(void *, struct zone___38 *, int);

typedef void (*btf_trace_mm_compaction_kcompactd_sleep)(void *, int);

typedef void (*btf_trace_mm_compaction_wakeup_kcompactd)(void *, int, int, enum zone_type);

typedef void (*btf_trace_mm_compaction_kcompactd_wake)(void *, int, int, enum zone_type);

typedef enum {
	ISOLATE_ABORT = 0,
	ISOLATE_NONE = 1,
	ISOLATE_SUCCESS = 2,
} isolate_migrate_t;

struct anon_vma_chain {
	struct vm_area_struct___78 *vma;
	struct anon_vma *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct rb_augment_callbacks {
	void (*propagate)(struct rb_node *, struct rb_node *);
	void (*copy)(struct rb_node *, struct rb_node *);
	void (*rotate)(struct rb_node *, struct rb_node *);
};

enum lru_status {
	LRU_REMOVED = 0,
	LRU_REMOVED_RETRY = 1,
	LRU_ROTATE = 2,
	LRU_SKIP = 3,
	LRU_RETRY = 4,
};

typedef enum lru_status (*list_lru_walk_cb)(struct list_head *, struct list_lru_one *, spinlock_t *, void *);

typedef struct pglist_data___34 pg_data_t___7;

typedef struct {
	long unsigned int pd;
} hugepd_t;

typedef struct page___78 *new_page_t___3(struct page___78 *, long unsigned int);

typedef void free_page_t___3(struct page___78 *, long unsigned int);

struct follow_page_context {
	struct dev_pagemap___72 *pgmap;
	unsigned int page_mask;
};

struct trace_event_raw_mmap_lock_start_locking {
	struct trace_entry ent;
	struct mm_struct___79 *mm;
	u32 __data_loc_memcg_path;
	bool write;
	char __data[0];
};

struct trace_event_raw_mmap_lock_acquire_returned {
	struct trace_entry ent;
	struct mm_struct___79 *mm;
	u32 __data_loc_memcg_path;
	bool write;
	bool success;
	char __data[0];
};

struct trace_event_raw_mmap_lock_released {
	struct trace_entry ent;
	struct mm_struct___79 *mm;
	u32 __data_loc_memcg_path;
	bool write;
	char __data[0];
};

struct trace_event_data_offsets_mmap_lock_start_locking {
	u32 memcg_path;
};

struct trace_event_data_offsets_mmap_lock_acquire_returned {
	u32 memcg_path;
};

struct trace_event_data_offsets_mmap_lock_released {
	u32 memcg_path;
};

typedef void (*btf_trace_mmap_lock_start_locking)(void *, struct mm_struct___79 *, const char *, bool);

typedef void (*btf_trace_mmap_lock_acquire_returned)(void *, struct mm_struct___79 *, const char *, bool, bool);

typedef void (*btf_trace_mmap_lock_released)(void *, struct mm_struct___79 *, const char *, bool);

struct memcg_path {
	local_lock_t lock;
	char *buf;
	local_t buf_idx;
};

typedef struct {
	u64 val;
} pfn_t;

typedef unsigned int pgtbl_mod_mask;

enum {
	SWP_USED = 1,
	SWP_WRITEOK = 2,
	SWP_DISCARDABLE = 4,
	SWP_DISCARDING = 8,
	SWP_SOLIDSTATE = 16,
	SWP_CONTINUED = 32,
	SWP_BLKDEV = 64,
	SWP_ACTIVATED = 128,
	SWP_FS_OPS = 256,
	SWP_AREA_DISCARD = 512,
	SWP_PAGE_DISCARD = 1024,
	SWP_STABLE_WRITES = 2048,
	SWP_SYNCHRONOUS_IO = 4096,
	SWP_SCANNING = 16384,
};

struct copy_subpage_arg {
	struct page___78 *dst;
	struct page___78 *src;
	struct vm_area_struct___78 *vma;
};

struct mm_walk;

struct mm_walk_ops {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*p4d_entry)(p4d_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk *);
	int (*pte_hole)(long unsigned int, long unsigned int, int, struct mm_walk *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk *);
	int (*pre_vma)(long unsigned int, long unsigned int, struct mm_walk *);
	void (*post_vma)(struct mm_walk *);
};

enum page_walk_action {
	ACTION_SUBTREE = 0,
	ACTION_CONTINUE = 1,
	ACTION_AGAIN = 2,
};

struct mm_walk {
	const struct mm_walk_ops *ops;
	struct mm_struct___81 *mm;
	pgd_t *pgd;
	struct vm_area_struct___80 *vma;
	enum page_walk_action action;
	bool no_vma;
	void *private;
};

struct syscall_metadata___18 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___42 *enter_event;
	struct trace_event_call___42 *exit_event;
};

struct vm_special_mapping___3 {
	const char *name;
	struct page___80 **pages;
	vm_fault_t (*fault)(const struct vm_special_mapping___3 *, struct vm_area_struct___80 *, struct vm_fault___74 *);
	int (*mremap)(const struct vm_special_mapping___3 *, struct vm_area_struct___80 *);
};

struct vm_unmapped_area_info {
	long unsigned int flags;
	long unsigned int length;
	long unsigned int low_limit;
	long unsigned int high_limit;
	long unsigned int align_mask;
	long unsigned int align_offset;
};

struct hstate___4;

struct hugepage_subpool___2 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___4 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___4 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___63 cgroup_files_dfl[7];
	struct cftype___63 cgroup_files_legacy[9];
	char name[32];
};

enum {
	HUGETLB_SHMFS_INODE = 1,
	HUGETLB_ANONHUGE_INODE = 2,
};

struct hugetlbfs_sb_info___2 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___4 *hstate;
	struct hugepage_subpool___2 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct anon_vma_chain___2 {
	struct vm_area_struct___80 *vma;
	struct anon_vma *anon_vma;
	struct list_head same_vma;
	struct rb_node rb;
	long unsigned int rb_subtree_last;
};

struct mmu_gather_batch___2 {
	struct mmu_gather_batch___2 *next;
	unsigned int nr;
	unsigned int max;
	struct page___80 *pages[0];
};

struct mmu_gather___2 {
	struct mm_struct___81 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___2 *active;
	struct mmu_gather_batch___2 local;
	struct page___80 *__pages[8];
};

struct trace_event_raw_vm_unmapped_area {
	struct trace_entry ent;
	long unsigned int addr;
	long unsigned int total_vm;
	long unsigned int flags;
	long unsigned int length;
	long unsigned int low_limit;
	long unsigned int high_limit;
	long unsigned int align_mask;
	long unsigned int align_offset;
	char __data[0];
};

struct trace_event_data_offsets_vm_unmapped_area {};

typedef void (*btf_trace_vm_unmapped_area)(void *, long unsigned int, struct vm_unmapped_area_info *);

struct mm_walk___2;

struct mm_walk_ops___2 {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*p4d_entry)(p4d_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pte_hole)(long unsigned int, long unsigned int, int, struct mm_walk___2 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___2 *);
	int (*pre_vma)(long unsigned int, long unsigned int, struct mm_walk___2 *);
	void (*post_vma)(struct mm_walk___2 *);
};

struct mm_walk___2 {
	const struct mm_walk_ops___2 *ops;
	struct mm_struct___79 *mm;
	pgd_t *pgd;
	struct vm_area_struct___78 *vma;
	enum page_walk_action action;
	bool no_vma;
	void *private;
};

enum pgt_entry {
	NORMAL_PMD = 0,
	HPAGE_PMD = 1,
	NORMAL_PUD = 2,
	HPAGE_PUD = 3,
};

struct page_vma_mapped_walk___2 {
	struct page___78 *page;
	struct vm_area_struct___78 *vma;
	long unsigned int address;
	pmd_t *pmd;
	pte_t *pte;
	spinlock_t *ptl;
	unsigned int flags;
};

struct hstate___5 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___61 cgroup_files_dfl[7];
	struct cftype___61 cgroup_files_legacy[9];
	char name[32];
};

struct dentry___79;

struct super_block___79;

struct module___77;

struct file_system_type___79 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___79 * (*mount)(struct file_system_type___79 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___79 *);
	struct module___77 *owner;
	struct file_system_type___79 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___79;

struct kiocb___79;

struct vm_area_struct___84;

struct inode___79;

struct file_lock___79;

struct page___84;

struct seq_file___75;

struct file_operations___79 {
	struct module___77 *owner;
	loff_t (*llseek)(struct file___79 *, loff_t, int);
	ssize_t (*read)(struct file___79 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___79 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___79 *, struct iov_iter___48 *);
	ssize_t (*write_iter)(struct kiocb___79 *, struct iov_iter___48 *);
	int (*iopoll)(struct kiocb___79 *, bool);
	int (*iterate)(struct file___79 *, struct dir_context *);
	int (*iterate_shared)(struct file___79 *, struct dir_context *);
	__poll_t (*poll)(struct file___79 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___79 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___79 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___79 *, struct vm_area_struct___84 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___79 *, struct file___79 *);
	int (*flush)(struct file___79 *, fl_owner_t);
	int (*release)(struct inode___79 *, struct file___79 *);
	int (*fsync)(struct file___79 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___79 *, int);
	int (*lock)(struct file___79 *, int, struct file_lock___79 *);
	ssize_t (*sendpage)(struct file___79 *, struct page___84 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___79 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___79 *, long unsigned int);
	int (*flock)(struct file___79 *, int, struct file_lock___79 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___79 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___79 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___79 *, long int, struct file_lock___79 **, void **);
	long int (*fallocate)(struct file___79 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___75 *, struct file___79 *);
	ssize_t (*copy_file_range)(struct file___79 *, loff_t, struct file___79 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___79 *, loff_t, struct file___79 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___79 *, loff_t, loff_t, int);
};

struct vmacache___84 {
	u64 seqnum;
	struct vm_area_struct___84 *vmas[4];
};

struct page_frag___84 {
	struct page___84 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___85;

struct pid___72;

struct nsproxy___77;

struct signal_struct___80;

struct css_set___66;

struct vm_struct___80;

struct task_struct___86 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___86 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___85 *mm;
	struct mm_struct___85 *active_mm;
	struct vmacache___84 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___86 *real_parent;
	struct task_struct___86 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___86 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___72 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___77 *nsproxy;
	struct signal_struct___80 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___86 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___38 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___66 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___84 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___86 *oom_reaper_list;
	struct vm_struct___80 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___79;

struct kobj_type___79;

struct kernfs_node___79;

struct kobject___79 {
	const char *name;
	struct list_head entry;
	struct kobject___79 *parent;
	struct kset___79 *kset;
	struct kobj_type___79 *ktype;
	struct kernfs_node___79 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___76 {
	struct kobject___79 kobj;
	struct module___77 *mod;
	struct kobject___79 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___76 {
	struct module___77 *mod;
	struct latch_tree_node node;
};

struct module_layout___76 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___76 mtn;
};

struct module_attribute___76;

struct kernel_param___76;

struct module___77 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___76 mkobj;
	struct module_attribute___76 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___79 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___76 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___76 core_layout;
	struct module_layout___76 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___84 *pgtable_t___84;

struct address_space___79;

struct dev_pagemap___78;

struct page___84 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___79 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___84 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___84 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___85 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___78 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___78;

struct vm_area_struct___84 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___84 *vm_next;
	struct vm_area_struct___84 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___85 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___78 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___79 *vm_file;
	struct file___79 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___84;

struct mm_struct___85 {
	struct {
		struct vm_area_struct___84 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___79 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___84 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___86 *owner;
		struct user_namespace___12 *user_ns;
		struct file___79 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___79;

struct address_space___79 {
	struct inode___79 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___79 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___78;

struct dev_pagemap___78 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___78 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___79;

struct path___79 {
	struct vfsmount___79 *mnt;
	struct dentry___79 *dentry;
};

struct fown_struct___72 {
	rwlock_t lock;
	struct pid___72 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___79 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___79 f_path;
	struct inode___79 *f_inode;
	const struct file_operations___79 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___72 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___79 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___78;

struct vm_operations_struct___78 {
	void (*open)(struct vm_area_struct___84 *);
	void (*close)(struct vm_area_struct___84 *);
	int (*may_split)(struct vm_area_struct___84 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___84 *);
	int (*mprotect)(struct vm_area_struct___84 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___78 *);
	vm_fault_t (*huge_fault)(struct vm_fault___78 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___78 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___84 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___78 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___78 *);
	int (*access)(struct vm_area_struct___84 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___84 *);
	int (*set_policy)(struct vm_area_struct___84 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___84 *, long unsigned int);
	struct page___84 * (*find_special_page)(struct vm_area_struct___84 *, long unsigned int);
};

struct core_thread___84 {
	struct task_struct___86 *task;
	struct core_thread___84 *next;
};

struct core_state___84 {
	atomic_t nr_threads;
	struct core_thread___84 dumper;
	struct completion startup;
};

struct vm_fault___78 {
	const struct {
		struct vm_area_struct___84 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___84 *cow_page;
	struct page___84 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___84 prealloc_pte;
};

struct dev_pagemap_ops___78 {
	void (*page_free)(struct page___84 *);
	void (*kill)(struct dev_pagemap___78 *);
	void (*cleanup)(struct dev_pagemap___78 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___78 *);
};

struct pid_namespace___72;

struct upid___72 {
	int nr;
	struct pid_namespace___72 *ns;
};

struct pid_namespace___72 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___86 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___72 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___72 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___72 numbers[1];
};

struct signal_struct___80 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___86 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___86 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___72 *pids[4];
	struct pid___72 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___85 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___66;

struct nsproxy___77 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___72 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___66 *cgroup_ns;
};

struct cgroup_subsys_state___66;

struct cgroup___66;

struct css_set___66 {
	struct cgroup_subsys_state___66 *subsys[14];
	refcount_t refcount;
	struct css_set___66 *dom_cset;
	struct cgroup___66 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___66 *mg_src_cgrp;
	struct cgroup___66 *mg_dst_cgrp;
	struct css_set___66 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___80 {
	struct vm_struct___80 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___84 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___79;

struct dentry___79 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___79 *d_parent;
	struct qstr d_name;
	struct inode___79 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___79 *d_op;
	struct super_block___79 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___79;

struct inode___79 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___79 *i_op;
	struct super_block___79 *i_sb;
	struct address_space___79 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___79 *i_fop;
		void (*free_inode)(struct inode___79 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___79 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___79 {
	int (*d_revalidate)(struct dentry___79 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___79 *, unsigned int);
	int (*d_hash)(const struct dentry___79 *, struct qstr *);
	int (*d_compare)(const struct dentry___79 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___79 *);
	int (*d_init)(struct dentry___79 *);
	void (*d_release)(struct dentry___79 *);
	void (*d_prune)(struct dentry___79 *);
	void (*d_iput)(struct dentry___79 *, struct inode___79 *);
	char * (*d_dname)(struct dentry___79 *, char *, int);
	struct vfsmount___79 * (*d_automount)(struct path___79 *);
	int (*d_manage)(const struct path___79 *, bool);
	struct dentry___79 * (*d_real)(struct dentry___79 *, const struct inode___79 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___79;

struct mem_dqinfo___79 {
	struct quota_format_type___79 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___79;

struct quota_info___79 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___79 *files[3];
	struct mem_dqinfo___79 info[3];
	const struct quota_format_ops___79 *ops[3];
};

struct rcuwait___80 {
	struct task_struct___86 *task;
};

struct percpu_rw_semaphore___80 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___80 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___79 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___80 rw_sem[3];
};

struct super_operations___79;

struct dquot_operations___79;

struct quotactl_ops___79;

struct super_block___79 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___79 *s_type;
	const struct super_operations___79 *s_op;
	const struct dquot_operations___79 *dq_op;
	const struct quotactl_ops___79 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___79 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___79 s_dquot;
	struct sb_writers___79 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___79 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___79 {
	struct dentry___79 *mnt_root;
	struct super_block___79 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct cgroup_subsys___66;

struct cgroup_subsys_state___66 {
	struct cgroup___66 *cgroup;
	struct cgroup_subsys___66 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___66 *parent;
};

struct cgroup_file___66 {
	struct kernfs_node___79 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___66 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___86 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___66;

struct cgroup_rstat_cpu___66;

struct cgroup___66 {
	struct cgroup_subsys_state___66 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___79 *kn;
	struct cgroup_file___66 procs_file;
	struct cgroup_file___66 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___66 *subsys[14];
	struct cgroup_root___66 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___66 *dom_cgrp;
	struct cgroup___66 *old_dom_cgrp;
	struct cgroup_rstat_cpu___66 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___66 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___37;

struct kiocb___79 {
	struct file___79 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___79 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___37 *ki_waitq;
	};
};

struct iattr___79 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___79 *ia_file;
};

struct dquot___79 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___79 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___79 {
	int qf_fmt_id;
	const struct quota_format_ops___79 *qf_ops;
	struct module___77 *qf_owner;
	struct quota_format_type___79 *qf_next;
};

struct quota_format_ops___79 {
	int (*check_quota_file)(struct super_block___79 *, int);
	int (*read_file_info)(struct super_block___79 *, int);
	int (*write_file_info)(struct super_block___79 *, int);
	int (*free_file_info)(struct super_block___79 *, int);
	int (*read_dqblk)(struct dquot___79 *);
	int (*commit_dqblk)(struct dquot___79 *);
	int (*release_dqblk)(struct dquot___79 *);
	int (*get_next_id)(struct super_block___79 *, struct kqid *);
};

struct dquot_operations___79 {
	int (*write_dquot)(struct dquot___79 *);
	struct dquot___79 * (*alloc_dquot)(struct super_block___79 *, int);
	void (*destroy_dquot)(struct dquot___79 *);
	int (*acquire_dquot)(struct dquot___79 *);
	int (*release_dquot)(struct dquot___79 *);
	int (*mark_dirty)(struct dquot___79 *);
	int (*write_info)(struct super_block___79 *, int);
	qsize_t * (*get_reserved_space)(struct inode___79 *);
	int (*get_projid)(struct inode___79 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___79 *, qsize_t *);
	int (*get_next_id)(struct super_block___79 *, struct kqid *);
};

struct quotactl_ops___79 {
	int (*quota_on)(struct super_block___79 *, int, int, const struct path___79 *);
	int (*quota_off)(struct super_block___79 *, int);
	int (*quota_enable)(struct super_block___79 *, unsigned int);
	int (*quota_disable)(struct super_block___79 *, unsigned int);
	int (*quota_sync)(struct super_block___79 *, int);
	int (*set_info)(struct super_block___79 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___79 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___79 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___79 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___79 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___79 *, unsigned int);
};

struct wait_page_queue___37 {
	struct page___84 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___37;

struct address_space_operations___79 {
	int (*writepage)(struct page___84 *, struct writeback_control___3 *);
	int (*readpage)(struct file___79 *, struct page___84 *);
	int (*writepages)(struct address_space___79 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___84 *);
	int (*readpages)(struct file___79 *, struct address_space___79 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___37 *);
	int (*write_begin)(struct file___79 *, struct address_space___79 *, loff_t, unsigned int, unsigned int, struct page___84 **, void **);
	int (*write_end)(struct file___79 *, struct address_space___79 *, loff_t, unsigned int, unsigned int, struct page___84 *, void *);
	sector_t (*bmap)(struct address_space___79 *, sector_t);
	void (*invalidatepage)(struct page___84 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___84 *, gfp_t);
	void (*freepage)(struct page___84 *);
	ssize_t (*direct_IO)(struct kiocb___79 *, struct iov_iter___48 *);
	int (*migratepage)(struct address_space___79 *, struct page___84 *, struct page___84 *, enum migrate_mode);
	bool (*isolate_page)(struct page___84 *, isolate_mode_t);
	void (*putback_page)(struct page___84 *);
	int (*launder_page)(struct page___84 *);
	int (*is_partially_uptodate)(struct page___84 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___84 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___79 *, struct page___84 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___79 *, sector_t *);
	void (*swap_deactivate)(struct file___79 *);
};

struct readahead_control___37 {
	struct file___79 *file;
	struct address_space___79 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___79 {
	struct dentry___79 * (*lookup)(struct inode___79 *, struct dentry___79 *, unsigned int);
	const char * (*get_link)(struct dentry___79 *, struct inode___79 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___79 *, int);
	struct posix_acl * (*get_acl)(struct inode___79 *, int, bool);
	int (*readlink)(struct dentry___79 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___79 *, struct dentry___79 *, umode_t, bool);
	int (*link)(struct dentry___79 *, struct inode___79 *, struct dentry___79 *);
	int (*unlink)(struct inode___79 *, struct dentry___79 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___79 *, struct dentry___79 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___79 *, struct dentry___79 *, umode_t);
	int (*rmdir)(struct inode___79 *, struct dentry___79 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___79 *, struct dentry___79 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___79 *, struct dentry___79 *, struct inode___79 *, struct dentry___79 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___79 *, struct iattr___79 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___79 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___79 *, char *, size_t);
	int (*fiemap)(struct inode___79 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___79 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___79 *, struct dentry___79 *, struct file___79 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___79 *, struct dentry___79 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___79 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___79 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___79 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___79 {
	void (*fl_copy_lock)(struct file_lock___79 *, struct file_lock___79 *);
	void (*fl_release_private)(struct file_lock___79 *);
};

struct fasync_struct___79;

struct lock_manager_operations___79;

struct file_lock___79 {
	struct file_lock___79 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___79 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___79 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___79 *fl_ops;
	const struct lock_manager_operations___79 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___79 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___79 *);
	int (*lm_grant)(struct file_lock___79 *, int);
	bool (*lm_break)(struct file_lock___79 *);
	int (*lm_change)(struct file_lock___79 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___79 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___79 *);
};

struct fasync_struct___79 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___79 *fa_next;
	struct file___79 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___79 {
	struct inode___79 * (*alloc_inode)(struct super_block___79 *);
	void (*destroy_inode)(struct inode___79 *);
	void (*free_inode)(struct inode___79 *);
	void (*dirty_inode)(struct inode___79 *, int);
	int (*write_inode)(struct inode___79 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___79 *);
	void (*evict_inode)(struct inode___79 *);
	void (*put_super)(struct super_block___79 *);
	int (*sync_fs)(struct super_block___79 *, int);
	int (*freeze_super)(struct super_block___79 *);
	int (*freeze_fs)(struct super_block___79 *);
	int (*thaw_super)(struct super_block___79 *);
	int (*unfreeze_fs)(struct super_block___79 *);
	int (*statfs)(struct dentry___79 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___79 *, int *, char *);
	void (*umount_begin)(struct super_block___79 *);
	int (*show_options)(struct seq_file___75 *, struct dentry___79 *);
	int (*show_devname)(struct seq_file___75 *, struct dentry___79 *);
	int (*show_path)(struct seq_file___75 *, struct dentry___79 *);
	int (*show_stats)(struct seq_file___75 *, struct dentry___79 *);
	ssize_t (*quota_read)(struct super_block___79 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___79 *, int, const char *, size_t, loff_t);
	struct dquot___79 ** (*get_dquots)(struct inode___79 *);
	long int (*nr_cached_objects)(struct super_block___79 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___79 *, struct shrink_control___35 *);
	struct file___79 * (*real_loop)(struct file___79 *);
};

struct seq_operations___75;

struct seq_file___75 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___75 *op;
	int poll_event;
	const struct file___79 *file;
	void *private;
};

struct mm_walk___3;

struct mm_walk_ops___3 {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*p4d_entry)(p4d_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pte_hole)(long unsigned int, long unsigned int, int, struct mm_walk___3 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___3 *);
	int (*pre_vma)(long unsigned int, long unsigned int, struct mm_walk___3 *);
	void (*post_vma)(struct mm_walk___3 *);
};

struct mm_walk___3 {
	const struct mm_walk_ops___3 *ops;
	struct mm_struct___85 *mm;
	pgd_t *pgd;
	struct vm_area_struct___84 *vma;
	enum page_walk_action action;
	bool no_vma;
	void *private;
};

struct kernfs_root___79;

struct kernfs_elem_dir___79 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___79 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___79;

struct kernfs_root___79 {
	struct kernfs_node___79 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___79 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___79 {
	struct kernfs_node___79 *target_kn;
};

struct kernfs_ops___79;

struct kernfs_elem_attr___79 {
	const struct kernfs_ops___79 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___79 *notify_next;
};

struct kernfs_node___79 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___79 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___79 dir;
		struct kernfs_elem_symlink___79 symlink;
		struct kernfs_elem_attr___79 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___79;

struct kernfs_ops___79 {
	int (*open)(struct kernfs_open_file___79 *);
	void (*release)(struct kernfs_open_file___79 *);
	int (*seq_show)(struct seq_file___75 *, void *);
	void * (*seq_start)(struct seq_file___75 *, loff_t *);
	void * (*seq_next)(struct seq_file___75 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___75 *, void *);
	ssize_t (*read)(struct kernfs_open_file___79 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___79 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___79 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___79 *, struct vm_area_struct___84 *);
};

struct kernfs_syscall_ops___79 {
	int (*show_options)(struct seq_file___75 *, struct kernfs_root___79 *);
	int (*mkdir)(struct kernfs_node___79 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___79 *);
	int (*rename)(struct kernfs_node___79 *, struct kernfs_node___79 *, const char *);
	int (*show_path)(struct seq_file___75 *, struct kernfs_node___79 *, struct kernfs_root___79 *);
};

struct kernfs_open_file___79 {
	struct kernfs_node___79 *kn;
	struct file___79 *file;
	struct seq_file___75 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___78 *vm_ops;
};

struct bin_attribute___79;

struct attribute_group___79 {
	const char *name;
	umode_t (*is_visible)(struct kobject___79 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___79 *, struct bin_attribute___79 *, int);
	struct attribute **attrs;
	struct bin_attribute___79 **bin_attrs;
};

struct bin_attribute___79 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___79 * (*f_mapping)();
	ssize_t (*read)(struct file___79 *, struct kobject___79 *, struct bin_attribute___79 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___79 *, struct kobject___79 *, struct bin_attribute___79 *, char *, loff_t, size_t);
	int (*mmap)(struct file___79 *, struct kobject___79 *, struct bin_attribute___79 *, struct vm_area_struct___84 *);
};

struct sysfs_ops___79 {
	ssize_t (*show)(struct kobject___79 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___79 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___79;

struct kset___79 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___79 kobj;
	const struct kset_uevent_ops___79 *uevent_ops;
};

struct kobj_type___79 {
	void (*release)(struct kobject___79 *);
	const struct sysfs_ops___79 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___79 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___79 *);
	const void * (*namespace)(struct kobject___79 *);
	void (*get_ownership)(struct kobject___79 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___79 {
	int (* const filter)(struct kset___79 *, struct kobject___79 *);
	const char * (* const name)(struct kset___79 *, struct kobject___79 *);
	int (* const uevent)(struct kset___79 *, struct kobject___79 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___76 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___76 *);
	int (*get)(char *, const struct kernel_param___76 *);
	void (*free)(void *);
};

struct kparam_array___76;

struct kernel_param___76 {
	const char *name;
	struct module___77 *mod;
	const struct kernel_param_ops___76 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___76 *arr;
	};
};

struct kparam_array___76 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___76 *ops;
	void *elem;
};

struct module_attribute___76 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___76 *, struct module_kobject___76 *, char *);
	ssize_t (*store)(struct module_attribute___76 *, struct module_kobject___76 *, const char *, size_t);
	void (*setup)(struct module___77 *, const char *);
	int (*test)(struct module___77 *);
	void (*free)(struct module___77 *);
};

struct cgroup_namespace___66 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___66 *root_cset;
};

struct seq_operations___75 {
	void * (*start)(struct seq_file___75 *, loff_t *);
	void (*stop)(struct seq_file___75 *, void *);
	void * (*next)(struct seq_file___75 *, void *, loff_t *);
	int (*show)(struct seq_file___75 *, void *);
};

struct cftype___66;

struct cgroup_subsys___66 {
	struct cgroup_subsys_state___66 * (*css_alloc)(struct cgroup_subsys_state___66 *);
	int (*css_online)(struct cgroup_subsys_state___66 *);
	void (*css_offline)(struct cgroup_subsys_state___66 *);
	void (*css_released)(struct cgroup_subsys_state___66 *);
	void (*css_free)(struct cgroup_subsys_state___66 *);
	void (*css_reset)(struct cgroup_subsys_state___66 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___66 *, int);
	int (*css_extra_stat_show)(struct seq_file___75 *, struct cgroup_subsys_state___66 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___86 *, struct css_set___66 *);
	void (*cancel_fork)(struct task_struct___86 *, struct css_set___66 *);
	void (*fork)(struct task_struct___86 *);
	void (*exit)(struct task_struct___86 *);
	void (*release)(struct task_struct___86 *);
	void (*bind)(struct cgroup_subsys_state___66 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___66 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___66 *dfl_cftypes;
	struct cftype___66 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___66 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___66 *updated_children;
	struct cgroup___66 *updated_next;
};

struct cgroup_root___66 {
	struct kernfs_root___79 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___66 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___66 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___66 *ss;
	struct list_head node;
	struct kernfs_ops___79 *kf_ops;
	int (*open)(struct kernfs_open_file___79 *);
	void (*release)(struct kernfs_open_file___79 *);
	u64 (*read_u64)(struct cgroup_subsys_state___66 *, struct cftype___66 *);
	s64 (*read_s64)(struct cgroup_subsys_state___66 *, struct cftype___66 *);
	int (*seq_show)(struct seq_file___75 *, void *);
	void * (*seq_start)(struct seq_file___75 *, loff_t *);
	void * (*seq_next)(struct seq_file___75 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___75 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___66 *, struct cftype___66 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___66 *, struct cftype___66 *, s64);
	ssize_t (*write)(struct kernfs_open_file___79 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___79 *, struct poll_table_struct___5 *);
};

struct hstate___6;

struct hugepage_subpool___3 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___6 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___6 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___66 cgroup_files_dfl[7];
	struct cftype___66 cgroup_files_legacy[9];
	char name[32];
};

struct hugetlbfs_sb_info___3 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___6 *hstate;
	struct hugepage_subpool___3 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct rmap_walk_control {
	void *arg;
	bool (*rmap_one)(struct page___78 *, struct vm_area_struct___78 *, long unsigned int, void *);
	int (*done)(struct page___78 *);
	struct anon_vma * (*anon_lock)(struct page___78 *);
	bool (*invalid_vma)(struct vm_area_struct___78 *, void *);
};

struct page_referenced_arg {
	int mapcount;
	int referenced;
	long unsigned int vm_flags;
	struct mem_cgroup___31 *memcg;
};

struct make_exclusive_args {
	struct mm_struct___79 *mm;
	long unsigned int address;
	void *owner;
	bool valid;
};

struct dentry___80;

struct super_block___80;

struct module___78;

struct file_system_type___80 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___80 * (*mount)(struct file_system_type___80 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___80 *);
	struct module___78 *owner;
	struct file_system_type___80 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___80;

struct kiocb___80;

struct vm_area_struct___85;

struct inode___80;

struct file_lock___80;

struct page___85;

struct seq_file___76;

struct file_operations___80 {
	struct module___78 *owner;
	loff_t (*llseek)(struct file___80 *, loff_t, int);
	ssize_t (*read)(struct file___80 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___80 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___80 *, struct iov_iter___48 *);
	ssize_t (*write_iter)(struct kiocb___80 *, struct iov_iter___48 *);
	int (*iopoll)(struct kiocb___80 *, bool);
	int (*iterate)(struct file___80 *, struct dir_context *);
	int (*iterate_shared)(struct file___80 *, struct dir_context *);
	__poll_t (*poll)(struct file___80 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___80 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___80 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___80 *, struct vm_area_struct___85 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___80 *, struct file___80 *);
	int (*flush)(struct file___80 *, fl_owner_t);
	int (*release)(struct inode___80 *, struct file___80 *);
	int (*fsync)(struct file___80 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___80 *, int);
	int (*lock)(struct file___80 *, int, struct file_lock___80 *);
	ssize_t (*sendpage)(struct file___80 *, struct page___85 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___80 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___80 *, long unsigned int);
	int (*flock)(struct file___80 *, int, struct file_lock___80 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___80 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___80 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___80 *, long int, struct file_lock___80 **, void **);
	long int (*fallocate)(struct file___80 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___76 *, struct file___80 *);
	ssize_t (*copy_file_range)(struct file___80 *, loff_t, struct file___80 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___80 *, loff_t, struct file___80 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___80 *, loff_t, loff_t, int);
};

struct vmacache___85 {
	u64 seqnum;
	struct vm_area_struct___85 *vmas[4];
};

struct page_frag___85 {
	struct page___85 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___86;

struct pid___73;

struct nsproxy___78;

struct signal_struct___81;

struct capture_control___9;

struct css_set___67;

struct vm_struct___81;

struct task_struct___87 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___87 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___86 *mm;
	struct mm_struct___86 *active_mm;
	struct vmacache___85 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___87 *real_parent;
	struct task_struct___87 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___87 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___73 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___78 *nsproxy;
	struct signal_struct___81 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___87 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___38 *io_context;
	struct capture_control___9 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___67 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___85 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___87 *oom_reaper_list;
	struct vm_struct___81 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___80;

struct kobj_type___80;

struct kernfs_node___80;

struct kobject___80 {
	const char *name;
	struct list_head entry;
	struct kobject___80 *parent;
	struct kset___80 *kset;
	struct kobj_type___80 *ktype;
	struct kernfs_node___80 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___77 {
	struct kobject___80 kobj;
	struct module___78 *mod;
	struct kobject___80 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___77 {
	struct module___78 *mod;
	struct latch_tree_node node;
};

struct module_layout___77 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___77 mtn;
};

struct module_attribute___77;

struct kernel_param___77;

struct module___78 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___77 mkobj;
	struct module_attribute___77 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___80 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___77 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___77 core_layout;
	struct module_layout___77 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___85 *pgtable_t___85;

struct address_space___80;

struct dev_pagemap___79;

struct page___85 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___80 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___85 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___85 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___86 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___79 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_struct___81 {
	struct vm_struct___81 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___85 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct vmap_area {
	long unsigned int va_start;
	long unsigned int va_end;
	struct rb_node rb_node;
	struct list_head list;
	union {
		long unsigned int subtree_max_size;
		struct vm_struct___81 *vm;
	};
};

struct vm_operations_struct___79;

struct vm_area_struct___85 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___85 *vm_next;
	struct vm_area_struct___85 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___86 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___79 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___80 *vm_file;
	struct file___80 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___85;

struct mm_struct___86 {
	struct {
		struct vm_area_struct___85 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___80 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___85 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___87 *owner;
		struct user_namespace___12 *user_ns;
		struct file___80 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___80;

struct address_space___80 {
	struct inode___80 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___80 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___79;

struct dev_pagemap___79 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___79 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___80;

struct path___80 {
	struct vfsmount___80 *mnt;
	struct dentry___80 *dentry;
};

struct fown_struct___73 {
	rwlock_t lock;
	struct pid___73 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___80 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___80 f_path;
	struct inode___80 *f_inode;
	const struct file_operations___80 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___73 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___80 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___79;

struct vm_operations_struct___79 {
	void (*open)(struct vm_area_struct___85 *);
	void (*close)(struct vm_area_struct___85 *);
	int (*may_split)(struct vm_area_struct___85 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___85 *);
	int (*mprotect)(struct vm_area_struct___85 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___79 *);
	vm_fault_t (*huge_fault)(struct vm_fault___79 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___79 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___85 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___79 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___79 *);
	int (*access)(struct vm_area_struct___85 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___85 *);
	int (*set_policy)(struct vm_area_struct___85 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___85 *, long unsigned int);
	struct page___85 * (*find_special_page)(struct vm_area_struct___85 *, long unsigned int);
};

struct core_thread___85 {
	struct task_struct___87 *task;
	struct core_thread___85 *next;
};

struct core_state___85 {
	atomic_t nr_threads;
	struct core_thread___85 dumper;
	struct completion startup;
};

struct vm_fault___79 {
	const struct {
		struct vm_area_struct___85 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___85 *cow_page;
	struct page___85 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___85 prealloc_pte;
};

struct pglist_data___39;

struct lruvec___39 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___39 *pgdat;
};

struct zone___39 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___39 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___39 {
	struct zone___39 *zone;
	int zone_idx;
};

struct zonelist___39 {
	struct zoneref___39 _zonerefs[321];
};

struct pglist_data___39 {
	struct zone___39 node_zones[5];
	struct zonelist___39 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___87 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___87 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___39 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dev_pagemap_ops___79 {
	void (*page_free)(struct page___85 *);
	void (*kill)(struct dev_pagemap___79 *);
	void (*cleanup)(struct dev_pagemap___79 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___79 *);
};

struct pid_namespace___73;

struct upid___73 {
	int nr;
	struct pid_namespace___73 *ns;
};

struct pid_namespace___73 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___87 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___73 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___73 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___73 numbers[1];
};

struct signal_struct___81 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___87 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___87 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___73 *pids[4];
	struct pid___73 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___86 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___67;

struct nsproxy___78 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___73 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___67 *cgroup_ns;
};

struct compact_control___9;

struct capture_control___9 {
	struct compact_control___9 *cc;
	struct page___85 *page;
};

struct cgroup_subsys_state___67;

struct cgroup___67;

struct css_set___67 {
	struct cgroup_subsys_state___67 *subsys[14];
	refcount_t refcount;
	struct css_set___67 *dom_cset;
	struct cgroup___67 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___67 *mg_src_cgrp;
	struct cgroup___67 *mg_dst_cgrp;
	struct css_set___67 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct dentry_operations___80;

struct dentry___80 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___80 *d_parent;
	struct qstr d_name;
	struct inode___80 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___80 *d_op;
	struct super_block___80 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___80;

struct inode___80 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___80 *i_op;
	struct super_block___80 *i_sb;
	struct address_space___80 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___80 *i_fop;
		void (*free_inode)(struct inode___80 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___80 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___80 {
	int (*d_revalidate)(struct dentry___80 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___80 *, unsigned int);
	int (*d_hash)(const struct dentry___80 *, struct qstr *);
	int (*d_compare)(const struct dentry___80 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___80 *);
	int (*d_init)(struct dentry___80 *);
	void (*d_release)(struct dentry___80 *);
	void (*d_prune)(struct dentry___80 *);
	void (*d_iput)(struct dentry___80 *, struct inode___80 *);
	char * (*d_dname)(struct dentry___80 *, char *, int);
	struct vfsmount___80 * (*d_automount)(struct path___80 *);
	int (*d_manage)(const struct path___80 *, bool);
	struct dentry___80 * (*d_real)(struct dentry___80 *, const struct inode___80 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___80;

struct mem_dqinfo___80 {
	struct quota_format_type___80 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___80;

struct quota_info___80 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___80 *files[3];
	struct mem_dqinfo___80 info[3];
	const struct quota_format_ops___80 *ops[3];
};

struct rcuwait___81 {
	struct task_struct___87 *task;
};

struct percpu_rw_semaphore___81 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___81 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___80 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___81 rw_sem[3];
};

struct super_operations___80;

struct dquot_operations___80;

struct quotactl_ops___80;

struct super_block___80 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___80 *s_type;
	const struct super_operations___80 *s_op;
	const struct dquot_operations___80 *dq_op;
	const struct quotactl_ops___80 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___80 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___80 s_dquot;
	struct sb_writers___80 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___80 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___80 {
	struct dentry___80 *mnt_root;
	struct super_block___80 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct cgroup_subsys___67;

struct cgroup_subsys_state___67 {
	struct cgroup___67 *cgroup;
	struct cgroup_subsys___67 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___67 *parent;
};

struct cgroup_file___67 {
	struct kernfs_node___80 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___67 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___87 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___67;

struct cgroup_rstat_cpu___67;

struct cgroup___67 {
	struct cgroup_subsys_state___67 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___80 *kn;
	struct cgroup_file___67 procs_file;
	struct cgroup_file___67 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___67 *subsys[14];
	struct cgroup_root___67 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___67 *dom_cgrp;
	struct cgroup___67 *old_dom_cgrp;
	struct cgroup_rstat_cpu___67 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___67 psi;
	struct cgroup_bpf___18 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___38;

struct kiocb___80 {
	struct file___80 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___80 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___38 *ki_waitq;
	};
};

struct iattr___80 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___80 *ia_file;
};

struct dquot___80 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___80 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___80 {
	int qf_fmt_id;
	const struct quota_format_ops___80 *qf_ops;
	struct module___78 *qf_owner;
	struct quota_format_type___80 *qf_next;
};

struct quota_format_ops___80 {
	int (*check_quota_file)(struct super_block___80 *, int);
	int (*read_file_info)(struct super_block___80 *, int);
	int (*write_file_info)(struct super_block___80 *, int);
	int (*free_file_info)(struct super_block___80 *, int);
	int (*read_dqblk)(struct dquot___80 *);
	int (*commit_dqblk)(struct dquot___80 *);
	int (*release_dqblk)(struct dquot___80 *);
	int (*get_next_id)(struct super_block___80 *, struct kqid *);
};

struct dquot_operations___80 {
	int (*write_dquot)(struct dquot___80 *);
	struct dquot___80 * (*alloc_dquot)(struct super_block___80 *, int);
	void (*destroy_dquot)(struct dquot___80 *);
	int (*acquire_dquot)(struct dquot___80 *);
	int (*release_dquot)(struct dquot___80 *);
	int (*mark_dirty)(struct dquot___80 *);
	int (*write_info)(struct super_block___80 *, int);
	qsize_t * (*get_reserved_space)(struct inode___80 *);
	int (*get_projid)(struct inode___80 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___80 *, qsize_t *);
	int (*get_next_id)(struct super_block___80 *, struct kqid *);
};

struct quotactl_ops___80 {
	int (*quota_on)(struct super_block___80 *, int, int, const struct path___80 *);
	int (*quota_off)(struct super_block___80 *, int);
	int (*quota_enable)(struct super_block___80 *, unsigned int);
	int (*quota_disable)(struct super_block___80 *, unsigned int);
	int (*quota_sync)(struct super_block___80 *, int);
	int (*set_info)(struct super_block___80 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___80 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___80 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___80 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___80 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___80 *, unsigned int);
};

struct wait_page_queue___38 {
	struct page___85 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___38;

struct address_space_operations___80 {
	int (*writepage)(struct page___85 *, struct writeback_control___3 *);
	int (*readpage)(struct file___80 *, struct page___85 *);
	int (*writepages)(struct address_space___80 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___85 *);
	int (*readpages)(struct file___80 *, struct address_space___80 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___38 *);
	int (*write_begin)(struct file___80 *, struct address_space___80 *, loff_t, unsigned int, unsigned int, struct page___85 **, void **);
	int (*write_end)(struct file___80 *, struct address_space___80 *, loff_t, unsigned int, unsigned int, struct page___85 *, void *);
	sector_t (*bmap)(struct address_space___80 *, sector_t);
	void (*invalidatepage)(struct page___85 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___85 *, gfp_t);
	void (*freepage)(struct page___85 *);
	ssize_t (*direct_IO)(struct kiocb___80 *, struct iov_iter___48 *);
	int (*migratepage)(struct address_space___80 *, struct page___85 *, struct page___85 *, enum migrate_mode);
	bool (*isolate_page)(struct page___85 *, isolate_mode_t);
	void (*putback_page)(struct page___85 *);
	int (*launder_page)(struct page___85 *);
	int (*is_partially_uptodate)(struct page___85 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___85 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___80 *, struct page___85 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___80 *, sector_t *);
	void (*swap_deactivate)(struct file___80 *);
};

struct readahead_control___38 {
	struct file___80 *file;
	struct address_space___80 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___80 {
	struct dentry___80 * (*lookup)(struct inode___80 *, struct dentry___80 *, unsigned int);
	const char * (*get_link)(struct dentry___80 *, struct inode___80 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___80 *, int);
	struct posix_acl * (*get_acl)(struct inode___80 *, int, bool);
	int (*readlink)(struct dentry___80 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___80 *, struct dentry___80 *, umode_t, bool);
	int (*link)(struct dentry___80 *, struct inode___80 *, struct dentry___80 *);
	int (*unlink)(struct inode___80 *, struct dentry___80 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___80 *, struct dentry___80 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___80 *, struct dentry___80 *, umode_t);
	int (*rmdir)(struct inode___80 *, struct dentry___80 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___80 *, struct dentry___80 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___80 *, struct dentry___80 *, struct inode___80 *, struct dentry___80 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___80 *, struct iattr___80 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___80 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___80 *, char *, size_t);
	int (*fiemap)(struct inode___80 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___80 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___80 *, struct dentry___80 *, struct file___80 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___80 *, struct dentry___80 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___80 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___80 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___80 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___80 {
	void (*fl_copy_lock)(struct file_lock___80 *, struct file_lock___80 *);
	void (*fl_release_private)(struct file_lock___80 *);
};

struct fasync_struct___80;

struct lock_manager_operations___80;

struct file_lock___80 {
	struct file_lock___80 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___80 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___80 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___80 *fl_ops;
	const struct lock_manager_operations___80 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___80 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___80 *);
	int (*lm_grant)(struct file_lock___80 *, int);
	bool (*lm_break)(struct file_lock___80 *);
	int (*lm_change)(struct file_lock___80 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___80 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___80 *);
};

struct fasync_struct___80 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___80 *fa_next;
	struct file___80 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___80 {
	struct inode___80 * (*alloc_inode)(struct super_block___80 *);
	void (*destroy_inode)(struct inode___80 *);
	void (*free_inode)(struct inode___80 *);
	void (*dirty_inode)(struct inode___80 *, int);
	int (*write_inode)(struct inode___80 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___80 *);
	void (*evict_inode)(struct inode___80 *);
	void (*put_super)(struct super_block___80 *);
	int (*sync_fs)(struct super_block___80 *, int);
	int (*freeze_super)(struct super_block___80 *);
	int (*freeze_fs)(struct super_block___80 *);
	int (*thaw_super)(struct super_block___80 *);
	int (*unfreeze_fs)(struct super_block___80 *);
	int (*statfs)(struct dentry___80 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___80 *, int *, char *);
	void (*umount_begin)(struct super_block___80 *);
	int (*show_options)(struct seq_file___76 *, struct dentry___80 *);
	int (*show_devname)(struct seq_file___76 *, struct dentry___80 *);
	int (*show_path)(struct seq_file___76 *, struct dentry___80 *);
	int (*show_stats)(struct seq_file___76 *, struct dentry___80 *);
	ssize_t (*quota_read)(struct super_block___80 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___80 *, int, const char *, size_t, loff_t);
	struct dquot___80 ** (*get_dquots)(struct inode___80 *);
	long int (*nr_cached_objects)(struct super_block___80 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___80 *, struct shrink_control___35 *);
	struct file___80 * (*real_loop)(struct file___80 *);
};

struct seq_operations___76;

struct seq_file___76 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___76 *op;
	int poll_event;
	const struct file___80 *file;
	void *private;
};

struct kernfs_root___80;

struct kernfs_elem_dir___80 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___80 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___80;

struct kernfs_root___80 {
	struct kernfs_node___80 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___80 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___80 {
	struct kernfs_node___80 *target_kn;
};

struct kernfs_ops___80;

struct kernfs_elem_attr___80 {
	const struct kernfs_ops___80 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___80 *notify_next;
};

struct kernfs_node___80 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___80 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___80 dir;
		struct kernfs_elem_symlink___80 symlink;
		struct kernfs_elem_attr___80 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___80;

struct kernfs_ops___80 {
	int (*open)(struct kernfs_open_file___80 *);
	void (*release)(struct kernfs_open_file___80 *);
	int (*seq_show)(struct seq_file___76 *, void *);
	void * (*seq_start)(struct seq_file___76 *, loff_t *);
	void * (*seq_next)(struct seq_file___76 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___76 *, void *);
	ssize_t (*read)(struct kernfs_open_file___80 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___80 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___80 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___80 *, struct vm_area_struct___85 *);
};

struct kernfs_syscall_ops___80 {
	int (*show_options)(struct seq_file___76 *, struct kernfs_root___80 *);
	int (*mkdir)(struct kernfs_node___80 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___80 *);
	int (*rename)(struct kernfs_node___80 *, struct kernfs_node___80 *, const char *);
	int (*show_path)(struct seq_file___76 *, struct kernfs_node___80 *, struct kernfs_root___80 *);
};

struct kernfs_open_file___80 {
	struct kernfs_node___80 *kn;
	struct file___80 *file;
	struct seq_file___76 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___79 *vm_ops;
};

struct bin_attribute___80;

struct attribute_group___80 {
	const char *name;
	umode_t (*is_visible)(struct kobject___80 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___80 *, struct bin_attribute___80 *, int);
	struct attribute **attrs;
	struct bin_attribute___80 **bin_attrs;
};

struct bin_attribute___80 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___80 * (*f_mapping)();
	ssize_t (*read)(struct file___80 *, struct kobject___80 *, struct bin_attribute___80 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___80 *, struct kobject___80 *, struct bin_attribute___80 *, char *, loff_t, size_t);
	int (*mmap)(struct file___80 *, struct kobject___80 *, struct bin_attribute___80 *, struct vm_area_struct___85 *);
};

struct sysfs_ops___80 {
	ssize_t (*show)(struct kobject___80 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___80 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___80;

struct kset___80 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___80 kobj;
	const struct kset_uevent_ops___80 *uevent_ops;
};

struct kobj_type___80 {
	void (*release)(struct kobject___80 *);
	const struct sysfs_ops___80 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___80 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___80 *);
	const void * (*namespace)(struct kobject___80 *);
	void (*get_ownership)(struct kobject___80 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___80 {
	int (* const filter)(struct kset___80 *, struct kobject___80 *);
	const char * (* const name)(struct kset___80 *, struct kobject___80 *);
	int (* const uevent)(struct kset___80 *, struct kobject___80 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___77 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___77 *);
	int (*get)(char *, const struct kernel_param___77 *);
	void (*free)(void *);
};

struct kparam_array___77;

struct kernel_param___77 {
	const char *name;
	struct module___78 *mod;
	const struct kernel_param_ops___77 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___77 *arr;
	};
};

struct kparam_array___77 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___77 *ops;
	void *elem;
};

struct module_attribute___77 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___77 *, struct module_kobject___77 *, char *);
	ssize_t (*store)(struct module_attribute___77 *, struct module_kobject___77 *, const char *, size_t);
	void (*setup)(struct module___78 *, const char *);
	int (*test)(struct module___78 *);
	void (*free)(struct module___78 *);
};

struct cgroup_namespace___67 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___67 *root_cset;
};

struct seq_operations___76 {
	void * (*start)(struct seq_file___76 *, loff_t *);
	void (*stop)(struct seq_file___76 *, void *);
	void * (*next)(struct seq_file___76 *, void *, loff_t *);
	int (*show)(struct seq_file___76 *, void *);
};

struct cftype___67;

struct cgroup_subsys___67 {
	struct cgroup_subsys_state___67 * (*css_alloc)(struct cgroup_subsys_state___67 *);
	int (*css_online)(struct cgroup_subsys_state___67 *);
	void (*css_offline)(struct cgroup_subsys_state___67 *);
	void (*css_released)(struct cgroup_subsys_state___67 *);
	void (*css_free)(struct cgroup_subsys_state___67 *);
	void (*css_reset)(struct cgroup_subsys_state___67 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___67 *, int);
	int (*css_extra_stat_show)(struct seq_file___76 *, struct cgroup_subsys_state___67 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___87 *, struct css_set___67 *);
	void (*cancel_fork)(struct task_struct___87 *, struct css_set___67 *);
	void (*fork)(struct task_struct___87 *);
	void (*exit)(struct task_struct___87 *);
	void (*release)(struct task_struct___87 *);
	void (*bind)(struct cgroup_subsys_state___67 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___67 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___67 *dfl_cftypes;
	struct cftype___67 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___67 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___67 *updated_children;
	struct cgroup___67 *updated_next;
};

struct cgroup_root___67 {
	struct kernfs_root___80 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___67 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___67 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___67 *ss;
	struct list_head node;
	struct kernfs_ops___80 *kf_ops;
	int (*open)(struct kernfs_open_file___80 *);
	void (*release)(struct kernfs_open_file___80 *);
	u64 (*read_u64)(struct cgroup_subsys_state___67 *, struct cftype___67 *);
	s64 (*read_s64)(struct cgroup_subsys_state___67 *, struct cftype___67 *);
	int (*seq_show)(struct seq_file___76 *, void *);
	void * (*seq_start)(struct seq_file___76 *, loff_t *);
	void * (*seq_next)(struct seq_file___76 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___76 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___67 *, struct cftype___67 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___67 *, struct cftype___67 *, s64);
	ssize_t (*write)(struct kernfs_open_file___80 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___80 *, struct poll_table_struct___5 *);
};

struct compact_control___9 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___39 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct vfree_deferred {
	struct llist_head list;
	struct work_struct wq;
};

enum fit_type {
	NOTHING_FIT = 0,
	FL_FIT_TYPE = 1,
	LE_FIT_TYPE = 2,
	RE_FIT_TYPE = 3,
	NE_FIT_TYPE = 4,
};

struct vmap_block_queue {
	spinlock_t lock;
	struct list_head free;
};

struct vmap_block {
	spinlock_t lock;
	struct vmap_area *va;
	long unsigned int free;
	long unsigned int dirty;
	long unsigned int dirty_min;
	long unsigned int dirty_max;
	struct list_head free_list;
	struct callback_head callback_head;
	struct list_head purge;
};

struct page_frag_cache {
	void *va;
	__u16 offset;
	__u16 size;
	unsigned int pagecnt_bias;
	bool pfmemalloc;
};

typedef void compound_page_dtor___3(struct page___80 *);

struct oom_control___2 {
	struct zonelist___34 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___33 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___82 *chosen;
	long int chosen_points;
	enum oom_constraint constraint;
};

typedef struct page___80 *new_page_t___4(struct page___80 *, long unsigned int);

typedef void free_page_t___4(struct page___80 *, long unsigned int);

struct alloc_context___2 {
	struct zonelist___34 *zonelist;
	nodemask_t *nodemask;
	struct zoneref___34 *preferred_zoneref;
	int migratetype;
	enum zone_type highest_zoneidx;
	bool spread_dirty_pages;
};

enum mminit_level {
	MMINIT_WARNING = 0,
	MMINIT_VERIFY = 1,
	MMINIT_TRACE = 2,
};

typedef int fpi_t;

struct pagesets {
	local_lock_t lock;
};

struct pcpu_drain {
	struct zone___34 *zone;
	struct work_struct work;
};

struct mminit_pfnnid_cache {
	long unsigned int last_start;
	long unsigned int last_end;
	int last_nid;
};

struct dentry___81;

struct super_block___81;

struct module___79;

struct file_system_type___81 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___81 * (*mount)(struct file_system_type___81 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___81 *);
	struct module___79 *owner;
	struct file_system_type___81 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___81;

struct kiocb___81;

struct vm_area_struct___86;

struct inode___81;

struct file_lock___81;

struct page___86;

struct file_operations___81 {
	struct module___79 *owner;
	loff_t (*llseek)(struct file___81 *, loff_t, int);
	ssize_t (*read)(struct file___81 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___81 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___81 *, struct iov_iter___48 *);
	ssize_t (*write_iter)(struct kiocb___81 *, struct iov_iter___48 *);
	int (*iopoll)(struct kiocb___81 *, bool);
	int (*iterate)(struct file___81 *, struct dir_context *);
	int (*iterate_shared)(struct file___81 *, struct dir_context *);
	__poll_t (*poll)(struct file___81 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___81 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___81 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___81 *, struct vm_area_struct___86 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___81 *, struct file___81 *);
	int (*flush)(struct file___81 *, fl_owner_t);
	int (*release)(struct inode___81 *, struct file___81 *);
	int (*fsync)(struct file___81 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___81 *, int);
	int (*lock)(struct file___81 *, int, struct file_lock___81 *);
	ssize_t (*sendpage)(struct file___81 *, struct page___86 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___81 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___81 *, long unsigned int);
	int (*flock)(struct file___81 *, int, struct file_lock___81 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___81 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___81 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___81 *, long int, struct file_lock___81 **, void **);
	long int (*fallocate)(struct file___81 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___81 *);
	ssize_t (*copy_file_range)(struct file___81 *, loff_t, struct file___81 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___81 *, loff_t, struct file___81 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___81 *, loff_t, loff_t, int);
};

struct vmacache___86 {
	u64 seqnum;
	struct vm_area_struct___86 *vmas[4];
};

struct page_frag___86 {
	struct page___86 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___87;

struct pid___74;

struct nsproxy___79;

struct signal_struct___82;

struct capture_control___10;

struct vm_struct___82;

struct task_struct___88 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___88 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___87 *mm;
	struct mm_struct___87 *active_mm;
	struct vmacache___86 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___88 *real_parent;
	struct task_struct___88 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___88 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___74 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___79 *nsproxy;
	struct signal_struct___82 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___88 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___38 *io_context;
	struct capture_control___10 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___86 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___88 *oom_reaper_list;
	struct vm_struct___82 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___81;

struct kobj_type___81;

struct kernfs_node___81;

struct kobject___81 {
	const char *name;
	struct list_head entry;
	struct kobject___81 *parent;
	struct kset___81 *kset;
	struct kobj_type___81 *ktype;
	struct kernfs_node___81 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___78 {
	struct kobject___81 kobj;
	struct module___79 *mod;
	struct kobject___81 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___78 {
	struct module___79 *mod;
	struct latch_tree_node node;
};

struct module_layout___78 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___78 mtn;
};

struct module_attribute___78;

struct kernel_param___78;

struct module___79 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___78 mkobj;
	struct module_attribute___78 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___81 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___78 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___78 core_layout;
	struct module_layout___78 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___86 *pgtable_t___86;

struct address_space___81;

struct dev_pagemap___80;

struct page___86 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___81 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___27 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___86 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___86 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___87 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___80 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___80;

struct vm_area_struct___86 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___86 *vm_next;
	struct vm_area_struct___86 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___87 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___80 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___81 *vm_file;
	struct file___81 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___86;

struct mm_struct___87 {
	struct {
		struct vm_area_struct___86 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___81 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___86 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___88 *owner;
		struct user_namespace *user_ns;
		struct file___81 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___81;

struct address_space___81 {
	struct inode___81 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___81 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___80;

struct dev_pagemap___80 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___80 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___81;

struct path___81 {
	struct vfsmount___81 *mnt;
	struct dentry___81 *dentry;
};

struct fown_struct___74 {
	rwlock_t lock;
	struct pid___74 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___81 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___81 f_path;
	struct inode___81 *f_inode;
	const struct file_operations___81 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___74 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___81 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___80;

struct vm_operations_struct___80 {
	void (*open)(struct vm_area_struct___86 *);
	void (*close)(struct vm_area_struct___86 *);
	int (*may_split)(struct vm_area_struct___86 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___86 *);
	int (*mprotect)(struct vm_area_struct___86 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___80 *);
	vm_fault_t (*huge_fault)(struct vm_fault___80 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___80 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___86 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___80 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___80 *);
	int (*access)(struct vm_area_struct___86 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___86 *);
	int (*set_policy)(struct vm_area_struct___86 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___86 *, long unsigned int);
	struct page___86 * (*find_special_page)(struct vm_area_struct___86 *, long unsigned int);
};

struct core_thread___86 {
	struct task_struct___88 *task;
	struct core_thread___86 *next;
};

struct core_state___86 {
	atomic_t nr_threads;
	struct core_thread___86 dumper;
	struct completion startup;
};

struct vm_fault___80 {
	const struct {
		struct vm_area_struct___86 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___86 *cow_page;
	struct page___86 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___86 prealloc_pte;
};

struct pglist_data___40;

struct lruvec___40 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___40 *pgdat;
};

struct zone___40 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___40 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___40 {
	struct zone___40 *zone;
	int zone_idx;
};

struct zonelist___40 {
	struct zoneref___40 _zonerefs[321];
};

struct pglist_data___40 {
	struct zone___40 node_zones[5];
	struct zonelist___40 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___88 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___88 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___40 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___40 pg_data_t___8;

struct dev_pagemap_ops___80 {
	void (*page_free)(struct page___86 *);
	void (*kill)(struct dev_pagemap___80 *);
	void (*cleanup)(struct dev_pagemap___80 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___80 *);
};

struct pid_namespace___74;

struct upid___74 {
	int nr;
	struct pid_namespace___74 *ns;
};

struct pid_namespace___74 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___88 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___74 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___74 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___74 numbers[1];
};

struct signal_struct___82 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___88 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___88 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___74 *pids[4];
	struct pid___74 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___87 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___79 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___74 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct compact_control___10;

struct capture_control___10 {
	struct compact_control___10 *cc;
	struct page___86 *page;
};

struct vm_struct___82 {
	struct vm_struct___82 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___86 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___81;

struct dentry___81 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___81 *d_parent;
	struct qstr d_name;
	struct inode___81 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___81 *d_op;
	struct super_block___81 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___81;

struct inode___81 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___81 *i_op;
	struct super_block___81 *i_sb;
	struct address_space___81 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___81 *i_fop;
		void (*free_inode)(struct inode___81 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___81 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___32 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___81 {
	int (*d_revalidate)(struct dentry___81 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___81 *, unsigned int);
	int (*d_hash)(const struct dentry___81 *, struct qstr *);
	int (*d_compare)(const struct dentry___81 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___81 *);
	int (*d_init)(struct dentry___81 *);
	void (*d_release)(struct dentry___81 *);
	void (*d_prune)(struct dentry___81 *);
	void (*d_iput)(struct dentry___81 *, struct inode___81 *);
	char * (*d_dname)(struct dentry___81 *, char *, int);
	struct vfsmount___81 * (*d_automount)(struct path___81 *);
	int (*d_manage)(const struct path___81 *, bool);
	struct dentry___81 * (*d_real)(struct dentry___81 *, const struct inode___81 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___81;

struct mem_dqinfo___81 {
	struct quota_format_type___81 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___81;

struct quota_info___81 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___81 *files[3];
	struct mem_dqinfo___81 info[3];
	const struct quota_format_ops___81 *ops[3];
};

struct rcuwait___82 {
	struct task_struct___88 *task;
};

struct percpu_rw_semaphore___82 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___82 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___81 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___82 rw_sem[3];
};

struct super_operations___81;

struct dquot_operations___81;

struct quotactl_ops___81;

struct super_block___81 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___81 *s_type;
	const struct super_operations___81 *s_op;
	const struct dquot_operations___81 *dq_op;
	const struct quotactl_ops___81 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___81 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___81 s_dquot;
	struct sb_writers___81 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___81 *s_d_op;
	int cleancache_poolid;
	struct shrinker___35 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___81 {
	struct dentry___81 *mnt_root;
	struct super_block___81 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___39;

struct kiocb___81 {
	struct file___81 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___81 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___39 *ki_waitq;
	};
};

struct iattr___81 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___81 *ia_file;
};

struct dquot___81 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___81 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___81 {
	int qf_fmt_id;
	const struct quota_format_ops___81 *qf_ops;
	struct module___79 *qf_owner;
	struct quota_format_type___81 *qf_next;
};

struct quota_format_ops___81 {
	int (*check_quota_file)(struct super_block___81 *, int);
	int (*read_file_info)(struct super_block___81 *, int);
	int (*write_file_info)(struct super_block___81 *, int);
	int (*free_file_info)(struct super_block___81 *, int);
	int (*read_dqblk)(struct dquot___81 *);
	int (*commit_dqblk)(struct dquot___81 *);
	int (*release_dqblk)(struct dquot___81 *);
	int (*get_next_id)(struct super_block___81 *, struct kqid *);
};

struct dquot_operations___81 {
	int (*write_dquot)(struct dquot___81 *);
	struct dquot___81 * (*alloc_dquot)(struct super_block___81 *, int);
	void (*destroy_dquot)(struct dquot___81 *);
	int (*acquire_dquot)(struct dquot___81 *);
	int (*release_dquot)(struct dquot___81 *);
	int (*mark_dirty)(struct dquot___81 *);
	int (*write_info)(struct super_block___81 *, int);
	qsize_t * (*get_reserved_space)(struct inode___81 *);
	int (*get_projid)(struct inode___81 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___81 *, qsize_t *);
	int (*get_next_id)(struct super_block___81 *, struct kqid *);
};

struct quotactl_ops___81 {
	int (*quota_on)(struct super_block___81 *, int, int, const struct path___81 *);
	int (*quota_off)(struct super_block___81 *, int);
	int (*quota_enable)(struct super_block___81 *, unsigned int);
	int (*quota_disable)(struct super_block___81 *, unsigned int);
	int (*quota_sync)(struct super_block___81 *, int);
	int (*set_info)(struct super_block___81 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___81 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___81 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___81 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___81 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___81 *, unsigned int);
};

struct wait_page_queue___39 {
	struct page___86 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___39;

struct address_space_operations___81 {
	int (*writepage)(struct page___86 *, struct writeback_control___3 *);
	int (*readpage)(struct file___81 *, struct page___86 *);
	int (*writepages)(struct address_space___81 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___86 *);
	int (*readpages)(struct file___81 *, struct address_space___81 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___39 *);
	int (*write_begin)(struct file___81 *, struct address_space___81 *, loff_t, unsigned int, unsigned int, struct page___86 **, void **);
	int (*write_end)(struct file___81 *, struct address_space___81 *, loff_t, unsigned int, unsigned int, struct page___86 *, void *);
	sector_t (*bmap)(struct address_space___81 *, sector_t);
	void (*invalidatepage)(struct page___86 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___86 *, gfp_t);
	void (*freepage)(struct page___86 *);
	ssize_t (*direct_IO)(struct kiocb___81 *, struct iov_iter___48 *);
	int (*migratepage)(struct address_space___81 *, struct page___86 *, struct page___86 *, enum migrate_mode);
	bool (*isolate_page)(struct page___86 *, isolate_mode_t);
	void (*putback_page)(struct page___86 *);
	int (*launder_page)(struct page___86 *);
	int (*is_partially_uptodate)(struct page___86 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___86 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___81 *, struct page___86 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___81 *, sector_t *);
	void (*swap_deactivate)(struct file___81 *);
};

struct readahead_control___39 {
	struct file___81 *file;
	struct address_space___81 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___81 {
	struct dentry___81 * (*lookup)(struct inode___81 *, struct dentry___81 *, unsigned int);
	const char * (*get_link)(struct dentry___81 *, struct inode___81 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___81 *, int);
	struct posix_acl * (*get_acl)(struct inode___81 *, int, bool);
	int (*readlink)(struct dentry___81 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___81 *, struct dentry___81 *, umode_t, bool);
	int (*link)(struct dentry___81 *, struct inode___81 *, struct dentry___81 *);
	int (*unlink)(struct inode___81 *, struct dentry___81 *);
	int (*symlink)(struct user_namespace *, struct inode___81 *, struct dentry___81 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___81 *, struct dentry___81 *, umode_t);
	int (*rmdir)(struct inode___81 *, struct dentry___81 *);
	int (*mknod)(struct user_namespace *, struct inode___81 *, struct dentry___81 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___81 *, struct dentry___81 *, struct inode___81 *, struct dentry___81 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___81 *, struct iattr___81 *);
	int (*getattr)(struct user_namespace *, const struct path___81 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___81 *, char *, size_t);
	int (*fiemap)(struct inode___81 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___81 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___81 *, struct dentry___81 *, struct file___81 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___81 *, struct dentry___81 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___81 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___81 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___81 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___81 {
	void (*fl_copy_lock)(struct file_lock___81 *, struct file_lock___81 *);
	void (*fl_release_private)(struct file_lock___81 *);
};

struct fasync_struct___81;

struct lock_manager_operations___81;

struct file_lock___81 {
	struct file_lock___81 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___81 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___81 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___81 *fl_ops;
	const struct lock_manager_operations___81 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___81 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___81 *);
	int (*lm_grant)(struct file_lock___81 *, int);
	bool (*lm_break)(struct file_lock___81 *);
	int (*lm_change)(struct file_lock___81 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___81 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___81 *);
};

struct fasync_struct___81 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___81 *fa_next;
	struct file___81 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___81 {
	struct inode___81 * (*alloc_inode)(struct super_block___81 *);
	void (*destroy_inode)(struct inode___81 *);
	void (*free_inode)(struct inode___81 *);
	void (*dirty_inode)(struct inode___81 *, int);
	int (*write_inode)(struct inode___81 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___81 *);
	void (*evict_inode)(struct inode___81 *);
	void (*put_super)(struct super_block___81 *);
	int (*sync_fs)(struct super_block___81 *, int);
	int (*freeze_super)(struct super_block___81 *);
	int (*freeze_fs)(struct super_block___81 *);
	int (*thaw_super)(struct super_block___81 *);
	int (*unfreeze_fs)(struct super_block___81 *);
	int (*statfs)(struct dentry___81 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___81 *, int *, char *);
	void (*umount_begin)(struct super_block___81 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___81 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___81 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___81 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___81 *);
	ssize_t (*quota_read)(struct super_block___81 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___81 *, int, const char *, size_t, loff_t);
	struct dquot___81 ** (*get_dquots)(struct inode___81 *);
	long int (*nr_cached_objects)(struct super_block___81 *, struct shrink_control___35 *);
	long int (*free_cached_objects)(struct super_block___81 *, struct shrink_control___35 *);
	struct file___81 * (*real_loop)(struct file___81 *);
};

struct kernel_param_ops___78 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___78 *);
	int (*get)(char *, const struct kernel_param___78 *);
	void (*free)(void *);
};

struct kparam_array___78;

struct kernel_param___78 {
	const char *name;
	struct module___79 *mod;
	const struct kernel_param_ops___78 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___78 *arr;
	};
};

struct kparam_array___78 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___78 *ops;
	void *elem;
};

struct kernfs_root___81;

struct kernfs_elem_dir___81 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___81 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___81;

struct kernfs_root___81 {
	struct kernfs_node___81 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___81 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___81 {
	struct kernfs_node___81 *target_kn;
};

struct kernfs_ops___81;

struct kernfs_elem_attr___81 {
	const struct kernfs_ops___81 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___81 *notify_next;
};

struct kernfs_node___81 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___81 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___81 dir;
		struct kernfs_elem_symlink___81 symlink;
		struct kernfs_elem_attr___81 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___81;

struct kernfs_ops___81 {
	int (*open)(struct kernfs_open_file___81 *);
	void (*release)(struct kernfs_open_file___81 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___81 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___81 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___81 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___81 *, struct vm_area_struct___86 *);
};

struct kernfs_syscall_ops___81 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___81 *);
	int (*mkdir)(struct kernfs_node___81 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___81 *);
	int (*rename)(struct kernfs_node___81 *, struct kernfs_node___81 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___81 *, struct kernfs_root___81 *);
};

struct kernfs_open_file___81 {
	struct kernfs_node___81 *kn;
	struct file___81 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___80 *vm_ops;
};

struct bin_attribute___81;

struct attribute_group___81 {
	const char *name;
	umode_t (*is_visible)(struct kobject___81 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___81 *, struct bin_attribute___81 *, int);
	struct attribute **attrs;
	struct bin_attribute___81 **bin_attrs;
};

struct bin_attribute___81 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___81 * (*f_mapping)();
	ssize_t (*read)(struct file___81 *, struct kobject___81 *, struct bin_attribute___81 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___81 *, struct kobject___81 *, struct bin_attribute___81 *, char *, loff_t, size_t);
	int (*mmap)(struct file___81 *, struct kobject___81 *, struct bin_attribute___81 *, struct vm_area_struct___86 *);
};

struct sysfs_ops___81 {
	ssize_t (*show)(struct kobject___81 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___81 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___81;

struct kset___81 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___81 kobj;
	const struct kset_uevent_ops___81 *uevent_ops;
};

struct kobj_type___81 {
	void (*release)(struct kobject___81 *);
	const struct sysfs_ops___81 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___81 **default_groups;
	const struct kobj_ns_type_operations___11 * (*child_ns_type)(struct kobject___81 *);
	const void * (*namespace)(struct kobject___81 *);
	void (*get_ownership)(struct kobject___81 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___81 {
	int (* const filter)(struct kset___81 *, struct kobject___81 *);
	const char * (* const name)(struct kset___81 *, struct kobject___81 *);
	int (* const uevent)(struct kset___81 *, struct kobject___81 *, struct kobj_uevent_env *);
};

struct module_attribute___78 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___78 *, struct module_kobject___78 *, char *);
	ssize_t (*store)(struct module_attribute___78 *, struct module_kobject___78 *, const char *, size_t);
	void (*setup)(struct module___79 *, const char *);
	int (*test)(struct module___79 *);
	void (*free)(struct module___79 *);
};

struct compact_control___10 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___40 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

typedef struct pglist_data___39 pg_data_t___9;

enum {
	MMOP_OFFLINE = 0,
	MMOP_ONLINE = 1,
	MMOP_ONLINE_KERNEL = 2,
	MMOP_ONLINE_MOVABLE = 3,
};

typedef int mhp_t;

typedef void (*online_page_callback_t)(struct page___80 *, unsigned int);

struct memory_group {
	int nid;
	struct list_head memory_blocks;
	long unsigned int present_kernel_pages;
	long unsigned int present_movable_pages;
	bool is_dynamic;
	union {
		struct {
			long unsigned int max_pages;
		} s;
		struct {
			long unsigned int unit_pages;
		} d;
	};
};

struct memory_block {
	long unsigned int start_section_nr;
	long unsigned int state;
	int online_type;
	int nid;
	struct device___67 dev;
	long unsigned int nr_vmemmap_pages;
	struct memory_group *group;
	struct list_head group_next;
};

typedef int (*walk_memory_blocks_func_t)(struct memory_block *, void *);

typedef int (*walk_memory_groups_func_t)(struct memory_group *, void *);

enum hugetlb_page_flags {
	HPG_restore_reserve = 0,
	HPG_migratable = 1,
	HPG_temporary = 2,
	HPG_freed = 3,
	HPG_vmemmap_optimized = 4,
	__NR_HPAGEFLAGS = 5,
};

enum {
	ONLINE_POLICY_CONTIG_ZONES = 0,
	ONLINE_POLICY_AUTO_MOVABLE = 1,
};

struct auto_movable_stats {
	long unsigned int kernel_early_pages;
	long unsigned int movable_pages;
};

struct auto_movable_group_stats {
	long unsigned int movable_pages;
	long unsigned int req_kernel_early_pages;
};

enum mf_flags {
	MF_COUNT_INCREASED = 1,
	MF_ACTION_REQUIRED = 2,
	MF_MUST_KILL = 4,
	MF_SOFT_OFFLINE = 8,
};

struct mmu_notifier_range___9 {
	struct vm_area_struct___80 *vma;
	struct mm_struct___81 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct madvise_walk_private {
	struct mmu_gather___2 *tlb;
	bool pageout;
};

enum {
	BIO_NO_PAGE_REF = 0,
	BIO_CLONED = 1,
	BIO_BOUNCED = 2,
	BIO_WORKINGSET = 3,
	BIO_QUIET = 4,
	BIO_CHAIN = 5,
	BIO_REFFED = 6,
	BIO_THROTTLED = 7,
	BIO_TRACE_COMPLETION = 8,
	BIO_CGROUP_ACCT = 9,
	BIO_TRACKED = 10,
	BIO_REMAPPED = 11,
	BIO_ZONE_WRITE_LOCKED = 12,
	BIO_PERCPU_CACHE = 13,
	BIO_FLAG_LAST = 14,
};

struct vma_swap_readahead {
	short unsigned int win;
	short unsigned int offset;
	short unsigned int nr_pte;
	pte_t *ptes;
};

enum {
	PERCPU_REF_INIT_ATOMIC = 1,
	PERCPU_REF_INIT_DEAD = 2,
	PERCPU_REF_ALLOW_REINIT = 4,
};

typedef int filler_t___2(void *, struct page___80 *);

union swap_header {
	struct {
		char reserved[4086];
		char magic[10];
	} magic;
	struct {
		char bootbits[1024];
		__u32 version;
		__u32 last_page;
		__u32 nr_badpages;
		unsigned char sws_uuid[16];
		unsigned char sws_volume[16];
		__u32 padding[117];
		__u32 badpages[1];
	} info;
};

struct swap_extent {
	struct rb_node rb_node;
	long unsigned int start_page;
	long unsigned int nr_pages;
	sector_t start_block;
};

struct proc_ops___7 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___2 *, struct file___75 *);
	ssize_t (*proc_read)(struct file___75 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___75 *, struct iov_iter___46 *);
	ssize_t (*proc_write)(struct file___75 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___75 *, loff_t, int);
	int (*proc_release)(struct inode___2 *, struct file___75 *);
	__poll_t (*proc_poll)(struct file___75 *, struct poll_table_struct___57 *);
	long int (*proc_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___75 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___75 *, struct vm_area_struct___80 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___75 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

typedef struct poll_table_struct___57 poll_table___14;

struct swap_slots_cache {
	bool lock_initialized;
	struct mutex alloc_lock;
	swp_entry_t *slots;
	int nr;
	int cur;
	spinlock_t free_lock;
	swp_entry_t *slots_ret;
	int n_ret;
};

struct frontswap_ops {
	void (*init)(unsigned int);
	int (*store)(unsigned int, long unsigned int, struct page___78 *);
	int (*load)(unsigned int, long unsigned int, struct page___78 *);
	void (*invalidate_page)(unsigned int, long unsigned int);
	void (*invalidate_area)(unsigned int);
	struct frontswap_ops *next;
};

struct frontswap_ops___2 {
	void (*init)(unsigned int);
	int (*store)(unsigned int, long unsigned int, struct page___80 *);
	int (*load)(unsigned int, long unsigned int, struct page___80 *);
	void (*invalidate_page)(unsigned int, long unsigned int);
	void (*invalidate_area)(unsigned int);
	struct frontswap_ops___2 *next;
};

struct crypto_async_request;

typedef void (*crypto_completion_t)(struct crypto_async_request *, int);

struct crypto_tfm___3;

struct crypto_async_request {
	struct list_head list;
	crypto_completion_t complete;
	void *data;
	struct crypto_tfm___3 *tfm;
	u32 flags;
};

struct crypto_alg___3;

struct crypto_tfm___3 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___3 *);
	struct crypto_alg___3 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___2 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___3 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___3 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___3 *, u8 *, const u8 *);
};

struct compress_alg___2 {
	int (*coa_compress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___3 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___3 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___2 cipher;
		struct compress_alg___2 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___3 *);
	void (*cra_exit)(struct crypto_tfm___3 *);
	void (*cra_destroy)(struct crypto_alg___3 *);
	struct module___73 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_wait {
	struct completion completion;
	int err;
};

struct zpool;

struct zpool_ops {
	int (*evict)(struct zpool *, long unsigned int);
};

enum zpool_mapmode {
	ZPOOL_MM_RW = 0,
	ZPOOL_MM_RO = 1,
	ZPOOL_MM_WO = 2,
	ZPOOL_MM_DEFAULT = 0,
};

struct acomp_req {
	struct crypto_async_request base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int slen;
	unsigned int dlen;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_acomp {
	int (*compress)(struct acomp_req *);
	int (*decompress)(struct acomp_req *);
	void (*dst_free)(struct scatterlist *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___3 base;
};

struct crypto_acomp_ctx {
	struct crypto_acomp *acomp;
	struct acomp_req *req;
	struct crypto_wait wait;
	u8 *dstmem;
	struct mutex *mutex;
};

struct zswap_pool {
	struct zpool *zpool;
	struct crypto_acomp_ctx *acomp_ctx;
	struct kref kref;
	struct list_head list;
	struct work_struct release_work;
	struct work_struct shrink_work;
	struct hlist_node node;
	char tfm_name[128];
};

struct zswap_entry {
	struct rb_node rbnode;
	long unsigned int offset;
	int refcount;
	unsigned int length;
	struct zswap_pool *pool;
	union {
		long unsigned int handle;
		long unsigned int value;
	};
};

struct zswap_header {
	swp_entry_t swpentry;
};

struct zswap_tree {
	struct rb_root rbroot;
	spinlock_t lock;
};

enum zswap_get_swap_ret {
	ZSWAP_SWAPCACHE_NEW = 0,
	ZSWAP_SWAPCACHE_EXIST = 1,
	ZSWAP_SWAPCACHE_FAIL = 2,
};

typedef void (*dr_release_t___5)(struct device___65 *, void *);

typedef int (*dr_match_t___4)(struct device___65 *, void *, void *);

struct dma_pool {
	struct list_head page_list;
	spinlock_t lock;
	size_t size;
	struct device___65 *dev;
	size_t allocation;
	size_t boundary;
	char name[32];
	struct list_head pools;
};

struct dma_page {
	struct list_head page_list;
	void *vaddr;
	dma_addr_t dma;
	unsigned int in_use;
	unsigned int offset;
};

struct kobj_attribute___7 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___73 *, struct kobj_attribute___7 *, char *);
	ssize_t (*store)(struct kobject___73 *, struct kobj_attribute___7 *, const char *, size_t);
};

enum string_size_units {
	STRING_UNITS_10 = 0,
	STRING_UNITS_2 = 1,
};

struct node___3 {
	struct device___65 dev;
	struct list_head access_list;
	struct work_struct node_work;
	struct list_head cache_attrs;
	struct device___65 *cache_dev;
};

typedef void (*node_registration_func_t)(struct node___3 *);

enum mcopy_atomic_mode {
	MCOPY_ATOMIC_NORMAL = 0,
	MCOPY_ATOMIC_ZEROPAGE = 1,
	MCOPY_ATOMIC_CONTINUE = 2,
};

enum {
	SUBPAGE_INDEX_SUBPOOL = 1,
	SUBPAGE_INDEX_CGROUP = 2,
	SUBPAGE_INDEX_CGROUP_RSVD = 3,
	__MAX_CGROUP_SUBPAGE_INDEX = 3,
	__NR_USED_SUBPAGE = 4,
};

struct hugepage_subpool___4 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___5 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct resv_map {
	struct kref refs;
	spinlock_t lock;
	struct list_head regions;
	long int adds_in_progress;
	struct list_head region_cache;
	long int region_cache_count;
	struct page_counter *reservation_counter;
	long unsigned int pages_per_hpage;
	struct cgroup_subsys_state___61 *css;
};

struct file_region {
	struct list_head link;
	long int from;
	long int to;
	struct page_counter *reservation_counter;
	struct cgroup_subsys_state___61 *css;
};

struct hugetlbfs_sb_info___4 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___5 *hstate;
	struct hugepage_subpool___4 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct huge_bootmem_page {
	struct list_head list;
	struct hstate___5 *hstate;
};

enum hugetlb_memory_event {
	HUGETLB_MAX = 0,
	HUGETLB_NR_MEMORY_EVENTS = 1,
};

struct hugetlb_cgroup {
	struct cgroup_subsys_state___61 css;
	struct page_counter hugepage[4];
	struct page_counter rsvd_hugepage[4];
	atomic_long_t events[4];
	atomic_long_t events_local[4];
	struct cgroup_file___61 events_file[4];
	struct cgroup_file___61 events_local_file[4];
};

enum vma_resv_mode {
	VMA_NEEDS_RESV = 0,
	VMA_COMMIT_RESV = 1,
	VMA_END_RESV = 2,
	VMA_ADD_RESV = 3,
	VMA_DEL_RESV = 4,
};

struct node_hstate {
	struct kobject___73 *hugepages_kobj;
	struct kobject___73 *hstate_kobjs[4];
};

struct nodemask_scratch {
	nodemask_t mask1;
	nodemask_t mask2;
};

struct sp_node {
	struct rb_node nd;
	long unsigned int start;
	long unsigned int end;
	struct mempolicy *policy;
};

struct mempolicy_operations {
	int (*create)(struct mempolicy *, const nodemask_t *);
	void (*rebind)(struct mempolicy *, const nodemask_t *);
};

struct queue_pages {
	struct list_head *pagelist;
	long unsigned int flags;
	nodemask_t *nmask;
	long unsigned int start;
	long unsigned int end;
	struct vm_area_struct___80 *first;
};

struct vmemmap_remap_walk {
	void (*remap_pte)(pte_t *, long unsigned int, struct vmemmap_remap_walk *);
	long unsigned int nr_walked;
	struct page___86 *reuse_page;
	long unsigned int reuse_addr;
	struct list_head *vmemmap_pages;
};

struct mmu_notifier_subscriptions {
	struct hlist_head list;
	bool has_itree;
	spinlock_t lock;
	long unsigned int invalidate_seq;
	long unsigned int active_invalidate_ranges;
	struct rb_root_cached itree;
	wait_queue_head_t wq;
	struct hlist_head deferred_list;
};

struct interval_tree_node {
	struct rb_node rb;
	long unsigned int start;
	long unsigned int last;
	long unsigned int __subtree_last;
};

struct mmu_notifier___7;

struct mmu_notifier_range___10;

struct mmu_notifier_ops___7 {
	void (*release)(struct mmu_notifier___7 *, struct mm_struct___86 *);
	int (*clear_flush_young)(struct mmu_notifier___7 *, struct mm_struct___86 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___7 *, struct mm_struct___86 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___7 *, struct mm_struct___86 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___7 *, struct mm_struct___86 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___7 *, const struct mmu_notifier_range___10 *);
	void (*invalidate_range_end)(struct mmu_notifier___7 *, const struct mmu_notifier_range___10 *);
	void (*invalidate_range)(struct mmu_notifier___7 *, struct mm_struct___86 *, long unsigned int, long unsigned int);
	struct mmu_notifier___7 * (*alloc_notifier)(struct mm_struct___86 *);
	void (*free_notifier)(struct mmu_notifier___7 *);
};

struct mmu_notifier___7 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___7 *ops;
	struct mm_struct___86 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___10 {
	struct vm_area_struct___85 *vma;
	struct mm_struct___86 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct mmu_interval_notifier;

struct mmu_interval_notifier_ops {
	bool (*invalidate)(struct mmu_interval_notifier *, const struct mmu_notifier_range___10 *, long unsigned int);
};

struct mmu_interval_notifier {
	struct interval_tree_node interval_tree;
	const struct mmu_interval_notifier_ops *ops;
	struct mm_struct___86 *mm;
	struct hlist_node deferred_item;
	long unsigned int invalidate_seq;
};

struct rmap_item;

struct mm_slot {
	struct hlist_node link;
	struct list_head mm_list;
	struct rmap_item *rmap_list;
	struct mm_struct___79 *mm;
};

struct stable_node;

struct rmap_item {
	struct rmap_item *rmap_list;
	union {
		struct anon_vma *anon_vma;
		int nid;
	};
	struct mm_struct___79 *mm;
	long unsigned int address;
	unsigned int oldchecksum;
	union {
		struct rb_node node;
		struct {
			struct stable_node *head;
			struct hlist_node hlist;
		};
	};
};

struct ksm_scan {
	struct mm_slot *mm_slot;
	long unsigned int address;
	struct rmap_item **rmap_list;
	long unsigned int seqnr;
};

struct stable_node {
	union {
		struct rb_node node;
		struct {
			struct list_head *head;
			struct {
				struct hlist_node hlist_dup;
				struct list_head list;
			};
		};
	};
	struct hlist_head hlist;
	union {
		long unsigned int kpfn;
		long unsigned int chain_prune_time;
	};
	int rmap_hlist_len;
	int nid;
};

enum get_ksm_page_flags {
	GET_KSM_PAGE_NOLOCK = 0,
	GET_KSM_PAGE_LOCK = 1,
	GET_KSM_PAGE_TRYLOCK = 2,
};

enum stat_item {
	ALLOC_FASTPATH = 0,
	ALLOC_SLOWPATH = 1,
	FREE_FASTPATH = 2,
	FREE_SLOWPATH = 3,
	FREE_FROZEN = 4,
	FREE_ADD_PARTIAL = 5,
	FREE_REMOVE_PARTIAL = 6,
	ALLOC_FROM_PARTIAL = 7,
	ALLOC_SLAB = 8,
	ALLOC_REFILL = 9,
	ALLOC_NODE_MISMATCH = 10,
	FREE_SLAB = 11,
	CPUSLAB_FLUSH = 12,
	DEACTIVATE_FULL = 13,
	DEACTIVATE_EMPTY = 14,
	DEACTIVATE_TO_HEAD = 15,
	DEACTIVATE_TO_TAIL = 16,
	DEACTIVATE_REMOTE_FREES = 17,
	DEACTIVATE_BYPASS = 18,
	ORDER_FALLBACK = 19,
	CMPXCHG_DOUBLE_CPU_FAIL = 20,
	CMPXCHG_DOUBLE_FAIL = 21,
	CPU_PARTIAL_ALLOC = 22,
	CPU_PARTIAL_FREE = 23,
	CPU_PARTIAL_NODE = 24,
	CPU_PARTIAL_DRAIN = 25,
	NR_SLUB_STAT_ITEMS = 26,
};

struct kmem_obj_info___2 {
	void *kp_ptr;
	struct page___78 *kp_page;
	void *kp_objp;
	long unsigned int kp_data_offset;
	struct kmem_cache___2 *kp_slab_cache;
	void *kp_ret;
	void *kp_stack[16];
	void *kp_free_stack[16];
};

struct track {
	long unsigned int addr;
	long unsigned int addrs[16];
	int cpu;
	int pid;
	long unsigned int when;
};

enum track_item {
	TRACK_ALLOC = 0,
	TRACK_FREE = 1,
};

struct slub_flush_work {
	struct work_struct work;
	struct kmem_cache___2 *s;
	bool skip;
};

struct detached_freelist {
	struct page___78 *page;
	void *tail;
	void *freelist;
	int cnt;
	struct kmem_cache___2 *s;
};

struct location {
	long unsigned int count;
	long unsigned int addr;
	long long int sum_time;
	long int min_time;
	long int max_time;
	long int min_pid;
	long int max_pid;
	long unsigned int cpus[4];
	nodemask_t nodes;
};

struct loc_track {
	long unsigned int max;
	long unsigned int count;
	struct location *loc;
	loff_t idx;
};

enum slab_stat_type {
	SL_ALL = 0,
	SL_PARTIAL = 1,
	SL_CPU = 2,
	SL_OBJECTS = 3,
	SL_TOTAL = 4,
};

struct slab_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kmem_cache___2 *, char *);
	ssize_t (*store)(struct kmem_cache___2 *, const char *, size_t);
};

struct saved_alias {
	struct kmem_cache___2 *s;
	const char *name;
	struct saved_alias *next;
};

enum slab_modes {
	M_NONE = 0,
	M_PARTIAL = 1,
	M_FULL = 2,
	M_FREE = 3,
};

struct kcsan_scoped_access {};

enum kfence_object_state {
	KFENCE_OBJECT_UNUSED = 0,
	KFENCE_OBJECT_ALLOCATED = 1,
	KFENCE_OBJECT_FREED = 2,
};

struct kfence_track {
	pid_t pid;
	int cpu;
	u64 ts_nsec;
	int num_stack_entries;
	long unsigned int stack_entries[64];
};

struct kfence_metadata {
	struct list_head list;
	struct callback_head callback_head;
	raw_spinlock_t lock;
	enum kfence_object_state state;
	long unsigned int addr;
	size_t size;
	struct kmem_cache___2 *cache;
	long unsigned int unprotected_page;
	struct kfence_track alloc_track;
	struct kfence_track free_track;
	u32 alloc_stack_hash;
};

enum kfence_error_type {
	KFENCE_ERROR_OOB = 0,
	KFENCE_ERROR_UAF = 1,
	KFENCE_ERROR_CORRUPTION = 2,
	KFENCE_ERROR_INVALID = 3,
	KFENCE_ERROR_INVALID_FREE = 4,
};

enum kfence_counter_id {
	KFENCE_COUNTER_ALLOCATED = 0,
	KFENCE_COUNTER_ALLOCS = 1,
	KFENCE_COUNTER_FREES = 2,
	KFENCE_COUNTER_ZOMBIES = 3,
	KFENCE_COUNTER_BUGS = 4,
	KFENCE_COUNTER_SKIP_INCOMPAT = 5,
	KFENCE_COUNTER_SKIP_CAPACITY = 6,
	KFENCE_COUNTER_SKIP_COVERED = 7,
	KFENCE_COUNTER_COUNT = 8,
};

typedef __kernel_long_t __kernel_ptrdiff_t;

typedef __kernel_ptrdiff_t ptrdiff_t;

struct buffer_head;

typedef void bh_end_io_t(struct buffer_head *, int);

struct buffer_head {
	long unsigned int b_state;
	struct buffer_head *b_this_page;
	struct page___78 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___35 *b_bdev;
	bh_end_io_t *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___73 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

enum migrate_vma_direction {
	MIGRATE_VMA_SELECT_SYSTEM = 1,
	MIGRATE_VMA_SELECT_DEVICE_PRIVATE = 2,
};

struct migrate_vma {
	struct vm_area_struct___78 *vma;
	long unsigned int *dst;
	long unsigned int *src;
	long unsigned int cpages;
	long unsigned int npages;
	long unsigned int start;
	long unsigned int end;
	void *pgmap_owner;
	long unsigned int flags;
};

enum bh_state_bits {
	BH_Uptodate = 0,
	BH_Dirty = 1,
	BH_Lock = 2,
	BH_Req = 3,
	BH_Mapped = 4,
	BH_New = 5,
	BH_Async_Read = 6,
	BH_Async_Write = 7,
	BH_Delay = 8,
	BH_Boundary = 9,
	BH_Write_EIO = 10,
	BH_Unwritten = 11,
	BH_Quiet = 12,
	BH_Meta = 13,
	BH_Prio = 14,
	BH_Defer_Completion = 15,
	BH_PrivateStart = 16,
};

struct trace_event_raw_mm_migrate_pages {
	struct trace_entry ent;
	long unsigned int succeeded;
	long unsigned int failed;
	long unsigned int thp_succeeded;
	long unsigned int thp_failed;
	long unsigned int thp_split;
	enum migrate_mode mode;
	int reason;
	char __data[0];
};

struct trace_event_raw_mm_migrate_pages_start {
	struct trace_entry ent;
	enum migrate_mode mode;
	int reason;
	char __data[0];
};

struct trace_event_data_offsets_mm_migrate_pages {};

struct trace_event_data_offsets_mm_migrate_pages_start {};

typedef void (*btf_trace_mm_migrate_pages)(void *, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, enum migrate_mode, int);

typedef void (*btf_trace_mm_migrate_pages_start)(void *, enum migrate_mode, int);

enum scan_result {
	SCAN_FAIL = 0,
	SCAN_SUCCEED = 1,
	SCAN_PMD_NULL = 2,
	SCAN_EXCEED_NONE_PTE = 3,
	SCAN_EXCEED_SWAP_PTE = 4,
	SCAN_EXCEED_SHARED_PTE = 5,
	SCAN_PTE_NON_PRESENT = 6,
	SCAN_PTE_UFFD_WP = 7,
	SCAN_PAGE_RO = 8,
	SCAN_LACK_REFERENCED_PAGE = 9,
	SCAN_PAGE_NULL = 10,
	SCAN_SCAN_ABORT = 11,
	SCAN_PAGE_COUNT = 12,
	SCAN_PAGE_LRU = 13,
	SCAN_PAGE_LOCK = 14,
	SCAN_PAGE_ANON = 15,
	SCAN_PAGE_COMPOUND = 16,
	SCAN_ANY_PROCESS = 17,
	SCAN_VMA_NULL = 18,
	SCAN_VMA_CHECK = 19,
	SCAN_ADDRESS_RANGE = 20,
	SCAN_SWAP_CACHE_PAGE = 21,
	SCAN_DEL_PAGE_LRU = 22,
	SCAN_ALLOC_HUGE_PAGE_FAIL = 23,
	SCAN_CGROUP_CHARGE_FAIL = 24,
	SCAN_TRUNCATED = 25,
	SCAN_PAGE_HAS_PRIVATE = 26,
};

struct trace_event_raw_mm_khugepaged_scan_pmd {
	struct trace_entry ent;
	struct mm_struct___81 *mm;
	long unsigned int pfn;
	bool writable;
	int referenced;
	int none_or_zero;
	int status;
	int unmapped;
	char __data[0];
};

struct trace_event_raw_mm_collapse_huge_page {
	struct trace_entry ent;
	struct mm_struct___81 *mm;
	int isolated;
	int status;
	char __data[0];
};

struct trace_event_raw_mm_collapse_huge_page_isolate {
	struct trace_entry ent;
	long unsigned int pfn;
	int none_or_zero;
	int referenced;
	bool writable;
	int status;
	char __data[0];
};

struct trace_event_raw_mm_collapse_huge_page_swapin {
	struct trace_entry ent;
	struct mm_struct___81 *mm;
	int swapped_in;
	int referenced;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_mm_khugepaged_scan_pmd {};

struct trace_event_data_offsets_mm_collapse_huge_page {};

struct trace_event_data_offsets_mm_collapse_huge_page_isolate {};

struct trace_event_data_offsets_mm_collapse_huge_page_swapin {};

typedef void (*btf_trace_mm_khugepaged_scan_pmd)(void *, struct mm_struct___81 *, struct page___80 *, bool, int, int, int, int);

typedef void (*btf_trace_mm_collapse_huge_page)(void *, struct mm_struct___81 *, int, int);

typedef void (*btf_trace_mm_collapse_huge_page_isolate)(void *, struct page___80 *, int, int, bool, int);

typedef void (*btf_trace_mm_collapse_huge_page_swapin)(void *, struct mm_struct___81 *, int, int, int);

struct mm_slot___2 {
	struct hlist_node hash;
	struct list_head mm_node;
	struct mm_struct___81 *mm;
	int nr_pte_mapped_thp;
	long unsigned int pte_mapped_thp[8];
};

struct khugepaged_scan {
	struct list_head mm_head;
	struct mm_slot___2 *mm_slot;
	long unsigned int address;
};

struct fs_context___13;

struct fs_parameter_spec___12;

struct dentry___82;

struct super_block___82;

struct module___80;

struct file_system_type___82 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___13 *);
	const struct fs_parameter_spec___12 *parameters;
	struct dentry___82 * (*mount)(struct file_system_type___82 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___82 *);
	struct module___80 *owner;
	struct file_system_type___82 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___82;

struct kiocb___82;

struct iov_iter___49;

struct poll_table_struct___60;

struct vm_area_struct___87;

struct inode___82;

struct file_lock___82;

struct page___87;

struct pipe_inode_info___33;

struct seq_file___77;

struct file_operations___82 {
	struct module___80 *owner;
	loff_t (*llseek)(struct file___82 *, loff_t, int);
	ssize_t (*read)(struct file___82 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___82 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___82 *, struct iov_iter___49 *);
	ssize_t (*write_iter)(struct kiocb___82 *, struct iov_iter___49 *);
	int (*iopoll)(struct kiocb___82 *, bool);
	int (*iterate)(struct file___82 *, struct dir_context *);
	int (*iterate_shared)(struct file___82 *, struct dir_context *);
	__poll_t (*poll)(struct file___82 *, struct poll_table_struct___60 *);
	long int (*unlocked_ioctl)(struct file___82 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___82 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___82 *, struct vm_area_struct___87 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___82 *, struct file___82 *);
	int (*flush)(struct file___82 *, fl_owner_t);
	int (*release)(struct inode___82 *, struct file___82 *);
	int (*fsync)(struct file___82 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___82 *, int);
	int (*lock)(struct file___82 *, int, struct file_lock___82 *);
	ssize_t (*sendpage)(struct file___82 *, struct page___87 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___82 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___82 *, long unsigned int);
	int (*flock)(struct file___82 *, int, struct file_lock___82 *);
	ssize_t (*splice_write)(struct pipe_inode_info___33 *, struct file___82 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___82 *, loff_t *, struct pipe_inode_info___33 *, size_t, unsigned int);
	int (*setlease)(struct file___82 *, long int, struct file_lock___82 **, void **);
	long int (*fallocate)(struct file___82 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___77 *, struct file___82 *);
	ssize_t (*copy_file_range)(struct file___82 *, loff_t, struct file___82 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___82 *, loff_t, struct file___82 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___82 *, loff_t, loff_t, int);
};

typedef struct page___87 *pgtable_t___87;

struct address_space___82;

struct page_pool___28;

struct kmem_cache___4;

struct mm_struct___88;

struct dev_pagemap___81;

struct page___87 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___82 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___28 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___87 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache___4 *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___87 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___88 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___81 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vmacache___87 {
	u64 seqnum;
	struct vm_area_struct___87 *vmas[4];
};

struct page_frag___87 {
	struct page___87 *page;
	__u32 offset;
	__u32 size;
};

struct pid___75;

struct nsproxy___80;

struct signal_struct___83;

struct bio_list___39;

struct backing_dev_info___38;

struct io_context___39;

struct capture_control___11;

struct css_set___68;

struct mem_cgroup___36;

struct request_queue___39;

struct vm_struct___83;

struct task_struct___89 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___89 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___88 *mm;
	struct mm_struct___88 *active_mm;
	struct vmacache___87 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___89 *real_parent;
	struct task_struct___89 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___89 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___75 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___80 *nsproxy;
	struct signal_struct___83 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___89 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___39 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___38 *backing_dev_info;
	struct io_context___39 *io_context;
	struct capture_control___11 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___68 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___33 *splice_pipe;
	struct page_frag___87 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___36 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___36 *active_memcg;
	struct request_queue___39 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___89 *oom_reaper_list;
	struct vm_struct___83 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___82;

struct kobj_type___82;

struct kernfs_node___82;

struct kobject___82 {
	const char *name;
	struct list_head entry;
	struct kobject___82 *parent;
	struct kset___82 *kset;
	struct kobj_type___82 *ktype;
	struct kernfs_node___82 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___79 {
	struct kobject___82 kobj;
	struct module___80 *mod;
	struct kobject___82 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___79 {
	struct module___80 *mod;
	struct latch_tree_node node;
};

struct module_layout___79 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___79 mtn;
};

struct module_attribute___79;

struct kernel_param___79;

struct module___80 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___79 mkobj;
	struct module_attribute___79 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___82 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___79 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___79 core_layout;
	struct module_layout___79 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___75;

struct upid___75 {
	int nr;
	struct pid_namespace___75 *ns;
};

struct pid_namespace___75 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___89 *child_reaper;
	struct kmem_cache___4 *pid_cachep;
	unsigned int level;
	struct pid_namespace___75 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___75 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___75 numbers[1];
};

struct vm_operations_struct___81;

struct vm_area_struct___87 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___87 *vm_next;
	struct vm_area_struct___87 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___88 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___81 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___82 *vm_file;
	struct file___82 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___83 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___89 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___89 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___75 *pids[4];
	struct pid___75 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___88 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___87;

struct mm_struct___88 {
	struct {
		struct vm_area_struct___87 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___82 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___87 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___89 *owner;
		struct user_namespace___12 *user_ns;
		struct file___82 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___22;

struct cgroup_namespace___68;

struct nsproxy___80 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___75 *pid_ns_for_children;
	struct net___22 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___68 *cgroup_ns;
};

struct bio___39;

struct bio_list___39 {
	struct bio___39 *head;
	struct bio___39 *tail;
};

struct cgroup_subsys_state___68;

struct bdi_writeback___38 {
	struct backing_dev_info___38 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___68 *memcg_css;
	struct cgroup_subsys_state___68 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___70;

struct backing_dev_info___38 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___38 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___70 *dev;
	char dev_name[64];
	struct device___70 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___82 *debug_dir;
};

struct io_cq___39;

struct io_context___39 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___39 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___11;

struct capture_control___11 {
	struct compact_control___11 *cc;
	struct page___87 *page;
};

struct cgroup___68;

struct css_set___68 {
	struct cgroup_subsys_state___68 *subsys[14];
	refcount_t refcount;
	struct css_set___68 *dom_cset;
	struct cgroup___68 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___68 *mg_src_cgrp;
	struct cgroup___68 *mg_dst_cgrp;
	struct css_set___68 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___82;

struct pipe_buffer___33;

struct pipe_inode_info___33 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___87 *tmp_page;
	struct fasync_struct___82 *fasync_readers;
	struct fasync_struct___82 *fasync_writers;
	struct pipe_buffer___33 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___68;

struct cgroup_subsys_state___68 {
	struct cgroup___68 *cgroup;
	struct cgroup_subsys___68 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___68 *parent;
};

struct cgroup_file___68 {
	struct kernfs_node___82 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___36;

struct mem_cgroup_per_node___36;

struct mem_cgroup___36 {
	struct cgroup_subsys_state___68 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___68 events_file;
	struct cgroup_file___68 events_local_file;
	struct cgroup_file___68 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___36 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___89 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___36 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___39;

struct blk_integrity___39 {
	const struct blk_integrity_profile___39 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___39 {
	struct kmem_cache___4 *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___39 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___39;

struct elevator_queue___39;

struct blk_mq_ops___38;

struct blk_mq_hw_ctx___38;

struct gendisk___39;

struct blkcg_gq___38;

struct blk_mq_tag_set___38;

struct request_queue___39 {
	struct request___39 *last_merge;
	struct elevator_queue___39 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___38 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___38 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___39 *disk;
	struct kobject___82 kobj;
	struct kobject___82 *mq_kobj;
	struct blk_integrity___39 integrity;
	struct device___70 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___38 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___38 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___39 bio_split;
	struct dentry___82 *debugfs_dir;
	struct dentry___82 *sched_debugfs_dir;
	struct dentry___82 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___83 {
	struct vm_struct___83 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___87 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___82;

struct dentry___82 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___82 *d_parent;
	struct qstr d_name;
	struct inode___82 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___82 *d_op;
	struct super_block___82 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___82;

struct address_space___82 {
	struct inode___82 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___82 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___82;

struct inode___82 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___82 *i_op;
	struct super_block___82 *i_sb;
	struct address_space___82 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___38 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___82 *i_fop;
		void (*free_inode)(struct inode___82 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___82 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___33 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___82;

struct path___82;

struct dentry_operations___82 {
	int (*d_revalidate)(struct dentry___82 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___82 *, unsigned int);
	int (*d_hash)(const struct dentry___82 *, struct qstr *);
	int (*d_compare)(const struct dentry___82 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___82 *);
	int (*d_init)(struct dentry___82 *);
	void (*d_release)(struct dentry___82 *);
	void (*d_prune)(struct dentry___82 *);
	void (*d_iput)(struct dentry___82 *, struct inode___82 *);
	char * (*d_dname)(struct dentry___82 *, char *, int);
	struct vfsmount___82 * (*d_automount)(struct path___82 *);
	int (*d_manage)(const struct path___82 *, bool);
	struct dentry___82 * (*d_real)(struct dentry___82 *, const struct inode___82 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___82;

struct mem_dqinfo___82 {
	struct quota_format_type___82 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___82;

struct quota_info___82 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___82 *files[3];
	struct mem_dqinfo___82 info[3];
	const struct quota_format_ops___82 *ops[3];
};

struct rcuwait___83 {
	struct task_struct___89 *task;
};

struct percpu_rw_semaphore___83 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___83 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___82 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___83 rw_sem[3];
};

struct shrink_control___36;

struct shrinker___36 {
	long unsigned int (*count_objects)(struct shrinker___36 *, struct shrink_control___36 *);
	long unsigned int (*scan_objects)(struct shrinker___36 *, struct shrink_control___36 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___82;

struct dquot_operations___82;

struct quotactl_ops___82;

struct xattr_handler___7;

struct block_device___40;

struct super_block___82 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___82 *s_type;
	const struct super_operations___82 *s_op;
	const struct dquot_operations___82 *dq_op;
	const struct quotactl_ops___82 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___82 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___7 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___40 *s_bdev;
	struct backing_dev_info___38 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___82 s_dquot;
	struct sb_writers___82 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___82 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___82 {
	struct dentry___82 *mnt_root;
	struct super_block___82 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct path___82 {
	struct vfsmount___82 *mnt;
	struct dentry___82 *dentry;
};

struct shrink_control___36 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___36 *memcg;
};

struct page_pool_params___28 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___70 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___28 {
	u32 count;
	struct page___87 *cache[128];
};

struct page_pool___28 {
	struct page_pool_params___28 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___87 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___28 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kmem_cache_cpu___4;

struct kmem_cache___4 {
	struct kmem_cache_cpu___4 *cpu_slab;
	slab_flags_t flags;
	long unsigned int min_partial;
	unsigned int size;
	unsigned int object_size;
	struct reciprocal_value reciprocal_size;
	unsigned int offset;
	unsigned int cpu_partial;
	struct kmem_cache_order_objects oo;
	struct kmem_cache_order_objects max;
	struct kmem_cache_order_objects min;
	gfp_t allocflags;
	int refcount;
	void (*ctor)(void *);
	unsigned int inuse;
	unsigned int align;
	unsigned int red_left_pad;
	const char *name;
	struct list_head list;
	struct kobject___82 kobj;
	long unsigned int random;
	unsigned int remote_node_defrag_ratio;
	unsigned int *random_seq;
	unsigned int useroffset;
	unsigned int usersize;
	struct kmem_cache_node *node[64];
};

struct dev_pagemap_ops___81;

struct dev_pagemap___81 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___81 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___75 {
	rwlock_t lock;
	struct pid___75 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___82 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___82 f_path;
	struct inode___82 *f_inode;
	const struct file_operations___82 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___75 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___82 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___81;

struct vm_operations_struct___81 {
	void (*open)(struct vm_area_struct___87 *);
	void (*close)(struct vm_area_struct___87 *);
	int (*may_split)(struct vm_area_struct___87 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___87 *);
	int (*mprotect)(struct vm_area_struct___87 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___81 *);
	vm_fault_t (*huge_fault)(struct vm_fault___81 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___81 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___87 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___81 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___81 *);
	int (*access)(struct vm_area_struct___87 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___87 *);
	int (*set_policy)(struct vm_area_struct___87 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___87 *, long unsigned int);
	struct page___87 * (*find_special_page)(struct vm_area_struct___87 *, long unsigned int);
};

struct core_thread___87 {
	struct task_struct___89 *task;
	struct core_thread___87 *next;
};

struct core_state___87 {
	atomic_t nr_threads;
	struct core_thread___87 dumper;
	struct completion startup;
};

struct vm_fault___81 {
	const struct {
		struct vm_area_struct___87 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___87 *cow_page;
	struct page___87 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___87 prealloc_pte;
};

struct pglist_data___41;

struct lruvec___41 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___41 *pgdat;
};

struct zone___41 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___41 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___41 {
	struct zone___41 *zone;
	int zone_idx;
};

struct zonelist___41 {
	struct zoneref___41 _zonerefs[321];
};

struct pglist_data___41 {
	struct zone___41 node_zones[5];
	struct zonelist___41 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___89 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___89 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___41 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___41 pg_data_t___10;

struct psi_group___68 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___89 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___19;

struct cgroup_bpf___19 {
	struct bpf_prog_array___19 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___19 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___68;

struct cgroup_rstat_cpu___68;

struct cgroup___68 {
	struct cgroup_subsys_state___68 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___82 *kn;
	struct cgroup_file___68 procs_file;
	struct cgroup_file___68 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___68 *subsys[14];
	struct cgroup_root___68 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___68 *dom_cgrp;
	struct cgroup___68 *old_dom_cgrp;
	struct cgroup_rstat_cpu___68 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___68 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___39 {
	struct request_queue___39 *q;
	struct io_context___39 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___40;

struct kiocb___82 {
	struct file___82 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___82 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___40 *ki_waitq;
	};
};

struct iattr___82 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___82 *ia_file;
};

struct dquot___82 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___82 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___82 {
	int qf_fmt_id;
	const struct quota_format_ops___82 *qf_ops;
	struct module___80 *qf_owner;
	struct quota_format_type___82 *qf_next;
};

struct quota_format_ops___82 {
	int (*check_quota_file)(struct super_block___82 *, int);
	int (*read_file_info)(struct super_block___82 *, int);
	int (*write_file_info)(struct super_block___82 *, int);
	int (*free_file_info)(struct super_block___82 *, int);
	int (*read_dqblk)(struct dquot___82 *);
	int (*commit_dqblk)(struct dquot___82 *);
	int (*release_dqblk)(struct dquot___82 *);
	int (*get_next_id)(struct super_block___82 *, struct kqid *);
};

struct dquot_operations___82 {
	int (*write_dquot)(struct dquot___82 *);
	struct dquot___82 * (*alloc_dquot)(struct super_block___82 *, int);
	void (*destroy_dquot)(struct dquot___82 *);
	int (*acquire_dquot)(struct dquot___82 *);
	int (*release_dquot)(struct dquot___82 *);
	int (*mark_dirty)(struct dquot___82 *);
	int (*write_info)(struct super_block___82 *, int);
	qsize_t * (*get_reserved_space)(struct inode___82 *);
	int (*get_projid)(struct inode___82 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___82 *, qsize_t *);
	int (*get_next_id)(struct super_block___82 *, struct kqid *);
};

struct quotactl_ops___82 {
	int (*quota_on)(struct super_block___82 *, int, int, const struct path___82 *);
	int (*quota_off)(struct super_block___82 *, int);
	int (*quota_enable)(struct super_block___82 *, unsigned int);
	int (*quota_disable)(struct super_block___82 *, unsigned int);
	int (*quota_sync)(struct super_block___82 *, int);
	int (*set_info)(struct super_block___82 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___82 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___82 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___82 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___82 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___82 *, unsigned int);
};

struct wait_page_queue___40 {
	struct page___87 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___38;

struct readahead_control___40;

struct swap_info_struct___23;

struct address_space_operations___82 {
	int (*writepage)(struct page___87 *, struct writeback_control___38 *);
	int (*readpage)(struct file___82 *, struct page___87 *);
	int (*writepages)(struct address_space___82 *, struct writeback_control___38 *);
	int (*set_page_dirty)(struct page___87 *);
	int (*readpages)(struct file___82 *, struct address_space___82 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___40 *);
	int (*write_begin)(struct file___82 *, struct address_space___82 *, loff_t, unsigned int, unsigned int, struct page___87 **, void **);
	int (*write_end)(struct file___82 *, struct address_space___82 *, loff_t, unsigned int, unsigned int, struct page___87 *, void *);
	sector_t (*bmap)(struct address_space___82 *, sector_t);
	void (*invalidatepage)(struct page___87 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___87 *, gfp_t);
	void (*freepage)(struct page___87 *);
	ssize_t (*direct_IO)(struct kiocb___82 *, struct iov_iter___49 *);
	int (*migratepage)(struct address_space___82 *, struct page___87 *, struct page___87 *, enum migrate_mode);
	bool (*isolate_page)(struct page___87 *, isolate_mode_t);
	void (*putback_page)(struct page___87 *);
	int (*launder_page)(struct page___87 *);
	int (*is_partially_uptodate)(struct page___87 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___87 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___82 *, struct page___87 *);
	int (*swap_activate)(struct swap_info_struct___23 *, struct file___82 *, sector_t *);
	void (*swap_deactivate)(struct file___82 *);
};

struct writeback_control___38 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___38 *wb;
	struct inode___82 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___40 {
	struct file___82 *file;
	struct address_space___82 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___48;

struct iov_iter___49 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___48 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___33 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___23 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___40 *bdev;
	struct file___82 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___82 {
	struct dentry___82 * (*lookup)(struct inode___82 *, struct dentry___82 *, unsigned int);
	const char * (*get_link)(struct dentry___82 *, struct inode___82 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___82 *, int);
	struct posix_acl * (*get_acl)(struct inode___82 *, int, bool);
	int (*readlink)(struct dentry___82 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___82 *, struct dentry___82 *, umode_t, bool);
	int (*link)(struct dentry___82 *, struct inode___82 *, struct dentry___82 *);
	int (*unlink)(struct inode___82 *, struct dentry___82 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___82 *, struct dentry___82 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___82 *, struct dentry___82 *, umode_t);
	int (*rmdir)(struct inode___82 *, struct dentry___82 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___82 *, struct dentry___82 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___82 *, struct dentry___82 *, struct inode___82 *, struct dentry___82 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___82 *, struct iattr___82 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___82 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___82 *, char *, size_t);
	int (*fiemap)(struct inode___82 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___82 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___82 *, struct dentry___82 *, struct file___82 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___82 *, struct dentry___82 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___82 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___82 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___82 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___82 {
	void (*fl_copy_lock)(struct file_lock___82 *, struct file_lock___82 *);
	void (*fl_release_private)(struct file_lock___82 *);
};

struct lock_manager_operations___82;

struct file_lock___82 {
	struct file_lock___82 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___82 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___82 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___82 *fl_ops;
	const struct lock_manager_operations___82 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___82 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___82 *);
	int (*lm_grant)(struct file_lock___82 *, int);
	bool (*lm_break)(struct file_lock___82 *);
	int (*lm_change)(struct file_lock___82 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___82 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___82 *);
};

struct fasync_struct___82 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___82 *fa_next;
	struct file___82 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___82 {
	struct inode___82 * (*alloc_inode)(struct super_block___82 *);
	void (*destroy_inode)(struct inode___82 *);
	void (*free_inode)(struct inode___82 *);
	void (*dirty_inode)(struct inode___82 *, int);
	int (*write_inode)(struct inode___82 *, struct writeback_control___38 *);
	int (*drop_inode)(struct inode___82 *);
	void (*evict_inode)(struct inode___82 *);
	void (*put_super)(struct super_block___82 *);
	int (*sync_fs)(struct super_block___82 *, int);
	int (*freeze_super)(struct super_block___82 *);
	int (*freeze_fs)(struct super_block___82 *);
	int (*thaw_super)(struct super_block___82 *);
	int (*unfreeze_fs)(struct super_block___82 *);
	int (*statfs)(struct dentry___82 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___82 *, int *, char *);
	void (*umount_begin)(struct super_block___82 *);
	int (*show_options)(struct seq_file___77 *, struct dentry___82 *);
	int (*show_devname)(struct seq_file___77 *, struct dentry___82 *);
	int (*show_path)(struct seq_file___77 *, struct dentry___82 *);
	int (*show_stats)(struct seq_file___77 *, struct dentry___82 *);
	ssize_t (*quota_read)(struct super_block___82 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___82 *, int, const char *, size_t, loff_t);
	struct dquot___82 ** (*get_dquots)(struct inode___82 *);
	long int (*nr_cached_objects)(struct super_block___82 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___82 *, struct shrink_control___36 *);
	struct file___82 * (*real_loop)(struct file___82 *);
};

struct xattr_handler___7 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___82 *);
	int (*get)(const struct xattr_handler___7 *, struct dentry___82 *, struct inode___82 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___7 *, struct user_namespace___12 *, struct dentry___82 *, struct inode___82 *, const char *, const void *, size_t, int);
};

struct wakeup_source___70;

struct dev_pm_info___70 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___70 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___70 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___70;

struct bus_type___70;

struct device_driver___70;

struct dev_pm_domain___70;

struct fwnode_handle___70;

struct class___70;

struct attribute_group___82;

struct device___70 {
	struct kobject___82 kobj;
	struct device___70 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___70 *type;
	struct bus_type___70 *bus;
	struct device_driver___70 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___70 power;
	struct dev_pm_domain___70 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___70 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___70 *class;
	const struct attribute_group___82 **groups;
	void (*release)(struct device___70 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___40 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___82 *bd_inode;
	struct super_block___82 *bd_super;
	void *bd_claiming;
	struct device___70 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___82 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___39 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___82 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___60)(struct file___82 *, wait_queue_head_t *, struct poll_table_struct___60 *);

struct poll_table_struct___60 {
	poll_queue_proc___60 _qproc;
	__poll_t _key;
};

struct seq_operations___77;

struct seq_file___77 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___77 *op;
	int poll_event;
	const struct file___82 *file;
	void *private;
};

struct fc_log___13;

struct p_log___13 {
	const char *prefix;
	struct fc_log___13 *log;
};

struct fs_context_operations___13;

struct fs_context___13 {
	const struct fs_context_operations___13 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___82 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___82 *root;
	struct user_namespace___12 *user_ns;
	struct net___22 *net_ns;
	const struct cred___11 *cred;
	struct p_log___13 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___13;

typedef int fs_param_type___12(struct p_log___13 *, const struct fs_parameter_spec___12 *, struct fs_parameter___13 *, struct fs_parse_result *);

struct fs_parameter_spec___12 {
	const char *name;
	fs_param_type___12 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___39(struct bio___39 *);

struct bio_vec___48 {
	struct page___87 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___39;

struct bio___39 {
	struct bio___39 *bi_next;
	struct block_device___40 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___39 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___38 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___39 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___48 *bi_io_vec;
	struct bio_set___39 *bi_pool;
	struct bio_vec___48 bi_inline_vecs[0];
};

struct seq_operations___77 {
	void * (*start)(struct seq_file___77 *, loff_t *);
	void (*stop)(struct seq_file___77 *, void *);
	void * (*next)(struct seq_file___77 *, void *, loff_t *);
	int (*show)(struct seq_file___77 *, void *);
};

struct kernfs_root___82;

struct kernfs_elem_dir___82 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___82 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___82;

struct kernfs_root___82 {
	struct kernfs_node___82 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___82 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___82 {
	struct kernfs_node___82 *target_kn;
};

struct kernfs_ops___82;

struct kernfs_elem_attr___82 {
	const struct kernfs_ops___82 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___82 *notify_next;
};

struct kernfs_node___82 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___82 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___82 dir;
		struct kernfs_elem_symlink___82 symlink;
		struct kernfs_elem_attr___82 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___82;

struct kernfs_ops___82 {
	int (*open)(struct kernfs_open_file___82 *);
	void (*release)(struct kernfs_open_file___82 *);
	int (*seq_show)(struct seq_file___77 *, void *);
	void * (*seq_start)(struct seq_file___77 *, loff_t *);
	void * (*seq_next)(struct seq_file___77 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___77 *, void *);
	ssize_t (*read)(struct kernfs_open_file___82 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___82 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___82 *, struct poll_table_struct___60 *);
	int (*mmap)(struct kernfs_open_file___82 *, struct vm_area_struct___87 *);
};

struct kernfs_syscall_ops___82 {
	int (*show_options)(struct seq_file___77 *, struct kernfs_root___82 *);
	int (*mkdir)(struct kernfs_node___82 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___82 *);
	int (*rename)(struct kernfs_node___82 *, struct kernfs_node___82 *, const char *);
	int (*show_path)(struct seq_file___77 *, struct kernfs_node___82 *, struct kernfs_root___82 *);
};

struct kernfs_open_file___82 {
	struct kernfs_node___82 *kn;
	struct file___82 *file;
	struct seq_file___77 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___81 *vm_ops;
};

struct ip_ra_chain___2;

struct fib_rules_ops___12;

struct sock___13;

struct fqdir___21;

struct fib_notifier_ops___12;

struct netns_ipv4___21 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___2 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___12 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___13 *fibnl;
	struct sock___13 **icmp_sk;
	struct sock___13 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___13 **tcp_sk;
	struct fqdir___21 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___12 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___12 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___12 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___12;

struct net_device___24;

struct sk_buff___21;

struct neighbour___12;

struct dst_ops___21 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___21 *);
	struct dst_entry___12 * (*check)(struct dst_entry___12 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___12 *);
	unsigned int (*mtu)(const struct dst_entry___12 *);
	u32 * (*cow_metrics)(struct dst_entry___12 *, long unsigned int);
	void (*destroy)(struct dst_entry___12 *);
	void (*ifdown)(struct dst_entry___12 *, struct net_device___24 *, int);
	struct dst_entry___12 * (*negative_advice)(struct dst_entry___12 *);
	void (*link_failure)(struct sk_buff___21 *);
	void (*update_pmtu)(struct dst_entry___12 *, struct sock___13 *, struct sk_buff___21 *, u32, bool);
	void (*redirect)(struct dst_entry___12 *, struct sock___13 *, struct sk_buff___21 *);
	int (*local_out)(struct net___22 *, struct sock___13 *, struct sk_buff___21 *);
	struct neighbour___12 * (*neigh_lookup)(const struct dst_entry___12 *, struct sk_buff___21 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___12 *, const void *);
	struct kmem_cache___4 *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___21 {
	struct dst_ops___21 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___21 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___12 *fib6_rules_ops;
	struct sock___13 **icmp_sk;
	struct sock___13 *ndisc_sk;
	struct sock___13 *tcp_sk;
	struct sock___13 *igmp_sk;
	struct sock___13 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___12 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___12 *notifier_ops;
	struct fib_notifier_ops___12 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___21 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___21 *fqdir;
};

struct netns_sctp___12 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___13 *ctl_sock;
	struct sock___13 *udp4_sock;
	struct sock___13 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___19 {
	struct sk_buff___21 *next;
	struct sk_buff___21 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___19;

struct netns_bpf___19 {
	struct bpf_prog_array___19 *run_array[2];
	struct bpf_prog___19 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___21 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___13 *nlsk;
	struct sock___13 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___21 xfrm4_dst_ops;
	struct dst_ops___21 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___22 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct idr netns_ids;
	struct ns_common___13 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___13 *rtnl;
	struct sock___13 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___24 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___21 ipv4;
	struct netns_ipv6___21 ipv6;
	struct netns_ieee802154_lowpan___21 ieee802154_lowpan;
	struct netns_sctp___12 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___19 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___19 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___21 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___13 *crypto_nlsk;
	struct sock___13 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___68 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___68 *root_cset;
};

struct fwnode_operations___70;

struct fwnode_handle___70 {
	struct fwnode_handle___70 *secondary;
	const struct fwnode_operations___70 *ops;
	struct device___70 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___70;

struct fwnode_endpoint___70;

struct fwnode_operations___70 {
	struct fwnode_handle___70 * (*get)(struct fwnode_handle___70 *);
	void (*put)(struct fwnode_handle___70 *);
	bool (*device_is_available)(const struct fwnode_handle___70 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___70 *, const struct device___70 *);
	bool (*property_present)(const struct fwnode_handle___70 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___70 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___70 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___70 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*get_parent)(const struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*get_next_child_node)(const struct fwnode_handle___70 *, struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*get_named_child_node)(const struct fwnode_handle___70 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___70 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___70 *);
	struct fwnode_handle___70 * (*graph_get_next_endpoint)(const struct fwnode_handle___70 *, struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*graph_get_remote_endpoint)(const struct fwnode_handle___70 *);
	struct fwnode_handle___70 * (*graph_get_port_parent)(struct fwnode_handle___70 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___70 *, struct fwnode_endpoint___70 *);
	int (*add_links)(struct fwnode_handle___70 *);
};

struct fwnode_endpoint___70 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___70 *local_fwnode;
};

struct fwnode_reference_args___70 {
	struct fwnode_handle___70 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kobj_ns_type_operations___12 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___13 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___22 *net;
} possible_net_t___19;

struct proto___12;

struct sock_common___12 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___12 *skc_prot;
	possible_net_t___19 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___13 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___12 {
	struct cgroup___68 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___12;

struct socket_wq___12;

struct socket___12;

struct sock___13 {
	struct sock_common___12 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___19 sk_error_queue;
	struct sk_buff___21 *sk_rx_skb_cache;
	struct sk_buff_head___19 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___21 *head;
		struct sk_buff___21 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___12 *sk_filter;
	union {
		struct socket_wq___12 *sk_wq;
		struct socket_wq___12 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___12 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___12 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___21 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___21 *sk_tx_skb_cache;
	struct sk_buff_head___19 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___87 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___12 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___75 *sk_peer_pid;
	const struct cred___11 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___12 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___12 sk_cgrp_data;
	struct mem_cgroup___36 *sk_memcg;
	void (*sk_state_change)(struct sock___13 *);
	void (*sk_data_ready)(struct sock___13 *);
	void (*sk_write_space)(struct sock___13 *);
	void (*sk_error_report)(struct sock___13 *);
	int (*sk_backlog_rcv)(struct sock___13 *, struct sk_buff___21 *);
	struct sk_buff___21 * (*sk_validate_xmit_skb)(struct sock___13 *, struct net_device___24 *, struct sk_buff___21 *);
	void (*sk_destruct)(struct sock___13 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___82;

struct attribute_group___82 {
	const char *name;
	umode_t (*is_visible)(struct kobject___82 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___82 *, struct bin_attribute___82 *, int);
	struct attribute **attrs;
	struct bin_attribute___82 **bin_attrs;
};

struct bin_attribute___82 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___82 * (*f_mapping)();
	ssize_t (*read)(struct file___82 *, struct kobject___82 *, struct bin_attribute___82 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___82 *, struct kobject___82 *, struct bin_attribute___82 *, char *, loff_t, size_t);
	int (*mmap)(struct file___82 *, struct kobject___82 *, struct bin_attribute___82 *, struct vm_area_struct___87 *);
};

struct sysfs_ops___82 {
	ssize_t (*show)(struct kobject___82 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___82 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___82;

struct kset___82 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___82 kobj;
	const struct kset_uevent_ops___82 *uevent_ops;
};

struct kobj_type___82 {
	void (*release)(struct kobject___82 *);
	const struct sysfs_ops___82 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___82 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___82 *);
	const void * (*namespace)(struct kobject___82 *);
	void (*get_ownership)(struct kobject___82 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___82 {
	int (* const filter)(struct kset___82 *, struct kobject___82 *);
	const char * (* const name)(struct kset___82 *, struct kobject___82 *);
	int (* const uevent)(struct kset___82 *, struct kobject___82 *, struct kobj_uevent_env *);
};

struct fd___12 {
	struct file___82 *file;
	unsigned int flags;
};

struct kernel_param_ops___79 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___79 *);
	int (*get)(char *, const struct kernel_param___79 *);
	void (*free)(void *);
};

struct kparam_array___79;

struct kernel_param___79 {
	const char *name;
	struct module___80 *mod;
	const struct kernel_param_ops___79 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___79 *arr;
	};
};

struct kparam_array___79 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___79 *ops;
	void *elem;
};

struct module_attribute___79 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___79 *, struct module_kobject___79 *, char *);
	ssize_t (*store)(struct module_attribute___79 *, struct module_kobject___79 *, const char *, size_t);
	void (*setup)(struct module___80 *, const char *);
	int (*test)(struct module___80 *);
	void (*free)(struct module___80 *);
};

struct dev_pagemap_ops___81 {
	void (*page_free)(struct page___87 *);
	void (*kill)(struct dev_pagemap___81 *);
	void (*cleanup)(struct dev_pagemap___81 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___81 *);
};

struct bpf_iter_aux_info___20;

typedef int (*bpf_iter_init_seq_priv_t___20)(void *, struct bpf_iter_aux_info___20 *);

struct bpf_map___20;

struct bpf_iter_aux_info___20 {
	struct bpf_map___20 *map;
};

struct bpf_iter_seq_info___20 {
	const struct seq_operations___77 *seq_ops;
	bpf_iter_init_seq_priv_t___20 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___20;

struct bpf_map_ops___20 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___20 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___20 *, struct file___82 *);
	void (*map_free)(struct bpf_map___20 *);
	int (*map_get_next_key)(struct bpf_map___20 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___20 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___20 *, void *);
	int (*map_lookup_batch)(struct bpf_map___20 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___20 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___20 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___20 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___20 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___20 *, void *);
	int (*map_update_elem)(struct bpf_map___20 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___20 *, void *);
	int (*map_push_elem)(struct bpf_map___20 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___20 *, void *);
	int (*map_peek_elem)(struct bpf_map___20 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___20 *, struct file___82 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___20 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___20 *, void *, struct seq_file___77 *);
	int (*map_check_btf)(const struct bpf_map___20 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___20 *, struct bpf_prog_aux___20 *);
	void (*map_poke_untrack)(struct bpf_map___20 *, struct bpf_prog_aux___20 *);
	void (*map_poke_run)(struct bpf_map___20 *, u32, struct bpf_prog___19 *, struct bpf_prog___19 *);
	int (*map_direct_value_addr)(const struct bpf_map___20 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___20 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___20 *, struct vm_area_struct___87 *);
	__poll_t (*map_poll)(struct bpf_map___20 *, struct file___82 *, struct poll_table_struct___60 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___20 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___20 *, const struct bpf_map___20 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___20 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___20 *iter_seq_info;
};

struct bpf_map___20 {
	const struct bpf_map_ops___20 *ops;
	struct bpf_map___20 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___36 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___20;

struct bpf_jit_poke_descriptor___20;

struct bpf_prog_ops___19;

struct btf_mod_pair___20;

struct bpf_prog_offload___19;

struct bpf_prog_aux___20 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___19 *dst_prog;
	struct bpf_trampoline___20 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___19 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___20 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___19 *ops;
	struct bpf_map___20 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___20 *used_btfs;
	struct bpf_prog___19 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___20 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___19 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___19 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___20 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___19;

struct bpf_map_dev_ops___19 {
	int (*map_get_next_key)(struct bpf_offloaded_map___19 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___19 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___19 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___19 *, void *);
};

struct bpf_offloaded_map___19 {
	struct bpf_map___20 map;
	struct net_device___24 *netdev;
	const struct bpf_map_dev_ops___19 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___19(struct sk_buff___21 **);

struct bpf_xdp_entity___19 {
	struct bpf_prog___19 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___19;

struct net_device_ops___19;

struct l3mdev_ops___12;

struct ndisc_ops___5;

struct xfrmdev_ops___19;

struct header_ops___19;

struct inet6_dev___5;

struct netdev_rx_queue___19;

struct mini_Qdisc___19;

struct netdev_queue___19;

struct Qdisc___19;

struct rtnl_link_ops___19;

struct dcbnl_rtnl_ops___19;

struct net_device___24 {
	char name[16];
	struct netdev_name_node___19 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___19 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___12 *l3mdev_ops;
	const struct ndisc_ops___5 *ndisc_ops;
	const struct xfrmdev_ops___19 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___19 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___82 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___5 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___19 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___19 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___19 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___19 *miniq_ingress;
	struct netdev_queue___19 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___19 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___19 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___19 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___19 = 0,
		NETREG_REGISTERED___19 = 1,
		NETREG_UNREGISTERING___19 = 2,
		NETREG_UNREGISTERED___19 = 3,
		NETREG_RELEASED___19 = 4,
		NETREG_DUMMY___19 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___19 = 0,
		RTNL_LINK_INITIALIZING___19 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___24 *);
	struct netpoll_info *npinfo;
	possible_net_t___19 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___70 dev;
	const struct attribute_group___82 *sysfs_groups[4];
	const struct attribute_group___82 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___19 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___19 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___19 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___19 {
	int (*test_run)(struct bpf_prog___19 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___19 {
	struct bpf_prog___19 *prog;
	struct net_device___24 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___20 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___19 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___80 *mod;
};

struct bpf_jit_poke_descriptor___20 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___20 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___20 {
	struct btf *btf;
	struct module___80 *module;
};

struct bpf_prog_array_item___19 {
	struct bpf_prog___19 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___19 {
	struct callback_head rcu;
	struct bpf_prog_array_item___19 items[0];
};

struct sk_buff___21 {
	union {
		struct {
			struct sk_buff___21 *next;
			struct sk_buff___21 *prev;
			union {
				struct net_device___24 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___13 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___21 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___68;

struct cgroup_subsys___68 {
	struct cgroup_subsys_state___68 * (*css_alloc)(struct cgroup_subsys_state___68 *);
	int (*css_online)(struct cgroup_subsys_state___68 *);
	void (*css_offline)(struct cgroup_subsys_state___68 *);
	void (*css_released)(struct cgroup_subsys_state___68 *);
	void (*css_free)(struct cgroup_subsys_state___68 *);
	void (*css_reset)(struct cgroup_subsys_state___68 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___68 *, int);
	int (*css_extra_stat_show)(struct seq_file___77 *, struct cgroup_subsys_state___68 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___89 *, struct css_set___68 *);
	void (*cancel_fork)(struct task_struct___89 *, struct css_set___68 *);
	void (*fork)(struct task_struct___89 *);
	void (*exit)(struct task_struct___89 *);
	void (*release)(struct task_struct___89 *);
	void (*bind)(struct cgroup_subsys_state___68 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___68 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___68 *dfl_cftypes;
	struct cftype___68 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___68 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___68 *updated_children;
	struct cgroup___68 *updated_next;
};

struct cgroup_root___68 {
	struct kernfs_root___82 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___68 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___68 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___68 *ss;
	struct list_head node;
	struct kernfs_ops___82 *kf_ops;
	int (*open)(struct kernfs_open_file___82 *);
	void (*release)(struct kernfs_open_file___82 *);
	u64 (*read_u64)(struct cgroup_subsys_state___68 *, struct cftype___68 *);
	s64 (*read_s64)(struct cgroup_subsys_state___68 *, struct cftype___68 *);
	int (*seq_show)(struct seq_file___77 *, void *);
	void * (*seq_start)(struct seq_file___77 *, loff_t *);
	void * (*seq_next)(struct seq_file___77 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___77 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___68 *, struct cftype___68 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___68 *, struct cftype___68 *, s64);
	ssize_t (*write)(struct kernfs_open_file___82 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___82 *, struct poll_table_struct___60 *);
};

struct css_task_iter___6 {
	struct cgroup_subsys___68 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___68 *cur_cset;
	struct css_set___68 *cur_dcset;
	struct task_struct___89 *cur_task;
	struct list_head iters_node;
};

struct msghdr___12 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___49 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___82 *msg_iocb;
};

struct dev_pm_ops___70 {
	int (*prepare)(struct device___70 *);
	void (*complete)(struct device___70 *);
	int (*suspend)(struct device___70 *);
	int (*resume)(struct device___70 *);
	int (*freeze)(struct device___70 *);
	int (*thaw)(struct device___70 *);
	int (*poweroff)(struct device___70 *);
	int (*restore)(struct device___70 *);
	int (*suspend_late)(struct device___70 *);
	int (*resume_early)(struct device___70 *);
	int (*freeze_late)(struct device___70 *);
	int (*thaw_early)(struct device___70 *);
	int (*poweroff_late)(struct device___70 *);
	int (*restore_early)(struct device___70 *);
	int (*suspend_noirq)(struct device___70 *);
	int (*resume_noirq)(struct device___70 *);
	int (*freeze_noirq)(struct device___70 *);
	int (*thaw_noirq)(struct device___70 *);
	int (*poweroff_noirq)(struct device___70 *);
	int (*restore_noirq)(struct device___70 *);
	int (*runtime_suspend)(struct device___70 *);
	int (*runtime_resume)(struct device___70 *);
	int (*runtime_idle)(struct device___70 *);
};

struct wakeup_source___70 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___70 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___70 {
	struct dev_pm_ops___70 ops;
	int (*start)(struct device___70 *);
	void (*detach)(struct device___70 *, bool);
	int (*activate)(struct device___70 *);
	void (*sync)(struct device___70 *);
	void (*dismiss)(struct device___70 *);
};

struct bus_type___70 {
	const char *name;
	const char *dev_name;
	struct device___70 *dev_root;
	const struct attribute_group___82 **bus_groups;
	const struct attribute_group___82 **dev_groups;
	const struct attribute_group___82 **drv_groups;
	int (*match)(struct device___70 *, struct device_driver___70 *);
	int (*uevent)(struct device___70 *, struct kobj_uevent_env *);
	int (*probe)(struct device___70 *);
	void (*sync_state)(struct device___70 *);
	void (*remove)(struct device___70 *);
	void (*shutdown)(struct device___70 *);
	int (*online)(struct device___70 *);
	int (*offline)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	int (*num_vf)(struct device___70 *);
	int (*dma_configure)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___70 {
	const char *name;
	struct bus_type___70 *bus;
	struct module___80 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___70 *);
	void (*sync_state)(struct device___70 *);
	int (*remove)(struct device___70 *);
	void (*shutdown)(struct device___70 *);
	int (*suspend)(struct device___70 *, pm_message_t);
	int (*resume)(struct device___70 *);
	const struct attribute_group___82 **groups;
	const struct attribute_group___82 **dev_groups;
	const struct dev_pm_ops___70 *pm;
	void (*coredump)(struct device___70 *);
	struct driver_private *p;
};

struct device_type___70 {
	const char *name;
	const struct attribute_group___82 **groups;
	int (*uevent)(struct device___70 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___70 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___70 *);
	const struct dev_pm_ops___70 *pm;
};

struct class___70 {
	const char *name;
	struct module___80 *owner;
	const struct attribute_group___82 **class_groups;
	const struct attribute_group___82 **dev_groups;
	struct kobject___82 *dev_kobj;
	int (*dev_uevent)(struct device___70 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___70 *, umode_t *);
	void (*class_release)(struct class___70 *);
	void (*dev_release)(struct device___70 *);
	int (*shutdown_pre)(struct device___70 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___70 *);
	void (*get_ownership)(struct device___70 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___70 *pm;
	struct subsys_private *p;
};

struct block_device_operations___39;

struct gendisk___39 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___40 *part0;
	const struct block_device_operations___39 *fops;
	struct request_queue___39 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___38 *bdi;
	struct kobject___82 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___82 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___39 {
	struct bio___39 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___48 *bip_vec;
	struct bio_vec___48 bip_inline_vecs[0];
};

struct blkcg___38;

struct blkg_policy_data___38;

struct blkcg_gq___38 {
	struct request_queue___39 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___38 *blkcg;
	struct blkcg_gq___38 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___38 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___39 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___39(struct request___39 *);

typedef void integrity_complete_fn___39(struct request___39 *, unsigned int);

struct blk_integrity_profile___39 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___39 *prepare_fn;
	integrity_complete_fn___39 *complete_fn;
	const char *name;
};

struct block_device_operations___39 {
	blk_qc_t (*submit_bio)(struct bio___39 *);
	int (*open)(struct block_device___40 *, fmode_t);
	void (*release)(struct gendisk___39 *, fmode_t);
	int (*rw_page)(struct block_device___40 *, sector_t, struct page___87 *, unsigned int);
	int (*ioctl)(struct block_device___40 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___40 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___39 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___39 *);
	int (*getgeo)(struct block_device___40 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___40 *, bool);
	void (*swap_slot_free_notify)(struct block_device___40 *, long unsigned int);
	int (*report_zones)(struct gendisk___39 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___39 *, umode_t *);
	struct module___80 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___39 *, sector_t *);
};

typedef void rq_end_io_fn___39(struct request___39 *, blk_status_t);

struct request___39 {
	struct request_queue___39 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___38 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___39 *bio;
	struct bio___39 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___48 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___39 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___39 *saved_end_io;
		} flush;
	};
	struct gendisk___39 *rq_disk;
	struct block_device___40 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___39 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___38 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___39 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___82 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___82 *debugfs_dir;
	struct dentry___82 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___39;

struct elevator_mq_ops___39 {
	int (*init_sched)(struct request_queue___39 *, struct elevator_type___39 *);
	void (*exit_sched)(struct elevator_queue___39 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___38 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___38 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___38 *);
	bool (*allow_merge)(struct request_queue___39 *, struct request___39 *, struct bio___39 *);
	bool (*bio_merge)(struct request_queue___39 *, struct bio___39 *, unsigned int);
	int (*request_merge)(struct request_queue___39 *, struct request___39 **, struct bio___39 *);
	void (*request_merged)(struct request_queue___39 *, struct request___39 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___39 *, struct request___39 *, struct request___39 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___39 *);
	void (*finish_request)(struct request___39 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___38 *, struct list_head *, bool);
	struct request___39 * (*dispatch_request)(struct blk_mq_hw_ctx___38 *);
	bool (*has_work)(struct blk_mq_hw_ctx___38 *);
	void (*completed_request)(struct request___39 *, u64);
	void (*requeue_request)(struct request___39 *);
	struct request___39 * (*former_request)(struct request_queue___39 *, struct request___39 *);
	struct request___39 * (*next_request)(struct request_queue___39 *, struct request___39 *);
	void (*init_icq)(struct io_cq___39 *);
	void (*exit_icq)(struct io_cq___39 *);
};

struct elv_fs_entry___39;

struct elevator_type___39 {
	struct kmem_cache___4 *icq_cache;
	struct elevator_mq_ops___39 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___39 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___80 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___39 {
	struct elevator_type___39 *type;
	void *elevator_data;
	struct kobject___82 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___39 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___39 *, char *);
	ssize_t (*store)(struct elevator_queue___39 *, const char *, size_t);
};

struct blk_mq_queue_data___38;

struct blk_mq_ops___38 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___38 *, const struct blk_mq_queue_data___38 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___38 *);
	int (*get_budget)(struct request_queue___39 *);
	void (*put_budget)(struct request_queue___39 *, int);
	void (*set_rq_budget_token)(struct request___39 *, int);
	int (*get_rq_budget_token)(struct request___39 *);
	enum blk_eh_timer_return (*timeout)(struct request___39 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___38 *);
	void (*complete)(struct request___39 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___38 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___38 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___38 *, struct request___39 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___38 *, struct request___39 *, unsigned int);
	void (*initialize_rq_fn)(struct request___39 *);
	void (*cleanup_rq)(struct request___39 *);
	bool (*busy)(struct request_queue___39 *);
	int (*map_queues)(struct blk_mq_tag_set___38 *);
	void (*show_rq)(struct seq_file___77 *, struct request___39 *);
};

struct blk_mq_tag_set___38 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___38 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___38 {
	struct request___39 *rq;
	bool last;
};

struct blkcg_policy_data___38;

struct blkcg___38 {
	struct cgroup_subsys_state___68 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___38 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___38 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___38 {
	struct blkcg___38 *blkcg;
	int plid;
};

struct blkg_policy_data___38 {
	struct blkcg_gq___38 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_cookie___2 {
	pg_data_t___10 *pgdat;
	unsigned int generation;
};

struct mem_cgroup_reclaim_iter___36 {
	struct mem_cgroup___36 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___36 {
	struct lruvec___41 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___36 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___36 *memcg;
};

struct obj_cgroup___36 {
	struct percpu_ref refcnt;
	struct mem_cgroup___36 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct mm_walk___4;

struct mm_walk_ops___4 {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*p4d_entry)(p4d_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pte_hole)(long unsigned int, long unsigned int, int, struct mm_walk___4 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___4 *);
	int (*pre_vma)(long unsigned int, long unsigned int, struct mm_walk___4 *);
	void (*post_vma)(struct mm_walk___4 *);
};

struct mm_walk___4 {
	const struct mm_walk_ops___4 *ops;
	struct mm_struct___88 *mm;
	pgd_t *pgd;
	struct vm_area_struct___87 *vma;
	enum page_walk_action action;
	bool no_vma;
	void *private;
};

struct fs_parameter___13 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___82 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___13 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___80 *owner;
	char *buffer[8];
};

struct fs_context_operations___13 {
	void (*free)(struct fs_context___13 *);
	int (*dup)(struct fs_context___13 *, struct fs_context___13 *);
	int (*parse_param)(struct fs_context___13 *, struct fs_parameter___13 *);
	int (*parse_monolithic)(struct fs_context___13 *, void *);
	int (*get_tree)(struct fs_context___13 *);
	int (*reconfigure)(struct fs_context___13 *);
};

typedef struct poll_table_struct___60 poll_table___15;

struct oom_control___3 {
	struct zonelist___41 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___36 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___89 *chosen;
	long int chosen_points;
	enum oom_constraint constraint;
};

struct compact_control___11 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___41 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

struct inet_frags___21;

struct fqdir___21 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___21 *f;
	struct net___22 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___21;

struct inet_frags___21 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___21 *, const void *);
	void (*destructor)(struct inet_frag_queue___21 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache___4 *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___21 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___21 *fragments_tail;
	struct sk_buff___21 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___21 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___2 {
	struct ip_ra_chain___2 *next;
	struct sock___13 *sk;
	union {
		void (*destructor)(struct sock___13 *);
		struct sock___13 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___12;

struct fib_lookup_arg___12;

struct fib_rules_ops___12 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___12 *, struct flowi *, int, struct fib_lookup_arg___12 *);
	bool (*suppress)(struct fib_rule___12 *, int, struct fib_lookup_arg___12 *);
	int (*match)(struct fib_rule___12 *, struct flowi *, int);
	int (*configure)(struct fib_rule___12 *, struct sk_buff___21 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___12 *);
	int (*compare)(struct fib_rule___12 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___12 *, struct sk_buff___21 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___12 *);
	void (*flush_cache)(struct fib_rules_ops___12 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___80 *owner;
	struct net___22 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___12 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___22 *);
	int (*fib_dump)(struct net___22 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___80 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___3;

struct dst_entry___12 {
	struct net_device___24 *dev;
	struct dst_ops___21 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___21 *);
	int (*output)(struct net___22 *, struct sock___13 *, struct sk_buff___21 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___3 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___12;

struct neigh_parms___12;

struct neigh_ops___12;

struct neighbour___12 {
	struct neighbour___12 *next;
	struct neigh_table___12 *tbl;
	struct neigh_parms___12 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___19 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___12 *, struct sk_buff___21 *);
	const struct neigh_ops___12 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___24 *dev;
	u8 primary_key[0];
};

struct socket_wq___12 {
	wait_queue_head_t wait;
	struct fasync_struct___82 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___12;

struct socket___12 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___82 *file;
	struct sock___13 *sk;
	const struct proto_ops___12 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___12 wq;
};

typedef int (*sk_read_actor_t___12)(read_descriptor_t *, struct sk_buff___21 *, unsigned int, size_t);

struct proto_ops___12 {
	int family;
	struct module___80 *owner;
	int (*release)(struct socket___12 *);
	int (*bind)(struct socket___12 *, struct sockaddr *, int);
	int (*connect)(struct socket___12 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___12 *, struct socket___12 *);
	int (*accept)(struct socket___12 *, struct socket___12 *, int, bool);
	int (*getname)(struct socket___12 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___82 *, struct socket___12 *, struct poll_table_struct___60 *);
	int (*ioctl)(struct socket___12 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___12 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___12 *, void *, bool, bool);
	int (*listen)(struct socket___12 *, int);
	int (*shutdown)(struct socket___12 *, int);
	int (*setsockopt)(struct socket___12 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___12 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___77 *, struct socket___12 *);
	int (*sendmsg)(struct socket___12 *, struct msghdr___12 *, size_t);
	int (*recvmsg)(struct socket___12 *, struct msghdr___12 *, size_t, int);
	int (*mmap)(struct file___82 *, struct socket___12 *, struct vm_area_struct___87 *);
	ssize_t (*sendpage)(struct socket___12 *, struct page___87 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___12 *, loff_t *, struct pipe_inode_info___33 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___13 *, int);
	int (*peek_len)(struct socket___12 *);
	int (*read_sock)(struct sock___13 *, read_descriptor_t *, sk_read_actor_t___12);
	int (*sendpage_locked)(struct sock___13 *, struct page___87 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___13 *, struct msghdr___12 *, size_t);
	int (*set_rcvlowat)(struct sock___13 *, int);
};

struct pipe_buf_operations___33;

struct pipe_buffer___33 {
	struct page___87 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___33 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___33 {
	int (*confirm)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
	void (*release)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
	bool (*try_steal)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
	bool (*get)(struct pipe_inode_info___33 *, struct pipe_buffer___33 *);
};

struct dcbnl_rtnl_ops___19 {
	int (*ieee_getets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___24 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___24 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___24 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___24 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___24 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___24 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___24 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___24 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___24 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___24 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___24 *);
	u8 (*setstate)(struct net_device___24 *, u8);
	void (*getpermhwaddr)(struct net_device___24 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___24 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___24 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___24 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___24 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___24 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___24 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___24 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___24 *, int, u8 *);
	void (*setpfccfg)(struct net_device___24 *, int, u8);
	void (*getpfccfg)(struct net_device___24 *, int, u8 *);
	u8 (*setall)(struct net_device___24 *);
	u8 (*getcap)(struct net_device___24 *, int, u8 *);
	int (*getnumtcs)(struct net_device___24 *, int, u8 *);
	int (*setnumtcs)(struct net_device___24 *, int, u8);
	u8 (*getpfcstate)(struct net_device___24 *);
	void (*setpfcstate)(struct net_device___24 *, u8);
	void (*getbcncfg)(struct net_device___24 *, int, u32 *);
	void (*setbcncfg)(struct net_device___24 *, int, u32);
	void (*getbcnrp)(struct net_device___24 *, int, u8 *);
	void (*setbcnrp)(struct net_device___24 *, int, u8);
	int (*setapp)(struct net_device___24 *, u8, u16, u8);
	int (*getapp)(struct net_device___24 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___24 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___24 *, int, u8);
	u8 (*getdcbx)(struct net_device___24 *);
	u8 (*setdcbx)(struct net_device___24 *, u8);
	int (*peer_getappinfo)(struct net_device___24 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___24 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___24 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___24 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___24 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___24 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___19 {
	struct net_device___24 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___19 {
	struct net_device___24 *dev;
};

struct xdp_buff___19 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___19 *rxq;
	struct xdp_txq_info___19 *txq;
	u32 frame_sz;
};

struct xdp_frame___19 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___24 *dev_rx;
};

struct netlink_callback___19 {
	struct sk_buff___21 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___21 *, struct netlink_callback___19 *);
	int (*done)(struct netlink_callback___19 *);
	void *data;
	struct module___80 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___19 {
	int (*create)(struct sk_buff___21 *, struct net_device___24 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___21 *, unsigned char *);
	int (*cache)(const struct neighbour___12 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___24 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___21 *);
};

struct netdev_queue___19 {
	struct net_device___24 *dev;
	struct Qdisc___19 *qdisc;
	struct Qdisc___19 *qdisc_sleeping;
	struct kobject___82 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___24 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___19 {
	struct sk_buff___21 *head;
	struct sk_buff___21 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___19;

struct Qdisc___19 {
	int (*enqueue)(struct sk_buff___21 *, struct Qdisc___19 *, struct sk_buff___21 **);
	struct sk_buff___21 * (*dequeue)(struct Qdisc___19 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___19 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___19 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___19 gso_skb;
	struct qdisc_skb_head___19 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___19 *next_sched;
	struct sk_buff_head___19 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___19 {
	struct xdp_rxq_info___19 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___82 kobj;
	struct net_device___24 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___19 {
	enum net_device_path_type type;
	const struct net_device___24 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___19 = 0,
				DEV_PATH_BR_VLAN_TAG___19 = 1,
				DEV_PATH_BR_VLAN_UNTAG___19 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___19 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___19 {
	const struct net_device___24 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___19 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___19 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___19 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___19 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___21 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___19 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___24 *dev;
	const char *name;
};

struct net_device_ops___19 {
	int (*ndo_init)(struct net_device___24 *);
	void (*ndo_uninit)(struct net_device___24 *);
	int (*ndo_open)(struct net_device___24 *);
	int (*ndo_stop)(struct net_device___24 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___21 *, struct net_device___24 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___21 *, struct net_device___24 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___24 *, struct sk_buff___21 *, struct net_device___24 *);
	void (*ndo_change_rx_flags)(struct net_device___24 *, int);
	void (*ndo_set_rx_mode)(struct net_device___24 *);
	int (*ndo_set_mac_address)(struct net_device___24 *, void *);
	int (*ndo_validate_addr)(struct net_device___24 *);
	int (*ndo_do_ioctl)(struct net_device___24 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___24 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___24 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___24 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___24 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___24 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___24 *, int);
	int (*ndo_neigh_setup)(struct net_device___24 *, struct neigh_parms___12 *);
	void (*ndo_tx_timeout)(struct net_device___24 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___24 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___24 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___24 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___24 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___24 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___24 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___24 *);
	int (*ndo_netpoll_setup)(struct net_device___24 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___24 *);
	int (*ndo_set_vf_mac)(struct net_device___24 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___24 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___24 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___24 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___24 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___24 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___24 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___24 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___24 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___24 *, int, struct sk_buff___21 *);
	int (*ndo_get_vf_guid)(struct net_device___24 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___24 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___24 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___24 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___24 *);
	int (*ndo_fcoe_disable)(struct net_device___24 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___24 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___24 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___24 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___24 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___24 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___24 *, const struct sk_buff___21 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___24 *, struct net_device___24 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___24 *, struct net_device___24 *);
	struct net_device___24 * (*ndo_get_xmit_slave)(struct net_device___24 *, struct sk_buff___21 *, bool);
	struct net_device___24 * (*ndo_sk_get_lower_dev)(struct net_device___24 *, struct sock___13 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___24 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___24 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___24 *, struct neighbour___12 *);
	void (*ndo_neigh_destroy)(struct net_device___24 *, struct neighbour___12 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___21 *, struct netlink_callback___19 *, struct net_device___24 *, struct net_device___24 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___21 *, struct nlattr **, struct net_device___24 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___24 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___21 *, u32, u32, struct net_device___24 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___24 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___24 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___24 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___24 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___24 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___24 *, struct net_device___24 *);
	void (*ndo_dfwd_del_station)(struct net_device___24 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___24 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___24 *);
	int (*ndo_change_proto_down)(struct net_device___24 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___24 *, struct sk_buff___21 *);
	void (*ndo_set_rx_headroom)(struct net_device___24 *, int);
	int (*ndo_bpf)(struct net_device___24 *, struct netdev_bpf___19 *);
	int (*ndo_xdp_xmit)(struct net_device___24 *, int, struct xdp_frame___19 **, u32);
	struct net_device___24 * (*ndo_xdp_get_xmit_slave)(struct net_device___24 *, struct xdp_buff___19 *);
	int (*ndo_xsk_wakeup)(struct net_device___24 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___24 *);
	int (*ndo_tunnel_ctl)(struct net_device___24 *, struct ip_tunnel_parm *, int);
	struct net_device___24 * (*ndo_get_peer_dev)(struct net_device___24 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___19 *, struct net_device_path___19 *);
};

struct neigh_parms___12 {
	possible_net_t___19 net;
	struct net_device___24 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___12 *);
	struct neigh_table___12 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___12 {
	u32 (*l3mdev_fib_table)(const struct net_device___24 *);
	struct sk_buff___21 * (*l3mdev_l3_rcv)(struct net_device___24 *, struct sk_buff___21 *, u16);
	struct sk_buff___21 * (*l3mdev_l3_out)(struct net_device___24 *, struct sock___13 *, struct sk_buff___21 *, u16);
	struct dst_entry___12 * (*l3mdev_link_scope_lookup)(const struct net_device___24 *, struct flowi6 *);
};

struct ndisc_ops___5 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___24 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___24 *, struct neighbour___12 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___24 *, u8, struct neighbour___12 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___24 *, struct sk_buff___21 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___22 *, struct net_device___24 *, const struct prefix_info *, struct inet6_dev___5 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___5;

struct inet6_dev___5 {
	struct net_device___24 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___5 *mc_list;
	struct ifmcaddr6___5 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___19 mc_query_queue;
	struct sk_buff_head___19 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___12 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___19;

struct tcf_block___19;

struct mini_Qdisc___19 {
	struct tcf_proto___19 *filter_list;
	struct tcf_block___19 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___19 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___24 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___24 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___22 *, struct net_device___24 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___24 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___24 *, struct list_head *);
	size_t (*get_size)(const struct net_device___24 *);
	int (*fill_info)(struct sk_buff___21 *, const struct net_device___24 *);
	size_t (*get_xstats_size)(const struct net_device___24 *);
	int (*fill_xstats)(struct sk_buff___21 *, const struct net_device___24 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___24 *, struct net_device___24 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___24 *, const struct net_device___24 *);
	int (*fill_slave_info)(struct sk_buff___21 *, const struct net_device___24 *, const struct net_device___24 *);
	struct net___22 * (*get_link_net)(const struct net_device___24 *);
	size_t (*get_linkxstats_size)(const struct net_device___24 *, int);
	int (*fill_linkxstats)(struct sk_buff___21 *, const struct net_device___24 *, int *, int);
};

struct gnet_dump___19 {
	spinlock_t *lock;
	struct sk_buff___21 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___19;

struct Qdisc_ops___19 {
	struct Qdisc_ops___19 *next;
	const struct Qdisc_class_ops___19 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___21 *, struct Qdisc___19 *, struct sk_buff___21 **);
	struct sk_buff___21 * (*dequeue)(struct Qdisc___19 *);
	struct sk_buff___21 * (*peek)(struct Qdisc___19 *);
	int (*init)(struct Qdisc___19 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___19 *);
	void (*destroy)(struct Qdisc___19 *);
	int (*change)(struct Qdisc___19 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___19 *);
	int (*change_tx_queue_len)(struct Qdisc___19 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___19 *, unsigned int);
	int (*dump)(struct Qdisc___19 *, struct sk_buff___21 *);
	int (*dump_stats)(struct Qdisc___19 *, struct gnet_dump___19 *);
	void (*ingress_block_set)(struct Qdisc___19 *, u32);
	void (*egress_block_set)(struct Qdisc___19 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___19 *);
	u32 (*egress_block_get)(struct Qdisc___19 *);
	struct module___80 *owner;
};

struct Qdisc_class_ops___19 {
	unsigned int flags;
	struct netdev_queue___19 * (*select_queue)(struct Qdisc___19 *, struct tcmsg *);
	int (*graft)(struct Qdisc___19 *, long unsigned int, struct Qdisc___19 *, struct Qdisc___19 **, struct netlink_ext_ack *);
	struct Qdisc___19 * (*leaf)(struct Qdisc___19 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___19 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___19 *, u32);
	int (*change)(struct Qdisc___19 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___19 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___19 *, struct qdisc_walker *);
	struct tcf_block___19 * (*tcf_block)(struct Qdisc___19 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___19 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___19 *, long unsigned int);
	int (*dump)(struct Qdisc___19 *, long unsigned int, struct sk_buff___21 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___19 *, long unsigned int, struct gnet_dump___19 *);
};

struct tcf_chain___19;

struct tcf_block___19 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___22 *net;
	struct Qdisc___19 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___19 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___19;

struct tcf_proto_ops___19;

struct tcf_proto___19 {
	struct tcf_proto___19 *next;
	void *root;
	int (*classify)(struct sk_buff___21 *, const struct tcf_proto___19 *, struct tcf_result___19 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___19 *ops;
	struct tcf_chain___19 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___19 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___19 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___19 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___21 *, const struct tcf_proto___19 *, struct tcf_result___19 *);
	int (*init)(struct tcf_proto___19 *);
	void (*destroy)(struct tcf_proto___19 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___19 *, u32);
	void (*put)(struct tcf_proto___19 *, void *);
	int (*change)(struct net___22 *, struct sk_buff___21 *, struct tcf_proto___19 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___19 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___19 *);
	void (*walk)(struct tcf_proto___19 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___19 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___19 *, void *);
	void (*hw_del)(struct tcf_proto___19 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___22 *, struct tcf_chain___19 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___22 *, struct tcf_proto___19 *, void *, struct sk_buff___21 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___22 *, struct tcf_proto___19 *, void *, struct sk_buff___21 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___21 *, struct net___22 *, void *);
	struct module___80 *owner;
	int flags;
};

struct tcf_chain___19 {
	struct mutex filter_chain_lock;
	struct tcf_proto___19 *filter_chain;
	struct list_head list;
	struct tcf_block___19 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___19 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___12 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___19 *prog;
};

struct pneigh_entry___12;

struct neigh_hash_table___12;

struct neigh_table___12 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___24 *, __u32 *);
	bool (*key_eq)(const struct neighbour___12 *, const void *);
	int (*constructor)(struct neighbour___12 *);
	int (*pconstructor)(struct pneigh_entry___12 *);
	void (*pdestructor)(struct pneigh_entry___12 *);
	void (*proxy_redo)(struct sk_buff___21 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___24 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___12 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___19 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___12 *nht;
	struct pneigh_entry___12 **phash_buckets;
};

struct neigh_ops___12 {
	int family;
	void (*solicit)(struct neighbour___12 *, struct sk_buff___21 *);
	void (*error_report)(struct neighbour___12 *, struct sk_buff___21 *);
	int (*output)(struct neighbour___12 *, struct sk_buff___21 *);
	int (*connected_output)(struct neighbour___12 *, struct sk_buff___21 *);
};

struct pneigh_entry___12 {
	struct pneigh_entry___12 *next;
	possible_net_t___19 net;
	struct net_device___24 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___12 {
	struct neighbour___12 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___3 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___22 *, struct sock___13 *, struct sk_buff___21 *);
	int (*orig_input)(struct sk_buff___21 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___12 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___12 *ctarget;
	struct net___22 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___12 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___12 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___6;

struct timewait_sock_ops___6;

struct proto___12 {
	void (*close)(struct sock___13 *, long int);
	int (*pre_connect)(struct sock___13 *, struct sockaddr *, int);
	int (*connect)(struct sock___13 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___13 *, int);
	struct sock___13 * (*accept)(struct sock___13 *, int, int *, bool);
	int (*ioctl)(struct sock___13 *, int, long unsigned int);
	int (*init)(struct sock___13 *);
	void (*destroy)(struct sock___13 *);
	void (*shutdown)(struct sock___13 *, int);
	int (*setsockopt)(struct sock___13 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___13 *, int, int, char *, int *);
	void (*keepalive)(struct sock___13 *, int);
	int (*compat_ioctl)(struct sock___13 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___13 *, struct msghdr___12 *, size_t);
	int (*recvmsg)(struct sock___13 *, struct msghdr___12 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___13 *, struct page___87 *, int, size_t, int);
	int (*bind)(struct sock___13 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___13 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___13 *, struct sk_buff___21 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___13 *);
	int (*hash)(struct sock___13 *);
	void (*unhash)(struct sock___13 *);
	void (*rehash)(struct sock___13 *);
	int (*get_port)(struct sock___13 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___13 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___13 *, int);
	bool (*sock_is_readable)(struct sock___13 *);
	void (*enter_memory_pressure)(struct sock___13 *);
	void (*leave_memory_pressure)(struct sock___13 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache___4 *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___6 *rsk_prot;
	struct timewait_sock_ops___6 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___80 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___13 *, int);
};

struct request_sock___6;

struct request_sock_ops___6 {
	int family;
	unsigned int obj_size;
	struct kmem_cache___4 *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___13 *, struct request_sock___6 *);
	void (*send_ack)(const struct sock___13 *, struct sk_buff___21 *, struct request_sock___6 *);
	void (*send_reset)(const struct sock___13 *, struct sk_buff___21 *);
	void (*destructor)(struct request_sock___6 *);
	void (*syn_ack_timeout)(const struct request_sock___6 *);
};

struct timewait_sock_ops___6 {
	struct kmem_cache___4 *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___13 *, struct sock___13 *, void *);
	void (*twsk_destructor)(struct sock___13 *);
};

struct request_sock___6 {
	struct sock_common___12 __req_common;
	struct request_sock___6 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___6 *rsk_ops;
	struct sock___13 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___5 {
	struct in6_addr mca_addr;
	struct inet6_dev___5 *idev;
	struct ifmcaddr6___5 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct kmem_cache_cpu___4 {
	void **freelist;
	long unsigned int tid;
	struct page___87 *page;
	struct page___87 *partial;
	local_lock_t lock;
};

struct mem_cgroup_tree_per_node {
	struct rb_root rb_root;
	struct rb_node *rb_rightmost;
	spinlock_t lock;
};

struct mem_cgroup_tree {
	struct mem_cgroup_tree_per_node *rb_tree_per_node[64];
};

struct mem_cgroup_eventfd_list {
	struct list_head list;
	struct eventfd_ctx *eventfd;
};

struct mem_cgroup_event {
	struct mem_cgroup___36 *memcg;
	struct eventfd_ctx *eventfd;
	struct list_head list;
	int (*register_event)(struct mem_cgroup___36 *, struct eventfd_ctx *, const char *);
	void (*unregister_event)(struct mem_cgroup___36 *, struct eventfd_ctx *);
	poll_table___15 pt;
	wait_queue_head_t *wqh;
	wait_queue_entry_t wait;
	struct work_struct remove;
};

struct move_charge_struct {
	spinlock_t lock;
	struct mm_struct___88 *mm;
	struct mem_cgroup___36 *from;
	struct mem_cgroup___36 *to;
	long unsigned int flags;
	long unsigned int precharge;
	long unsigned int moved_charge;
	long unsigned int moved_swap;
	struct task_struct___89 *moving_task;
	wait_queue_head_t waitq;
};

enum res_type {
	_MEM = 0,
	_MEMSWAP = 1,
	_OOM_TYPE = 2,
	_KMEM = 3,
	_TCP = 4,
};

struct memory_stat {
	const char *name;
	unsigned int idx;
};

struct oom_wait_info {
	struct mem_cgroup___36 *memcg;
	wait_queue_entry_t wait;
};

enum oom_status {
	OOM_SUCCESS = 0,
	OOM_FAILED = 1,
	OOM_ASYNC = 2,
	OOM_SKIPPED = 3,
};

struct obj_stock {
	struct obj_cgroup___36 *cached_objcg;
	struct pglist_data___41 *cached_pgdat;
	unsigned int nr_bytes;
	int nr_slab_reclaimable_b;
	int nr_slab_unreclaimable_b;
};

struct memcg_stock_pcp {
	struct mem_cgroup___36 *cached;
	unsigned int nr_pages;
	struct obj_stock task_obj;
	struct obj_stock irq_obj;
	struct work_struct work;
	long unsigned int flags;
};

enum {
	RES_USAGE = 0,
	RES_LIMIT = 1,
	RES_MAX_USAGE = 2,
	RES_FAILCNT = 3,
	RES_SOFT_LIMIT = 4,
};

union mc_target {
	struct page___87 *page;
	swp_entry_t ent;
};

enum mc_target_type {
	MC_TARGET_NONE = 0,
	MC_TARGET_PAGE = 1,
	MC_TARGET_SWAP = 2,
	MC_TARGET_DEVICE = 3,
};

struct uncharge_gather {
	struct mem_cgroup___36 *memcg;
	long unsigned int nr_memory;
	long unsigned int pgpgout;
	long unsigned int nr_kmem;
	struct page___87 *dummy_page;
};

struct numa_stat {
	const char *name;
	unsigned int lru_mask;
};

enum vmpressure_levels {
	VMPRESSURE_LOW = 0,
	VMPRESSURE_MEDIUM = 1,
	VMPRESSURE_CRITICAL = 2,
	VMPRESSURE_NUM_LEVELS = 3,
};

enum vmpressure_modes {
	VMPRESSURE_NO_PASSTHROUGH = 0,
	VMPRESSURE_HIERARCHY = 1,
	VMPRESSURE_LOCAL = 2,
	VMPRESSURE_NUM_MODES = 3,
};

struct vmpressure_event {
	struct eventfd_ctx *efd;
	enum vmpressure_levels level;
	enum vmpressure_modes mode;
	struct list_head node;
};

struct swap_cgroup_ctrl {
	struct page___78 **map;
	long unsigned int length;
	spinlock_t lock;
};

struct swap_cgroup {
	short unsigned int id;
};

struct resv_map___2 {
	struct kref refs;
	spinlock_t lock;
	struct list_head regions;
	long int adds_in_progress;
	struct list_head region_cache;
	long int region_cache_count;
	struct page_counter *reservation_counter;
	long unsigned int pages_per_hpage;
	struct cgroup_subsys_state___67 *css;
};

struct file_region___2 {
	struct list_head link;
	long int from;
	long int to;
	struct page_counter *reservation_counter;
	struct cgroup_subsys_state___67 *css;
};

struct hugetlb_cgroup___2 {
	struct cgroup_subsys_state___67 css;
	struct page_counter hugepage[4];
	struct page_counter rsvd_hugepage[4];
	atomic_long_t events[4];
	atomic_long_t events_local[4];
	struct cgroup_file___67 events_file[4];
	struct cgroup_file___67 events_local_file[4];
};

enum {
	RES_USAGE___2 = 0,
	RES_RSVD_USAGE = 1,
	RES_LIMIT___2 = 2,
	RES_RSVD_LIMIT = 3,
	RES_MAX_USAGE___2 = 4,
	RES_RSVD_MAX_USAGE = 5,
	RES_FAILCNT___2 = 6,
	RES_RSVD_FAILCNT = 7,
};

enum mf_result {
	MF_IGNORED = 0,
	MF_FAILED = 1,
	MF_DELAYED = 2,
	MF_RECOVERED = 3,
};

enum mf_action_page_type {
	MF_MSG_KERNEL = 0,
	MF_MSG_KERNEL_HIGH_ORDER = 1,
	MF_MSG_SLAB = 2,
	MF_MSG_DIFFERENT_COMPOUND = 3,
	MF_MSG_POISONED_HUGE = 4,
	MF_MSG_HUGE = 5,
	MF_MSG_FREE_HUGE = 6,
	MF_MSG_NON_PMD_HUGE = 7,
	MF_MSG_UNMAP_FAILED = 8,
	MF_MSG_DIRTY_SWAPCACHE = 9,
	MF_MSG_CLEAN_SWAPCACHE = 10,
	MF_MSG_DIRTY_MLOCKED_LRU = 11,
	MF_MSG_CLEAN_MLOCKED_LRU = 12,
	MF_MSG_DIRTY_UNEVICTABLE_LRU = 13,
	MF_MSG_CLEAN_UNEVICTABLE_LRU = 14,
	MF_MSG_DIRTY_LRU = 15,
	MF_MSG_CLEAN_LRU = 16,
	MF_MSG_TRUNCATED_LRU = 17,
	MF_MSG_BUDDY = 18,
	MF_MSG_BUDDY_2ND = 19,
	MF_MSG_DAX = 20,
	MF_MSG_UNSPLIT_THP = 21,
	MF_MSG_UNKNOWN = 22,
};

typedef long unsigned int dax_entry_t;

struct __kfifo {
	unsigned int in;
	unsigned int out;
	unsigned int mask;
	unsigned int esize;
	void *data;
};

struct to_kill {
	struct list_head nd;
	struct task_struct___80 *tsk;
	long unsigned int addr;
	short int size_shift;
};

struct hwp_walk {
	struct to_kill tk;
	long unsigned int pfn;
	int flags;
};

struct page_state {
	long unsigned int mask;
	long unsigned int res;
	enum mf_action_page_type type;
	int (*action)(struct page___78 *, long unsigned int);
};

struct memory_failure_entry {
	long unsigned int pfn;
	int flags;
};

struct memory_failure_cpu {
	struct {
		union {
			struct __kfifo kfifo;
			struct memory_failure_entry *type;
			const struct memory_failure_entry *const_type;
			char (*rectype)[0];
			struct memory_failure_entry *ptr;
			const struct memory_failure_entry *ptr_const;
		};
		struct memory_failure_entry buf[16];
	} fifo;
	spinlock_t lock;
	struct work_struct work;
};

struct dentry___83;

struct super_block___83;

struct module___81;

struct file_system_type___83 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___83 * (*mount)(struct file_system_type___83 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___83 *);
	struct module___81 *owner;
	struct file_system_type___83 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___83;

struct kiocb___83;

struct vm_area_struct___88;

struct inode___83;

struct file_lock___83;

struct page___88;

struct seq_file___78;

struct file_operations___83 {
	struct module___81 *owner;
	loff_t (*llseek)(struct file___83 *, loff_t, int);
	ssize_t (*read)(struct file___83 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___83 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___83 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___83 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___83 *, bool);
	int (*iterate)(struct file___83 *, struct dir_context *);
	int (*iterate_shared)(struct file___83 *, struct dir_context *);
	__poll_t (*poll)(struct file___83 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___83 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___83 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___83 *, struct vm_area_struct___88 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___83 *, struct file___83 *);
	int (*flush)(struct file___83 *, fl_owner_t);
	int (*release)(struct inode___83 *, struct file___83 *);
	int (*fsync)(struct file___83 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___83 *, int);
	int (*lock)(struct file___83 *, int, struct file_lock___83 *);
	ssize_t (*sendpage)(struct file___83 *, struct page___88 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___83 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___83 *, long unsigned int);
	int (*flock)(struct file___83 *, int, struct file_lock___83 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___83 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___83 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___83 *, long int, struct file_lock___83 **, void **);
	long int (*fallocate)(struct file___83 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___78 *, struct file___83 *);
	ssize_t (*copy_file_range)(struct file___83 *, loff_t, struct file___83 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___83 *, loff_t, struct file___83 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___83 *, loff_t, loff_t, int);
};

struct vmacache___88 {
	u64 seqnum;
	struct vm_area_struct___88 *vmas[4];
};

struct page_frag___88 {
	struct page___88 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___89;

struct signal_struct___84;

struct task_struct___90 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___90 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___89 *mm;
	struct mm_struct___89 *active_mm;
	struct vmacache___88 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___90 *real_parent;
	struct task_struct___90 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___90 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___75 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___84 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___90 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___39 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___88 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___90 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___83;

struct kobj_type___83;

struct kernfs_node___83;

struct kobject___83 {
	const char *name;
	struct list_head entry;
	struct kobject___83 *parent;
	struct kset___83 *kset;
	struct kobj_type___83 *ktype;
	struct kernfs_node___83 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___80 {
	struct kobject___83 kobj;
	struct module___81 *mod;
	struct kobject___83 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___80 {
	struct module___81 *mod;
	struct latch_tree_node node;
};

struct module_layout___80 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___80 mtn;
};

struct module_attribute___80;

struct kernel_param___80;

struct module___81 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___80 mkobj;
	struct module_attribute___80 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___83 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___80 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___80 core_layout;
	struct module_layout___80 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___88 *pgtable_t___88;

struct address_space___83;

struct dev_pagemap___82;

struct page___88 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___83 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___28 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___88 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___88 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___89 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___82 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___82;

struct vm_area_struct___88 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___88 *vm_next;
	struct vm_area_struct___88 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___89 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___82 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___83 *vm_file;
	struct file___83 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___84 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___90 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___90 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___75 *pids[4];
	struct pid___75 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___89 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___88;

struct mm_struct___89 {
	struct {
		struct vm_area_struct___88 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___83 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___88 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___90 *owner;
		struct user_namespace *user_ns;
		struct file___83 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___83;

struct address_space___83 {
	struct inode___83 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___83 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___82;

struct dev_pagemap___82 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___82 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___83;

struct path___83 {
	struct vfsmount___83 *mnt;
	struct dentry___83 *dentry;
};

struct file___83 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___83 f_path;
	struct inode___83 *f_inode;
	const struct file_operations___83 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___75 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___83 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___82;

struct vm_operations_struct___82 {
	void (*open)(struct vm_area_struct___88 *);
	void (*close)(struct vm_area_struct___88 *);
	int (*may_split)(struct vm_area_struct___88 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___88 *);
	int (*mprotect)(struct vm_area_struct___88 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___82 *);
	vm_fault_t (*huge_fault)(struct vm_fault___82 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___82 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___88 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___82 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___82 *);
	int (*access)(struct vm_area_struct___88 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___88 *);
	int (*set_policy)(struct vm_area_struct___88 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___88 *, long unsigned int);
	struct page___88 * (*find_special_page)(struct vm_area_struct___88 *, long unsigned int);
};

struct core_thread___88 {
	struct task_struct___90 *task;
	struct core_thread___88 *next;
};

struct core_state___88 {
	atomic_t nr_threads;
	struct core_thread___88 dumper;
	struct completion startup;
};

struct vm_fault___82 {
	const struct {
		struct vm_area_struct___88 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___88 *cow_page;
	struct page___88 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___88 prealloc_pte;
};

struct dentry_operations___83;

struct dentry___83 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___83 *d_parent;
	struct qstr d_name;
	struct inode___83 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___83 *d_op;
	struct super_block___83 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___83;

struct inode___83 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___83 *i_op;
	struct super_block___83 *i_sb;
	struct address_space___83 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___83 *i_fop;
		void (*free_inode)(struct inode___83 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___83 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___33 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___83 {
	int (*d_revalidate)(struct dentry___83 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___83 *, unsigned int);
	int (*d_hash)(const struct dentry___83 *, struct qstr *);
	int (*d_compare)(const struct dentry___83 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___83 *);
	int (*d_init)(struct dentry___83 *);
	void (*d_release)(struct dentry___83 *);
	void (*d_prune)(struct dentry___83 *);
	void (*d_iput)(struct dentry___83 *, struct inode___83 *);
	char * (*d_dname)(struct dentry___83 *, char *, int);
	struct vfsmount___83 * (*d_automount)(struct path___83 *);
	int (*d_manage)(const struct path___83 *, bool);
	struct dentry___83 * (*d_real)(struct dentry___83 *, const struct inode___83 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___83;

struct mem_dqinfo___83 {
	struct quota_format_type___83 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___83;

struct quota_info___83 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___83 *files[3];
	struct mem_dqinfo___83 info[3];
	const struct quota_format_ops___83 *ops[3];
};

struct rcuwait___84 {
	struct task_struct___90 *task;
};

struct percpu_rw_semaphore___84 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___84 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___83 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___84 rw_sem[3];
};

struct super_operations___83;

struct dquot_operations___83;

struct quotactl_ops___83;

struct export_operations___3;

struct super_block___83 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___83 *s_type;
	const struct super_operations___83 *s_op;
	const struct dquot_operations___83 *dq_op;
	const struct quotactl_ops___83 *s_qcop;
	const struct export_operations___3 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___83 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___83 s_dquot;
	struct sb_writers___83 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___83 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___83 {
	struct dentry___83 *mnt_root;
	struct super_block___83 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___83 {
	struct file___83 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___83 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___40 *ki_waitq;
	};
};

struct iattr___83 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___83 *ia_file;
};

struct dquot___83 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___83 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___83 {
	int qf_fmt_id;
	const struct quota_format_ops___83 *qf_ops;
	struct module___81 *qf_owner;
	struct quota_format_type___83 *qf_next;
};

struct quota_format_ops___83 {
	int (*check_quota_file)(struct super_block___83 *, int);
	int (*read_file_info)(struct super_block___83 *, int);
	int (*write_file_info)(struct super_block___83 *, int);
	int (*free_file_info)(struct super_block___83 *, int);
	int (*read_dqblk)(struct dquot___83 *);
	int (*commit_dqblk)(struct dquot___83 *);
	int (*release_dqblk)(struct dquot___83 *);
	int (*get_next_id)(struct super_block___83 *, struct kqid *);
};

struct dquot_operations___83 {
	int (*write_dquot)(struct dquot___83 *);
	struct dquot___83 * (*alloc_dquot)(struct super_block___83 *, int);
	void (*destroy_dquot)(struct dquot___83 *);
	int (*acquire_dquot)(struct dquot___83 *);
	int (*release_dquot)(struct dquot___83 *);
	int (*mark_dirty)(struct dquot___83 *);
	int (*write_info)(struct super_block___83 *, int);
	qsize_t * (*get_reserved_space)(struct inode___83 *);
	int (*get_projid)(struct inode___83 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___83 *, qsize_t *);
	int (*get_next_id)(struct super_block___83 *, struct kqid *);
};

struct quotactl_ops___83 {
	int (*quota_on)(struct super_block___83 *, int, int, const struct path___83 *);
	int (*quota_off)(struct super_block___83 *, int);
	int (*quota_enable)(struct super_block___83 *, unsigned int);
	int (*quota_disable)(struct super_block___83 *, unsigned int);
	int (*quota_sync)(struct super_block___83 *, int);
	int (*set_info)(struct super_block___83 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___83 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___83 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___83 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___83 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___83 *, unsigned int);
};

struct address_space_operations___83 {
	int (*writepage)(struct page___88 *, struct writeback_control___3 *);
	int (*readpage)(struct file___83 *, struct page___88 *);
	int (*writepages)(struct address_space___83 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___88 *);
	int (*readpages)(struct file___83 *, struct address_space___83 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___83 *, struct address_space___83 *, loff_t, unsigned int, unsigned int, struct page___88 **, void **);
	int (*write_end)(struct file___83 *, struct address_space___83 *, loff_t, unsigned int, unsigned int, struct page___88 *, void *);
	sector_t (*bmap)(struct address_space___83 *, sector_t);
	void (*invalidatepage)(struct page___88 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___88 *, gfp_t);
	void (*freepage)(struct page___88 *);
	ssize_t (*direct_IO)(struct kiocb___83 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___83 *, struct page___88 *, struct page___88 *, enum migrate_mode);
	bool (*isolate_page)(struct page___88 *, isolate_mode_t);
	void (*putback_page)(struct page___88 *);
	int (*launder_page)(struct page___88 *);
	int (*is_partially_uptodate)(struct page___88 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___88 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___83 *, struct page___88 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___83 *, sector_t *);
	void (*swap_deactivate)(struct file___83 *);
};

struct inode_operations___83 {
	struct dentry___83 * (*lookup)(struct inode___83 *, struct dentry___83 *, unsigned int);
	const char * (*get_link)(struct dentry___83 *, struct inode___83 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___83 *, int);
	struct posix_acl * (*get_acl)(struct inode___83 *, int, bool);
	int (*readlink)(struct dentry___83 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___83 *, struct dentry___83 *, umode_t, bool);
	int (*link)(struct dentry___83 *, struct inode___83 *, struct dentry___83 *);
	int (*unlink)(struct inode___83 *, struct dentry___83 *);
	int (*symlink)(struct user_namespace *, struct inode___83 *, struct dentry___83 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___83 *, struct dentry___83 *, umode_t);
	int (*rmdir)(struct inode___83 *, struct dentry___83 *);
	int (*mknod)(struct user_namespace *, struct inode___83 *, struct dentry___83 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___83 *, struct dentry___83 *, struct inode___83 *, struct dentry___83 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___83 *, struct iattr___83 *);
	int (*getattr)(struct user_namespace *, const struct path___83 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___83 *, char *, size_t);
	int (*fiemap)(struct inode___83 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___83 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___83 *, struct dentry___83 *, struct file___83 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___83 *, struct dentry___83 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___83 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___83 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___83 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___83 {
	void (*fl_copy_lock)(struct file_lock___83 *, struct file_lock___83 *);
	void (*fl_release_private)(struct file_lock___83 *);
};

struct fasync_struct___83;

struct lock_manager_operations___83;

struct file_lock___83 {
	struct file_lock___83 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___83 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___83 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___83 *fl_ops;
	const struct lock_manager_operations___83 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___83 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___83 *);
	int (*lm_grant)(struct file_lock___83 *, int);
	bool (*lm_break)(struct file_lock___83 *);
	int (*lm_change)(struct file_lock___83 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___83 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___83 *);
};

struct fasync_struct___83 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___83 *fa_next;
	struct file___83 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___83 {
	struct inode___83 * (*alloc_inode)(struct super_block___83 *);
	void (*destroy_inode)(struct inode___83 *);
	void (*free_inode)(struct inode___83 *);
	void (*dirty_inode)(struct inode___83 *, int);
	int (*write_inode)(struct inode___83 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___83 *);
	void (*evict_inode)(struct inode___83 *);
	void (*put_super)(struct super_block___83 *);
	int (*sync_fs)(struct super_block___83 *, int);
	int (*freeze_super)(struct super_block___83 *);
	int (*freeze_fs)(struct super_block___83 *);
	int (*thaw_super)(struct super_block___83 *);
	int (*unfreeze_fs)(struct super_block___83 *);
	int (*statfs)(struct dentry___83 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___83 *, int *, char *);
	void (*umount_begin)(struct super_block___83 *);
	int (*show_options)(struct seq_file___78 *, struct dentry___83 *);
	int (*show_devname)(struct seq_file___78 *, struct dentry___83 *);
	int (*show_path)(struct seq_file___78 *, struct dentry___83 *);
	int (*show_stats)(struct seq_file___78 *, struct dentry___83 *);
	ssize_t (*quota_read)(struct super_block___83 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___83 *, int, const char *, size_t, loff_t);
	struct dquot___83 ** (*get_dquots)(struct inode___83 *);
	long int (*nr_cached_objects)(struct super_block___83 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___83 *, struct shrink_control___36 *);
	struct file___83 * (*real_loop)(struct file___83 *);
};

struct export_operations___3 {
	int (*encode_fh)(struct inode___83 *, __u32 *, int *, struct inode___83 *);
	struct dentry___83 * (*fh_to_dentry)(struct super_block___83 *, struct fid *, int, int);
	struct dentry___83 * (*fh_to_parent)(struct super_block___83 *, struct fid *, int, int);
	int (*get_name)(struct dentry___83 *, char *, struct dentry___83 *);
	struct dentry___83 * (*get_parent)(struct dentry___83 *);
	int (*commit_metadata)(struct inode___83 *);
	int (*get_uuid)(struct super_block___83 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___83 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___83 *, struct iomap *, int, struct iattr___83 *);
	u64 (*fetch_iversion)(struct inode___83 *);
	long unsigned int flags;
};

struct seq_operations___78;

struct seq_file___78 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___78 *op;
	int poll_event;
	const struct file___83 *file;
	void *private;
};

struct kernfs_root___83;

struct kernfs_elem_dir___83 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___83 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___83;

struct kernfs_root___83 {
	struct kernfs_node___83 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___83 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___83 {
	struct kernfs_node___83 *target_kn;
};

struct kernfs_ops___83;

struct kernfs_elem_attr___83 {
	const struct kernfs_ops___83 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___83 *notify_next;
};

struct kernfs_node___83 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___83 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___83 dir;
		struct kernfs_elem_symlink___83 symlink;
		struct kernfs_elem_attr___83 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___83;

struct kernfs_ops___83 {
	int (*open)(struct kernfs_open_file___83 *);
	void (*release)(struct kernfs_open_file___83 *);
	int (*seq_show)(struct seq_file___78 *, void *);
	void * (*seq_start)(struct seq_file___78 *, loff_t *);
	void * (*seq_next)(struct seq_file___78 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___78 *, void *);
	ssize_t (*read)(struct kernfs_open_file___83 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___83 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___83 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___83 *, struct vm_area_struct___88 *);
};

struct kernfs_syscall_ops___83 {
	int (*show_options)(struct seq_file___78 *, struct kernfs_root___83 *);
	int (*mkdir)(struct kernfs_node___83 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___83 *);
	int (*rename)(struct kernfs_node___83 *, struct kernfs_node___83 *, const char *);
	int (*show_path)(struct seq_file___78 *, struct kernfs_node___83 *, struct kernfs_root___83 *);
};

struct kernfs_open_file___83 {
	struct kernfs_node___83 *kn;
	struct file___83 *file;
	struct seq_file___78 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___82 *vm_ops;
};

struct bin_attribute___83;

struct attribute_group___83 {
	const char *name;
	umode_t (*is_visible)(struct kobject___83 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___83 *, struct bin_attribute___83 *, int);
	struct attribute **attrs;
	struct bin_attribute___83 **bin_attrs;
};

struct bin_attribute___83 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___83 * (*f_mapping)();
	ssize_t (*read)(struct file___83 *, struct kobject___83 *, struct bin_attribute___83 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___83 *, struct kobject___83 *, struct bin_attribute___83 *, char *, loff_t, size_t);
	int (*mmap)(struct file___83 *, struct kobject___83 *, struct bin_attribute___83 *, struct vm_area_struct___88 *);
};

struct sysfs_ops___83 {
	ssize_t (*show)(struct kobject___83 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___83 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___83;

struct kset___83 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___83 kobj;
	const struct kset_uevent_ops___83 *uevent_ops;
};

struct kobj_type___83 {
	void (*release)(struct kobject___83 *);
	const struct sysfs_ops___83 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___83 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___83 *);
	const void * (*namespace)(struct kobject___83 *);
	void (*get_ownership)(struct kobject___83 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___83 {
	int (* const filter)(struct kset___83 *, struct kobject___83 *);
	const char * (* const name)(struct kset___83 *, struct kobject___83 *);
	int (* const uevent)(struct kset___83 *, struct kobject___83 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___80 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___80 *);
	int (*get)(char *, const struct kernel_param___80 *);
	void (*free)(void *);
};

struct kparam_array___80;

struct kernel_param___80 {
	const char *name;
	struct module___81 *mod;
	const struct kernel_param_ops___80 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___80 *arr;
	};
};

struct kparam_array___80 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___80 *ops;
	void *elem;
};

struct module_attribute___80 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___80 *, struct module_kobject___80 *, char *);
	ssize_t (*store)(struct module_attribute___80 *, struct module_kobject___80 *, const char *, size_t);
	void (*setup)(struct module___81 *, const char *);
	int (*test)(struct module___81 *);
	void (*free)(struct module___81 *);
};

struct dev_pagemap_ops___82 {
	void (*page_free)(struct page___88 *);
	void (*kill)(struct dev_pagemap___82 *);
	void (*cleanup)(struct dev_pagemap___82 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___82 *);
};

struct seq_operations___78 {
	void * (*start)(struct seq_file___78 *, loff_t *);
	void (*stop)(struct seq_file___78 *, void *);
	void * (*next)(struct seq_file___78 *, void *, loff_t *);
	int (*show)(struct seq_file___78 *, void *);
};

struct cleancache_filekey {
	union {
		ino_t ino;
		__u32 fh[6];
		u32 key[6];
	} u;
};

struct cleancache_ops {
	int (*init_fs)(size_t);
	int (*init_shared_fs)(uuid_t *, size_t);
	int (*get_page)(int, struct cleancache_filekey, long unsigned int, struct page___88 *);
	void (*put_page)(int, struct cleancache_filekey, long unsigned int, struct page___88 *);
	void (*invalidate_page)(int, struct cleancache_filekey, long unsigned int);
	void (*invalidate_inode)(int, struct cleancache_filekey);
	void (*invalidate_fs)(int);
};

struct trace_event_raw_test_pages_isolated {
	struct trace_entry ent;
	long unsigned int start_pfn;
	long unsigned int end_pfn;
	long unsigned int fin_pfn;
	char __data[0];
};

struct trace_event_data_offsets_test_pages_isolated {};

typedef void (*btf_trace_test_pages_isolated)(void *, long unsigned int, long unsigned int, long unsigned int);

struct zpool_driver;

struct zpool {
	struct zpool_driver *driver;
	void *pool;
	const struct zpool_ops *ops;
	bool evictable;
	bool can_sleep_mapped;
	struct list_head list;
};

struct zpool_driver {
	char *type;
	struct module___79 *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(const char *, gfp_t, const struct zpool_ops *, struct zpool *);
	void (*destroy)(void *);
	bool malloc_support_movable;
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	bool sleep_mapped;
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

typedef void (*exitcall_t)();

struct zpool_driver___2 {
	char *type;
	struct module___81 *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(const char *, gfp_t, const struct zpool_ops *, struct zpool *);
	void (*destroy)(void *);
	bool malloc_support_movable;
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	bool sleep_mapped;
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

struct zbud_pool;

struct zbud_ops {
	int (*evict)(struct zbud_pool *, long unsigned int);
};

struct zbud_pool {
	spinlock_t lock;
	union {
		struct list_head buddied;
		struct list_head unbuddied[63];
	};
	struct list_head lru;
	u64 pages_nr;
	const struct zbud_ops *ops;
	struct zpool *zpool;
	const struct zpool_ops *zpool_ops;
};

struct zbud_header {
	struct list_head buddy;
	struct list_head lru;
	unsigned int first_chunks;
	unsigned int last_chunks;
	bool under_reclaim;
};

enum buddy {
	FIRST = 0,
	LAST = 1,
};

struct fs_context___14;

struct dentry___84;

struct super_block___84;

struct module___82;

struct file_system_type___84 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___14 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___84 * (*mount)(struct file_system_type___84 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___84 *);
	struct module___82 *owner;
	struct file_system_type___84 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___84;

struct kiocb___84;

struct vm_area_struct___89;

struct inode___84;

struct file_lock___84;

struct page___89;

struct seq_file___79;

struct file_operations___84 {
	struct module___82 *owner;
	loff_t (*llseek)(struct file___84 *, loff_t, int);
	ssize_t (*read)(struct file___84 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___84 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___84 *, struct iov_iter___49 *);
	ssize_t (*write_iter)(struct kiocb___84 *, struct iov_iter___49 *);
	int (*iopoll)(struct kiocb___84 *, bool);
	int (*iterate)(struct file___84 *, struct dir_context *);
	int (*iterate_shared)(struct file___84 *, struct dir_context *);
	__poll_t (*poll)(struct file___84 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___84 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___84 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___84 *, struct vm_area_struct___89 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___84 *, struct file___84 *);
	int (*flush)(struct file___84 *, fl_owner_t);
	int (*release)(struct inode___84 *, struct file___84 *);
	int (*fsync)(struct file___84 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___84 *, int);
	int (*lock)(struct file___84 *, int, struct file_lock___84 *);
	ssize_t (*sendpage)(struct file___84 *, struct page___89 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___84 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___84 *, long unsigned int);
	int (*flock)(struct file___84 *, int, struct file_lock___84 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___84 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___84 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___84 *, long int, struct file_lock___84 **, void **);
	long int (*fallocate)(struct file___84 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___79 *, struct file___84 *);
	ssize_t (*copy_file_range)(struct file___84 *, loff_t, struct file___84 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___84 *, loff_t, struct file___84 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___84 *, loff_t, loff_t, int);
};

struct vmacache___89 {
	u64 seqnum;
	struct vm_area_struct___89 *vmas[4];
};

struct page_frag___89 {
	struct page___89 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___90;

struct pid___76;

struct nsproxy___81;

struct signal_struct___85;

struct css_set___69;

struct vm_struct___84;

struct task_struct___91 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___91 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___90 *mm;
	struct mm_struct___90 *active_mm;
	struct vmacache___89 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___91 *real_parent;
	struct task_struct___91 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___91 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___76 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___81 *nsproxy;
	struct signal_struct___85 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___91 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___39 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___69 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___89 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___91 *oom_reaper_list;
	struct vm_struct___84 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___50 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___84;

struct kobj_type___84;

struct kernfs_node___84;

struct kobject___84 {
	const char *name;
	struct list_head entry;
	struct kobject___84 *parent;
	struct kset___84 *kset;
	struct kobj_type___84 *ktype;
	struct kernfs_node___84 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___81 {
	struct kobject___84 kobj;
	struct module___82 *mod;
	struct kobject___84 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___81 {
	struct module___82 *mod;
	struct latch_tree_node node;
};

struct module_layout___81 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___81 mtn;
};

struct module_attribute___81;

struct kernel_param___81;

struct module___82 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___81 mkobj;
	struct module_attribute___81 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___84 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___81 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___81 core_layout;
	struct module_layout___81 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___76;

struct upid___76 {
	int nr;
	struct pid_namespace___76 *ns;
};

struct pid_namespace___76 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___91 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___76 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___76 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___76 numbers[1];
};

typedef struct page___89 *pgtable_t___89;

struct address_space___84;

struct dev_pagemap___83;

struct page___89 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___84 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___28 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___89 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___89 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___90 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___83 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___83;

struct vm_area_struct___89 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___89 *vm_next;
	struct vm_area_struct___89 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___90 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___83 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___84 *vm_file;
	struct file___84 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___85 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___91 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___91 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___76 *pids[4];
	struct pid___76 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___90 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___89;

struct mm_struct___90 {
	struct {
		struct vm_area_struct___89 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___84 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___89 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___91 *owner;
		struct user_namespace___12 *user_ns;
		struct file___84 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___69;

struct nsproxy___81 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___76 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___69 *cgroup_ns;
};

struct cgroup_subsys_state___69;

struct cgroup___69;

struct css_set___69 {
	struct cgroup_subsys_state___69 *subsys[14];
	refcount_t refcount;
	struct css_set___69 *dom_cset;
	struct cgroup___69 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___69 *mg_src_cgrp;
	struct cgroup___69 *mg_dst_cgrp;
	struct css_set___69 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___84 {
	struct vm_struct___84 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___89 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___84;

struct address_space___84 {
	struct inode___84 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___84 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___83;

struct dev_pagemap___83 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___83 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___84;

struct path___84 {
	struct vfsmount___84 *mnt;
	struct dentry___84 *dentry;
};

struct fown_struct___76 {
	rwlock_t lock;
	struct pid___76 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___84 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___84 f_path;
	struct inode___84 *f_inode;
	const struct file_operations___84 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___76 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___84 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___83;

struct vm_operations_struct___83 {
	void (*open)(struct vm_area_struct___89 *);
	void (*close)(struct vm_area_struct___89 *);
	int (*may_split)(struct vm_area_struct___89 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___89 *);
	int (*mprotect)(struct vm_area_struct___89 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___83 *);
	vm_fault_t (*huge_fault)(struct vm_fault___83 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___83 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___89 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___83 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___83 *);
	int (*access)(struct vm_area_struct___89 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___89 *);
	int (*set_policy)(struct vm_area_struct___89 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___89 *, long unsigned int);
	struct page___89 * (*find_special_page)(struct vm_area_struct___89 *, long unsigned int);
};

struct core_thread___89 {
	struct task_struct___91 *task;
	struct core_thread___89 *next;
};

struct core_state___89 {
	atomic_t nr_threads;
	struct core_thread___89 dumper;
	struct completion startup;
};

struct vm_fault___83 {
	const struct {
		struct vm_area_struct___89 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___89 *cow_page;
	struct page___89 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___89 prealloc_pte;
};

struct pglist_data___42;

struct lruvec___42 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___42 *pgdat;
};

struct zone___42 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___42 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___42 {
	struct zone___42 *zone;
	int zone_idx;
};

struct zonelist___42 {
	struct zoneref___42 _zonerefs[321];
};

struct pglist_data___42 {
	struct zone___42 node_zones[5];
	struct zonelist___42 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___91 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___91 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___42 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___42 pg_data_t___11;

struct dentry_operations___84;

struct dentry___84 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___84 *d_parent;
	struct qstr d_name;
	struct inode___84 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___84 *d_op;
	struct super_block___84 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___84;

struct inode___84 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___84 *i_op;
	struct super_block___84 *i_sb;
	struct address_space___84 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___84 *i_fop;
		void (*free_inode)(struct inode___84 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___84 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___33 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___84 {
	int (*d_revalidate)(struct dentry___84 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___84 *, unsigned int);
	int (*d_hash)(const struct dentry___84 *, struct qstr *);
	int (*d_compare)(const struct dentry___84 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___84 *);
	int (*d_init)(struct dentry___84 *);
	void (*d_release)(struct dentry___84 *);
	void (*d_prune)(struct dentry___84 *);
	void (*d_iput)(struct dentry___84 *, struct inode___84 *);
	char * (*d_dname)(struct dentry___84 *, char *, int);
	struct vfsmount___84 * (*d_automount)(struct path___84 *);
	int (*d_manage)(const struct path___84 *, bool);
	struct dentry___84 * (*d_real)(struct dentry___84 *, const struct inode___84 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___84;

struct mem_dqinfo___84 {
	struct quota_format_type___84 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___84;

struct quota_info___84 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___84 *files[3];
	struct mem_dqinfo___84 info[3];
	const struct quota_format_ops___84 *ops[3];
};

struct rcuwait___85 {
	struct task_struct___91 *task;
};

struct percpu_rw_semaphore___85 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___85 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___84 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___85 rw_sem[3];
};

struct super_operations___84;

struct dquot_operations___84;

struct quotactl_ops___84;

struct super_block___84 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___84 *s_type;
	const struct super_operations___84 *s_op;
	const struct dquot_operations___84 *dq_op;
	const struct quotactl_ops___84 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___84 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___84 s_dquot;
	struct sb_writers___84 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___84 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___84 {
	struct dentry___84 *mnt_root;
	struct super_block___84 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct cgroup_subsys___69;

struct cgroup_subsys_state___69 {
	struct cgroup___69 *cgroup;
	struct cgroup_subsys___69 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___69 *parent;
};

struct cgroup_file___69 {
	struct kernfs_node___84 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___69 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___91 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___69;

struct cgroup_rstat_cpu___69;

struct cgroup___69 {
	struct cgroup_subsys_state___69 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___84 *kn;
	struct cgroup_file___69 procs_file;
	struct cgroup_file___69 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___69 *subsys[14];
	struct cgroup_root___69 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___69 *dom_cgrp;
	struct cgroup___69 *old_dom_cgrp;
	struct cgroup_rstat_cpu___69 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___69 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___41;

struct kiocb___84 {
	struct file___84 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___84 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___41 *ki_waitq;
	};
};

struct iattr___84 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___84 *ia_file;
};

struct dquot___84 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___84 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___84 {
	int qf_fmt_id;
	const struct quota_format_ops___84 *qf_ops;
	struct module___82 *qf_owner;
	struct quota_format_type___84 *qf_next;
};

struct quota_format_ops___84 {
	int (*check_quota_file)(struct super_block___84 *, int);
	int (*read_file_info)(struct super_block___84 *, int);
	int (*write_file_info)(struct super_block___84 *, int);
	int (*free_file_info)(struct super_block___84 *, int);
	int (*read_dqblk)(struct dquot___84 *);
	int (*commit_dqblk)(struct dquot___84 *);
	int (*release_dqblk)(struct dquot___84 *);
	int (*get_next_id)(struct super_block___84 *, struct kqid *);
};

struct dquot_operations___84 {
	int (*write_dquot)(struct dquot___84 *);
	struct dquot___84 * (*alloc_dquot)(struct super_block___84 *, int);
	void (*destroy_dquot)(struct dquot___84 *);
	int (*acquire_dquot)(struct dquot___84 *);
	int (*release_dquot)(struct dquot___84 *);
	int (*mark_dirty)(struct dquot___84 *);
	int (*write_info)(struct super_block___84 *, int);
	qsize_t * (*get_reserved_space)(struct inode___84 *);
	int (*get_projid)(struct inode___84 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___84 *, qsize_t *);
	int (*get_next_id)(struct super_block___84 *, struct kqid *);
};

struct quotactl_ops___84 {
	int (*quota_on)(struct super_block___84 *, int, int, const struct path___84 *);
	int (*quota_off)(struct super_block___84 *, int);
	int (*quota_enable)(struct super_block___84 *, unsigned int);
	int (*quota_disable)(struct super_block___84 *, unsigned int);
	int (*quota_sync)(struct super_block___84 *, int);
	int (*set_info)(struct super_block___84 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___84 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___84 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___84 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___84 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___84 *, unsigned int);
};

struct wait_page_queue___41 {
	struct page___89 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___41;

struct address_space_operations___84 {
	int (*writepage)(struct page___89 *, struct writeback_control___3 *);
	int (*readpage)(struct file___84 *, struct page___89 *);
	int (*writepages)(struct address_space___84 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___89 *);
	int (*readpages)(struct file___84 *, struct address_space___84 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___41 *);
	int (*write_begin)(struct file___84 *, struct address_space___84 *, loff_t, unsigned int, unsigned int, struct page___89 **, void **);
	int (*write_end)(struct file___84 *, struct address_space___84 *, loff_t, unsigned int, unsigned int, struct page___89 *, void *);
	sector_t (*bmap)(struct address_space___84 *, sector_t);
	void (*invalidatepage)(struct page___89 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___89 *, gfp_t);
	void (*freepage)(struct page___89 *);
	ssize_t (*direct_IO)(struct kiocb___84 *, struct iov_iter___49 *);
	int (*migratepage)(struct address_space___84 *, struct page___89 *, struct page___89 *, enum migrate_mode);
	bool (*isolate_page)(struct page___89 *, isolate_mode_t);
	void (*putback_page)(struct page___89 *);
	int (*launder_page)(struct page___89 *);
	int (*is_partially_uptodate)(struct page___89 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___89 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___84 *, struct page___89 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___84 *, sector_t *);
	void (*swap_deactivate)(struct file___84 *);
};

struct readahead_control___41 {
	struct file___84 *file;
	struct address_space___84 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___84 {
	struct dentry___84 * (*lookup)(struct inode___84 *, struct dentry___84 *, unsigned int);
	const char * (*get_link)(struct dentry___84 *, struct inode___84 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___84 *, int);
	struct posix_acl * (*get_acl)(struct inode___84 *, int, bool);
	int (*readlink)(struct dentry___84 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___84 *, struct dentry___84 *, umode_t, bool);
	int (*link)(struct dentry___84 *, struct inode___84 *, struct dentry___84 *);
	int (*unlink)(struct inode___84 *, struct dentry___84 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___84 *, struct dentry___84 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___84 *, struct dentry___84 *, umode_t);
	int (*rmdir)(struct inode___84 *, struct dentry___84 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___84 *, struct dentry___84 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___84 *, struct dentry___84 *, struct inode___84 *, struct dentry___84 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___84 *, struct iattr___84 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___84 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___84 *, char *, size_t);
	int (*fiemap)(struct inode___84 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___84 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___84 *, struct dentry___84 *, struct file___84 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___84 *, struct dentry___84 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___84 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___84 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___84 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___84 {
	void (*fl_copy_lock)(struct file_lock___84 *, struct file_lock___84 *);
	void (*fl_release_private)(struct file_lock___84 *);
};

struct fasync_struct___84;

struct lock_manager_operations___84;

struct file_lock___84 {
	struct file_lock___84 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___84 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___84 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___84 *fl_ops;
	const struct lock_manager_operations___84 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___84 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___84 *);
	int (*lm_grant)(struct file_lock___84 *, int);
	bool (*lm_break)(struct file_lock___84 *);
	int (*lm_change)(struct file_lock___84 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___84 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___84 *);
};

struct fasync_struct___84 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___84 *fa_next;
	struct file___84 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___84 {
	struct inode___84 * (*alloc_inode)(struct super_block___84 *);
	void (*destroy_inode)(struct inode___84 *);
	void (*free_inode)(struct inode___84 *);
	void (*dirty_inode)(struct inode___84 *, int);
	int (*write_inode)(struct inode___84 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___84 *);
	void (*evict_inode)(struct inode___84 *);
	void (*put_super)(struct super_block___84 *);
	int (*sync_fs)(struct super_block___84 *, int);
	int (*freeze_super)(struct super_block___84 *);
	int (*freeze_fs)(struct super_block___84 *);
	int (*thaw_super)(struct super_block___84 *);
	int (*unfreeze_fs)(struct super_block___84 *);
	int (*statfs)(struct dentry___84 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___84 *, int *, char *);
	void (*umount_begin)(struct super_block___84 *);
	int (*show_options)(struct seq_file___79 *, struct dentry___84 *);
	int (*show_devname)(struct seq_file___79 *, struct dentry___84 *);
	int (*show_path)(struct seq_file___79 *, struct dentry___84 *);
	int (*show_stats)(struct seq_file___79 *, struct dentry___84 *);
	ssize_t (*quota_read)(struct super_block___84 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___84 *, int, const char *, size_t, loff_t);
	struct dquot___84 ** (*get_dquots)(struct inode___84 *);
	long int (*nr_cached_objects)(struct super_block___84 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___84 *, struct shrink_control___36 *);
	struct file___84 * (*real_loop)(struct file___84 *);
};

struct seq_operations___79;

struct seq_file___79 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___79 *op;
	int poll_event;
	const struct file___84 *file;
	void *private;
};

struct fc_log___14;

struct p_log___14 {
	const char *prefix;
	struct fc_log___14 *log;
};

struct fs_context_operations___14;

struct fs_context___14 {
	const struct fs_context_operations___14 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___84 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___84 *root;
	struct user_namespace___12 *user_ns;
	struct net *net_ns;
	const struct cred___11 *cred;
	struct p_log___14 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___84;

struct kernfs_elem_dir___84 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___84 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___84;

struct kernfs_root___84 {
	struct kernfs_node___84 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___84 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___84 {
	struct kernfs_node___84 *target_kn;
};

struct kernfs_ops___84;

struct kernfs_elem_attr___84 {
	const struct kernfs_ops___84 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___84 *notify_next;
};

struct kernfs_node___84 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___84 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___84 dir;
		struct kernfs_elem_symlink___84 symlink;
		struct kernfs_elem_attr___84 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___84;

struct kernfs_ops___84 {
	int (*open)(struct kernfs_open_file___84 *);
	void (*release)(struct kernfs_open_file___84 *);
	int (*seq_show)(struct seq_file___79 *, void *);
	void * (*seq_start)(struct seq_file___79 *, loff_t *);
	void * (*seq_next)(struct seq_file___79 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___79 *, void *);
	ssize_t (*read)(struct kernfs_open_file___84 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___84 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___84 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___84 *, struct vm_area_struct___89 *);
};

struct kernfs_syscall_ops___84 {
	int (*show_options)(struct seq_file___79 *, struct kernfs_root___84 *);
	int (*mkdir)(struct kernfs_node___84 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___84 *);
	int (*rename)(struct kernfs_node___84 *, struct kernfs_node___84 *, const char *);
	int (*show_path)(struct seq_file___79 *, struct kernfs_node___84 *, struct kernfs_root___84 *);
};

struct kernfs_open_file___84 {
	struct kernfs_node___84 *kn;
	struct file___84 *file;
	struct seq_file___79 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___83 *vm_ops;
};

struct bin_attribute___84;

struct attribute_group___84 {
	const char *name;
	umode_t (*is_visible)(struct kobject___84 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___84 *, struct bin_attribute___84 *, int);
	struct attribute **attrs;
	struct bin_attribute___84 **bin_attrs;
};

struct bin_attribute___84 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___84 * (*f_mapping)();
	ssize_t (*read)(struct file___84 *, struct kobject___84 *, struct bin_attribute___84 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___84 *, struct kobject___84 *, struct bin_attribute___84 *, char *, loff_t, size_t);
	int (*mmap)(struct file___84 *, struct kobject___84 *, struct bin_attribute___84 *, struct vm_area_struct___89 *);
};

struct sysfs_ops___84 {
	ssize_t (*show)(struct kobject___84 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___84 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___84;

struct kset___84 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___84 kobj;
	const struct kset_uevent_ops___84 *uevent_ops;
};

struct kobj_type___84 {
	void (*release)(struct kobject___84 *);
	const struct sysfs_ops___84 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___84 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___84 *);
	const void * (*namespace)(struct kobject___84 *);
	void (*get_ownership)(struct kobject___84 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___84 {
	int (* const filter)(struct kset___84 *, struct kobject___84 *);
	const char * (* const name)(struct kset___84 *, struct kobject___84 *);
	int (* const uevent)(struct kset___84 *, struct kobject___84 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___81 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___81 *);
	int (*get)(char *, const struct kernel_param___81 *);
	void (*free)(void *);
};

struct kparam_array___81;

struct kernel_param___81 {
	const char *name;
	struct module___82 *mod;
	const struct kernel_param_ops___81 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___81 *arr;
	};
};

struct kparam_array___81 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___81 *ops;
	void *elem;
};

struct module_attribute___81 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___81 *, struct module_kobject___81 *, char *);
	ssize_t (*store)(struct module_attribute___81 *, struct module_kobject___81 *, const char *, size_t);
	void (*setup)(struct module___82 *, const char *);
	int (*test)(struct module___82 *);
	void (*free)(struct module___82 *);
};

struct dev_pagemap_ops___83 {
	void (*page_free)(struct page___89 *);
	void (*kill)(struct dev_pagemap___83 *);
	void (*cleanup)(struct dev_pagemap___83 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___83 *);
};

struct cgroup_namespace___69 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___69 *root_cset;
};

struct seq_operations___79 {
	void * (*start)(struct seq_file___79 *, loff_t *);
	void (*stop)(struct seq_file___79 *, void *);
	void * (*next)(struct seq_file___79 *, void *, loff_t *);
	int (*show)(struct seq_file___79 *, void *);
};

enum zs_mapmode {
	ZS_MM_RW = 0,
	ZS_MM_RO = 1,
	ZS_MM_WO = 2,
};

struct zs_pool_stats {
	atomic_long_t pages_compacted;
};

struct zpool_driver___3 {
	char *type;
	struct module___82 *owner;
	atomic_t refcount;
	struct list_head list;
	void * (*create)(const char *, gfp_t, const struct zpool_ops *, struct zpool *);
	void (*destroy)(void *);
	bool malloc_support_movable;
	int (*malloc)(void *, size_t, gfp_t, long unsigned int *);
	void (*free)(void *, long unsigned int);
	int (*shrink)(void *, unsigned int, unsigned int *);
	bool sleep_mapped;
	void * (*map)(void *, long unsigned int, enum zpool_mapmode);
	void (*unmap)(void *, long unsigned int);
	u64 (*total_size)(void *);
};

struct fs_parameter___14 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___84 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___14 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___82 *owner;
	char *buffer[8];
};

struct fs_context_operations___14 {
	void (*free)(struct fs_context___14 *);
	int (*dup)(struct fs_context___14 *, struct fs_context___14 *);
	int (*parse_param)(struct fs_context___14 *, struct fs_parameter___14 *);
	int (*parse_monolithic)(struct fs_context___14 *, void *);
	int (*get_tree)(struct fs_context___14 *);
	int (*reconfigure)(struct fs_context___14 *);
};

struct pseudo_fs_context___2 {
	const struct super_operations___84 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___84 *dops;
	long unsigned int magic;
};

struct cftype___69;

struct cgroup_subsys___69 {
	struct cgroup_subsys_state___69 * (*css_alloc)(struct cgroup_subsys_state___69 *);
	int (*css_online)(struct cgroup_subsys_state___69 *);
	void (*css_offline)(struct cgroup_subsys_state___69 *);
	void (*css_released)(struct cgroup_subsys_state___69 *);
	void (*css_free)(struct cgroup_subsys_state___69 *);
	void (*css_reset)(struct cgroup_subsys_state___69 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___69 *, int);
	int (*css_extra_stat_show)(struct seq_file___79 *, struct cgroup_subsys_state___69 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___91 *, struct css_set___69 *);
	void (*cancel_fork)(struct task_struct___91 *, struct css_set___69 *);
	void (*fork)(struct task_struct___91 *);
	void (*exit)(struct task_struct___91 *);
	void (*release)(struct task_struct___91 *);
	void (*bind)(struct cgroup_subsys_state___69 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___69 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___69 *dfl_cftypes;
	struct cftype___69 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___69 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___69 *updated_children;
	struct cgroup___69 *updated_next;
};

struct cgroup_root___69 {
	struct kernfs_root___84 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___69 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___69 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___69 *ss;
	struct list_head node;
	struct kernfs_ops___84 *kf_ops;
	int (*open)(struct kernfs_open_file___84 *);
	void (*release)(struct kernfs_open_file___84 *);
	u64 (*read_u64)(struct cgroup_subsys_state___69 *, struct cftype___69 *);
	s64 (*read_s64)(struct cgroup_subsys_state___69 *, struct cftype___69 *);
	int (*seq_show)(struct seq_file___79 *, void *);
	void * (*seq_start)(struct seq_file___79 *, loff_t *);
	void * (*seq_next)(struct seq_file___79 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___79 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___69 *, struct cftype___69 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___69 *, struct cftype___69 *, s64);
	ssize_t (*write)(struct kernfs_open_file___84 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___84 *, struct poll_table_struct___5 *);
};

enum fullness_group {
	ZS_EMPTY = 0,
	ZS_ALMOST_EMPTY = 1,
	ZS_ALMOST_FULL = 2,
	ZS_FULL = 3,
	NR_ZS_FULLNESS = 4,
};

enum zs_stat_type {
	CLASS_EMPTY = 0,
	CLASS_ALMOST_EMPTY = 1,
	CLASS_ALMOST_FULL = 2,
	CLASS_FULL = 3,
	OBJ_ALLOCATED = 4,
	OBJ_USED = 5,
	NR_ZS_STAT_TYPE = 6,
};

struct zs_size_stat {
	long unsigned int objs[6];
};

struct size_class {
	spinlock_t lock;
	struct list_head fullness_list[4];
	int size;
	int objs_per_zspage;
	int pages_per_zspage;
	unsigned int index;
	struct zs_size_stat stats;
};

struct link_free {
	union {
		long unsigned int next;
		long unsigned int handle;
	};
};

struct zs_pool {
	const char *name;
	struct size_class *size_class[255];
	struct kmem_cache *handle_cachep;
	struct kmem_cache *zspage_cachep;
	atomic_long_t pages_allocated;
	struct zs_pool_stats stats;
	struct shrinker___36 shrinker;
	struct inode___84 *inode;
	struct work_struct free_work;
	struct wait_queue_head migration_wait;
	atomic_long_t isolated_pages;
	bool destroying;
};

struct zspage {
	struct {
		unsigned int fullness: 2;
		unsigned int class: 9;
		unsigned int isolated: 3;
		unsigned int magic: 8;
	};
	unsigned int inuse;
	unsigned int freeobj;
	struct page___89 *first_page;
	struct list_head list;
	rwlock_t lock;
};

struct mapping_area {
	char *vm_buf;
	char *vm_addr;
	enum zs_mapmode vm_mm;
};

struct zs_compact_control {
	struct page___89 *s_page;
	struct page___89 *d_page;
	int obj_idx;
};

struct trace_event_raw_cma_alloc_class {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int pfn;
	const struct page___80 *page;
	long unsigned int count;
	unsigned int align;
	char __data[0];
};

struct trace_event_raw_cma_release {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int pfn;
	const struct page___80 *page;
	long unsigned int count;
	char __data[0];
};

struct trace_event_raw_cma_alloc_start {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int count;
	unsigned int align;
	char __data[0];
};

struct trace_event_data_offsets_cma_alloc_class {
	u32 name;
};

struct trace_event_data_offsets_cma_release {
	u32 name;
};

struct trace_event_data_offsets_cma_alloc_start {
	u32 name;
};

typedef void (*btf_trace_cma_release)(void *, const char *, long unsigned int, const struct page___80 *, long unsigned int);

typedef void (*btf_trace_cma_alloc_start)(void *, const char *, long unsigned int, unsigned int);

typedef void (*btf_trace_cma_alloc_finish)(void *, const char *, long unsigned int, const struct page___80 *, long unsigned int, unsigned int);

typedef void (*btf_trace_cma_alloc_busy_retry)(void *, const char *, long unsigned int, const struct page___80 *, long unsigned int, unsigned int);

struct cma_kobject {
	struct kobject___75 kobj;
	struct cma *cma;
};

struct balloon_dev_info {
	long unsigned int isolated_pages;
	spinlock_t pages_lock;
	struct list_head pages;
	int (*migratepage)(struct balloon_dev_info *, struct page___85 *, struct page___85 *, enum migrate_mode);
	struct inode___80 *inode;
};

struct pseudo_fs_context___3 {
	const struct super_operations___75 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___75 *dops;
	long unsigned int magic;
};

struct cma___2;

struct cma_kobject___2 {
	struct kobject___83 kobj;
	struct cma___2 *cma;
};

struct cma___2 {
	long unsigned int base_pfn;
	long unsigned int count;
	long unsigned int *bitmap;
	unsigned int order_per_bit;
	spinlock_t lock;
	char name[64];
	atomic64_t nr_pages_succeeded;
	atomic64_t nr_pages_failed;
	struct cma_kobject___2 *cma_kobj;
};

enum {
	BAD_STACK = 0,
	NOT_STACK = 0,
	GOOD_FRAME = 1,
	GOOD_STACK = 2,
};

struct mmu_interval_notifier___2;

struct mmu_interval_notifier_ops___2 {
	bool (*invalidate)(struct mmu_interval_notifier___2 *, const struct mmu_notifier_range___8 *, long unsigned int);
};

struct mmu_interval_notifier___2 {
	struct interval_tree_node interval_tree;
	const struct mmu_interval_notifier_ops___2 *ops;
	struct mm_struct___79 *mm;
	struct hlist_node deferred_item;
	long unsigned int invalidate_seq;
};

enum hmm_pfn_flags {
	HMM_PFN_VALID = 0,
	HMM_PFN_WRITE = 0,
	HMM_PFN_ERROR = 0,
	HMM_PFN_ORDER_SHIFT = 56,
	HMM_PFN_REQ_FAULT = 0,
	HMM_PFN_REQ_WRITE = 0,
	HMM_PFN_FLAGS = 0,
};

struct hmm_range {
	struct mmu_interval_notifier___2 *notifier;
	long unsigned int notifier_seq;
	long unsigned int start;
	long unsigned int end;
	long unsigned int *hmm_pfns;
	long unsigned int default_flags;
	long unsigned int pfn_flags_mask;
	void *dev_private_owner;
};

struct hmm_vma_walk {
	struct hmm_range *range;
	long unsigned int last;
};

enum {
	HMM_NEED_FAULT = 1,
	HMM_NEED_WRITE_FAULT = 2,
	HMM_NEED_ALL_BITS = 3,
};

struct hugetlbfs_inode_info {
	struct shared_policy policy;
	struct inode___2 vfs_inode;
	unsigned int seals;
};

struct wp_walk {
	struct mmu_notifier_range___10 range;
	long unsigned int tlbflush_start;
	long unsigned int tlbflush_end;
	long unsigned int total;
};

struct clean_walk {
	struct wp_walk base;
	long unsigned int bitmap_pgoff;
	long unsigned int *bitmap;
	long unsigned int start;
	long unsigned int end;
};

struct page_reporting_dev_info {
	int (*report)(struct page_reporting_dev_info *, struct scatterlist *, unsigned int);
	struct delayed_work work;
	atomic_t state;
	unsigned int order;
};

enum {
	PAGE_REPORTING_IDLE = 0,
	PAGE_REPORTING_REQUESTED = 1,
	PAGE_REPORTING_ACTIVE = 2,
};

struct dentry___85;

struct super_block___85;

struct module___83;

struct file_system_type___85 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___85 * (*mount)(struct file_system_type___85 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___85 *);
	struct module___83 *owner;
	struct file_system_type___85 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___85;

struct kiocb___85;

struct iov_iter___50;

struct poll_table_struct___61;

struct vm_area_struct___90;

struct inode___85;

struct file_lock___85;

struct page___90;

struct seq_file___80;

struct file_operations___85 {
	struct module___83 *owner;
	loff_t (*llseek)(struct file___85 *, loff_t, int);
	ssize_t (*read)(struct file___85 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___85 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___85 *, struct iov_iter___50 *);
	ssize_t (*write_iter)(struct kiocb___85 *, struct iov_iter___50 *);
	int (*iopoll)(struct kiocb___85 *, bool);
	int (*iterate)(struct file___85 *, struct dir_context *);
	int (*iterate_shared)(struct file___85 *, struct dir_context *);
	__poll_t (*poll)(struct file___85 *, struct poll_table_struct___61 *);
	long int (*unlocked_ioctl)(struct file___85 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___85 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___85 *, struct vm_area_struct___90 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___85 *, struct file___85 *);
	int (*flush)(struct file___85 *, fl_owner_t);
	int (*release)(struct inode___85 *, struct file___85 *);
	int (*fsync)(struct file___85 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___85 *, int);
	int (*lock)(struct file___85 *, int, struct file_lock___85 *);
	ssize_t (*sendpage)(struct file___85 *, struct page___90 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___85 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___85 *, long unsigned int);
	int (*flock)(struct file___85 *, int, struct file_lock___85 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___85 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___85 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___85 *, long int, struct file_lock___85 **, void **);
	long int (*fallocate)(struct file___85 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___80 *, struct file___85 *);
	ssize_t (*copy_file_range)(struct file___85 *, loff_t, struct file___85 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___85 *, loff_t, struct file___85 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___85 *, loff_t, loff_t, int);
};

struct vmacache___90 {
	u64 seqnum;
	struct vm_area_struct___90 *vmas[4];
};

struct page_frag___90 {
	struct page___90 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___51;

struct debug_info___51 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___51 *hbp_break[16];
	struct perf_event___51 *hbp_watch[16];
};

struct thread_struct___51 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___51 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___91;

struct pid___77;

struct fs_struct___10;

struct files_struct___7;

struct nsproxy___82;

struct signal_struct___86;

struct bio_list___40;

struct backing_dev_info___39;

struct io_context___40;

struct css_set___70;

struct perf_event_context___51;

struct request_queue___40;

struct vm_struct___85;

struct task_struct___92 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___92 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___91 *mm;
	struct mm_struct___91 *active_mm;
	struct vmacache___90 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___92 *real_parent;
	struct task_struct___92 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___92 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___77 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___10 *fs;
	struct files_struct___7 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___82 *nsproxy;
	struct signal_struct___86 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___92 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___40 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___39 *backing_dev_info;
	struct io_context___40 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___70 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___51 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___90 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___40 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___92 *oom_reaper_list;
	struct vm_struct___85 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___51 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___85;

struct kobj_type___85;

struct kernfs_node___85;

struct kobject___85 {
	const char *name;
	struct list_head entry;
	struct kobject___85 *parent;
	struct kset___85 *kset;
	struct kobj_type___85 *ktype;
	struct kernfs_node___85 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___82 {
	struct kobject___85 kobj;
	struct module___83 *mod;
	struct kobject___85 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___82 {
	struct module___83 *mod;
	struct latch_tree_node node;
};

struct module_layout___82 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___82 mtn;
};

struct module_attribute___82;

struct kernel_param___82;

struct trace_event_call___45;

struct module___83 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___82 mkobj;
	struct module_attribute___82 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___85 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___82 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___82 core_layout;
	struct module_layout___82 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___45 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___51 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___92 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___51)(struct perf_event___51 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___51;

struct fasync_struct___85;

struct pid_namespace___77;

struct perf_cgroup___51;

struct perf_event___51 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___51 *group_leader;
	struct pmu___51 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___51 hw;
	struct perf_event_context___51 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___51 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___92 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___85 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___51 *aux_event;
	void (*destroy)(struct perf_event___51 *);
	struct callback_head callback_head;
	struct pid_namespace___77 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___51 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___51 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___45 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___51 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___90 *pgtable_t___90;

struct address_space___85;

struct dev_pagemap___84;

struct page___90 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___85 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___28 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___90 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___90 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___91 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___84 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___84;

struct vm_area_struct___90 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___90 *vm_next;
	struct vm_area_struct___90 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___91 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___84 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___85 *vm_file;
	struct file___85 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___90;

struct mm_struct___91 {
	struct {
		struct vm_area_struct___90 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___85 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___90 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___92 *owner;
		struct user_namespace___12 *user_ns;
		struct file___85 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___85;

struct address_space___85 {
	struct inode___85 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___85 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___84;

struct dev_pagemap___84 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___84 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___85;

struct path___85 {
	struct vfsmount___85 *mnt;
	struct dentry___85 *dentry;
};

struct fown_struct___77 {
	rwlock_t lock;
	struct pid___77 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___85 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___85 f_path;
	struct inode___85 *f_inode;
	const struct file_operations___85 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___77 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___85 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___84;

struct vm_operations_struct___84 {
	void (*open)(struct vm_area_struct___90 *);
	void (*close)(struct vm_area_struct___90 *);
	int (*may_split)(struct vm_area_struct___90 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___90 *);
	int (*mprotect)(struct vm_area_struct___90 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___84 *);
	vm_fault_t (*huge_fault)(struct vm_fault___84 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___84 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___90 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___84 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___84 *);
	int (*access)(struct vm_area_struct___90 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___90 *);
	int (*set_policy)(struct vm_area_struct___90 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___90 *, long unsigned int);
	struct page___90 * (*find_special_page)(struct vm_area_struct___90 *, long unsigned int);
};

struct core_thread___90 {
	struct task_struct___92 *task;
	struct core_thread___90 *next;
};

struct core_state___90 {
	atomic_t nr_threads;
	struct core_thread___90 dumper;
	struct completion startup;
};

struct vm_fault___84 {
	const struct {
		struct vm_area_struct___90 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___90 *cow_page;
	struct page___90 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___90 prealloc_pte;
};

struct dev_pagemap_ops___84 {
	void (*page_free)(struct page___90 *);
	void (*kill)(struct dev_pagemap___84 *);
	void (*cleanup)(struct dev_pagemap___84 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___84 *);
};

struct upid___77 {
	int nr;
	struct pid_namespace___77 *ns;
};

struct pid_namespace___77 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___92 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___77 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___77 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___77 numbers[1];
};

struct tty_struct___10;

struct signal_struct___86 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___92 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___92 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___77 *pids[4];
	struct pid___77 *tty_old_pgrp;
	int leader;
	struct tty_struct___10 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___91 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___10 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___85 root;
	struct path___85 pwd;
};

struct fdtable___7 {
	unsigned int max_fds;
	struct file___85 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___7 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___7 *fdt;
	struct fdtable___7 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___85 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___70;

struct nsproxy___82 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___77 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___70 *cgroup_ns;
};

struct bio___40;

struct bio_list___40 {
	struct bio___40 *head;
	struct bio___40 *tail;
};

struct cgroup_subsys_state___70;

struct bdi_writeback___39 {
	struct backing_dev_info___39 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___70 *memcg_css;
	struct cgroup_subsys_state___70 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___71;

struct backing_dev_info___39 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___39 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___71 *dev;
	char dev_name[64];
	struct device___71 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___85 *debug_dir;
};

struct io_cq___40;

struct io_context___40 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___40 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___70;

struct css_set___70 {
	struct cgroup_subsys_state___70 *subsys[14];
	refcount_t refcount;
	struct css_set___70 *dom_cset;
	struct cgroup___70 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___70 *mg_src_cgrp;
	struct cgroup___70 *mg_dst_cgrp;
	struct css_set___70 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___51 {
	struct pmu___51 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___92 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___51 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___40;

struct blk_integrity___40 {
	const struct blk_integrity_profile___40 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___40 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___40 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___40;

struct elevator_queue___40;

struct blk_mq_ops___39;

struct blk_mq_hw_ctx___39;

struct gendisk___40;

struct blkcg_gq___39;

struct blk_mq_tag_set___39;

struct request_queue___40 {
	struct request___40 *last_merge;
	struct elevator_queue___40 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___39 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___39 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___40 *disk;
	struct kobject___85 kobj;
	struct kobject___85 *mq_kobj;
	struct blk_integrity___40 integrity;
	struct device___71 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___39 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___39 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___40 bio_split;
	struct dentry___85 *debugfs_dir;
	struct dentry___85 *sched_debugfs_dir;
	struct dentry___85 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___85 {
	struct vm_struct___85 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___90 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___85;

struct dentry___85 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___85 *d_parent;
	struct qstr d_name;
	struct inode___85 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___85 *d_op;
	struct super_block___85 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___85;

struct cdev___20;

struct inode___85 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___85 *i_op;
	struct super_block___85 *i_sb;
	struct address_space___85 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___39 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___85 *i_fop;
		void (*free_inode)(struct inode___85 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___85 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___20 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___85 {
	int (*d_revalidate)(struct dentry___85 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___85 *, unsigned int);
	int (*d_hash)(const struct dentry___85 *, struct qstr *);
	int (*d_compare)(const struct dentry___85 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___85 *);
	int (*d_init)(struct dentry___85 *);
	void (*d_release)(struct dentry___85 *);
	void (*d_prune)(struct dentry___85 *);
	void (*d_iput)(struct dentry___85 *, struct inode___85 *);
	char * (*d_dname)(struct dentry___85 *, char *, int);
	struct vfsmount___85 * (*d_automount)(struct path___85 *);
	int (*d_manage)(const struct path___85 *, bool);
	struct dentry___85 * (*d_real)(struct dentry___85 *, const struct inode___85 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___85;

struct mem_dqinfo___85 {
	struct quota_format_type___85 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___85;

struct quota_info___85 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___85 *files[3];
	struct mem_dqinfo___85 info[3];
	const struct quota_format_ops___85 *ops[3];
};

struct rcuwait___86 {
	struct task_struct___92 *task;
};

struct percpu_rw_semaphore___86 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___86 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___85 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___86 rw_sem[3];
};

struct super_operations___85;

struct dquot_operations___85;

struct quotactl_ops___85;

struct block_device___41;

struct super_block___85 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___85 *s_type;
	const struct super_operations___85 *s_op;
	const struct dquot_operations___85 *dq_op;
	const struct quotactl_ops___85 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___85 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___41 *s_bdev;
	struct backing_dev_info___39 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___85 s_dquot;
	struct sb_writers___85 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___85 *s_d_op;
	int cleancache_poolid;
	struct shrinker___36 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___85 {
	struct dentry___85 *mnt_root;
	struct super_block___85 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

typedef s32 compat_off_t;

struct open_how {
	__u64 flags;
	__u64 mode;
	__u64 resolve;
};

struct cgroup_subsys___70;

struct cgroup_subsys_state___70 {
	struct cgroup___70 *cgroup;
	struct cgroup_subsys___70 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___70 *parent;
};

struct cgroup_file___70 {
	struct kernfs_node___85 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___70 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___92 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___70;

struct cgroup_rstat_cpu___70;

struct cgroup___70 {
	struct cgroup_subsys_state___70 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___85 *kn;
	struct cgroup_file___70 procs_file;
	struct cgroup_file___70 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___70 *subsys[14];
	struct cgroup_root___70 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___70 *dom_cgrp;
	struct cgroup___70 *old_dom_cgrp;
	struct cgroup_rstat_cpu___70 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___70 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___10;

struct tty_operations___10;

struct tty_ldisc___10;

struct tty_port___10;

struct tty_struct___10 {
	int magic;
	struct kref kref;
	struct device___71 *dev;
	struct tty_driver___10 *driver;
	const struct tty_operations___10 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___10 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___77 *pgrp;
		struct pid___77 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___10 *link;
	struct fasync_struct___85 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___10 *port;
};

struct io_cq___40 {
	struct request_queue___40 *q;
	struct io_context___40 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___42;

struct kiocb___85 {
	struct file___85 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___85 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___42 *ki_waitq;
	};
};

struct iattr___85 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___85 *ia_file;
};

struct dquot___85 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___85 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___85 {
	int qf_fmt_id;
	const struct quota_format_ops___85 *qf_ops;
	struct module___83 *qf_owner;
	struct quota_format_type___85 *qf_next;
};

struct quota_format_ops___85 {
	int (*check_quota_file)(struct super_block___85 *, int);
	int (*read_file_info)(struct super_block___85 *, int);
	int (*write_file_info)(struct super_block___85 *, int);
	int (*free_file_info)(struct super_block___85 *, int);
	int (*read_dqblk)(struct dquot___85 *);
	int (*commit_dqblk)(struct dquot___85 *);
	int (*release_dqblk)(struct dquot___85 *);
	int (*get_next_id)(struct super_block___85 *, struct kqid *);
};

struct dquot_operations___85 {
	int (*write_dquot)(struct dquot___85 *);
	struct dquot___85 * (*alloc_dquot)(struct super_block___85 *, int);
	void (*destroy_dquot)(struct dquot___85 *);
	int (*acquire_dquot)(struct dquot___85 *);
	int (*release_dquot)(struct dquot___85 *);
	int (*mark_dirty)(struct dquot___85 *);
	int (*write_info)(struct super_block___85 *, int);
	qsize_t * (*get_reserved_space)(struct inode___85 *);
	int (*get_projid)(struct inode___85 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___85 *, qsize_t *);
	int (*get_next_id)(struct super_block___85 *, struct kqid *);
};

struct quotactl_ops___85 {
	int (*quota_on)(struct super_block___85 *, int, int, const struct path___85 *);
	int (*quota_off)(struct super_block___85 *, int);
	int (*quota_enable)(struct super_block___85 *, unsigned int);
	int (*quota_disable)(struct super_block___85 *, unsigned int);
	int (*quota_sync)(struct super_block___85 *, int);
	int (*set_info)(struct super_block___85 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___85 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___85 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___85 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___85 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___85 *, unsigned int);
};

struct wait_page_queue___42 {
	struct page___90 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___39;

struct readahead_control___42;

struct address_space_operations___85 {
	int (*writepage)(struct page___90 *, struct writeback_control___39 *);
	int (*readpage)(struct file___85 *, struct page___90 *);
	int (*writepages)(struct address_space___85 *, struct writeback_control___39 *);
	int (*set_page_dirty)(struct page___90 *);
	int (*readpages)(struct file___85 *, struct address_space___85 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___42 *);
	int (*write_begin)(struct file___85 *, struct address_space___85 *, loff_t, unsigned int, unsigned int, struct page___90 **, void **);
	int (*write_end)(struct file___85 *, struct address_space___85 *, loff_t, unsigned int, unsigned int, struct page___90 *, void *);
	sector_t (*bmap)(struct address_space___85 *, sector_t);
	void (*invalidatepage)(struct page___90 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___90 *, gfp_t);
	void (*freepage)(struct page___90 *);
	ssize_t (*direct_IO)(struct kiocb___85 *, struct iov_iter___50 *);
	int (*migratepage)(struct address_space___85 *, struct page___90 *, struct page___90 *, enum migrate_mode);
	bool (*isolate_page)(struct page___90 *, isolate_mode_t);
	void (*putback_page)(struct page___90 *);
	int (*launder_page)(struct page___90 *);
	int (*is_partially_uptodate)(struct page___90 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___90 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___85 *, struct page___90 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___85 *, sector_t *);
	void (*swap_deactivate)(struct file___85 *);
};

struct writeback_control___39 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___39 *wb;
	struct inode___85 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___42 {
	struct file___85 *file;
	struct address_space___85 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___49;

struct iov_iter___50 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___49 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___20 {
	struct kobject___85 kobj;
	struct module___83 *owner;
	const struct file_operations___85 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___85 {
	struct dentry___85 * (*lookup)(struct inode___85 *, struct dentry___85 *, unsigned int);
	const char * (*get_link)(struct dentry___85 *, struct inode___85 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___85 *, int);
	struct posix_acl * (*get_acl)(struct inode___85 *, int, bool);
	int (*readlink)(struct dentry___85 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___85 *, struct dentry___85 *, umode_t, bool);
	int (*link)(struct dentry___85 *, struct inode___85 *, struct dentry___85 *);
	int (*unlink)(struct inode___85 *, struct dentry___85 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___85 *, struct dentry___85 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___85 *, struct dentry___85 *, umode_t);
	int (*rmdir)(struct inode___85 *, struct dentry___85 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___85 *, struct dentry___85 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___85 *, struct dentry___85 *, struct inode___85 *, struct dentry___85 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___85 *, struct iattr___85 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___85 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___85 *, char *, size_t);
	int (*fiemap)(struct inode___85 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___85 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___85 *, struct dentry___85 *, struct file___85 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___85 *, struct dentry___85 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___85 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___85 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___85 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___85 {
	void (*fl_copy_lock)(struct file_lock___85 *, struct file_lock___85 *);
	void (*fl_release_private)(struct file_lock___85 *);
};

struct lock_manager_operations___85;

struct file_lock___85 {
	struct file_lock___85 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___85 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___85 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___85 *fl_ops;
	const struct lock_manager_operations___85 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___85 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___85 *);
	int (*lm_grant)(struct file_lock___85 *, int);
	bool (*lm_break)(struct file_lock___85 *);
	int (*lm_change)(struct file_lock___85 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___85 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___85 *);
};

struct fasync_struct___85 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___85 *fa_next;
	struct file___85 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___85 {
	struct inode___85 * (*alloc_inode)(struct super_block___85 *);
	void (*destroy_inode)(struct inode___85 *);
	void (*free_inode)(struct inode___85 *);
	void (*dirty_inode)(struct inode___85 *, int);
	int (*write_inode)(struct inode___85 *, struct writeback_control___39 *);
	int (*drop_inode)(struct inode___85 *);
	void (*evict_inode)(struct inode___85 *);
	void (*put_super)(struct super_block___85 *);
	int (*sync_fs)(struct super_block___85 *, int);
	int (*freeze_super)(struct super_block___85 *);
	int (*freeze_fs)(struct super_block___85 *);
	int (*thaw_super)(struct super_block___85 *);
	int (*unfreeze_fs)(struct super_block___85 *);
	int (*statfs)(struct dentry___85 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___85 *, int *, char *);
	void (*umount_begin)(struct super_block___85 *);
	int (*show_options)(struct seq_file___80 *, struct dentry___85 *);
	int (*show_devname)(struct seq_file___80 *, struct dentry___85 *);
	int (*show_path)(struct seq_file___80 *, struct dentry___85 *);
	int (*show_stats)(struct seq_file___80 *, struct dentry___85 *);
	ssize_t (*quota_read)(struct super_block___85 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___85 *, int, const char *, size_t, loff_t);
	struct dquot___85 ** (*get_dquots)(struct inode___85 *);
	long int (*nr_cached_objects)(struct super_block___85 *, struct shrink_control___36 *);
	long int (*free_cached_objects)(struct super_block___85 *, struct shrink_control___36 *);
	struct file___85 * (*real_loop)(struct file___85 *);
};

struct wakeup_source___71;

struct dev_pm_info___71 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___71 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___71 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___71;

struct bus_type___71;

struct device_driver___71;

struct dev_pm_domain___71;

struct fwnode_handle___71;

struct class___71;

struct attribute_group___85;

struct device___71 {
	struct kobject___85 kobj;
	struct device___71 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___71 *type;
	struct bus_type___71 *bus;
	struct device_driver___71 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___71 power;
	struct dev_pm_domain___71 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___71 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___71 *class;
	const struct attribute_group___85 **groups;
	void (*release)(struct device___71 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___41 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___85 *bd_inode;
	struct super_block___85 *bd_super;
	void *bd_claiming;
	struct device___71 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___85 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___40 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___85 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___61)(struct file___85 *, wait_queue_head_t *, struct poll_table_struct___61 *);

struct poll_table_struct___61 {
	poll_queue_proc___61 _qproc;
	__poll_t _key;
};

struct seq_operations___80;

struct seq_file___80 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___80 *op;
	int poll_event;
	const struct file___85 *file;
	void *private;
};

typedef void bio_end_io_t___40(struct bio___40 *);

struct bio_vec___49 {
	struct page___90 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___40;

struct bio___40 {
	struct bio___40 *bi_next;
	struct block_device___41 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___40 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___39 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___40 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___49 *bi_io_vec;
	struct bio_set___40 *bi_pool;
	struct bio_vec___49 bi_inline_vecs[0];
};

struct fd___13 {
	struct file___85 *file;
	unsigned int flags;
};

struct cgroup_namespace___70 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___70 *root_cset;
};

struct seq_operations___80 {
	void * (*start)(struct seq_file___80 *, loff_t *);
	void (*stop)(struct seq_file___80 *, void *);
	void * (*next)(struct seq_file___80 *, void *, loff_t *);
	int (*show)(struct seq_file___80 *, void *);
};

struct kernfs_root___85;

struct kernfs_elem_dir___85 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___85 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___85;

struct kernfs_root___85 {
	struct kernfs_node___85 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___85 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___85 {
	struct kernfs_node___85 *target_kn;
};

struct kernfs_ops___85;

struct kernfs_elem_attr___85 {
	const struct kernfs_ops___85 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___85 *notify_next;
};

struct kernfs_node___85 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___85 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___85 dir;
		struct kernfs_elem_symlink___85 symlink;
		struct kernfs_elem_attr___85 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___85;

struct kernfs_ops___85 {
	int (*open)(struct kernfs_open_file___85 *);
	void (*release)(struct kernfs_open_file___85 *);
	int (*seq_show)(struct seq_file___80 *, void *);
	void * (*seq_start)(struct seq_file___80 *, loff_t *);
	void * (*seq_next)(struct seq_file___80 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___80 *, void *);
	ssize_t (*read)(struct kernfs_open_file___85 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___85 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___85 *, struct poll_table_struct___61 *);
	int (*mmap)(struct kernfs_open_file___85 *, struct vm_area_struct___90 *);
};

struct kernfs_syscall_ops___85 {
	int (*show_options)(struct seq_file___80 *, struct kernfs_root___85 *);
	int (*mkdir)(struct kernfs_node___85 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___85 *);
	int (*rename)(struct kernfs_node___85 *, struct kernfs_node___85 *, const char *);
	int (*show_path)(struct seq_file___80 *, struct kernfs_node___85 *, struct kernfs_root___85 *);
};

struct kernfs_open_file___85 {
	struct kernfs_node___85 *kn;
	struct file___85 *file;
	struct seq_file___80 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___84 *vm_ops;
};

struct bin_attribute___85;

struct attribute_group___85 {
	const char *name;
	umode_t (*is_visible)(struct kobject___85 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___85 *, struct bin_attribute___85 *, int);
	struct attribute **attrs;
	struct bin_attribute___85 **bin_attrs;
};

struct bin_attribute___85 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___85 * (*f_mapping)();
	ssize_t (*read)(struct file___85 *, struct kobject___85 *, struct bin_attribute___85 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___85 *, struct kobject___85 *, struct bin_attribute___85 *, char *, loff_t, size_t);
	int (*mmap)(struct file___85 *, struct kobject___85 *, struct bin_attribute___85 *, struct vm_area_struct___90 *);
};

struct sysfs_ops___85 {
	ssize_t (*show)(struct kobject___85 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___85 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___85;

struct kset___85 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___85 kobj;
	const struct kset_uevent_ops___85 *uevent_ops;
};

struct kobj_type___85 {
	void (*release)(struct kobject___85 *);
	const struct sysfs_ops___85 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___85 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___85 *);
	const void * (*namespace)(struct kobject___85 *);
	void (*get_ownership)(struct kobject___85 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___85 {
	int (* const filter)(struct kset___85 *, struct kobject___85 *);
	const char * (* const name)(struct kset___85 *, struct kobject___85 *);
	int (* const uevent)(struct kset___85 *, struct kobject___85 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___82 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___82 *);
	int (*get)(char *, const struct kernel_param___82 *);
	void (*free)(void *);
};

struct kparam_array___82;

struct kernel_param___82 {
	const char *name;
	struct module___83 *mod;
	const struct kernel_param_ops___82 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___82 *arr;
	};
};

struct kparam_array___82 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___82 *ops;
	void *elem;
};

struct module_attribute___82 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___82 *, struct module_kobject___82 *, char *);
	ssize_t (*store)(struct module_attribute___82 *, struct module_kobject___82 *, const char *, size_t);
	void (*setup)(struct module___83 *, const char *);
	int (*test)(struct module___83 *);
	void (*free)(struct module___83 *);
};

struct trace_event_class___45;

struct trace_event_call___45 {
	struct list_head list;
	struct trace_event_class___45 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___45 *, struct perf_event___51 *);
};

struct dev_pm_ops___71 {
	int (*prepare)(struct device___71 *);
	void (*complete)(struct device___71 *);
	int (*suspend)(struct device___71 *);
	int (*resume)(struct device___71 *);
	int (*freeze)(struct device___71 *);
	int (*thaw)(struct device___71 *);
	int (*poweroff)(struct device___71 *);
	int (*restore)(struct device___71 *);
	int (*suspend_late)(struct device___71 *);
	int (*resume_early)(struct device___71 *);
	int (*freeze_late)(struct device___71 *);
	int (*thaw_early)(struct device___71 *);
	int (*poweroff_late)(struct device___71 *);
	int (*restore_early)(struct device___71 *);
	int (*suspend_noirq)(struct device___71 *);
	int (*resume_noirq)(struct device___71 *);
	int (*freeze_noirq)(struct device___71 *);
	int (*thaw_noirq)(struct device___71 *);
	int (*poweroff_noirq)(struct device___71 *);
	int (*restore_noirq)(struct device___71 *);
	int (*runtime_suspend)(struct device___71 *);
	int (*runtime_resume)(struct device___71 *);
	int (*runtime_idle)(struct device___71 *);
};

struct wakeup_source___71 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___71 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___71 {
	struct dev_pm_ops___71 ops;
	int (*start)(struct device___71 *);
	void (*detach)(struct device___71 *, bool);
	int (*activate)(struct device___71 *);
	void (*sync)(struct device___71 *);
	void (*dismiss)(struct device___71 *);
};

struct bus_type___71 {
	const char *name;
	const char *dev_name;
	struct device___71 *dev_root;
	const struct attribute_group___85 **bus_groups;
	const struct attribute_group___85 **dev_groups;
	const struct attribute_group___85 **drv_groups;
	int (*match)(struct device___71 *, struct device_driver___71 *);
	int (*uevent)(struct device___71 *, struct kobj_uevent_env *);
	int (*probe)(struct device___71 *);
	void (*sync_state)(struct device___71 *);
	void (*remove)(struct device___71 *);
	void (*shutdown)(struct device___71 *);
	int (*online)(struct device___71 *);
	int (*offline)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	int (*num_vf)(struct device___71 *);
	int (*dma_configure)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___71 {
	const char *name;
	struct bus_type___71 *bus;
	struct module___83 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___71 *);
	void (*sync_state)(struct device___71 *);
	int (*remove)(struct device___71 *);
	void (*shutdown)(struct device___71 *);
	int (*suspend)(struct device___71 *, pm_message_t);
	int (*resume)(struct device___71 *);
	const struct attribute_group___85 **groups;
	const struct attribute_group___85 **dev_groups;
	const struct dev_pm_ops___71 *pm;
	void (*coredump)(struct device___71 *);
	struct driver_private *p;
};

struct device_type___71 {
	const char *name;
	const struct attribute_group___85 **groups;
	int (*uevent)(struct device___71 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___71 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___71 *);
	const struct dev_pm_ops___71 *pm;
};

struct class___71 {
	const char *name;
	struct module___83 *owner;
	const struct attribute_group___85 **class_groups;
	const struct attribute_group___85 **dev_groups;
	struct kobject___85 *dev_kobj;
	int (*dev_uevent)(struct device___71 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___71 *, umode_t *);
	void (*class_release)(struct class___71 *);
	void (*dev_release)(struct device___71 *);
	int (*shutdown_pre)(struct device___71 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___71 *);
	void (*get_ownership)(struct device___71 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___71 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___71;

struct fwnode_handle___71 {
	struct fwnode_handle___71 *secondary;
	const struct fwnode_operations___71 *ops;
	struct device___71 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct tty_operations___10 {
	struct tty_struct___10 * (*lookup)(struct tty_driver___10 *, struct file___85 *, int);
	int (*install)(struct tty_driver___10 *, struct tty_struct___10 *);
	void (*remove)(struct tty_driver___10 *, struct tty_struct___10 *);
	int (*open)(struct tty_struct___10 *, struct file___85 *);
	void (*close)(struct tty_struct___10 *, struct file___85 *);
	void (*shutdown)(struct tty_struct___10 *);
	void (*cleanup)(struct tty_struct___10 *);
	int (*write)(struct tty_struct___10 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___10 *, unsigned char);
	void (*flush_chars)(struct tty_struct___10 *);
	unsigned int (*write_room)(struct tty_struct___10 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___10 *);
	int (*ioctl)(struct tty_struct___10 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___10 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___10 *, struct ktermios *);
	void (*throttle)(struct tty_struct___10 *);
	void (*unthrottle)(struct tty_struct___10 *);
	void (*stop)(struct tty_struct___10 *);
	void (*start)(struct tty_struct___10 *);
	void (*hangup)(struct tty_struct___10 *);
	int (*break_ctl)(struct tty_struct___10 *, int);
	void (*flush_buffer)(struct tty_struct___10 *);
	void (*set_ldisc)(struct tty_struct___10 *);
	void (*wait_until_sent)(struct tty_struct___10 *, int);
	void (*send_xchar)(struct tty_struct___10 *, char);
	int (*tiocmget)(struct tty_struct___10 *);
	int (*tiocmset)(struct tty_struct___10 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___10 *, struct winsize *);
	int (*get_icount)(struct tty_struct___10 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___10 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___10 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___10 *, struct seq_file___80 *);
	int (*poll_init)(struct tty_driver___10 *, int, char *);
	int (*poll_get_char)(struct tty_driver___10 *, int);
	void (*poll_put_char)(struct tty_driver___10 *, int, char);
	int (*proc_show)(struct seq_file___80 *, void *);
};

struct tty_driver___10 {
	int magic;
	struct kref kref;
	struct cdev___20 **cdevs;
	struct module___83 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___10 *other;
	struct tty_struct___10 **ttys;
	struct tty_port___10 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___10 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___10;

struct tty_port_client_operations___10;

struct tty_port___10 {
	struct tty_bufhead buf;
	struct tty_struct___10 *tty;
	struct tty_struct___10 *itty;
	const struct tty_port_operations___10 *ops;
	const struct tty_port_client_operations___10 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___10 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___10 *);
	void (*close)(struct tty_struct___10 *);
	void (*flush_buffer)(struct tty_struct___10 *);
	ssize_t (*read)(struct tty_struct___10 *, struct file___85 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___10 *, struct file___85 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___10 *, struct file___85 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___10 *, struct file___85 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___10 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___10 *, struct file___85 *, struct poll_table_struct___61 *);
	int (*hangup)(struct tty_struct___10 *);
	void (*receive_buf)(struct tty_struct___10 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___10 *);
	void (*dcd_change)(struct tty_struct___10 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___10 *, const unsigned char *, const char *, int);
	struct module___83 *owner;
};

struct tty_ldisc___10 {
	struct tty_ldisc_ops___10 *ops;
	struct tty_struct___10 *tty;
};

struct tty_port_operations___10 {
	int (*carrier_raised)(struct tty_port___10 *);
	void (*dtr_rts)(struct tty_port___10 *, int);
	void (*shutdown)(struct tty_port___10 *);
	int (*activate)(struct tty_port___10 *, struct tty_struct___10 *);
	void (*destruct)(struct tty_port___10 *);
};

struct tty_port_client_operations___10 {
	int (*receive_buf)(struct tty_port___10 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___10 *);
};

struct fwnode_reference_args___71;

struct fwnode_endpoint___71;

struct fwnode_operations___71 {
	struct fwnode_handle___71 * (*get)(struct fwnode_handle___71 *);
	void (*put)(struct fwnode_handle___71 *);
	bool (*device_is_available)(const struct fwnode_handle___71 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___71 *, const struct device___71 *);
	bool (*property_present)(const struct fwnode_handle___71 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___71 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___71 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___71 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*get_parent)(const struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*get_next_child_node)(const struct fwnode_handle___71 *, struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*get_named_child_node)(const struct fwnode_handle___71 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___71 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___71 *);
	struct fwnode_handle___71 * (*graph_get_next_endpoint)(const struct fwnode_handle___71 *, struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*graph_get_remote_endpoint)(const struct fwnode_handle___71 *);
	struct fwnode_handle___71 * (*graph_get_port_parent)(struct fwnode_handle___71 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___71 *, struct fwnode_endpoint___71 *);
	int (*add_links)(struct fwnode_handle___71 *);
};

struct fwnode_endpoint___71 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___71 *local_fwnode;
};

struct fwnode_reference_args___71 {
	struct fwnode_handle___71 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct block_device_operations___40;

struct gendisk___40 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___41 *part0;
	const struct block_device_operations___40 *fops;
	struct request_queue___40 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___39 *bdi;
	struct kobject___85 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___85 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___40 {
	struct bio___40 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___49 *bip_vec;
	struct bio_vec___49 bip_inline_vecs[0];
};

struct blkcg___39;

struct blkg_policy_data___39;

struct blkcg_gq___39 {
	struct request_queue___40 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___39 *blkcg;
	struct blkcg_gq___39 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___39 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___40 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___40(struct request___40 *);

typedef void integrity_complete_fn___40(struct request___40 *, unsigned int);

struct blk_integrity_profile___40 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___40 *prepare_fn;
	integrity_complete_fn___40 *complete_fn;
	const char *name;
};

struct block_device_operations___40 {
	blk_qc_t (*submit_bio)(struct bio___40 *);
	int (*open)(struct block_device___41 *, fmode_t);
	void (*release)(struct gendisk___40 *, fmode_t);
	int (*rw_page)(struct block_device___41 *, sector_t, struct page___90 *, unsigned int);
	int (*ioctl)(struct block_device___41 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___41 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___40 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___40 *);
	int (*getgeo)(struct block_device___41 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___41 *, bool);
	void (*swap_slot_free_notify)(struct block_device___41 *, long unsigned int);
	int (*report_zones)(struct gendisk___40 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___40 *, umode_t *);
	struct module___83 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___40 *, sector_t *);
};

typedef void rq_end_io_fn___40(struct request___40 *, blk_status_t);

struct request___40 {
	struct request_queue___40 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___39 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___40 *bio;
	struct bio___40 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___49 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___40 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___40 *saved_end_io;
		} flush;
	};
	struct gendisk___40 *rq_disk;
	struct block_device___41 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___40 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___39 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___40 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___85 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___85 *debugfs_dir;
	struct dentry___85 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___40;

struct elevator_mq_ops___40 {
	int (*init_sched)(struct request_queue___40 *, struct elevator_type___40 *);
	void (*exit_sched)(struct elevator_queue___40 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___39 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___39 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___39 *);
	bool (*allow_merge)(struct request_queue___40 *, struct request___40 *, struct bio___40 *);
	bool (*bio_merge)(struct request_queue___40 *, struct bio___40 *, unsigned int);
	int (*request_merge)(struct request_queue___40 *, struct request___40 **, struct bio___40 *);
	void (*request_merged)(struct request_queue___40 *, struct request___40 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___40 *, struct request___40 *, struct request___40 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___40 *);
	void (*finish_request)(struct request___40 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___39 *, struct list_head *, bool);
	struct request___40 * (*dispatch_request)(struct blk_mq_hw_ctx___39 *);
	bool (*has_work)(struct blk_mq_hw_ctx___39 *);
	void (*completed_request)(struct request___40 *, u64);
	void (*requeue_request)(struct request___40 *);
	struct request___40 * (*former_request)(struct request_queue___40 *, struct request___40 *);
	struct request___40 * (*next_request)(struct request_queue___40 *, struct request___40 *);
	void (*init_icq)(struct io_cq___40 *);
	void (*exit_icq)(struct io_cq___40 *);
};

struct elv_fs_entry___40;

struct elevator_type___40 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___40 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___40 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___83 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___40 {
	struct elevator_type___40 *type;
	void *elevator_data;
	struct kobject___85 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___40 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___40 *, char *);
	ssize_t (*store)(struct elevator_queue___40 *, const char *, size_t);
};

struct blk_mq_queue_data___39;

struct blk_mq_ops___39 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___39 *, const struct blk_mq_queue_data___39 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___39 *);
	int (*get_budget)(struct request_queue___40 *);
	void (*put_budget)(struct request_queue___40 *, int);
	void (*set_rq_budget_token)(struct request___40 *, int);
	int (*get_rq_budget_token)(struct request___40 *);
	enum blk_eh_timer_return (*timeout)(struct request___40 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___39 *);
	void (*complete)(struct request___40 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___39 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___39 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___39 *, struct request___40 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___39 *, struct request___40 *, unsigned int);
	void (*initialize_rq_fn)(struct request___40 *);
	void (*cleanup_rq)(struct request___40 *);
	bool (*busy)(struct request_queue___40 *);
	int (*map_queues)(struct blk_mq_tag_set___39 *);
	void (*show_rq)(struct seq_file___80 *, struct request___40 *);
};

struct blk_mq_tag_set___39 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___39 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct cftype___70;

struct cgroup_subsys___70 {
	struct cgroup_subsys_state___70 * (*css_alloc)(struct cgroup_subsys_state___70 *);
	int (*css_online)(struct cgroup_subsys_state___70 *);
	void (*css_offline)(struct cgroup_subsys_state___70 *);
	void (*css_released)(struct cgroup_subsys_state___70 *);
	void (*css_free)(struct cgroup_subsys_state___70 *);
	void (*css_reset)(struct cgroup_subsys_state___70 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___70 *, int);
	int (*css_extra_stat_show)(struct seq_file___80 *, struct cgroup_subsys_state___70 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___92 *, struct css_set___70 *);
	void (*cancel_fork)(struct task_struct___92 *, struct css_set___70 *);
	void (*fork)(struct task_struct___92 *);
	void (*exit)(struct task_struct___92 *);
	void (*release)(struct task_struct___92 *);
	void (*bind)(struct cgroup_subsys_state___70 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___70 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___70 *dfl_cftypes;
	struct cftype___70 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___70 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___70 *updated_children;
	struct cgroup___70 *updated_next;
};

struct cgroup_root___70 {
	struct kernfs_root___85 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___70 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___70 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___70 *ss;
	struct list_head node;
	struct kernfs_ops___85 *kf_ops;
	int (*open)(struct kernfs_open_file___85 *);
	void (*release)(struct kernfs_open_file___85 *);
	u64 (*read_u64)(struct cgroup_subsys_state___70 *, struct cftype___70 *);
	s64 (*read_s64)(struct cgroup_subsys_state___70 *, struct cftype___70 *);
	int (*seq_show)(struct seq_file___80 *, void *);
	void * (*seq_start)(struct seq_file___80 *, loff_t *);
	void * (*seq_next)(struct seq_file___80 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___80 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___70 *, struct cftype___70 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___70 *, struct cftype___70 *, s64);
	ssize_t (*write)(struct kernfs_open_file___85 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___85 *, struct poll_table_struct___61 *);
};

struct blk_mq_queue_data___39 {
	struct request___40 *rq;
	bool last;
};

struct blkcg_policy_data___39;

struct blkcg___39 {
	struct cgroup_subsys_state___70 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___39 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___39 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___39 {
	struct blkcg___39 *blkcg;
	int plid;
};

struct blkg_policy_data___39 {
	struct blkcg_gq___39 *blkg;
	int plid;
};

struct perf_cpu_context___51;

struct perf_output_handle___51;

struct pmu___51 {
	struct list_head entry;
	struct module___83 *module;
	struct device___71 *dev;
	const struct attribute_group___85 **attr_groups;
	const struct attribute_group___85 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___51 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___51 *);
	void (*pmu_disable)(struct pmu___51 *);
	int (*event_init)(struct perf_event___51 *);
	void (*event_mapped)(struct perf_event___51 *, struct mm_struct___91 *);
	void (*event_unmapped)(struct perf_event___51 *, struct mm_struct___91 *);
	int (*add)(struct perf_event___51 *, int);
	void (*del)(struct perf_event___51 *, int);
	void (*start)(struct perf_event___51 *, int);
	void (*stop)(struct perf_event___51 *, int);
	void (*read)(struct perf_event___51 *);
	void (*start_txn)(struct pmu___51 *, unsigned int);
	int (*commit_txn)(struct pmu___51 *);
	void (*cancel_txn)(struct pmu___51 *);
	int (*event_idx)(struct perf_event___51 *);
	void (*sched_task)(struct perf_event_context___51 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___51 *, struct perf_event_context___51 *);
	void * (*setup_aux)(struct perf_event___51 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___51 *, struct perf_output_handle___51 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___51 *);
	int (*aux_output_match)(struct perf_event___51 *);
	int (*filter_match)(struct perf_event___51 *);
	int (*check_period)(struct perf_event___51 *, u64);
};

struct perf_cpu_context___51 {
	struct perf_event_context___51 ctx;
	struct perf_event_context___51 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___51 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___51 **heap;
	struct perf_event___51 *heap_default[2];
};

struct perf_output_handle___51 {
	struct perf_event___51 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___51 {
	struct cgroup_subsys_state___70 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___45 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___45 *);
	};
};

struct trace_event_class___45 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___45 *, enum trace_reg, void *);
	struct trace_event_fields___45 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___45 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___45 *);
};

struct syscall_metadata___19 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___45 *enter_event;
	struct trace_event_call___45 *exit_event;
};

struct open_flags {
	int open_flag;
	umode_t mode;
	int acc_mode;
	int intent;
	int lookup_flags;
};

typedef s64 compat_loff_t;

struct fd___14 {
	struct file___57 *file;
	unsigned int flags;
};

typedef __kernel_rwf_t rwf_t;

struct syscall_metadata___20 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___33 *enter_event;
	struct trace_event_call___33 *exit_event;
};

struct dentry___86;

struct super_block___86;

struct module___84;

struct file_system_type___86 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___86 * (*mount)(struct file_system_type___86 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___86 *);
	struct module___84 *owner;
	struct file_system_type___86 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___86;

struct kiocb___86;

struct iov_iter___51;

struct vm_area_struct___91;

struct inode___86;

struct file_lock___86;

struct page___91;

struct seq_file___81;

struct file_operations___86 {
	struct module___84 *owner;
	loff_t (*llseek)(struct file___86 *, loff_t, int);
	ssize_t (*read)(struct file___86 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___86 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___86 *, struct iov_iter___51 *);
	ssize_t (*write_iter)(struct kiocb___86 *, struct iov_iter___51 *);
	int (*iopoll)(struct kiocb___86 *, bool);
	int (*iterate)(struct file___86 *, struct dir_context *);
	int (*iterate_shared)(struct file___86 *, struct dir_context *);
	__poll_t (*poll)(struct file___86 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___86 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___86 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___86 *, struct vm_area_struct___91 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___86 *, struct file___86 *);
	int (*flush)(struct file___86 *, fl_owner_t);
	int (*release)(struct inode___86 *, struct file___86 *);
	int (*fsync)(struct file___86 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___86 *, int);
	int (*lock)(struct file___86 *, int, struct file_lock___86 *);
	ssize_t (*sendpage)(struct file___86 *, struct page___91 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___86 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___86 *, long unsigned int);
	int (*flock)(struct file___86 *, int, struct file_lock___86 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___86 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___86 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___86 *, long int, struct file_lock___86 **, void **);
	long int (*fallocate)(struct file___86 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___81 *, struct file___86 *);
	ssize_t (*copy_file_range)(struct file___86 *, loff_t, struct file___86 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___86 *, loff_t, struct file___86 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___86 *, loff_t, loff_t, int);
};

struct vmacache___91 {
	u64 seqnum;
	struct vm_area_struct___91 *vmas[4];
};

struct page_frag___91 {
	struct page___91 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___92;

struct pid___78;

struct files_struct___8;

struct nsproxy___83;

struct signal_struct___87;

struct bio_list___41;

struct backing_dev_info___40;

struct io_context___41;

struct css_set___71;

struct mem_cgroup___37;

struct request_queue___41;

struct vm_struct___86;

struct task_struct___93 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___93 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___92 *mm;
	struct mm_struct___92 *active_mm;
	struct vmacache___91 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___93 *real_parent;
	struct task_struct___93 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___93 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___78 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___11 *ptracer_cred;
	const struct cred___11 *real_cred;
	const struct cred___11 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___8 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___83 *nsproxy;
	struct signal_struct___87 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___93 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___41 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___40 *backing_dev_info;
	struct io_context___41 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___71 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___91 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___37 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___37 *active_memcg;
	struct request_queue___41 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___93 *oom_reaper_list;
	struct vm_struct___86 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___51 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___86;

struct kobj_type___86;

struct kernfs_node___86;

struct kobject___86 {
	const char *name;
	struct list_head entry;
	struct kobject___86 *parent;
	struct kset___86 *kset;
	struct kobj_type___86 *ktype;
	struct kernfs_node___86 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___83 {
	struct kobject___86 kobj;
	struct module___84 *mod;
	struct kobject___86 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___83 {
	struct module___84 *mod;
	struct latch_tree_node node;
};

struct module_layout___83 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___83 mtn;
};

struct module_attribute___83;

struct kernel_param___83;

struct module___84 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___83 mkobj;
	struct module_attribute___83 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___86 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___83 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___83 core_layout;
	struct module_layout___83 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___91 *pgtable_t___91;

struct address_space___86;

struct dev_pagemap___85;

struct page___91 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___86 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___28 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___91 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___91 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___92 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___85 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___85;

struct vm_area_struct___91 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___91 *vm_next;
	struct vm_area_struct___91 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___92 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___85 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___86 *vm_file;
	struct file___86 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___91;

struct mm_struct___92 {
	struct {
		struct vm_area_struct___91 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___86 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___91 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___93 *owner;
		struct user_namespace___12 *user_ns;
		struct file___86 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___86;

struct address_space___86 {
	struct inode___86 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___86 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___85;

struct dev_pagemap___85 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___85 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___86;

struct path___86 {
	struct vfsmount___86 *mnt;
	struct dentry___86 *dentry;
};

struct fown_struct___78 {
	rwlock_t lock;
	struct pid___78 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___86 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___86 f_path;
	struct inode___86 *f_inode;
	const struct file_operations___86 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___78 f_owner;
	const struct cred___11 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___86 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___85;

struct vm_operations_struct___85 {
	void (*open)(struct vm_area_struct___91 *);
	void (*close)(struct vm_area_struct___91 *);
	int (*may_split)(struct vm_area_struct___91 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___91 *);
	int (*mprotect)(struct vm_area_struct___91 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___85 *);
	vm_fault_t (*huge_fault)(struct vm_fault___85 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___85 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___91 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___85 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___85 *);
	int (*access)(struct vm_area_struct___91 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___91 *);
	int (*set_policy)(struct vm_area_struct___91 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___91 *, long unsigned int);
	struct page___91 * (*find_special_page)(struct vm_area_struct___91 *, long unsigned int);
};

struct core_thread___91 {
	struct task_struct___93 *task;
	struct core_thread___91 *next;
};

struct core_state___91 {
	atomic_t nr_threads;
	struct core_thread___91 dumper;
	struct completion startup;
};

struct vm_fault___85 {
	const struct {
		struct vm_area_struct___91 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___91 *cow_page;
	struct page___91 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___91 prealloc_pte;
};

struct pglist_data___43;

struct lruvec___43 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___43 *pgdat;
};

struct zone___43 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___43 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___43 {
	struct zone___43 *zone;
	int zone_idx;
};

struct zonelist___43 {
	struct zoneref___43 _zonerefs[321];
};

struct pglist_data___43 {
	struct zone___43 node_zones[5];
	struct zonelist___43 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___93 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___93 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___43 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___86;

struct dentry___86 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___86 *d_parent;
	struct qstr d_name;
	struct inode___86 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___86 *d_op;
	struct super_block___86 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___86;

struct bdi_writeback___40;

struct cdev___21;

struct inode___86 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___86 *i_op;
	struct super_block___86 *i_sb;
	struct address_space___86 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___40 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___86 *i_fop;
		void (*free_inode)(struct inode___86 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___86 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___21 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___86 {
	int (*d_revalidate)(struct dentry___86 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___86 *, unsigned int);
	int (*d_hash)(const struct dentry___86 *, struct qstr *);
	int (*d_compare)(const struct dentry___86 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___86 *);
	int (*d_init)(struct dentry___86 *);
	void (*d_release)(struct dentry___86 *);
	void (*d_prune)(struct dentry___86 *);
	void (*d_iput)(struct dentry___86 *, struct inode___86 *);
	char * (*d_dname)(struct dentry___86 *, char *, int);
	struct vfsmount___86 * (*d_automount)(struct path___86 *);
	int (*d_manage)(const struct path___86 *, bool);
	struct dentry___86 * (*d_real)(struct dentry___86 *, const struct inode___86 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___86;

struct mem_dqinfo___86 {
	struct quota_format_type___86 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___86;

struct quota_info___86 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___86 *files[3];
	struct mem_dqinfo___86 info[3];
	const struct quota_format_ops___86 *ops[3];
};

struct rcuwait___87 {
	struct task_struct___93 *task;
};

struct percpu_rw_semaphore___87 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___87 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___86 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___87 rw_sem[3];
};

struct shrink_control___37;

struct shrinker___37 {
	long unsigned int (*count_objects)(struct shrinker___37 *, struct shrink_control___37 *);
	long unsigned int (*scan_objects)(struct shrinker___37 *, struct shrink_control___37 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___86;

struct dquot_operations___86;

struct quotactl_ops___86;

struct block_device___42;

struct super_block___86 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___86 *s_type;
	const struct super_operations___86 *s_op;
	const struct dquot_operations___86 *dq_op;
	const struct quotactl_ops___86 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___86 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___42 *s_bdev;
	struct backing_dev_info___40 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___86 s_dquot;
	struct sb_writers___86 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___86 *s_d_op;
	int cleancache_poolid;
	struct shrinker___37 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___12 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___86 {
	struct dentry___86 *mnt_root;
	struct super_block___86 *mnt_sb;
	int mnt_flags;
	struct user_namespace___12 *mnt_userns;
};

struct pid_namespace___78;

struct upid___78 {
	int nr;
	struct pid_namespace___78 *ns;
};

struct pid_namespace___78 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___93 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___78 *parent;
	struct fs_pin *bacct;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___78 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___78 numbers[1];
};

struct signal_struct___87 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___93 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___93 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___78 *pids[4];
	struct pid___78 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___92 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fdtable___8 {
	unsigned int max_fds;
	struct file___86 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___8 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___8 *fdt;
	struct fdtable___8 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___86 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___71;

struct nsproxy___83 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___78 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___71 *cgroup_ns;
};

struct bio___41;

struct bio_list___41 {
	struct bio___41 *head;
	struct bio___41 *tail;
};

struct cgroup_subsys_state___71;

struct bdi_writeback___40 {
	struct backing_dev_info___40 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___71 *memcg_css;
	struct cgroup_subsys_state___71 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___72;

struct backing_dev_info___40 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___40 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___72 *dev;
	char dev_name[64];
	struct device___72 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___86 *debug_dir;
};

struct io_cq___41;

struct io_context___41 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___41 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___71;

struct css_set___71 {
	struct cgroup_subsys_state___71 *subsys[14];
	refcount_t refcount;
	struct css_set___71 *dom_cset;
	struct cgroup___71 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___71 *mg_src_cgrp;
	struct cgroup___71 *mg_dst_cgrp;
	struct css_set___71 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___71;

struct cgroup_subsys_state___71 {
	struct cgroup___71 *cgroup;
	struct cgroup_subsys___71 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___71 *parent;
};

struct cgroup_file___71 {
	struct kernfs_node___86 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___37;

struct mem_cgroup_per_node___37;

struct mem_cgroup___37 {
	struct cgroup_subsys_state___71 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___71 events_file;
	struct cgroup_file___71 events_local_file;
	struct cgroup_file___71 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___37 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___93 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___37 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___41;

struct blk_integrity___41 {
	const struct blk_integrity_profile___41 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___41 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___41 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___41;

struct elevator_queue___41;

struct blk_mq_ops___40;

struct blk_mq_hw_ctx___40;

struct gendisk___41;

struct blkcg_gq___40;

struct blk_mq_tag_set___40;

struct request_queue___41 {
	struct request___41 *last_merge;
	struct elevator_queue___41 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___40 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___40 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___41 *disk;
	struct kobject___86 kobj;
	struct kobject___86 *mq_kobj;
	struct blk_integrity___41 integrity;
	struct device___72 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___40 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___40 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___41 bio_split;
	struct dentry___86 *debugfs_dir;
	struct dentry___86 *sched_debugfs_dir;
	struct dentry___86 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___86 {
	struct vm_struct___86 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___91 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___37 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___37 *memcg;
};

struct psi_group___71 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___93 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___71;

struct cgroup_rstat_cpu___71;

struct cgroup___71 {
	struct cgroup_subsys_state___71 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___86 *kn;
	struct cgroup_file___71 procs_file;
	struct cgroup_file___71 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___71 *subsys[14];
	struct cgroup_root___71 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___71 *dom_cgrp;
	struct cgroup___71 *old_dom_cgrp;
	struct cgroup_rstat_cpu___71 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___71 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___41 {
	struct request_queue___41 *q;
	struct io_context___41 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___43;

struct kiocb___86 {
	struct file___86 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___86 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___43 *ki_waitq;
	};
};

struct iattr___86 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___86 *ia_file;
};

struct dquot___86 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___86 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___86 {
	int qf_fmt_id;
	const struct quota_format_ops___86 *qf_ops;
	struct module___84 *qf_owner;
	struct quota_format_type___86 *qf_next;
};

struct quota_format_ops___86 {
	int (*check_quota_file)(struct super_block___86 *, int);
	int (*read_file_info)(struct super_block___86 *, int);
	int (*write_file_info)(struct super_block___86 *, int);
	int (*free_file_info)(struct super_block___86 *, int);
	int (*read_dqblk)(struct dquot___86 *);
	int (*commit_dqblk)(struct dquot___86 *);
	int (*release_dqblk)(struct dquot___86 *);
	int (*get_next_id)(struct super_block___86 *, struct kqid *);
};

struct dquot_operations___86 {
	int (*write_dquot)(struct dquot___86 *);
	struct dquot___86 * (*alloc_dquot)(struct super_block___86 *, int);
	void (*destroy_dquot)(struct dquot___86 *);
	int (*acquire_dquot)(struct dquot___86 *);
	int (*release_dquot)(struct dquot___86 *);
	int (*mark_dirty)(struct dquot___86 *);
	int (*write_info)(struct super_block___86 *, int);
	qsize_t * (*get_reserved_space)(struct inode___86 *);
	int (*get_projid)(struct inode___86 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___86 *, qsize_t *);
	int (*get_next_id)(struct super_block___86 *, struct kqid *);
};

struct quotactl_ops___86 {
	int (*quota_on)(struct super_block___86 *, int, int, const struct path___86 *);
	int (*quota_off)(struct super_block___86 *, int);
	int (*quota_enable)(struct super_block___86 *, unsigned int);
	int (*quota_disable)(struct super_block___86 *, unsigned int);
	int (*quota_sync)(struct super_block___86 *, int);
	int (*set_info)(struct super_block___86 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___86 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___86 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___86 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___86 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___86 *, unsigned int);
};

struct wait_page_queue___43 {
	struct page___91 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___40;

struct readahead_control___43;

struct swap_info_struct___24;

struct address_space_operations___86 {
	int (*writepage)(struct page___91 *, struct writeback_control___40 *);
	int (*readpage)(struct file___86 *, struct page___91 *);
	int (*writepages)(struct address_space___86 *, struct writeback_control___40 *);
	int (*set_page_dirty)(struct page___91 *);
	int (*readpages)(struct file___86 *, struct address_space___86 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___43 *);
	int (*write_begin)(struct file___86 *, struct address_space___86 *, loff_t, unsigned int, unsigned int, struct page___91 **, void **);
	int (*write_end)(struct file___86 *, struct address_space___86 *, loff_t, unsigned int, unsigned int, struct page___91 *, void *);
	sector_t (*bmap)(struct address_space___86 *, sector_t);
	void (*invalidatepage)(struct page___91 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___91 *, gfp_t);
	void (*freepage)(struct page___91 *);
	ssize_t (*direct_IO)(struct kiocb___86 *, struct iov_iter___51 *);
	int (*migratepage)(struct address_space___86 *, struct page___91 *, struct page___91 *, enum migrate_mode);
	bool (*isolate_page)(struct page___91 *, isolate_mode_t);
	void (*putback_page)(struct page___91 *);
	int (*launder_page)(struct page___91 *);
	int (*is_partially_uptodate)(struct page___91 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___91 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___86 *, struct page___91 *);
	int (*swap_activate)(struct swap_info_struct___24 *, struct file___86 *, sector_t *);
	void (*swap_deactivate)(struct file___86 *);
};

struct writeback_control___40 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___40 *wb;
	struct inode___86 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___43 {
	struct file___86 *file;
	struct address_space___86 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___50;

struct iov_iter___51 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___50 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___24 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___42 *bdev;
	struct file___86 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___21 {
	struct kobject___86 kobj;
	struct module___84 *owner;
	const struct file_operations___86 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___86 {
	struct dentry___86 * (*lookup)(struct inode___86 *, struct dentry___86 *, unsigned int);
	const char * (*get_link)(struct dentry___86 *, struct inode___86 *, struct delayed_call *);
	int (*permission)(struct user_namespace___12 *, struct inode___86 *, int);
	struct posix_acl * (*get_acl)(struct inode___86 *, int, bool);
	int (*readlink)(struct dentry___86 *, char *, int);
	int (*create)(struct user_namespace___12 *, struct inode___86 *, struct dentry___86 *, umode_t, bool);
	int (*link)(struct dentry___86 *, struct inode___86 *, struct dentry___86 *);
	int (*unlink)(struct inode___86 *, struct dentry___86 *);
	int (*symlink)(struct user_namespace___12 *, struct inode___86 *, struct dentry___86 *, const char *);
	int (*mkdir)(struct user_namespace___12 *, struct inode___86 *, struct dentry___86 *, umode_t);
	int (*rmdir)(struct inode___86 *, struct dentry___86 *);
	int (*mknod)(struct user_namespace___12 *, struct inode___86 *, struct dentry___86 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___12 *, struct inode___86 *, struct dentry___86 *, struct inode___86 *, struct dentry___86 *, unsigned int);
	int (*setattr)(struct user_namespace___12 *, struct dentry___86 *, struct iattr___86 *);
	int (*getattr)(struct user_namespace___12 *, const struct path___86 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___86 *, char *, size_t);
	int (*fiemap)(struct inode___86 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___86 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___86 *, struct dentry___86 *, struct file___86 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___12 *, struct inode___86 *, struct dentry___86 *, umode_t);
	int (*set_acl)(struct user_namespace___12 *, struct inode___86 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___12 *, struct dentry___86 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___86 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___86 {
	void (*fl_copy_lock)(struct file_lock___86 *, struct file_lock___86 *);
	void (*fl_release_private)(struct file_lock___86 *);
};

struct fasync_struct___86;

struct lock_manager_operations___86;

struct file_lock___86 {
	struct file_lock___86 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___86 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___86 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___86 *fl_ops;
	const struct lock_manager_operations___86 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___86 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___86 *);
	int (*lm_grant)(struct file_lock___86 *, int);
	bool (*lm_break)(struct file_lock___86 *);
	int (*lm_change)(struct file_lock___86 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___86 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___86 *);
};

struct fasync_struct___86 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___86 *fa_next;
	struct file___86 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___86 {
	struct inode___86 * (*alloc_inode)(struct super_block___86 *);
	void (*destroy_inode)(struct inode___86 *);
	void (*free_inode)(struct inode___86 *);
	void (*dirty_inode)(struct inode___86 *, int);
	int (*write_inode)(struct inode___86 *, struct writeback_control___40 *);
	int (*drop_inode)(struct inode___86 *);
	void (*evict_inode)(struct inode___86 *);
	void (*put_super)(struct super_block___86 *);
	int (*sync_fs)(struct super_block___86 *, int);
	int (*freeze_super)(struct super_block___86 *);
	int (*freeze_fs)(struct super_block___86 *);
	int (*thaw_super)(struct super_block___86 *);
	int (*unfreeze_fs)(struct super_block___86 *);
	int (*statfs)(struct dentry___86 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___86 *, int *, char *);
	void (*umount_begin)(struct super_block___86 *);
	int (*show_options)(struct seq_file___81 *, struct dentry___86 *);
	int (*show_devname)(struct seq_file___81 *, struct dentry___86 *);
	int (*show_path)(struct seq_file___81 *, struct dentry___86 *);
	int (*show_stats)(struct seq_file___81 *, struct dentry___86 *);
	ssize_t (*quota_read)(struct super_block___86 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___86 *, int, const char *, size_t, loff_t);
	struct dquot___86 ** (*get_dquots)(struct inode___86 *);
	long int (*nr_cached_objects)(struct super_block___86 *, struct shrink_control___37 *);
	long int (*free_cached_objects)(struct super_block___86 *, struct shrink_control___37 *);
	struct file___86 * (*real_loop)(struct file___86 *);
};

struct wakeup_source___72;

struct dev_pm_info___72 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___72 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___72 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___72;

struct bus_type___72;

struct device_driver___72;

struct dev_pm_domain___72;

struct fwnode_handle___72;

struct class___72;

struct attribute_group___86;

struct device___72 {
	struct kobject___86 kobj;
	struct device___72 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___72 *type;
	struct bus_type___72 *bus;
	struct device_driver___72 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___72 power;
	struct dev_pm_domain___72 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___72 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___72 *class;
	const struct attribute_group___86 **groups;
	void (*release)(struct device___72 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___42 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___86 *bd_inode;
	struct super_block___86 *bd_super;
	void *bd_claiming;
	struct device___72 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___86 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___41 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___86 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___81;

struct seq_file___81 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___81 *op;
	int poll_event;
	const struct file___86 *file;
	void *private;
};

typedef void bio_end_io_t___41(struct bio___41 *);

struct bio_vec___50 {
	struct page___91 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___41;

struct bio___41 {
	struct bio___41 *bi_next;
	struct block_device___42 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___41 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___40 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___41 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___50 *bi_io_vec;
	struct bio_set___41 *bi_pool;
	struct bio_vec___50 bi_inline_vecs[0];
};

struct kernfs_root___86;

struct kernfs_elem_dir___86 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___86 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___86;

struct kernfs_root___86 {
	struct kernfs_node___86 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___86 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___86 {
	struct kernfs_node___86 *target_kn;
};

struct kernfs_ops___86;

struct kernfs_elem_attr___86 {
	const struct kernfs_ops___86 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___86 *notify_next;
};

struct kernfs_node___86 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___86 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___86 dir;
		struct kernfs_elem_symlink___86 symlink;
		struct kernfs_elem_attr___86 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___86;

struct kernfs_ops___86 {
	int (*open)(struct kernfs_open_file___86 *);
	void (*release)(struct kernfs_open_file___86 *);
	int (*seq_show)(struct seq_file___81 *, void *);
	void * (*seq_start)(struct seq_file___81 *, loff_t *);
	void * (*seq_next)(struct seq_file___81 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___81 *, void *);
	ssize_t (*read)(struct kernfs_open_file___86 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___86 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___86 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___86 *, struct vm_area_struct___91 *);
};

struct kernfs_syscall_ops___86 {
	int (*show_options)(struct seq_file___81 *, struct kernfs_root___86 *);
	int (*mkdir)(struct kernfs_node___86 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___86 *);
	int (*rename)(struct kernfs_node___86 *, struct kernfs_node___86 *, const char *);
	int (*show_path)(struct seq_file___81 *, struct kernfs_node___86 *, struct kernfs_root___86 *);
};

struct kernfs_open_file___86 {
	struct kernfs_node___86 *kn;
	struct file___86 *file;
	struct seq_file___81 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___85 *vm_ops;
};

struct bin_attribute___86;

struct attribute_group___86 {
	const char *name;
	umode_t (*is_visible)(struct kobject___86 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___86 *, struct bin_attribute___86 *, int);
	struct attribute **attrs;
	struct bin_attribute___86 **bin_attrs;
};

struct bin_attribute___86 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___86 * (*f_mapping)();
	ssize_t (*read)(struct file___86 *, struct kobject___86 *, struct bin_attribute___86 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___86 *, struct kobject___86 *, struct bin_attribute___86 *, char *, loff_t, size_t);
	int (*mmap)(struct file___86 *, struct kobject___86 *, struct bin_attribute___86 *, struct vm_area_struct___91 *);
};

struct sysfs_ops___86 {
	ssize_t (*show)(struct kobject___86 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___86 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___86;

struct kset___86 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___86 kobj;
	const struct kset_uevent_ops___86 *uevent_ops;
};

struct kobj_type___86 {
	void (*release)(struct kobject___86 *);
	const struct sysfs_ops___86 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___86 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___86 *);
	const void * (*namespace)(struct kobject___86 *);
	void (*get_ownership)(struct kobject___86 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___86 {
	int (* const filter)(struct kset___86 *, struct kobject___86 *);
	const char * (* const name)(struct kset___86 *, struct kobject___86 *);
	int (* const uevent)(struct kset___86 *, struct kobject___86 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___83 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___83 *);
	int (*get)(char *, const struct kernel_param___83 *);
	void (*free)(void *);
};

struct kparam_array___83;

struct kernel_param___83 {
	const char *name;
	struct module___84 *mod;
	const struct kernel_param_ops___83 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___83 *arr;
	};
};

struct kparam_array___83 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___83 *ops;
	void *elem;
};

struct module_attribute___83 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___83 *, struct module_kobject___83 *, char *);
	ssize_t (*store)(struct module_attribute___83 *, struct module_kobject___83 *, const char *, size_t);
	void (*setup)(struct module___84 *, const char *);
	int (*test)(struct module___84 *);
	void (*free)(struct module___84 *);
};

struct dev_pagemap_ops___85 {
	void (*page_free)(struct page___91 *);
	void (*kill)(struct dev_pagemap___85 *);
	void (*cleanup)(struct dev_pagemap___85 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___85 *);
};

struct dev_pm_ops___72 {
	int (*prepare)(struct device___72 *);
	void (*complete)(struct device___72 *);
	int (*suspend)(struct device___72 *);
	int (*resume)(struct device___72 *);
	int (*freeze)(struct device___72 *);
	int (*thaw)(struct device___72 *);
	int (*poweroff)(struct device___72 *);
	int (*restore)(struct device___72 *);
	int (*suspend_late)(struct device___72 *);
	int (*resume_early)(struct device___72 *);
	int (*freeze_late)(struct device___72 *);
	int (*thaw_early)(struct device___72 *);
	int (*poweroff_late)(struct device___72 *);
	int (*restore_early)(struct device___72 *);
	int (*suspend_noirq)(struct device___72 *);
	int (*resume_noirq)(struct device___72 *);
	int (*freeze_noirq)(struct device___72 *);
	int (*thaw_noirq)(struct device___72 *);
	int (*poweroff_noirq)(struct device___72 *);
	int (*restore_noirq)(struct device___72 *);
	int (*runtime_suspend)(struct device___72 *);
	int (*runtime_resume)(struct device___72 *);
	int (*runtime_idle)(struct device___72 *);
};

struct wakeup_source___72 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___72 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___72 {
	struct dev_pm_ops___72 ops;
	int (*start)(struct device___72 *);
	void (*detach)(struct device___72 *, bool);
	int (*activate)(struct device___72 *);
	void (*sync)(struct device___72 *);
	void (*dismiss)(struct device___72 *);
};

struct bus_type___72 {
	const char *name;
	const char *dev_name;
	struct device___72 *dev_root;
	const struct attribute_group___86 **bus_groups;
	const struct attribute_group___86 **dev_groups;
	const struct attribute_group___86 **drv_groups;
	int (*match)(struct device___72 *, struct device_driver___72 *);
	int (*uevent)(struct device___72 *, struct kobj_uevent_env *);
	int (*probe)(struct device___72 *);
	void (*sync_state)(struct device___72 *);
	void (*remove)(struct device___72 *);
	void (*shutdown)(struct device___72 *);
	int (*online)(struct device___72 *);
	int (*offline)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	int (*num_vf)(struct device___72 *);
	int (*dma_configure)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___72 {
	const char *name;
	struct bus_type___72 *bus;
	struct module___84 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___72 *);
	void (*sync_state)(struct device___72 *);
	int (*remove)(struct device___72 *);
	void (*shutdown)(struct device___72 *);
	int (*suspend)(struct device___72 *, pm_message_t);
	int (*resume)(struct device___72 *);
	const struct attribute_group___86 **groups;
	const struct attribute_group___86 **dev_groups;
	const struct dev_pm_ops___72 *pm;
	void (*coredump)(struct device___72 *);
	struct driver_private *p;
};

struct device_type___72 {
	const char *name;
	const struct attribute_group___86 **groups;
	int (*uevent)(struct device___72 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___72 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___72 *);
	const struct dev_pm_ops___72 *pm;
};

struct class___72 {
	const char *name;
	struct module___84 *owner;
	const struct attribute_group___86 **class_groups;
	const struct attribute_group___86 **dev_groups;
	struct kobject___86 *dev_kobj;
	int (*dev_uevent)(struct device___72 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___72 *, umode_t *);
	void (*class_release)(struct class___72 *);
	void (*dev_release)(struct device___72 *);
	int (*shutdown_pre)(struct device___72 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___72 *);
	void (*get_ownership)(struct device___72 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___72 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___72;

struct fwnode_handle___72 {
	struct fwnode_handle___72 *secondary;
	const struct fwnode_operations___72 *ops;
	struct device___72 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct cgroup_namespace___71 {
	struct ns_common___13 ns;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	struct css_set___71 *root_cset;
};

struct seq_operations___81 {
	void * (*start)(struct seq_file___81 *, loff_t *);
	void (*stop)(struct seq_file___81 *, void *);
	void * (*next)(struct seq_file___81 *, void *, loff_t *);
	int (*show)(struct seq_file___81 *, void *);
};

struct fwnode_reference_args___72;

struct fwnode_endpoint___72;

struct fwnode_operations___72 {
	struct fwnode_handle___72 * (*get)(struct fwnode_handle___72 *);
	void (*put)(struct fwnode_handle___72 *);
	bool (*device_is_available)(const struct fwnode_handle___72 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___72 *, const struct device___72 *);
	bool (*property_present)(const struct fwnode_handle___72 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___72 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___72 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___72 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*get_parent)(const struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*get_next_child_node)(const struct fwnode_handle___72 *, struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*get_named_child_node)(const struct fwnode_handle___72 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___72 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___72 *);
	struct fwnode_handle___72 * (*graph_get_next_endpoint)(const struct fwnode_handle___72 *, struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*graph_get_remote_endpoint)(const struct fwnode_handle___72 *);
	struct fwnode_handle___72 * (*graph_get_port_parent)(struct fwnode_handle___72 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___72 *, struct fwnode_endpoint___72 *);
	int (*add_links)(struct fwnode_handle___72 *);
};

struct fwnode_endpoint___72 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___72 *local_fwnode;
};

struct fwnode_reference_args___72 {
	struct fwnode_handle___72 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cftype___71;

struct cgroup_subsys___71 {
	struct cgroup_subsys_state___71 * (*css_alloc)(struct cgroup_subsys_state___71 *);
	int (*css_online)(struct cgroup_subsys_state___71 *);
	void (*css_offline)(struct cgroup_subsys_state___71 *);
	void (*css_released)(struct cgroup_subsys_state___71 *);
	void (*css_free)(struct cgroup_subsys_state___71 *);
	void (*css_reset)(struct cgroup_subsys_state___71 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___71 *, int);
	int (*css_extra_stat_show)(struct seq_file___81 *, struct cgroup_subsys_state___71 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___93 *, struct css_set___71 *);
	void (*cancel_fork)(struct task_struct___93 *, struct css_set___71 *);
	void (*fork)(struct task_struct___93 *);
	void (*exit)(struct task_struct___93 *);
	void (*release)(struct task_struct___93 *);
	void (*bind)(struct cgroup_subsys_state___71 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___71 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___71 *dfl_cftypes;
	struct cftype___71 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___71 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___71 *updated_children;
	struct cgroup___71 *updated_next;
};

struct cgroup_root___71 {
	struct kernfs_root___86 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___71 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___71 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___71 *ss;
	struct list_head node;
	struct kernfs_ops___86 *kf_ops;
	int (*open)(struct kernfs_open_file___86 *);
	void (*release)(struct kernfs_open_file___86 *);
	u64 (*read_u64)(struct cgroup_subsys_state___71 *, struct cftype___71 *);
	s64 (*read_s64)(struct cgroup_subsys_state___71 *, struct cftype___71 *);
	int (*seq_show)(struct seq_file___81 *, void *);
	void * (*seq_start)(struct seq_file___81 *, loff_t *);
	void * (*seq_next)(struct seq_file___81 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___81 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___71 *, struct cftype___71 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___71 *, struct cftype___71 *, s64);
	ssize_t (*write)(struct kernfs_open_file___86 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___86 *, struct poll_table_struct___5 *);
};

struct block_device_operations___41;

struct gendisk___41 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___42 *part0;
	const struct block_device_operations___41 *fops;
	struct request_queue___41 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___40 *bdi;
	struct kobject___86 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___86 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___41 {
	struct bio___41 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___50 *bip_vec;
	struct bio_vec___50 bip_inline_vecs[0];
};

struct blkcg___40;

struct blkg_policy_data___40;

struct blkcg_gq___40 {
	struct request_queue___41 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___40 *blkcg;
	struct blkcg_gq___40 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___40 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___41 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___41(struct request___41 *);

typedef void integrity_complete_fn___41(struct request___41 *, unsigned int);

struct blk_integrity_profile___41 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___41 *prepare_fn;
	integrity_complete_fn___41 *complete_fn;
	const char *name;
};

struct block_device_operations___41 {
	blk_qc_t (*submit_bio)(struct bio___41 *);
	int (*open)(struct block_device___42 *, fmode_t);
	void (*release)(struct gendisk___41 *, fmode_t);
	int (*rw_page)(struct block_device___42 *, sector_t, struct page___91 *, unsigned int);
	int (*ioctl)(struct block_device___42 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___42 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___41 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___41 *);
	int (*getgeo)(struct block_device___42 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___42 *, bool);
	void (*swap_slot_free_notify)(struct block_device___42 *, long unsigned int);
	int (*report_zones)(struct gendisk___41 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___41 *, umode_t *);
	struct module___84 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___41 *, sector_t *);
};

typedef void rq_end_io_fn___41(struct request___41 *, blk_status_t);

struct request___41 {
	struct request_queue___41 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___40 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___41 *bio;
	struct bio___41 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___50 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___41 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___41 *saved_end_io;
		} flush;
	};
	struct gendisk___41 *rq_disk;
	struct block_device___42 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___41 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___40 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___41 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___86 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___86 *debugfs_dir;
	struct dentry___86 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___41;

struct elevator_mq_ops___41 {
	int (*init_sched)(struct request_queue___41 *, struct elevator_type___41 *);
	void (*exit_sched)(struct elevator_queue___41 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___40 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___40 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___40 *);
	bool (*allow_merge)(struct request_queue___41 *, struct request___41 *, struct bio___41 *);
	bool (*bio_merge)(struct request_queue___41 *, struct bio___41 *, unsigned int);
	int (*request_merge)(struct request_queue___41 *, struct request___41 **, struct bio___41 *);
	void (*request_merged)(struct request_queue___41 *, struct request___41 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___41 *, struct request___41 *, struct request___41 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___41 *);
	void (*finish_request)(struct request___41 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___40 *, struct list_head *, bool);
	struct request___41 * (*dispatch_request)(struct blk_mq_hw_ctx___40 *);
	bool (*has_work)(struct blk_mq_hw_ctx___40 *);
	void (*completed_request)(struct request___41 *, u64);
	void (*requeue_request)(struct request___41 *);
	struct request___41 * (*former_request)(struct request_queue___41 *, struct request___41 *);
	struct request___41 * (*next_request)(struct request_queue___41 *, struct request___41 *);
	void (*init_icq)(struct io_cq___41 *);
	void (*exit_icq)(struct io_cq___41 *);
};

struct elv_fs_entry___41;

struct elevator_type___41 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___41 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___41 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___84 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___41 {
	struct elevator_type___41 *type;
	void *elevator_data;
	struct kobject___86 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___41 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___41 *, char *);
	ssize_t (*store)(struct elevator_queue___41 *, const char *, size_t);
};

struct blk_mq_queue_data___40;

struct blk_mq_ops___40 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___40 *, const struct blk_mq_queue_data___40 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___40 *);
	int (*get_budget)(struct request_queue___41 *);
	void (*put_budget)(struct request_queue___41 *, int);
	void (*set_rq_budget_token)(struct request___41 *, int);
	int (*get_rq_budget_token)(struct request___41 *);
	enum blk_eh_timer_return (*timeout)(struct request___41 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___40 *);
	void (*complete)(struct request___41 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___40 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___40 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___40 *, struct request___41 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___40 *, struct request___41 *, unsigned int);
	void (*initialize_rq_fn)(struct request___41 *);
	void (*cleanup_rq)(struct request___41 *);
	bool (*busy)(struct request_queue___41 *);
	int (*map_queues)(struct blk_mq_tag_set___40 *);
	void (*show_rq)(struct seq_file___81 *, struct request___41 *);
};

struct blk_mq_tag_set___40 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___40 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___40 {
	struct request___41 *rq;
	bool last;
};

struct blkcg_policy_data___40;

struct blkcg___40 {
	struct cgroup_subsys_state___71 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___40 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___40 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___40 {
	struct blkcg___40 *blkcg;
	int plid;
};

struct blkg_policy_data___40 {
	struct blkcg_gq___40 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___37 {
	struct mem_cgroup___37 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___37 {
	struct lruvec___43 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___37 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___37 *memcg;
};

struct obj_cgroup___37 {
	struct percpu_ref refcnt;
	struct mem_cgroup___37 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fscrypt_policy_v1 {
	__u8 version;
	__u8 contents_encryption_mode;
	__u8 filenames_encryption_mode;
	__u8 flags;
	__u8 master_key_descriptor[8];
};

struct fscrypt_policy_v2 {
	__u8 version;
	__u8 contents_encryption_mode;
	__u8 filenames_encryption_mode;
	__u8 flags;
	__u8 __reserved[4];
	__u8 master_key_identifier[16];
};

union fscrypt_policy {
	u8 version;
	struct fscrypt_policy_v1 v1;
	struct fscrypt_policy_v2 v2;
};

enum vfs_get_super_keying {
	vfs_get_single_super = 0,
	vfs_get_single_reconf_super = 1,
	vfs_get_keyed_super = 2,
	vfs_get_independent_super = 3,
};

typedef struct kobject___85 *kobj_probe_t(dev_t, int *, void *);

struct kobj_map;

struct char_device_struct {
	struct char_device_struct *next;
	unsigned int major;
	unsigned int baseminor;
	int minorct;
	char name[64];
	struct cdev___20 *cdev;
};

struct stat {
	long unsigned int st_dev;
	long unsigned int st_ino;
	unsigned int st_mode;
	unsigned int st_nlink;
	unsigned int st_uid;
	unsigned int st_gid;
	long unsigned int st_rdev;
	long unsigned int __pad1;
	long int st_size;
	int st_blksize;
	int __pad2;
	long int st_blocks;
	long int st_atime;
	long unsigned int st_atime_nsec;
	long int st_mtime;
	long unsigned int st_mtime_nsec;
	long int st_ctime;
	long unsigned int st_ctime_nsec;
	unsigned int __unused4;
	unsigned int __unused5;
};

typedef u16 compat_mode_t;

typedef u32 compat_ino_t;

typedef u16 compat_ushort_t;

typedef s64 compat_s64;

typedef u16 __compat_uid16_t;

typedef u16 __compat_gid16_t;

typedef u32 compat_dev_t;

struct compat_stat {
	compat_dev_t st_dev;
	compat_ino_t st_ino;
	compat_mode_t st_mode;
	compat_ushort_t st_nlink;
	__compat_uid16_t st_uid;
	__compat_gid16_t st_gid;
	compat_dev_t st_rdev;
	compat_off_t st_size;
	compat_off_t st_blksize;
	compat_off_t st_blocks;
	old_time32_t st_atime;
	compat_ulong_t st_atime_nsec;
	old_time32_t st_mtime;
	compat_ulong_t st_mtime_nsec;
	old_time32_t st_ctime;
	compat_ulong_t st_ctime_nsec;
	compat_ulong_t __unused4[2];
};

struct stat64 {
	compat_u64 st_dev;
	unsigned char __pad0[4];
	compat_ulong_t __st_ino;
	compat_uint_t st_mode;
	compat_uint_t st_nlink;
	compat_ulong_t st_uid;
	compat_ulong_t st_gid;
	compat_u64 st_rdev;
	unsigned char __pad3[4];
	compat_s64 st_size;
	compat_ulong_t st_blksize;
	compat_u64 st_blocks;
	compat_ulong_t st_atime;
	compat_ulong_t st_atime_nsec;
	compat_ulong_t st_mtime;
	compat_ulong_t st_mtime_nsec;
	compat_ulong_t st_ctime;
	compat_ulong_t st_ctime_nsec;
	compat_u64 st_ino;
};

struct statx_timestamp {
	__s64 tv_sec;
	__u32 tv_nsec;
	__s32 __reserved;
};

struct statx {
	__u32 stx_mask;
	__u32 stx_blksize;
	__u64 stx_attributes;
	__u32 stx_nlink;
	__u32 stx_uid;
	__u32 stx_gid;
	__u16 stx_mode;
	__u16 __spare0[1];
	__u64 stx_ino;
	__u64 stx_size;
	__u64 stx_blocks;
	__u64 stx_attributes_mask;
	struct statx_timestamp stx_atime;
	struct statx_timestamp stx_btime;
	struct statx_timestamp stx_ctime;
	struct statx_timestamp stx_mtime;
	__u32 stx_rdev_major;
	__u32 stx_rdev_minor;
	__u32 stx_dev_major;
	__u32 stx_dev_minor;
	__u64 stx_mnt_id;
	__u64 __spare2;
	__u64 __spare3[12];
};

struct mount;

struct mnt_namespace {
	struct ns_common___13 ns;
	struct mount *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___12 *user_ns;
	struct ucounts___12 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct mnt_pcp;

struct mountpoint;

struct mount {
	struct hlist_node mnt_hash;
	struct mount *mnt_parent;
	struct dentry___85 *mnt_mountpoint;
	struct vfsmount___85 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount *mnt_master;
	struct mnt_namespace *mnt_ns;
	struct mountpoint *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mnt_pcp {
	int mnt_count;
	int mnt_writers;
};

struct mountpoint {
	struct hlist_node m_hash;
	struct dentry___85 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

typedef short unsigned int ushort;

struct mmu_gather_batch___3 {
	struct mmu_gather_batch___3 *next;
	unsigned int nr;
	unsigned int max;
	struct page___32 *pages[0];
};

struct mmu_gather___3 {
	struct mm_struct___32 *mm;
	struct mmu_table_batch *batch;
	long unsigned int start;
	long unsigned int end;
	unsigned int fullmm: 1;
	unsigned int need_flush_all: 1;
	unsigned int freed_tables: 1;
	unsigned int cleared_ptes: 1;
	unsigned int cleared_pmds: 1;
	unsigned int cleared_puds: 1;
	unsigned int cleared_p4ds: 1;
	unsigned int vma_exec: 1;
	unsigned int vma_huge: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int batch_count;
	struct mmu_gather_batch___3 *active;
	struct mmu_gather_batch___3 local;
	struct page___32 *__pages[8];
};

struct user_arg_ptr {
	bool is_compat;
	union {
		const char * const *native;
		const compat_uptr_t *compat;
	} ptr;
};

struct fs_context___15;

struct dentry___87;

struct super_block___87;

struct module___85;

struct file_system_type___87 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___15 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___87 * (*mount)(struct file_system_type___87 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___87 *);
	struct module___85 *owner;
	struct file_system_type___87 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___87;

struct kiocb___87;

struct iov_iter___52;

struct poll_table_struct___62;

struct vm_area_struct___92;

struct inode___87;

struct file_lock___87;

struct page___92;

struct pipe_inode_info___34;

struct seq_file___82;

struct file_operations___87 {
	struct module___85 *owner;
	loff_t (*llseek)(struct file___87 *, loff_t, int);
	ssize_t (*read)(struct file___87 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___87 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___87 *, struct iov_iter___52 *);
	ssize_t (*write_iter)(struct kiocb___87 *, struct iov_iter___52 *);
	int (*iopoll)(struct kiocb___87 *, bool);
	int (*iterate)(struct file___87 *, struct dir_context *);
	int (*iterate_shared)(struct file___87 *, struct dir_context *);
	__poll_t (*poll)(struct file___87 *, struct poll_table_struct___62 *);
	long int (*unlocked_ioctl)(struct file___87 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___87 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___87 *, struct vm_area_struct___92 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___87 *, struct file___87 *);
	int (*flush)(struct file___87 *, fl_owner_t);
	int (*release)(struct inode___87 *, struct file___87 *);
	int (*fsync)(struct file___87 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___87 *, int);
	int (*lock)(struct file___87 *, int, struct file_lock___87 *);
	ssize_t (*sendpage)(struct file___87 *, struct page___92 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___87 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___87 *, long unsigned int);
	int (*flock)(struct file___87 *, int, struct file_lock___87 *);
	ssize_t (*splice_write)(struct pipe_inode_info___34 *, struct file___87 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___87 *, loff_t *, struct pipe_inode_info___34 *, size_t, unsigned int);
	int (*setlease)(struct file___87 *, long int, struct file_lock___87 **, void **);
	long int (*fallocate)(struct file___87 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___82 *, struct file___87 *);
	ssize_t (*copy_file_range)(struct file___87 *, loff_t, struct file___87 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___87 *, loff_t, struct file___87 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___87 *, loff_t, loff_t, int);
};

struct vmacache___92 {
	u64 seqnum;
	struct vm_area_struct___92 *vmas[4];
};

struct page_frag___92 {
	struct page___92 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___52;

struct debug_info___52 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___52 *hbp_break[16];
	struct perf_event___52 *hbp_watch[16];
};

struct thread_struct___52 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___52 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___93;

struct pid___79;

struct cred___12;

struct key___2;

struct nsproxy___84;

struct signal_struct___88;

struct bio_list___42;

struct backing_dev_info___41;

struct io_context___42;

struct css_set___72;

struct perf_event_context___52;

struct mem_cgroup___38;

struct request_queue___42;

struct vm_struct___87;

struct task_struct___94 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___94 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___93 *mm;
	struct mm_struct___93 *active_mm;
	struct vmacache___92 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___94 *real_parent;
	struct task_struct___94 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___94 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___79 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___84 *nsproxy;
	struct signal_struct___88 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___94 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___42 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___41 *backing_dev_info;
	struct io_context___42 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___72 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___52 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___34 *splice_pipe;
	struct page_frag___92 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___38 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___38 *active_memcg;
	struct request_queue___42 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___94 *oom_reaper_list;
	struct vm_struct___87 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___52 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___87;

struct kobj_type___87;

struct kernfs_node___87;

struct kobject___87 {
	const char *name;
	struct list_head entry;
	struct kobject___87 *parent;
	struct kset___87 *kset;
	struct kobj_type___87 *ktype;
	struct kernfs_node___87 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___84 {
	struct kobject___87 kobj;
	struct module___85 *mod;
	struct kobject___87 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___84 {
	struct module___85 *mod;
	struct latch_tree_node node;
};

struct module_layout___84 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___84 mtn;
};

struct module_attribute___84;

struct kernel_param___84;

struct trace_event_call___46;

struct module___85 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___84 mkobj;
	struct module_attribute___84 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___87 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___84 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___84 core_layout;
	struct module_layout___84 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___46 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___52 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___94 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___52)(struct perf_event___52 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___52;

struct fasync_struct___87;

struct pid_namespace___79;

struct perf_cgroup___52;

struct perf_event___52 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___52 *group_leader;
	struct pmu___52 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___52 hw;
	struct perf_event_context___52 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___52 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___94 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___87 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___52 *aux_event;
	void (*destroy)(struct perf_event___52 *);
	struct callback_head callback_head;
	struct pid_namespace___79 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___52 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___52 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___46 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___52 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___92 *pgtable_t___92;

struct address_space___87;

struct dev_pagemap___86;

struct page___92 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___87 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___28 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___92 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___92 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___93 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___86 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___86;

struct vm_area_struct___92 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___92 *vm_next;
	struct vm_area_struct___92 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___93 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___86 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___87 *vm_file;
	struct file___87 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___92;

struct user_namespace___13;

struct mm_struct___93 {
	struct {
		struct vm_area_struct___92 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___87 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___92 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___94 *owner;
		struct user_namespace___13 *user_ns;
		struct file___87 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___87;

struct address_space___87 {
	struct inode___87 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___87 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___86;

struct dev_pagemap___86 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___86 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___87;

struct path___87 {
	struct vfsmount___87 *mnt;
	struct dentry___87 *dentry;
};

struct fown_struct___79 {
	rwlock_t lock;
	struct pid___79 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___87 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___87 f_path;
	struct inode___87 *f_inode;
	const struct file_operations___87 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___79 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___87 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___86;

struct vm_operations_struct___86 {
	void (*open)(struct vm_area_struct___92 *);
	void (*close)(struct vm_area_struct___92 *);
	int (*may_split)(struct vm_area_struct___92 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___92 *);
	int (*mprotect)(struct vm_area_struct___92 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___86 *);
	vm_fault_t (*huge_fault)(struct vm_fault___86 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___86 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___92 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___86 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___86 *);
	int (*access)(struct vm_area_struct___92 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___92 *);
	int (*set_policy)(struct vm_area_struct___92 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___92 *, long unsigned int);
	struct page___92 * (*find_special_page)(struct vm_area_struct___92 *, long unsigned int);
};

struct core_thread___92 {
	struct task_struct___94 *task;
	struct core_thread___92 *next;
};

struct core_state___92 {
	atomic_t nr_threads;
	struct core_thread___92 dumper;
	struct completion startup;
};

struct ucounts___13;

struct user_namespace___13 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___13 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___13 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___2 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___2 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___13 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___86 {
	const struct {
		struct vm_area_struct___92 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___92 *cow_page;
	struct page___92 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___92 prealloc_pte;
};

struct pglist_data___44;

struct lruvec___44 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___44 *pgdat;
};

struct zone___44 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___44 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___44 {
	struct zone___44 *zone;
	int zone_idx;
};

struct zonelist___44 {
	struct zoneref___44 _zonerefs[321];
};

struct pglist_data___44 {
	struct zone___44 node_zones[5];
	struct zonelist___44 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___94 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___94 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___44 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___38 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___38 *memcg;
};

struct cgroup___72;

struct cgroup_subsys___72;

struct cgroup_subsys_state___72 {
	struct cgroup___72 *cgroup;
	struct cgroup_subsys___72 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___72 *parent;
};

struct cgroup_file___72 {
	struct kernfs_node___87 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___38;

struct mem_cgroup_per_node___38;

struct mem_cgroup___38 {
	struct cgroup_subsys_state___72 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___72 events_file;
	struct cgroup_file___72 events_local_file;
	struct cgroup_file___72 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___38 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___94 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___38 *nodeinfo[0];
	long: 64;
};

struct shrinker___38 {
	long unsigned int (*count_objects)(struct shrinker___38 *, struct shrink_control___38 *);
	long unsigned int (*scan_objects)(struct shrinker___38 *, struct shrink_control___38 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___86 {
	void (*page_free)(struct page___92 *);
	void (*kill)(struct dev_pagemap___86 *);
	void (*cleanup)(struct dev_pagemap___86 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___86 *);
};

struct upid___79 {
	int nr;
	struct pid_namespace___79 *ns;
};

struct pid_namespace___79 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___94 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___79 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___79 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___79 numbers[1];
};

struct ucounts___13 {
	struct hlist_node node;
	struct user_namespace___13 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___88 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___94 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___94 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___79 *pids[4];
	struct pid___79 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___93 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___12 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___2 *session_keyring;
	struct key___2 *process_keyring;
	struct key___2 *thread_keyring;
	struct key___2 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct watch_list___2;

struct key_restriction___2;

struct key___2 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list___2 *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___2 *restrict_link;
};

struct cgroup_namespace___72;

struct nsproxy___84 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___79 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___72 *cgroup_ns;
};

struct bio___42;

struct bio_list___42 {
	struct bio___42 *head;
	struct bio___42 *tail;
};

struct bdi_writeback___41 {
	struct backing_dev_info___41 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___72 *memcg_css;
	struct cgroup_subsys_state___72 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___73;

struct backing_dev_info___41 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___41 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___73 *dev;
	char dev_name[64];
	struct device___73 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___87 *debug_dir;
};

struct io_cq___42;

struct io_context___42 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___42 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___72 {
	struct cgroup_subsys_state___72 *subsys[14];
	refcount_t refcount;
	struct css_set___72 *dom_cset;
	struct cgroup___72 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___72 *mg_src_cgrp;
	struct cgroup___72 *mg_dst_cgrp;
	struct css_set___72 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___52 {
	struct pmu___52 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___94 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___52 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___34;

struct watch_queue___3;

struct pipe_inode_info___34 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___92 *tmp_page;
	struct fasync_struct___87 *fasync_readers;
	struct fasync_struct___87 *fasync_writers;
	struct pipe_buffer___34 *bufs;
	struct user_struct *user;
	struct watch_queue___3 *watch_queue;
};

struct blk_integrity_profile___42;

struct blk_integrity___42 {
	const struct blk_integrity_profile___42 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___42 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___42 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___42;

struct elevator_queue___42;

struct blk_mq_ops___41;

struct blk_mq_hw_ctx___41;

struct gendisk___42;

struct blkcg_gq___41;

struct blk_mq_tag_set___41;

struct request_queue___42 {
	struct request___42 *last_merge;
	struct elevator_queue___42 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___41 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___41 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___42 *disk;
	struct kobject___87 kobj;
	struct kobject___87 *mq_kobj;
	struct blk_integrity___42 integrity;
	struct device___73 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___41 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___41 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___42 bio_split;
	struct dentry___87 *debugfs_dir;
	struct dentry___87 *sched_debugfs_dir;
	struct dentry___87 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___87 {
	struct vm_struct___87 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___92 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___87;

struct dentry___87 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___87 *d_parent;
	struct qstr d_name;
	struct inode___87 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___87 *d_op;
	struct super_block___87 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___87;

struct inode___87 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___87 *i_op;
	struct super_block___87 *i_sb;
	struct address_space___87 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___41 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___87 *i_fop;
		void (*free_inode)(struct inode___87 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___87 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___34 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___87 {
	int (*d_revalidate)(struct dentry___87 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___87 *, unsigned int);
	int (*d_hash)(const struct dentry___87 *, struct qstr *);
	int (*d_compare)(const struct dentry___87 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___87 *);
	int (*d_init)(struct dentry___87 *);
	void (*d_release)(struct dentry___87 *);
	void (*d_prune)(struct dentry___87 *);
	void (*d_iput)(struct dentry___87 *, struct inode___87 *);
	char * (*d_dname)(struct dentry___87 *, char *, int);
	struct vfsmount___87 * (*d_automount)(struct path___87 *);
	int (*d_manage)(const struct path___87 *, bool);
	struct dentry___87 * (*d_real)(struct dentry___87 *, const struct inode___87 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___87;

struct mem_dqinfo___87 {
	struct quota_format_type___87 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___87;

struct quota_info___87 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___87 *files[3];
	struct mem_dqinfo___87 info[3];
	const struct quota_format_ops___87 *ops[3];
};

struct rcuwait___88 {
	struct task_struct___94 *task;
};

struct percpu_rw_semaphore___88 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___88 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___87 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___88 rw_sem[3];
};

struct super_operations___87;

struct dquot_operations___87;

struct quotactl_ops___87;

struct block_device___43;

struct super_block___87 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___87 *s_type;
	const struct super_operations___87 *s_op;
	const struct dquot_operations___87 *dq_op;
	const struct quotactl_ops___87 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___87 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___43 *s_bdev;
	struct backing_dev_info___41 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___87 s_dquot;
	struct sb_writers___87 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___87 *s_d_op;
	int cleancache_poolid;
	struct shrinker___38 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___87 {
	struct dentry___87 *mnt_root;
	struct super_block___87 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct psi_group___72 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___94 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___72;

struct cgroup_rstat_cpu___72;

struct cgroup___72 {
	struct cgroup_subsys_state___72 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___87 *kn;
	struct cgroup_file___72 procs_file;
	struct cgroup_file___72 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___72 *subsys[14];
	struct cgroup_root___72 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___72 *dom_cgrp;
	struct cgroup___72 *old_dom_cgrp;
	struct cgroup_rstat_cpu___72 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___72 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

typedef int (*key_restrict_link_func_t___2)(struct key___2 *, const struct key_type *, const union key_payload *, struct key___2 *);

struct key_restriction___2 {
	key_restrict_link_func_t___2 check;
	struct key___2 *key;
	struct key_type *keytype;
};

struct watch___2;

struct watch_list___2 {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch___2 *);
	spinlock_t lock;
};

struct io_cq___42 {
	struct request_queue___42 *q;
	struct io_context___42 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___44;

struct kiocb___87 {
	struct file___87 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___87 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___44 *ki_waitq;
	};
};

struct iattr___87 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___87 *ia_file;
};

struct dquot___87 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___87 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___87 {
	int qf_fmt_id;
	const struct quota_format_ops___87 *qf_ops;
	struct module___85 *qf_owner;
	struct quota_format_type___87 *qf_next;
};

struct quota_format_ops___87 {
	int (*check_quota_file)(struct super_block___87 *, int);
	int (*read_file_info)(struct super_block___87 *, int);
	int (*write_file_info)(struct super_block___87 *, int);
	int (*free_file_info)(struct super_block___87 *, int);
	int (*read_dqblk)(struct dquot___87 *);
	int (*commit_dqblk)(struct dquot___87 *);
	int (*release_dqblk)(struct dquot___87 *);
	int (*get_next_id)(struct super_block___87 *, struct kqid *);
};

struct dquot_operations___87 {
	int (*write_dquot)(struct dquot___87 *);
	struct dquot___87 * (*alloc_dquot)(struct super_block___87 *, int);
	void (*destroy_dquot)(struct dquot___87 *);
	int (*acquire_dquot)(struct dquot___87 *);
	int (*release_dquot)(struct dquot___87 *);
	int (*mark_dirty)(struct dquot___87 *);
	int (*write_info)(struct super_block___87 *, int);
	qsize_t * (*get_reserved_space)(struct inode___87 *);
	int (*get_projid)(struct inode___87 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___87 *, qsize_t *);
	int (*get_next_id)(struct super_block___87 *, struct kqid *);
};

struct quotactl_ops___87 {
	int (*quota_on)(struct super_block___87 *, int, int, const struct path___87 *);
	int (*quota_off)(struct super_block___87 *, int);
	int (*quota_enable)(struct super_block___87 *, unsigned int);
	int (*quota_disable)(struct super_block___87 *, unsigned int);
	int (*quota_sync)(struct super_block___87 *, int);
	int (*set_info)(struct super_block___87 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___87 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___87 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___87 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___87 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___87 *, unsigned int);
};

struct wait_page_queue___44 {
	struct page___92 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___41;

struct readahead_control___44;

struct address_space_operations___87 {
	int (*writepage)(struct page___92 *, struct writeback_control___41 *);
	int (*readpage)(struct file___87 *, struct page___92 *);
	int (*writepages)(struct address_space___87 *, struct writeback_control___41 *);
	int (*set_page_dirty)(struct page___92 *);
	int (*readpages)(struct file___87 *, struct address_space___87 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___44 *);
	int (*write_begin)(struct file___87 *, struct address_space___87 *, loff_t, unsigned int, unsigned int, struct page___92 **, void **);
	int (*write_end)(struct file___87 *, struct address_space___87 *, loff_t, unsigned int, unsigned int, struct page___92 *, void *);
	sector_t (*bmap)(struct address_space___87 *, sector_t);
	void (*invalidatepage)(struct page___92 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___92 *, gfp_t);
	void (*freepage)(struct page___92 *);
	ssize_t (*direct_IO)(struct kiocb___87 *, struct iov_iter___52 *);
	int (*migratepage)(struct address_space___87 *, struct page___92 *, struct page___92 *, enum migrate_mode);
	bool (*isolate_page)(struct page___92 *, isolate_mode_t);
	void (*putback_page)(struct page___92 *);
	int (*launder_page)(struct page___92 *);
	int (*is_partially_uptodate)(struct page___92 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___92 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___87 *, struct page___92 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___87 *, sector_t *);
	void (*swap_deactivate)(struct file___87 *);
};

struct writeback_control___41 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___41 *wb;
	struct inode___87 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___44 {
	struct file___87 *file;
	struct address_space___87 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___51;

struct iov_iter___52 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___51 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___34 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___87 {
	struct dentry___87 * (*lookup)(struct inode___87 *, struct dentry___87 *, unsigned int);
	const char * (*get_link)(struct dentry___87 *, struct inode___87 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___87 *, int);
	struct posix_acl * (*get_acl)(struct inode___87 *, int, bool);
	int (*readlink)(struct dentry___87 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___87 *, struct dentry___87 *, umode_t, bool);
	int (*link)(struct dentry___87 *, struct inode___87 *, struct dentry___87 *);
	int (*unlink)(struct inode___87 *, struct dentry___87 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___87 *, struct dentry___87 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___87 *, struct dentry___87 *, umode_t);
	int (*rmdir)(struct inode___87 *, struct dentry___87 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___87 *, struct dentry___87 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___87 *, struct dentry___87 *, struct inode___87 *, struct dentry___87 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___87 *, struct iattr___87 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___87 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___87 *, char *, size_t);
	int (*fiemap)(struct inode___87 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___87 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___87 *, struct dentry___87 *, struct file___87 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___87 *, struct dentry___87 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___87 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___87 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___87 *, struct fileattr *);
	long: 64;
};

enum inode_i_mutex_lock_class {
	I_MUTEX_NORMAL = 0,
	I_MUTEX_PARENT = 1,
	I_MUTEX_CHILD = 2,
	I_MUTEX_XATTR = 3,
	I_MUTEX_NONDIR2 = 4,
	I_MUTEX_PARENT2 = 5,
};

struct file_lock_operations___87 {
	void (*fl_copy_lock)(struct file_lock___87 *, struct file_lock___87 *);
	void (*fl_release_private)(struct file_lock___87 *);
};

struct lock_manager_operations___87;

struct file_lock___87 {
	struct file_lock___87 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___87 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___87 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___87 *fl_ops;
	const struct lock_manager_operations___87 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___87 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___87 *);
	int (*lm_grant)(struct file_lock___87 *, int);
	bool (*lm_break)(struct file_lock___87 *);
	int (*lm_change)(struct file_lock___87 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___87 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___87 *);
};

struct fasync_struct___87 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___87 *fa_next;
	struct file___87 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___87 {
	struct inode___87 * (*alloc_inode)(struct super_block___87 *);
	void (*destroy_inode)(struct inode___87 *);
	void (*free_inode)(struct inode___87 *);
	void (*dirty_inode)(struct inode___87 *, int);
	int (*write_inode)(struct inode___87 *, struct writeback_control___41 *);
	int (*drop_inode)(struct inode___87 *);
	void (*evict_inode)(struct inode___87 *);
	void (*put_super)(struct super_block___87 *);
	int (*sync_fs)(struct super_block___87 *, int);
	int (*freeze_super)(struct super_block___87 *);
	int (*freeze_fs)(struct super_block___87 *);
	int (*thaw_super)(struct super_block___87 *);
	int (*unfreeze_fs)(struct super_block___87 *);
	int (*statfs)(struct dentry___87 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___87 *, int *, char *);
	void (*umount_begin)(struct super_block___87 *);
	int (*show_options)(struct seq_file___82 *, struct dentry___87 *);
	int (*show_devname)(struct seq_file___82 *, struct dentry___87 *);
	int (*show_path)(struct seq_file___82 *, struct dentry___87 *);
	int (*show_stats)(struct seq_file___82 *, struct dentry___87 *);
	ssize_t (*quota_read)(struct super_block___87 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___87 *, int, const char *, size_t, loff_t);
	struct dquot___87 ** (*get_dquots)(struct inode___87 *);
	long int (*nr_cached_objects)(struct super_block___87 *, struct shrink_control___38 *);
	long int (*free_cached_objects)(struct super_block___87 *, struct shrink_control___38 *);
	struct file___87 * (*real_loop)(struct file___87 *);
};

struct wakeup_source___73;

struct dev_pm_info___73 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___73 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___73 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___73;

struct bus_type___73;

struct device_driver___73;

struct dev_pm_domain___73;

struct fwnode_handle___73;

struct class___73;

struct attribute_group___87;

struct device___73 {
	struct kobject___87 kobj;
	struct device___73 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___73 *type;
	struct bus_type___73 *bus;
	struct device_driver___73 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___73 power;
	struct dev_pm_domain___73 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___73 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___73 *class;
	const struct attribute_group___87 **groups;
	void (*release)(struct device___73 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___43 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___87 *bd_inode;
	struct super_block___87 *bd_super;
	void *bd_claiming;
	struct device___73 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___87 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___42 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___87 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___62)(struct file___87 *, wait_queue_head_t *, struct poll_table_struct___62 *);

struct poll_table_struct___62 {
	poll_queue_proc___62 _qproc;
	__poll_t _key;
};

struct seq_operations___82;

struct seq_file___82 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___82 *op;
	int poll_event;
	const struct file___87 *file;
	void *private;
};

struct fc_log___15;

struct p_log___15 {
	const char *prefix;
	struct fc_log___15 *log;
};

struct fs_context_operations___15;

struct fs_context___15 {
	const struct fs_context_operations___15 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___87 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___87 *root;
	struct user_namespace___13 *user_ns;
	struct net *net_ns;
	const struct cred___12 *cred;
	struct p_log___15 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___42(struct bio___42 *);

struct bio_vec___51 {
	struct page___92 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___42;

struct bio___42 {
	struct bio___42 *bi_next;
	struct block_device___43 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___42 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___41 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___42 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___51 *bi_io_vec;
	struct bio_set___42 *bi_pool;
	struct bio_vec___51 bi_inline_vecs[0];
};

typedef struct poll_table_struct___62 poll_table___16;

struct kernfs_root___87;

struct kernfs_elem_dir___87 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___87 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___87;

struct kernfs_root___87 {
	struct kernfs_node___87 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___87 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___87 {
	struct kernfs_node___87 *target_kn;
};

struct kernfs_ops___87;

struct kernfs_elem_attr___87 {
	const struct kernfs_ops___87 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___87 *notify_next;
};

struct kernfs_node___87 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___87 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___87 dir;
		struct kernfs_elem_symlink___87 symlink;
		struct kernfs_elem_attr___87 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___87;

struct kernfs_ops___87 {
	int (*open)(struct kernfs_open_file___87 *);
	void (*release)(struct kernfs_open_file___87 *);
	int (*seq_show)(struct seq_file___82 *, void *);
	void * (*seq_start)(struct seq_file___82 *, loff_t *);
	void * (*seq_next)(struct seq_file___82 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___82 *, void *);
	ssize_t (*read)(struct kernfs_open_file___87 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___87 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___87 *, struct poll_table_struct___62 *);
	int (*mmap)(struct kernfs_open_file___87 *, struct vm_area_struct___92 *);
};

struct kernfs_syscall_ops___87 {
	int (*show_options)(struct seq_file___82 *, struct kernfs_root___87 *);
	int (*mkdir)(struct kernfs_node___87 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___87 *);
	int (*rename)(struct kernfs_node___87 *, struct kernfs_node___87 *, const char *);
	int (*show_path)(struct seq_file___82 *, struct kernfs_node___87 *, struct kernfs_root___87 *);
};

struct kernfs_open_file___87 {
	struct kernfs_node___87 *kn;
	struct file___87 *file;
	struct seq_file___82 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___86 *vm_ops;
};

struct bin_attribute___87;

struct attribute_group___87 {
	const char *name;
	umode_t (*is_visible)(struct kobject___87 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___87 *, struct bin_attribute___87 *, int);
	struct attribute **attrs;
	struct bin_attribute___87 **bin_attrs;
};

struct bin_attribute___87 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___87 * (*f_mapping)();
	ssize_t (*read)(struct file___87 *, struct kobject___87 *, struct bin_attribute___87 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___87 *, struct kobject___87 *, struct bin_attribute___87 *, char *, loff_t, size_t);
	int (*mmap)(struct file___87 *, struct kobject___87 *, struct bin_attribute___87 *, struct vm_area_struct___92 *);
};

struct sysfs_ops___87 {
	ssize_t (*show)(struct kobject___87 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___87 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___87;

struct kset___87 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___87 kobj;
	const struct kset_uevent_ops___87 *uevent_ops;
};

struct kobj_type___87 {
	void (*release)(struct kobject___87 *);
	const struct sysfs_ops___87 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___87 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___87 *);
	const void * (*namespace)(struct kobject___87 *);
	void (*get_ownership)(struct kobject___87 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___87 {
	int (* const filter)(struct kset___87 *, struct kobject___87 *);
	const char * (* const name)(struct kset___87 *, struct kobject___87 *);
	int (* const uevent)(struct kset___87 *, struct kobject___87 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___84 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___84 *);
	int (*get)(char *, const struct kernel_param___84 *);
	void (*free)(void *);
};

struct kparam_array___84;

struct kernel_param___84 {
	const char *name;
	struct module___85 *mod;
	const struct kernel_param_ops___84 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___84 *arr;
	};
};

struct kparam_array___84 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___84 *ops;
	void *elem;
};

struct module_attribute___84 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___84 *, struct module_kobject___84 *, char *);
	ssize_t (*store)(struct module_attribute___84 *, struct module_kobject___84 *, const char *, size_t);
	void (*setup)(struct module___85 *, const char *);
	int (*test)(struct module___85 *);
	void (*free)(struct module___85 *);
};

struct trace_event_class___46;

struct trace_event_call___46 {
	struct list_head list;
	struct trace_event_class___46 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___46 *, struct perf_event___52 *);
};

struct fs_parameter___15 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___87 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___15 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___85 *owner;
	char *buffer[8];
};

struct fs_context_operations___15 {
	void (*free)(struct fs_context___15 *);
	int (*dup)(struct fs_context___15 *, struct fs_context___15 *);
	int (*parse_param)(struct fs_context___15 *, struct fs_parameter___15 *);
	int (*parse_monolithic)(struct fs_context___15 *, void *);
	int (*get_tree)(struct fs_context___15 *);
	int (*reconfigure)(struct fs_context___15 *);
};

struct pseudo_fs_context___4 {
	const struct super_operations___87 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___87 *dops;
	long unsigned int magic;
};

struct pipe_buf_operations___34;

struct pipe_buffer___34 {
	struct page___92 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___34 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___34 {
	int (*confirm)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
	void (*release)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
	bool (*try_steal)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
	bool (*get)(struct pipe_inode_info___34 *, struct pipe_buffer___34 *);
};

struct watch_queue___3 {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___34 *pipe;
	struct hlist_head watches;
	struct page___92 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

struct fwnode_operations___73;

struct fwnode_handle___73 {
	struct fwnode_handle___73 *secondary;
	const struct fwnode_operations___73 *ops;
	struct device___73 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___73;

struct fwnode_endpoint___73;

struct fwnode_operations___73 {
	struct fwnode_handle___73 * (*get)(struct fwnode_handle___73 *);
	void (*put)(struct fwnode_handle___73 *);
	bool (*device_is_available)(const struct fwnode_handle___73 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___73 *, const struct device___73 *);
	bool (*property_present)(const struct fwnode_handle___73 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___73 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___73 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___73 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*get_parent)(const struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*get_next_child_node)(const struct fwnode_handle___73 *, struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*get_named_child_node)(const struct fwnode_handle___73 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___73 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___73 *);
	struct fwnode_handle___73 * (*graph_get_next_endpoint)(const struct fwnode_handle___73 *, struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*graph_get_remote_endpoint)(const struct fwnode_handle___73 *);
	struct fwnode_handle___73 * (*graph_get_port_parent)(struct fwnode_handle___73 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___73 *, struct fwnode_endpoint___73 *);
	int (*add_links)(struct fwnode_handle___73 *);
};

struct fwnode_endpoint___73 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___73 *local_fwnode;
};

struct fwnode_reference_args___73 {
	struct fwnode_handle___73 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___72 {
	struct ns_common___13 ns;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct css_set___72 *root_cset;
};

struct dev_pm_ops___73 {
	int (*prepare)(struct device___73 *);
	void (*complete)(struct device___73 *);
	int (*suspend)(struct device___73 *);
	int (*resume)(struct device___73 *);
	int (*freeze)(struct device___73 *);
	int (*thaw)(struct device___73 *);
	int (*poweroff)(struct device___73 *);
	int (*restore)(struct device___73 *);
	int (*suspend_late)(struct device___73 *);
	int (*resume_early)(struct device___73 *);
	int (*freeze_late)(struct device___73 *);
	int (*thaw_early)(struct device___73 *);
	int (*poweroff_late)(struct device___73 *);
	int (*restore_early)(struct device___73 *);
	int (*suspend_noirq)(struct device___73 *);
	int (*resume_noirq)(struct device___73 *);
	int (*freeze_noirq)(struct device___73 *);
	int (*thaw_noirq)(struct device___73 *);
	int (*poweroff_noirq)(struct device___73 *);
	int (*restore_noirq)(struct device___73 *);
	int (*runtime_suspend)(struct device___73 *);
	int (*runtime_resume)(struct device___73 *);
	int (*runtime_idle)(struct device___73 *);
};

struct wakeup_source___73 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___73 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___73 {
	struct dev_pm_ops___73 ops;
	int (*start)(struct device___73 *);
	void (*detach)(struct device___73 *, bool);
	int (*activate)(struct device___73 *);
	void (*sync)(struct device___73 *);
	void (*dismiss)(struct device___73 *);
};

struct bus_type___73 {
	const char *name;
	const char *dev_name;
	struct device___73 *dev_root;
	const struct attribute_group___87 **bus_groups;
	const struct attribute_group___87 **dev_groups;
	const struct attribute_group___87 **drv_groups;
	int (*match)(struct device___73 *, struct device_driver___73 *);
	int (*uevent)(struct device___73 *, struct kobj_uevent_env *);
	int (*probe)(struct device___73 *);
	void (*sync_state)(struct device___73 *);
	void (*remove)(struct device___73 *);
	void (*shutdown)(struct device___73 *);
	int (*online)(struct device___73 *);
	int (*offline)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	int (*num_vf)(struct device___73 *);
	int (*dma_configure)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___73 {
	const char *name;
	struct bus_type___73 *bus;
	struct module___85 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___73 *);
	void (*sync_state)(struct device___73 *);
	int (*remove)(struct device___73 *);
	void (*shutdown)(struct device___73 *);
	int (*suspend)(struct device___73 *, pm_message_t);
	int (*resume)(struct device___73 *);
	const struct attribute_group___87 **groups;
	const struct attribute_group___87 **dev_groups;
	const struct dev_pm_ops___73 *pm;
	void (*coredump)(struct device___73 *);
	struct driver_private *p;
};

struct device_type___73 {
	const char *name;
	const struct attribute_group___87 **groups;
	int (*uevent)(struct device___73 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___73 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___73 *);
	const struct dev_pm_ops___73 *pm;
};

struct class___73 {
	const char *name;
	struct module___85 *owner;
	const struct attribute_group___87 **class_groups;
	const struct attribute_group___87 **dev_groups;
	struct kobject___87 *dev_kobj;
	int (*dev_uevent)(struct device___73 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___73 *, umode_t *);
	void (*class_release)(struct class___73 *);
	void (*dev_release)(struct device___73 *);
	int (*shutdown_pre)(struct device___73 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___73 *);
	void (*get_ownership)(struct device___73 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___73 *pm;
	struct subsys_private *p;
};

struct seq_operations___82 {
	void * (*start)(struct seq_file___82 *, loff_t *);
	void (*stop)(struct seq_file___82 *, void *);
	void * (*next)(struct seq_file___82 *, void *, loff_t *);
	int (*show)(struct seq_file___82 *, void *);
};

struct cftype___72;

struct cgroup_subsys___72 {
	struct cgroup_subsys_state___72 * (*css_alloc)(struct cgroup_subsys_state___72 *);
	int (*css_online)(struct cgroup_subsys_state___72 *);
	void (*css_offline)(struct cgroup_subsys_state___72 *);
	void (*css_released)(struct cgroup_subsys_state___72 *);
	void (*css_free)(struct cgroup_subsys_state___72 *);
	void (*css_reset)(struct cgroup_subsys_state___72 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___72 *, int);
	int (*css_extra_stat_show)(struct seq_file___82 *, struct cgroup_subsys_state___72 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___94 *, struct css_set___72 *);
	void (*cancel_fork)(struct task_struct___94 *, struct css_set___72 *);
	void (*fork)(struct task_struct___94 *);
	void (*exit)(struct task_struct___94 *);
	void (*release)(struct task_struct___94 *);
	void (*bind)(struct cgroup_subsys_state___72 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___72 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___72 *dfl_cftypes;
	struct cftype___72 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___72 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___72 *updated_children;
	struct cgroup___72 *updated_next;
};

struct cgroup_root___72 {
	struct kernfs_root___87 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___72 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___72 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___72 *ss;
	struct list_head node;
	struct kernfs_ops___87 *kf_ops;
	int (*open)(struct kernfs_open_file___87 *);
	void (*release)(struct kernfs_open_file___87 *);
	u64 (*read_u64)(struct cgroup_subsys_state___72 *, struct cftype___72 *);
	s64 (*read_s64)(struct cgroup_subsys_state___72 *, struct cftype___72 *);
	int (*seq_show)(struct seq_file___82 *, void *);
	void * (*seq_start)(struct seq_file___82 *, loff_t *);
	void * (*seq_next)(struct seq_file___82 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___82 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___72 *, struct cftype___72 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___72 *, struct cftype___72 *, s64);
	ssize_t (*write)(struct kernfs_open_file___87 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___87 *, struct poll_table_struct___62 *);
};

struct perf_cpu_context___52;

struct perf_output_handle___52;

struct pmu___52 {
	struct list_head entry;
	struct module___85 *module;
	struct device___73 *dev;
	const struct attribute_group___87 **attr_groups;
	const struct attribute_group___87 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___52 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___52 *);
	void (*pmu_disable)(struct pmu___52 *);
	int (*event_init)(struct perf_event___52 *);
	void (*event_mapped)(struct perf_event___52 *, struct mm_struct___93 *);
	void (*event_unmapped)(struct perf_event___52 *, struct mm_struct___93 *);
	int (*add)(struct perf_event___52 *, int);
	void (*del)(struct perf_event___52 *, int);
	void (*start)(struct perf_event___52 *, int);
	void (*stop)(struct perf_event___52 *, int);
	void (*read)(struct perf_event___52 *);
	void (*start_txn)(struct pmu___52 *, unsigned int);
	int (*commit_txn)(struct pmu___52 *);
	void (*cancel_txn)(struct pmu___52 *);
	int (*event_idx)(struct perf_event___52 *);
	void (*sched_task)(struct perf_event_context___52 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___52 *, struct perf_event_context___52 *);
	void * (*setup_aux)(struct perf_event___52 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___52 *, struct perf_output_handle___52 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___52 *);
	int (*aux_output_match)(struct perf_event___52 *);
	int (*filter_match)(struct perf_event___52 *);
	int (*check_period)(struct perf_event___52 *, u64);
};

struct perf_cpu_context___52 {
	struct perf_event_context___52 ctx;
	struct perf_event_context___52 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___52 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___52 **heap;
	struct perf_event___52 *heap_default[2];
};

struct perf_output_handle___52 {
	struct perf_event___52 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___52 {
	struct cgroup_subsys_state___72 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___46 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___46 *);
	};
};

struct trace_event_class___46 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___46 *, enum trace_reg, void *);
	struct trace_event_fields___46 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___46 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___46 *);
};

struct syscall_metadata___21 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___46 *enter_event;
	struct trace_event_call___46 *exit_event;
};

struct block_device_operations___42;

struct gendisk___42 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___43 *part0;
	const struct block_device_operations___42 *fops;
	struct request_queue___42 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___41 *bdi;
	struct kobject___87 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___87 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___42 {
	struct bio___42 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___51 *bip_vec;
	struct bio_vec___51 bip_inline_vecs[0];
};

struct blkcg___41;

struct blkg_policy_data___41;

struct blkcg_gq___41 {
	struct request_queue___42 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___41 *blkcg;
	struct blkcg_gq___41 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___41 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___42 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___42(struct request___42 *);

typedef void integrity_complete_fn___42(struct request___42 *, unsigned int);

struct blk_integrity_profile___42 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___42 *prepare_fn;
	integrity_complete_fn___42 *complete_fn;
	const char *name;
};

struct block_device_operations___42 {
	blk_qc_t (*submit_bio)(struct bio___42 *);
	int (*open)(struct block_device___43 *, fmode_t);
	void (*release)(struct gendisk___42 *, fmode_t);
	int (*rw_page)(struct block_device___43 *, sector_t, struct page___92 *, unsigned int);
	int (*ioctl)(struct block_device___43 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___43 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___42 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___42 *);
	int (*getgeo)(struct block_device___43 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___43 *, bool);
	void (*swap_slot_free_notify)(struct block_device___43 *, long unsigned int);
	int (*report_zones)(struct gendisk___42 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___42 *, umode_t *);
	struct module___85 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___42 *, sector_t *);
};

typedef void rq_end_io_fn___42(struct request___42 *, blk_status_t);

struct request___42 {
	struct request_queue___42 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___41 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___42 *bio;
	struct bio___42 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___51 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___42 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___42 *saved_end_io;
		} flush;
	};
	struct gendisk___42 *rq_disk;
	struct block_device___43 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___42 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___41 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___42 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___87 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___87 *debugfs_dir;
	struct dentry___87 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___42;

struct elevator_mq_ops___42 {
	int (*init_sched)(struct request_queue___42 *, struct elevator_type___42 *);
	void (*exit_sched)(struct elevator_queue___42 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___41 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___41 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___41 *);
	bool (*allow_merge)(struct request_queue___42 *, struct request___42 *, struct bio___42 *);
	bool (*bio_merge)(struct request_queue___42 *, struct bio___42 *, unsigned int);
	int (*request_merge)(struct request_queue___42 *, struct request___42 **, struct bio___42 *);
	void (*request_merged)(struct request_queue___42 *, struct request___42 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___42 *, struct request___42 *, struct request___42 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___42 *);
	void (*finish_request)(struct request___42 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___41 *, struct list_head *, bool);
	struct request___42 * (*dispatch_request)(struct blk_mq_hw_ctx___41 *);
	bool (*has_work)(struct blk_mq_hw_ctx___41 *);
	void (*completed_request)(struct request___42 *, u64);
	void (*requeue_request)(struct request___42 *);
	struct request___42 * (*former_request)(struct request_queue___42 *, struct request___42 *);
	struct request___42 * (*next_request)(struct request_queue___42 *, struct request___42 *);
	void (*init_icq)(struct io_cq___42 *);
	void (*exit_icq)(struct io_cq___42 *);
};

struct elv_fs_entry___42;

struct elevator_type___42 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___42 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___42 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___85 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___42 {
	struct elevator_type___42 *type;
	void *elevator_data;
	struct kobject___87 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___42 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___42 *, char *);
	ssize_t (*store)(struct elevator_queue___42 *, const char *, size_t);
};

struct blk_mq_queue_data___41;

struct blk_mq_ops___41 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___41 *, const struct blk_mq_queue_data___41 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___41 *);
	int (*get_budget)(struct request_queue___42 *);
	void (*put_budget)(struct request_queue___42 *, int);
	void (*set_rq_budget_token)(struct request___42 *, int);
	int (*get_rq_budget_token)(struct request___42 *);
	enum blk_eh_timer_return (*timeout)(struct request___42 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___41 *);
	void (*complete)(struct request___42 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___41 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___41 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___41 *, struct request___42 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___41 *, struct request___42 *, unsigned int);
	void (*initialize_rq_fn)(struct request___42 *);
	void (*cleanup_rq)(struct request___42 *);
	bool (*busy)(struct request_queue___42 *);
	int (*map_queues)(struct blk_mq_tag_set___41 *);
	void (*show_rq)(struct seq_file___82 *, struct request___42 *);
};

struct blk_mq_tag_set___41 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___41 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___41 {
	struct request___42 *rq;
	bool last;
};

struct blkcg_policy_data___41;

struct blkcg___41 {
	struct cgroup_subsys_state___72 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___41 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___41 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___41 {
	struct blkcg___41 *blkcg;
	int plid;
};

struct blkg_policy_data___41 {
	struct blkcg_gq___41 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___38 {
	struct mem_cgroup___38 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___38 {
	struct lruvec___44 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___38 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___38 *memcg;
};

struct obj_cgroup___38 {
	struct percpu_ref refcnt;
	struct mem_cgroup___38 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct watch___2 {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue___3 *queue;
	struct hlist_node queue_node;
	struct watch_list___2 *watch_list;
	struct hlist_node list_node;
	const struct cred___12 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

struct dentry___88;

struct super_block___88;

struct module___86;

struct file_system_type___88 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___88 * (*mount)(struct file_system_type___88 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___88 *);
	struct module___86 *owner;
	struct file_system_type___88 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___88;

struct kiocb___88;

struct iov_iter___53;

struct poll_table_struct___63;

struct vm_area_struct___93;

struct inode___88;

struct file_lock___88;

struct page___93;

struct pipe_inode_info___35;

struct seq_file___83;

struct file_operations___88 {
	struct module___86 *owner;
	loff_t (*llseek)(struct file___88 *, loff_t, int);
	ssize_t (*read)(struct file___88 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___88 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___88 *, struct iov_iter___53 *);
	ssize_t (*write_iter)(struct kiocb___88 *, struct iov_iter___53 *);
	int (*iopoll)(struct kiocb___88 *, bool);
	int (*iterate)(struct file___88 *, struct dir_context *);
	int (*iterate_shared)(struct file___88 *, struct dir_context *);
	__poll_t (*poll)(struct file___88 *, struct poll_table_struct___63 *);
	long int (*unlocked_ioctl)(struct file___88 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___88 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___88 *, struct vm_area_struct___93 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___88 *, struct file___88 *);
	int (*flush)(struct file___88 *, fl_owner_t);
	int (*release)(struct inode___88 *, struct file___88 *);
	int (*fsync)(struct file___88 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___88 *, int);
	int (*lock)(struct file___88 *, int, struct file_lock___88 *);
	ssize_t (*sendpage)(struct file___88 *, struct page___93 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___88 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___88 *, long unsigned int);
	int (*flock)(struct file___88 *, int, struct file_lock___88 *);
	ssize_t (*splice_write)(struct pipe_inode_info___35 *, struct file___88 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___88 *, loff_t *, struct pipe_inode_info___35 *, size_t, unsigned int);
	int (*setlease)(struct file___88 *, long int, struct file_lock___88 **, void **);
	long int (*fallocate)(struct file___88 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___83 *, struct file___88 *);
	ssize_t (*copy_file_range)(struct file___88 *, loff_t, struct file___88 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___88 *, loff_t, struct file___88 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___88 *, loff_t, loff_t, int);
};

struct vmacache___93 {
	u64 seqnum;
	struct vm_area_struct___93 *vmas[4];
};

struct page_frag___93 {
	struct page___93 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___53;

struct debug_info___53 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___53 *hbp_break[16];
	struct perf_event___53 *hbp_watch[16];
};

struct thread_struct___53 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___53 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___94;

struct pid___80;

struct nameidata___2;

struct fs_struct___11;

struct nsproxy___85;

struct signal_struct___89;

struct css_set___73;

struct perf_event_context___53;

struct vm_struct___88;

struct task_struct___95 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___95 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___94 *mm;
	struct mm_struct___94 *active_mm;
	struct vmacache___93 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___95 *real_parent;
	struct task_struct___95 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___95 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___80 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata___2 *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___11 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___85 *nsproxy;
	struct signal_struct___89 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___95 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___42 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___73 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___53 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___35 *splice_pipe;
	struct page_frag___93 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___95 *oom_reaper_list;
	struct vm_struct___88 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___53 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___88;

struct kobj_type___88;

struct kernfs_node___88;

struct kobject___88 {
	const char *name;
	struct list_head entry;
	struct kobject___88 *parent;
	struct kset___88 *kset;
	struct kobj_type___88 *ktype;
	struct kernfs_node___88 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___85 {
	struct kobject___88 kobj;
	struct module___86 *mod;
	struct kobject___88 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___85 {
	struct module___86 *mod;
	struct latch_tree_node node;
};

struct module_layout___85 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___85 mtn;
};

struct module_attribute___85;

struct kernel_param___85;

struct trace_event_call___47;

struct module___86 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___85 mkobj;
	struct module_attribute___85 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___88 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___85 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___85 core_layout;
	struct module_layout___85 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___47 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___53 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___95 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___53)(struct perf_event___53 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___53;

struct fasync_struct___88;

struct pid_namespace___80;

struct perf_cgroup___53;

struct perf_event___53 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___53 *group_leader;
	struct pmu___53 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___53 hw;
	struct perf_event_context___53 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___53 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___95 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___88 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___53 *aux_event;
	void (*destroy)(struct perf_event___53 *);
	struct callback_head callback_head;
	struct pid_namespace___80 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___53 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___53 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___47 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___53 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___93 *pgtable_t___93;

struct address_space___88;

struct page_pool___29;

struct dev_pagemap___87;

struct page___93 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___88 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___29 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___93 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___93 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___94 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___87 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___87;

struct vm_area_struct___93 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___93 *vm_next;
	struct vm_area_struct___93 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___94 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___87 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___88 *vm_file;
	struct file___88 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___93;

struct mm_struct___94 {
	struct {
		struct vm_area_struct___93 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___88 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___93 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___95 *owner;
		struct user_namespace___13 *user_ns;
		struct file___88 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___88;

struct address_space___88 {
	struct inode___88 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___88 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___74;

struct page_pool_params___29 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___74 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___29 {
	u32 count;
	struct page___93 *cache[128];
};

struct page_pool___29 {
	struct page_pool_params___29 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___93 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___29 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___87;

struct dev_pagemap___87 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___87 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___88;

struct path___88 {
	struct vfsmount___88 *mnt;
	struct dentry___88 *dentry;
};

struct fown_struct___80 {
	rwlock_t lock;
	struct pid___80 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___88 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___88 f_path;
	struct inode___88 *f_inode;
	const struct file_operations___88 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___80 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___88 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___87;

struct vm_operations_struct___87 {
	void (*open)(struct vm_area_struct___93 *);
	void (*close)(struct vm_area_struct___93 *);
	int (*may_split)(struct vm_area_struct___93 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___93 *);
	int (*mprotect)(struct vm_area_struct___93 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___87 *);
	vm_fault_t (*huge_fault)(struct vm_fault___87 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___87 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___93 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___87 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___87 *);
	int (*access)(struct vm_area_struct___93 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___93 *);
	int (*set_policy)(struct vm_area_struct___93 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___93 *, long unsigned int);
	struct page___93 * (*find_special_page)(struct vm_area_struct___93 *, long unsigned int);
};

struct core_thread___93 {
	struct task_struct___95 *task;
	struct core_thread___93 *next;
};

struct core_state___93 {
	atomic_t nr_threads;
	struct core_thread___93 dumper;
	struct completion startup;
};

struct vm_fault___87 {
	const struct {
		struct vm_area_struct___93 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___93 *cow_page;
	struct page___93 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___93 prealloc_pte;
};

struct dentry_operations___88;

struct dentry___88 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___88 *d_parent;
	struct qstr d_name;
	struct inode___88 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___88 *d_op;
	struct super_block___88 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___88;

struct inode___88 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___88 *i_op;
	struct super_block___88 *i_sb;
	struct address_space___88 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___88 *i_fop;
		void (*free_inode)(struct inode___88 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___88 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___35 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___88 {
	int (*d_revalidate)(struct dentry___88 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___88 *, unsigned int);
	int (*d_hash)(const struct dentry___88 *, struct qstr *);
	int (*d_compare)(const struct dentry___88 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___88 *);
	int (*d_init)(struct dentry___88 *);
	void (*d_release)(struct dentry___88 *);
	void (*d_prune)(struct dentry___88 *);
	void (*d_iput)(struct dentry___88 *, struct inode___88 *);
	char * (*d_dname)(struct dentry___88 *, char *, int);
	struct vfsmount___88 * (*d_automount)(struct path___88 *);
	int (*d_manage)(const struct path___88 *, bool);
	struct dentry___88 * (*d_real)(struct dentry___88 *, const struct inode___88 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___88;

struct mem_dqinfo___88 {
	struct quota_format_type___88 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___88;

struct quota_info___88 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___88 *files[3];
	struct mem_dqinfo___88 info[3];
	const struct quota_format_ops___88 *ops[3];
};

struct rcuwait___89 {
	struct task_struct___95 *task;
};

struct percpu_rw_semaphore___89 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___89 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___88 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___89 rw_sem[3];
};

struct super_operations___88;

struct dquot_operations___88;

struct quotactl_ops___88;

struct super_block___88 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___88 *s_type;
	const struct super_operations___88 *s_op;
	const struct dquot_operations___88 *dq_op;
	const struct quotactl_ops___88 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___88 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___88 s_dquot;
	struct sb_writers___88 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___88 *s_d_op;
	int cleancache_poolid;
	struct shrinker___38 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___88 {
	struct dentry___88 *mnt_root;
	struct super_block___88 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct name_snapshot {
	struct qstr name;
	unsigned char inline_name[32];
};

struct upid___80 {
	int nr;
	struct pid_namespace___80 *ns;
};

struct pid_namespace___80 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___95 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___80 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___80 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___80 numbers[1];
};

struct signal_struct___89 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___95 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___95 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___80 *pids[4];
	struct pid___80 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___94 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct saved {
	struct path___88 link;
	struct delayed_call done;
	const char *name;
	unsigned int seq;
};

struct nameidata___2 {
	struct path___88 path;
	struct qstr last;
	struct path___88 root;
	struct inode___88 *inode;
	unsigned int flags;
	unsigned int state;
	unsigned int seq;
	unsigned int m_seq;
	unsigned int r_seq;
	int last_type;
	unsigned int depth;
	int total_link_count;
	struct saved *stack;
	struct saved internal[2];
	struct filename *name;
	struct nameidata___2 *saved;
	unsigned int root_seq;
	int dfd;
	kuid_t dir_uid;
	umode_t dir_mode;
};

struct fs_struct___11 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___88 root;
	struct path___88 pwd;
};

struct mnt_namespace___2;

struct cgroup_namespace___73;

struct nsproxy___85 {
	atomic_t count;
	struct uts_namespace___6 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___2 *mnt_ns;
	struct pid_namespace___80 *pid_ns_for_children;
	struct net___22 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___73 *cgroup_ns;
};

struct cgroup_subsys_state___73;

struct cgroup___73;

struct css_set___73 {
	struct cgroup_subsys_state___73 *subsys[14];
	refcount_t refcount;
	struct css_set___73 *dom_cset;
	struct cgroup___73 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___73 *mg_src_cgrp;
	struct cgroup___73 *mg_dst_cgrp;
	struct css_set___73 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___53 {
	struct pmu___53 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___95 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___53 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___35;

struct pipe_inode_info___35 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___93 *tmp_page;
	struct fasync_struct___88 *fasync_readers;
	struct fasync_struct___88 *fasync_writers;
	struct pipe_buffer___35 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___88 {
	struct vm_struct___88 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___93 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct cgroup_subsys___73;

struct cgroup_subsys_state___73 {
	struct cgroup___73 *cgroup;
	struct cgroup_subsys___73 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___73 *parent;
};

struct cgroup_file___73 {
	struct kernfs_node___88 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___73 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___95 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___73;

struct cgroup_rstat_cpu___73;

struct cgroup___73 {
	struct cgroup_subsys_state___73 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___88 *kn;
	struct cgroup_file___73 procs_file;
	struct cgroup_file___73 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___73 *subsys[14];
	struct cgroup_root___73 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___73 *dom_cgrp;
	struct cgroup___73 *old_dom_cgrp;
	struct cgroup_rstat_cpu___73 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___73 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___45;

struct kiocb___88 {
	struct file___88 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___88 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___45 *ki_waitq;
	};
};

struct iattr___88 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___88 *ia_file;
};

struct dquot___88 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___88 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___88 {
	int qf_fmt_id;
	const struct quota_format_ops___88 *qf_ops;
	struct module___86 *qf_owner;
	struct quota_format_type___88 *qf_next;
};

struct quota_format_ops___88 {
	int (*check_quota_file)(struct super_block___88 *, int);
	int (*read_file_info)(struct super_block___88 *, int);
	int (*write_file_info)(struct super_block___88 *, int);
	int (*free_file_info)(struct super_block___88 *, int);
	int (*read_dqblk)(struct dquot___88 *);
	int (*commit_dqblk)(struct dquot___88 *);
	int (*release_dqblk)(struct dquot___88 *);
	int (*get_next_id)(struct super_block___88 *, struct kqid *);
};

struct dquot_operations___88 {
	int (*write_dquot)(struct dquot___88 *);
	struct dquot___88 * (*alloc_dquot)(struct super_block___88 *, int);
	void (*destroy_dquot)(struct dquot___88 *);
	int (*acquire_dquot)(struct dquot___88 *);
	int (*release_dquot)(struct dquot___88 *);
	int (*mark_dirty)(struct dquot___88 *);
	int (*write_info)(struct super_block___88 *, int);
	qsize_t * (*get_reserved_space)(struct inode___88 *);
	int (*get_projid)(struct inode___88 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___88 *, qsize_t *);
	int (*get_next_id)(struct super_block___88 *, struct kqid *);
};

struct quotactl_ops___88 {
	int (*quota_on)(struct super_block___88 *, int, int, const struct path___88 *);
	int (*quota_off)(struct super_block___88 *, int);
	int (*quota_enable)(struct super_block___88 *, unsigned int);
	int (*quota_disable)(struct super_block___88 *, unsigned int);
	int (*quota_sync)(struct super_block___88 *, int);
	int (*set_info)(struct super_block___88 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___88 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___88 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___88 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___88 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___88 *, unsigned int);
};

struct wait_page_queue___45 {
	struct page___93 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___45;

struct address_space_operations___88 {
	int (*writepage)(struct page___93 *, struct writeback_control___3 *);
	int (*readpage)(struct file___88 *, struct page___93 *);
	int (*writepages)(struct address_space___88 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___93 *);
	int (*readpages)(struct file___88 *, struct address_space___88 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___45 *);
	int (*write_begin)(struct file___88 *, struct address_space___88 *, loff_t, unsigned int, unsigned int, struct page___93 **, void **);
	int (*write_end)(struct file___88 *, struct address_space___88 *, loff_t, unsigned int, unsigned int, struct page___93 *, void *);
	sector_t (*bmap)(struct address_space___88 *, sector_t);
	void (*invalidatepage)(struct page___93 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___93 *, gfp_t);
	void (*freepage)(struct page___93 *);
	ssize_t (*direct_IO)(struct kiocb___88 *, struct iov_iter___53 *);
	int (*migratepage)(struct address_space___88 *, struct page___93 *, struct page___93 *, enum migrate_mode);
	bool (*isolate_page)(struct page___93 *, isolate_mode_t);
	void (*putback_page)(struct page___93 *);
	int (*launder_page)(struct page___93 *);
	int (*is_partially_uptodate)(struct page___93 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___93 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___88 *, struct page___93 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___88 *, sector_t *);
	void (*swap_deactivate)(struct file___88 *);
};

struct readahead_control___45 {
	struct file___88 *file;
	struct address_space___88 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___52;

struct iov_iter___53 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___52 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___35 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___88 {
	struct dentry___88 * (*lookup)(struct inode___88 *, struct dentry___88 *, unsigned int);
	const char * (*get_link)(struct dentry___88 *, struct inode___88 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___88 *, int);
	struct posix_acl * (*get_acl)(struct inode___88 *, int, bool);
	int (*readlink)(struct dentry___88 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___88 *, struct dentry___88 *, umode_t, bool);
	int (*link)(struct dentry___88 *, struct inode___88 *, struct dentry___88 *);
	int (*unlink)(struct inode___88 *, struct dentry___88 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___88 *, struct dentry___88 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___88 *, struct dentry___88 *, umode_t);
	int (*rmdir)(struct inode___88 *, struct dentry___88 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___88 *, struct dentry___88 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___88 *, struct dentry___88 *, struct inode___88 *, struct dentry___88 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___88 *, struct iattr___88 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___88 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___88 *, char *, size_t);
	int (*fiemap)(struct inode___88 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___88 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___88 *, struct dentry___88 *, struct file___88 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___88 *, struct dentry___88 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___88 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___88 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___88 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___88 {
	void (*fl_copy_lock)(struct file_lock___88 *, struct file_lock___88 *);
	void (*fl_release_private)(struct file_lock___88 *);
};

struct lock_manager_operations___88;

struct file_lock___88 {
	struct file_lock___88 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___88 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___88 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___88 *fl_ops;
	const struct lock_manager_operations___88 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___88 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___88 *);
	int (*lm_grant)(struct file_lock___88 *, int);
	bool (*lm_break)(struct file_lock___88 *);
	int (*lm_change)(struct file_lock___88 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___88 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___88 *);
};

struct fasync_struct___88 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___88 *fa_next;
	struct file___88 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___88 {
	struct inode___88 * (*alloc_inode)(struct super_block___88 *);
	void (*destroy_inode)(struct inode___88 *);
	void (*free_inode)(struct inode___88 *);
	void (*dirty_inode)(struct inode___88 *, int);
	int (*write_inode)(struct inode___88 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___88 *);
	void (*evict_inode)(struct inode___88 *);
	void (*put_super)(struct super_block___88 *);
	int (*sync_fs)(struct super_block___88 *, int);
	int (*freeze_super)(struct super_block___88 *);
	int (*freeze_fs)(struct super_block___88 *);
	int (*thaw_super)(struct super_block___88 *);
	int (*unfreeze_fs)(struct super_block___88 *);
	int (*statfs)(struct dentry___88 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___88 *, int *, char *);
	void (*umount_begin)(struct super_block___88 *);
	int (*show_options)(struct seq_file___83 *, struct dentry___88 *);
	int (*show_devname)(struct seq_file___83 *, struct dentry___88 *);
	int (*show_path)(struct seq_file___83 *, struct dentry___88 *);
	int (*show_stats)(struct seq_file___83 *, struct dentry___88 *);
	ssize_t (*quota_read)(struct super_block___88 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___88 *, int, const char *, size_t, loff_t);
	struct dquot___88 ** (*get_dquots)(struct inode___88 *);
	long int (*nr_cached_objects)(struct super_block___88 *, struct shrink_control___38 *);
	long int (*free_cached_objects)(struct super_block___88 *, struct shrink_control___38 *);
	struct file___88 * (*real_loop)(struct file___88 *);
};

struct renamedata {
	struct user_namespace___13 *old_mnt_userns;
	struct inode___88 *old_dir;
	struct dentry___88 *old_dentry;
	struct user_namespace___13 *new_mnt_userns;
	struct inode___88 *new_dir;
	struct dentry___88 *new_dentry;
	struct inode___88 **delegated_inode;
	unsigned int flags;
};

typedef void (*poll_queue_proc___63)(struct file___88 *, wait_queue_head_t *, struct poll_table_struct___63 *);

struct poll_table_struct___63 {
	poll_queue_proc___63 _qproc;
	__poll_t _key;
};

struct seq_operations___83;

struct seq_file___83 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___83 *op;
	int poll_event;
	const struct file___88 *file;
	void *private;
};

enum {
	LAST_NORM = 0,
	LAST_ROOT = 1,
	LAST_DOT = 2,
	LAST_DOTDOT = 3,
};

struct dev_pagemap_ops___87 {
	void (*page_free)(struct page___93 *);
	void (*kill)(struct dev_pagemap___87 *);
	void (*cleanup)(struct dev_pagemap___87 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___87 *);
};

struct fwnode_operations___74;

struct fwnode_handle___74 {
	struct fwnode_handle___74 *secondary;
	const struct fwnode_operations___74 *ops;
	struct device___74 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___74;

struct fwnode_endpoint___74;

struct fwnode_operations___74 {
	struct fwnode_handle___74 * (*get)(struct fwnode_handle___74 *);
	void (*put)(struct fwnode_handle___74 *);
	bool (*device_is_available)(const struct fwnode_handle___74 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___74 *, const struct device___74 *);
	bool (*property_present)(const struct fwnode_handle___74 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___74 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___74 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___74 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*get_parent)(const struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*get_next_child_node)(const struct fwnode_handle___74 *, struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*get_named_child_node)(const struct fwnode_handle___74 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___74 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___74 *);
	struct fwnode_handle___74 * (*graph_get_next_endpoint)(const struct fwnode_handle___74 *, struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*graph_get_remote_endpoint)(const struct fwnode_handle___74 *);
	struct fwnode_handle___74 * (*graph_get_port_parent)(struct fwnode_handle___74 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___74 *, struct fwnode_endpoint___74 *);
	int (*add_links)(struct fwnode_handle___74 *);
};

struct wakeup_source___74;

struct dev_pm_info___74 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___74 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___74 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___74;

struct bus_type___74;

struct device_driver___74;

struct dev_pm_domain___74;

struct class___74;

struct attribute_group___88;

struct device___74 {
	struct kobject___88 kobj;
	struct device___74 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___74 *type;
	struct bus_type___74 *bus;
	struct device_driver___74 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___74 power;
	struct dev_pm_domain___74 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___74 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___74 *class;
	const struct attribute_group___88 **groups;
	void (*release)(struct device___74 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___74 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___74 *local_fwnode;
};

struct fwnode_reference_args___74 {
	struct fwnode_handle___74 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___88;

struct kernfs_elem_dir___88 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___88 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___88;

struct kernfs_root___88 {
	struct kernfs_node___88 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___88 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___88 {
	struct kernfs_node___88 *target_kn;
};

struct kernfs_ops___88;

struct kernfs_elem_attr___88 {
	const struct kernfs_ops___88 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___88 *notify_next;
};

struct kernfs_node___88 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___88 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___88 dir;
		struct kernfs_elem_symlink___88 symlink;
		struct kernfs_elem_attr___88 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___88;

struct kernfs_ops___88 {
	int (*open)(struct kernfs_open_file___88 *);
	void (*release)(struct kernfs_open_file___88 *);
	int (*seq_show)(struct seq_file___83 *, void *);
	void * (*seq_start)(struct seq_file___83 *, loff_t *);
	void * (*seq_next)(struct seq_file___83 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___83 *, void *);
	ssize_t (*read)(struct kernfs_open_file___88 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___88 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___88 *, struct poll_table_struct___63 *);
	int (*mmap)(struct kernfs_open_file___88 *, struct vm_area_struct___93 *);
};

struct kernfs_syscall_ops___88 {
	int (*show_options)(struct seq_file___83 *, struct kernfs_root___88 *);
	int (*mkdir)(struct kernfs_node___88 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___88 *);
	int (*rename)(struct kernfs_node___88 *, struct kernfs_node___88 *, const char *);
	int (*show_path)(struct seq_file___83 *, struct kernfs_node___88 *, struct kernfs_root___88 *);
};

struct kernfs_open_file___88 {
	struct kernfs_node___88 *kn;
	struct file___88 *file;
	struct seq_file___83 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___87 *vm_ops;
};

struct bin_attribute___88;

struct attribute_group___88 {
	const char *name;
	umode_t (*is_visible)(struct kobject___88 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___88 *, struct bin_attribute___88 *, int);
	struct attribute **attrs;
	struct bin_attribute___88 **bin_attrs;
};

struct bin_attribute___88 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___88 * (*f_mapping)();
	ssize_t (*read)(struct file___88 *, struct kobject___88 *, struct bin_attribute___88 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___88 *, struct kobject___88 *, struct bin_attribute___88 *, char *, loff_t, size_t);
	int (*mmap)(struct file___88 *, struct kobject___88 *, struct bin_attribute___88 *, struct vm_area_struct___93 *);
};

struct sysfs_ops___88 {
	ssize_t (*show)(struct kobject___88 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___88 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___88;

struct kset___88 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___88 kobj;
	const struct kset_uevent_ops___88 *uevent_ops;
};

struct kobj_type___88 {
	void (*release)(struct kobject___88 *);
	const struct sysfs_ops___88 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___88 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___88 *);
	const void * (*namespace)(struct kobject___88 *);
	void (*get_ownership)(struct kobject___88 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___88 {
	int (* const filter)(struct kset___88 *, struct kobject___88 *);
	const char * (* const name)(struct kset___88 *, struct kobject___88 *);
	int (* const uevent)(struct kset___88 *, struct kobject___88 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___85 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___85 *);
	int (*get)(char *, const struct kernel_param___85 *);
	void (*free)(void *);
};

struct kparam_array___85;

struct kernel_param___85 {
	const char *name;
	struct module___86 *mod;
	const struct kernel_param_ops___85 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___85 *arr;
	};
};

struct kparam_array___85 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___85 *ops;
	void *elem;
};

struct module_attribute___85 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___85 *, struct module_kobject___85 *, char *);
	ssize_t (*store)(struct module_attribute___85 *, struct module_kobject___85 *, const char *, size_t);
	void (*setup)(struct module___86 *, const char *);
	int (*test)(struct module___86 *);
	void (*free)(struct module___86 *);
};

struct trace_event_class___47;

struct trace_event_call___47 {
	struct list_head list;
	struct trace_event_class___47 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___47 *, struct perf_event___53 *);
};

struct mount___2;

struct mnt_namespace___2 {
	struct ns_common___13 ns;
	struct mount___2 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___73 {
	struct ns_common___13 ns;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct css_set___73 *root_cset;
};

struct bio_vec___52 {
	struct page___93 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

typedef int filler_t___3(void *, struct page___93 *);

struct seq_operations___83 {
	void * (*start)(struct seq_file___83 *, loff_t *);
	void (*stop)(struct seq_file___83 *, void *);
	void * (*next)(struct seq_file___83 *, void *, loff_t *);
	int (*show)(struct seq_file___83 *, void *);
};

struct fd___15 {
	struct file___88 *file;
	unsigned int flags;
};

struct dev_pm_ops___74 {
	int (*prepare)(struct device___74 *);
	void (*complete)(struct device___74 *);
	int (*suspend)(struct device___74 *);
	int (*resume)(struct device___74 *);
	int (*freeze)(struct device___74 *);
	int (*thaw)(struct device___74 *);
	int (*poweroff)(struct device___74 *);
	int (*restore)(struct device___74 *);
	int (*suspend_late)(struct device___74 *);
	int (*resume_early)(struct device___74 *);
	int (*freeze_late)(struct device___74 *);
	int (*thaw_early)(struct device___74 *);
	int (*poweroff_late)(struct device___74 *);
	int (*restore_early)(struct device___74 *);
	int (*suspend_noirq)(struct device___74 *);
	int (*resume_noirq)(struct device___74 *);
	int (*freeze_noirq)(struct device___74 *);
	int (*thaw_noirq)(struct device___74 *);
	int (*poweroff_noirq)(struct device___74 *);
	int (*restore_noirq)(struct device___74 *);
	int (*runtime_suspend)(struct device___74 *);
	int (*runtime_resume)(struct device___74 *);
	int (*runtime_idle)(struct device___74 *);
};

struct wakeup_source___74 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___74 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___74 {
	struct dev_pm_ops___74 ops;
	int (*start)(struct device___74 *);
	void (*detach)(struct device___74 *, bool);
	int (*activate)(struct device___74 *);
	void (*sync)(struct device___74 *);
	void (*dismiss)(struct device___74 *);
};

struct bus_type___74 {
	const char *name;
	const char *dev_name;
	struct device___74 *dev_root;
	const struct attribute_group___88 **bus_groups;
	const struct attribute_group___88 **dev_groups;
	const struct attribute_group___88 **drv_groups;
	int (*match)(struct device___74 *, struct device_driver___74 *);
	int (*uevent)(struct device___74 *, struct kobj_uevent_env *);
	int (*probe)(struct device___74 *);
	void (*sync_state)(struct device___74 *);
	void (*remove)(struct device___74 *);
	void (*shutdown)(struct device___74 *);
	int (*online)(struct device___74 *);
	int (*offline)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	int (*num_vf)(struct device___74 *);
	int (*dma_configure)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___74 {
	const char *name;
	struct bus_type___74 *bus;
	struct module___86 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___74 *);
	void (*sync_state)(struct device___74 *);
	int (*remove)(struct device___74 *);
	void (*shutdown)(struct device___74 *);
	int (*suspend)(struct device___74 *, pm_message_t);
	int (*resume)(struct device___74 *);
	const struct attribute_group___88 **groups;
	const struct attribute_group___88 **dev_groups;
	const struct dev_pm_ops___74 *pm;
	void (*coredump)(struct device___74 *);
	struct driver_private *p;
};

struct device_type___74 {
	const char *name;
	const struct attribute_group___88 **groups;
	int (*uevent)(struct device___74 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___74 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___74 *);
	const struct dev_pm_ops___74 *pm;
};

struct class___74 {
	const char *name;
	struct module___86 *owner;
	const struct attribute_group___88 **class_groups;
	const struct attribute_group___88 **dev_groups;
	struct kobject___88 *dev_kobj;
	int (*dev_uevent)(struct device___74 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___74 *, umode_t *);
	void (*class_release)(struct class___74 *);
	void (*dev_release)(struct device___74 *);
	int (*shutdown_pre)(struct device___74 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___74 *);
	void (*get_ownership)(struct device___74 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___74 *pm;
	struct subsys_private *p;
};

struct cftype___73;

struct cgroup_subsys___73 {
	struct cgroup_subsys_state___73 * (*css_alloc)(struct cgroup_subsys_state___73 *);
	int (*css_online)(struct cgroup_subsys_state___73 *);
	void (*css_offline)(struct cgroup_subsys_state___73 *);
	void (*css_released)(struct cgroup_subsys_state___73 *);
	void (*css_free)(struct cgroup_subsys_state___73 *);
	void (*css_reset)(struct cgroup_subsys_state___73 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___73 *, int);
	int (*css_extra_stat_show)(struct seq_file___83 *, struct cgroup_subsys_state___73 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___95 *, struct css_set___73 *);
	void (*cancel_fork)(struct task_struct___95 *, struct css_set___73 *);
	void (*fork)(struct task_struct___95 *);
	void (*exit)(struct task_struct___95 *);
	void (*release)(struct task_struct___95 *);
	void (*bind)(struct cgroup_subsys_state___73 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___73 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___73 *dfl_cftypes;
	struct cftype___73 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___73 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___73 *updated_children;
	struct cgroup___73 *updated_next;
};

struct cgroup_root___73 {
	struct kernfs_root___88 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___73 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___73 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___73 *ss;
	struct list_head node;
	struct kernfs_ops___88 *kf_ops;
	int (*open)(struct kernfs_open_file___88 *);
	void (*release)(struct kernfs_open_file___88 *);
	u64 (*read_u64)(struct cgroup_subsys_state___73 *, struct cftype___73 *);
	s64 (*read_s64)(struct cgroup_subsys_state___73 *, struct cftype___73 *);
	int (*seq_show)(struct seq_file___83 *, void *);
	void * (*seq_start)(struct seq_file___83 *, loff_t *);
	void * (*seq_next)(struct seq_file___83 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___83 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___73 *, struct cftype___73 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___73 *, struct cftype___73 *, s64);
	ssize_t (*write)(struct kernfs_open_file___88 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___88 *, struct poll_table_struct___63 *);
};

struct perf_cpu_context___53;

struct perf_output_handle___53;

struct pmu___53 {
	struct list_head entry;
	struct module___86 *module;
	struct device___74 *dev;
	const struct attribute_group___88 **attr_groups;
	const struct attribute_group___88 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___53 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___53 *);
	void (*pmu_disable)(struct pmu___53 *);
	int (*event_init)(struct perf_event___53 *);
	void (*event_mapped)(struct perf_event___53 *, struct mm_struct___94 *);
	void (*event_unmapped)(struct perf_event___53 *, struct mm_struct___94 *);
	int (*add)(struct perf_event___53 *, int);
	void (*del)(struct perf_event___53 *, int);
	void (*start)(struct perf_event___53 *, int);
	void (*stop)(struct perf_event___53 *, int);
	void (*read)(struct perf_event___53 *);
	void (*start_txn)(struct pmu___53 *, unsigned int);
	int (*commit_txn)(struct pmu___53 *);
	void (*cancel_txn)(struct pmu___53 *);
	int (*event_idx)(struct perf_event___53 *);
	void (*sched_task)(struct perf_event_context___53 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___53 *, struct perf_event_context___53 *);
	void * (*setup_aux)(struct perf_event___53 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___53 *, struct perf_output_handle___53 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___53 *);
	int (*aux_output_match)(struct perf_event___53 *);
	int (*filter_match)(struct perf_event___53 *);
	int (*check_period)(struct perf_event___53 *, u64);
};

struct perf_cpu_context___53 {
	struct perf_event_context___53 ctx;
	struct perf_event_context___53 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___53 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___53 **heap;
	struct perf_event___53 *heap_default[2];
};

struct perf_output_handle___53 {
	struct perf_event___53 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___53 {
	struct cgroup_subsys_state___73 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___47 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___47 *);
	};
};

struct trace_event_class___47 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___47 *, enum trace_reg, void *);
	struct trace_event_fields___47 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___47 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___47 *);
};

struct syscall_metadata___22 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___47 *enter_event;
	struct trace_event_call___47 *exit_event;
};

struct pipe_buf_operations___35;

struct pipe_buffer___35 {
	struct page___93 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___35 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___35 {
	int (*confirm)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
	void (*release)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
	bool (*try_steal)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
	bool (*get)(struct pipe_inode_info___35 *, struct pipe_buffer___35 *);
};

struct mountpoint___2;

struct mount___2 {
	struct hlist_node mnt_hash;
	struct mount___2 *mnt_parent;
	struct dentry___88 *mnt_mountpoint;
	struct vfsmount___88 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___2 *mnt_master;
	struct mnt_namespace___2 *mnt_ns;
	struct mountpoint___2 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___2 {
	struct hlist_node m_hash;
	struct dentry___88 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

enum {
	WALK_TRAILING = 1,
	WALK_MORE = 2,
	WALK_NOFOLLOW = 4,
};

struct word_at_a_time {
	const long unsigned int one_bits;
	const long unsigned int high_bits;
};

struct dentry___89;

struct super_block___89;

struct module___87;

struct file_system_type___89 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___89 * (*mount)(struct file_system_type___89 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___89 *);
	struct module___87 *owner;
	struct file_system_type___89 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___89;

struct kiocb___89;

struct iov_iter___54;

struct poll_table_struct___64;

struct vm_area_struct___94;

struct inode___89;

struct file_lock___89;

struct page___94;

struct pipe_inode_info___36;

struct seq_file___84;

struct file_operations___89 {
	struct module___87 *owner;
	loff_t (*llseek)(struct file___89 *, loff_t, int);
	ssize_t (*read)(struct file___89 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___89 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___89 *, struct iov_iter___54 *);
	ssize_t (*write_iter)(struct kiocb___89 *, struct iov_iter___54 *);
	int (*iopoll)(struct kiocb___89 *, bool);
	int (*iterate)(struct file___89 *, struct dir_context *);
	int (*iterate_shared)(struct file___89 *, struct dir_context *);
	__poll_t (*poll)(struct file___89 *, struct poll_table_struct___64 *);
	long int (*unlocked_ioctl)(struct file___89 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___89 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___89 *, struct vm_area_struct___94 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___89 *, struct file___89 *);
	int (*flush)(struct file___89 *, fl_owner_t);
	int (*release)(struct inode___89 *, struct file___89 *);
	int (*fsync)(struct file___89 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___89 *, int);
	int (*lock)(struct file___89 *, int, struct file_lock___89 *);
	ssize_t (*sendpage)(struct file___89 *, struct page___94 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___89 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___89 *, long unsigned int);
	int (*flock)(struct file___89 *, int, struct file_lock___89 *);
	ssize_t (*splice_write)(struct pipe_inode_info___36 *, struct file___89 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___89 *, loff_t *, struct pipe_inode_info___36 *, size_t, unsigned int);
	int (*setlease)(struct file___89 *, long int, struct file_lock___89 **, void **);
	long int (*fallocate)(struct file___89 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___84 *, struct file___89 *);
	ssize_t (*copy_file_range)(struct file___89 *, loff_t, struct file___89 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___89 *, loff_t, struct file___89 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___89 *, loff_t, loff_t, int);
};

struct vmacache___94 {
	u64 seqnum;
	struct vm_area_struct___94 *vmas[4];
};

struct page_frag___94 {
	struct page___94 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___54;

struct debug_info___54 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___54 *hbp_break[16];
	struct perf_event___54 *hbp_watch[16];
};

struct thread_struct___54 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___54 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___95;

struct pid___81;

struct files_struct___9;

struct nsproxy___86;

struct signal_struct___90;

struct css_set___74;

struct perf_event_context___54;

struct vm_struct___89;

struct task_struct___96 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___96 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___95 *mm;
	struct mm_struct___95 *active_mm;
	struct vmacache___94 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___96 *real_parent;
	struct task_struct___96 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___96 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___81 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___9 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___86 *nsproxy;
	struct signal_struct___90 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___96 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___42 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___74 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___54 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___36 *splice_pipe;
	struct page_frag___94 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___96 *oom_reaper_list;
	struct vm_struct___89 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___54 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___89;

struct kobj_type___89;

struct kernfs_node___89;

struct kobject___89 {
	const char *name;
	struct list_head entry;
	struct kobject___89 *parent;
	struct kset___89 *kset;
	struct kobj_type___89 *ktype;
	struct kernfs_node___89 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___86 {
	struct kobject___89 kobj;
	struct module___87 *mod;
	struct kobject___89 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___86 {
	struct module___87 *mod;
	struct latch_tree_node node;
};

struct module_layout___86 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___86 mtn;
};

struct module_attribute___86;

struct kernel_param___86;

struct trace_event_call___48;

struct module___87 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___86 mkobj;
	struct module_attribute___86 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___89 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___86 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___86 core_layout;
	struct module_layout___86 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___48 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___54 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___96 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___54)(struct perf_event___54 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___54;

struct fasync_struct___89;

struct pid_namespace___81;

struct perf_cgroup___54;

struct perf_event___54 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___54 *group_leader;
	struct pmu___54 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___54 hw;
	struct perf_event_context___54 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___54 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___96 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___89 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___54 *aux_event;
	void (*destroy)(struct perf_event___54 *);
	struct callback_head callback_head;
	struct pid_namespace___81 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___54 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___54 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___48 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___54 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___89;

struct dentry___89 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___89 *d_parent;
	struct qstr d_name;
	struct inode___89 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___89 *d_op;
	struct super_block___89 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___89;

struct address_space___89 {
	struct inode___89 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___89 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___89;

struct inode___89 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___89 *i_op;
	struct super_block___89 *i_sb;
	struct address_space___89 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___89 *i_fop;
		void (*free_inode)(struct inode___89 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___89 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___36 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___89;

struct path___89;

struct dentry_operations___89 {
	int (*d_revalidate)(struct dentry___89 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___89 *, unsigned int);
	int (*d_hash)(const struct dentry___89 *, struct qstr *);
	int (*d_compare)(const struct dentry___89 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___89 *);
	int (*d_init)(struct dentry___89 *);
	void (*d_release)(struct dentry___89 *);
	void (*d_prune)(struct dentry___89 *);
	void (*d_iput)(struct dentry___89 *, struct inode___89 *);
	char * (*d_dname)(struct dentry___89 *, char *, int);
	struct vfsmount___89 * (*d_automount)(struct path___89 *);
	int (*d_manage)(const struct path___89 *, bool);
	struct dentry___89 * (*d_real)(struct dentry___89 *, const struct inode___89 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___89;

struct mem_dqinfo___89 {
	struct quota_format_type___89 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___89;

struct quota_info___89 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___89 *files[3];
	struct mem_dqinfo___89 info[3];
	const struct quota_format_ops___89 *ops[3];
};

struct rcuwait___90 {
	struct task_struct___96 *task;
};

struct percpu_rw_semaphore___90 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___90 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___89 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___90 rw_sem[3];
};

struct super_operations___89;

struct dquot_operations___89;

struct quotactl_ops___89;

struct super_block___89 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___89 *s_type;
	const struct super_operations___89 *s_op;
	const struct dquot_operations___89 *dq_op;
	const struct quotactl_ops___89 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___89 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___89 s_dquot;
	struct sb_writers___89 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___89 *s_d_op;
	int cleancache_poolid;
	struct shrinker___38 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___89 {
	struct dentry___89 *mnt_root;
	struct super_block___89 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct path___89 {
	struct vfsmount___89 *mnt;
	struct dentry___89 *dentry;
};

struct upid___81 {
	int nr;
	struct pid_namespace___81 *ns;
};

struct pid_namespace___81 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___96 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___81 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___81 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___81 numbers[1];
};

typedef struct page___94 *pgtable_t___94;

struct dev_pagemap___88;

struct page___94 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___89 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___29 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___94 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___94 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___95 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___88 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___88;

struct vm_area_struct___94 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___94 *vm_next;
	struct vm_area_struct___94 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___95 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___88 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___89 *vm_file;
	struct file___89 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___90 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___96 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___96 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___81 *pids[4];
	struct pid___81 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___95 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___94;

struct mm_struct___95 {
	struct {
		struct vm_area_struct___94 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___89 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___94 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___96 *owner;
		struct user_namespace___13 *user_ns;
		struct file___89 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___9 {
	unsigned int max_fds;
	struct file___89 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___9 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___9 *fdt;
	struct fdtable___9 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___89 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___74;

struct nsproxy___86 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___81 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___74 *cgroup_ns;
};

struct cgroup_subsys_state___74;

struct cgroup___74;

struct css_set___74 {
	struct cgroup_subsys_state___74 *subsys[14];
	refcount_t refcount;
	struct css_set___74 *dom_cset;
	struct cgroup___74 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___74 *mg_src_cgrp;
	struct cgroup___74 *mg_dst_cgrp;
	struct css_set___74 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___54 {
	struct pmu___54 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___96 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___54 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___36;

struct pipe_inode_info___36 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___94 *tmp_page;
	struct fasync_struct___89 *fasync_readers;
	struct fasync_struct___89 *fasync_writers;
	struct pipe_buffer___36 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___89 {
	struct vm_struct___89 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___94 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct compat_flock {
	short int l_type;
	short int l_whence;
	compat_off_t l_start;
	compat_off_t l_len;
	compat_pid_t l_pid;
};

struct compat_flock64 {
	short int l_type;
	short int l_whence;
	compat_loff_t l_start;
	compat_loff_t l_len;
	compat_pid_t l_pid;
};

struct dev_pagemap_ops___88;

struct dev_pagemap___88 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___88 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___81 {
	rwlock_t lock;
	struct pid___81 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___89 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___89 f_path;
	struct inode___89 *f_inode;
	const struct file_operations___89 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___81 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___89 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___88;

struct vm_operations_struct___88 {
	void (*open)(struct vm_area_struct___94 *);
	void (*close)(struct vm_area_struct___94 *);
	int (*may_split)(struct vm_area_struct___94 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___94 *);
	int (*mprotect)(struct vm_area_struct___94 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___88 *);
	vm_fault_t (*huge_fault)(struct vm_fault___88 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___88 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___94 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___88 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___88 *);
	int (*access)(struct vm_area_struct___94 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___94 *);
	int (*set_policy)(struct vm_area_struct___94 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___94 *, long unsigned int);
	struct page___94 * (*find_special_page)(struct vm_area_struct___94 *, long unsigned int);
};

struct core_thread___94 {
	struct task_struct___96 *task;
	struct core_thread___94 *next;
};

struct core_state___94 {
	atomic_t nr_threads;
	struct core_thread___94 dumper;
	struct completion startup;
};

struct vm_fault___88 {
	const struct {
		struct vm_area_struct___94 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___94 *cow_page;
	struct page___94 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___94 prealloc_pte;
};

struct f_owner_ex {
	int type;
	__kernel_pid_t pid;
};

struct flock {
	short int l_type;
	short int l_whence;
	__kernel_off_t l_start;
	__kernel_off_t l_len;
	__kernel_pid_t l_pid;
};

struct cgroup_subsys___74;

struct cgroup_subsys_state___74 {
	struct cgroup___74 *cgroup;
	struct cgroup_subsys___74 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___74 *parent;
};

struct cgroup_file___74 {
	struct kernfs_node___89 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___74 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___96 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___74;

struct cgroup_rstat_cpu___74;

struct cgroup___74 {
	struct cgroup_subsys_state___74 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___89 *kn;
	struct cgroup_file___74 procs_file;
	struct cgroup_file___74 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___74 *subsys[14];
	struct cgroup_root___74 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___74 *dom_cgrp;
	struct cgroup___74 *old_dom_cgrp;
	struct cgroup_rstat_cpu___74 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___74 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___89 {
	struct file___89 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___89 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___45 *ki_waitq;
	};
};

struct iattr___89 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___89 *ia_file;
};

struct dquot___89 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___89 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___89 {
	int qf_fmt_id;
	const struct quota_format_ops___89 *qf_ops;
	struct module___87 *qf_owner;
	struct quota_format_type___89 *qf_next;
};

struct quota_format_ops___89 {
	int (*check_quota_file)(struct super_block___89 *, int);
	int (*read_file_info)(struct super_block___89 *, int);
	int (*write_file_info)(struct super_block___89 *, int);
	int (*free_file_info)(struct super_block___89 *, int);
	int (*read_dqblk)(struct dquot___89 *);
	int (*commit_dqblk)(struct dquot___89 *);
	int (*release_dqblk)(struct dquot___89 *);
	int (*get_next_id)(struct super_block___89 *, struct kqid *);
};

struct dquot_operations___89 {
	int (*write_dquot)(struct dquot___89 *);
	struct dquot___89 * (*alloc_dquot)(struct super_block___89 *, int);
	void (*destroy_dquot)(struct dquot___89 *);
	int (*acquire_dquot)(struct dquot___89 *);
	int (*release_dquot)(struct dquot___89 *);
	int (*mark_dirty)(struct dquot___89 *);
	int (*write_info)(struct super_block___89 *, int);
	qsize_t * (*get_reserved_space)(struct inode___89 *);
	int (*get_projid)(struct inode___89 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___89 *, qsize_t *);
	int (*get_next_id)(struct super_block___89 *, struct kqid *);
};

struct quotactl_ops___89 {
	int (*quota_on)(struct super_block___89 *, int, int, const struct path___89 *);
	int (*quota_off)(struct super_block___89 *, int);
	int (*quota_enable)(struct super_block___89 *, unsigned int);
	int (*quota_disable)(struct super_block___89 *, unsigned int);
	int (*quota_sync)(struct super_block___89 *, int);
	int (*set_info)(struct super_block___89 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___89 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___89 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___89 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___89 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___89 *, unsigned int);
};

struct address_space_operations___89 {
	int (*writepage)(struct page___94 *, struct writeback_control___3 *);
	int (*readpage)(struct file___89 *, struct page___94 *);
	int (*writepages)(struct address_space___89 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___94 *);
	int (*readpages)(struct file___89 *, struct address_space___89 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___89 *, struct address_space___89 *, loff_t, unsigned int, unsigned int, struct page___94 **, void **);
	int (*write_end)(struct file___89 *, struct address_space___89 *, loff_t, unsigned int, unsigned int, struct page___94 *, void *);
	sector_t (*bmap)(struct address_space___89 *, sector_t);
	void (*invalidatepage)(struct page___94 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___94 *, gfp_t);
	void (*freepage)(struct page___94 *);
	ssize_t (*direct_IO)(struct kiocb___89 *, struct iov_iter___54 *);
	int (*migratepage)(struct address_space___89 *, struct page___94 *, struct page___94 *, enum migrate_mode);
	bool (*isolate_page)(struct page___94 *, isolate_mode_t);
	void (*putback_page)(struct page___94 *);
	int (*launder_page)(struct page___94 *);
	int (*is_partially_uptodate)(struct page___94 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___94 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___89 *, struct page___94 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___89 *, sector_t *);
	void (*swap_deactivate)(struct file___89 *);
};

struct iov_iter___54 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___36 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___89 {
	struct dentry___89 * (*lookup)(struct inode___89 *, struct dentry___89 *, unsigned int);
	const char * (*get_link)(struct dentry___89 *, struct inode___89 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___89 *, int);
	struct posix_acl * (*get_acl)(struct inode___89 *, int, bool);
	int (*readlink)(struct dentry___89 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___89 *, struct dentry___89 *, umode_t, bool);
	int (*link)(struct dentry___89 *, struct inode___89 *, struct dentry___89 *);
	int (*unlink)(struct inode___89 *, struct dentry___89 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___89 *, struct dentry___89 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___89 *, struct dentry___89 *, umode_t);
	int (*rmdir)(struct inode___89 *, struct dentry___89 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___89 *, struct dentry___89 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___89 *, struct dentry___89 *, struct inode___89 *, struct dentry___89 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___89 *, struct iattr___89 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___89 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___89 *, char *, size_t);
	int (*fiemap)(struct inode___89 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___89 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___89 *, struct dentry___89 *, struct file___89 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___89 *, struct dentry___89 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___89 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___89 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___89 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___89 {
	void (*fl_copy_lock)(struct file_lock___89 *, struct file_lock___89 *);
	void (*fl_release_private)(struct file_lock___89 *);
};

struct lock_manager_operations___89;

struct file_lock___89 {
	struct file_lock___89 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___89 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___89 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___89 *fl_ops;
	const struct lock_manager_operations___89 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___89 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___89 *);
	int (*lm_grant)(struct file_lock___89 *, int);
	bool (*lm_break)(struct file_lock___89 *);
	int (*lm_change)(struct file_lock___89 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___89 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___89 *);
};

struct fasync_struct___89 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___89 *fa_next;
	struct file___89 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___89 {
	struct inode___89 * (*alloc_inode)(struct super_block___89 *);
	void (*destroy_inode)(struct inode___89 *);
	void (*free_inode)(struct inode___89 *);
	void (*dirty_inode)(struct inode___89 *, int);
	int (*write_inode)(struct inode___89 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___89 *);
	void (*evict_inode)(struct inode___89 *);
	void (*put_super)(struct super_block___89 *);
	int (*sync_fs)(struct super_block___89 *, int);
	int (*freeze_super)(struct super_block___89 *);
	int (*freeze_fs)(struct super_block___89 *);
	int (*thaw_super)(struct super_block___89 *);
	int (*unfreeze_fs)(struct super_block___89 *);
	int (*statfs)(struct dentry___89 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___89 *, int *, char *);
	void (*umount_begin)(struct super_block___89 *);
	int (*show_options)(struct seq_file___84 *, struct dentry___89 *);
	int (*show_devname)(struct seq_file___84 *, struct dentry___89 *);
	int (*show_path)(struct seq_file___84 *, struct dentry___89 *);
	int (*show_stats)(struct seq_file___84 *, struct dentry___89 *);
	ssize_t (*quota_read)(struct super_block___89 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___89 *, int, const char *, size_t, loff_t);
	struct dquot___89 ** (*get_dquots)(struct inode___89 *);
	long int (*nr_cached_objects)(struct super_block___89 *, struct shrink_control___38 *);
	long int (*free_cached_objects)(struct super_block___89 *, struct shrink_control___38 *);
	struct file___89 * (*real_loop)(struct file___89 *);
};

typedef void (*poll_queue_proc___64)(struct file___89 *, wait_queue_head_t *, struct poll_table_struct___64 *);

struct poll_table_struct___64 {
	poll_queue_proc___64 _qproc;
	__poll_t _key;
};

struct seq_operations___84;

struct seq_file___84 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___84 *op;
	int poll_event;
	const struct file___89 *file;
	void *private;
};

struct kernfs_root___89;

struct kernfs_elem_dir___89 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___89 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___89;

struct kernfs_root___89 {
	struct kernfs_node___89 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___89 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___89 {
	struct kernfs_node___89 *target_kn;
};

struct kernfs_ops___89;

struct kernfs_elem_attr___89 {
	const struct kernfs_ops___89 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___89 *notify_next;
};

struct kernfs_node___89 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___89 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___89 dir;
		struct kernfs_elem_symlink___89 symlink;
		struct kernfs_elem_attr___89 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___89;

struct kernfs_ops___89 {
	int (*open)(struct kernfs_open_file___89 *);
	void (*release)(struct kernfs_open_file___89 *);
	int (*seq_show)(struct seq_file___84 *, void *);
	void * (*seq_start)(struct seq_file___84 *, loff_t *);
	void * (*seq_next)(struct seq_file___84 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___84 *, void *);
	ssize_t (*read)(struct kernfs_open_file___89 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___89 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___89 *, struct poll_table_struct___64 *);
	int (*mmap)(struct kernfs_open_file___89 *, struct vm_area_struct___94 *);
};

struct kernfs_syscall_ops___89 {
	int (*show_options)(struct seq_file___84 *, struct kernfs_root___89 *);
	int (*mkdir)(struct kernfs_node___89 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___89 *);
	int (*rename)(struct kernfs_node___89 *, struct kernfs_node___89 *, const char *);
	int (*show_path)(struct seq_file___84 *, struct kernfs_node___89 *, struct kernfs_root___89 *);
};

struct kernfs_open_file___89 {
	struct kernfs_node___89 *kn;
	struct file___89 *file;
	struct seq_file___84 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___88 *vm_ops;
};

struct bin_attribute___89;

struct attribute_group___89 {
	const char *name;
	umode_t (*is_visible)(struct kobject___89 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___89 *, struct bin_attribute___89 *, int);
	struct attribute **attrs;
	struct bin_attribute___89 **bin_attrs;
};

struct bin_attribute___89 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___89 * (*f_mapping)();
	ssize_t (*read)(struct file___89 *, struct kobject___89 *, struct bin_attribute___89 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___89 *, struct kobject___89 *, struct bin_attribute___89 *, char *, loff_t, size_t);
	int (*mmap)(struct file___89 *, struct kobject___89 *, struct bin_attribute___89 *, struct vm_area_struct___94 *);
};

struct sysfs_ops___89 {
	ssize_t (*show)(struct kobject___89 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___89 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___89;

struct kset___89 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___89 kobj;
	const struct kset_uevent_ops___89 *uevent_ops;
};

struct kobj_type___89 {
	void (*release)(struct kobject___89 *);
	const struct sysfs_ops___89 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___89 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___89 *);
	const void * (*namespace)(struct kobject___89 *);
	void (*get_ownership)(struct kobject___89 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___89 {
	int (* const filter)(struct kset___89 *, struct kobject___89 *);
	const char * (* const name)(struct kset___89 *, struct kobject___89 *);
	int (* const uevent)(struct kset___89 *, struct kobject___89 *, struct kobj_uevent_env *);
};

struct wakeup_source___75;

struct device___75;

struct dev_pm_info___75 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___75 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___75 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___75;

struct bus_type___75;

struct device_driver___75;

struct dev_pm_domain___75;

struct fwnode_handle___75;

struct class___75;

struct device___75 {
	struct kobject___89 kobj;
	struct device___75 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___75 *type;
	struct bus_type___75 *bus;
	struct device_driver___75 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___75 power;
	struct dev_pm_domain___75 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___75 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___75 *class;
	const struct attribute_group___89 **groups;
	void (*release)(struct device___75 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___75 {
	int (*prepare)(struct device___75 *);
	void (*complete)(struct device___75 *);
	int (*suspend)(struct device___75 *);
	int (*resume)(struct device___75 *);
	int (*freeze)(struct device___75 *);
	int (*thaw)(struct device___75 *);
	int (*poweroff)(struct device___75 *);
	int (*restore)(struct device___75 *);
	int (*suspend_late)(struct device___75 *);
	int (*resume_early)(struct device___75 *);
	int (*freeze_late)(struct device___75 *);
	int (*thaw_early)(struct device___75 *);
	int (*poweroff_late)(struct device___75 *);
	int (*restore_early)(struct device___75 *);
	int (*suspend_noirq)(struct device___75 *);
	int (*resume_noirq)(struct device___75 *);
	int (*freeze_noirq)(struct device___75 *);
	int (*thaw_noirq)(struct device___75 *);
	int (*poweroff_noirq)(struct device___75 *);
	int (*restore_noirq)(struct device___75 *);
	int (*runtime_suspend)(struct device___75 *);
	int (*runtime_resume)(struct device___75 *);
	int (*runtime_idle)(struct device___75 *);
};

struct wakeup_source___75 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___75 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___75 {
	struct dev_pm_ops___75 ops;
	int (*start)(struct device___75 *);
	void (*detach)(struct device___75 *, bool);
	int (*activate)(struct device___75 *);
	void (*sync)(struct device___75 *);
	void (*dismiss)(struct device___75 *);
};

struct bus_type___75 {
	const char *name;
	const char *dev_name;
	struct device___75 *dev_root;
	const struct attribute_group___89 **bus_groups;
	const struct attribute_group___89 **dev_groups;
	const struct attribute_group___89 **drv_groups;
	int (*match)(struct device___75 *, struct device_driver___75 *);
	int (*uevent)(struct device___75 *, struct kobj_uevent_env *);
	int (*probe)(struct device___75 *);
	void (*sync_state)(struct device___75 *);
	void (*remove)(struct device___75 *);
	void (*shutdown)(struct device___75 *);
	int (*online)(struct device___75 *);
	int (*offline)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	int (*num_vf)(struct device___75 *);
	int (*dma_configure)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___75 {
	const char *name;
	struct bus_type___75 *bus;
	struct module___87 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___75 *);
	void (*sync_state)(struct device___75 *);
	int (*remove)(struct device___75 *);
	void (*shutdown)(struct device___75 *);
	int (*suspend)(struct device___75 *, pm_message_t);
	int (*resume)(struct device___75 *);
	const struct attribute_group___89 **groups;
	const struct attribute_group___89 **dev_groups;
	const struct dev_pm_ops___75 *pm;
	void (*coredump)(struct device___75 *);
	struct driver_private *p;
};

struct device_type___75 {
	const char *name;
	const struct attribute_group___89 **groups;
	int (*uevent)(struct device___75 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___75 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___75 *);
	const struct dev_pm_ops___75 *pm;
};

struct class___75 {
	const char *name;
	struct module___87 *owner;
	const struct attribute_group___89 **class_groups;
	const struct attribute_group___89 **dev_groups;
	struct kobject___89 *dev_kobj;
	int (*dev_uevent)(struct device___75 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___75 *, umode_t *);
	void (*class_release)(struct class___75 *);
	void (*dev_release)(struct device___75 *);
	int (*shutdown_pre)(struct device___75 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___75 *);
	void (*get_ownership)(struct device___75 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___75 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___75;

struct fwnode_handle___75 {
	struct fwnode_handle___75 *secondary;
	const struct fwnode_operations___75 *ops;
	struct device___75 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___88 {
	void (*page_free)(struct page___94 *);
	void (*kill)(struct dev_pagemap___88 *);
	void (*cleanup)(struct dev_pagemap___88 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___88 *);
};

struct seq_operations___84 {
	void * (*start)(struct seq_file___84 *, loff_t *);
	void (*stop)(struct seq_file___84 *, void *);
	void * (*next)(struct seq_file___84 *, void *, loff_t *);
	int (*show)(struct seq_file___84 *, void *);
};

struct fwnode_reference_args___75;

struct fwnode_endpoint___75;

struct fwnode_operations___75 {
	struct fwnode_handle___75 * (*get)(struct fwnode_handle___75 *);
	void (*put)(struct fwnode_handle___75 *);
	bool (*device_is_available)(const struct fwnode_handle___75 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___75 *, const struct device___75 *);
	bool (*property_present)(const struct fwnode_handle___75 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___75 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___75 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___75 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*get_parent)(const struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*get_next_child_node)(const struct fwnode_handle___75 *, struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*get_named_child_node)(const struct fwnode_handle___75 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___75 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___75 *);
	struct fwnode_handle___75 * (*graph_get_next_endpoint)(const struct fwnode_handle___75 *, struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*graph_get_remote_endpoint)(const struct fwnode_handle___75 *);
	struct fwnode_handle___75 * (*graph_get_port_parent)(struct fwnode_handle___75 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___75 *, struct fwnode_endpoint___75 *);
	int (*add_links)(struct fwnode_handle___75 *);
};

struct fwnode_endpoint___75 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___75 *local_fwnode;
};

struct fwnode_reference_args___75 {
	struct fwnode_handle___75 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___74 {
	struct ns_common___13 ns;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct css_set___74 *root_cset;
};

struct kernel_param_ops___86 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___86 *);
	int (*get)(char *, const struct kernel_param___86 *);
	void (*free)(void *);
};

struct kparam_array___86;

struct kernel_param___86 {
	const char *name;
	struct module___87 *mod;
	const struct kernel_param_ops___86 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___86 *arr;
	};
};

struct kparam_array___86 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___86 *ops;
	void *elem;
};

struct module_attribute___86 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___86 *, struct module_kobject___86 *, char *);
	ssize_t (*store)(struct module_attribute___86 *, struct module_kobject___86 *, const char *, size_t);
	void (*setup)(struct module___87 *, const char *);
	int (*test)(struct module___87 *);
	void (*free)(struct module___87 *);
};

struct trace_event_class___48;

struct trace_event_call___48 {
	struct list_head list;
	struct trace_event_class___48 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___48 *, struct perf_event___54 *);
};

struct fd___16 {
	struct file___89 *file;
	unsigned int flags;
};

struct cftype___74;

struct cgroup_subsys___74 {
	struct cgroup_subsys_state___74 * (*css_alloc)(struct cgroup_subsys_state___74 *);
	int (*css_online)(struct cgroup_subsys_state___74 *);
	void (*css_offline)(struct cgroup_subsys_state___74 *);
	void (*css_released)(struct cgroup_subsys_state___74 *);
	void (*css_free)(struct cgroup_subsys_state___74 *);
	void (*css_reset)(struct cgroup_subsys_state___74 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___74 *, int);
	int (*css_extra_stat_show)(struct seq_file___84 *, struct cgroup_subsys_state___74 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___96 *, struct css_set___74 *);
	void (*cancel_fork)(struct task_struct___96 *, struct css_set___74 *);
	void (*fork)(struct task_struct___96 *);
	void (*exit)(struct task_struct___96 *);
	void (*release)(struct task_struct___96 *);
	void (*bind)(struct cgroup_subsys_state___74 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___74 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___74 *dfl_cftypes;
	struct cftype___74 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___74 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___74 *updated_children;
	struct cgroup___74 *updated_next;
};

struct cgroup_root___74 {
	struct kernfs_root___89 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___74 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___74 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___74 *ss;
	struct list_head node;
	struct kernfs_ops___89 *kf_ops;
	int (*open)(struct kernfs_open_file___89 *);
	void (*release)(struct kernfs_open_file___89 *);
	u64 (*read_u64)(struct cgroup_subsys_state___74 *, struct cftype___74 *);
	s64 (*read_s64)(struct cgroup_subsys_state___74 *, struct cftype___74 *);
	int (*seq_show)(struct seq_file___84 *, void *);
	void * (*seq_start)(struct seq_file___84 *, loff_t *);
	void * (*seq_next)(struct seq_file___84 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___84 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___74 *, struct cftype___74 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___74 *, struct cftype___74 *, s64);
	ssize_t (*write)(struct kernfs_open_file___89 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___89 *, struct poll_table_struct___64 *);
};

struct perf_cpu_context___54;

struct perf_output_handle___54;

struct pmu___54 {
	struct list_head entry;
	struct module___87 *module;
	struct device___75 *dev;
	const struct attribute_group___89 **attr_groups;
	const struct attribute_group___89 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___54 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___54 *);
	void (*pmu_disable)(struct pmu___54 *);
	int (*event_init)(struct perf_event___54 *);
	void (*event_mapped)(struct perf_event___54 *, struct mm_struct___95 *);
	void (*event_unmapped)(struct perf_event___54 *, struct mm_struct___95 *);
	int (*add)(struct perf_event___54 *, int);
	void (*del)(struct perf_event___54 *, int);
	void (*start)(struct perf_event___54 *, int);
	void (*stop)(struct perf_event___54 *, int);
	void (*read)(struct perf_event___54 *);
	void (*start_txn)(struct pmu___54 *, unsigned int);
	int (*commit_txn)(struct pmu___54 *);
	void (*cancel_txn)(struct pmu___54 *);
	int (*event_idx)(struct perf_event___54 *);
	void (*sched_task)(struct perf_event_context___54 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___54 *, struct perf_event_context___54 *);
	void * (*setup_aux)(struct perf_event___54 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___54 *, struct perf_output_handle___54 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___54 *);
	int (*aux_output_match)(struct perf_event___54 *);
	int (*filter_match)(struct perf_event___54 *);
	int (*check_period)(struct perf_event___54 *, u64);
};

struct perf_cpu_context___54 {
	struct perf_event_context___54 ctx;
	struct perf_event_context___54 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___54 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___54 **heap;
	struct perf_event___54 *heap_default[2];
};

struct perf_output_handle___54 {
	struct perf_event___54 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___54 {
	struct cgroup_subsys_state___74 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___48 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___48 *);
	};
};

struct trace_event_class___48 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___48 *, enum trace_reg, void *);
	struct trace_event_fields___48 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___48 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___48 *);
};

struct syscall_metadata___23 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___48 *enter_event;
	struct trace_event_call___48 *exit_event;
};

struct pipe_buf_operations___36;

struct pipe_buffer___36 {
	struct page___94 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___36 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___36 {
	int (*confirm)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
	void (*release)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
	bool (*try_steal)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
	bool (*get)(struct pipe_inode_info___36 *, struct pipe_buffer___36 *);
};

struct dentry___90;

struct super_block___90;

struct module___88;

struct file_system_type___90 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___90 * (*mount)(struct file_system_type___90 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___90 *);
	struct module___88 *owner;
	struct file_system_type___90 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___90;

struct kiocb___90;

struct iov_iter___55;

struct poll_table_struct___65;

struct vm_area_struct___95;

struct inode___90;

struct file_lock___90;

struct page___95;

struct seq_file___85;

struct file_operations___90 {
	struct module___88 *owner;
	loff_t (*llseek)(struct file___90 *, loff_t, int);
	ssize_t (*read)(struct file___90 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___90 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___90 *, struct iov_iter___55 *);
	ssize_t (*write_iter)(struct kiocb___90 *, struct iov_iter___55 *);
	int (*iopoll)(struct kiocb___90 *, bool);
	int (*iterate)(struct file___90 *, struct dir_context *);
	int (*iterate_shared)(struct file___90 *, struct dir_context *);
	__poll_t (*poll)(struct file___90 *, struct poll_table_struct___65 *);
	long int (*unlocked_ioctl)(struct file___90 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___90 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___90 *, struct vm_area_struct___95 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___90 *, struct file___90 *);
	int (*flush)(struct file___90 *, fl_owner_t);
	int (*release)(struct inode___90 *, struct file___90 *);
	int (*fsync)(struct file___90 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___90 *, int);
	int (*lock)(struct file___90 *, int, struct file_lock___90 *);
	ssize_t (*sendpage)(struct file___90 *, struct page___95 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___90 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___90 *, long unsigned int);
	int (*flock)(struct file___90 *, int, struct file_lock___90 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___90 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___90 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___90 *, long int, struct file_lock___90 **, void **);
	long int (*fallocate)(struct file___90 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___85 *, struct file___90 *);
	ssize_t (*copy_file_range)(struct file___90 *, loff_t, struct file___90 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___90 *, loff_t, struct file___90 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___90 *, loff_t, loff_t, int);
};

struct vmacache___95 {
	u64 seqnum;
	struct vm_area_struct___95 *vmas[4];
};

struct page_frag___95 {
	struct page___95 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___55;

struct debug_info___55 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___55 *hbp_break[16];
	struct perf_event___55 *hbp_watch[16];
};

struct thread_struct___55 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___55 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___96;

struct pid___82;

struct nsproxy___87;

struct signal_struct___91;

struct bio_list___43;

struct backing_dev_info___42;

struct io_context___43;

struct css_set___75;

struct perf_event_context___55;

struct request_queue___43;

struct vm_struct___90;

struct task_struct___97 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___97 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___96 *mm;
	struct mm_struct___96 *active_mm;
	struct vmacache___95 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___97 *real_parent;
	struct task_struct___97 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___97 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___82 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___87 *nsproxy;
	struct signal_struct___91 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___97 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___43 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___42 *backing_dev_info;
	struct io_context___43 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___75 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___55 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___95 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___43 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___97 *oom_reaper_list;
	struct vm_struct___90 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___55 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___90;

struct kobj_type___90;

struct kernfs_node___90;

struct kobject___90 {
	const char *name;
	struct list_head entry;
	struct kobject___90 *parent;
	struct kset___90 *kset;
	struct kobj_type___90 *ktype;
	struct kernfs_node___90 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___87 {
	struct kobject___90 kobj;
	struct module___88 *mod;
	struct kobject___90 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___87 {
	struct module___88 *mod;
	struct latch_tree_node node;
};

struct module_layout___87 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___87 mtn;
};

struct module_attribute___87;

struct kernel_param___87;

struct trace_event_call___49;

struct module___88 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___87 mkobj;
	struct module_attribute___87 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___90 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___87 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___87 core_layout;
	struct module_layout___87 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___49 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___55 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___97 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___55)(struct perf_event___55 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___55;

struct fasync_struct___90;

struct pid_namespace___82;

struct perf_cgroup___55;

struct perf_event___55 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___55 *group_leader;
	struct pmu___55 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___55 hw;
	struct perf_event_context___55 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___55 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___97 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___90 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___55 *aux_event;
	void (*destroy)(struct perf_event___55 *);
	struct callback_head callback_head;
	struct pid_namespace___82 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___55 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___55 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___49 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___55 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___90;

struct dentry___90 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___90 *d_parent;
	struct qstr d_name;
	struct inode___90 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___90 *d_op;
	struct super_block___90 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___90;

struct address_space___90 {
	struct inode___90 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___90 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___90;

struct bdi_writeback___42;

struct inode___90 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___90 *i_op;
	struct super_block___90 *i_sb;
	struct address_space___90 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___42 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___90 *i_fop;
		void (*free_inode)(struct inode___90 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___90 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___36 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___90;

struct path___90;

struct dentry_operations___90 {
	int (*d_revalidate)(struct dentry___90 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___90 *, unsigned int);
	int (*d_hash)(const struct dentry___90 *, struct qstr *);
	int (*d_compare)(const struct dentry___90 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___90 *);
	int (*d_init)(struct dentry___90 *);
	void (*d_release)(struct dentry___90 *);
	void (*d_prune)(struct dentry___90 *);
	void (*d_iput)(struct dentry___90 *, struct inode___90 *);
	char * (*d_dname)(struct dentry___90 *, char *, int);
	struct vfsmount___90 * (*d_automount)(struct path___90 *);
	int (*d_manage)(const struct path___90 *, bool);
	struct dentry___90 * (*d_real)(struct dentry___90 *, const struct inode___90 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___90;

struct mem_dqinfo___90 {
	struct quota_format_type___90 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___90;

struct quota_info___90 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___90 *files[3];
	struct mem_dqinfo___90 info[3];
	const struct quota_format_ops___90 *ops[3];
};

struct rcuwait___91 {
	struct task_struct___97 *task;
};

struct percpu_rw_semaphore___91 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___91 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___90 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___91 rw_sem[3];
};

struct super_operations___90;

struct dquot_operations___90;

struct quotactl_ops___90;

struct fscrypt_operations___2;

struct block_device___44;

struct super_block___90 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___90 *s_type;
	const struct super_operations___90 *s_op;
	const struct dquot_operations___90 *dq_op;
	const struct quotactl_ops___90 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___90 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___2 *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___44 *s_bdev;
	struct backing_dev_info___42 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___90 s_dquot;
	struct sb_writers___90 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___90 *s_d_op;
	int cleancache_poolid;
	struct shrinker___38 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___90 {
	struct dentry___90 *mnt_root;
	struct super_block___90 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct path___90 {
	struct vfsmount___90 *mnt;
	struct dentry___90 *dentry;
};

struct upid___82 {
	int nr;
	struct pid_namespace___82 *ns;
};

struct pid_namespace___82 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___97 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___82 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___82 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___82 numbers[1];
};

typedef struct page___95 *pgtable_t___95;

struct dev_pagemap___89;

struct page___95 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___90 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___29 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___95 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___95 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___96 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___89 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___89;

struct vm_area_struct___95 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___95 *vm_next;
	struct vm_area_struct___95 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___96 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___89 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___90 *vm_file;
	struct file___90 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___91 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___97 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___97 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___82 *pids[4];
	struct pid___82 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___96 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___95;

struct mm_struct___96 {
	struct {
		struct vm_area_struct___95 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___90 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___95 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___97 *owner;
		struct user_namespace___13 *user_ns;
		struct file___90 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___75;

struct nsproxy___87 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___82 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___75 *cgroup_ns;
};

struct bio___43;

struct bio_list___43 {
	struct bio___43 *head;
	struct bio___43 *tail;
};

struct cgroup_subsys_state___75;

struct bdi_writeback___42 {
	struct backing_dev_info___42 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___75 *memcg_css;
	struct cgroup_subsys_state___75 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___76;

struct backing_dev_info___42 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___42 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___76 *dev;
	char dev_name[64];
	struct device___76 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___90 *debug_dir;
};

struct io_cq___43;

struct io_context___43 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___43 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___75;

struct css_set___75 {
	struct cgroup_subsys_state___75 *subsys[14];
	refcount_t refcount;
	struct css_set___75 *dom_cset;
	struct cgroup___75 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___75 *mg_src_cgrp;
	struct cgroup___75 *mg_dst_cgrp;
	struct css_set___75 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___55 {
	struct pmu___55 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___97 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___55 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___43;

struct blk_integrity___43 {
	const struct blk_integrity_profile___43 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___43 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___43 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___43;

struct elevator_queue___43;

struct blk_mq_ops___42;

struct blk_mq_hw_ctx___42;

struct gendisk___43;

struct blkcg_gq___42;

struct blk_mq_tag_set___42;

struct request_queue___43 {
	struct request___43 *last_merge;
	struct elevator_queue___43 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___42 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___42 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___43 *disk;
	struct kobject___90 kobj;
	struct kobject___90 *mq_kobj;
	struct blk_integrity___43 integrity;
	struct device___76 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___42 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___42 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___43 bio_split;
	struct dentry___90 *debugfs_dir;
	struct dentry___90 *sched_debugfs_dir;
	struct dentry___90 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___90 {
	struct vm_struct___90 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___95 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___89;

struct dev_pagemap___89 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___89 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___82 {
	rwlock_t lock;
	struct pid___82 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___90 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___90 f_path;
	struct inode___90 *f_inode;
	const struct file_operations___90 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___82 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___90 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___89;

struct vm_operations_struct___89 {
	void (*open)(struct vm_area_struct___95 *);
	void (*close)(struct vm_area_struct___95 *);
	int (*may_split)(struct vm_area_struct___95 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___95 *);
	int (*mprotect)(struct vm_area_struct___95 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___89 *);
	vm_fault_t (*huge_fault)(struct vm_fault___89 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___89 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___95 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___89 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___89 *);
	int (*access)(struct vm_area_struct___95 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___95 *);
	int (*set_policy)(struct vm_area_struct___95 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___95 *, long unsigned int);
	struct page___95 * (*find_special_page)(struct vm_area_struct___95 *, long unsigned int);
};

struct core_thread___95 {
	struct task_struct___97 *task;
	struct core_thread___95 *next;
};

struct core_state___95 {
	atomic_t nr_threads;
	struct core_thread___95 dumper;
	struct completion startup;
};

struct vm_fault___89 {
	const struct {
		struct vm_area_struct___95 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___95 *cow_page;
	struct page___95 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___95 prealloc_pte;
};

struct cgroup_subsys___75;

struct cgroup_subsys_state___75 {
	struct cgroup___75 *cgroup;
	struct cgroup_subsys___75 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___75 *parent;
};

struct cgroup_file___75 {
	struct kernfs_node___90 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___75 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___97 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___75;

struct cgroup_rstat_cpu___75;

struct cgroup___75 {
	struct cgroup_subsys_state___75 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___90 *kn;
	struct cgroup_file___75 procs_file;
	struct cgroup_file___75 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___75 *subsys[14];
	struct cgroup_root___75 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___75 *dom_cgrp;
	struct cgroup___75 *old_dom_cgrp;
	struct cgroup_rstat_cpu___75 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___75 psi;
	struct cgroup_bpf___19 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___43 {
	struct request_queue___43 *q;
	struct io_context___43 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct file_clone_range {
	__s64 src_fd;
	__u64 src_offset;
	__u64 src_length;
	__u64 dest_offset;
};

struct file_dedupe_range_info {
	__s64 dest_fd;
	__u64 dest_offset;
	__u64 bytes_deduped;
	__s32 status;
	__u32 reserved;
};

struct file_dedupe_range {
	__u64 src_offset;
	__u64 src_length;
	__u16 dest_count;
	__u16 reserved1;
	__u32 reserved2;
	struct file_dedupe_range_info info[0];
};

struct fsxattr {
	__u32 fsx_xflags;
	__u32 fsx_extsize;
	__u32 fsx_nextents;
	__u32 fsx_projid;
	__u32 fsx_cowextsize;
	unsigned char fsx_pad[8];
};

struct wait_page_queue___46;

struct kiocb___90 {
	struct file___90 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___90 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___46 *ki_waitq;
	};
};

struct iattr___90 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___90 *ia_file;
};

struct dquot___90 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___90 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___90 {
	int qf_fmt_id;
	const struct quota_format_ops___90 *qf_ops;
	struct module___88 *qf_owner;
	struct quota_format_type___90 *qf_next;
};

struct quota_format_ops___90 {
	int (*check_quota_file)(struct super_block___90 *, int);
	int (*read_file_info)(struct super_block___90 *, int);
	int (*write_file_info)(struct super_block___90 *, int);
	int (*free_file_info)(struct super_block___90 *, int);
	int (*read_dqblk)(struct dquot___90 *);
	int (*commit_dqblk)(struct dquot___90 *);
	int (*release_dqblk)(struct dquot___90 *);
	int (*get_next_id)(struct super_block___90 *, struct kqid *);
};

struct dquot_operations___90 {
	int (*write_dquot)(struct dquot___90 *);
	struct dquot___90 * (*alloc_dquot)(struct super_block___90 *, int);
	void (*destroy_dquot)(struct dquot___90 *);
	int (*acquire_dquot)(struct dquot___90 *);
	int (*release_dquot)(struct dquot___90 *);
	int (*mark_dirty)(struct dquot___90 *);
	int (*write_info)(struct super_block___90 *, int);
	qsize_t * (*get_reserved_space)(struct inode___90 *);
	int (*get_projid)(struct inode___90 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___90 *, qsize_t *);
	int (*get_next_id)(struct super_block___90 *, struct kqid *);
};

struct quotactl_ops___90 {
	int (*quota_on)(struct super_block___90 *, int, int, const struct path___90 *);
	int (*quota_off)(struct super_block___90 *, int);
	int (*quota_enable)(struct super_block___90 *, unsigned int);
	int (*quota_disable)(struct super_block___90 *, unsigned int);
	int (*quota_sync)(struct super_block___90 *, int);
	int (*set_info)(struct super_block___90 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___90 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___90 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___90 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___90 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___90 *, unsigned int);
};

struct wait_page_queue___46 {
	struct page___95 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___42;

struct readahead_control___46;

struct address_space_operations___90 {
	int (*writepage)(struct page___95 *, struct writeback_control___42 *);
	int (*readpage)(struct file___90 *, struct page___95 *);
	int (*writepages)(struct address_space___90 *, struct writeback_control___42 *);
	int (*set_page_dirty)(struct page___95 *);
	int (*readpages)(struct file___90 *, struct address_space___90 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___46 *);
	int (*write_begin)(struct file___90 *, struct address_space___90 *, loff_t, unsigned int, unsigned int, struct page___95 **, void **);
	int (*write_end)(struct file___90 *, struct address_space___90 *, loff_t, unsigned int, unsigned int, struct page___95 *, void *);
	sector_t (*bmap)(struct address_space___90 *, sector_t);
	void (*invalidatepage)(struct page___95 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___95 *, gfp_t);
	void (*freepage)(struct page___95 *);
	ssize_t (*direct_IO)(struct kiocb___90 *, struct iov_iter___55 *);
	int (*migratepage)(struct address_space___90 *, struct page___95 *, struct page___95 *, enum migrate_mode);
	bool (*isolate_page)(struct page___95 *, isolate_mode_t);
	void (*putback_page)(struct page___95 *);
	int (*launder_page)(struct page___95 *);
	int (*is_partially_uptodate)(struct page___95 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___95 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___90 *, struct page___95 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___90 *, sector_t *);
	void (*swap_deactivate)(struct file___90 *);
};

struct writeback_control___42 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___42 *wb;
	struct inode___90 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___46 {
	struct file___90 *file;
	struct address_space___90 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___53;

struct iov_iter___55 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___53 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___90 {
	struct dentry___90 * (*lookup)(struct inode___90 *, struct dentry___90 *, unsigned int);
	const char * (*get_link)(struct dentry___90 *, struct inode___90 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___90 *, int);
	struct posix_acl * (*get_acl)(struct inode___90 *, int, bool);
	int (*readlink)(struct dentry___90 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___90 *, struct dentry___90 *, umode_t, bool);
	int (*link)(struct dentry___90 *, struct inode___90 *, struct dentry___90 *);
	int (*unlink)(struct inode___90 *, struct dentry___90 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___90 *, struct dentry___90 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___90 *, struct dentry___90 *, umode_t);
	int (*rmdir)(struct inode___90 *, struct dentry___90 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___90 *, struct dentry___90 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___90 *, struct dentry___90 *, struct inode___90 *, struct dentry___90 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___90 *, struct iattr___90 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___90 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___90 *, char *, size_t);
	int (*fiemap)(struct inode___90 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___90 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___90 *, struct dentry___90 *, struct file___90 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___90 *, struct dentry___90 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___90 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___90 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___90 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___90 {
	void (*fl_copy_lock)(struct file_lock___90 *, struct file_lock___90 *);
	void (*fl_release_private)(struct file_lock___90 *);
};

struct lock_manager_operations___90;

struct file_lock___90 {
	struct file_lock___90 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___90 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___90 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___90 *fl_ops;
	const struct lock_manager_operations___90 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___90 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___90 *);
	int (*lm_grant)(struct file_lock___90 *, int);
	bool (*lm_break)(struct file_lock___90 *);
	int (*lm_change)(struct file_lock___90 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___90 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___90 *);
};

struct fasync_struct___90 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___90 *fa_next;
	struct file___90 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___90 {
	struct inode___90 * (*alloc_inode)(struct super_block___90 *);
	void (*destroy_inode)(struct inode___90 *);
	void (*free_inode)(struct inode___90 *);
	void (*dirty_inode)(struct inode___90 *, int);
	int (*write_inode)(struct inode___90 *, struct writeback_control___42 *);
	int (*drop_inode)(struct inode___90 *);
	void (*evict_inode)(struct inode___90 *);
	void (*put_super)(struct super_block___90 *);
	int (*sync_fs)(struct super_block___90 *, int);
	int (*freeze_super)(struct super_block___90 *);
	int (*freeze_fs)(struct super_block___90 *);
	int (*thaw_super)(struct super_block___90 *);
	int (*unfreeze_fs)(struct super_block___90 *);
	int (*statfs)(struct dentry___90 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___90 *, int *, char *);
	void (*umount_begin)(struct super_block___90 *);
	int (*show_options)(struct seq_file___85 *, struct dentry___90 *);
	int (*show_devname)(struct seq_file___85 *, struct dentry___90 *);
	int (*show_path)(struct seq_file___85 *, struct dentry___90 *);
	int (*show_stats)(struct seq_file___85 *, struct dentry___90 *);
	ssize_t (*quota_read)(struct super_block___90 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___90 *, int, const char *, size_t, loff_t);
	struct dquot___90 ** (*get_dquots)(struct inode___90 *);
	long int (*nr_cached_objects)(struct super_block___90 *, struct shrink_control___38 *);
	long int (*free_cached_objects)(struct super_block___90 *, struct shrink_control___38 *);
	struct file___90 * (*real_loop)(struct file___90 *);
};

struct fscrypt_operations___2 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___90 *, void *, size_t);
	int (*set_context)(struct inode___90 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___90 *);
	bool (*empty_dir)(struct inode___90 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___90 *);
	void (*get_ino_and_lblk_bits)(struct super_block___90 *, int *, int *);
	int (*get_num_devices)(struct super_block___90 *);
	void (*get_devices)(struct super_block___90 *, struct request_queue___43 **);
};

struct wakeup_source___76;

struct dev_pm_info___76 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___76 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___76 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___76;

struct bus_type___76;

struct device_driver___76;

struct dev_pm_domain___76;

struct fwnode_handle___76;

struct class___76;

struct attribute_group___90;

struct device___76 {
	struct kobject___90 kobj;
	struct device___76 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___76 *type;
	struct bus_type___76 *bus;
	struct device_driver___76 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___76 power;
	struct dev_pm_domain___76 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___76 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___76 *class;
	const struct attribute_group___90 **groups;
	void (*release)(struct device___76 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___44 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___90 *bd_inode;
	struct super_block___90 *bd_super;
	void *bd_claiming;
	struct device___76 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___90 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___43 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___90 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___65)(struct file___90 *, wait_queue_head_t *, struct poll_table_struct___65 *);

struct poll_table_struct___65 {
	poll_queue_proc___65 _qproc;
	__poll_t _key;
};

struct seq_operations___85;

struct seq_file___85 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___85 *op;
	int poll_event;
	const struct file___90 *file;
	void *private;
};

struct fiemap_extent;

struct fiemap_extent_info {
	unsigned int fi_flags;
	unsigned int fi_extents_mapped;
	unsigned int fi_extents_max;
	struct fiemap_extent *fi_extents_start;
};

struct fileattr {
	u32 flags;
	u32 fsx_xflags;
	u32 fsx_extsize;
	u32 fsx_nextents;
	u32 fsx_projid;
	u32 fsx_cowextsize;
	bool flags_valid: 1;
	bool fsx_valid: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___43(struct bio___43 *);

struct bio_vec___53 {
	struct page___95 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___43;

struct bio___43 {
	struct bio___43 *bi_next;
	struct block_device___44 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___43 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___42 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___43 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___53 *bi_io_vec;
	struct bio_set___43 *bi_pool;
	struct bio_vec___53 bi_inline_vecs[0];
};

struct kernfs_root___90;

struct kernfs_elem_dir___90 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___90 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___90;

struct kernfs_root___90 {
	struct kernfs_node___90 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___90 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___90 {
	struct kernfs_node___90 *target_kn;
};

struct kernfs_ops___90;

struct kernfs_elem_attr___90 {
	const struct kernfs_ops___90 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___90 *notify_next;
};

struct kernfs_node___90 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___90 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___90 dir;
		struct kernfs_elem_symlink___90 symlink;
		struct kernfs_elem_attr___90 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___90;

struct kernfs_ops___90 {
	int (*open)(struct kernfs_open_file___90 *);
	void (*release)(struct kernfs_open_file___90 *);
	int (*seq_show)(struct seq_file___85 *, void *);
	void * (*seq_start)(struct seq_file___85 *, loff_t *);
	void * (*seq_next)(struct seq_file___85 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___85 *, void *);
	ssize_t (*read)(struct kernfs_open_file___90 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___90 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___90 *, struct poll_table_struct___65 *);
	int (*mmap)(struct kernfs_open_file___90 *, struct vm_area_struct___95 *);
};

struct kernfs_syscall_ops___90 {
	int (*show_options)(struct seq_file___85 *, struct kernfs_root___90 *);
	int (*mkdir)(struct kernfs_node___90 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___90 *);
	int (*rename)(struct kernfs_node___90 *, struct kernfs_node___90 *, const char *);
	int (*show_path)(struct seq_file___85 *, struct kernfs_node___90 *, struct kernfs_root___90 *);
};

struct kernfs_open_file___90 {
	struct kernfs_node___90 *kn;
	struct file___90 *file;
	struct seq_file___85 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___89 *vm_ops;
};

struct bin_attribute___90;

struct attribute_group___90 {
	const char *name;
	umode_t (*is_visible)(struct kobject___90 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___90 *, struct bin_attribute___90 *, int);
	struct attribute **attrs;
	struct bin_attribute___90 **bin_attrs;
};

struct bin_attribute___90 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___90 * (*f_mapping)();
	ssize_t (*read)(struct file___90 *, struct kobject___90 *, struct bin_attribute___90 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___90 *, struct kobject___90 *, struct bin_attribute___90 *, char *, loff_t, size_t);
	int (*mmap)(struct file___90 *, struct kobject___90 *, struct bin_attribute___90 *, struct vm_area_struct___95 *);
};

struct sysfs_ops___90 {
	ssize_t (*show)(struct kobject___90 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___90 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___90;

struct kset___90 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___90 kobj;
	const struct kset_uevent_ops___90 *uevent_ops;
};

struct kobj_type___90 {
	void (*release)(struct kobject___90 *);
	const struct sysfs_ops___90 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___90 **default_groups;
	const struct kobj_ns_type_operations___12 * (*child_ns_type)(struct kobject___90 *);
	const void * (*namespace)(struct kobject___90 *);
	void (*get_ownership)(struct kobject___90 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___90 {
	int (* const filter)(struct kset___90 *, struct kobject___90 *);
	const char * (* const name)(struct kset___90 *, struct kobject___90 *);
	int (* const uevent)(struct kset___90 *, struct kobject___90 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___76 {
	int (*prepare)(struct device___76 *);
	void (*complete)(struct device___76 *);
	int (*suspend)(struct device___76 *);
	int (*resume)(struct device___76 *);
	int (*freeze)(struct device___76 *);
	int (*thaw)(struct device___76 *);
	int (*poweroff)(struct device___76 *);
	int (*restore)(struct device___76 *);
	int (*suspend_late)(struct device___76 *);
	int (*resume_early)(struct device___76 *);
	int (*freeze_late)(struct device___76 *);
	int (*thaw_early)(struct device___76 *);
	int (*poweroff_late)(struct device___76 *);
	int (*restore_early)(struct device___76 *);
	int (*suspend_noirq)(struct device___76 *);
	int (*resume_noirq)(struct device___76 *);
	int (*freeze_noirq)(struct device___76 *);
	int (*thaw_noirq)(struct device___76 *);
	int (*poweroff_noirq)(struct device___76 *);
	int (*restore_noirq)(struct device___76 *);
	int (*runtime_suspend)(struct device___76 *);
	int (*runtime_resume)(struct device___76 *);
	int (*runtime_idle)(struct device___76 *);
};

struct wakeup_source___76 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___76 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___76 {
	struct dev_pm_ops___76 ops;
	int (*start)(struct device___76 *);
	void (*detach)(struct device___76 *, bool);
	int (*activate)(struct device___76 *);
	void (*sync)(struct device___76 *);
	void (*dismiss)(struct device___76 *);
};

struct bus_type___76 {
	const char *name;
	const char *dev_name;
	struct device___76 *dev_root;
	const struct attribute_group___90 **bus_groups;
	const struct attribute_group___90 **dev_groups;
	const struct attribute_group___90 **drv_groups;
	int (*match)(struct device___76 *, struct device_driver___76 *);
	int (*uevent)(struct device___76 *, struct kobj_uevent_env *);
	int (*probe)(struct device___76 *);
	void (*sync_state)(struct device___76 *);
	void (*remove)(struct device___76 *);
	void (*shutdown)(struct device___76 *);
	int (*online)(struct device___76 *);
	int (*offline)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	int (*num_vf)(struct device___76 *);
	int (*dma_configure)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___76 {
	const char *name;
	struct bus_type___76 *bus;
	struct module___88 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___76 *);
	void (*sync_state)(struct device___76 *);
	int (*remove)(struct device___76 *);
	void (*shutdown)(struct device___76 *);
	int (*suspend)(struct device___76 *, pm_message_t);
	int (*resume)(struct device___76 *);
	const struct attribute_group___90 **groups;
	const struct attribute_group___90 **dev_groups;
	const struct dev_pm_ops___76 *pm;
	void (*coredump)(struct device___76 *);
	struct driver_private *p;
};

struct device_type___76 {
	const char *name;
	const struct attribute_group___90 **groups;
	int (*uevent)(struct device___76 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___76 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___76 *);
	const struct dev_pm_ops___76 *pm;
};

struct class___76 {
	const char *name;
	struct module___88 *owner;
	const struct attribute_group___90 **class_groups;
	const struct attribute_group___90 **dev_groups;
	struct kobject___90 *dev_kobj;
	int (*dev_uevent)(struct device___76 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___76 *, umode_t *);
	void (*class_release)(struct class___76 *);
	void (*dev_release)(struct device___76 *);
	int (*shutdown_pre)(struct device___76 *);
	const struct kobj_ns_type_operations___12 *ns_type;
	const void * (*namespace)(struct device___76 *);
	void (*get_ownership)(struct device___76 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___76 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___76;

struct fwnode_handle___76 {
	struct fwnode_handle___76 *secondary;
	const struct fwnode_operations___76 *ops;
	struct device___76 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___89 {
	void (*page_free)(struct page___95 *);
	void (*kill)(struct dev_pagemap___89 *);
	void (*cleanup)(struct dev_pagemap___89 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___89 *);
};

struct seq_operations___85 {
	void * (*start)(struct seq_file___85 *, loff_t *);
	void (*stop)(struct seq_file___85 *, void *);
	void * (*next)(struct seq_file___85 *, void *, loff_t *);
	int (*show)(struct seq_file___85 *, void *);
};

struct fwnode_reference_args___76;

struct fwnode_endpoint___76;

struct fwnode_operations___76 {
	struct fwnode_handle___76 * (*get)(struct fwnode_handle___76 *);
	void (*put)(struct fwnode_handle___76 *);
	bool (*device_is_available)(const struct fwnode_handle___76 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___76 *, const struct device___76 *);
	bool (*property_present)(const struct fwnode_handle___76 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___76 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___76 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___76 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*get_parent)(const struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*get_next_child_node)(const struct fwnode_handle___76 *, struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*get_named_child_node)(const struct fwnode_handle___76 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___76 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___76 *);
	struct fwnode_handle___76 * (*graph_get_next_endpoint)(const struct fwnode_handle___76 *, struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*graph_get_remote_endpoint)(const struct fwnode_handle___76 *);
	struct fwnode_handle___76 * (*graph_get_port_parent)(struct fwnode_handle___76 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___76 *, struct fwnode_endpoint___76 *);
	int (*add_links)(struct fwnode_handle___76 *);
};

struct fwnode_endpoint___76 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___76 *local_fwnode;
};

struct fwnode_reference_args___76 {
	struct fwnode_handle___76 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___75 {
	struct ns_common___13 ns;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct css_set___75 *root_cset;
};

struct kernel_param_ops___87 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___87 *);
	int (*get)(char *, const struct kernel_param___87 *);
	void (*free)(void *);
};

struct kparam_array___87;

struct kernel_param___87 {
	const char *name;
	struct module___88 *mod;
	const struct kernel_param_ops___87 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___87 *arr;
	};
};

struct kparam_array___87 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___87 *ops;
	void *elem;
};

struct module_attribute___87 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___87 *, struct module_kobject___87 *, char *);
	ssize_t (*store)(struct module_attribute___87 *, struct module_kobject___87 *, const char *, size_t);
	void (*setup)(struct module___88 *, const char *);
	int (*test)(struct module___88 *);
	void (*free)(struct module___88 *);
};

struct trace_event_class___49;

struct trace_event_call___49 {
	struct list_head list;
	struct trace_event_class___49 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___19 *prog_array;
	int (*perf_perm)(struct trace_event_call___49 *, struct perf_event___55 *);
};

struct fd___17 {
	struct file___90 *file;
	unsigned int flags;
};

struct cftype___75;

struct cgroup_subsys___75 {
	struct cgroup_subsys_state___75 * (*css_alloc)(struct cgroup_subsys_state___75 *);
	int (*css_online)(struct cgroup_subsys_state___75 *);
	void (*css_offline)(struct cgroup_subsys_state___75 *);
	void (*css_released)(struct cgroup_subsys_state___75 *);
	void (*css_free)(struct cgroup_subsys_state___75 *);
	void (*css_reset)(struct cgroup_subsys_state___75 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___75 *, int);
	int (*css_extra_stat_show)(struct seq_file___85 *, struct cgroup_subsys_state___75 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___97 *, struct css_set___75 *);
	void (*cancel_fork)(struct task_struct___97 *, struct css_set___75 *);
	void (*fork)(struct task_struct___97 *);
	void (*exit)(struct task_struct___97 *);
	void (*release)(struct task_struct___97 *);
	void (*bind)(struct cgroup_subsys_state___75 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___75 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___75 *dfl_cftypes;
	struct cftype___75 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___75 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___75 *updated_children;
	struct cgroup___75 *updated_next;
};

struct cgroup_root___75 {
	struct kernfs_root___90 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___75 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___75 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___75 *ss;
	struct list_head node;
	struct kernfs_ops___90 *kf_ops;
	int (*open)(struct kernfs_open_file___90 *);
	void (*release)(struct kernfs_open_file___90 *);
	u64 (*read_u64)(struct cgroup_subsys_state___75 *, struct cftype___75 *);
	s64 (*read_s64)(struct cgroup_subsys_state___75 *, struct cftype___75 *);
	int (*seq_show)(struct seq_file___85 *, void *);
	void * (*seq_start)(struct seq_file___85 *, loff_t *);
	void * (*seq_next)(struct seq_file___85 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___85 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___75 *, struct cftype___75 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___75 *, struct cftype___75 *, s64);
	ssize_t (*write)(struct kernfs_open_file___90 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___90 *, struct poll_table_struct___65 *);
};

struct perf_cpu_context___55;

struct perf_output_handle___55;

struct pmu___55 {
	struct list_head entry;
	struct module___88 *module;
	struct device___76 *dev;
	const struct attribute_group___90 **attr_groups;
	const struct attribute_group___90 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___55 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___55 *);
	void (*pmu_disable)(struct pmu___55 *);
	int (*event_init)(struct perf_event___55 *);
	void (*event_mapped)(struct perf_event___55 *, struct mm_struct___96 *);
	void (*event_unmapped)(struct perf_event___55 *, struct mm_struct___96 *);
	int (*add)(struct perf_event___55 *, int);
	void (*del)(struct perf_event___55 *, int);
	void (*start)(struct perf_event___55 *, int);
	void (*stop)(struct perf_event___55 *, int);
	void (*read)(struct perf_event___55 *);
	void (*start_txn)(struct pmu___55 *, unsigned int);
	int (*commit_txn)(struct pmu___55 *);
	void (*cancel_txn)(struct pmu___55 *);
	int (*event_idx)(struct perf_event___55 *);
	void (*sched_task)(struct perf_event_context___55 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___55 *, struct perf_event_context___55 *);
	void * (*setup_aux)(struct perf_event___55 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___55 *, struct perf_output_handle___55 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___55 *);
	int (*aux_output_match)(struct perf_event___55 *);
	int (*filter_match)(struct perf_event___55 *);
	int (*check_period)(struct perf_event___55 *, u64);
};

struct perf_cpu_context___55 {
	struct perf_event_context___55 ctx;
	struct perf_event_context___55 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___55 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___55 **heap;
	struct perf_event___55 *heap_default[2];
};

struct perf_output_handle___55 {
	struct perf_event___55 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___55 {
	struct cgroup_subsys_state___75 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___49 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___49 *);
	};
};

struct trace_event_class___49 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___49 *, enum trace_reg, void *);
	struct trace_event_fields___49 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___49 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___49 *);
};

struct syscall_metadata___24 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___49 *enter_event;
	struct trace_event_call___49 *exit_event;
};

struct block_device_operations___43;

struct gendisk___43 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___44 *part0;
	const struct block_device_operations___43 *fops;
	struct request_queue___43 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___42 *bdi;
	struct kobject___90 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___90 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___43 {
	struct bio___43 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___53 *bip_vec;
	struct bio_vec___53 bip_inline_vecs[0];
};

struct blkcg___42;

struct blkg_policy_data___42;

struct blkcg_gq___42 {
	struct request_queue___43 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___42 *blkcg;
	struct blkcg_gq___42 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___42 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___43 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___43(struct request___43 *);

typedef void integrity_complete_fn___43(struct request___43 *, unsigned int);

struct blk_integrity_profile___43 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___43 *prepare_fn;
	integrity_complete_fn___43 *complete_fn;
	const char *name;
};

struct block_device_operations___43 {
	blk_qc_t (*submit_bio)(struct bio___43 *);
	int (*open)(struct block_device___44 *, fmode_t);
	void (*release)(struct gendisk___43 *, fmode_t);
	int (*rw_page)(struct block_device___44 *, sector_t, struct page___95 *, unsigned int);
	int (*ioctl)(struct block_device___44 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___44 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___43 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___43 *);
	int (*getgeo)(struct block_device___44 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___44 *, bool);
	void (*swap_slot_free_notify)(struct block_device___44 *, long unsigned int);
	int (*report_zones)(struct gendisk___43 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___43 *, umode_t *);
	struct module___88 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___43 *, sector_t *);
};

typedef void rq_end_io_fn___43(struct request___43 *, blk_status_t);

struct request___43 {
	struct request_queue___43 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___42 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___43 *bio;
	struct bio___43 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___53 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___43 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___43 *saved_end_io;
		} flush;
	};
	struct gendisk___43 *rq_disk;
	struct block_device___44 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___43 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___42 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___43 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___90 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___90 *debugfs_dir;
	struct dentry___90 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___43;

struct elevator_mq_ops___43 {
	int (*init_sched)(struct request_queue___43 *, struct elevator_type___43 *);
	void (*exit_sched)(struct elevator_queue___43 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___42 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___42 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___42 *);
	bool (*allow_merge)(struct request_queue___43 *, struct request___43 *, struct bio___43 *);
	bool (*bio_merge)(struct request_queue___43 *, struct bio___43 *, unsigned int);
	int (*request_merge)(struct request_queue___43 *, struct request___43 **, struct bio___43 *);
	void (*request_merged)(struct request_queue___43 *, struct request___43 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___43 *, struct request___43 *, struct request___43 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___43 *);
	void (*finish_request)(struct request___43 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___42 *, struct list_head *, bool);
	struct request___43 * (*dispatch_request)(struct blk_mq_hw_ctx___42 *);
	bool (*has_work)(struct blk_mq_hw_ctx___42 *);
	void (*completed_request)(struct request___43 *, u64);
	void (*requeue_request)(struct request___43 *);
	struct request___43 * (*former_request)(struct request_queue___43 *, struct request___43 *);
	struct request___43 * (*next_request)(struct request_queue___43 *, struct request___43 *);
	void (*init_icq)(struct io_cq___43 *);
	void (*exit_icq)(struct io_cq___43 *);
};

struct elv_fs_entry___43;

struct elevator_type___43 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___43 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___43 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___88 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___43 {
	struct elevator_type___43 *type;
	void *elevator_data;
	struct kobject___90 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___43 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___43 *, char *);
	ssize_t (*store)(struct elevator_queue___43 *, const char *, size_t);
};

struct blk_mq_queue_data___42;

struct blk_mq_ops___42 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___42 *, const struct blk_mq_queue_data___42 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___42 *);
	int (*get_budget)(struct request_queue___43 *);
	void (*put_budget)(struct request_queue___43 *, int);
	void (*set_rq_budget_token)(struct request___43 *, int);
	int (*get_rq_budget_token)(struct request___43 *);
	enum blk_eh_timer_return (*timeout)(struct request___43 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___42 *);
	void (*complete)(struct request___43 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___42 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___42 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___42 *, struct request___43 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___42 *, struct request___43 *, unsigned int);
	void (*initialize_rq_fn)(struct request___43 *);
	void (*cleanup_rq)(struct request___43 *);
	bool (*busy)(struct request_queue___43 *);
	int (*map_queues)(struct blk_mq_tag_set___42 *);
	void (*show_rq)(struct seq_file___85 *, struct request___43 *);
};

struct blk_mq_tag_set___42 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___42 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___42 {
	struct request___43 *rq;
	bool last;
};

struct blkcg_policy_data___42;

struct blkcg___42 {
	struct cgroup_subsys_state___75 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___42 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___42 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___42 {
	struct blkcg___42 *blkcg;
	int plid;
};

struct blkg_policy_data___42 {
	struct blkcg_gq___42 *blkg;
	int plid;
};

struct space_resv {
	__s16 l_type;
	__s16 l_whence;
	__s64 l_start;
	__s64 l_len;
	__s32 l_sysid;
	__u32 l_pid;
	__s32 l_pad[4];
};

struct fiemap_extent {
	__u64 fe_logical;
	__u64 fe_physical;
	__u64 fe_length;
	__u64 fe_reserved64[2];
	__u32 fe_flags;
	__u32 fe_reserved[3];
};

struct fiemap {
	__u64 fm_start;
	__u64 fm_length;
	__u32 fm_flags;
	__u32 fm_mapped_extents;
	__u32 fm_extent_count;
	__u32 fm_reserved;
	struct fiemap_extent fm_extents[0];
};

struct linux_dirent64 {
	u64 d_ino;
	s64 d_off;
	short unsigned int d_reclen;
	unsigned char d_type;
	char d_name[0];
};

struct linux_dirent {
	long unsigned int d_ino;
	long unsigned int d_off;
	short unsigned int d_reclen;
	char d_name[1];
};

struct getdents_callback {
	struct dir_context ctx;
	struct linux_dirent *current_dir;
	int prev_reclen;
	int count;
	int error;
};

struct getdents_callback64 {
	struct dir_context ctx;
	struct linux_dirent64 *current_dir;
	int prev_reclen;
	int count;
	int error;
};

struct compat_old_linux_dirent {
	compat_ulong_t d_ino;
	compat_ulong_t d_offset;
	short unsigned int d_namlen;
	char d_name[1];
};

struct compat_readdir_callback {
	struct dir_context ctx;
	struct compat_old_linux_dirent *dirent;
	int result;
};

struct compat_linux_dirent {
	compat_ulong_t d_ino;
	compat_ulong_t d_off;
	short unsigned int d_reclen;
	char d_name[1];
};

struct compat_getdents_callback {
	struct dir_context ctx;
	struct compat_linux_dirent *current_dir;
	int prev_reclen;
	int count;
	int error;
};

typedef struct {
	long unsigned int fds_bits[16];
} __kernel_fd_set;

typedef __kernel_fd_set fd_set;

struct dentry___91;

struct super_block___91;

struct module___89;

struct file_system_type___91 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___91 * (*mount)(struct file_system_type___91 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___91 *);
	struct module___89 *owner;
	struct file_system_type___91 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___91;

struct kiocb___91;

struct iov_iter___56;

struct poll_table_struct___66;

struct vm_area_struct___96;

struct inode___91;

struct file_lock___91;

struct page___96;

struct pipe_inode_info___37;

struct seq_file___86;

struct file_operations___91 {
	struct module___89 *owner;
	loff_t (*llseek)(struct file___91 *, loff_t, int);
	ssize_t (*read)(struct file___91 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___91 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___91 *, struct iov_iter___56 *);
	ssize_t (*write_iter)(struct kiocb___91 *, struct iov_iter___56 *);
	int (*iopoll)(struct kiocb___91 *, bool);
	int (*iterate)(struct file___91 *, struct dir_context *);
	int (*iterate_shared)(struct file___91 *, struct dir_context *);
	__poll_t (*poll)(struct file___91 *, struct poll_table_struct___66 *);
	long int (*unlocked_ioctl)(struct file___91 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___91 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___91 *, struct vm_area_struct___96 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___91 *, struct file___91 *);
	int (*flush)(struct file___91 *, fl_owner_t);
	int (*release)(struct inode___91 *, struct file___91 *);
	int (*fsync)(struct file___91 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___91 *, int);
	int (*lock)(struct file___91 *, int, struct file_lock___91 *);
	ssize_t (*sendpage)(struct file___91 *, struct page___96 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___91 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___91 *, long unsigned int);
	int (*flock)(struct file___91 *, int, struct file_lock___91 *);
	ssize_t (*splice_write)(struct pipe_inode_info___37 *, struct file___91 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___91 *, loff_t *, struct pipe_inode_info___37 *, size_t, unsigned int);
	int (*setlease)(struct file___91 *, long int, struct file_lock___91 **, void **);
	long int (*fallocate)(struct file___91 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___86 *, struct file___91 *);
	ssize_t (*copy_file_range)(struct file___91 *, loff_t, struct file___91 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___91 *, loff_t, struct file___91 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___91 *, loff_t, loff_t, int);
};

struct vmacache___96 {
	u64 seqnum;
	struct vm_area_struct___96 *vmas[4];
};

struct page_frag___96 {
	struct page___96 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___56;

struct debug_info___56 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___56 *hbp_break[16];
	struct perf_event___56 *hbp_watch[16];
};

struct thread_struct___56 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___56 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___97;

struct pid___83;

struct files_struct___10;

struct nsproxy___88;

struct signal_struct___92;

struct bio_list___44;

struct backing_dev_info___43;

struct io_context___44;

struct css_set___76;

struct perf_event_context___56;

struct mem_cgroup___39;

struct request_queue___44;

struct vm_struct___91;

struct task_struct___98 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___98 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___97 *mm;
	struct mm_struct___97 *active_mm;
	struct vmacache___96 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___98 *real_parent;
	struct task_struct___98 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___98 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___83 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___10 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___88 *nsproxy;
	struct signal_struct___92 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___98 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___44 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___43 *backing_dev_info;
	struct io_context___44 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___76 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___56 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___37 *splice_pipe;
	struct page_frag___96 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___39 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___39 *active_memcg;
	struct request_queue___44 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___98 *oom_reaper_list;
	struct vm_struct___91 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___91;

struct kobj_type___91;

struct kernfs_node___91;

struct kobject___91 {
	const char *name;
	struct list_head entry;
	struct kobject___91 *parent;
	struct kset___91 *kset;
	struct kobj_type___91 *ktype;
	struct kernfs_node___91 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___88 {
	struct kobject___91 kobj;
	struct module___89 *mod;
	struct kobject___91 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___88 {
	struct module___89 *mod;
	struct latch_tree_node node;
};

struct module_layout___88 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___88 mtn;
};

struct module_attribute___88;

struct kernel_param___88;

struct trace_event_call___50;

struct module___89 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___88 mkobj;
	struct module_attribute___88 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___91 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___88 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___88 core_layout;
	struct module_layout___88 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___50 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___56 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___98 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___56)(struct perf_event___56 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___56;

struct fasync_struct___91;

struct pid_namespace___83;

struct bpf_prog___20;

struct perf_cgroup___56;

struct perf_event___56 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___56 *group_leader;
	struct pmu___56 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___56 hw;
	struct perf_event_context___56 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___56 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___98 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___91 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___56 *aux_event;
	void (*destroy)(struct perf_event___56 *);
	struct callback_head callback_head;
	struct pid_namespace___83 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___56 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___56 orig_overflow_handler;
	struct bpf_prog___20 *prog;
	u64 bpf_cookie;
	struct trace_event_call___50 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___56 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___83 {
	int nr;
	struct pid_namespace___83 *ns;
};

struct pid_namespace___83 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___98 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___83 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___83 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___83 numbers[1];
};

typedef struct page___96 *pgtable_t___96;

struct address_space___91;

struct page_pool___30;

struct dev_pagemap___90;

struct page___96 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___91 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___96 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___96 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___97 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___90 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___90;

struct vm_area_struct___96 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___96 *vm_next;
	struct vm_area_struct___96 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___97 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___90 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___91 *vm_file;
	struct file___91 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___92 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___98 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___98 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___83 *pids[4];
	struct pid___83 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___97 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___96;

struct mm_struct___97 {
	struct {
		struct vm_area_struct___96 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___91 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___96 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___98 *owner;
		struct user_namespace___13 *user_ns;
		struct file___91 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___10 {
	unsigned int max_fds;
	struct file___91 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___10 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___10 *fdt;
	struct fdtable___10 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___91 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___23;

struct cgroup_namespace___76;

struct nsproxy___88 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___83 *pid_ns_for_children;
	struct net___23 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___76 *cgroup_ns;
};

struct bio___44;

struct bio_list___44 {
	struct bio___44 *head;
	struct bio___44 *tail;
};

struct cgroup_subsys_state___76;

struct bdi_writeback___43 {
	struct backing_dev_info___43 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___76 *memcg_css;
	struct cgroup_subsys_state___76 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___77;

struct backing_dev_info___43 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___43 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___77 *dev;
	char dev_name[64];
	struct device___77 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___91 *debug_dir;
};

struct io_cq___44;

struct io_context___44 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___44 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___76;

struct css_set___76 {
	struct cgroup_subsys_state___76 *subsys[14];
	refcount_t refcount;
	struct css_set___76 *dom_cset;
	struct cgroup___76 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___76 *mg_src_cgrp;
	struct cgroup___76 *mg_dst_cgrp;
	struct css_set___76 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___56 {
	struct pmu___56 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___98 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___56 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___37;

struct pipe_inode_info___37 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___96 *tmp_page;
	struct fasync_struct___91 *fasync_readers;
	struct fasync_struct___91 *fasync_writers;
	struct pipe_buffer___37 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___76;

struct cgroup_subsys_state___76 {
	struct cgroup___76 *cgroup;
	struct cgroup_subsys___76 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___76 *parent;
};

struct cgroup_file___76 {
	struct kernfs_node___91 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___39;

struct mem_cgroup_per_node___39;

struct mem_cgroup___39 {
	struct cgroup_subsys_state___76 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___76 events_file;
	struct cgroup_file___76 events_local_file;
	struct cgroup_file___76 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___39 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___98 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___39 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___44;

struct blk_integrity___44 {
	const struct blk_integrity_profile___44 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___44 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___44 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___44;

struct elevator_queue___44;

struct blk_mq_ops___43;

struct blk_mq_hw_ctx___43;

struct gendisk___44;

struct blkcg_gq___43;

struct blk_mq_tag_set___43;

struct request_queue___44 {
	struct request___44 *last_merge;
	struct elevator_queue___44 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___43 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___43 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___44 *disk;
	struct kobject___91 kobj;
	struct kobject___91 *mq_kobj;
	struct blk_integrity___44 integrity;
	struct device___77 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___43 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___43 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___44 bio_split;
	struct dentry___91 *debugfs_dir;
	struct dentry___91 *sched_debugfs_dir;
	struct dentry___91 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___91 {
	struct vm_struct___91 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___96 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___91;

struct address_space___91 {
	struct inode___91 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___91 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___30 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___77 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___30 {
	u32 count;
	struct page___96 *cache[128];
};

struct page_pool___30 {
	struct page_pool_params___30 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___96 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___30 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___90;

struct dev_pagemap___90 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___90 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___91;

struct path___91 {
	struct vfsmount___91 *mnt;
	struct dentry___91 *dentry;
};

struct fown_struct___83 {
	rwlock_t lock;
	struct pid___83 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___91 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___91 f_path;
	struct inode___91 *f_inode;
	const struct file_operations___91 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___83 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___91 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___90;

struct vm_operations_struct___90 {
	void (*open)(struct vm_area_struct___96 *);
	void (*close)(struct vm_area_struct___96 *);
	int (*may_split)(struct vm_area_struct___96 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___96 *);
	int (*mprotect)(struct vm_area_struct___96 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___90 *);
	vm_fault_t (*huge_fault)(struct vm_fault___90 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___90 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___96 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___90 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___90 *);
	int (*access)(struct vm_area_struct___96 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___96 *);
	int (*set_policy)(struct vm_area_struct___96 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___96 *, long unsigned int);
	struct page___96 * (*find_special_page)(struct vm_area_struct___96 *, long unsigned int);
};

struct core_thread___96 {
	struct task_struct___98 *task;
	struct core_thread___96 *next;
};

struct core_state___96 {
	atomic_t nr_threads;
	struct core_thread___96 dumper;
	struct completion startup;
};

struct vm_fault___90 {
	const struct {
		struct vm_area_struct___96 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___96 *cow_page;
	struct page___96 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___96 prealloc_pte;
};

struct psi_group___76 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___98 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___20;

struct cgroup_bpf___20 {
	struct bpf_prog_array___20 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___20 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___76;

struct cgroup_rstat_cpu___76;

struct cgroup___76 {
	struct cgroup_subsys_state___76 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___91 *kn;
	struct cgroup_file___76 procs_file;
	struct cgroup_file___76 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___76 *subsys[14];
	struct cgroup_root___76 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___76 *dom_cgrp;
	struct cgroup___76 *old_dom_cgrp;
	struct cgroup_rstat_cpu___76 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___76 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___45;

struct lruvec___45 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___45 *pgdat;
};

struct zone___45 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___45 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___45 {
	struct zone___45 *zone;
	int zone_idx;
};

struct zonelist___45 {
	struct zoneref___45 _zonerefs[321];
};

struct pglist_data___45 {
	struct zone___45 node_zones[5];
	struct zonelist___45 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___98 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___98 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___45 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___91;

struct dentry___91 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___91 *d_parent;
	struct qstr d_name;
	struct inode___91 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___91 *d_op;
	struct super_block___91 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___91;

struct inode___91 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___91 *i_op;
	struct super_block___91 *i_sb;
	struct address_space___91 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___43 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___91 *i_fop;
		void (*free_inode)(struct inode___91 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___91 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___91 {
	int (*d_revalidate)(struct dentry___91 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___91 *, unsigned int);
	int (*d_hash)(const struct dentry___91 *, struct qstr *);
	int (*d_compare)(const struct dentry___91 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___91 *);
	int (*d_init)(struct dentry___91 *);
	void (*d_release)(struct dentry___91 *);
	void (*d_prune)(struct dentry___91 *);
	void (*d_iput)(struct dentry___91 *, struct inode___91 *);
	char * (*d_dname)(struct dentry___91 *, char *, int);
	struct vfsmount___91 * (*d_automount)(struct path___91 *);
	int (*d_manage)(const struct path___91 *, bool);
	struct dentry___91 * (*d_real)(struct dentry___91 *, const struct inode___91 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___91;

struct mem_dqinfo___91 {
	struct quota_format_type___91 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___91;

struct quota_info___91 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___91 *files[3];
	struct mem_dqinfo___91 info[3];
	const struct quota_format_ops___91 *ops[3];
};

struct rcuwait___92 {
	struct task_struct___98 *task;
};

struct percpu_rw_semaphore___92 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___92 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___91 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___92 rw_sem[3];
};

struct shrink_control___39;

struct shrinker___39 {
	long unsigned int (*count_objects)(struct shrinker___39 *, struct shrink_control___39 *);
	long unsigned int (*scan_objects)(struct shrinker___39 *, struct shrink_control___39 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___91;

struct dquot_operations___91;

struct quotactl_ops___91;

struct block_device___45;

struct super_block___91 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___91 *s_type;
	const struct super_operations___91 *s_op;
	const struct dquot_operations___91 *dq_op;
	const struct quotactl_ops___91 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___91 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___45 *s_bdev;
	struct backing_dev_info___43 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___91 s_dquot;
	struct sb_writers___91 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___91 *s_d_op;
	int cleancache_poolid;
	struct shrinker___39 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___91 {
	struct dentry___91 *mnt_root;
	struct super_block___91 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct shrink_control___39 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___39 *memcg;
};

struct io_cq___44 {
	struct request_queue___44 *q;
	struct io_context___44 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___91 {
	struct file___91 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___91 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___46 *ki_waitq;
	};
};

struct iattr___91 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___91 *ia_file;
};

struct dquot___91 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___91 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___91 {
	int qf_fmt_id;
	const struct quota_format_ops___91 *qf_ops;
	struct module___89 *qf_owner;
	struct quota_format_type___91 *qf_next;
};

struct quota_format_ops___91 {
	int (*check_quota_file)(struct super_block___91 *, int);
	int (*read_file_info)(struct super_block___91 *, int);
	int (*write_file_info)(struct super_block___91 *, int);
	int (*free_file_info)(struct super_block___91 *, int);
	int (*read_dqblk)(struct dquot___91 *);
	int (*commit_dqblk)(struct dquot___91 *);
	int (*release_dqblk)(struct dquot___91 *);
	int (*get_next_id)(struct super_block___91 *, struct kqid *);
};

struct dquot_operations___91 {
	int (*write_dquot)(struct dquot___91 *);
	struct dquot___91 * (*alloc_dquot)(struct super_block___91 *, int);
	void (*destroy_dquot)(struct dquot___91 *);
	int (*acquire_dquot)(struct dquot___91 *);
	int (*release_dquot)(struct dquot___91 *);
	int (*mark_dirty)(struct dquot___91 *);
	int (*write_info)(struct super_block___91 *, int);
	qsize_t * (*get_reserved_space)(struct inode___91 *);
	int (*get_projid)(struct inode___91 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___91 *, qsize_t *);
	int (*get_next_id)(struct super_block___91 *, struct kqid *);
};

struct quotactl_ops___91 {
	int (*quota_on)(struct super_block___91 *, int, int, const struct path___91 *);
	int (*quota_off)(struct super_block___91 *, int);
	int (*quota_enable)(struct super_block___91 *, unsigned int);
	int (*quota_disable)(struct super_block___91 *, unsigned int);
	int (*quota_sync)(struct super_block___91 *, int);
	int (*set_info)(struct super_block___91 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___91 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___91 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___91 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___91 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___91 *, unsigned int);
};

struct writeback_control___43;

struct address_space_operations___91 {
	int (*writepage)(struct page___96 *, struct writeback_control___43 *);
	int (*readpage)(struct file___91 *, struct page___96 *);
	int (*writepages)(struct address_space___91 *, struct writeback_control___43 *);
	int (*set_page_dirty)(struct page___96 *);
	int (*readpages)(struct file___91 *, struct address_space___91 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___91 *, struct address_space___91 *, loff_t, unsigned int, unsigned int, struct page___96 **, void **);
	int (*write_end)(struct file___91 *, struct address_space___91 *, loff_t, unsigned int, unsigned int, struct page___96 *, void *);
	sector_t (*bmap)(struct address_space___91 *, sector_t);
	void (*invalidatepage)(struct page___96 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___96 *, gfp_t);
	void (*freepage)(struct page___96 *);
	ssize_t (*direct_IO)(struct kiocb___91 *, struct iov_iter___56 *);
	int (*migratepage)(struct address_space___91 *, struct page___96 *, struct page___96 *, enum migrate_mode);
	bool (*isolate_page)(struct page___96 *, isolate_mode_t);
	void (*putback_page)(struct page___96 *);
	int (*launder_page)(struct page___96 *);
	int (*is_partially_uptodate)(struct page___96 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___96 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___91 *, struct page___96 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___91 *, sector_t *);
	void (*swap_deactivate)(struct file___91 *);
};

struct writeback_control___43 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___43 *wb;
	struct inode___91 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___54;

struct iov_iter___56 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___54 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___37 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___91 {
	struct dentry___91 * (*lookup)(struct inode___91 *, struct dentry___91 *, unsigned int);
	const char * (*get_link)(struct dentry___91 *, struct inode___91 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___91 *, int);
	struct posix_acl * (*get_acl)(struct inode___91 *, int, bool);
	int (*readlink)(struct dentry___91 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___91 *, struct dentry___91 *, umode_t, bool);
	int (*link)(struct dentry___91 *, struct inode___91 *, struct dentry___91 *);
	int (*unlink)(struct inode___91 *, struct dentry___91 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___91 *, struct dentry___91 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___91 *, struct dentry___91 *, umode_t);
	int (*rmdir)(struct inode___91 *, struct dentry___91 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___91 *, struct dentry___91 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___91 *, struct dentry___91 *, struct inode___91 *, struct dentry___91 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___91 *, struct iattr___91 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___91 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___91 *, char *, size_t);
	int (*fiemap)(struct inode___91 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___91 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___91 *, struct dentry___91 *, struct file___91 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___91 *, struct dentry___91 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___91 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___91 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___91 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___91 {
	void (*fl_copy_lock)(struct file_lock___91 *, struct file_lock___91 *);
	void (*fl_release_private)(struct file_lock___91 *);
};

struct lock_manager_operations___91;

struct file_lock___91 {
	struct file_lock___91 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___91 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___91 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___91 *fl_ops;
	const struct lock_manager_operations___91 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___91 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___91 *);
	int (*lm_grant)(struct file_lock___91 *, int);
	bool (*lm_break)(struct file_lock___91 *);
	int (*lm_change)(struct file_lock___91 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___91 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___91 *);
};

struct fasync_struct___91 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___91 *fa_next;
	struct file___91 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___91 {
	struct inode___91 * (*alloc_inode)(struct super_block___91 *);
	void (*destroy_inode)(struct inode___91 *);
	void (*free_inode)(struct inode___91 *);
	void (*dirty_inode)(struct inode___91 *, int);
	int (*write_inode)(struct inode___91 *, struct writeback_control___43 *);
	int (*drop_inode)(struct inode___91 *);
	void (*evict_inode)(struct inode___91 *);
	void (*put_super)(struct super_block___91 *);
	int (*sync_fs)(struct super_block___91 *, int);
	int (*freeze_super)(struct super_block___91 *);
	int (*freeze_fs)(struct super_block___91 *);
	int (*thaw_super)(struct super_block___91 *);
	int (*unfreeze_fs)(struct super_block___91 *);
	int (*statfs)(struct dentry___91 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___91 *, int *, char *);
	void (*umount_begin)(struct super_block___91 *);
	int (*show_options)(struct seq_file___86 *, struct dentry___91 *);
	int (*show_devname)(struct seq_file___86 *, struct dentry___91 *);
	int (*show_path)(struct seq_file___86 *, struct dentry___91 *);
	int (*show_stats)(struct seq_file___86 *, struct dentry___91 *);
	ssize_t (*quota_read)(struct super_block___91 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___91 *, int, const char *, size_t, loff_t);
	struct dquot___91 ** (*get_dquots)(struct inode___91 *);
	long int (*nr_cached_objects)(struct super_block___91 *, struct shrink_control___39 *);
	long int (*free_cached_objects)(struct super_block___91 *, struct shrink_control___39 *);
	struct file___91 * (*real_loop)(struct file___91 *);
};

struct wakeup_source___77;

struct dev_pm_info___77 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___77 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___77 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___77;

struct bus_type___77;

struct device_driver___77;

struct dev_pm_domain___77;

struct fwnode_handle___77;

struct class___77;

struct attribute_group___91;

struct device___77 {
	struct kobject___91 kobj;
	struct device___77 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___77 *type;
	struct bus_type___77 *bus;
	struct device_driver___77 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___77 power;
	struct dev_pm_domain___77 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___77 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___77 *class;
	const struct attribute_group___91 **groups;
	void (*release)(struct device___77 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___45 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___91 *bd_inode;
	struct super_block___91 *bd_super;
	void *bd_claiming;
	struct device___77 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___91 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___44 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___91 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___66)(struct file___91 *, wait_queue_head_t *, struct poll_table_struct___66 *);

struct poll_table_struct___66 {
	poll_queue_proc___66 _qproc;
	__poll_t _key;
};

struct seq_operations___86;

struct seq_file___86 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___86 *op;
	int poll_event;
	const struct file___91 *file;
	void *private;
};

typedef void bio_end_io_t___44(struct bio___44 *);

struct bio_vec___54 {
	struct page___96 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___44;

struct bio___44 {
	struct bio___44 *bi_next;
	struct block_device___45 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___44 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___43 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___44 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___54 *bi_io_vec;
	struct bio_set___44 *bi_pool;
	struct bio_vec___54 bi_inline_vecs[0];
};

struct kernfs_root___91;

struct kernfs_elem_dir___91 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___91 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___91;

struct kernfs_root___91 {
	struct kernfs_node___91 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___91 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___91 {
	struct kernfs_node___91 *target_kn;
};

struct kernfs_ops___91;

struct kernfs_elem_attr___91 {
	const struct kernfs_ops___91 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___91 *notify_next;
};

struct kernfs_node___91 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___91 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___91 dir;
		struct kernfs_elem_symlink___91 symlink;
		struct kernfs_elem_attr___91 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___91;

struct kernfs_ops___91 {
	int (*open)(struct kernfs_open_file___91 *);
	void (*release)(struct kernfs_open_file___91 *);
	int (*seq_show)(struct seq_file___86 *, void *);
	void * (*seq_start)(struct seq_file___86 *, loff_t *);
	void * (*seq_next)(struct seq_file___86 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___86 *, void *);
	ssize_t (*read)(struct kernfs_open_file___91 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___91 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___91 *, struct poll_table_struct___66 *);
	int (*mmap)(struct kernfs_open_file___91 *, struct vm_area_struct___96 *);
};

struct kernfs_syscall_ops___91 {
	int (*show_options)(struct seq_file___86 *, struct kernfs_root___91 *);
	int (*mkdir)(struct kernfs_node___91 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___91 *);
	int (*rename)(struct kernfs_node___91 *, struct kernfs_node___91 *, const char *);
	int (*show_path)(struct seq_file___86 *, struct kernfs_node___91 *, struct kernfs_root___91 *);
};

struct kernfs_open_file___91 {
	struct kernfs_node___91 *kn;
	struct file___91 *file;
	struct seq_file___86 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___90 *vm_ops;
};

struct sock___14;

struct kobj_ns_type_operations___13 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___14 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___23 *net;
} possible_net_t___20;

struct proto___13;

struct sock_common___13 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___13 *skc_prot;
	possible_net_t___20 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___14 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___22;

struct sk_buff_head___20 {
	struct sk_buff___22 *next;
	struct sk_buff___22 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___13 {
	struct cgroup___76 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___13;

struct socket_wq___13;

struct dst_entry___13;

struct socket___13;

struct sock___14 {
	struct sock_common___13 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___20 sk_error_queue;
	struct sk_buff___22 *sk_rx_skb_cache;
	struct sk_buff_head___20 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___22 *head;
		struct sk_buff___22 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___13 *sk_filter;
	union {
		struct socket_wq___13 *sk_wq;
		struct socket_wq___13 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___13 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___13 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___22 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___22 *sk_tx_skb_cache;
	struct sk_buff_head___20 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___96 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___13 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___83 *sk_peer_pid;
	const struct cred___12 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___13 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___13 sk_cgrp_data;
	struct mem_cgroup___39 *sk_memcg;
	void (*sk_state_change)(struct sock___14 *);
	void (*sk_data_ready)(struct sock___14 *);
	void (*sk_write_space)(struct sock___14 *);
	void (*sk_error_report)(struct sock___14 *);
	int (*sk_backlog_rcv)(struct sock___14 *, struct sk_buff___22 *);
	struct sk_buff___22 * (*sk_validate_xmit_skb)(struct sock___14 *, struct net_device___4 *, struct sk_buff___22 *);
	void (*sk_destruct)(struct sock___14 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___91;

struct attribute_group___91 {
	const char *name;
	umode_t (*is_visible)(struct kobject___91 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___91 *, struct bin_attribute___91 *, int);
	struct attribute **attrs;
	struct bin_attribute___91 **bin_attrs;
};

struct bin_attribute___91 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___91 * (*f_mapping)();
	ssize_t (*read)(struct file___91 *, struct kobject___91 *, struct bin_attribute___91 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___91 *, struct kobject___91 *, struct bin_attribute___91 *, char *, loff_t, size_t);
	int (*mmap)(struct file___91 *, struct kobject___91 *, struct bin_attribute___91 *, struct vm_area_struct___96 *);
};

struct sysfs_ops___91 {
	ssize_t (*show)(struct kobject___91 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___91 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___91;

struct kset___91 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___91 kobj;
	const struct kset_uevent_ops___91 *uevent_ops;
};

struct kobj_type___91 {
	void (*release)(struct kobject___91 *);
	const struct sysfs_ops___91 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___91 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___91 *);
	const void * (*namespace)(struct kobject___91 *);
	void (*get_ownership)(struct kobject___91 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___91 {
	int (* const filter)(struct kset___91 *, struct kobject___91 *);
	const char * (* const name)(struct kset___91 *, struct kobject___91 *);
	int (* const uevent)(struct kset___91 *, struct kobject___91 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___77 {
	int (*prepare)(struct device___77 *);
	void (*complete)(struct device___77 *);
	int (*suspend)(struct device___77 *);
	int (*resume)(struct device___77 *);
	int (*freeze)(struct device___77 *);
	int (*thaw)(struct device___77 *);
	int (*poweroff)(struct device___77 *);
	int (*restore)(struct device___77 *);
	int (*suspend_late)(struct device___77 *);
	int (*resume_early)(struct device___77 *);
	int (*freeze_late)(struct device___77 *);
	int (*thaw_early)(struct device___77 *);
	int (*poweroff_late)(struct device___77 *);
	int (*restore_early)(struct device___77 *);
	int (*suspend_noirq)(struct device___77 *);
	int (*resume_noirq)(struct device___77 *);
	int (*freeze_noirq)(struct device___77 *);
	int (*thaw_noirq)(struct device___77 *);
	int (*poweroff_noirq)(struct device___77 *);
	int (*restore_noirq)(struct device___77 *);
	int (*runtime_suspend)(struct device___77 *);
	int (*runtime_resume)(struct device___77 *);
	int (*runtime_idle)(struct device___77 *);
};

struct wakeup_source___77 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___77 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___77 {
	struct dev_pm_ops___77 ops;
	int (*start)(struct device___77 *);
	void (*detach)(struct device___77 *, bool);
	int (*activate)(struct device___77 *);
	void (*sync)(struct device___77 *);
	void (*dismiss)(struct device___77 *);
};

struct bus_type___77 {
	const char *name;
	const char *dev_name;
	struct device___77 *dev_root;
	const struct attribute_group___91 **bus_groups;
	const struct attribute_group___91 **dev_groups;
	const struct attribute_group___91 **drv_groups;
	int (*match)(struct device___77 *, struct device_driver___77 *);
	int (*uevent)(struct device___77 *, struct kobj_uevent_env *);
	int (*probe)(struct device___77 *);
	void (*sync_state)(struct device___77 *);
	void (*remove)(struct device___77 *);
	void (*shutdown)(struct device___77 *);
	int (*online)(struct device___77 *);
	int (*offline)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	int (*num_vf)(struct device___77 *);
	int (*dma_configure)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___77 {
	const char *name;
	struct bus_type___77 *bus;
	struct module___89 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___77 *);
	void (*sync_state)(struct device___77 *);
	int (*remove)(struct device___77 *);
	void (*shutdown)(struct device___77 *);
	int (*suspend)(struct device___77 *, pm_message_t);
	int (*resume)(struct device___77 *);
	const struct attribute_group___91 **groups;
	const struct attribute_group___91 **dev_groups;
	const struct dev_pm_ops___77 *pm;
	void (*coredump)(struct device___77 *);
	struct driver_private *p;
};

struct device_type___77 {
	const char *name;
	const struct attribute_group___91 **groups;
	int (*uevent)(struct device___77 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___77 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___77 *);
	const struct dev_pm_ops___77 *pm;
};

struct class___77 {
	const char *name;
	struct module___89 *owner;
	const struct attribute_group___91 **class_groups;
	const struct attribute_group___91 **dev_groups;
	struct kobject___91 *dev_kobj;
	int (*dev_uevent)(struct device___77 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___77 *, umode_t *);
	void (*class_release)(struct class___77 *);
	void (*dev_release)(struct device___77 *);
	int (*shutdown_pre)(struct device___77 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___77 *);
	void (*get_ownership)(struct device___77 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___77 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___77;

struct fwnode_handle___77 {
	struct fwnode_handle___77 *secondary;
	const struct fwnode_operations___77 *ops;
	struct device___77 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___90 {
	void (*page_free)(struct page___96 *);
	void (*kill)(struct dev_pagemap___90 *);
	void (*cleanup)(struct dev_pagemap___90 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___90 *);
};

struct seq_operations___86 {
	void * (*start)(struct seq_file___86 *, loff_t *);
	void (*stop)(struct seq_file___86 *, void *);
	void * (*next)(struct seq_file___86 *, void *, loff_t *);
	int (*show)(struct seq_file___86 *, void *);
};

typedef struct poll_table_struct___66 poll_table___17;

struct poll_table_entry {
	struct file___91 *filp;
	__poll_t key;
	wait_queue_entry_t wait;
	wait_queue_head_t *wait_address;
};

struct poll_table_page;

struct poll_wqueues {
	poll_table___17 pt;
	struct poll_table_page *table;
	struct task_struct___98 *polling_task;
	int triggered;
	int error;
	int inline_index;
	struct poll_table_entry inline_entries[9];
};

struct poll_table_page {
	struct poll_table_page *next;
	struct poll_table_entry *entry;
	struct poll_table_entry entries[0];
};

struct fwnode_reference_args___77;

struct fwnode_endpoint___77;

struct fwnode_operations___77 {
	struct fwnode_handle___77 * (*get)(struct fwnode_handle___77 *);
	void (*put)(struct fwnode_handle___77 *);
	bool (*device_is_available)(const struct fwnode_handle___77 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___77 *, const struct device___77 *);
	bool (*property_present)(const struct fwnode_handle___77 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___77 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___77 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___77 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*get_parent)(const struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*get_next_child_node)(const struct fwnode_handle___77 *, struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*get_named_child_node)(const struct fwnode_handle___77 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___77 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___77 *);
	struct fwnode_handle___77 * (*graph_get_next_endpoint)(const struct fwnode_handle___77 *, struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*graph_get_remote_endpoint)(const struct fwnode_handle___77 *);
	struct fwnode_handle___77 * (*graph_get_port_parent)(struct fwnode_handle___77 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___77 *, struct fwnode_endpoint___77 *);
	int (*add_links)(struct fwnode_handle___77 *);
};

struct fwnode_endpoint___77 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___77 *local_fwnode;
};

struct fwnode_reference_args___77 {
	struct fwnode_handle___77 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___3;

struct fib_rules_ops___13;

struct fqdir___22;

struct fib_notifier_ops___13;

struct netns_ipv4___22 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___3 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___13 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___14 *fibnl;
	struct sock___14 **icmp_sk;
	struct sock___14 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___14 **tcp_sk;
	struct fqdir___22 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___13 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___13 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___13 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___13;

struct dst_ops___22 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___22 *);
	struct dst_entry___13 * (*check)(struct dst_entry___13 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___13 *);
	unsigned int (*mtu)(const struct dst_entry___13 *);
	u32 * (*cow_metrics)(struct dst_entry___13 *, long unsigned int);
	void (*destroy)(struct dst_entry___13 *);
	void (*ifdown)(struct dst_entry___13 *, struct net_device___4 *, int);
	struct dst_entry___13 * (*negative_advice)(struct dst_entry___13 *);
	void (*link_failure)(struct sk_buff___22 *);
	void (*update_pmtu)(struct dst_entry___13 *, struct sock___14 *, struct sk_buff___22 *, u32, bool);
	void (*redirect)(struct dst_entry___13 *, struct sock___14 *, struct sk_buff___22 *);
	int (*local_out)(struct net___23 *, struct sock___14 *, struct sk_buff___22 *);
	struct neighbour___13 * (*neigh_lookup)(const struct dst_entry___13 *, struct sk_buff___22 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___13 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___22 {
	struct dst_ops___22 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___22 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___13 *fib6_rules_ops;
	struct sock___14 **icmp_sk;
	struct sock___14 *ndisc_sk;
	struct sock___14 *tcp_sk;
	struct sock___14 *igmp_sk;
	struct sock___14 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___13 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___13 *notifier_ops;
	struct fib_notifier_ops___13 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___22 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___22 *fqdir;
};

struct netns_sctp___13 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___14 *ctl_sock;
	struct sock___14 *udp4_sock;
	struct sock___14 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___20 {
	struct bpf_prog_array___20 *run_array[2];
	struct bpf_prog___20 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___22 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___14 *nlsk;
	struct sock___14 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___22 xfrm4_dst_ops;
	struct dst_ops___22 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___23 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct idr netns_ids;
	struct ns_common___13 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___14 *rtnl;
	struct sock___14 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___4 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___22 ipv4;
	struct netns_ipv6___22 ipv6;
	struct netns_ieee802154_lowpan___22 ieee802154_lowpan;
	struct netns_sctp___13 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___20 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___20 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___22 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___14 *crypto_nlsk;
	struct sock___14 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___76 {
	struct ns_common___13 ns;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	struct css_set___76 *root_cset;
};

struct kernel_param_ops___88 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___88 *);
	int (*get)(char *, const struct kernel_param___88 *);
	void (*free)(void *);
};

struct kparam_array___88;

struct kernel_param___88 {
	const char *name;
	struct module___89 *mod;
	const struct kernel_param_ops___88 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___88 *arr;
	};
};

struct kparam_array___88 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___88 *ops;
	void *elem;
};

struct module_attribute___88 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___88 *, struct module_kobject___88 *, char *);
	ssize_t (*store)(struct module_attribute___88 *, struct module_kobject___88 *, const char *, size_t);
	void (*setup)(struct module___89 *, const char *);
	int (*test)(struct module___89 *);
	void (*free)(struct module___89 *);
};

struct trace_event_class___50;

struct trace_event_call___50 {
	struct list_head list;
	struct trace_event_class___50 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___50 *, struct perf_event___56 *);
};

struct msghdr___13 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___56 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___91 *msg_iocb;
};

struct fd___18 {
	struct file___91 *file;
	unsigned int flags;
};

struct bpf_iter_aux_info___21;

typedef int (*bpf_iter_init_seq_priv_t___21)(void *, struct bpf_iter_aux_info___21 *);

struct bpf_map___21;

struct bpf_iter_aux_info___21 {
	struct bpf_map___21 *map;
};

struct bpf_iter_seq_info___21 {
	const struct seq_operations___86 *seq_ops;
	bpf_iter_init_seq_priv_t___21 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___21;

struct bpf_map_ops___21 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___21 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___21 *, struct file___91 *);
	void (*map_free)(struct bpf_map___21 *);
	int (*map_get_next_key)(struct bpf_map___21 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___21 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___21 *, void *);
	int (*map_lookup_batch)(struct bpf_map___21 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___21 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___21 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___21 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___21 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___21 *, void *);
	int (*map_update_elem)(struct bpf_map___21 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___21 *, void *);
	int (*map_push_elem)(struct bpf_map___21 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___21 *, void *);
	int (*map_peek_elem)(struct bpf_map___21 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___21 *, struct file___91 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___21 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___21 *, void *, struct seq_file___86 *);
	int (*map_check_btf)(const struct bpf_map___21 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___21 *, struct bpf_prog_aux___21 *);
	void (*map_poke_untrack)(struct bpf_map___21 *, struct bpf_prog_aux___21 *);
	void (*map_poke_run)(struct bpf_map___21 *, u32, struct bpf_prog___20 *, struct bpf_prog___20 *);
	int (*map_direct_value_addr)(const struct bpf_map___21 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___21 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___21 *, struct vm_area_struct___96 *);
	__poll_t (*map_poll)(struct bpf_map___21 *, struct file___91 *, struct poll_table_struct___66 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___21 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___21 *, const struct bpf_map___21 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___21 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___21 *iter_seq_info;
};

struct bpf_map___21 {
	const struct bpf_map_ops___21 *ops;
	struct bpf_map___21 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___39 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___21;

struct bpf_jit_poke_descriptor___21;

struct bpf_prog_ops___20;

struct btf_mod_pair___21;

struct bpf_prog_offload___20;

struct bpf_prog_aux___21 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___20 *dst_prog;
	struct bpf_trampoline___21 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___20 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___21 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___20 *ops;
	struct bpf_map___21 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___21 *used_btfs;
	struct bpf_prog___20 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___21 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___20 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___20 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___21 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___20;

struct bpf_map_dev_ops___20 {
	int (*map_get_next_key)(struct bpf_offloaded_map___20 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___20 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___20 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___20 *, void *);
};

struct bpf_offloaded_map___20 {
	struct bpf_map___21 map;
	struct net_device___4 *netdev;
	const struct bpf_map_dev_ops___20 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___20(struct sk_buff___22 **);

struct bpf_xdp_entity___20 {
	struct bpf_prog___20 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___20;

struct net_device_ops___20;

struct l3mdev_ops___13;

struct ndisc_ops___6;

struct xfrmdev_ops___20;

struct header_ops___20;

struct inet6_dev___6;

struct netdev_rx_queue___20;

struct mini_Qdisc___20;

struct netdev_queue___20;

struct Qdisc___20;

struct rtnl_link_ops___20;

struct dcbnl_rtnl_ops___20;

struct net_device___4 {
	char name[16];
	struct netdev_name_node___20 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___20 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___13 *l3mdev_ops;
	const struct ndisc_ops___6 *ndisc_ops;
	const struct xfrmdev_ops___20 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___20 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___91 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___6 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___20 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___20 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___20 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___20 *miniq_ingress;
	struct netdev_queue___20 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___20 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___20 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___20 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___20 = 0,
		NETREG_REGISTERED___20 = 1,
		NETREG_UNREGISTERING___20 = 2,
		NETREG_UNREGISTERED___20 = 3,
		NETREG_RELEASED___20 = 4,
		NETREG_DUMMY___20 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___20 = 0,
		RTNL_LINK_INITIALIZING___20 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___4 *);
	struct netpoll_info *npinfo;
	possible_net_t___20 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___77 dev;
	const struct attribute_group___91 *sysfs_groups[4];
	const struct attribute_group___91 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___20 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___20 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___20 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___20 {
	int (*test_run)(struct bpf_prog___20 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___20 {
	struct bpf_prog___20 *prog;
	struct net_device___4 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___21 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___20 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___89 *mod;
};

struct bpf_jit_poke_descriptor___21 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___21 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___21 {
	struct btf *btf;
	struct module___89 *module;
};

struct bpf_prog_array_item___20 {
	struct bpf_prog___20 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___20 {
	struct callback_head rcu;
	struct bpf_prog_array_item___20 items[0];
};

struct sk_buff___22 {
	union {
		struct {
			struct sk_buff___22 *next;
			struct sk_buff___22 *prev;
			union {
				struct net_device___4 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___14 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___22 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___76;

struct cgroup_subsys___76 {
	struct cgroup_subsys_state___76 * (*css_alloc)(struct cgroup_subsys_state___76 *);
	int (*css_online)(struct cgroup_subsys_state___76 *);
	void (*css_offline)(struct cgroup_subsys_state___76 *);
	void (*css_released)(struct cgroup_subsys_state___76 *);
	void (*css_free)(struct cgroup_subsys_state___76 *);
	void (*css_reset)(struct cgroup_subsys_state___76 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___76 *, int);
	int (*css_extra_stat_show)(struct seq_file___86 *, struct cgroup_subsys_state___76 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___98 *, struct css_set___76 *);
	void (*cancel_fork)(struct task_struct___98 *, struct css_set___76 *);
	void (*fork)(struct task_struct___98 *);
	void (*exit)(struct task_struct___98 *);
	void (*release)(struct task_struct___98 *);
	void (*bind)(struct cgroup_subsys_state___76 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___76 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___76 *dfl_cftypes;
	struct cftype___76 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___76 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___76 *updated_children;
	struct cgroup___76 *updated_next;
};

struct cgroup_root___76 {
	struct kernfs_root___91 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___76 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___76 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___76 *ss;
	struct list_head node;
	struct kernfs_ops___91 *kf_ops;
	int (*open)(struct kernfs_open_file___91 *);
	void (*release)(struct kernfs_open_file___91 *);
	u64 (*read_u64)(struct cgroup_subsys_state___76 *, struct cftype___76 *);
	s64 (*read_s64)(struct cgroup_subsys_state___76 *, struct cftype___76 *);
	int (*seq_show)(struct seq_file___86 *, void *);
	void * (*seq_start)(struct seq_file___86 *, loff_t *);
	void * (*seq_next)(struct seq_file___86 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___86 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___76 *, struct cftype___76 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___76 *, struct cftype___76 *, s64);
	ssize_t (*write)(struct kernfs_open_file___91 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___91 *, struct poll_table_struct___66 *);
};

struct perf_cpu_context___56;

struct perf_output_handle___56;

struct pmu___56 {
	struct list_head entry;
	struct module___89 *module;
	struct device___77 *dev;
	const struct attribute_group___91 **attr_groups;
	const struct attribute_group___91 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___56 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___56 *);
	void (*pmu_disable)(struct pmu___56 *);
	int (*event_init)(struct perf_event___56 *);
	void (*event_mapped)(struct perf_event___56 *, struct mm_struct___97 *);
	void (*event_unmapped)(struct perf_event___56 *, struct mm_struct___97 *);
	int (*add)(struct perf_event___56 *, int);
	void (*del)(struct perf_event___56 *, int);
	void (*start)(struct perf_event___56 *, int);
	void (*stop)(struct perf_event___56 *, int);
	void (*read)(struct perf_event___56 *);
	void (*start_txn)(struct pmu___56 *, unsigned int);
	int (*commit_txn)(struct pmu___56 *);
	void (*cancel_txn)(struct pmu___56 *);
	int (*event_idx)(struct perf_event___56 *);
	void (*sched_task)(struct perf_event_context___56 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___56 *, struct perf_event_context___56 *);
	void * (*setup_aux)(struct perf_event___56 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___56 *, struct perf_output_handle___56 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___56 *);
	int (*aux_output_match)(struct perf_event___56 *);
	int (*filter_match)(struct perf_event___56 *);
	int (*check_period)(struct perf_event___56 *, u64);
};

struct perf_cpu_context___56 {
	struct perf_event_context___56 ctx;
	struct perf_event_context___56 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___56 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___56 **heap;
	struct perf_event___56 *heap_default[2];
};

struct perf_output_handle___56 {
	struct perf_event___56 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___56 {
	struct cgroup_subsys_state___76 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___50 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___50 *);
	};
};

struct trace_event_class___50 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___50 *, enum trace_reg, void *);
	struct trace_event_fields___50 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___50 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___50 *);
};

struct syscall_metadata___25 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___50 *enter_event;
	struct trace_event_call___50 *exit_event;
};

struct inet_frags___22;

struct fqdir___22 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___22 *f;
	struct net___23 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___22;

struct inet_frags___22 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___22 *, const void *);
	void (*destructor)(struct inet_frag_queue___22 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___22 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___22 *fragments_tail;
	struct sk_buff___22 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___22 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___3 {
	struct ip_ra_chain___3 *next;
	struct sock___14 *sk;
	union {
		void (*destructor)(struct sock___14 *);
		struct sock___14 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___13;

struct fib_lookup_arg___13;

struct fib_rules_ops___13 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___13 *, struct flowi *, int, struct fib_lookup_arg___13 *);
	bool (*suppress)(struct fib_rule___13 *, int, struct fib_lookup_arg___13 *);
	int (*match)(struct fib_rule___13 *, struct flowi *, int);
	int (*configure)(struct fib_rule___13 *, struct sk_buff___22 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___13 *);
	int (*compare)(struct fib_rule___13 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___13 *, struct sk_buff___22 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___13 *);
	void (*flush_cache)(struct fib_rules_ops___13 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___89 *owner;
	struct net___23 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___13 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___23 *);
	int (*fib_dump)(struct net___23 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___89 *owner;
	struct callback_head rcu;
};

struct dst_entry___13 {
	struct net_device___4 *dev;
	struct dst_ops___22 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___22 *);
	int (*output)(struct net___23 *, struct sock___14 *, struct sk_buff___22 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___13;

struct neigh_parms___13;

struct neigh_ops___13;

struct neighbour___13 {
	struct neighbour___13 *next;
	struct neigh_table___13 *tbl;
	struct neigh_parms___13 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___20 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___13 *, struct sk_buff___22 *);
	const struct neigh_ops___13 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___4 *dev;
	u8 primary_key[0];
};

struct socket_wq___13 {
	wait_queue_head_t wait;
	struct fasync_struct___91 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___13;

struct socket___13 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___91 *file;
	struct sock___14 *sk;
	const struct proto_ops___13 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___13 wq;
};

typedef int (*sk_read_actor_t___13)(read_descriptor_t *, struct sk_buff___22 *, unsigned int, size_t);

struct proto_ops___13 {
	int family;
	struct module___89 *owner;
	int (*release)(struct socket___13 *);
	int (*bind)(struct socket___13 *, struct sockaddr *, int);
	int (*connect)(struct socket___13 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___13 *, struct socket___13 *);
	int (*accept)(struct socket___13 *, struct socket___13 *, int, bool);
	int (*getname)(struct socket___13 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___91 *, struct socket___13 *, struct poll_table_struct___66 *);
	int (*ioctl)(struct socket___13 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___13 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___13 *, void *, bool, bool);
	int (*listen)(struct socket___13 *, int);
	int (*shutdown)(struct socket___13 *, int);
	int (*setsockopt)(struct socket___13 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___13 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___86 *, struct socket___13 *);
	int (*sendmsg)(struct socket___13 *, struct msghdr___13 *, size_t);
	int (*recvmsg)(struct socket___13 *, struct msghdr___13 *, size_t, int);
	int (*mmap)(struct file___91 *, struct socket___13 *, struct vm_area_struct___96 *);
	ssize_t (*sendpage)(struct socket___13 *, struct page___96 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___13 *, loff_t *, struct pipe_inode_info___37 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___14 *, int);
	int (*peek_len)(struct socket___13 *);
	int (*read_sock)(struct sock___14 *, read_descriptor_t *, sk_read_actor_t___13);
	int (*sendpage_locked)(struct sock___14 *, struct page___96 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___14 *, struct msghdr___13 *, size_t);
	int (*set_rcvlowat)(struct sock___14 *, int);
};

struct pipe_buf_operations___37;

struct pipe_buffer___37 {
	struct page___96 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___37 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___37 {
	int (*confirm)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
	void (*release)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
	bool (*try_steal)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
	bool (*get)(struct pipe_inode_info___37 *, struct pipe_buffer___37 *);
};

struct dcbnl_rtnl_ops___20 {
	int (*ieee_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___4 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___4 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___4 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___4 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___4 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___4 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___4 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___4 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___4 *);
	u8 (*setstate)(struct net_device___4 *, u8);
	void (*getpermhwaddr)(struct net_device___4 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___4 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___4 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___4 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___4 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___4 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___4 *, int, u8 *);
	void (*setpfccfg)(struct net_device___4 *, int, u8);
	void (*getpfccfg)(struct net_device___4 *, int, u8 *);
	u8 (*setall)(struct net_device___4 *);
	u8 (*getcap)(struct net_device___4 *, int, u8 *);
	int (*getnumtcs)(struct net_device___4 *, int, u8 *);
	int (*setnumtcs)(struct net_device___4 *, int, u8);
	u8 (*getpfcstate)(struct net_device___4 *);
	void (*setpfcstate)(struct net_device___4 *, u8);
	void (*getbcncfg)(struct net_device___4 *, int, u32 *);
	void (*setbcncfg)(struct net_device___4 *, int, u32);
	void (*getbcnrp)(struct net_device___4 *, int, u8 *);
	void (*setbcnrp)(struct net_device___4 *, int, u8);
	int (*setapp)(struct net_device___4 *, u8, u16, u8);
	int (*getapp)(struct net_device___4 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___4 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___4 *, int, u8);
	u8 (*getdcbx)(struct net_device___4 *);
	u8 (*setdcbx)(struct net_device___4 *, u8);
	int (*peer_getappinfo)(struct net_device___4 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___4 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___4 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___4 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___4 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___4 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___20 {
	struct net_device___4 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___20 {
	struct net_device___4 *dev;
};

struct xdp_buff___20 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___20 *rxq;
	struct xdp_txq_info___20 *txq;
	u32 frame_sz;
};

struct xdp_frame___20 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___4 *dev_rx;
};

struct netlink_callback___20 {
	struct sk_buff___22 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___22 *, struct netlink_callback___20 *);
	int (*done)(struct netlink_callback___20 *);
	void *data;
	struct module___89 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___20 {
	int (*create)(struct sk_buff___22 *, struct net_device___4 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___22 *, unsigned char *);
	int (*cache)(const struct neighbour___13 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___4 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___22 *);
};

struct netdev_queue___20 {
	struct net_device___4 *dev;
	struct Qdisc___20 *qdisc;
	struct Qdisc___20 *qdisc_sleeping;
	struct kobject___91 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___4 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___20 {
	struct sk_buff___22 *head;
	struct sk_buff___22 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___20;

struct Qdisc___20 {
	int (*enqueue)(struct sk_buff___22 *, struct Qdisc___20 *, struct sk_buff___22 **);
	struct sk_buff___22 * (*dequeue)(struct Qdisc___20 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___20 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___20 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___20 gso_skb;
	struct qdisc_skb_head___20 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___20 *next_sched;
	struct sk_buff_head___20 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___20 {
	struct xdp_rxq_info___20 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___91 kobj;
	struct net_device___4 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___20 {
	enum net_device_path_type type;
	const struct net_device___4 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___20 = 0,
				DEV_PATH_BR_VLAN_TAG___20 = 1,
				DEV_PATH_BR_VLAN_UNTAG___20 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___20 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___20 {
	const struct net_device___4 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___20 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___20 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___20 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___20 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___22 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___20 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___4 *dev;
	const char *name;
};

struct net_device_ops___20 {
	int (*ndo_init)(struct net_device___4 *);
	void (*ndo_uninit)(struct net_device___4 *);
	int (*ndo_open)(struct net_device___4 *);
	int (*ndo_stop)(struct net_device___4 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___22 *, struct net_device___4 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___22 *, struct net_device___4 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___4 *, struct sk_buff___22 *, struct net_device___4 *);
	void (*ndo_change_rx_flags)(struct net_device___4 *, int);
	void (*ndo_set_rx_mode)(struct net_device___4 *);
	int (*ndo_set_mac_address)(struct net_device___4 *, void *);
	int (*ndo_validate_addr)(struct net_device___4 *);
	int (*ndo_do_ioctl)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___4 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___4 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___4 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___4 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___4 *, int);
	int (*ndo_neigh_setup)(struct net_device___4 *, struct neigh_parms___13 *);
	void (*ndo_tx_timeout)(struct net_device___4 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___4 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___4 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___4 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___4 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___4 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___4 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___4 *);
	int (*ndo_netpoll_setup)(struct net_device___4 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___4 *);
	int (*ndo_set_vf_mac)(struct net_device___4 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___4 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___4 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___4 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___4 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___4 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___4 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___4 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___4 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___4 *, int, struct sk_buff___22 *);
	int (*ndo_get_vf_guid)(struct net_device___4 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___4 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___4 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___4 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___4 *);
	int (*ndo_fcoe_disable)(struct net_device___4 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___4 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___4 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___4 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___4 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___4 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___4 *, const struct sk_buff___22 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___4 *, struct net_device___4 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___4 *, struct net_device___4 *);
	struct net_device___4 * (*ndo_get_xmit_slave)(struct net_device___4 *, struct sk_buff___22 *, bool);
	struct net_device___4 * (*ndo_sk_get_lower_dev)(struct net_device___4 *, struct sock___14 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___4 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___4 *, struct neighbour___13 *);
	void (*ndo_neigh_destroy)(struct net_device___4 *, struct neighbour___13 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___22 *, struct netlink_callback___20 *, struct net_device___4 *, struct net_device___4 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___22 *, struct nlattr **, struct net_device___4 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___4 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___22 *, u32, u32, struct net_device___4 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___4 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___4 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___4 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___4 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___4 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___4 *, struct net_device___4 *);
	void (*ndo_dfwd_del_station)(struct net_device___4 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___4 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___4 *);
	int (*ndo_change_proto_down)(struct net_device___4 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___4 *, struct sk_buff___22 *);
	void (*ndo_set_rx_headroom)(struct net_device___4 *, int);
	int (*ndo_bpf)(struct net_device___4 *, struct netdev_bpf___20 *);
	int (*ndo_xdp_xmit)(struct net_device___4 *, int, struct xdp_frame___20 **, u32);
	struct net_device___4 * (*ndo_xdp_get_xmit_slave)(struct net_device___4 *, struct xdp_buff___20 *);
	int (*ndo_xsk_wakeup)(struct net_device___4 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___4 *);
	int (*ndo_tunnel_ctl)(struct net_device___4 *, struct ip_tunnel_parm *, int);
	struct net_device___4 * (*ndo_get_peer_dev)(struct net_device___4 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___20 *, struct net_device_path___20 *);
};

struct neigh_parms___13 {
	possible_net_t___20 net;
	struct net_device___4 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___13 *);
	struct neigh_table___13 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___13 {
	u32 (*l3mdev_fib_table)(const struct net_device___4 *);
	struct sk_buff___22 * (*l3mdev_l3_rcv)(struct net_device___4 *, struct sk_buff___22 *, u16);
	struct sk_buff___22 * (*l3mdev_l3_out)(struct net_device___4 *, struct sock___14 *, struct sk_buff___22 *, u16);
	struct dst_entry___13 * (*l3mdev_link_scope_lookup)(const struct net_device___4 *, struct flowi6 *);
};

struct ndisc_ops___6 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___4 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___4 *, struct neighbour___13 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___4 *, u8, struct neighbour___13 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___4 *, struct sk_buff___22 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___23 *, struct net_device___4 *, const struct prefix_info *, struct inet6_dev___6 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___6;

struct inet6_dev___6 {
	struct net_device___4 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___6 *mc_list;
	struct ifmcaddr6___6 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___20 mc_query_queue;
	struct sk_buff_head___20 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___13 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___20;

struct tcf_block___20;

struct mini_Qdisc___20 {
	struct tcf_proto___20 *filter_list;
	struct tcf_block___20 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___20 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___4 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___4 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___23 *, struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___4 *, struct list_head *);
	size_t (*get_size)(const struct net_device___4 *);
	int (*fill_info)(struct sk_buff___22 *, const struct net_device___4 *);
	size_t (*get_xstats_size)(const struct net_device___4 *);
	int (*fill_xstats)(struct sk_buff___22 *, const struct net_device___4 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___4 *, struct net_device___4 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___4 *, const struct net_device___4 *);
	int (*fill_slave_info)(struct sk_buff___22 *, const struct net_device___4 *, const struct net_device___4 *);
	struct net___23 * (*get_link_net)(const struct net_device___4 *);
	size_t (*get_linkxstats_size)(const struct net_device___4 *, int);
	int (*fill_linkxstats)(struct sk_buff___22 *, const struct net_device___4 *, int *, int);
};

struct block_device_operations___44;

struct gendisk___44 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___45 *part0;
	const struct block_device_operations___44 *fops;
	struct request_queue___44 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___43 *bdi;
	struct kobject___91 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___91 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___44 {
	struct bio___44 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___54 *bip_vec;
	struct bio_vec___54 bip_inline_vecs[0];
};

struct blkcg___43;

struct blkg_policy_data___43;

struct blkcg_gq___43 {
	struct request_queue___44 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___43 *blkcg;
	struct blkcg_gq___43 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___43 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___44 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___44(struct request___44 *);

typedef void integrity_complete_fn___44(struct request___44 *, unsigned int);

struct blk_integrity_profile___44 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___44 *prepare_fn;
	integrity_complete_fn___44 *complete_fn;
	const char *name;
};

struct block_device_operations___44 {
	blk_qc_t (*submit_bio)(struct bio___44 *);
	int (*open)(struct block_device___45 *, fmode_t);
	void (*release)(struct gendisk___44 *, fmode_t);
	int (*rw_page)(struct block_device___45 *, sector_t, struct page___96 *, unsigned int);
	int (*ioctl)(struct block_device___45 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___45 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___44 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___44 *);
	int (*getgeo)(struct block_device___45 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___45 *, bool);
	void (*swap_slot_free_notify)(struct block_device___45 *, long unsigned int);
	int (*report_zones)(struct gendisk___44 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___44 *, umode_t *);
	struct module___89 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___44 *, sector_t *);
};

typedef void rq_end_io_fn___44(struct request___44 *, blk_status_t);

struct request___44 {
	struct request_queue___44 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___43 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___44 *bio;
	struct bio___44 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___54 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___44 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___44 *saved_end_io;
		} flush;
	};
	struct gendisk___44 *rq_disk;
	struct block_device___45 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___44 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___43 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___44 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___91 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___91 *debugfs_dir;
	struct dentry___91 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___44;

struct elevator_mq_ops___44 {
	int (*init_sched)(struct request_queue___44 *, struct elevator_type___44 *);
	void (*exit_sched)(struct elevator_queue___44 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___43 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___43 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___43 *);
	bool (*allow_merge)(struct request_queue___44 *, struct request___44 *, struct bio___44 *);
	bool (*bio_merge)(struct request_queue___44 *, struct bio___44 *, unsigned int);
	int (*request_merge)(struct request_queue___44 *, struct request___44 **, struct bio___44 *);
	void (*request_merged)(struct request_queue___44 *, struct request___44 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___44 *, struct request___44 *, struct request___44 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___44 *);
	void (*finish_request)(struct request___44 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___43 *, struct list_head *, bool);
	struct request___44 * (*dispatch_request)(struct blk_mq_hw_ctx___43 *);
	bool (*has_work)(struct blk_mq_hw_ctx___43 *);
	void (*completed_request)(struct request___44 *, u64);
	void (*requeue_request)(struct request___44 *);
	struct request___44 * (*former_request)(struct request_queue___44 *, struct request___44 *);
	struct request___44 * (*next_request)(struct request_queue___44 *, struct request___44 *);
	void (*init_icq)(struct io_cq___44 *);
	void (*exit_icq)(struct io_cq___44 *);
};

struct elv_fs_entry___44;

struct elevator_type___44 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___44 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___44 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___89 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___44 {
	struct elevator_type___44 *type;
	void *elevator_data;
	struct kobject___91 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___44 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___44 *, char *);
	ssize_t (*store)(struct elevator_queue___44 *, const char *, size_t);
};

struct blk_mq_queue_data___43;

struct blk_mq_ops___43 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___43 *, const struct blk_mq_queue_data___43 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___43 *);
	int (*get_budget)(struct request_queue___44 *);
	void (*put_budget)(struct request_queue___44 *, int);
	void (*set_rq_budget_token)(struct request___44 *, int);
	int (*get_rq_budget_token)(struct request___44 *);
	enum blk_eh_timer_return (*timeout)(struct request___44 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___43 *);
	void (*complete)(struct request___44 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___43 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___43 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___43 *, struct request___44 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___43 *, struct request___44 *, unsigned int);
	void (*initialize_rq_fn)(struct request___44 *);
	void (*cleanup_rq)(struct request___44 *);
	bool (*busy)(struct request_queue___44 *);
	int (*map_queues)(struct blk_mq_tag_set___43 *);
	void (*show_rq)(struct seq_file___86 *, struct request___44 *);
};

struct blk_mq_tag_set___43 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___43 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___43 {
	struct request___44 *rq;
	bool last;
};

struct blkcg_policy_data___43;

struct blkcg___43 {
	struct cgroup_subsys_state___76 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___43 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___43 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___43 {
	struct blkcg___43 *blkcg;
	int plid;
};

struct blkg_policy_data___43 {
	struct blkcg_gq___43 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___39 {
	struct mem_cgroup___39 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___39 {
	struct lruvec___45 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___39 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___39 *memcg;
};

struct obj_cgroup___39 {
	struct percpu_ref refcnt;
	struct mem_cgroup___39 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___20 {
	spinlock_t *lock;
	struct sk_buff___22 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___20;

struct Qdisc_ops___20 {
	struct Qdisc_ops___20 *next;
	const struct Qdisc_class_ops___20 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___22 *, struct Qdisc___20 *, struct sk_buff___22 **);
	struct sk_buff___22 * (*dequeue)(struct Qdisc___20 *);
	struct sk_buff___22 * (*peek)(struct Qdisc___20 *);
	int (*init)(struct Qdisc___20 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___20 *);
	void (*destroy)(struct Qdisc___20 *);
	int (*change)(struct Qdisc___20 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___20 *);
	int (*change_tx_queue_len)(struct Qdisc___20 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___20 *, unsigned int);
	int (*dump)(struct Qdisc___20 *, struct sk_buff___22 *);
	int (*dump_stats)(struct Qdisc___20 *, struct gnet_dump___20 *);
	void (*ingress_block_set)(struct Qdisc___20 *, u32);
	void (*egress_block_set)(struct Qdisc___20 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___20 *);
	u32 (*egress_block_get)(struct Qdisc___20 *);
	struct module___89 *owner;
};

struct Qdisc_class_ops___20 {
	unsigned int flags;
	struct netdev_queue___20 * (*select_queue)(struct Qdisc___20 *, struct tcmsg *);
	int (*graft)(struct Qdisc___20 *, long unsigned int, struct Qdisc___20 *, struct Qdisc___20 **, struct netlink_ext_ack *);
	struct Qdisc___20 * (*leaf)(struct Qdisc___20 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___20 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___20 *, u32);
	int (*change)(struct Qdisc___20 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___20 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___20 *, struct qdisc_walker *);
	struct tcf_block___20 * (*tcf_block)(struct Qdisc___20 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___20 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___20 *, long unsigned int);
	int (*dump)(struct Qdisc___20 *, long unsigned int, struct sk_buff___22 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___20 *, long unsigned int, struct gnet_dump___20 *);
};

struct tcf_chain___20;

struct tcf_block___20 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___23 *net;
	struct Qdisc___20 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___20 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___20;

struct tcf_proto_ops___20;

struct tcf_proto___20 {
	struct tcf_proto___20 *next;
	void *root;
	int (*classify)(struct sk_buff___22 *, const struct tcf_proto___20 *, struct tcf_result___20 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___20 *ops;
	struct tcf_chain___20 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___20 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___20 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___20 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___22 *, const struct tcf_proto___20 *, struct tcf_result___20 *);
	int (*init)(struct tcf_proto___20 *);
	void (*destroy)(struct tcf_proto___20 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___20 *, u32);
	void (*put)(struct tcf_proto___20 *, void *);
	int (*change)(struct net___23 *, struct sk_buff___22 *, struct tcf_proto___20 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___20 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___20 *);
	void (*walk)(struct tcf_proto___20 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___20 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___20 *, void *);
	void (*hw_del)(struct tcf_proto___20 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___23 *, struct tcf_chain___20 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___23 *, struct tcf_proto___20 *, void *, struct sk_buff___22 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___23 *, struct tcf_proto___20 *, void *, struct sk_buff___22 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___22 *, struct net___23 *, void *);
	struct module___89 *owner;
	int flags;
};

struct tcf_chain___20 {
	struct mutex filter_chain_lock;
	struct tcf_proto___20 *filter_chain;
	struct list_head list;
	struct tcf_block___20 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___20 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___13 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___20 *prog;
};

struct pneigh_entry___13;

struct neigh_hash_table___13;

struct neigh_table___13 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___4 *, __u32 *);
	bool (*key_eq)(const struct neighbour___13 *, const void *);
	int (*constructor)(struct neighbour___13 *);
	int (*pconstructor)(struct pneigh_entry___13 *);
	void (*pdestructor)(struct pneigh_entry___13 *);
	void (*proxy_redo)(struct sk_buff___22 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___4 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___13 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___20 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___13 *nht;
	struct pneigh_entry___13 **phash_buckets;
};

struct neigh_ops___13 {
	int family;
	void (*solicit)(struct neighbour___13 *, struct sk_buff___22 *);
	void (*error_report)(struct neighbour___13 *, struct sk_buff___22 *);
	int (*output)(struct neighbour___13 *, struct sk_buff___22 *);
	int (*connected_output)(struct neighbour___13 *, struct sk_buff___22 *);
};

struct pneigh_entry___13 {
	struct pneigh_entry___13 *next;
	possible_net_t___20 net;
	struct net_device___4 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___13 {
	struct neighbour___13 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___23 *, struct sock___14 *, struct sk_buff___22 *);
	int (*orig_input)(struct sk_buff___22 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___13 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___13 *ctarget;
	struct net___23 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___13 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___13 *rule;
	u32 table;
	int flags;
};

struct proto___13 {
	void (*close)(struct sock___14 *, long int);
	int (*pre_connect)(struct sock___14 *, struct sockaddr *, int);
	int (*connect)(struct sock___14 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___14 *, int);
	struct sock___14 * (*accept)(struct sock___14 *, int, int *, bool);
	int (*ioctl)(struct sock___14 *, int, long unsigned int);
	int (*init)(struct sock___14 *);
	void (*destroy)(struct sock___14 *);
	void (*shutdown)(struct sock___14 *, int);
	int (*setsockopt)(struct sock___14 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___14 *, int, int, char *, int *);
	void (*keepalive)(struct sock___14 *, int);
	int (*compat_ioctl)(struct sock___14 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___14 *, struct msghdr___13 *, size_t);
	int (*recvmsg)(struct sock___14 *, struct msghdr___13 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___14 *, struct page___96 *, int, size_t, int);
	int (*bind)(struct sock___14 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___14 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___14 *, struct sk_buff___22 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___14 *);
	int (*hash)(struct sock___14 *);
	void (*unhash)(struct sock___14 *);
	void (*rehash)(struct sock___14 *);
	int (*get_port)(struct sock___14 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___14 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___14 *, int);
	bool (*sock_is_readable)(struct sock___14 *);
	void (*enter_memory_pressure)(struct sock___14 *);
	void (*leave_memory_pressure)(struct sock___14 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___89 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___14 *, int);
};

struct request_sock___7;

struct request_sock_ops___3 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___14 *, struct request_sock___7 *);
	void (*send_ack)(const struct sock___14 *, struct sk_buff___22 *, struct request_sock___7 *);
	void (*send_reset)(const struct sock___14 *, struct sk_buff___22 *);
	void (*destructor)(struct request_sock___7 *);
	void (*syn_ack_timeout)(const struct request_sock___7 *);
};

struct timewait_sock_ops___3 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___14 *, struct sock___14 *, void *);
	void (*twsk_destructor)(struct sock___14 *);
};

struct request_sock___7 {
	struct sock_common___13 __req_common;
	struct request_sock___7 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___3 *rsk_ops;
	struct sock___14 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___6 {
	struct in6_addr mca_addr;
	struct inet6_dev___6 *idev;
	struct ifmcaddr6___6 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

enum poll_time_type {
	PT_TIMEVAL = 0,
	PT_OLD_TIMEVAL = 1,
	PT_TIMESPEC = 2,
	PT_OLD_TIMESPEC = 3,
};

typedef struct {
	long unsigned int *in;
	long unsigned int *out;
	long unsigned int *ex;
	long unsigned int *res_in;
	long unsigned int *res_out;
	long unsigned int *res_ex;
} fd_set_bits;

struct sigset_argpack {
	sigset_t *p;
	size_t size;
};

struct poll_list {
	struct poll_list *next;
	int len;
	struct pollfd entries[0];
};

struct compat_sel_arg_struct {
	compat_ulong_t n;
	compat_uptr_t inp;
	compat_uptr_t outp;
	compat_uptr_t exp;
	compat_uptr_t tvp;
};

struct compat_sigset_argpack {
	compat_uptr_t p;
	compat_size_t size;
};

struct dentry___92;

struct super_block___92;

struct file_system_type___92 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___92 * (*mount)(struct file_system_type___92 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___92 *);
	struct module___8 *owner;
	struct file_system_type___92 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___92;

struct kiocb___92;

struct poll_table_struct___67;

struct vm_area_struct___97;

struct inode___92;

struct file_lock___92;

struct page___97;

struct seq_file___87;

struct file_operations___92 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___92 *, loff_t, int);
	ssize_t (*read)(struct file___92 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___92 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___92 *, struct iov_iter___56 *);
	ssize_t (*write_iter)(struct kiocb___92 *, struct iov_iter___56 *);
	int (*iopoll)(struct kiocb___92 *, bool);
	int (*iterate)(struct file___92 *, struct dir_context *);
	int (*iterate_shared)(struct file___92 *, struct dir_context *);
	__poll_t (*poll)(struct file___92 *, struct poll_table_struct___67 *);
	long int (*unlocked_ioctl)(struct file___92 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___92 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___92 *, struct vm_area_struct___97 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___92 *, struct file___92 *);
	int (*flush)(struct file___92 *, fl_owner_t);
	int (*release)(struct inode___92 *, struct file___92 *);
	int (*fsync)(struct file___92 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___92 *, int);
	int (*lock)(struct file___92 *, int, struct file_lock___92 *);
	ssize_t (*sendpage)(struct file___92 *, struct page___97 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___92 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___92 *, long unsigned int);
	int (*flock)(struct file___92 *, int, struct file_lock___92 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___92 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___92 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___92 *, long int, struct file_lock___92 **, void **);
	long int (*fallocate)(struct file___92 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___87 *, struct file___92 *);
	ssize_t (*copy_file_range)(struct file___92 *, loff_t, struct file___92 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___92 *, loff_t, struct file___92 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___92 *, loff_t, loff_t, int);
};

struct vmacache___97 {
	u64 seqnum;
	struct vm_area_struct___97 *vmas[4];
};

struct page_frag___97 {
	struct page___97 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___98;

struct pid___84;

struct nsproxy___89;

struct signal_struct___93;

struct task_struct___99 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___99 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___98 *mm;
	struct mm_struct___98 *active_mm;
	struct vmacache___97 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___99 *real_parent;
	struct task_struct___99 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___99 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___84 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___89 *nsproxy;
	struct signal_struct___93 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___99 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___44 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___97 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___99 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___84;

struct upid___84 {
	int nr;
	struct pid_namespace___84 *ns;
};

struct pid_namespace___84 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___99 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___84 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___84 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___84 numbers[1];
};

typedef struct page___97 *pgtable_t___97;

struct address_space___92;

struct dev_pagemap___91;

struct page___97 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___92 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___97 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___97 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___98 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___91 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___91;

struct vm_area_struct___97 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___97 *vm_next;
	struct vm_area_struct___97 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___98 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___91 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___92 *vm_file;
	struct file___92 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___93 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___99 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___99 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___84 *pids[4];
	struct pid___84 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___98 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___97;

struct mm_struct___98 {
	struct {
		struct vm_area_struct___97 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___92 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___97 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___99 *owner;
		struct user_namespace___13 *user_ns;
		struct file___92 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct mnt_namespace___3;

struct nsproxy___89 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___3 *mnt_ns;
	struct pid_namespace___84 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct address_space_operations___92;

struct address_space___92 {
	struct inode___92 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___92 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___91;

struct dev_pagemap___91 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___91 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___92;

struct path___92 {
	struct vfsmount___92 *mnt;
	struct dentry___92 *dentry;
};

struct fown_struct___84 {
	rwlock_t lock;
	struct pid___84 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___92 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___92 f_path;
	struct inode___92 *f_inode;
	const struct file_operations___92 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___84 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___92 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___91;

struct vm_operations_struct___91 {
	void (*open)(struct vm_area_struct___97 *);
	void (*close)(struct vm_area_struct___97 *);
	int (*may_split)(struct vm_area_struct___97 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___97 *);
	int (*mprotect)(struct vm_area_struct___97 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___91 *);
	vm_fault_t (*huge_fault)(struct vm_fault___91 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___91 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___97 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___91 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___91 *);
	int (*access)(struct vm_area_struct___97 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___97 *);
	int (*set_policy)(struct vm_area_struct___97 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___97 *, long unsigned int);
	struct page___97 * (*find_special_page)(struct vm_area_struct___97 *, long unsigned int);
};

struct core_thread___97 {
	struct task_struct___99 *task;
	struct core_thread___97 *next;
};

struct core_state___97 {
	atomic_t nr_threads;
	struct core_thread___97 dumper;
	struct completion startup;
};

struct vm_fault___91 {
	const struct {
		struct vm_area_struct___97 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___97 *cow_page;
	struct page___97 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___97 prealloc_pte;
};

struct dev_pagemap_ops___91 {
	void (*page_free)(struct page___97 *);
	void (*kill)(struct dev_pagemap___91 *);
	void (*cleanup)(struct dev_pagemap___91 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___91 *);
};

struct dentry_operations___92;

struct dentry___92 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___92 *d_parent;
	struct qstr d_name;
	struct inode___92 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___92 *d_op;
	struct super_block___92 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___92;

struct inode___92 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___92 *i_op;
	struct super_block___92 *i_sb;
	struct address_space___92 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___92 *i_fop;
		void (*free_inode)(struct inode___92 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___92 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___92 {
	int (*d_revalidate)(struct dentry___92 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___92 *, unsigned int);
	int (*d_hash)(const struct dentry___92 *, struct qstr *);
	int (*d_compare)(const struct dentry___92 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___92 *);
	int (*d_init)(struct dentry___92 *);
	void (*d_release)(struct dentry___92 *);
	void (*d_prune)(struct dentry___92 *);
	void (*d_iput)(struct dentry___92 *, struct inode___92 *);
	char * (*d_dname)(struct dentry___92 *, char *, int);
	struct vfsmount___92 * (*d_automount)(struct path___92 *);
	int (*d_manage)(const struct path___92 *, bool);
	struct dentry___92 * (*d_real)(struct dentry___92 *, const struct inode___92 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___92;

struct mem_dqinfo___92 {
	struct quota_format_type___92 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___92;

struct quota_info___92 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___92 *files[3];
	struct mem_dqinfo___92 info[3];
	const struct quota_format_ops___92 *ops[3];
};

struct rcuwait___93 {
	struct task_struct___99 *task;
};

struct percpu_rw_semaphore___93 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___93 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___92 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___93 rw_sem[3];
};

struct super_operations___92;

struct dquot_operations___92;

struct quotactl_ops___92;

struct fscrypt_operations___3;

struct super_block___92 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___92 *s_type;
	const struct super_operations___92 *s_op;
	const struct dquot_operations___92 *dq_op;
	const struct quotactl_ops___92 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___92 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___3 *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___92 s_dquot;
	struct sb_writers___92 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___92 *s_d_op;
	int cleancache_poolid;
	struct shrinker___39 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

enum dentry_d_lock_class {
	DENTRY_D_LOCK_NORMAL = 0,
	DENTRY_D_LOCK_NESTED = 1,
};

struct vfsmount___92 {
	struct dentry___92 *mnt_root;
	struct super_block___92 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct kiocb___92 {
	struct file___92 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___92 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___46 *ki_waitq;
	};
};

struct iattr___92 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___92 *ia_file;
};

struct dquot___92 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___92 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___92 {
	int qf_fmt_id;
	const struct quota_format_ops___92 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___92 *qf_next;
};

struct quota_format_ops___92 {
	int (*check_quota_file)(struct super_block___92 *, int);
	int (*read_file_info)(struct super_block___92 *, int);
	int (*write_file_info)(struct super_block___92 *, int);
	int (*free_file_info)(struct super_block___92 *, int);
	int (*read_dqblk)(struct dquot___92 *);
	int (*commit_dqblk)(struct dquot___92 *);
	int (*release_dqblk)(struct dquot___92 *);
	int (*get_next_id)(struct super_block___92 *, struct kqid *);
};

struct dquot_operations___92 {
	int (*write_dquot)(struct dquot___92 *);
	struct dquot___92 * (*alloc_dquot)(struct super_block___92 *, int);
	void (*destroy_dquot)(struct dquot___92 *);
	int (*acquire_dquot)(struct dquot___92 *);
	int (*release_dquot)(struct dquot___92 *);
	int (*mark_dirty)(struct dquot___92 *);
	int (*write_info)(struct super_block___92 *, int);
	qsize_t * (*get_reserved_space)(struct inode___92 *);
	int (*get_projid)(struct inode___92 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___92 *, qsize_t *);
	int (*get_next_id)(struct super_block___92 *, struct kqid *);
};

struct quotactl_ops___92 {
	int (*quota_on)(struct super_block___92 *, int, int, const struct path___92 *);
	int (*quota_off)(struct super_block___92 *, int);
	int (*quota_enable)(struct super_block___92 *, unsigned int);
	int (*quota_disable)(struct super_block___92 *, unsigned int);
	int (*quota_sync)(struct super_block___92 *, int);
	int (*set_info)(struct super_block___92 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___92 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___92 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___92 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___92 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___92 *, unsigned int);
};

struct address_space_operations___92 {
	int (*writepage)(struct page___97 *, struct writeback_control___3 *);
	int (*readpage)(struct file___92 *, struct page___97 *);
	int (*writepages)(struct address_space___92 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___97 *);
	int (*readpages)(struct file___92 *, struct address_space___92 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___92 *, struct address_space___92 *, loff_t, unsigned int, unsigned int, struct page___97 **, void **);
	int (*write_end)(struct file___92 *, struct address_space___92 *, loff_t, unsigned int, unsigned int, struct page___97 *, void *);
	sector_t (*bmap)(struct address_space___92 *, sector_t);
	void (*invalidatepage)(struct page___97 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___97 *, gfp_t);
	void (*freepage)(struct page___97 *);
	ssize_t (*direct_IO)(struct kiocb___92 *, struct iov_iter___56 *);
	int (*migratepage)(struct address_space___92 *, struct page___97 *, struct page___97 *, enum migrate_mode);
	bool (*isolate_page)(struct page___97 *, isolate_mode_t);
	void (*putback_page)(struct page___97 *);
	int (*launder_page)(struct page___97 *);
	int (*is_partially_uptodate)(struct page___97 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___97 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___92 *, struct page___97 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___92 *, sector_t *);
	void (*swap_deactivate)(struct file___92 *);
};

struct inode_operations___92 {
	struct dentry___92 * (*lookup)(struct inode___92 *, struct dentry___92 *, unsigned int);
	const char * (*get_link)(struct dentry___92 *, struct inode___92 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___92 *, int);
	struct posix_acl * (*get_acl)(struct inode___92 *, int, bool);
	int (*readlink)(struct dentry___92 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___92 *, struct dentry___92 *, umode_t, bool);
	int (*link)(struct dentry___92 *, struct inode___92 *, struct dentry___92 *);
	int (*unlink)(struct inode___92 *, struct dentry___92 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___92 *, struct dentry___92 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___92 *, struct dentry___92 *, umode_t);
	int (*rmdir)(struct inode___92 *, struct dentry___92 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___92 *, struct dentry___92 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___92 *, struct dentry___92 *, struct inode___92 *, struct dentry___92 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___92 *, struct iattr___92 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___92 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___92 *, char *, size_t);
	int (*fiemap)(struct inode___92 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___92 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___92 *, struct dentry___92 *, struct file___92 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___92 *, struct dentry___92 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___92 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___92 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___92 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___92 {
	void (*fl_copy_lock)(struct file_lock___92 *, struct file_lock___92 *);
	void (*fl_release_private)(struct file_lock___92 *);
};

struct fasync_struct___92;

struct lock_manager_operations___92;

struct file_lock___92 {
	struct file_lock___92 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___92 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___92 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___92 *fl_ops;
	const struct lock_manager_operations___92 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___92 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___92 *);
	int (*lm_grant)(struct file_lock___92 *, int);
	bool (*lm_break)(struct file_lock___92 *);
	int (*lm_change)(struct file_lock___92 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___92 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___92 *);
};

struct fasync_struct___92 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___92 *fa_next;
	struct file___92 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___92 {
	struct inode___92 * (*alloc_inode)(struct super_block___92 *);
	void (*destroy_inode)(struct inode___92 *);
	void (*free_inode)(struct inode___92 *);
	void (*dirty_inode)(struct inode___92 *, int);
	int (*write_inode)(struct inode___92 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___92 *);
	void (*evict_inode)(struct inode___92 *);
	void (*put_super)(struct super_block___92 *);
	int (*sync_fs)(struct super_block___92 *, int);
	int (*freeze_super)(struct super_block___92 *);
	int (*freeze_fs)(struct super_block___92 *);
	int (*thaw_super)(struct super_block___92 *);
	int (*unfreeze_fs)(struct super_block___92 *);
	int (*statfs)(struct dentry___92 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___92 *, int *, char *);
	void (*umount_begin)(struct super_block___92 *);
	int (*show_options)(struct seq_file___87 *, struct dentry___92 *);
	int (*show_devname)(struct seq_file___87 *, struct dentry___92 *);
	int (*show_path)(struct seq_file___87 *, struct dentry___92 *);
	int (*show_stats)(struct seq_file___87 *, struct dentry___92 *);
	ssize_t (*quota_read)(struct super_block___92 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___92 *, int, const char *, size_t, loff_t);
	struct dquot___92 ** (*get_dquots)(struct inode___92 *);
	long int (*nr_cached_objects)(struct super_block___92 *, struct shrink_control___39 *);
	long int (*free_cached_objects)(struct super_block___92 *, struct shrink_control___39 *);
	struct file___92 * (*real_loop)(struct file___92 *);
};

struct fscrypt_operations___3 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___92 *, void *, size_t);
	int (*set_context)(struct inode___92 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___92 *);
	bool (*empty_dir)(struct inode___92 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___92 *);
	void (*get_ino_and_lblk_bits)(struct super_block___92 *, int *, int *);
	int (*get_num_devices)(struct super_block___92 *);
	void (*get_devices)(struct super_block___92 *, struct request_queue___3 **);
};

typedef void (*poll_queue_proc___67)(struct file___92 *, wait_queue_head_t *, struct poll_table_struct___67 *);

struct poll_table_struct___67 {
	poll_queue_proc___67 _qproc;
	__poll_t _key;
};

struct seq_operations___87;

struct seq_file___87 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___87 *op;
	int poll_event;
	const struct file___92 *file;
	void *private;
};

struct mount___3;

struct mnt_namespace___3 {
	struct ns_common___13 ns;
	struct mount___3 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct seq_operations___87 {
	void * (*start)(struct seq_file___87 *, loff_t *);
	void (*stop)(struct seq_file___87 *, void *);
	void * (*next)(struct seq_file___87 *, void *, loff_t *);
	int (*show)(struct seq_file___87 *, void *);
};

struct mountpoint___3;

struct mount___3 {
	struct hlist_node mnt_hash;
	struct mount___3 *mnt_parent;
	struct dentry___92 *mnt_mountpoint;
	struct vfsmount___92 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___3 *mnt_master;
	struct mnt_namespace___3 *mnt_ns;
	struct mountpoint___3 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___3 {
	struct hlist_node m_hash;
	struct dentry___92 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct external_name {
	union {
		atomic_t count;
		struct callback_head head;
	} u;
	long: 64;
	long: 64;
	unsigned char name[0];
};

enum d_walk_ret {
	D_WALK_CONTINUE = 0,
	D_WALK_QUIT = 1,
	D_WALK_NORETRY = 2,
	D_WALK_SKIP = 3,
};

struct check_mount {
	struct vfsmount___92 *mnt;
	unsigned int mounted;
};

struct select_data {
	struct dentry___92 *start;
	union {
		long int found;
		struct dentry___92 *victim;
	};
	struct list_head dispose;
};

enum file_time_flags {
	S_ATIME = 1,
	S_MTIME = 2,
	S_CTIME = 4,
	S_VERSION = 8,
};

struct dentry___93;

struct super_block___93;

struct module___90;

struct file_system_type___93 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___93 * (*mount)(struct file_system_type___93 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___93 *);
	struct module___90 *owner;
	struct file_system_type___93 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___93;

struct kiocb___93;

struct vm_area_struct___98;

struct inode___93;

struct file_lock___93;

struct page___98;

struct file_operations___93 {
	struct module___90 *owner;
	loff_t (*llseek)(struct file___93 *, loff_t, int);
	ssize_t (*read)(struct file___93 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___93 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___93 *, struct iov_iter___56 *);
	ssize_t (*write_iter)(struct kiocb___93 *, struct iov_iter___56 *);
	int (*iopoll)(struct kiocb___93 *, bool);
	int (*iterate)(struct file___93 *, struct dir_context *);
	int (*iterate_shared)(struct file___93 *, struct dir_context *);
	__poll_t (*poll)(struct file___93 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___93 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___93 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___93 *, struct vm_area_struct___98 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___93 *, struct file___93 *);
	int (*flush)(struct file___93 *, fl_owner_t);
	int (*release)(struct inode___93 *, struct file___93 *);
	int (*fsync)(struct file___93 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___93 *, int);
	int (*lock)(struct file___93 *, int, struct file_lock___93 *);
	ssize_t (*sendpage)(struct file___93 *, struct page___98 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___93 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___93 *, long unsigned int);
	int (*flock)(struct file___93 *, int, struct file_lock___93 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___93 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___93 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___93 *, long int, struct file_lock___93 **, void **);
	long int (*fallocate)(struct file___93 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___93 *);
	ssize_t (*copy_file_range)(struct file___93 *, loff_t, struct file___93 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___93 *, loff_t, struct file___93 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___93 *, loff_t, loff_t, int);
};

struct vmacache___98 {
	u64 seqnum;
	struct vm_area_struct___98 *vmas[4];
};

struct page_frag___98 {
	struct page___98 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___99;

struct pid___85;

struct nsproxy___90;

struct signal_struct___94;

struct vm_struct___92;

struct task_struct___100 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___100 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___99 *mm;
	struct mm_struct___99 *active_mm;
	struct vmacache___98 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___100 *real_parent;
	struct task_struct___100 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___100 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___85 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___12 *ptracer_cred;
	const struct cred___12 *real_cred;
	const struct cred___12 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___90 *nsproxy;
	struct signal_struct___94 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___100 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___44 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___98 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___100 *oom_reaper_list;
	struct vm_struct___92 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___56 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___92;

struct kobj_type___92;

struct kernfs_node___92;

struct kobject___92 {
	const char *name;
	struct list_head entry;
	struct kobject___92 *parent;
	struct kset___92 *kset;
	struct kobj_type___92 *ktype;
	struct kernfs_node___92 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___89 {
	struct kobject___92 kobj;
	struct module___90 *mod;
	struct kobject___92 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___89 {
	struct module___90 *mod;
	struct latch_tree_node node;
};

struct module_layout___89 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___89 mtn;
};

struct module_attribute___89;

struct kernel_param___89;

struct module___90 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___89 mkobj;
	struct module_attribute___89 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___92 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___89 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___89 core_layout;
	struct module_layout___89 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___98 *pgtable_t___98;

struct address_space___93;

struct dev_pagemap___92;

struct page___98 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___93 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___98 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___98 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___99 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___92 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___92;

struct vm_area_struct___98 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___98 *vm_next;
	struct vm_area_struct___98 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___99 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___92 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___93 *vm_file;
	struct file___93 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___98;

struct mm_struct___99 {
	struct {
		struct vm_area_struct___98 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___93 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___98 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___100 *owner;
		struct user_namespace___13 *user_ns;
		struct file___93 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___93;

struct address_space___93 {
	struct inode___93 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___93 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___92;

struct dev_pagemap___92 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___92 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___93;

struct path___93 {
	struct vfsmount___93 *mnt;
	struct dentry___93 *dentry;
};

struct fown_struct___85 {
	rwlock_t lock;
	struct pid___85 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___93 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___93 f_path;
	struct inode___93 *f_inode;
	const struct file_operations___93 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___85 f_owner;
	const struct cred___12 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___93 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___92;

struct vm_operations_struct___92 {
	void (*open)(struct vm_area_struct___98 *);
	void (*close)(struct vm_area_struct___98 *);
	int (*may_split)(struct vm_area_struct___98 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___98 *);
	int (*mprotect)(struct vm_area_struct___98 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___92 *);
	vm_fault_t (*huge_fault)(struct vm_fault___92 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___92 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___98 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___92 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___92 *);
	int (*access)(struct vm_area_struct___98 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___98 *);
	int (*set_policy)(struct vm_area_struct___98 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___98 *, long unsigned int);
	struct page___98 * (*find_special_page)(struct vm_area_struct___98 *, long unsigned int);
};

struct core_thread___98 {
	struct task_struct___100 *task;
	struct core_thread___98 *next;
};

struct core_state___98 {
	atomic_t nr_threads;
	struct core_thread___98 dumper;
	struct completion startup;
};

struct vm_fault___92 {
	const struct {
		struct vm_area_struct___98 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___98 *cow_page;
	struct page___98 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___98 prealloc_pte;
};

struct dev_pagemap_ops___92 {
	void (*page_free)(struct page___98 *);
	void (*kill)(struct dev_pagemap___92 *);
	void (*cleanup)(struct dev_pagemap___92 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___92 *);
};

struct pid_namespace___85;

struct upid___85 {
	int nr;
	struct pid_namespace___85 *ns;
};

struct pid_namespace___85 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___100 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___85 *parent;
	struct fs_pin *bacct;
	struct user_namespace___13 *user_ns;
	struct ucounts___13 *ucounts;
	int reboot;
	struct ns_common___13 ns;
};

struct pid___85 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___85 numbers[1];
};

struct signal_struct___94 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___100 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___100 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___85 *pids[4];
	struct pid___85 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___99 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___90 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___85 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___92 {
	struct vm_struct___92 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___98 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___93;

struct dentry___93 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___93 *d_parent;
	struct qstr d_name;
	struct inode___93 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___93 *d_op;
	struct super_block___93 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___93;

struct inode___93 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___93 *i_op;
	struct super_block___93 *i_sb;
	struct address_space___93 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___93 *i_fop;
		void (*free_inode)(struct inode___93 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___93 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___93 {
	int (*d_revalidate)(struct dentry___93 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___93 *, unsigned int);
	int (*d_hash)(const struct dentry___93 *, struct qstr *);
	int (*d_compare)(const struct dentry___93 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___93 *);
	int (*d_init)(struct dentry___93 *);
	void (*d_release)(struct dentry___93 *);
	void (*d_prune)(struct dentry___93 *);
	void (*d_iput)(struct dentry___93 *, struct inode___93 *);
	char * (*d_dname)(struct dentry___93 *, char *, int);
	struct vfsmount___93 * (*d_automount)(struct path___93 *);
	int (*d_manage)(const struct path___93 *, bool);
	struct dentry___93 * (*d_real)(struct dentry___93 *, const struct inode___93 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___93;

struct mem_dqinfo___93 {
	struct quota_format_type___93 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___93;

struct quota_info___93 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___93 *files[3];
	struct mem_dqinfo___93 info[3];
	const struct quota_format_ops___93 *ops[3];
};

struct rcuwait___94 {
	struct task_struct___100 *task;
};

struct percpu_rw_semaphore___94 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___94 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___93 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___94 rw_sem[3];
};

struct super_operations___93;

struct dquot_operations___93;

struct quotactl_ops___93;

struct xattr_handler___8;

struct super_block___93 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___93 *s_type;
	const struct super_operations___93 *s_op;
	const struct dquot_operations___93 *dq_op;
	const struct quotactl_ops___93 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___93 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___8 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___93 s_dquot;
	struct sb_writers___93 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___93 *s_d_op;
	int cleancache_poolid;
	struct shrinker___39 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___13 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___93 {
	struct dentry___93 *mnt_root;
	struct super_block___93 *mnt_sb;
	int mnt_flags;
	struct user_namespace___13 *mnt_userns;
};

struct kiocb___93 {
	struct file___93 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___93 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___46 *ki_waitq;
	};
};

struct iattr___93 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___93 *ia_file;
};

struct dquot___93 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___93 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___93 {
	int qf_fmt_id;
	const struct quota_format_ops___93 *qf_ops;
	struct module___90 *qf_owner;
	struct quota_format_type___93 *qf_next;
};

struct quota_format_ops___93 {
	int (*check_quota_file)(struct super_block___93 *, int);
	int (*read_file_info)(struct super_block___93 *, int);
	int (*write_file_info)(struct super_block___93 *, int);
	int (*free_file_info)(struct super_block___93 *, int);
	int (*read_dqblk)(struct dquot___93 *);
	int (*commit_dqblk)(struct dquot___93 *);
	int (*release_dqblk)(struct dquot___93 *);
	int (*get_next_id)(struct super_block___93 *, struct kqid *);
};

struct dquot_operations___93 {
	int (*write_dquot)(struct dquot___93 *);
	struct dquot___93 * (*alloc_dquot)(struct super_block___93 *, int);
	void (*destroy_dquot)(struct dquot___93 *);
	int (*acquire_dquot)(struct dquot___93 *);
	int (*release_dquot)(struct dquot___93 *);
	int (*mark_dirty)(struct dquot___93 *);
	int (*write_info)(struct super_block___93 *, int);
	qsize_t * (*get_reserved_space)(struct inode___93 *);
	int (*get_projid)(struct inode___93 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___93 *, qsize_t *);
	int (*get_next_id)(struct super_block___93 *, struct kqid *);
};

struct quotactl_ops___93 {
	int (*quota_on)(struct super_block___93 *, int, int, const struct path___93 *);
	int (*quota_off)(struct super_block___93 *, int);
	int (*quota_enable)(struct super_block___93 *, unsigned int);
	int (*quota_disable)(struct super_block___93 *, unsigned int);
	int (*quota_sync)(struct super_block___93 *, int);
	int (*set_info)(struct super_block___93 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___93 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___93 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___93 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___93 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___93 *, unsigned int);
};

struct address_space_operations___93 {
	int (*writepage)(struct page___98 *, struct writeback_control___3 *);
	int (*readpage)(struct file___93 *, struct page___98 *);
	int (*writepages)(struct address_space___93 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___98 *);
	int (*readpages)(struct file___93 *, struct address_space___93 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___93 *, struct address_space___93 *, loff_t, unsigned int, unsigned int, struct page___98 **, void **);
	int (*write_end)(struct file___93 *, struct address_space___93 *, loff_t, unsigned int, unsigned int, struct page___98 *, void *);
	sector_t (*bmap)(struct address_space___93 *, sector_t);
	void (*invalidatepage)(struct page___98 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___98 *, gfp_t);
	void (*freepage)(struct page___98 *);
	ssize_t (*direct_IO)(struct kiocb___93 *, struct iov_iter___56 *);
	int (*migratepage)(struct address_space___93 *, struct page___98 *, struct page___98 *, enum migrate_mode);
	bool (*isolate_page)(struct page___98 *, isolate_mode_t);
	void (*putback_page)(struct page___98 *);
	int (*launder_page)(struct page___98 *);
	int (*is_partially_uptodate)(struct page___98 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___98 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___93 *, struct page___98 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___93 *, sector_t *);
	void (*swap_deactivate)(struct file___93 *);
};

struct inode_operations___93 {
	struct dentry___93 * (*lookup)(struct inode___93 *, struct dentry___93 *, unsigned int);
	const char * (*get_link)(struct dentry___93 *, struct inode___93 *, struct delayed_call *);
	int (*permission)(struct user_namespace___13 *, struct inode___93 *, int);
	struct posix_acl * (*get_acl)(struct inode___93 *, int, bool);
	int (*readlink)(struct dentry___93 *, char *, int);
	int (*create)(struct user_namespace___13 *, struct inode___93 *, struct dentry___93 *, umode_t, bool);
	int (*link)(struct dentry___93 *, struct inode___93 *, struct dentry___93 *);
	int (*unlink)(struct inode___93 *, struct dentry___93 *);
	int (*symlink)(struct user_namespace___13 *, struct inode___93 *, struct dentry___93 *, const char *);
	int (*mkdir)(struct user_namespace___13 *, struct inode___93 *, struct dentry___93 *, umode_t);
	int (*rmdir)(struct inode___93 *, struct dentry___93 *);
	int (*mknod)(struct user_namespace___13 *, struct inode___93 *, struct dentry___93 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___13 *, struct inode___93 *, struct dentry___93 *, struct inode___93 *, struct dentry___93 *, unsigned int);
	int (*setattr)(struct user_namespace___13 *, struct dentry___93 *, struct iattr___93 *);
	int (*getattr)(struct user_namespace___13 *, const struct path___93 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___93 *, char *, size_t);
	int (*fiemap)(struct inode___93 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___93 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___93 *, struct dentry___93 *, struct file___93 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___13 *, struct inode___93 *, struct dentry___93 *, umode_t);
	int (*set_acl)(struct user_namespace___13 *, struct inode___93 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___13 *, struct dentry___93 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___93 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___93 {
	void (*fl_copy_lock)(struct file_lock___93 *, struct file_lock___93 *);
	void (*fl_release_private)(struct file_lock___93 *);
};

struct fasync_struct___93;

struct lock_manager_operations___93;

struct file_lock___93 {
	struct file_lock___93 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___93 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___93 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___93 *fl_ops;
	const struct lock_manager_operations___93 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___93 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___93 *);
	int (*lm_grant)(struct file_lock___93 *, int);
	bool (*lm_break)(struct file_lock___93 *);
	int (*lm_change)(struct file_lock___93 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___93 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___93 *);
};

struct fasync_struct___93 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___93 *fa_next;
	struct file___93 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___93 {
	struct inode___93 * (*alloc_inode)(struct super_block___93 *);
	void (*destroy_inode)(struct inode___93 *);
	void (*free_inode)(struct inode___93 *);
	void (*dirty_inode)(struct inode___93 *, int);
	int (*write_inode)(struct inode___93 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___93 *);
	void (*evict_inode)(struct inode___93 *);
	void (*put_super)(struct super_block___93 *);
	int (*sync_fs)(struct super_block___93 *, int);
	int (*freeze_super)(struct super_block___93 *);
	int (*freeze_fs)(struct super_block___93 *);
	int (*thaw_super)(struct super_block___93 *);
	int (*unfreeze_fs)(struct super_block___93 *);
	int (*statfs)(struct dentry___93 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___93 *, int *, char *);
	void (*umount_begin)(struct super_block___93 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___93 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___93 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___93 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___93 *);
	ssize_t (*quota_read)(struct super_block___93 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___93 *, int, const char *, size_t, loff_t);
	struct dquot___93 ** (*get_dquots)(struct inode___93 *);
	long int (*nr_cached_objects)(struct super_block___93 *, struct shrink_control___39 *);
	long int (*free_cached_objects)(struct super_block___93 *, struct shrink_control___39 *);
	struct file___93 * (*real_loop)(struct file___93 *);
};

struct xattr_handler___8 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___93 *);
	int (*get)(const struct xattr_handler___8 *, struct dentry___93 *, struct inode___93 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___8 *, struct user_namespace___13 *, struct dentry___93 *, struct inode___93 *, const char *, const void *, size_t, int);
};

struct kernfs_root___92;

struct kernfs_elem_dir___92 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___92 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___92;

struct kernfs_root___92 {
	struct kernfs_node___92 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___92 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___92 {
	struct kernfs_node___92 *target_kn;
};

struct kernfs_ops___92;

struct kernfs_elem_attr___92 {
	const struct kernfs_ops___92 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___92 *notify_next;
};

struct kernfs_node___92 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___92 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___92 dir;
		struct kernfs_elem_symlink___92 symlink;
		struct kernfs_elem_attr___92 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___92;

struct kernfs_ops___92 {
	int (*open)(struct kernfs_open_file___92 *);
	void (*release)(struct kernfs_open_file___92 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___92 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___92 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___92 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___92 *, struct vm_area_struct___98 *);
};

struct kernfs_syscall_ops___92 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___92 *);
	int (*mkdir)(struct kernfs_node___92 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___92 *);
	int (*rename)(struct kernfs_node___92 *, struct kernfs_node___92 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___92 *, struct kernfs_root___92 *);
};

struct kernfs_open_file___92 {
	struct kernfs_node___92 *kn;
	struct file___93 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___92 *vm_ops;
};

struct bin_attribute___92;

struct attribute_group___92 {
	const char *name;
	umode_t (*is_visible)(struct kobject___92 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___92 *, struct bin_attribute___92 *, int);
	struct attribute **attrs;
	struct bin_attribute___92 **bin_attrs;
};

struct bin_attribute___92 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___93 * (*f_mapping)();
	ssize_t (*read)(struct file___93 *, struct kobject___92 *, struct bin_attribute___92 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___93 *, struct kobject___92 *, struct bin_attribute___92 *, char *, loff_t, size_t);
	int (*mmap)(struct file___93 *, struct kobject___92 *, struct bin_attribute___92 *, struct vm_area_struct___98 *);
};

struct sysfs_ops___92 {
	ssize_t (*show)(struct kobject___92 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___92 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___92;

struct kset___92 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___92 kobj;
	const struct kset_uevent_ops___92 *uevent_ops;
};

struct kobj_type___92 {
	void (*release)(struct kobject___92 *);
	const struct sysfs_ops___92 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___92 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___92 *);
	const void * (*namespace)(struct kobject___92 *);
	void (*get_ownership)(struct kobject___92 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___92 {
	int (* const filter)(struct kset___92 *, struct kobject___92 *);
	const char * (* const name)(struct kset___92 *, struct kobject___92 *);
	int (* const uevent)(struct kset___92 *, struct kobject___92 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___89 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___89 *);
	int (*get)(char *, const struct kernel_param___89 *);
	void (*free)(void *);
};

struct kparam_array___89;

struct kernel_param___89 {
	const char *name;
	struct module___90 *mod;
	const struct kernel_param_ops___89 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___89 *arr;
	};
};

struct kparam_array___89 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___89 *ops;
	void *elem;
};

struct module_attribute___89 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___89 *, struct module_kobject___89 *, char *);
	ssize_t (*store)(struct module_attribute___89 *, struct module_kobject___89 *, const char *, size_t);
	void (*setup)(struct module___90 *, const char *);
	int (*test)(struct module___90 *);
	void (*free)(struct module___90 *);
};

struct fs_context___16;

struct fs_parameter_spec___13;

struct dentry___94;

struct super_block___94;

struct module___91;

struct file_system_type___94 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___16 *);
	const struct fs_parameter_spec___13 *parameters;
	struct dentry___94 * (*mount)(struct file_system_type___94 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___94 *);
	struct module___91 *owner;
	struct file_system_type___94 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___94;

struct kiocb___94;

struct iov_iter___57;

struct poll_table_struct___68;

struct vm_area_struct___99;

struct inode___94;

struct file_lock___94;

struct page___99;

struct seq_file___88;

struct file_operations___94 {
	struct module___91 *owner;
	loff_t (*llseek)(struct file___94 *, loff_t, int);
	ssize_t (*read)(struct file___94 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___94 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___94 *, struct iov_iter___57 *);
	ssize_t (*write_iter)(struct kiocb___94 *, struct iov_iter___57 *);
	int (*iopoll)(struct kiocb___94 *, bool);
	int (*iterate)(struct file___94 *, struct dir_context *);
	int (*iterate_shared)(struct file___94 *, struct dir_context *);
	__poll_t (*poll)(struct file___94 *, struct poll_table_struct___68 *);
	long int (*unlocked_ioctl)(struct file___94 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___94 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___94 *, struct vm_area_struct___99 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___94 *, struct file___94 *);
	int (*flush)(struct file___94 *, fl_owner_t);
	int (*release)(struct inode___94 *, struct file___94 *);
	int (*fsync)(struct file___94 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___94 *, int);
	int (*lock)(struct file___94 *, int, struct file_lock___94 *);
	ssize_t (*sendpage)(struct file___94 *, struct page___99 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___94 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___94 *, long unsigned int);
	int (*flock)(struct file___94 *, int, struct file_lock___94 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___94 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___94 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___94 *, long int, struct file_lock___94 **, void **);
	long int (*fallocate)(struct file___94 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___88 *, struct file___94 *);
	ssize_t (*copy_file_range)(struct file___94 *, loff_t, struct file___94 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___94 *, loff_t, struct file___94 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___94 *, loff_t, loff_t, int);
};

struct vmacache___99 {
	u64 seqnum;
	struct vm_area_struct___99 *vmas[4];
};

struct page_frag___99 {
	struct page___99 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___57;

struct debug_info___57 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___57 *hbp_break[16];
	struct perf_event___57 *hbp_watch[16];
};

struct thread_struct___57 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___57 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___100;

struct pid___86;

struct cred___13;

struct fs_struct___12;

struct nsproxy___91;

struct signal_struct___95;

struct bio_list___45;

struct backing_dev_info___44;

struct io_context___45;

struct css_set___77;

struct perf_event_context___57;

struct mem_cgroup___40;

struct request_queue___45;

struct vm_struct___93;

struct task_struct___101 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___101 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___100 *mm;
	struct mm_struct___100 *active_mm;
	struct vmacache___99 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___101 *real_parent;
	struct task_struct___101 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___101 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___86 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___12 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___91 *nsproxy;
	struct signal_struct___95 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___101 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___45 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___44 *backing_dev_info;
	struct io_context___45 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___77 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___57 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___99 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___40 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___40 *active_memcg;
	struct request_queue___45 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___101 *oom_reaper_list;
	struct vm_struct___93 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___57 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___93;

struct kobj_type___93;

struct kernfs_node___93;

struct kobject___93 {
	const char *name;
	struct list_head entry;
	struct kobject___93 *parent;
	struct kset___93 *kset;
	struct kobj_type___93 *ktype;
	struct kernfs_node___93 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___90 {
	struct kobject___93 kobj;
	struct module___91 *mod;
	struct kobject___93 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___90 {
	struct module___91 *mod;
	struct latch_tree_node node;
};

struct module_layout___90 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___90 mtn;
};

struct module_attribute___90;

struct kernel_param___90;

struct trace_event_call___51;

struct module___91 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___90 mkobj;
	struct module_attribute___90 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___93 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___90 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___90 core_layout;
	struct module_layout___90 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___51 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___57 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___101 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___57)(struct perf_event___57 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___57;

struct fasync_struct___94;

struct pid_namespace___86;

struct perf_cgroup___57;

struct perf_event___57 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___57 *group_leader;
	struct pmu___57 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___57 hw;
	struct perf_event_context___57 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___57 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___101 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___94 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___57 *aux_event;
	void (*destroy)(struct perf_event___57 *);
	struct callback_head callback_head;
	struct pid_namespace___86 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___57 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___57 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___51 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___57 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___94;

struct dentry___94 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___94 *d_parent;
	struct qstr d_name;
	struct inode___94 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___94 *d_op;
	struct super_block___94 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___94;

struct address_space___94 {
	struct inode___94 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___94 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___94;

struct bdi_writeback___44;

struct inode___94 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___94 *i_op;
	struct super_block___94 *i_sb;
	struct address_space___94 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___44 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___94 *i_fop;
		void (*free_inode)(struct inode___94 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___94 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___94;

struct path___94;

struct dentry_operations___94 {
	int (*d_revalidate)(struct dentry___94 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___94 *, unsigned int);
	int (*d_hash)(const struct dentry___94 *, struct qstr *);
	int (*d_compare)(const struct dentry___94 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___94 *);
	int (*d_init)(struct dentry___94 *);
	void (*d_release)(struct dentry___94 *);
	void (*d_prune)(struct dentry___94 *);
	void (*d_iput)(struct dentry___94 *, struct inode___94 *);
	char * (*d_dname)(struct dentry___94 *, char *, int);
	struct vfsmount___94 * (*d_automount)(struct path___94 *);
	int (*d_manage)(const struct path___94 *, bool);
	struct dentry___94 * (*d_real)(struct dentry___94 *, const struct inode___94 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___94;

struct mem_dqinfo___94 {
	struct quota_format_type___94 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___94;

struct quota_info___94 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___94 *files[3];
	struct mem_dqinfo___94 info[3];
	const struct quota_format_ops___94 *ops[3];
};

struct rcuwait___95 {
	struct task_struct___101 *task;
};

struct percpu_rw_semaphore___95 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___95 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___94 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___95 rw_sem[3];
};

struct shrink_control___40;

struct shrinker___40 {
	long unsigned int (*count_objects)(struct shrinker___40 *, struct shrink_control___40 *);
	long unsigned int (*scan_objects)(struct shrinker___40 *, struct shrink_control___40 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___94;

struct dquot_operations___94;

struct quotactl_ops___94;

struct xattr_handler___9;

struct block_device___46;

struct user_namespace___14;

struct super_block___94 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___94 *s_type;
	const struct super_operations___94 *s_op;
	const struct dquot_operations___94 *dq_op;
	const struct quotactl_ops___94 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___94 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___9 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___46 *s_bdev;
	struct backing_dev_info___44 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___94 s_dquot;
	struct sb_writers___94 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___94 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___94 {
	struct dentry___94 *mnt_root;
	struct super_block___94 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___94 {
	struct vfsmount___94 *mnt;
	struct dentry___94 *dentry;
};

struct upid___86 {
	int nr;
	struct pid_namespace___86 *ns;
};

struct proc_ns_operations___14;

struct ns_common___14 {
	atomic_long_t stashed;
	const struct proc_ns_operations___14 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___14;

struct pid_namespace___86 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___101 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___86 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___86 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___86 numbers[1];
};

struct user_namespace___14 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___14 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___14 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___2 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___2 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___14 *ucounts;
	long int ucount_max[16];
};

typedef struct page___99 *pgtable_t___99;

struct dev_pagemap___93;

struct page___99 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___94 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___99 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___99 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___100 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___93 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___14 {
	struct hlist_node node;
	struct user_namespace___14 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___93;

struct vm_area_struct___99 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___99 *vm_next;
	struct vm_area_struct___99 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___100 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___93 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___94 *vm_file;
	struct file___94 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___95 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___101 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___101 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___86 *pids[4];
	struct pid___86 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___100 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___99;

struct mm_struct___100 {
	struct {
		struct vm_area_struct___99 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___94 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___99 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___101 *owner;
		struct user_namespace___14 *user_ns;
		struct file___94 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___13 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___2 *session_keyring;
	struct key___2 *process_keyring;
	struct key___2 *thread_keyring;
	struct key___2 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct fs_struct___12 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___94 root;
	struct path___94 pwd;
};

struct mnt_namespace___4;

struct cgroup_namespace___77;

struct nsproxy___91 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___4 *mnt_ns;
	struct pid_namespace___86 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___77 *cgroup_ns;
};

struct bio___45;

struct bio_list___45 {
	struct bio___45 *head;
	struct bio___45 *tail;
};

struct cgroup_subsys_state___77;

struct bdi_writeback___44 {
	struct backing_dev_info___44 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___77 *memcg_css;
	struct cgroup_subsys_state___77 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___78;

struct backing_dev_info___44 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___44 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___78 *dev;
	char dev_name[64];
	struct device___78 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___94 *debug_dir;
};

struct io_cq___45;

struct io_context___45 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___45 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___77;

struct css_set___77 {
	struct cgroup_subsys_state___77 *subsys[14];
	refcount_t refcount;
	struct css_set___77 *dom_cset;
	struct cgroup___77 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___77 *mg_src_cgrp;
	struct cgroup___77 *mg_dst_cgrp;
	struct css_set___77 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___57 {
	struct pmu___57 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___101 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___57 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___77;

struct cgroup_subsys_state___77 {
	struct cgroup___77 *cgroup;
	struct cgroup_subsys___77 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___77 *parent;
};

struct cgroup_file___77 {
	struct kernfs_node___93 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___40;

struct mem_cgroup_per_node___40;

struct mem_cgroup___40 {
	struct cgroup_subsys_state___77 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___77 events_file;
	struct cgroup_file___77 events_local_file;
	struct cgroup_file___77 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___40 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___101 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___40 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___45;

struct blk_integrity___45 {
	const struct blk_integrity_profile___45 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___45 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___45 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___45;

struct elevator_queue___45;

struct blk_mq_ops___44;

struct blk_mq_hw_ctx___44;

struct gendisk___45;

struct blkcg_gq___44;

struct blk_mq_tag_set___44;

struct request_queue___45 {
	struct request___45 *last_merge;
	struct elevator_queue___45 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___44 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___44 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___45 *disk;
	struct kobject___93 kobj;
	struct kobject___93 *mq_kobj;
	struct blk_integrity___45 integrity;
	struct device___78 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___44 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___44 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___45 bio_split;
	struct dentry___94 *debugfs_dir;
	struct dentry___94 *sched_debugfs_dir;
	struct dentry___94 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___93 {
	struct vm_struct___93 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___99 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___40 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___40 *memcg;
};

struct dev_pagemap_ops___93;

struct dev_pagemap___93 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___93 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___86 {
	rwlock_t lock;
	struct pid___86 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___94 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___94 f_path;
	struct inode___94 *f_inode;
	const struct file_operations___94 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___86 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___94 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___93;

struct vm_operations_struct___93 {
	void (*open)(struct vm_area_struct___99 *);
	void (*close)(struct vm_area_struct___99 *);
	int (*may_split)(struct vm_area_struct___99 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___99 *);
	int (*mprotect)(struct vm_area_struct___99 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___93 *);
	vm_fault_t (*huge_fault)(struct vm_fault___93 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___93 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___99 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___93 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___93 *);
	int (*access)(struct vm_area_struct___99 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___99 *);
	int (*set_policy)(struct vm_area_struct___99 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___99 *, long unsigned int);
	struct page___99 * (*find_special_page)(struct vm_area_struct___99 *, long unsigned int);
};

struct core_thread___99 {
	struct task_struct___101 *task;
	struct core_thread___99 *next;
};

struct core_state___99 {
	atomic_t nr_threads;
	struct core_thread___99 dumper;
	struct completion startup;
};

struct vm_fault___93 {
	const struct {
		struct vm_area_struct___99 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___99 *cow_page;
	struct page___99 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___99 prealloc_pte;
};

struct pglist_data___46;

struct lruvec___46 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___46 *pgdat;
};

struct zone___46 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___46 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___46 {
	struct zone___46 *zone;
	int zone_idx;
};

struct zonelist___46 {
	struct zoneref___46 _zonerefs[321];
};

struct pglist_data___46 {
	struct zone___46 node_zones[5];
	struct zonelist___46 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___101 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___101 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___46 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___77 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___101 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___77;

struct cgroup_rstat_cpu___77;

struct cgroup___77 {
	struct cgroup_subsys_state___77 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___93 *kn;
	struct cgroup_file___77 procs_file;
	struct cgroup_file___77 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___77 *subsys[14];
	struct cgroup_root___77 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___77 *dom_cgrp;
	struct cgroup___77 *old_dom_cgrp;
	struct cgroup_rstat_cpu___77 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___77 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___45 {
	struct request_queue___45 *q;
	struct io_context___45 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___47;

struct kiocb___94 {
	struct file___94 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___94 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___47 *ki_waitq;
	};
};

struct iattr___94 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___94 *ia_file;
};

struct dquot___94 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___94 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___94 {
	int qf_fmt_id;
	const struct quota_format_ops___94 *qf_ops;
	struct module___91 *qf_owner;
	struct quota_format_type___94 *qf_next;
};

struct quota_format_ops___94 {
	int (*check_quota_file)(struct super_block___94 *, int);
	int (*read_file_info)(struct super_block___94 *, int);
	int (*write_file_info)(struct super_block___94 *, int);
	int (*free_file_info)(struct super_block___94 *, int);
	int (*read_dqblk)(struct dquot___94 *);
	int (*commit_dqblk)(struct dquot___94 *);
	int (*release_dqblk)(struct dquot___94 *);
	int (*get_next_id)(struct super_block___94 *, struct kqid *);
};

struct dquot_operations___94 {
	int (*write_dquot)(struct dquot___94 *);
	struct dquot___94 * (*alloc_dquot)(struct super_block___94 *, int);
	void (*destroy_dquot)(struct dquot___94 *);
	int (*acquire_dquot)(struct dquot___94 *);
	int (*release_dquot)(struct dquot___94 *);
	int (*mark_dirty)(struct dquot___94 *);
	int (*write_info)(struct super_block___94 *, int);
	qsize_t * (*get_reserved_space)(struct inode___94 *);
	int (*get_projid)(struct inode___94 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___94 *, qsize_t *);
	int (*get_next_id)(struct super_block___94 *, struct kqid *);
};

struct quotactl_ops___94 {
	int (*quota_on)(struct super_block___94 *, int, int, const struct path___94 *);
	int (*quota_off)(struct super_block___94 *, int);
	int (*quota_enable)(struct super_block___94 *, unsigned int);
	int (*quota_disable)(struct super_block___94 *, unsigned int);
	int (*quota_sync)(struct super_block___94 *, int);
	int (*set_info)(struct super_block___94 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___94 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___94 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___94 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___94 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___94 *, unsigned int);
};

struct wait_page_queue___47 {
	struct page___99 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___44;

struct readahead_control___47;

struct swap_info_struct___25;

struct address_space_operations___94 {
	int (*writepage)(struct page___99 *, struct writeback_control___44 *);
	int (*readpage)(struct file___94 *, struct page___99 *);
	int (*writepages)(struct address_space___94 *, struct writeback_control___44 *);
	int (*set_page_dirty)(struct page___99 *);
	int (*readpages)(struct file___94 *, struct address_space___94 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___47 *);
	int (*write_begin)(struct file___94 *, struct address_space___94 *, loff_t, unsigned int, unsigned int, struct page___99 **, void **);
	int (*write_end)(struct file___94 *, struct address_space___94 *, loff_t, unsigned int, unsigned int, struct page___99 *, void *);
	sector_t (*bmap)(struct address_space___94 *, sector_t);
	void (*invalidatepage)(struct page___99 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___99 *, gfp_t);
	void (*freepage)(struct page___99 *);
	ssize_t (*direct_IO)(struct kiocb___94 *, struct iov_iter___57 *);
	int (*migratepage)(struct address_space___94 *, struct page___99 *, struct page___99 *, enum migrate_mode);
	bool (*isolate_page)(struct page___99 *, isolate_mode_t);
	void (*putback_page)(struct page___99 *);
	int (*launder_page)(struct page___99 *);
	int (*is_partially_uptodate)(struct page___99 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___99 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___94 *, struct page___99 *);
	int (*swap_activate)(struct swap_info_struct___25 *, struct file___94 *, sector_t *);
	void (*swap_deactivate)(struct file___94 *);
};

struct writeback_control___44 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___44 *wb;
	struct inode___94 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___47 {
	struct file___94 *file;
	struct address_space___94 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___55;

struct iov_iter___57 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___55 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___25 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___46 *bdev;
	struct file___94 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___94 {
	struct dentry___94 * (*lookup)(struct inode___94 *, struct dentry___94 *, unsigned int);
	const char * (*get_link)(struct dentry___94 *, struct inode___94 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___94 *, int);
	struct posix_acl * (*get_acl)(struct inode___94 *, int, bool);
	int (*readlink)(struct dentry___94 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___94 *, struct dentry___94 *, umode_t, bool);
	int (*link)(struct dentry___94 *, struct inode___94 *, struct dentry___94 *);
	int (*unlink)(struct inode___94 *, struct dentry___94 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___94 *, struct dentry___94 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___94 *, struct dentry___94 *, umode_t);
	int (*rmdir)(struct inode___94 *, struct dentry___94 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___94 *, struct dentry___94 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___94 *, struct dentry___94 *, struct inode___94 *, struct dentry___94 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___94 *, struct iattr___94 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___94 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___94 *, char *, size_t);
	int (*fiemap)(struct inode___94 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___94 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___94 *, struct dentry___94 *, struct file___94 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___94 *, struct dentry___94 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___94 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___94 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___94 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___94 {
	void (*fl_copy_lock)(struct file_lock___94 *, struct file_lock___94 *);
	void (*fl_release_private)(struct file_lock___94 *);
};

struct lock_manager_operations___94;

struct file_lock___94 {
	struct file_lock___94 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___94 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___94 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___94 *fl_ops;
	const struct lock_manager_operations___94 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___94 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___94 *);
	int (*lm_grant)(struct file_lock___94 *, int);
	bool (*lm_break)(struct file_lock___94 *);
	int (*lm_change)(struct file_lock___94 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___94 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___94 *);
};

struct fasync_struct___94 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___94 *fa_next;
	struct file___94 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___94 {
	struct inode___94 * (*alloc_inode)(struct super_block___94 *);
	void (*destroy_inode)(struct inode___94 *);
	void (*free_inode)(struct inode___94 *);
	void (*dirty_inode)(struct inode___94 *, int);
	int (*write_inode)(struct inode___94 *, struct writeback_control___44 *);
	int (*drop_inode)(struct inode___94 *);
	void (*evict_inode)(struct inode___94 *);
	void (*put_super)(struct super_block___94 *);
	int (*sync_fs)(struct super_block___94 *, int);
	int (*freeze_super)(struct super_block___94 *);
	int (*freeze_fs)(struct super_block___94 *);
	int (*thaw_super)(struct super_block___94 *);
	int (*unfreeze_fs)(struct super_block___94 *);
	int (*statfs)(struct dentry___94 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___94 *, int *, char *);
	void (*umount_begin)(struct super_block___94 *);
	int (*show_options)(struct seq_file___88 *, struct dentry___94 *);
	int (*show_devname)(struct seq_file___88 *, struct dentry___94 *);
	int (*show_path)(struct seq_file___88 *, struct dentry___94 *);
	int (*show_stats)(struct seq_file___88 *, struct dentry___94 *);
	ssize_t (*quota_read)(struct super_block___94 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___94 *, int, const char *, size_t, loff_t);
	struct dquot___94 ** (*get_dquots)(struct inode___94 *);
	long int (*nr_cached_objects)(struct super_block___94 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___94 *, struct shrink_control___40 *);
	struct file___94 * (*real_loop)(struct file___94 *);
};

struct xattr_handler___9 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___94 *);
	int (*get)(const struct xattr_handler___9 *, struct dentry___94 *, struct inode___94 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___9 *, struct user_namespace___14 *, struct dentry___94 *, struct inode___94 *, const char *, const void *, size_t, int);
};

struct wakeup_source___78;

struct dev_pm_info___78 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___78 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___78 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___78;

struct bus_type___78;

struct device_driver___78;

struct dev_pm_domain___78;

struct fwnode_handle___78;

struct class___78;

struct attribute_group___93;

struct device___78 {
	struct kobject___93 kobj;
	struct device___78 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___78 *type;
	struct bus_type___78 *bus;
	struct device_driver___78 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___78 power;
	struct dev_pm_domain___78 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___78 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___78 *class;
	const struct attribute_group___93 **groups;
	void (*release)(struct device___78 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___46 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___94 *bd_inode;
	struct super_block___94 *bd_super;
	void *bd_claiming;
	struct device___78 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___93 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___45 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___94 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___68)(struct file___94 *, wait_queue_head_t *, struct poll_table_struct___68 *);

struct poll_table_struct___68 {
	poll_queue_proc___68 _qproc;
	__poll_t _key;
};

struct seq_operations___88;

struct seq_file___88 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___88 *op;
	int poll_event;
	const struct file___94 *file;
	void *private;
};

struct fc_log___16;

struct p_log___16 {
	const char *prefix;
	struct fc_log___16 *log;
};

struct fs_context_operations___16;

struct fs_context___16 {
	const struct fs_context_operations___16 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___94 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___94 *root;
	struct user_namespace___14 *user_ns;
	struct net *net_ns;
	const struct cred___13 *cred;
	struct p_log___16 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___16;

typedef int fs_param_type___13(struct p_log___16 *, const struct fs_parameter_spec___13 *, struct fs_parameter___16 *, struct fs_parse_result *);

struct fs_parameter_spec___13 {
	const char *name;
	fs_param_type___13 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___45(struct bio___45 *);

struct bio_vec___55 {
	struct page___99 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___45;

struct bio___45 {
	struct bio___45 *bi_next;
	struct block_device___46 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___45 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___44 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___45 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___55 *bi_io_vec;
	struct bio_set___45 *bi_pool;
	struct bio_vec___55 bi_inline_vecs[0];
};

struct kernfs_root___93;

struct kernfs_elem_dir___93 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___93 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___93;

struct kernfs_root___93 {
	struct kernfs_node___93 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___93 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___93 {
	struct kernfs_node___93 *target_kn;
};

struct kernfs_ops___93;

struct kernfs_elem_attr___93 {
	const struct kernfs_ops___93 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___93 *notify_next;
};

struct kernfs_node___93 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___93 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___93 dir;
		struct kernfs_elem_symlink___93 symlink;
		struct kernfs_elem_attr___93 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___93;

struct kernfs_ops___93 {
	int (*open)(struct kernfs_open_file___93 *);
	void (*release)(struct kernfs_open_file___93 *);
	int (*seq_show)(struct seq_file___88 *, void *);
	void * (*seq_start)(struct seq_file___88 *, loff_t *);
	void * (*seq_next)(struct seq_file___88 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___88 *, void *);
	ssize_t (*read)(struct kernfs_open_file___93 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___93 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___93 *, struct poll_table_struct___68 *);
	int (*mmap)(struct kernfs_open_file___93 *, struct vm_area_struct___99 *);
};

struct kernfs_syscall_ops___93 {
	int (*show_options)(struct seq_file___88 *, struct kernfs_root___93 *);
	int (*mkdir)(struct kernfs_node___93 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___93 *);
	int (*rename)(struct kernfs_node___93 *, struct kernfs_node___93 *, const char *);
	int (*show_path)(struct seq_file___88 *, struct kernfs_node___93 *, struct kernfs_root___93 *);
};

struct kernfs_open_file___93 {
	struct kernfs_node___93 *kn;
	struct file___94 *file;
	struct seq_file___88 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___93 *vm_ops;
};

struct bin_attribute___93;

struct attribute_group___93 {
	const char *name;
	umode_t (*is_visible)(struct kobject___93 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___93 *, struct bin_attribute___93 *, int);
	struct attribute **attrs;
	struct bin_attribute___93 **bin_attrs;
};

struct bin_attribute___93 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___94 * (*f_mapping)();
	ssize_t (*read)(struct file___94 *, struct kobject___93 *, struct bin_attribute___93 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___94 *, struct kobject___93 *, struct bin_attribute___93 *, char *, loff_t, size_t);
	int (*mmap)(struct file___94 *, struct kobject___93 *, struct bin_attribute___93 *, struct vm_area_struct___99 *);
};

struct sysfs_ops___93 {
	ssize_t (*show)(struct kobject___93 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___93 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___93;

struct kset___93 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___93 kobj;
	const struct kset_uevent_ops___93 *uevent_ops;
};

struct kobj_type___93 {
	void (*release)(struct kobject___93 *);
	const struct sysfs_ops___93 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___93 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___93 *);
	const void * (*namespace)(struct kobject___93 *);
	void (*get_ownership)(struct kobject___93 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___93 {
	int (* const filter)(struct kset___93 *, struct kobject___93 *);
	const char * (* const name)(struct kset___93 *, struct kobject___93 *);
	int (* const uevent)(struct kset___93 *, struct kobject___93 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___78 {
	int (*prepare)(struct device___78 *);
	void (*complete)(struct device___78 *);
	int (*suspend)(struct device___78 *);
	int (*resume)(struct device___78 *);
	int (*freeze)(struct device___78 *);
	int (*thaw)(struct device___78 *);
	int (*poweroff)(struct device___78 *);
	int (*restore)(struct device___78 *);
	int (*suspend_late)(struct device___78 *);
	int (*resume_early)(struct device___78 *);
	int (*freeze_late)(struct device___78 *);
	int (*thaw_early)(struct device___78 *);
	int (*poweroff_late)(struct device___78 *);
	int (*restore_early)(struct device___78 *);
	int (*suspend_noirq)(struct device___78 *);
	int (*resume_noirq)(struct device___78 *);
	int (*freeze_noirq)(struct device___78 *);
	int (*thaw_noirq)(struct device___78 *);
	int (*poweroff_noirq)(struct device___78 *);
	int (*restore_noirq)(struct device___78 *);
	int (*runtime_suspend)(struct device___78 *);
	int (*runtime_resume)(struct device___78 *);
	int (*runtime_idle)(struct device___78 *);
};

struct wakeup_source___78 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___78 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___78 {
	struct dev_pm_ops___78 ops;
	int (*start)(struct device___78 *);
	void (*detach)(struct device___78 *, bool);
	int (*activate)(struct device___78 *);
	void (*sync)(struct device___78 *);
	void (*dismiss)(struct device___78 *);
};

struct bus_type___78 {
	const char *name;
	const char *dev_name;
	struct device___78 *dev_root;
	const struct attribute_group___93 **bus_groups;
	const struct attribute_group___93 **dev_groups;
	const struct attribute_group___93 **drv_groups;
	int (*match)(struct device___78 *, struct device_driver___78 *);
	int (*uevent)(struct device___78 *, struct kobj_uevent_env *);
	int (*probe)(struct device___78 *);
	void (*sync_state)(struct device___78 *);
	void (*remove)(struct device___78 *);
	void (*shutdown)(struct device___78 *);
	int (*online)(struct device___78 *);
	int (*offline)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	int (*num_vf)(struct device___78 *);
	int (*dma_configure)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___78 {
	const char *name;
	struct bus_type___78 *bus;
	struct module___91 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___78 *);
	void (*sync_state)(struct device___78 *);
	int (*remove)(struct device___78 *);
	void (*shutdown)(struct device___78 *);
	int (*suspend)(struct device___78 *, pm_message_t);
	int (*resume)(struct device___78 *);
	const struct attribute_group___93 **groups;
	const struct attribute_group___93 **dev_groups;
	const struct dev_pm_ops___78 *pm;
	void (*coredump)(struct device___78 *);
	struct driver_private *p;
};

struct device_type___78 {
	const char *name;
	const struct attribute_group___93 **groups;
	int (*uevent)(struct device___78 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___78 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___78 *);
	const struct dev_pm_ops___78 *pm;
};

struct class___78 {
	const char *name;
	struct module___91 *owner;
	const struct attribute_group___93 **class_groups;
	const struct attribute_group___93 **dev_groups;
	struct kobject___93 *dev_kobj;
	int (*dev_uevent)(struct device___78 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___78 *, umode_t *);
	void (*class_release)(struct class___78 *);
	void (*dev_release)(struct device___78 *);
	int (*shutdown_pre)(struct device___78 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___78 *);
	void (*get_ownership)(struct device___78 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___78 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___78;

struct fwnode_handle___78 {
	struct fwnode_handle___78 *secondary;
	const struct fwnode_operations___78 *ops;
	struct device___78 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___93 {
	void (*page_free)(struct page___99 *);
	void (*kill)(struct dev_pagemap___93 *);
	void (*cleanup)(struct dev_pagemap___93 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___93 *);
};

struct seq_operations___88 {
	void * (*start)(struct seq_file___88 *, loff_t *);
	void (*stop)(struct seq_file___88 *, void *);
	void * (*next)(struct seq_file___88 *, void *, loff_t *);
	int (*show)(struct seq_file___88 *, void *);
};

struct fwnode_reference_args___78;

struct fwnode_endpoint___78;

struct fwnode_operations___78 {
	struct fwnode_handle___78 * (*get)(struct fwnode_handle___78 *);
	void (*put)(struct fwnode_handle___78 *);
	bool (*device_is_available)(const struct fwnode_handle___78 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___78 *, const struct device___78 *);
	bool (*property_present)(const struct fwnode_handle___78 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___78 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___78 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___78 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*get_parent)(const struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*get_next_child_node)(const struct fwnode_handle___78 *, struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*get_named_child_node)(const struct fwnode_handle___78 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___78 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___78 *);
	struct fwnode_handle___78 * (*graph_get_next_endpoint)(const struct fwnode_handle___78 *, struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*graph_get_remote_endpoint)(const struct fwnode_handle___78 *);
	struct fwnode_handle___78 * (*graph_get_port_parent)(struct fwnode_handle___78 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___78 *, struct fwnode_endpoint___78 *);
	int (*add_links)(struct fwnode_handle___78 *);
};

struct fwnode_endpoint___78 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___78 *local_fwnode;
};

struct fwnode_reference_args___78 {
	struct fwnode_handle___78 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct mount___4;

struct mnt_namespace___4 {
	struct ns_common___14 ns;
	struct mount___4 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___77 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___77 *root_cset;
};

struct nsset___13 {
	unsigned int flags;
	struct nsproxy___91 *nsproxy;
	struct fs_struct___12 *fs;
	const struct cred___13 *cred;
};

struct proc_ns_operations___14 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___14 * (*get)(struct task_struct___101 *);
	void (*put)(struct ns_common___14 *);
	int (*install)(struct nsset___13 *, struct ns_common___14 *);
	struct user_namespace___14 * (*owner)(struct ns_common___14 *);
	struct ns_common___14 * (*get_parent)(struct ns_common___14 *);
};

struct kernel_param_ops___90 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___90 *);
	int (*get)(char *, const struct kernel_param___90 *);
	void (*free)(void *);
};

struct kparam_array___90;

struct kernel_param___90 {
	const char *name;
	struct module___91 *mod;
	const struct kernel_param_ops___90 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___90 *arr;
	};
};

struct kparam_array___90 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___90 *ops;
	void *elem;
};

struct module_attribute___90 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___90 *, struct module_kobject___90 *, char *);
	ssize_t (*store)(struct module_attribute___90 *, struct module_kobject___90 *, const char *, size_t);
	void (*setup)(struct module___91 *, const char *);
	int (*test)(struct module___91 *);
	void (*free)(struct module___91 *);
};

struct trace_event_class___51;

struct trace_event_call___51 {
	struct list_head list;
	struct trace_event_class___51 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___51 *, struct perf_event___57 *);
};

struct fd___19 {
	struct file___94 *file;
	unsigned int flags;
};

struct cftype___77;

struct cgroup_subsys___77 {
	struct cgroup_subsys_state___77 * (*css_alloc)(struct cgroup_subsys_state___77 *);
	int (*css_online)(struct cgroup_subsys_state___77 *);
	void (*css_offline)(struct cgroup_subsys_state___77 *);
	void (*css_released)(struct cgroup_subsys_state___77 *);
	void (*css_free)(struct cgroup_subsys_state___77 *);
	void (*css_reset)(struct cgroup_subsys_state___77 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___77 *, int);
	int (*css_extra_stat_show)(struct seq_file___88 *, struct cgroup_subsys_state___77 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___101 *, struct css_set___77 *);
	void (*cancel_fork)(struct task_struct___101 *, struct css_set___77 *);
	void (*fork)(struct task_struct___101 *);
	void (*exit)(struct task_struct___101 *);
	void (*release)(struct task_struct___101 *);
	void (*bind)(struct cgroup_subsys_state___77 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___77 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___77 *dfl_cftypes;
	struct cftype___77 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___77 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___77 *updated_children;
	struct cgroup___77 *updated_next;
};

struct cgroup_root___77 {
	struct kernfs_root___93 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___77 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___77 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___77 *ss;
	struct list_head node;
	struct kernfs_ops___93 *kf_ops;
	int (*open)(struct kernfs_open_file___93 *);
	void (*release)(struct kernfs_open_file___93 *);
	u64 (*read_u64)(struct cgroup_subsys_state___77 *, struct cftype___77 *);
	s64 (*read_s64)(struct cgroup_subsys_state___77 *, struct cftype___77 *);
	int (*seq_show)(struct seq_file___88 *, void *);
	void * (*seq_start)(struct seq_file___88 *, loff_t *);
	void * (*seq_next)(struct seq_file___88 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___88 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___77 *, struct cftype___77 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___77 *, struct cftype___77 *, s64);
	ssize_t (*write)(struct kernfs_open_file___93 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___93 *, struct poll_table_struct___68 *);
};

struct perf_cpu_context___57;

struct perf_output_handle___57;

struct pmu___57 {
	struct list_head entry;
	struct module___91 *module;
	struct device___78 *dev;
	const struct attribute_group___93 **attr_groups;
	const struct attribute_group___93 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___57 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___57 *);
	void (*pmu_disable)(struct pmu___57 *);
	int (*event_init)(struct perf_event___57 *);
	void (*event_mapped)(struct perf_event___57 *, struct mm_struct___100 *);
	void (*event_unmapped)(struct perf_event___57 *, struct mm_struct___100 *);
	int (*add)(struct perf_event___57 *, int);
	void (*del)(struct perf_event___57 *, int);
	void (*start)(struct perf_event___57 *, int);
	void (*stop)(struct perf_event___57 *, int);
	void (*read)(struct perf_event___57 *);
	void (*start_txn)(struct pmu___57 *, unsigned int);
	int (*commit_txn)(struct pmu___57 *);
	void (*cancel_txn)(struct pmu___57 *);
	int (*event_idx)(struct perf_event___57 *);
	void (*sched_task)(struct perf_event_context___57 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___57 *, struct perf_event_context___57 *);
	void * (*setup_aux)(struct perf_event___57 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___57 *, struct perf_output_handle___57 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___57 *);
	int (*aux_output_match)(struct perf_event___57 *);
	int (*filter_match)(struct perf_event___57 *);
	int (*check_period)(struct perf_event___57 *, u64);
};

struct perf_cpu_context___57 {
	struct perf_event_context___57 ctx;
	struct perf_event_context___57 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___57 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___57 **heap;
	struct perf_event___57 *heap_default[2];
};

struct perf_output_handle___57 {
	struct perf_event___57 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___57 {
	struct cgroup_subsys_state___77 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___51 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___51 *);
	};
};

struct trace_event_class___51 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___51 *, enum trace_reg, void *);
	struct trace_event_fields___51 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___51 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___51 *);
};

struct syscall_metadata___26 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___51 *enter_event;
	struct trace_event_call___51 *exit_event;
};

struct mount_attr {
	__u64 attr_set;
	__u64 attr_clr;
	__u64 propagation;
	__u64 userns_fd;
};

struct fs_parameter___16 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___94 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___16 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___91 *owner;
	char *buffer[8];
};

struct fs_context_operations___16 {
	void (*free)(struct fs_context___16 *);
	int (*dup)(struct fs_context___16 *, struct fs_context___16 *);
	int (*parse_param)(struct fs_context___16 *, struct fs_parameter___16 *);
	int (*parse_monolithic)(struct fs_context___16 *, void *);
	int (*get_tree)(struct fs_context___16 *);
	int (*reconfigure)(struct fs_context___16 *);
};

struct block_device_operations___45;

struct gendisk___45 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___46 *part0;
	const struct block_device_operations___45 *fops;
	struct request_queue___45 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___44 *bdi;
	struct kobject___93 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___93 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___45 {
	struct bio___45 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___55 *bip_vec;
	struct bio_vec___55 bip_inline_vecs[0];
};

struct blkcg___44;

struct blkg_policy_data___44;

struct blkcg_gq___44 {
	struct request_queue___45 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___44 *blkcg;
	struct blkcg_gq___44 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___44 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___45 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___45(struct request___45 *);

typedef void integrity_complete_fn___45(struct request___45 *, unsigned int);

struct blk_integrity_profile___45 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___45 *prepare_fn;
	integrity_complete_fn___45 *complete_fn;
	const char *name;
};

struct block_device_operations___45 {
	blk_qc_t (*submit_bio)(struct bio___45 *);
	int (*open)(struct block_device___46 *, fmode_t);
	void (*release)(struct gendisk___45 *, fmode_t);
	int (*rw_page)(struct block_device___46 *, sector_t, struct page___99 *, unsigned int);
	int (*ioctl)(struct block_device___46 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___46 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___45 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___45 *);
	int (*getgeo)(struct block_device___46 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___46 *, bool);
	void (*swap_slot_free_notify)(struct block_device___46 *, long unsigned int);
	int (*report_zones)(struct gendisk___45 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___45 *, umode_t *);
	struct module___91 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___45 *, sector_t *);
};

typedef void rq_end_io_fn___45(struct request___45 *, blk_status_t);

struct request___45 {
	struct request_queue___45 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___44 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___45 *bio;
	struct bio___45 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___55 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___45 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___45 *saved_end_io;
		} flush;
	};
	struct gendisk___45 *rq_disk;
	struct block_device___46 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___45 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___44 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___45 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___93 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___94 *debugfs_dir;
	struct dentry___94 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___45;

struct elevator_mq_ops___45 {
	int (*init_sched)(struct request_queue___45 *, struct elevator_type___45 *);
	void (*exit_sched)(struct elevator_queue___45 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___44 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___44 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___44 *);
	bool (*allow_merge)(struct request_queue___45 *, struct request___45 *, struct bio___45 *);
	bool (*bio_merge)(struct request_queue___45 *, struct bio___45 *, unsigned int);
	int (*request_merge)(struct request_queue___45 *, struct request___45 **, struct bio___45 *);
	void (*request_merged)(struct request_queue___45 *, struct request___45 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___45 *, struct request___45 *, struct request___45 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___45 *);
	void (*finish_request)(struct request___45 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___44 *, struct list_head *, bool);
	struct request___45 * (*dispatch_request)(struct blk_mq_hw_ctx___44 *);
	bool (*has_work)(struct blk_mq_hw_ctx___44 *);
	void (*completed_request)(struct request___45 *, u64);
	void (*requeue_request)(struct request___45 *);
	struct request___45 * (*former_request)(struct request_queue___45 *, struct request___45 *);
	struct request___45 * (*next_request)(struct request_queue___45 *, struct request___45 *);
	void (*init_icq)(struct io_cq___45 *);
	void (*exit_icq)(struct io_cq___45 *);
};

struct elv_fs_entry___45;

struct elevator_type___45 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___45 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___45 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___91 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___45 {
	struct elevator_type___45 *type;
	void *elevator_data;
	struct kobject___93 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___45 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___45 *, char *);
	ssize_t (*store)(struct elevator_queue___45 *, const char *, size_t);
};

struct blk_mq_queue_data___44;

struct blk_mq_ops___44 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___44 *, const struct blk_mq_queue_data___44 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___44 *);
	int (*get_budget)(struct request_queue___45 *);
	void (*put_budget)(struct request_queue___45 *, int);
	void (*set_rq_budget_token)(struct request___45 *, int);
	int (*get_rq_budget_token)(struct request___45 *);
	enum blk_eh_timer_return (*timeout)(struct request___45 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___44 *);
	void (*complete)(struct request___45 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___44 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___44 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___44 *, struct request___45 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___44 *, struct request___45 *, unsigned int);
	void (*initialize_rq_fn)(struct request___45 *);
	void (*cleanup_rq)(struct request___45 *);
	bool (*busy)(struct request_queue___45 *);
	int (*map_queues)(struct blk_mq_tag_set___44 *);
	void (*show_rq)(struct seq_file___88 *, struct request___45 *);
};

struct blk_mq_tag_set___44 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___44 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___44 {
	struct request___45 *rq;
	bool last;
};

struct blkcg_policy_data___44;

struct blkcg___44 {
	struct cgroup_subsys_state___77 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___44 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___44 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___44 {
	struct blkcg___44 *blkcg;
	int plid;
};

struct blkg_policy_data___44 {
	struct blkcg_gq___44 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___40 {
	struct mem_cgroup___40 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___40 {
	struct lruvec___46 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___40 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___40 *memcg;
};

struct obj_cgroup___40 {
	struct percpu_ref refcnt;
	struct mem_cgroup___40 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct mountpoint___4;

struct mount___4 {
	struct hlist_node mnt_hash;
	struct mount___4 *mnt_parent;
	struct dentry___94 *mnt_mountpoint;
	struct vfsmount___94 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___4 *mnt_master;
	struct mnt_namespace___4 *mnt_ns;
	struct mountpoint___4 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___4 {
	struct hlist_node m_hash;
	struct dentry___94 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct proc_mounts {
	struct mnt_namespace___4 *ns;
	struct path___94 root;
	int (*show)(struct seq_file___88 *, struct vfsmount___94 *);
	struct mount___4 cursor;
};

struct mount_kattr {
	unsigned int attr_set;
	unsigned int attr_clr;
	unsigned int propagation;
	unsigned int lookup_flags;
	bool recurse;
	struct user_namespace___14 *mnt_userns;
};

enum umount_tree_flags {
	UMOUNT_SYNC = 1,
	UMOUNT_PROPAGATE = 2,
	UMOUNT_CONNECTED = 4,
};

struct dentry___95;

struct super_block___95;

struct module___92;

struct file_system_type___95 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___95 * (*mount)(struct file_system_type___95 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___95 *);
	struct module___92 *owner;
	struct file_system_type___95 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___95;

struct kiocb___95;

struct poll_table_struct___69;

struct vm_area_struct___100;

struct inode___95;

struct file_lock___95;

struct page___100;

struct seq_file___89;

struct file_operations___95 {
	struct module___92 *owner;
	loff_t (*llseek)(struct file___95 *, loff_t, int);
	ssize_t (*read)(struct file___95 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___95 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___95 *, struct iov_iter___57 *);
	ssize_t (*write_iter)(struct kiocb___95 *, struct iov_iter___57 *);
	int (*iopoll)(struct kiocb___95 *, bool);
	int (*iterate)(struct file___95 *, struct dir_context *);
	int (*iterate_shared)(struct file___95 *, struct dir_context *);
	__poll_t (*poll)(struct file___95 *, struct poll_table_struct___69 *);
	long int (*unlocked_ioctl)(struct file___95 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___95 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___95 *, struct vm_area_struct___100 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___95 *, struct file___95 *);
	int (*flush)(struct file___95 *, fl_owner_t);
	int (*release)(struct inode___95 *, struct file___95 *);
	int (*fsync)(struct file___95 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___95 *, int);
	int (*lock)(struct file___95 *, int, struct file_lock___95 *);
	ssize_t (*sendpage)(struct file___95 *, struct page___100 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___95 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___95 *, long unsigned int);
	int (*flock)(struct file___95 *, int, struct file_lock___95 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___95 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___95 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___95 *, long int, struct file_lock___95 **, void **);
	long int (*fallocate)(struct file___95 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___89 *, struct file___95 *);
	ssize_t (*copy_file_range)(struct file___95 *, loff_t, struct file___95 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___95 *, loff_t, struct file___95 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___95 *, loff_t, loff_t, int);
};

struct vmacache___100 {
	u64 seqnum;
	struct vm_area_struct___100 *vmas[4];
};

struct page_frag___100 {
	struct page___100 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___58;

struct debug_info___58 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___58 *hbp_break[16];
	struct perf_event___58 *hbp_watch[16];
};

struct thread_struct___58 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___58 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___101;

struct pid___87;

struct nsproxy___92;

struct signal_struct___96;

struct css_set___78;

struct perf_event_context___58;

struct vm_struct___94;

struct task_struct___102 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___102 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___101 *mm;
	struct mm_struct___101 *active_mm;
	struct vmacache___100 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___102 *real_parent;
	struct task_struct___102 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___102 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___87 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___92 *nsproxy;
	struct signal_struct___96 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___102 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___45 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___78 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___58 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___100 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___102 *oom_reaper_list;
	struct vm_struct___94 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___58 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___94;

struct kobj_type___94;

struct kernfs_node___94;

struct kobject___94 {
	const char *name;
	struct list_head entry;
	struct kobject___94 *parent;
	struct kset___94 *kset;
	struct kobj_type___94 *ktype;
	struct kernfs_node___94 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___91 {
	struct kobject___94 kobj;
	struct module___92 *mod;
	struct kobject___94 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___91 {
	struct module___92 *mod;
	struct latch_tree_node node;
};

struct module_layout___91 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___91 mtn;
};

struct module_attribute___91;

struct kernel_param___91;

struct trace_event_call___52;

struct module___92 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___91 mkobj;
	struct module_attribute___91 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___94 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___91 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___91 core_layout;
	struct module_layout___91 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___52 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___58 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___102 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___58)(struct perf_event___58 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___58;

struct fasync_struct___95;

struct pid_namespace___87;

struct perf_cgroup___58;

struct perf_event___58 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___58 *group_leader;
	struct pmu___58 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___58 hw;
	struct perf_event_context___58 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___58 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___102 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___95 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___58 *aux_event;
	void (*destroy)(struct perf_event___58 *);
	struct callback_head callback_head;
	struct pid_namespace___87 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___58 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___58 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___52 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___58 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___95;

struct dentry___95 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___95 *d_parent;
	struct qstr d_name;
	struct inode___95 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___95 *d_op;
	struct super_block___95 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___95;

struct address_space___95 {
	struct inode___95 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___95 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___95;

struct inode___95 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___95 *i_op;
	struct super_block___95 *i_sb;
	struct address_space___95 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___95 *i_fop;
		void (*free_inode)(struct inode___95 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___95 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___95;

struct path___95;

struct dentry_operations___95 {
	int (*d_revalidate)(struct dentry___95 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___95 *, unsigned int);
	int (*d_hash)(const struct dentry___95 *, struct qstr *);
	int (*d_compare)(const struct dentry___95 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___95 *);
	int (*d_init)(struct dentry___95 *);
	void (*d_release)(struct dentry___95 *);
	void (*d_prune)(struct dentry___95 *);
	void (*d_iput)(struct dentry___95 *, struct inode___95 *);
	char * (*d_dname)(struct dentry___95 *, char *, int);
	struct vfsmount___95 * (*d_automount)(struct path___95 *);
	int (*d_manage)(const struct path___95 *, bool);
	struct dentry___95 * (*d_real)(struct dentry___95 *, const struct inode___95 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___95;

struct mem_dqinfo___95 {
	struct quota_format_type___95 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___95;

struct quota_info___95 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___95 *files[3];
	struct mem_dqinfo___95 info[3];
	const struct quota_format_ops___95 *ops[3];
};

struct rcuwait___96 {
	struct task_struct___102 *task;
};

struct percpu_rw_semaphore___96 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___96 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___95 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___96 rw_sem[3];
};

struct super_operations___95;

struct dquot_operations___95;

struct quotactl_ops___95;

struct xattr_handler___10;

struct super_block___95 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___95 *s_type;
	const struct super_operations___95 *s_op;
	const struct dquot_operations___95 *dq_op;
	const struct quotactl_ops___95 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___95 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___10 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___95 s_dquot;
	struct sb_writers___95 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___95 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___95 {
	struct dentry___95 *mnt_root;
	struct super_block___95 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___95 {
	struct vfsmount___95 *mnt;
	struct dentry___95 *dentry;
};

struct upid___87 {
	int nr;
	struct pid_namespace___87 *ns;
};

struct pid_namespace___87 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___102 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___87 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___87 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___87 numbers[1];
};

typedef struct page___100 *pgtable_t___100;

struct dev_pagemap___94;

struct page___100 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___95 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___100 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___100 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___101 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___94 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___94;

struct vm_area_struct___100 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___100 *vm_next;
	struct vm_area_struct___100 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___101 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___94 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___95 *vm_file;
	struct file___95 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___96 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___102 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___102 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___87 *pids[4];
	struct pid___87 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___101 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___100;

struct mm_struct___101 {
	struct {
		struct vm_area_struct___100 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___95 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___100 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___102 *owner;
		struct user_namespace___14 *user_ns;
		struct file___95 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___78;

struct nsproxy___92 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___87 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___78 *cgroup_ns;
};

struct cgroup_subsys_state___78;

struct cgroup___78;

struct css_set___78 {
	struct cgroup_subsys_state___78 *subsys[14];
	refcount_t refcount;
	struct css_set___78 *dom_cset;
	struct cgroup___78 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___78 *mg_src_cgrp;
	struct cgroup___78 *mg_dst_cgrp;
	struct css_set___78 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___58 {
	struct pmu___58 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___102 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___58 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___94 {
	struct vm_struct___94 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___100 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___94;

struct dev_pagemap___94 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___94 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___87 {
	rwlock_t lock;
	struct pid___87 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___95 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___95 f_path;
	struct inode___95 *f_inode;
	const struct file_operations___95 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___87 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___95 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___94;

struct vm_operations_struct___94 {
	void (*open)(struct vm_area_struct___100 *);
	void (*close)(struct vm_area_struct___100 *);
	int (*may_split)(struct vm_area_struct___100 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___100 *);
	int (*mprotect)(struct vm_area_struct___100 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___94 *);
	vm_fault_t (*huge_fault)(struct vm_fault___94 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___94 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___100 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___94 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___94 *);
	int (*access)(struct vm_area_struct___100 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___100 *);
	int (*set_policy)(struct vm_area_struct___100 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___100 *, long unsigned int);
	struct page___100 * (*find_special_page)(struct vm_area_struct___100 *, long unsigned int);
};

struct core_thread___100 {
	struct task_struct___102 *task;
	struct core_thread___100 *next;
};

struct core_state___100 {
	atomic_t nr_threads;
	struct core_thread___100 dumper;
	struct completion startup;
};

struct vm_fault___94 {
	const struct {
		struct vm_area_struct___100 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___100 *cow_page;
	struct page___100 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___100 prealloc_pte;
};

struct cgroup_subsys___78;

struct cgroup_subsys_state___78 {
	struct cgroup___78 *cgroup;
	struct cgroup_subsys___78 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___78 *parent;
};

struct cgroup_file___78 {
	struct kernfs_node___94 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___78 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___102 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___78;

struct cgroup_rstat_cpu___78;

struct cgroup___78 {
	struct cgroup_subsys_state___78 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___94 *kn;
	struct cgroup_file___78 procs_file;
	struct cgroup_file___78 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___78 *subsys[14];
	struct cgroup_root___78 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___78 *dom_cgrp;
	struct cgroup___78 *old_dom_cgrp;
	struct cgroup_rstat_cpu___78 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___78 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___95 {
	struct file___95 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___95 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___47 *ki_waitq;
	};
};

struct iattr___95 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___95 *ia_file;
};

struct dquot___95 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___95 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___95 {
	int qf_fmt_id;
	const struct quota_format_ops___95 *qf_ops;
	struct module___92 *qf_owner;
	struct quota_format_type___95 *qf_next;
};

struct quota_format_ops___95 {
	int (*check_quota_file)(struct super_block___95 *, int);
	int (*read_file_info)(struct super_block___95 *, int);
	int (*write_file_info)(struct super_block___95 *, int);
	int (*free_file_info)(struct super_block___95 *, int);
	int (*read_dqblk)(struct dquot___95 *);
	int (*commit_dqblk)(struct dquot___95 *);
	int (*release_dqblk)(struct dquot___95 *);
	int (*get_next_id)(struct super_block___95 *, struct kqid *);
};

struct dquot_operations___95 {
	int (*write_dquot)(struct dquot___95 *);
	struct dquot___95 * (*alloc_dquot)(struct super_block___95 *, int);
	void (*destroy_dquot)(struct dquot___95 *);
	int (*acquire_dquot)(struct dquot___95 *);
	int (*release_dquot)(struct dquot___95 *);
	int (*mark_dirty)(struct dquot___95 *);
	int (*write_info)(struct super_block___95 *, int);
	qsize_t * (*get_reserved_space)(struct inode___95 *);
	int (*get_projid)(struct inode___95 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___95 *, qsize_t *);
	int (*get_next_id)(struct super_block___95 *, struct kqid *);
};

struct quotactl_ops___95 {
	int (*quota_on)(struct super_block___95 *, int, int, const struct path___95 *);
	int (*quota_off)(struct super_block___95 *, int);
	int (*quota_enable)(struct super_block___95 *, unsigned int);
	int (*quota_disable)(struct super_block___95 *, unsigned int);
	int (*quota_sync)(struct super_block___95 *, int);
	int (*set_info)(struct super_block___95 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___95 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___95 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___95 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___95 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___95 *, unsigned int);
};

struct address_space_operations___95 {
	int (*writepage)(struct page___100 *, struct writeback_control___3 *);
	int (*readpage)(struct file___95 *, struct page___100 *);
	int (*writepages)(struct address_space___95 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___100 *);
	int (*readpages)(struct file___95 *, struct address_space___95 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___95 *, struct address_space___95 *, loff_t, unsigned int, unsigned int, struct page___100 **, void **);
	int (*write_end)(struct file___95 *, struct address_space___95 *, loff_t, unsigned int, unsigned int, struct page___100 *, void *);
	sector_t (*bmap)(struct address_space___95 *, sector_t);
	void (*invalidatepage)(struct page___100 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___100 *, gfp_t);
	void (*freepage)(struct page___100 *);
	ssize_t (*direct_IO)(struct kiocb___95 *, struct iov_iter___57 *);
	int (*migratepage)(struct address_space___95 *, struct page___100 *, struct page___100 *, enum migrate_mode);
	bool (*isolate_page)(struct page___100 *, isolate_mode_t);
	void (*putback_page)(struct page___100 *);
	int (*launder_page)(struct page___100 *);
	int (*is_partially_uptodate)(struct page___100 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___100 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___95 *, struct page___100 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___95 *, sector_t *);
	void (*swap_deactivate)(struct file___95 *);
};

struct inode_operations___95 {
	struct dentry___95 * (*lookup)(struct inode___95 *, struct dentry___95 *, unsigned int);
	const char * (*get_link)(struct dentry___95 *, struct inode___95 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___95 *, int);
	struct posix_acl * (*get_acl)(struct inode___95 *, int, bool);
	int (*readlink)(struct dentry___95 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___95 *, struct dentry___95 *, umode_t, bool);
	int (*link)(struct dentry___95 *, struct inode___95 *, struct dentry___95 *);
	int (*unlink)(struct inode___95 *, struct dentry___95 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___95 *, struct dentry___95 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___95 *, struct dentry___95 *, umode_t);
	int (*rmdir)(struct inode___95 *, struct dentry___95 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___95 *, struct dentry___95 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___95 *, struct dentry___95 *, struct inode___95 *, struct dentry___95 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___95 *, struct iattr___95 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___95 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___95 *, char *, size_t);
	int (*fiemap)(struct inode___95 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___95 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___95 *, struct dentry___95 *, struct file___95 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___95 *, struct dentry___95 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___95 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___95 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___95 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___95 {
	void (*fl_copy_lock)(struct file_lock___95 *, struct file_lock___95 *);
	void (*fl_release_private)(struct file_lock___95 *);
};

struct lock_manager_operations___95;

struct file_lock___95 {
	struct file_lock___95 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___95 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___95 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___95 *fl_ops;
	const struct lock_manager_operations___95 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___95 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___95 *);
	int (*lm_grant)(struct file_lock___95 *, int);
	bool (*lm_break)(struct file_lock___95 *);
	int (*lm_change)(struct file_lock___95 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___95 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___95 *);
};

struct fasync_struct___95 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___95 *fa_next;
	struct file___95 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___95 {
	struct inode___95 * (*alloc_inode)(struct super_block___95 *);
	void (*destroy_inode)(struct inode___95 *);
	void (*free_inode)(struct inode___95 *);
	void (*dirty_inode)(struct inode___95 *, int);
	int (*write_inode)(struct inode___95 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___95 *);
	void (*evict_inode)(struct inode___95 *);
	void (*put_super)(struct super_block___95 *);
	int (*sync_fs)(struct super_block___95 *, int);
	int (*freeze_super)(struct super_block___95 *);
	int (*freeze_fs)(struct super_block___95 *);
	int (*thaw_super)(struct super_block___95 *);
	int (*unfreeze_fs)(struct super_block___95 *);
	int (*statfs)(struct dentry___95 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___95 *, int *, char *);
	void (*umount_begin)(struct super_block___95 *);
	int (*show_options)(struct seq_file___89 *, struct dentry___95 *);
	int (*show_devname)(struct seq_file___89 *, struct dentry___95 *);
	int (*show_path)(struct seq_file___89 *, struct dentry___95 *);
	int (*show_stats)(struct seq_file___89 *, struct dentry___95 *);
	ssize_t (*quota_read)(struct super_block___95 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___95 *, int, const char *, size_t, loff_t);
	struct dquot___95 ** (*get_dquots)(struct inode___95 *);
	long int (*nr_cached_objects)(struct super_block___95 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___95 *, struct shrink_control___40 *);
	struct file___95 * (*real_loop)(struct file___95 *);
};

struct xattr_handler___10 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___95 *);
	int (*get)(const struct xattr_handler___10 *, struct dentry___95 *, struct inode___95 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___10 *, struct user_namespace___14 *, struct dentry___95 *, struct inode___95 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___69)(struct file___95 *, wait_queue_head_t *, struct poll_table_struct___69 *);

struct poll_table_struct___69 {
	poll_queue_proc___69 _qproc;
	__poll_t _key;
};

struct seq_operations___89;

struct seq_file___89 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___89 *op;
	int poll_event;
	const struct file___95 *file;
	void *private;
};

struct fd___20 {
	struct file___95 *file;
	unsigned int flags;
};

struct dev_pagemap_ops___94 {
	void (*page_free)(struct page___100 *);
	void (*kill)(struct dev_pagemap___94 *);
	void (*cleanup)(struct dev_pagemap___94 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___94 *);
};

struct cgroup_namespace___78 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___78 *root_cset;
};

struct seq_operations___89 {
	void * (*start)(struct seq_file___89 *, loff_t *);
	void (*stop)(struct seq_file___89 *, void *);
	void * (*next)(struct seq_file___89 *, void *, loff_t *);
	int (*show)(struct seq_file___89 *, void *);
};

struct kernfs_root___94;

struct kernfs_elem_dir___94 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___94 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___94;

struct kernfs_root___94 {
	struct kernfs_node___94 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___94 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___94 {
	struct kernfs_node___94 *target_kn;
};

struct kernfs_ops___94;

struct kernfs_elem_attr___94 {
	const struct kernfs_ops___94 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___94 *notify_next;
};

struct kernfs_node___94 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___94 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___94 dir;
		struct kernfs_elem_symlink___94 symlink;
		struct kernfs_elem_attr___94 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___94;

struct kernfs_ops___94 {
	int (*open)(struct kernfs_open_file___94 *);
	void (*release)(struct kernfs_open_file___94 *);
	int (*seq_show)(struct seq_file___89 *, void *);
	void * (*seq_start)(struct seq_file___89 *, loff_t *);
	void * (*seq_next)(struct seq_file___89 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___89 *, void *);
	ssize_t (*read)(struct kernfs_open_file___94 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___94 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___94 *, struct poll_table_struct___69 *);
	int (*mmap)(struct kernfs_open_file___94 *, struct vm_area_struct___100 *);
};

struct kernfs_syscall_ops___94 {
	int (*show_options)(struct seq_file___89 *, struct kernfs_root___94 *);
	int (*mkdir)(struct kernfs_node___94 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___94 *);
	int (*rename)(struct kernfs_node___94 *, struct kernfs_node___94 *, const char *);
	int (*show_path)(struct seq_file___89 *, struct kernfs_node___94 *, struct kernfs_root___94 *);
};

struct kernfs_open_file___94 {
	struct kernfs_node___94 *kn;
	struct file___95 *file;
	struct seq_file___89 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___94 *vm_ops;
};

struct bin_attribute___94;

struct attribute_group___94 {
	const char *name;
	umode_t (*is_visible)(struct kobject___94 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___94 *, struct bin_attribute___94 *, int);
	struct attribute **attrs;
	struct bin_attribute___94 **bin_attrs;
};

struct bin_attribute___94 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___95 * (*f_mapping)();
	ssize_t (*read)(struct file___95 *, struct kobject___94 *, struct bin_attribute___94 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___95 *, struct kobject___94 *, struct bin_attribute___94 *, char *, loff_t, size_t);
	int (*mmap)(struct file___95 *, struct kobject___94 *, struct bin_attribute___94 *, struct vm_area_struct___100 *);
};

struct sysfs_ops___94 {
	ssize_t (*show)(struct kobject___94 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___94 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___94;

struct kset___94 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___94 kobj;
	const struct kset_uevent_ops___94 *uevent_ops;
};

struct kobj_type___94 {
	void (*release)(struct kobject___94 *);
	const struct sysfs_ops___94 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___94 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___94 *);
	const void * (*namespace)(struct kobject___94 *);
	void (*get_ownership)(struct kobject___94 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___94 {
	int (* const filter)(struct kset___94 *, struct kobject___94 *);
	const char * (* const name)(struct kset___94 *, struct kobject___94 *);
	int (* const uevent)(struct kset___94 *, struct kobject___94 *, struct kobj_uevent_env *);
};

struct wakeup_source___79;

struct device___79;

struct dev_pm_info___79 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___79 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___79 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___79;

struct bus_type___79;

struct device_driver___79;

struct dev_pm_domain___79;

struct fwnode_handle___79;

struct class___79;

struct device___79 {
	struct kobject___94 kobj;
	struct device___79 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___79 *type;
	struct bus_type___79 *bus;
	struct device_driver___79 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___79 power;
	struct dev_pm_domain___79 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___79 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___79 *class;
	const struct attribute_group___94 **groups;
	void (*release)(struct device___79 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___79 {
	int (*prepare)(struct device___79 *);
	void (*complete)(struct device___79 *);
	int (*suspend)(struct device___79 *);
	int (*resume)(struct device___79 *);
	int (*freeze)(struct device___79 *);
	int (*thaw)(struct device___79 *);
	int (*poweroff)(struct device___79 *);
	int (*restore)(struct device___79 *);
	int (*suspend_late)(struct device___79 *);
	int (*resume_early)(struct device___79 *);
	int (*freeze_late)(struct device___79 *);
	int (*thaw_early)(struct device___79 *);
	int (*poweroff_late)(struct device___79 *);
	int (*restore_early)(struct device___79 *);
	int (*suspend_noirq)(struct device___79 *);
	int (*resume_noirq)(struct device___79 *);
	int (*freeze_noirq)(struct device___79 *);
	int (*thaw_noirq)(struct device___79 *);
	int (*poweroff_noirq)(struct device___79 *);
	int (*restore_noirq)(struct device___79 *);
	int (*runtime_suspend)(struct device___79 *);
	int (*runtime_resume)(struct device___79 *);
	int (*runtime_idle)(struct device___79 *);
};

struct wakeup_source___79 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___79 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___79 {
	struct dev_pm_ops___79 ops;
	int (*start)(struct device___79 *);
	void (*detach)(struct device___79 *, bool);
	int (*activate)(struct device___79 *);
	void (*sync)(struct device___79 *);
	void (*dismiss)(struct device___79 *);
};

struct bus_type___79 {
	const char *name;
	const char *dev_name;
	struct device___79 *dev_root;
	const struct attribute_group___94 **bus_groups;
	const struct attribute_group___94 **dev_groups;
	const struct attribute_group___94 **drv_groups;
	int (*match)(struct device___79 *, struct device_driver___79 *);
	int (*uevent)(struct device___79 *, struct kobj_uevent_env *);
	int (*probe)(struct device___79 *);
	void (*sync_state)(struct device___79 *);
	void (*remove)(struct device___79 *);
	void (*shutdown)(struct device___79 *);
	int (*online)(struct device___79 *);
	int (*offline)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	int (*num_vf)(struct device___79 *);
	int (*dma_configure)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___79 {
	const char *name;
	struct bus_type___79 *bus;
	struct module___92 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___79 *);
	void (*sync_state)(struct device___79 *);
	int (*remove)(struct device___79 *);
	void (*shutdown)(struct device___79 *);
	int (*suspend)(struct device___79 *, pm_message_t);
	int (*resume)(struct device___79 *);
	const struct attribute_group___94 **groups;
	const struct attribute_group___94 **dev_groups;
	const struct dev_pm_ops___79 *pm;
	void (*coredump)(struct device___79 *);
	struct driver_private *p;
};

struct device_type___79 {
	const char *name;
	const struct attribute_group___94 **groups;
	int (*uevent)(struct device___79 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___79 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___79 *);
	const struct dev_pm_ops___79 *pm;
};

struct class___79 {
	const char *name;
	struct module___92 *owner;
	const struct attribute_group___94 **class_groups;
	const struct attribute_group___94 **dev_groups;
	struct kobject___94 *dev_kobj;
	int (*dev_uevent)(struct device___79 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___79 *, umode_t *);
	void (*class_release)(struct class___79 *);
	void (*dev_release)(struct device___79 *);
	int (*shutdown_pre)(struct device___79 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___79 *);
	void (*get_ownership)(struct device___79 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___79 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___79;

struct fwnode_handle___79 {
	struct fwnode_handle___79 *secondary;
	const struct fwnode_operations___79 *ops;
	struct device___79 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___79;

struct fwnode_endpoint___79;

struct fwnode_operations___79 {
	struct fwnode_handle___79 * (*get)(struct fwnode_handle___79 *);
	void (*put)(struct fwnode_handle___79 *);
	bool (*device_is_available)(const struct fwnode_handle___79 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___79 *, const struct device___79 *);
	bool (*property_present)(const struct fwnode_handle___79 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___79 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___79 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___79 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*get_parent)(const struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*get_next_child_node)(const struct fwnode_handle___79 *, struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*get_named_child_node)(const struct fwnode_handle___79 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___79 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___79 *);
	struct fwnode_handle___79 * (*graph_get_next_endpoint)(const struct fwnode_handle___79 *, struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*graph_get_remote_endpoint)(const struct fwnode_handle___79 *);
	struct fwnode_handle___79 * (*graph_get_port_parent)(struct fwnode_handle___79 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___79 *, struct fwnode_endpoint___79 *);
	int (*add_links)(struct fwnode_handle___79 *);
};

struct fwnode_endpoint___79 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___79 *local_fwnode;
};

struct fwnode_reference_args___79 {
	struct fwnode_handle___79 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___91 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___91 *);
	int (*get)(char *, const struct kernel_param___91 *);
	void (*free)(void *);
};

struct kparam_array___91;

struct kernel_param___91 {
	const char *name;
	struct module___92 *mod;
	const struct kernel_param_ops___91 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___91 *arr;
	};
};

struct kparam_array___91 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___91 *ops;
	void *elem;
};

struct module_attribute___91 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___91 *, struct module_kobject___91 *, char *);
	ssize_t (*store)(struct module_attribute___91 *, struct module_kobject___91 *, const char *, size_t);
	void (*setup)(struct module___92 *, const char *);
	int (*test)(struct module___92 *);
	void (*free)(struct module___92 *);
};

struct trace_event_class___52;

struct trace_event_call___52 {
	struct list_head list;
	struct trace_event_class___52 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___52 *, struct perf_event___58 *);
};

struct cftype___78;

struct cgroup_subsys___78 {
	struct cgroup_subsys_state___78 * (*css_alloc)(struct cgroup_subsys_state___78 *);
	int (*css_online)(struct cgroup_subsys_state___78 *);
	void (*css_offline)(struct cgroup_subsys_state___78 *);
	void (*css_released)(struct cgroup_subsys_state___78 *);
	void (*css_free)(struct cgroup_subsys_state___78 *);
	void (*css_reset)(struct cgroup_subsys_state___78 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___78 *, int);
	int (*css_extra_stat_show)(struct seq_file___89 *, struct cgroup_subsys_state___78 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___102 *, struct css_set___78 *);
	void (*cancel_fork)(struct task_struct___102 *, struct css_set___78 *);
	void (*fork)(struct task_struct___102 *);
	void (*exit)(struct task_struct___102 *);
	void (*release)(struct task_struct___102 *);
	void (*bind)(struct cgroup_subsys_state___78 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___78 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___78 *dfl_cftypes;
	struct cftype___78 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___78 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___78 *updated_children;
	struct cgroup___78 *updated_next;
};

struct cgroup_root___78 {
	struct kernfs_root___94 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___78 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___78 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___78 *ss;
	struct list_head node;
	struct kernfs_ops___94 *kf_ops;
	int (*open)(struct kernfs_open_file___94 *);
	void (*release)(struct kernfs_open_file___94 *);
	u64 (*read_u64)(struct cgroup_subsys_state___78 *, struct cftype___78 *);
	s64 (*read_s64)(struct cgroup_subsys_state___78 *, struct cftype___78 *);
	int (*seq_show)(struct seq_file___89 *, void *);
	void * (*seq_start)(struct seq_file___89 *, loff_t *);
	void * (*seq_next)(struct seq_file___89 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___89 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___78 *, struct cftype___78 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___78 *, struct cftype___78 *, s64);
	ssize_t (*write)(struct kernfs_open_file___94 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___94 *, struct poll_table_struct___69 *);
};

struct perf_cpu_context___58;

struct perf_output_handle___58;

struct pmu___58 {
	struct list_head entry;
	struct module___92 *module;
	struct device___79 *dev;
	const struct attribute_group___94 **attr_groups;
	const struct attribute_group___94 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___58 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___58 *);
	void (*pmu_disable)(struct pmu___58 *);
	int (*event_init)(struct perf_event___58 *);
	void (*event_mapped)(struct perf_event___58 *, struct mm_struct___101 *);
	void (*event_unmapped)(struct perf_event___58 *, struct mm_struct___101 *);
	int (*add)(struct perf_event___58 *, int);
	void (*del)(struct perf_event___58 *, int);
	void (*start)(struct perf_event___58 *, int);
	void (*stop)(struct perf_event___58 *, int);
	void (*read)(struct perf_event___58 *);
	void (*start_txn)(struct pmu___58 *, unsigned int);
	int (*commit_txn)(struct pmu___58 *);
	void (*cancel_txn)(struct pmu___58 *);
	int (*event_idx)(struct perf_event___58 *);
	void (*sched_task)(struct perf_event_context___58 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___58 *, struct perf_event_context___58 *);
	void * (*setup_aux)(struct perf_event___58 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___58 *, struct perf_output_handle___58 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___58 *);
	int (*aux_output_match)(struct perf_event___58 *);
	int (*filter_match)(struct perf_event___58 *);
	int (*check_period)(struct perf_event___58 *, u64);
};

struct perf_cpu_context___58 {
	struct perf_event_context___58 ctx;
	struct perf_event_context___58 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___58 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___58 **heap;
	struct perf_event___58 *heap_default[2];
};

struct perf_output_handle___58 {
	struct perf_event___58 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___58 {
	struct cgroup_subsys_state___78 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___52 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___52 *);
	};
};

struct trace_event_class___52 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___52 *, enum trace_reg, void *);
	struct trace_event_fields___52 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___52 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___52 *);
};

struct syscall_metadata___27 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___52 *enter_event;
	struct trace_event_call___52 *exit_event;
};

struct fs_context___17;

struct dentry___96;

struct super_block___96;

struct module___93;

struct file_system_type___96 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___17 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___96 * (*mount)(struct file_system_type___96 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___96 *);
	struct module___93 *owner;
	struct file_system_type___96 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___96;

struct kiocb___96;

struct iov_iter___58;

struct vm_area_struct___101;

struct inode___96;

struct file_lock___96;

struct page___101;

struct seq_file___90;

struct file_operations___96 {
	struct module___93 *owner;
	loff_t (*llseek)(struct file___96 *, loff_t, int);
	ssize_t (*read)(struct file___96 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___96 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___96 *, struct iov_iter___58 *);
	ssize_t (*write_iter)(struct kiocb___96 *, struct iov_iter___58 *);
	int (*iopoll)(struct kiocb___96 *, bool);
	int (*iterate)(struct file___96 *, struct dir_context *);
	int (*iterate_shared)(struct file___96 *, struct dir_context *);
	__poll_t (*poll)(struct file___96 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___96 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___96 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___96 *, struct vm_area_struct___101 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___96 *, struct file___96 *);
	int (*flush)(struct file___96 *, fl_owner_t);
	int (*release)(struct inode___96 *, struct file___96 *);
	int (*fsync)(struct file___96 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___96 *, int);
	int (*lock)(struct file___96 *, int, struct file_lock___96 *);
	ssize_t (*sendpage)(struct file___96 *, struct page___101 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___96 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___96 *, long unsigned int);
	int (*flock)(struct file___96 *, int, struct file_lock___96 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___96 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___96 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___96 *, long int, struct file_lock___96 **, void **);
	long int (*fallocate)(struct file___96 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___90 *, struct file___96 *);
	ssize_t (*copy_file_range)(struct file___96 *, loff_t, struct file___96 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___96 *, loff_t, struct file___96 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___96 *, loff_t, loff_t, int);
};

struct vmacache___101 {
	u64 seqnum;
	struct vm_area_struct___101 *vmas[4];
};

struct page_frag___101 {
	struct page___101 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___102;

struct pid___88;

struct nsproxy___93;

struct signal_struct___97;

struct bio_list___46;

struct backing_dev_info___45;

struct io_context___46;

struct css_set___79;

struct request_queue___46;

struct vm_struct___95;

struct task_struct___103 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___103 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___102 *mm;
	struct mm_struct___102 *active_mm;
	struct vmacache___101 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___103 *real_parent;
	struct task_struct___103 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___103 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___88 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___93 *nsproxy;
	struct signal_struct___97 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___103 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___46 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___45 *backing_dev_info;
	struct io_context___46 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___79 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___101 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___46 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___103 *oom_reaper_list;
	struct vm_struct___95 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___58 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___95;

struct kobj_type___95;

struct kernfs_node___95;

struct kobject___95 {
	const char *name;
	struct list_head entry;
	struct kobject___95 *parent;
	struct kset___95 *kset;
	struct kobj_type___95 *ktype;
	struct kernfs_node___95 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___92 {
	struct kobject___95 kobj;
	struct module___93 *mod;
	struct kobject___95 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___92 {
	struct module___93 *mod;
	struct latch_tree_node node;
};

struct module_layout___92 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___92 mtn;
};

struct module_attribute___92;

struct kernel_param___92;

struct module___93 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___92 mkobj;
	struct module_attribute___92 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___95 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___92 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___92 core_layout;
	struct module_layout___92 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___88;

struct upid___88 {
	int nr;
	struct pid_namespace___88 *ns;
};

struct pid_namespace___88 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___103 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___88 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___88 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___88 numbers[1];
};

typedef struct page___101 *pgtable_t___101;

struct address_space___96;

struct dev_pagemap___95;

struct page___101 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___96 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___101 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___101 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___102 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___95 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___95;

struct vm_area_struct___101 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___101 *vm_next;
	struct vm_area_struct___101 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___102 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___95 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___96 *vm_file;
	struct file___96 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___97 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___103 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___103 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___88 *pids[4];
	struct pid___88 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___102 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___101;

struct mm_struct___102 {
	struct {
		struct vm_area_struct___101 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___96 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___101 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___103 *owner;
		struct user_namespace___14 *user_ns;
		struct file___96 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___79;

struct nsproxy___93 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___88 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___79 *cgroup_ns;
};

struct bio___46;

struct bio_list___46 {
	struct bio___46 *head;
	struct bio___46 *tail;
};

struct cgroup_subsys_state___79;

struct bdi_writeback___45 {
	struct backing_dev_info___45 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___79 *memcg_css;
	struct cgroup_subsys_state___79 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___80;

struct backing_dev_info___45 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___45 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___80 *dev;
	char dev_name[64];
	struct device___80 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___96 *debug_dir;
};

struct io_cq___46;

struct io_context___46 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___46 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___79;

struct css_set___79 {
	struct cgroup_subsys_state___79 *subsys[14];
	refcount_t refcount;
	struct css_set___79 *dom_cset;
	struct cgroup___79 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___79 *mg_src_cgrp;
	struct cgroup___79 *mg_dst_cgrp;
	struct css_set___79 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___46;

struct blk_integrity___46 {
	const struct blk_integrity_profile___46 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___46 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___46 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___46;

struct elevator_queue___46;

struct blk_mq_ops___45;

struct blk_mq_hw_ctx___45;

struct gendisk___46;

struct blkcg_gq___45;

struct blk_mq_tag_set___45;

struct request_queue___46 {
	struct request___46 *last_merge;
	struct elevator_queue___46 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___45 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___45 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___46 *disk;
	struct kobject___95 kobj;
	struct kobject___95 *mq_kobj;
	struct blk_integrity___46 integrity;
	struct device___80 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___45 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___45 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___46 bio_split;
	struct dentry___96 *debugfs_dir;
	struct dentry___96 *sched_debugfs_dir;
	struct dentry___96 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___95 {
	struct vm_struct___95 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___101 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___96;

struct dentry___96 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___96 *d_parent;
	struct qstr d_name;
	struct inode___96 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___96 *d_op;
	struct super_block___96 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___96;

struct address_space___96 {
	struct inode___96 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___96 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___96;

struct inode___96 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___96 *i_op;
	struct super_block___96 *i_sb;
	struct address_space___96 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___45 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___96 *i_fop;
		void (*free_inode)(struct inode___96 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___96 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___96;

struct path___96;

struct dentry_operations___96 {
	int (*d_revalidate)(struct dentry___96 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___96 *, unsigned int);
	int (*d_hash)(const struct dentry___96 *, struct qstr *);
	int (*d_compare)(const struct dentry___96 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___96 *);
	int (*d_init)(struct dentry___96 *);
	void (*d_release)(struct dentry___96 *);
	void (*d_prune)(struct dentry___96 *);
	void (*d_iput)(struct dentry___96 *, struct inode___96 *);
	char * (*d_dname)(struct dentry___96 *, char *, int);
	struct vfsmount___96 * (*d_automount)(struct path___96 *);
	int (*d_manage)(const struct path___96 *, bool);
	struct dentry___96 * (*d_real)(struct dentry___96 *, const struct inode___96 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___96;

struct mem_dqinfo___96 {
	struct quota_format_type___96 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___96;

struct quota_info___96 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___96 *files[3];
	struct mem_dqinfo___96 info[3];
	const struct quota_format_ops___96 *ops[3];
};

struct rcuwait___97 {
	struct task_struct___103 *task;
};

struct percpu_rw_semaphore___97 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___97 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___96 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___97 rw_sem[3];
};

struct super_operations___96;

struct dquot_operations___96;

struct quotactl_ops___96;

struct export_operations___4;

struct fscrypt_operations___4;

struct block_device___47;

struct super_block___96 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___96 *s_type;
	const struct super_operations___96 *s_op;
	const struct dquot_operations___96 *dq_op;
	const struct quotactl_ops___96 *s_qcop;
	const struct export_operations___4 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___96 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___4 *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___47 *s_bdev;
	struct backing_dev_info___45 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___96 s_dquot;
	struct sb_writers___96 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___96 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___96 {
	struct dentry___96 *mnt_root;
	struct super_block___96 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___96 {
	struct vfsmount___96 *mnt;
	struct dentry___96 *dentry;
};

struct dev_pagemap_ops___95;

struct dev_pagemap___95 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___95 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___88 {
	rwlock_t lock;
	struct pid___88 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___96 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___96 f_path;
	struct inode___96 *f_inode;
	const struct file_operations___96 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___88 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___96 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___95;

struct vm_operations_struct___95 {
	void (*open)(struct vm_area_struct___101 *);
	void (*close)(struct vm_area_struct___101 *);
	int (*may_split)(struct vm_area_struct___101 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___101 *);
	int (*mprotect)(struct vm_area_struct___101 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___95 *);
	vm_fault_t (*huge_fault)(struct vm_fault___95 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___95 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___101 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___95 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___95 *);
	int (*access)(struct vm_area_struct___101 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___101 *);
	int (*set_policy)(struct vm_area_struct___101 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___101 *, long unsigned int);
	struct page___101 * (*find_special_page)(struct vm_area_struct___101 *, long unsigned int);
};

struct core_thread___101 {
	struct task_struct___103 *task;
	struct core_thread___101 *next;
};

struct core_state___101 {
	atomic_t nr_threads;
	struct core_thread___101 dumper;
	struct completion startup;
};

struct vm_fault___95 {
	const struct {
		struct vm_area_struct___101 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___101 *cow_page;
	struct page___101 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___101 prealloc_pte;
};

struct cgroup_subsys___79;

struct cgroup_subsys_state___79 {
	struct cgroup___79 *cgroup;
	struct cgroup_subsys___79 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___79 *parent;
};

struct cgroup_file___79 {
	struct kernfs_node___95 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___79 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___103 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___79;

struct cgroup_rstat_cpu___79;

struct cgroup___79 {
	struct cgroup_subsys_state___79 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___95 *kn;
	struct cgroup_file___79 procs_file;
	struct cgroup_file___79 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___79 *subsys[14];
	struct cgroup_root___79 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___79 *dom_cgrp;
	struct cgroup___79 *old_dom_cgrp;
	struct cgroup_rstat_cpu___79 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___79 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___46 {
	struct request_queue___46 *q;
	struct io_context___46 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___48;

struct kiocb___96 {
	struct file___96 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___96 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___48 *ki_waitq;
	};
};

struct iattr___96 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___96 *ia_file;
};

struct dquot___96 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___96 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___96 {
	int qf_fmt_id;
	const struct quota_format_ops___96 *qf_ops;
	struct module___93 *qf_owner;
	struct quota_format_type___96 *qf_next;
};

struct quota_format_ops___96 {
	int (*check_quota_file)(struct super_block___96 *, int);
	int (*read_file_info)(struct super_block___96 *, int);
	int (*write_file_info)(struct super_block___96 *, int);
	int (*free_file_info)(struct super_block___96 *, int);
	int (*read_dqblk)(struct dquot___96 *);
	int (*commit_dqblk)(struct dquot___96 *);
	int (*release_dqblk)(struct dquot___96 *);
	int (*get_next_id)(struct super_block___96 *, struct kqid *);
};

struct dquot_operations___96 {
	int (*write_dquot)(struct dquot___96 *);
	struct dquot___96 * (*alloc_dquot)(struct super_block___96 *, int);
	void (*destroy_dquot)(struct dquot___96 *);
	int (*acquire_dquot)(struct dquot___96 *);
	int (*release_dquot)(struct dquot___96 *);
	int (*mark_dirty)(struct dquot___96 *);
	int (*write_info)(struct super_block___96 *, int);
	qsize_t * (*get_reserved_space)(struct inode___96 *);
	int (*get_projid)(struct inode___96 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___96 *, qsize_t *);
	int (*get_next_id)(struct super_block___96 *, struct kqid *);
};

struct quotactl_ops___96 {
	int (*quota_on)(struct super_block___96 *, int, int, const struct path___96 *);
	int (*quota_off)(struct super_block___96 *, int);
	int (*quota_enable)(struct super_block___96 *, unsigned int);
	int (*quota_disable)(struct super_block___96 *, unsigned int);
	int (*quota_sync)(struct super_block___96 *, int);
	int (*set_info)(struct super_block___96 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___96 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___96 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___96 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___96 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___96 *, unsigned int);
};

struct wait_page_queue___48 {
	struct page___101 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___45;

struct readahead_control___48;

struct address_space_operations___96 {
	int (*writepage)(struct page___101 *, struct writeback_control___45 *);
	int (*readpage)(struct file___96 *, struct page___101 *);
	int (*writepages)(struct address_space___96 *, struct writeback_control___45 *);
	int (*set_page_dirty)(struct page___101 *);
	int (*readpages)(struct file___96 *, struct address_space___96 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___48 *);
	int (*write_begin)(struct file___96 *, struct address_space___96 *, loff_t, unsigned int, unsigned int, struct page___101 **, void **);
	int (*write_end)(struct file___96 *, struct address_space___96 *, loff_t, unsigned int, unsigned int, struct page___101 *, void *);
	sector_t (*bmap)(struct address_space___96 *, sector_t);
	void (*invalidatepage)(struct page___101 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___101 *, gfp_t);
	void (*freepage)(struct page___101 *);
	ssize_t (*direct_IO)(struct kiocb___96 *, struct iov_iter___58 *);
	int (*migratepage)(struct address_space___96 *, struct page___101 *, struct page___101 *, enum migrate_mode);
	bool (*isolate_page)(struct page___101 *, isolate_mode_t);
	void (*putback_page)(struct page___101 *);
	int (*launder_page)(struct page___101 *);
	int (*is_partially_uptodate)(struct page___101 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___101 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___96 *, struct page___101 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___96 *, sector_t *);
	void (*swap_deactivate)(struct file___96 *);
};

struct writeback_control___45 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___45 *wb;
	struct inode___96 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___48 {
	struct file___96 *file;
	struct address_space___96 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___56;

struct iov_iter___58 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___56 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___96 {
	struct dentry___96 * (*lookup)(struct inode___96 *, struct dentry___96 *, unsigned int);
	const char * (*get_link)(struct dentry___96 *, struct inode___96 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___96 *, int);
	struct posix_acl * (*get_acl)(struct inode___96 *, int, bool);
	int (*readlink)(struct dentry___96 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___96 *, struct dentry___96 *, umode_t, bool);
	int (*link)(struct dentry___96 *, struct inode___96 *, struct dentry___96 *);
	int (*unlink)(struct inode___96 *, struct dentry___96 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___96 *, struct dentry___96 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___96 *, struct dentry___96 *, umode_t);
	int (*rmdir)(struct inode___96 *, struct dentry___96 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___96 *, struct dentry___96 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___96 *, struct dentry___96 *, struct inode___96 *, struct dentry___96 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___96 *, struct iattr___96 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___96 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___96 *, char *, size_t);
	int (*fiemap)(struct inode___96 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___96 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___96 *, struct dentry___96 *, struct file___96 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___96 *, struct dentry___96 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___96 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___96 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___96 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___96 {
	void (*fl_copy_lock)(struct file_lock___96 *, struct file_lock___96 *);
	void (*fl_release_private)(struct file_lock___96 *);
};

struct fasync_struct___96;

struct lock_manager_operations___96;

struct file_lock___96 {
	struct file_lock___96 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___96 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___96 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___96 *fl_ops;
	const struct lock_manager_operations___96 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___96 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___96 *);
	int (*lm_grant)(struct file_lock___96 *, int);
	bool (*lm_break)(struct file_lock___96 *);
	int (*lm_change)(struct file_lock___96 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___96 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___96 *);
};

struct fasync_struct___96 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___96 *fa_next;
	struct file___96 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___96 {
	struct inode___96 * (*alloc_inode)(struct super_block___96 *);
	void (*destroy_inode)(struct inode___96 *);
	void (*free_inode)(struct inode___96 *);
	void (*dirty_inode)(struct inode___96 *, int);
	int (*write_inode)(struct inode___96 *, struct writeback_control___45 *);
	int (*drop_inode)(struct inode___96 *);
	void (*evict_inode)(struct inode___96 *);
	void (*put_super)(struct super_block___96 *);
	int (*sync_fs)(struct super_block___96 *, int);
	int (*freeze_super)(struct super_block___96 *);
	int (*freeze_fs)(struct super_block___96 *);
	int (*thaw_super)(struct super_block___96 *);
	int (*unfreeze_fs)(struct super_block___96 *);
	int (*statfs)(struct dentry___96 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___96 *, int *, char *);
	void (*umount_begin)(struct super_block___96 *);
	int (*show_options)(struct seq_file___90 *, struct dentry___96 *);
	int (*show_devname)(struct seq_file___90 *, struct dentry___96 *);
	int (*show_path)(struct seq_file___90 *, struct dentry___96 *);
	int (*show_stats)(struct seq_file___90 *, struct dentry___96 *);
	ssize_t (*quota_read)(struct super_block___96 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___96 *, int, const char *, size_t, loff_t);
	struct dquot___96 ** (*get_dquots)(struct inode___96 *);
	long int (*nr_cached_objects)(struct super_block___96 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___96 *, struct shrink_control___40 *);
	struct file___96 * (*real_loop)(struct file___96 *);
};

struct export_operations___4 {
	int (*encode_fh)(struct inode___96 *, __u32 *, int *, struct inode___96 *);
	struct dentry___96 * (*fh_to_dentry)(struct super_block___96 *, struct fid *, int, int);
	struct dentry___96 * (*fh_to_parent)(struct super_block___96 *, struct fid *, int, int);
	int (*get_name)(struct dentry___96 *, char *, struct dentry___96 *);
	struct dentry___96 * (*get_parent)(struct dentry___96 *);
	int (*commit_metadata)(struct inode___96 *);
	int (*get_uuid)(struct super_block___96 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___96 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___96 *, struct iomap *, int, struct iattr___96 *);
	u64 (*fetch_iversion)(struct inode___96 *);
	long unsigned int flags;
};

struct fscrypt_operations___4 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___96 *, void *, size_t);
	int (*set_context)(struct inode___96 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___96 *);
	bool (*empty_dir)(struct inode___96 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___96 *);
	void (*get_ino_and_lblk_bits)(struct super_block___96 *, int *, int *);
	int (*get_num_devices)(struct super_block___96 *);
	void (*get_devices)(struct super_block___96 *, struct request_queue___46 **);
};

struct unicode_map {
	const char *charset;
	int version;
};

struct wakeup_source___80;

struct dev_pm_info___80 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___80 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___80 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___80;

struct bus_type___80;

struct device_driver___80;

struct dev_pm_domain___80;

struct fwnode_handle___80;

struct class___80;

struct attribute_group___95;

struct device___80 {
	struct kobject___95 kobj;
	struct device___80 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___80 *type;
	struct bus_type___80 *bus;
	struct device_driver___80 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___80 power;
	struct dev_pm_domain___80 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___80 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___80 *class;
	const struct attribute_group___95 **groups;
	void (*release)(struct device___80 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___47 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___96 *bd_inode;
	struct super_block___96 *bd_super;
	void *bd_claiming;
	struct device___80 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___95 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___46 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___96 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___90;

struct seq_file___90 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___90 *op;
	int poll_event;
	const struct file___96 *file;
	void *private;
};

struct fc_log___17;

struct p_log___17 {
	const char *prefix;
	struct fc_log___17 *log;
};

struct fs_context_operations___17;

struct fs_context___17 {
	const struct fs_context_operations___17 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___96 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___96 *root;
	struct user_namespace___14 *user_ns;
	struct net *net_ns;
	const struct cred___13 *cred;
	struct p_log___17 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___46(struct bio___46 *);

struct bio_vec___56 {
	struct page___101 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___46;

struct bio___46 {
	struct bio___46 *bi_next;
	struct block_device___47 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___46 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___45 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___46 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___56 *bi_io_vec;
	struct bio_set___46 *bi_pool;
	struct bio_vec___56 bi_inline_vecs[0];
};

struct tree_descr___2 {
	const char *name;
	const struct file_operations___96 *ops;
	int mode;
};

struct simple_transaction_argresp {
	ssize_t size;
	char data[0];
};

struct dev_pagemap_ops___95 {
	void (*page_free)(struct page___101 *);
	void (*kill)(struct dev_pagemap___95 *);
	void (*cleanup)(struct dev_pagemap___95 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___95 *);
};

struct fwnode_operations___80;

struct fwnode_handle___80 {
	struct fwnode_handle___80 *secondary;
	const struct fwnode_operations___80 *ops;
	struct device___80 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___80;

struct fwnode_endpoint___80;

struct fwnode_operations___80 {
	struct fwnode_handle___80 * (*get)(struct fwnode_handle___80 *);
	void (*put)(struct fwnode_handle___80 *);
	bool (*device_is_available)(const struct fwnode_handle___80 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___80 *, const struct device___80 *);
	bool (*property_present)(const struct fwnode_handle___80 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___80 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___80 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___80 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*get_parent)(const struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*get_next_child_node)(const struct fwnode_handle___80 *, struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*get_named_child_node)(const struct fwnode_handle___80 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___80 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___80 *);
	struct fwnode_handle___80 * (*graph_get_next_endpoint)(const struct fwnode_handle___80 *, struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*graph_get_remote_endpoint)(const struct fwnode_handle___80 *);
	struct fwnode_handle___80 * (*graph_get_port_parent)(struct fwnode_handle___80 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___80 *, struct fwnode_endpoint___80 *);
	int (*add_links)(struct fwnode_handle___80 *);
};

struct fwnode_endpoint___80 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___80 *local_fwnode;
};

struct fwnode_reference_args___80 {
	struct fwnode_handle___80 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___95;

struct kernfs_elem_dir___95 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___95 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___95;

struct kernfs_root___95 {
	struct kernfs_node___95 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___95 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___95 {
	struct kernfs_node___95 *target_kn;
};

struct kernfs_ops___95;

struct kernfs_elem_attr___95 {
	const struct kernfs_ops___95 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___95 *notify_next;
};

struct kernfs_node___95 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___95 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___95 dir;
		struct kernfs_elem_symlink___95 symlink;
		struct kernfs_elem_attr___95 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___95;

struct kernfs_ops___95 {
	int (*open)(struct kernfs_open_file___95 *);
	void (*release)(struct kernfs_open_file___95 *);
	int (*seq_show)(struct seq_file___90 *, void *);
	void * (*seq_start)(struct seq_file___90 *, loff_t *);
	void * (*seq_next)(struct seq_file___90 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___90 *, void *);
	ssize_t (*read)(struct kernfs_open_file___95 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___95 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___95 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___95 *, struct vm_area_struct___101 *);
};

struct kernfs_syscall_ops___95 {
	int (*show_options)(struct seq_file___90 *, struct kernfs_root___95 *);
	int (*mkdir)(struct kernfs_node___95 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___95 *);
	int (*rename)(struct kernfs_node___95 *, struct kernfs_node___95 *, const char *);
	int (*show_path)(struct seq_file___90 *, struct kernfs_node___95 *, struct kernfs_root___95 *);
};

struct kernfs_open_file___95 {
	struct kernfs_node___95 *kn;
	struct file___96 *file;
	struct seq_file___90 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___95 *vm_ops;
};

struct bin_attribute___95;

struct attribute_group___95 {
	const char *name;
	umode_t (*is_visible)(struct kobject___95 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___95 *, struct bin_attribute___95 *, int);
	struct attribute **attrs;
	struct bin_attribute___95 **bin_attrs;
};

struct bin_attribute___95 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___96 * (*f_mapping)();
	ssize_t (*read)(struct file___96 *, struct kobject___95 *, struct bin_attribute___95 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___96 *, struct kobject___95 *, struct bin_attribute___95 *, char *, loff_t, size_t);
	int (*mmap)(struct file___96 *, struct kobject___95 *, struct bin_attribute___95 *, struct vm_area_struct___101 *);
};

struct sysfs_ops___95 {
	ssize_t (*show)(struct kobject___95 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___95 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___95;

struct kset___95 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___95 kobj;
	const struct kset_uevent_ops___95 *uevent_ops;
};

struct kobj_type___95 {
	void (*release)(struct kobject___95 *);
	const struct sysfs_ops___95 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___95 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___95 *);
	const void * (*namespace)(struct kobject___95 *);
	void (*get_ownership)(struct kobject___95 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___95 {
	int (* const filter)(struct kset___95 *, struct kobject___95 *);
	const char * (* const name)(struct kset___95 *, struct kobject___95 *);
	int (* const uevent)(struct kset___95 *, struct kobject___95 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___92 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___92 *);
	int (*get)(char *, const struct kernel_param___92 *);
	void (*free)(void *);
};

struct kparam_array___92;

struct kernel_param___92 {
	const char *name;
	struct module___93 *mod;
	const struct kernel_param_ops___92 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___92 *arr;
	};
};

struct kparam_array___92 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___92 *ops;
	void *elem;
};

struct module_attribute___92 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___92 *, struct module_kobject___92 *, char *);
	ssize_t (*store)(struct module_attribute___92 *, struct module_kobject___92 *, const char *, size_t);
	void (*setup)(struct module___93 *, const char *);
	int (*test)(struct module___93 *);
	void (*free)(struct module___93 *);
};

struct cgroup_namespace___79 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___79 *root_cset;
};

struct dev_pm_ops___80 {
	int (*prepare)(struct device___80 *);
	void (*complete)(struct device___80 *);
	int (*suspend)(struct device___80 *);
	int (*resume)(struct device___80 *);
	int (*freeze)(struct device___80 *);
	int (*thaw)(struct device___80 *);
	int (*poweroff)(struct device___80 *);
	int (*restore)(struct device___80 *);
	int (*suspend_late)(struct device___80 *);
	int (*resume_early)(struct device___80 *);
	int (*freeze_late)(struct device___80 *);
	int (*thaw_early)(struct device___80 *);
	int (*poweroff_late)(struct device___80 *);
	int (*restore_early)(struct device___80 *);
	int (*suspend_noirq)(struct device___80 *);
	int (*resume_noirq)(struct device___80 *);
	int (*freeze_noirq)(struct device___80 *);
	int (*thaw_noirq)(struct device___80 *);
	int (*poweroff_noirq)(struct device___80 *);
	int (*restore_noirq)(struct device___80 *);
	int (*runtime_suspend)(struct device___80 *);
	int (*runtime_resume)(struct device___80 *);
	int (*runtime_idle)(struct device___80 *);
};

struct wakeup_source___80 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___80 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___80 {
	struct dev_pm_ops___80 ops;
	int (*start)(struct device___80 *);
	void (*detach)(struct device___80 *, bool);
	int (*activate)(struct device___80 *);
	void (*sync)(struct device___80 *);
	void (*dismiss)(struct device___80 *);
};

struct bus_type___80 {
	const char *name;
	const char *dev_name;
	struct device___80 *dev_root;
	const struct attribute_group___95 **bus_groups;
	const struct attribute_group___95 **dev_groups;
	const struct attribute_group___95 **drv_groups;
	int (*match)(struct device___80 *, struct device_driver___80 *);
	int (*uevent)(struct device___80 *, struct kobj_uevent_env *);
	int (*probe)(struct device___80 *);
	void (*sync_state)(struct device___80 *);
	void (*remove)(struct device___80 *);
	void (*shutdown)(struct device___80 *);
	int (*online)(struct device___80 *);
	int (*offline)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	int (*num_vf)(struct device___80 *);
	int (*dma_configure)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___80 {
	const char *name;
	struct bus_type___80 *bus;
	struct module___93 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___80 *);
	void (*sync_state)(struct device___80 *);
	int (*remove)(struct device___80 *);
	void (*shutdown)(struct device___80 *);
	int (*suspend)(struct device___80 *, pm_message_t);
	int (*resume)(struct device___80 *);
	const struct attribute_group___95 **groups;
	const struct attribute_group___95 **dev_groups;
	const struct dev_pm_ops___80 *pm;
	void (*coredump)(struct device___80 *);
	struct driver_private *p;
};

struct device_type___80 {
	const char *name;
	const struct attribute_group___95 **groups;
	int (*uevent)(struct device___80 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___80 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___80 *);
	const struct dev_pm_ops___80 *pm;
};

struct class___80 {
	const char *name;
	struct module___93 *owner;
	const struct attribute_group___95 **class_groups;
	const struct attribute_group___95 **dev_groups;
	struct kobject___95 *dev_kobj;
	int (*dev_uevent)(struct device___80 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___80 *, umode_t *);
	void (*class_release)(struct class___80 *);
	void (*dev_release)(struct device___80 *);
	int (*shutdown_pre)(struct device___80 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___80 *);
	void (*get_ownership)(struct device___80 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___80 *pm;
	struct subsys_private *p;
};

struct block_device_operations___46;

struct gendisk___46 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___47 *part0;
	const struct block_device_operations___46 *fops;
	struct request_queue___46 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___45 *bdi;
	struct kobject___95 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___95 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___46 {
	struct bio___46 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___56 *bip_vec;
	struct bio_vec___56 bip_inline_vecs[0];
};

struct blkcg___45;

struct blkg_policy_data___45;

struct blkcg_gq___45 {
	struct request_queue___46 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___45 *blkcg;
	struct blkcg_gq___45 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___45 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___46 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___46(struct request___46 *);

typedef void integrity_complete_fn___46(struct request___46 *, unsigned int);

struct blk_integrity_profile___46 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___46 *prepare_fn;
	integrity_complete_fn___46 *complete_fn;
	const char *name;
};

struct block_device_operations___46 {
	blk_qc_t (*submit_bio)(struct bio___46 *);
	int (*open)(struct block_device___47 *, fmode_t);
	void (*release)(struct gendisk___46 *, fmode_t);
	int (*rw_page)(struct block_device___47 *, sector_t, struct page___101 *, unsigned int);
	int (*ioctl)(struct block_device___47 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___47 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___46 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___46 *);
	int (*getgeo)(struct block_device___47 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___47 *, bool);
	void (*swap_slot_free_notify)(struct block_device___47 *, long unsigned int);
	int (*report_zones)(struct gendisk___46 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___46 *, umode_t *);
	struct module___93 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___46 *, sector_t *);
};

typedef void rq_end_io_fn___46(struct request___46 *, blk_status_t);

struct request___46 {
	struct request_queue___46 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___45 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___46 *bio;
	struct bio___46 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___56 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___46 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___46 *saved_end_io;
		} flush;
	};
	struct gendisk___46 *rq_disk;
	struct block_device___47 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___46 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___45 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___46 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___95 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___96 *debugfs_dir;
	struct dentry___96 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___46;

struct elevator_mq_ops___46 {
	int (*init_sched)(struct request_queue___46 *, struct elevator_type___46 *);
	void (*exit_sched)(struct elevator_queue___46 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___45 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___45 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___45 *);
	bool (*allow_merge)(struct request_queue___46 *, struct request___46 *, struct bio___46 *);
	bool (*bio_merge)(struct request_queue___46 *, struct bio___46 *, unsigned int);
	int (*request_merge)(struct request_queue___46 *, struct request___46 **, struct bio___46 *);
	void (*request_merged)(struct request_queue___46 *, struct request___46 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___46 *, struct request___46 *, struct request___46 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___46 *);
	void (*finish_request)(struct request___46 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___45 *, struct list_head *, bool);
	struct request___46 * (*dispatch_request)(struct blk_mq_hw_ctx___45 *);
	bool (*has_work)(struct blk_mq_hw_ctx___45 *);
	void (*completed_request)(struct request___46 *, u64);
	void (*requeue_request)(struct request___46 *);
	struct request___46 * (*former_request)(struct request_queue___46 *, struct request___46 *);
	struct request___46 * (*next_request)(struct request_queue___46 *, struct request___46 *);
	void (*init_icq)(struct io_cq___46 *);
	void (*exit_icq)(struct io_cq___46 *);
};

struct elv_fs_entry___46;

struct elevator_type___46 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___46 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___46 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___93 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___46 {
	struct elevator_type___46 *type;
	void *elevator_data;
	struct kobject___95 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___46 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___46 *, char *);
	ssize_t (*store)(struct elevator_queue___46 *, const char *, size_t);
};

struct blk_mq_queue_data___45;

struct blk_mq_ops___45 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___45 *, const struct blk_mq_queue_data___45 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___45 *);
	int (*get_budget)(struct request_queue___46 *);
	void (*put_budget)(struct request_queue___46 *, int);
	void (*set_rq_budget_token)(struct request___46 *, int);
	int (*get_rq_budget_token)(struct request___46 *);
	enum blk_eh_timer_return (*timeout)(struct request___46 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___45 *);
	void (*complete)(struct request___46 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___45 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___45 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___45 *, struct request___46 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___45 *, struct request___46 *, unsigned int);
	void (*initialize_rq_fn)(struct request___46 *);
	void (*cleanup_rq)(struct request___46 *);
	bool (*busy)(struct request_queue___46 *);
	int (*map_queues)(struct blk_mq_tag_set___45 *);
	void (*show_rq)(struct seq_file___90 *, struct request___46 *);
};

struct blk_mq_tag_set___45 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___45 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___90 {
	void * (*start)(struct seq_file___90 *, loff_t *);
	void (*stop)(struct seq_file___90 *, void *);
	void * (*next)(struct seq_file___90 *, void *, loff_t *);
	int (*show)(struct seq_file___90 *, void *);
};

struct cftype___79;

struct cgroup_subsys___79 {
	struct cgroup_subsys_state___79 * (*css_alloc)(struct cgroup_subsys_state___79 *);
	int (*css_online)(struct cgroup_subsys_state___79 *);
	void (*css_offline)(struct cgroup_subsys_state___79 *);
	void (*css_released)(struct cgroup_subsys_state___79 *);
	void (*css_free)(struct cgroup_subsys_state___79 *);
	void (*css_reset)(struct cgroup_subsys_state___79 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___79 *, int);
	int (*css_extra_stat_show)(struct seq_file___90 *, struct cgroup_subsys_state___79 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___103 *, struct css_set___79 *);
	void (*cancel_fork)(struct task_struct___103 *, struct css_set___79 *);
	void (*fork)(struct task_struct___103 *);
	void (*exit)(struct task_struct___103 *);
	void (*release)(struct task_struct___103 *);
	void (*bind)(struct cgroup_subsys_state___79 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___79 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___79 *dfl_cftypes;
	struct cftype___79 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___79 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___79 *updated_children;
	struct cgroup___79 *updated_next;
};

struct cgroup_root___79 {
	struct kernfs_root___95 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___79 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___79 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___79 *ss;
	struct list_head node;
	struct kernfs_ops___95 *kf_ops;
	int (*open)(struct kernfs_open_file___95 *);
	void (*release)(struct kernfs_open_file___95 *);
	u64 (*read_u64)(struct cgroup_subsys_state___79 *, struct cftype___79 *);
	s64 (*read_s64)(struct cgroup_subsys_state___79 *, struct cftype___79 *);
	int (*seq_show)(struct seq_file___90 *, void *);
	void * (*seq_start)(struct seq_file___90 *, loff_t *);
	void * (*seq_next)(struct seq_file___90 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___90 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___79 *, struct cftype___79 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___79 *, struct cftype___79 *, s64);
	ssize_t (*write)(struct kernfs_open_file___95 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___95 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___45 {
	struct request___46 *rq;
	bool last;
};

struct blkcg_policy_data___45;

struct blkcg___45 {
	struct cgroup_subsys_state___79 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___45 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___45 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___45 {
	struct blkcg___45 *blkcg;
	int plid;
};

struct blkg_policy_data___45 {
	struct blkcg_gq___45 *blkg;
	int plid;
};

struct fs_parameter___17 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___96 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___17 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___93 *owner;
	char *buffer[8];
};

struct fs_context_operations___17 {
	void (*free)(struct fs_context___17 *);
	int (*dup)(struct fs_context___17 *, struct fs_context___17 *);
	int (*parse_param)(struct fs_context___17 *, struct fs_parameter___17 *);
	int (*parse_monolithic)(struct fs_context___17 *, void *);
	int (*get_tree)(struct fs_context___17 *);
	int (*reconfigure)(struct fs_context___17 *);
};

struct pseudo_fs_context___5 {
	const struct super_operations___96 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___96 *dops;
	long unsigned int magic;
};

struct simple_attr {
	int (*get)(void *, u64 *);
	int (*set)(void *, u64);
	char get_buf[24];
	char set_buf[24];
	void *data;
	const char *fmt;
	struct mutex mutex;
};

struct xa_node___2 {
	unsigned char shift;
	unsigned char offset;
	unsigned char count;
	unsigned char nr_values;
	struct xa_node___2 *parent;
	struct xarray *array;
	union {
		struct list_head private_list;
		struct callback_head callback_head;
	};
	void *slots[64];
	union {
		long unsigned int tags[3];
		long unsigned int marks[3];
	};
};

typedef void (*xa_update_node_t___2)(struct xa_node___2 *);

struct xa_state___2 {
	struct xarray *xa;
	long unsigned int xa_index;
	unsigned char xa_shift;
	unsigned char xa_sibs;
	unsigned char xa_offset;
	unsigned char xa_pad;
	struct xa_node___2 *xa_node;
	struct xa_node___2 *xa_alloc;
	xa_update_node_t___2 xa_update;
};

struct wb_writeback_work {
	long int nr_pages;
	struct super_block___78 *sb;
	enum writeback_sync_modes sync_mode;
	unsigned int tagged_writepages: 1;
	unsigned int for_kupdate: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_background: 1;
	unsigned int for_sync: 1;
	unsigned int auto_free: 1;
	long: 63;
	long: 64;
	long: 64;
	enum wb_reason reason;
	struct list_head list;
	struct wb_completion *done;
};

struct trace_event_raw_writeback_page_template {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	long unsigned int index;
	char __data[0];
};

struct trace_event_raw_writeback_dirty_inode_template {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	long unsigned int state;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_inode_foreign_history {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	ino_t cgroup_ino;
	unsigned int history;
	char __data[0];
};

struct trace_event_raw_inode_switch_wbs {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	ino_t old_cgroup_ino;
	ino_t new_cgroup_ino;
	char __data[0];
};

struct trace_event_raw_track_foreign_dirty {
	struct trace_entry ent;
	char name[32];
	u64 bdi_id;
	ino_t ino;
	unsigned int memcg_id;
	ino_t cgroup_ino;
	ino_t page_cgroup_ino;
	char __data[0];
};

struct trace_event_raw_flush_foreign {
	struct trace_entry ent;
	char name[32];
	ino_t cgroup_ino;
	unsigned int frn_bdi_id;
	unsigned int frn_memcg_id;
	char __data[0];
};

struct trace_event_raw_writeback_write_inode_template {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	int sync_mode;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_work_class {
	struct trace_entry ent;
	char name[32];
	long int nr_pages;
	dev_t sb_dev;
	int sync_mode;
	int for_kupdate;
	int range_cyclic;
	int for_background;
	int reason;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_pages_written {
	struct trace_entry ent;
	long int pages;
	char __data[0];
};

struct trace_event_raw_writeback_class {
	struct trace_entry ent;
	char name[32];
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_bdi_register {
	struct trace_entry ent;
	char name[32];
	char __data[0];
};

struct trace_event_raw_wbc_class {
	struct trace_entry ent;
	char name[32];
	long int nr_to_write;
	long int pages_skipped;
	int sync_mode;
	int for_kupdate;
	int for_background;
	int for_reclaim;
	int range_cyclic;
	long int range_start;
	long int range_end;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_queue_io {
	struct trace_entry ent;
	char name[32];
	long unsigned int older;
	long int age;
	int moved;
	int reason;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_global_dirty_state {
	struct trace_entry ent;
	long unsigned int nr_dirty;
	long unsigned int nr_writeback;
	long unsigned int background_thresh;
	long unsigned int dirty_thresh;
	long unsigned int dirty_limit;
	long unsigned int nr_dirtied;
	long unsigned int nr_written;
	char __data[0];
};

struct trace_event_raw_bdi_dirty_ratelimit {
	struct trace_entry ent;
	char bdi[32];
	long unsigned int write_bw;
	long unsigned int avg_write_bw;
	long unsigned int dirty_rate;
	long unsigned int dirty_ratelimit;
	long unsigned int task_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_balance_dirty_pages {
	struct trace_entry ent;
	char bdi[32];
	long unsigned int limit;
	long unsigned int setpoint;
	long unsigned int dirty;
	long unsigned int bdi_setpoint;
	long unsigned int bdi_dirty;
	long unsigned int dirty_ratelimit;
	long unsigned int task_ratelimit;
	unsigned int dirtied;
	unsigned int dirtied_pause;
	long unsigned int paused;
	long int pause;
	long unsigned int period;
	long int think;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_sb_inodes_requeue {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	long unsigned int state;
	long unsigned int dirtied_when;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_congest_waited_template {
	struct trace_entry ent;
	unsigned int usec_timeout;
	unsigned int usec_delayed;
	char __data[0];
};

struct trace_event_raw_writeback_single_inode_template {
	struct trace_entry ent;
	char name[32];
	ino_t ino;
	long unsigned int state;
	long unsigned int dirtied_when;
	long unsigned int writeback_index;
	long int nr_to_write;
	long unsigned int wrote;
	ino_t cgroup_ino;
	char __data[0];
};

struct trace_event_raw_writeback_inode_template {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	long unsigned int state;
	__u16 mode;
	long unsigned int dirtied_when;
	char __data[0];
};

struct trace_event_data_offsets_writeback_page_template {};

struct trace_event_data_offsets_writeback_dirty_inode_template {};

struct trace_event_data_offsets_inode_foreign_history {};

struct trace_event_data_offsets_inode_switch_wbs {};

struct trace_event_data_offsets_track_foreign_dirty {};

struct trace_event_data_offsets_flush_foreign {};

struct trace_event_data_offsets_writeback_write_inode_template {};

struct trace_event_data_offsets_writeback_work_class {};

struct trace_event_data_offsets_writeback_pages_written {};

struct trace_event_data_offsets_writeback_class {};

struct trace_event_data_offsets_writeback_bdi_register {};

struct trace_event_data_offsets_wbc_class {};

struct trace_event_data_offsets_writeback_queue_io {};

struct trace_event_data_offsets_global_dirty_state {};

struct trace_event_data_offsets_bdi_dirty_ratelimit {};

struct trace_event_data_offsets_balance_dirty_pages {};

struct trace_event_data_offsets_writeback_sb_inodes_requeue {};

struct trace_event_data_offsets_writeback_congest_waited_template {};

struct trace_event_data_offsets_writeback_single_inode_template {};

struct trace_event_data_offsets_writeback_inode_template {};

typedef void (*btf_trace_writeback_dirty_page)(void *, struct page___83 *, struct address_space___78 *);

typedef void (*btf_trace_wait_on_page_writeback)(void *, struct page___83 *, struct address_space___78 *);

typedef void (*btf_trace_writeback_mark_inode_dirty)(void *, struct inode___78 *, int);

typedef void (*btf_trace_writeback_dirty_inode_start)(void *, struct inode___78 *, int);

typedef void (*btf_trace_writeback_dirty_inode)(void *, struct inode___78 *, int);

typedef void (*btf_trace_inode_foreign_history)(void *, struct inode___78 *, struct writeback_control___37 *, unsigned int);

typedef void (*btf_trace_inode_switch_wbs)(void *, struct inode___78 *, struct bdi_writeback___37 *, struct bdi_writeback___37 *);

typedef void (*btf_trace_track_foreign_dirty)(void *, struct page___83 *, struct bdi_writeback___37 *);

typedef void (*btf_trace_flush_foreign)(void *, struct bdi_writeback___37 *, unsigned int, unsigned int);

typedef void (*btf_trace_writeback_write_inode_start)(void *, struct inode___78 *, struct writeback_control___37 *);

typedef void (*btf_trace_writeback_write_inode)(void *, struct inode___78 *, struct writeback_control___37 *);

typedef void (*btf_trace_writeback_queue)(void *, struct bdi_writeback___37 *, struct wb_writeback_work *);

typedef void (*btf_trace_writeback_exec)(void *, struct bdi_writeback___37 *, struct wb_writeback_work *);

typedef void (*btf_trace_writeback_start)(void *, struct bdi_writeback___37 *, struct wb_writeback_work *);

typedef void (*btf_trace_writeback_written)(void *, struct bdi_writeback___37 *, struct wb_writeback_work *);

typedef void (*btf_trace_writeback_wait)(void *, struct bdi_writeback___37 *, struct wb_writeback_work *);

typedef void (*btf_trace_writeback_pages_written)(void *, long int);

typedef void (*btf_trace_writeback_wake_background)(void *, struct bdi_writeback___37 *);

typedef void (*btf_trace_writeback_bdi_register)(void *, struct backing_dev_info___37 *);

typedef void (*btf_trace_wbc_writepage)(void *, struct writeback_control___37 *, struct backing_dev_info___37 *);

typedef void (*btf_trace_writeback_queue_io)(void *, struct bdi_writeback___37 *, struct wb_writeback_work *, long unsigned int, int);

typedef void (*btf_trace_global_dirty_state)(void *, long unsigned int, long unsigned int);

typedef void (*btf_trace_bdi_dirty_ratelimit)(void *, struct bdi_writeback___37 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_balance_dirty_pages)(void *, struct bdi_writeback___37 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long unsigned int, long int, long unsigned int);

typedef void (*btf_trace_writeback_sb_inodes_requeue)(void *, struct inode___78 *);

typedef void (*btf_trace_writeback_congestion_wait)(void *, unsigned int, unsigned int);

typedef void (*btf_trace_writeback_wait_iff_congested)(void *, unsigned int, unsigned int);

typedef void (*btf_trace_writeback_single_inode_start)(void *, struct inode___78 *, struct writeback_control___37 *, long unsigned int);

typedef void (*btf_trace_writeback_single_inode)(void *, struct inode___78 *, struct writeback_control___37 *, long unsigned int);

typedef void (*btf_trace_writeback_lazytime)(void *, struct inode___78 *);

typedef void (*btf_trace_writeback_lazytime_iput)(void *, struct inode___78 *);

typedef void (*btf_trace_writeback_dirty_inode_enqueue)(void *, struct inode___78 *);

typedef void (*btf_trace_sb_mark_inode_writeback)(void *, struct inode___78 *);

typedef void (*btf_trace_sb_clear_inode_writeback)(void *, struct inode___78 *);

struct inode_switch_wbs_context {
	struct rcu_work work;
	struct bdi_writeback___37 *new_wb;
	struct inode___78 *inodes[0];
};

struct fd___21 {
	struct file___75 *file;
	unsigned int flags;
};

struct splice_desc {
	size_t total_len;
	unsigned int len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___75 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

struct splice_pipe_desc___3 {
	struct page___80 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___32 *ops;
	void (*spd_release)(struct splice_pipe_desc___3 *, unsigned int);
};

typedef int splice_actor(struct pipe_inode_info___32 *, struct pipe_buffer___32 *, struct splice_desc *);

typedef int splice_direct_actor(struct pipe_inode_info___32 *, struct splice_desc *);

struct old_utimbuf32 {
	old_time32_t actime;
	old_time32_t modtime;
};

struct dentry___97;

struct super_block___97;

struct module___94;

struct file_system_type___97 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___97 * (*mount)(struct file_system_type___97 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___97 *);
	struct module___94 *owner;
	struct file_system_type___97 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___97;

struct kiocb___97;

struct poll_table_struct___70;

struct vm_area_struct___102;

struct inode___97;

struct file_lock___97;

struct page___102;

struct seq_file___91;

struct file_operations___97 {
	struct module___94 *owner;
	loff_t (*llseek)(struct file___97 *, loff_t, int);
	ssize_t (*read)(struct file___97 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___97 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___97 *, struct iov_iter___58 *);
	ssize_t (*write_iter)(struct kiocb___97 *, struct iov_iter___58 *);
	int (*iopoll)(struct kiocb___97 *, bool);
	int (*iterate)(struct file___97 *, struct dir_context *);
	int (*iterate_shared)(struct file___97 *, struct dir_context *);
	__poll_t (*poll)(struct file___97 *, struct poll_table_struct___70 *);
	long int (*unlocked_ioctl)(struct file___97 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___97 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___97 *, struct vm_area_struct___102 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___97 *, struct file___97 *);
	int (*flush)(struct file___97 *, fl_owner_t);
	int (*release)(struct inode___97 *, struct file___97 *);
	int (*fsync)(struct file___97 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___97 *, int);
	int (*lock)(struct file___97 *, int, struct file_lock___97 *);
	ssize_t (*sendpage)(struct file___97 *, struct page___102 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___97 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___97 *, long unsigned int);
	int (*flock)(struct file___97 *, int, struct file_lock___97 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___97 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___97 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___97 *, long int, struct file_lock___97 **, void **);
	long int (*fallocate)(struct file___97 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___91 *, struct file___97 *);
	ssize_t (*copy_file_range)(struct file___97 *, loff_t, struct file___97 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___97 *, loff_t, struct file___97 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___97 *, loff_t, loff_t, int);
};

struct vmacache___102 {
	u64 seqnum;
	struct vm_area_struct___102 *vmas[4];
};

struct page_frag___102 {
	struct page___102 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___59;

struct debug_info___59 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___59 *hbp_break[16];
	struct perf_event___59 *hbp_watch[16];
};

struct thread_struct___59 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___59 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___103;

struct pid___89;

struct fs_struct___13;

struct nsproxy___94;

struct signal_struct___98;

struct css_set___80;

struct perf_event_context___59;

struct vm_struct___96;

struct task_struct___104 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___104 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___103 *mm;
	struct mm_struct___103 *active_mm;
	struct vmacache___102 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___104 *real_parent;
	struct task_struct___104 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___104 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___89 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___13 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___94 *nsproxy;
	struct signal_struct___98 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___104 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___46 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___80 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___59 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___102 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___104 *oom_reaper_list;
	struct vm_struct___96 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___59 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___96;

struct kobj_type___96;

struct kernfs_node___96;

struct kobject___96 {
	const char *name;
	struct list_head entry;
	struct kobject___96 *parent;
	struct kset___96 *kset;
	struct kobj_type___96 *ktype;
	struct kernfs_node___96 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___93 {
	struct kobject___96 kobj;
	struct module___94 *mod;
	struct kobject___96 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___93 {
	struct module___94 *mod;
	struct latch_tree_node node;
};

struct module_layout___93 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___93 mtn;
};

struct module_attribute___93;

struct kernel_param___93;

struct trace_event_call___53;

struct module___94 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___93 mkobj;
	struct module_attribute___93 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___96 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___93 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___93 core_layout;
	struct module_layout___93 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___53 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___59 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___104 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___59)(struct perf_event___59 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___59;

struct fasync_struct___97;

struct pid_namespace___89;

struct perf_cgroup___59;

struct perf_event___59 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___59 *group_leader;
	struct pmu___59 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___59 hw;
	struct perf_event_context___59 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___59 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___104 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___97 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___59 *aux_event;
	void (*destroy)(struct perf_event___59 *);
	struct callback_head callback_head;
	struct pid_namespace___89 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___59 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___59 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___53 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___59 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___97;

struct dentry___97 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___97 *d_parent;
	struct qstr d_name;
	struct inode___97 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___97 *d_op;
	struct super_block___97 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___97;

struct address_space___97 {
	struct inode___97 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___97 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___97;

struct inode___97 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___97 *i_op;
	struct super_block___97 *i_sb;
	struct address_space___97 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___97 *i_fop;
		void (*free_inode)(struct inode___97 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___97 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___37 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___97;

struct path___97;

struct dentry_operations___97 {
	int (*d_revalidate)(struct dentry___97 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___97 *, unsigned int);
	int (*d_hash)(const struct dentry___97 *, struct qstr *);
	int (*d_compare)(const struct dentry___97 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___97 *);
	int (*d_init)(struct dentry___97 *);
	void (*d_release)(struct dentry___97 *);
	void (*d_prune)(struct dentry___97 *);
	void (*d_iput)(struct dentry___97 *, struct inode___97 *);
	char * (*d_dname)(struct dentry___97 *, char *, int);
	struct vfsmount___97 * (*d_automount)(struct path___97 *);
	int (*d_manage)(const struct path___97 *, bool);
	struct dentry___97 * (*d_real)(struct dentry___97 *, const struct inode___97 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___97;

struct mem_dqinfo___97 {
	struct quota_format_type___97 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___97;

struct quota_info___97 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___97 *files[3];
	struct mem_dqinfo___97 info[3];
	const struct quota_format_ops___97 *ops[3];
};

struct rcuwait___98 {
	struct task_struct___104 *task;
};

struct percpu_rw_semaphore___98 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___98 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___97 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___98 rw_sem[3];
};

struct super_operations___97;

struct dquot_operations___97;

struct quotactl_ops___97;

struct super_block___97 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___97 *s_type;
	const struct super_operations___97 *s_op;
	const struct dquot_operations___97 *dq_op;
	const struct quotactl_ops___97 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___97 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___97 s_dquot;
	struct sb_writers___97 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___97 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___97 {
	struct dentry___97 *mnt_root;
	struct super_block___97 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___97 {
	struct vfsmount___97 *mnt;
	struct dentry___97 *dentry;
};

struct upid___89 {
	int nr;
	struct pid_namespace___89 *ns;
};

struct pid_namespace___89 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___104 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___89 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___89 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___89 numbers[1];
};

typedef struct page___102 *pgtable_t___102;

struct dev_pagemap___96;

struct page___102 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___97 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___30 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___102 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___102 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___103 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___96 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___96;

struct vm_area_struct___102 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___102 *vm_next;
	struct vm_area_struct___102 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___103 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___96 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___97 *vm_file;
	struct file___97 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___98 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___104 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___104 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___89 *pids[4];
	struct pid___89 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___103 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___102;

struct mm_struct___103 {
	struct {
		struct vm_area_struct___102 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___97 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___102 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___104 *owner;
		struct user_namespace___14 *user_ns;
		struct file___97 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fs_struct___13 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___97 root;
	struct path___97 pwd;
};

struct mnt_namespace___5;

struct cgroup_namespace___80;

struct nsproxy___94 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___5 *mnt_ns;
	struct pid_namespace___89 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___80 *cgroup_ns;
};

struct cgroup_subsys_state___80;

struct cgroup___80;

struct css_set___80 {
	struct cgroup_subsys_state___80 *subsys[14];
	refcount_t refcount;
	struct css_set___80 *dom_cset;
	struct cgroup___80 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___80 *mg_src_cgrp;
	struct cgroup___80 *mg_dst_cgrp;
	struct css_set___80 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___59 {
	struct pmu___59 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___104 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___59 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___96 {
	struct vm_struct___96 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___102 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___96;

struct dev_pagemap___96 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___96 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___89 {
	rwlock_t lock;
	struct pid___89 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___97 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___97 f_path;
	struct inode___97 *f_inode;
	const struct file_operations___97 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___89 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___97 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___96;

struct vm_operations_struct___96 {
	void (*open)(struct vm_area_struct___102 *);
	void (*close)(struct vm_area_struct___102 *);
	int (*may_split)(struct vm_area_struct___102 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___102 *);
	int (*mprotect)(struct vm_area_struct___102 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___96 *);
	vm_fault_t (*huge_fault)(struct vm_fault___96 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___96 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___102 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___96 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___96 *);
	int (*access)(struct vm_area_struct___102 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___102 *);
	int (*set_policy)(struct vm_area_struct___102 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___102 *, long unsigned int);
	struct page___102 * (*find_special_page)(struct vm_area_struct___102 *, long unsigned int);
};

struct core_thread___102 {
	struct task_struct___104 *task;
	struct core_thread___102 *next;
};

struct core_state___102 {
	atomic_t nr_threads;
	struct core_thread___102 dumper;
	struct completion startup;
};

struct vm_fault___96 {
	const struct {
		struct vm_area_struct___102 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___102 *cow_page;
	struct page___102 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___102 prealloc_pte;
};

struct cgroup_subsys___80;

struct cgroup_subsys_state___80 {
	struct cgroup___80 *cgroup;
	struct cgroup_subsys___80 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___80 *parent;
};

struct cgroup_file___80 {
	struct kernfs_node___96 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___80 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___104 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___80;

struct cgroup_rstat_cpu___80;

struct cgroup___80 {
	struct cgroup_subsys_state___80 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___96 *kn;
	struct cgroup_file___80 procs_file;
	struct cgroup_file___80 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___80 *subsys[14];
	struct cgroup_root___80 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___80 *dom_cgrp;
	struct cgroup___80 *old_dom_cgrp;
	struct cgroup_rstat_cpu___80 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___80 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___97 {
	struct file___97 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___97 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___48 *ki_waitq;
	};
};

struct iattr___97 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___97 *ia_file;
};

struct dquot___97 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___97 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___97 {
	int qf_fmt_id;
	const struct quota_format_ops___97 *qf_ops;
	struct module___94 *qf_owner;
	struct quota_format_type___97 *qf_next;
};

struct quota_format_ops___97 {
	int (*check_quota_file)(struct super_block___97 *, int);
	int (*read_file_info)(struct super_block___97 *, int);
	int (*write_file_info)(struct super_block___97 *, int);
	int (*free_file_info)(struct super_block___97 *, int);
	int (*read_dqblk)(struct dquot___97 *);
	int (*commit_dqblk)(struct dquot___97 *);
	int (*release_dqblk)(struct dquot___97 *);
	int (*get_next_id)(struct super_block___97 *, struct kqid *);
};

struct dquot_operations___97 {
	int (*write_dquot)(struct dquot___97 *);
	struct dquot___97 * (*alloc_dquot)(struct super_block___97 *, int);
	void (*destroy_dquot)(struct dquot___97 *);
	int (*acquire_dquot)(struct dquot___97 *);
	int (*release_dquot)(struct dquot___97 *);
	int (*mark_dirty)(struct dquot___97 *);
	int (*write_info)(struct super_block___97 *, int);
	qsize_t * (*get_reserved_space)(struct inode___97 *);
	int (*get_projid)(struct inode___97 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___97 *, qsize_t *);
	int (*get_next_id)(struct super_block___97 *, struct kqid *);
};

struct quotactl_ops___97 {
	int (*quota_on)(struct super_block___97 *, int, int, const struct path___97 *);
	int (*quota_off)(struct super_block___97 *, int);
	int (*quota_enable)(struct super_block___97 *, unsigned int);
	int (*quota_disable)(struct super_block___97 *, unsigned int);
	int (*quota_sync)(struct super_block___97 *, int);
	int (*set_info)(struct super_block___97 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___97 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___97 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___97 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___97 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___97 *, unsigned int);
};

struct address_space_operations___97 {
	int (*writepage)(struct page___102 *, struct writeback_control___3 *);
	int (*readpage)(struct file___97 *, struct page___102 *);
	int (*writepages)(struct address_space___97 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___102 *);
	int (*readpages)(struct file___97 *, struct address_space___97 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___97 *, struct address_space___97 *, loff_t, unsigned int, unsigned int, struct page___102 **, void **);
	int (*write_end)(struct file___97 *, struct address_space___97 *, loff_t, unsigned int, unsigned int, struct page___102 *, void *);
	sector_t (*bmap)(struct address_space___97 *, sector_t);
	void (*invalidatepage)(struct page___102 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___102 *, gfp_t);
	void (*freepage)(struct page___102 *);
	ssize_t (*direct_IO)(struct kiocb___97 *, struct iov_iter___58 *);
	int (*migratepage)(struct address_space___97 *, struct page___102 *, struct page___102 *, enum migrate_mode);
	bool (*isolate_page)(struct page___102 *, isolate_mode_t);
	void (*putback_page)(struct page___102 *);
	int (*launder_page)(struct page___102 *);
	int (*is_partially_uptodate)(struct page___102 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___102 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___97 *, struct page___102 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___97 *, sector_t *);
	void (*swap_deactivate)(struct file___97 *);
};

struct inode_operations___97 {
	struct dentry___97 * (*lookup)(struct inode___97 *, struct dentry___97 *, unsigned int);
	const char * (*get_link)(struct dentry___97 *, struct inode___97 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___97 *, int);
	struct posix_acl * (*get_acl)(struct inode___97 *, int, bool);
	int (*readlink)(struct dentry___97 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___97 *, struct dentry___97 *, umode_t, bool);
	int (*link)(struct dentry___97 *, struct inode___97 *, struct dentry___97 *);
	int (*unlink)(struct inode___97 *, struct dentry___97 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___97 *, struct dentry___97 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___97 *, struct dentry___97 *, umode_t);
	int (*rmdir)(struct inode___97 *, struct dentry___97 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___97 *, struct dentry___97 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___97 *, struct dentry___97 *, struct inode___97 *, struct dentry___97 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___97 *, struct iattr___97 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___97 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___97 *, char *, size_t);
	int (*fiemap)(struct inode___97 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___97 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___97 *, struct dentry___97 *, struct file___97 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___97 *, struct dentry___97 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___97 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___97 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___97 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___97 {
	void (*fl_copy_lock)(struct file_lock___97 *, struct file_lock___97 *);
	void (*fl_release_private)(struct file_lock___97 *);
};

struct lock_manager_operations___97;

struct file_lock___97 {
	struct file_lock___97 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___97 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___97 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___97 *fl_ops;
	const struct lock_manager_operations___97 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___97 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___97 *);
	int (*lm_grant)(struct file_lock___97 *, int);
	bool (*lm_break)(struct file_lock___97 *);
	int (*lm_change)(struct file_lock___97 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___97 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___97 *);
};

struct fasync_struct___97 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___97 *fa_next;
	struct file___97 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___97 {
	struct inode___97 * (*alloc_inode)(struct super_block___97 *);
	void (*destroy_inode)(struct inode___97 *);
	void (*free_inode)(struct inode___97 *);
	void (*dirty_inode)(struct inode___97 *, int);
	int (*write_inode)(struct inode___97 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___97 *);
	void (*evict_inode)(struct inode___97 *);
	void (*put_super)(struct super_block___97 *);
	int (*sync_fs)(struct super_block___97 *, int);
	int (*freeze_super)(struct super_block___97 *);
	int (*freeze_fs)(struct super_block___97 *);
	int (*thaw_super)(struct super_block___97 *);
	int (*unfreeze_fs)(struct super_block___97 *);
	int (*statfs)(struct dentry___97 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___97 *, int *, char *);
	void (*umount_begin)(struct super_block___97 *);
	int (*show_options)(struct seq_file___91 *, struct dentry___97 *);
	int (*show_devname)(struct seq_file___91 *, struct dentry___97 *);
	int (*show_path)(struct seq_file___91 *, struct dentry___97 *);
	int (*show_stats)(struct seq_file___91 *, struct dentry___97 *);
	ssize_t (*quota_read)(struct super_block___97 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___97 *, int, const char *, size_t, loff_t);
	struct dquot___97 ** (*get_dquots)(struct inode___97 *);
	long int (*nr_cached_objects)(struct super_block___97 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___97 *, struct shrink_control___40 *);
	struct file___97 * (*real_loop)(struct file___97 *);
};

typedef void (*poll_queue_proc___70)(struct file___97 *, wait_queue_head_t *, struct poll_table_struct___70 *);

struct poll_table_struct___70 {
	poll_queue_proc___70 _qproc;
	__poll_t _key;
};

struct seq_operations___91;

struct seq_file___91 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___91 *op;
	int poll_event;
	const struct file___97 *file;
	void *private;
};

struct kernfs_root___96;

struct kernfs_elem_dir___96 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___96 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___96;

struct kernfs_root___96 {
	struct kernfs_node___96 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___96 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___96 {
	struct kernfs_node___96 *target_kn;
};

struct kernfs_ops___96;

struct kernfs_elem_attr___96 {
	const struct kernfs_ops___96 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___96 *notify_next;
};

struct kernfs_node___96 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___96 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___96 dir;
		struct kernfs_elem_symlink___96 symlink;
		struct kernfs_elem_attr___96 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___96;

struct kernfs_ops___96 {
	int (*open)(struct kernfs_open_file___96 *);
	void (*release)(struct kernfs_open_file___96 *);
	int (*seq_show)(struct seq_file___91 *, void *);
	void * (*seq_start)(struct seq_file___91 *, loff_t *);
	void * (*seq_next)(struct seq_file___91 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___91 *, void *);
	ssize_t (*read)(struct kernfs_open_file___96 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___96 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___96 *, struct poll_table_struct___70 *);
	int (*mmap)(struct kernfs_open_file___96 *, struct vm_area_struct___102 *);
};

struct kernfs_syscall_ops___96 {
	int (*show_options)(struct seq_file___91 *, struct kernfs_root___96 *);
	int (*mkdir)(struct kernfs_node___96 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___96 *);
	int (*rename)(struct kernfs_node___96 *, struct kernfs_node___96 *, const char *);
	int (*show_path)(struct seq_file___91 *, struct kernfs_node___96 *, struct kernfs_root___96 *);
};

struct kernfs_open_file___96 {
	struct kernfs_node___96 *kn;
	struct file___97 *file;
	struct seq_file___91 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___96 *vm_ops;
};

struct bin_attribute___96;

struct attribute_group___96 {
	const char *name;
	umode_t (*is_visible)(struct kobject___96 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___96 *, struct bin_attribute___96 *, int);
	struct attribute **attrs;
	struct bin_attribute___96 **bin_attrs;
};

struct bin_attribute___96 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___97 * (*f_mapping)();
	ssize_t (*read)(struct file___97 *, struct kobject___96 *, struct bin_attribute___96 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___97 *, struct kobject___96 *, struct bin_attribute___96 *, char *, loff_t, size_t);
	int (*mmap)(struct file___97 *, struct kobject___96 *, struct bin_attribute___96 *, struct vm_area_struct___102 *);
};

struct sysfs_ops___96 {
	ssize_t (*show)(struct kobject___96 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___96 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___96;

struct kset___96 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___96 kobj;
	const struct kset_uevent_ops___96 *uevent_ops;
};

struct kobj_type___96 {
	void (*release)(struct kobject___96 *);
	const struct sysfs_ops___96 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___96 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___96 *);
	const void * (*namespace)(struct kobject___96 *);
	void (*get_ownership)(struct kobject___96 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___96 {
	int (* const filter)(struct kset___96 *, struct kobject___96 *);
	const char * (* const name)(struct kset___96 *, struct kobject___96 *);
	int (* const uevent)(struct kset___96 *, struct kobject___96 *, struct kobj_uevent_env *);
};

struct wakeup_source___81;

struct device___81;

struct dev_pm_info___81 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___81 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___81 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___81;

struct bus_type___81;

struct device_driver___81;

struct dev_pm_domain___81;

struct fwnode_handle___81;

struct class___81;

struct device___81 {
	struct kobject___96 kobj;
	struct device___81 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___81 *type;
	struct bus_type___81 *bus;
	struct device_driver___81 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___81 power;
	struct dev_pm_domain___81 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___81 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___81 *class;
	const struct attribute_group___96 **groups;
	void (*release)(struct device___81 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___81 {
	int (*prepare)(struct device___81 *);
	void (*complete)(struct device___81 *);
	int (*suspend)(struct device___81 *);
	int (*resume)(struct device___81 *);
	int (*freeze)(struct device___81 *);
	int (*thaw)(struct device___81 *);
	int (*poweroff)(struct device___81 *);
	int (*restore)(struct device___81 *);
	int (*suspend_late)(struct device___81 *);
	int (*resume_early)(struct device___81 *);
	int (*freeze_late)(struct device___81 *);
	int (*thaw_early)(struct device___81 *);
	int (*poweroff_late)(struct device___81 *);
	int (*restore_early)(struct device___81 *);
	int (*suspend_noirq)(struct device___81 *);
	int (*resume_noirq)(struct device___81 *);
	int (*freeze_noirq)(struct device___81 *);
	int (*thaw_noirq)(struct device___81 *);
	int (*poweroff_noirq)(struct device___81 *);
	int (*restore_noirq)(struct device___81 *);
	int (*runtime_suspend)(struct device___81 *);
	int (*runtime_resume)(struct device___81 *);
	int (*runtime_idle)(struct device___81 *);
};

struct wakeup_source___81 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___81 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___81 {
	struct dev_pm_ops___81 ops;
	int (*start)(struct device___81 *);
	void (*detach)(struct device___81 *, bool);
	int (*activate)(struct device___81 *);
	void (*sync)(struct device___81 *);
	void (*dismiss)(struct device___81 *);
};

struct bus_type___81 {
	const char *name;
	const char *dev_name;
	struct device___81 *dev_root;
	const struct attribute_group___96 **bus_groups;
	const struct attribute_group___96 **dev_groups;
	const struct attribute_group___96 **drv_groups;
	int (*match)(struct device___81 *, struct device_driver___81 *);
	int (*uevent)(struct device___81 *, struct kobj_uevent_env *);
	int (*probe)(struct device___81 *);
	void (*sync_state)(struct device___81 *);
	void (*remove)(struct device___81 *);
	void (*shutdown)(struct device___81 *);
	int (*online)(struct device___81 *);
	int (*offline)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	int (*num_vf)(struct device___81 *);
	int (*dma_configure)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___81 {
	const char *name;
	struct bus_type___81 *bus;
	struct module___94 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___81 *);
	void (*sync_state)(struct device___81 *);
	int (*remove)(struct device___81 *);
	void (*shutdown)(struct device___81 *);
	int (*suspend)(struct device___81 *, pm_message_t);
	int (*resume)(struct device___81 *);
	const struct attribute_group___96 **groups;
	const struct attribute_group___96 **dev_groups;
	const struct dev_pm_ops___81 *pm;
	void (*coredump)(struct device___81 *);
	struct driver_private *p;
};

struct device_type___81 {
	const char *name;
	const struct attribute_group___96 **groups;
	int (*uevent)(struct device___81 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___81 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___81 *);
	const struct dev_pm_ops___81 *pm;
};

struct class___81 {
	const char *name;
	struct module___94 *owner;
	const struct attribute_group___96 **class_groups;
	const struct attribute_group___96 **dev_groups;
	struct kobject___96 *dev_kobj;
	int (*dev_uevent)(struct device___81 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___81 *, umode_t *);
	void (*class_release)(struct class___81 *);
	void (*dev_release)(struct device___81 *);
	int (*shutdown_pre)(struct device___81 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___81 *);
	void (*get_ownership)(struct device___81 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___81 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___81;

struct fwnode_handle___81 {
	struct fwnode_handle___81 *secondary;
	const struct fwnode_operations___81 *ops;
	struct device___81 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___96 {
	void (*page_free)(struct page___102 *);
	void (*kill)(struct dev_pagemap___96 *);
	void (*cleanup)(struct dev_pagemap___96 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___96 *);
};

struct seq_operations___91 {
	void * (*start)(struct seq_file___91 *, loff_t *);
	void (*stop)(struct seq_file___91 *, void *);
	void * (*next)(struct seq_file___91 *, void *, loff_t *);
	int (*show)(struct seq_file___91 *, void *);
};

struct fwnode_reference_args___81;

struct fwnode_endpoint___81;

struct fwnode_operations___81 {
	struct fwnode_handle___81 * (*get)(struct fwnode_handle___81 *);
	void (*put)(struct fwnode_handle___81 *);
	bool (*device_is_available)(const struct fwnode_handle___81 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___81 *, const struct device___81 *);
	bool (*property_present)(const struct fwnode_handle___81 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___81 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___81 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___81 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*get_parent)(const struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*get_next_child_node)(const struct fwnode_handle___81 *, struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*get_named_child_node)(const struct fwnode_handle___81 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___81 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___81 *);
	struct fwnode_handle___81 * (*graph_get_next_endpoint)(const struct fwnode_handle___81 *, struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*graph_get_remote_endpoint)(const struct fwnode_handle___81 *);
	struct fwnode_handle___81 * (*graph_get_port_parent)(struct fwnode_handle___81 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___81 *, struct fwnode_endpoint___81 *);
	int (*add_links)(struct fwnode_handle___81 *);
};

struct fwnode_endpoint___81 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___81 *local_fwnode;
};

struct fwnode_reference_args___81 {
	struct fwnode_handle___81 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct mount___5;

struct mnt_namespace___5 {
	struct ns_common___14 ns;
	struct mount___5 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___80 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___80 *root_cset;
};

struct kernel_param_ops___93 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___93 *);
	int (*get)(char *, const struct kernel_param___93 *);
	void (*free)(void *);
};

struct kparam_array___93;

struct kernel_param___93 {
	const char *name;
	struct module___94 *mod;
	const struct kernel_param_ops___93 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___93 *arr;
	};
};

struct kparam_array___93 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___93 *ops;
	void *elem;
};

struct module_attribute___93 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___93 *, struct module_kobject___93 *, char *);
	ssize_t (*store)(struct module_attribute___93 *, struct module_kobject___93 *, const char *, size_t);
	void (*setup)(struct module___94 *, const char *);
	int (*test)(struct module___94 *);
	void (*free)(struct module___94 *);
};

struct trace_event_class___53;

struct trace_event_call___53 {
	struct list_head list;
	struct trace_event_class___53 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___53 *, struct perf_event___59 *);
};

struct cftype___80;

struct cgroup_subsys___80 {
	struct cgroup_subsys_state___80 * (*css_alloc)(struct cgroup_subsys_state___80 *);
	int (*css_online)(struct cgroup_subsys_state___80 *);
	void (*css_offline)(struct cgroup_subsys_state___80 *);
	void (*css_released)(struct cgroup_subsys_state___80 *);
	void (*css_free)(struct cgroup_subsys_state___80 *);
	void (*css_reset)(struct cgroup_subsys_state___80 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___80 *, int);
	int (*css_extra_stat_show)(struct seq_file___91 *, struct cgroup_subsys_state___80 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___104 *, struct css_set___80 *);
	void (*cancel_fork)(struct task_struct___104 *, struct css_set___80 *);
	void (*fork)(struct task_struct___104 *);
	void (*exit)(struct task_struct___104 *);
	void (*release)(struct task_struct___104 *);
	void (*bind)(struct cgroup_subsys_state___80 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___80 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___80 *dfl_cftypes;
	struct cftype___80 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___80 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___80 *updated_children;
	struct cgroup___80 *updated_next;
};

struct cgroup_root___80 {
	struct kernfs_root___96 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___80 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___80 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___80 *ss;
	struct list_head node;
	struct kernfs_ops___96 *kf_ops;
	int (*open)(struct kernfs_open_file___96 *);
	void (*release)(struct kernfs_open_file___96 *);
	u64 (*read_u64)(struct cgroup_subsys_state___80 *, struct cftype___80 *);
	s64 (*read_s64)(struct cgroup_subsys_state___80 *, struct cftype___80 *);
	int (*seq_show)(struct seq_file___91 *, void *);
	void * (*seq_start)(struct seq_file___91 *, loff_t *);
	void * (*seq_next)(struct seq_file___91 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___91 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___80 *, struct cftype___80 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___80 *, struct cftype___80 *, s64);
	ssize_t (*write)(struct kernfs_open_file___96 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___96 *, struct poll_table_struct___70 *);
};

struct perf_cpu_context___59;

struct perf_output_handle___59;

struct pmu___59 {
	struct list_head entry;
	struct module___94 *module;
	struct device___81 *dev;
	const struct attribute_group___96 **attr_groups;
	const struct attribute_group___96 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___59 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___59 *);
	void (*pmu_disable)(struct pmu___59 *);
	int (*event_init)(struct perf_event___59 *);
	void (*event_mapped)(struct perf_event___59 *, struct mm_struct___103 *);
	void (*event_unmapped)(struct perf_event___59 *, struct mm_struct___103 *);
	int (*add)(struct perf_event___59 *, int);
	void (*del)(struct perf_event___59 *, int);
	void (*start)(struct perf_event___59 *, int);
	void (*stop)(struct perf_event___59 *, int);
	void (*read)(struct perf_event___59 *);
	void (*start_txn)(struct pmu___59 *, unsigned int);
	int (*commit_txn)(struct pmu___59 *);
	void (*cancel_txn)(struct pmu___59 *);
	int (*event_idx)(struct perf_event___59 *);
	void (*sched_task)(struct perf_event_context___59 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___59 *, struct perf_event_context___59 *);
	void * (*setup_aux)(struct perf_event___59 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___59 *, struct perf_output_handle___59 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___59 *);
	int (*aux_output_match)(struct perf_event___59 *);
	int (*filter_match)(struct perf_event___59 *);
	int (*check_period)(struct perf_event___59 *, u64);
};

struct perf_cpu_context___59 {
	struct perf_event_context___59 ctx;
	struct perf_event_context___59 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___59 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___59 **heap;
	struct perf_event___59 *heap_default[2];
};

struct perf_output_handle___59 {
	struct perf_event___59 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___59 {
	struct cgroup_subsys_state___80 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___53 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___53 *);
	};
};

struct trace_event_class___53 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___53 *, enum trace_reg, void *);
	struct trace_event_fields___53 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___53 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___53 *);
};

struct syscall_metadata___28 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___53 *enter_event;
	struct trace_event_call___53 *exit_event;
};

struct mountpoint___5;

struct mount___5 {
	struct hlist_node mnt_hash;
	struct mount___5 *mnt_parent;
	struct dentry___97 *mnt_mountpoint;
	struct vfsmount___97 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___5 *mnt_master;
	struct mnt_namespace___5 *mnt_ns;
	struct mountpoint___5 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___5 {
	struct hlist_node m_hash;
	struct dentry___97 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct prepend_buffer {
	char *buf;
	int len;
};

typedef int __kernel_daddr_t;

struct ustat {
	__kernel_daddr_t f_tfree;
	long unsigned int f_tinode;
	char f_fname[6];
	char f_fpack[6];
};

typedef s32 compat_daddr_t;

typedef __kernel_fsid_t compat_fsid_t;

struct compat_statfs {
	int f_type;
	int f_bsize;
	int f_blocks;
	int f_bfree;
	int f_bavail;
	int f_files;
	int f_ffree;
	compat_fsid_t f_fsid;
	int f_namelen;
	int f_frsize;
	int f_flags;
	int f_spare[4];
};

struct compat_ustat {
	compat_daddr_t f_tfree;
	compat_ino_t f_tinode;
	char f_fname[6];
	char f_fpack[6];
};

struct statfs {
	__kernel_long_t f_type;
	__kernel_long_t f_bsize;
	__kernel_long_t f_blocks;
	__kernel_long_t f_bfree;
	__kernel_long_t f_bavail;
	__kernel_long_t f_files;
	__kernel_long_t f_ffree;
	__kernel_fsid_t f_fsid;
	__kernel_long_t f_namelen;
	__kernel_long_t f_frsize;
	__kernel_long_t f_flags;
	__kernel_long_t f_spare[4];
};

struct statfs64 {
	__kernel_long_t f_type;
	__kernel_long_t f_bsize;
	__u64 f_blocks;
	__u64 f_bfree;
	__u64 f_bavail;
	__u64 f_files;
	__u64 f_ffree;
	__kernel_fsid_t f_fsid;
	__kernel_long_t f_namelen;
	__kernel_long_t f_frsize;
	__kernel_long_t f_flags;
	__kernel_long_t f_spare[4];
};

struct compat_statfs64___2 {
	__u32 f_type;
	__u32 f_bsize;
	__u64 f_blocks;
	__u64 f_bfree;
	__u64 f_bavail;
	__u64 f_files;
	__u64 f_ffree;
	__kernel_fsid_t f_fsid;
	__u32 f_namelen;
	__u32 f_frsize;
	__u32 f_flags;
	__u32 f_spare[4];
} __attribute__((packed));

struct pseudo_fs_context___6 {
	const struct super_operations___47 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___47 *dops;
	long unsigned int magic;
};

typedef struct ns_common___8 *ns_get_path_helper_t___2(void *);

struct ns_get_path_task_args {
	const struct proc_ns_operations___8 *ns_ops;
	struct task_struct___52 *task;
};

struct fs_context___18;

struct fs_parameter_spec___14;

struct dentry___98;

struct super_block___98;

struct module___95;

struct file_system_type___98 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___18 *);
	const struct fs_parameter_spec___14 *parameters;
	struct dentry___98 * (*mount)(struct file_system_type___98 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___98 *);
	struct module___95 *owner;
	struct file_system_type___98 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___98;

struct kiocb___98;

struct iov_iter___59;

struct poll_table_struct___71;

struct vm_area_struct___103;

struct inode___98;

struct file_lock___98;

struct page___103;

struct pipe_inode_info___38;

struct seq_file___92;

struct file_operations___98 {
	struct module___95 *owner;
	loff_t (*llseek)(struct file___98 *, loff_t, int);
	ssize_t (*read)(struct file___98 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___98 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___98 *, struct iov_iter___59 *);
	ssize_t (*write_iter)(struct kiocb___98 *, struct iov_iter___59 *);
	int (*iopoll)(struct kiocb___98 *, bool);
	int (*iterate)(struct file___98 *, struct dir_context *);
	int (*iterate_shared)(struct file___98 *, struct dir_context *);
	__poll_t (*poll)(struct file___98 *, struct poll_table_struct___71 *);
	long int (*unlocked_ioctl)(struct file___98 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___98 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___98 *, struct vm_area_struct___103 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___98 *, struct file___98 *);
	int (*flush)(struct file___98 *, fl_owner_t);
	int (*release)(struct inode___98 *, struct file___98 *);
	int (*fsync)(struct file___98 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___98 *, int);
	int (*lock)(struct file___98 *, int, struct file_lock___98 *);
	ssize_t (*sendpage)(struct file___98 *, struct page___103 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___98 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___98 *, long unsigned int);
	int (*flock)(struct file___98 *, int, struct file_lock___98 *);
	ssize_t (*splice_write)(struct pipe_inode_info___38 *, struct file___98 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___98 *, loff_t *, struct pipe_inode_info___38 *, size_t, unsigned int);
	int (*setlease)(struct file___98 *, long int, struct file_lock___98 **, void **);
	long int (*fallocate)(struct file___98 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___92 *, struct file___98 *);
	ssize_t (*copy_file_range)(struct file___98 *, loff_t, struct file___98 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___98 *, loff_t, struct file___98 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___98 *, loff_t, loff_t, int);
};

struct vmacache___103 {
	u64 seqnum;
	struct vm_area_struct___103 *vmas[4];
};

struct page_frag___103 {
	struct page___103 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___104;

struct pid___90;

struct nsproxy___95;

struct signal_struct___99;

struct vm_struct___97;

struct task_struct___105 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___105 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___104 *mm;
	struct mm_struct___104 *active_mm;
	struct vmacache___103 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___105 *real_parent;
	struct task_struct___105 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___105 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___90 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___95 *nsproxy;
	struct signal_struct___99 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___105 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___46 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___38 *splice_pipe;
	struct page_frag___103 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___105 *oom_reaper_list;
	struct vm_struct___97 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___59 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___97;

struct kobj_type___97;

struct kernfs_node___97;

struct kobject___97 {
	const char *name;
	struct list_head entry;
	struct kobject___97 *parent;
	struct kset___97 *kset;
	struct kobj_type___97 *ktype;
	struct kernfs_node___97 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___94 {
	struct kobject___97 kobj;
	struct module___95 *mod;
	struct kobject___97 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___94 {
	struct module___95 *mod;
	struct latch_tree_node node;
};

struct module_layout___94 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___94 mtn;
};

struct module_attribute___94;

struct kernel_param___94;

struct module___95 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___94 mkobj;
	struct module_attribute___94 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___97 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___94 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___94 core_layout;
	struct module_layout___94 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___90;

struct upid___90 {
	int nr;
	struct pid_namespace___90 *ns;
};

struct pid_namespace___90 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___105 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___90 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___90 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___90 numbers[1];
};

typedef struct page___103 *pgtable_t___103;

struct address_space___98;

struct page_pool___31;

struct dev_pagemap___97;

struct page___103 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___98 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___103 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___103 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___104 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___97 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___97;

struct vm_area_struct___103 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___103 *vm_next;
	struct vm_area_struct___103 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___104 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___97 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___98 *vm_file;
	struct file___98 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___99 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___105 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___105 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___90 *pids[4];
	struct pid___90 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___104 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___103;

struct mm_struct___104 {
	struct {
		struct vm_area_struct___103 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___98 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___103 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___105 *owner;
		struct user_namespace___14 *user_ns;
		struct file___98 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct mnt_namespace___6;

struct nsproxy___95 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___6 *mnt_ns;
	struct pid_namespace___90 *pid_ns_for_children;
	struct net___23 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___98;

struct pipe_buffer___38;

struct pipe_inode_info___38 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___103 *tmp_page;
	struct fasync_struct___98 *fasync_readers;
	struct fasync_struct___98 *fasync_writers;
	struct pipe_buffer___38 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___97 {
	struct vm_struct___97 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___103 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___98;

struct address_space___98 {
	struct inode___98 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___98 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___82;

struct page_pool_params___31 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___82 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___31 {
	u32 count;
	struct page___103 *cache[128];
};

struct page_pool___31 {
	struct page_pool_params___31 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___103 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___31 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___97;

struct dev_pagemap___97 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___97 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___98;

struct path___98 {
	struct vfsmount___98 *mnt;
	struct dentry___98 *dentry;
};

struct fown_struct___90 {
	rwlock_t lock;
	struct pid___90 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___98 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___98 f_path;
	struct inode___98 *f_inode;
	const struct file_operations___98 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___90 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___98 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___97;

struct vm_operations_struct___97 {
	void (*open)(struct vm_area_struct___103 *);
	void (*close)(struct vm_area_struct___103 *);
	int (*may_split)(struct vm_area_struct___103 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___103 *);
	int (*mprotect)(struct vm_area_struct___103 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___97 *);
	vm_fault_t (*huge_fault)(struct vm_fault___97 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___97 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___103 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___97 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___97 *);
	int (*access)(struct vm_area_struct___103 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___103 *);
	int (*set_policy)(struct vm_area_struct___103 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___103 *, long unsigned int);
	struct page___103 * (*find_special_page)(struct vm_area_struct___103 *, long unsigned int);
};

struct core_thread___103 {
	struct task_struct___105 *task;
	struct core_thread___103 *next;
};

struct core_state___103 {
	atomic_t nr_threads;
	struct core_thread___103 dumper;
	struct completion startup;
};

struct vm_fault___97 {
	const struct {
		struct vm_area_struct___103 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___103 *cow_page;
	struct page___103 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___103 prealloc_pte;
};

struct dentry_operations___98;

struct dentry___98 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___98 *d_parent;
	struct qstr d_name;
	struct inode___98 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___98 *d_op;
	struct super_block___98 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___98;

struct inode___98 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___98 *i_op;
	struct super_block___98 *i_sb;
	struct address_space___98 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___98 *i_fop;
		void (*free_inode)(struct inode___98 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___98 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___98 {
	int (*d_revalidate)(struct dentry___98 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___98 *, unsigned int);
	int (*d_hash)(const struct dentry___98 *, struct qstr *);
	int (*d_compare)(const struct dentry___98 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___98 *);
	int (*d_init)(struct dentry___98 *);
	void (*d_release)(struct dentry___98 *);
	void (*d_prune)(struct dentry___98 *);
	void (*d_iput)(struct dentry___98 *, struct inode___98 *);
	char * (*d_dname)(struct dentry___98 *, char *, int);
	struct vfsmount___98 * (*d_automount)(struct path___98 *);
	int (*d_manage)(const struct path___98 *, bool);
	struct dentry___98 * (*d_real)(struct dentry___98 *, const struct inode___98 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___98;

struct mem_dqinfo___98 {
	struct quota_format_type___98 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___98;

struct quota_info___98 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___98 *files[3];
	struct mem_dqinfo___98 info[3];
	const struct quota_format_ops___98 *ops[3];
};

struct rcuwait___99 {
	struct task_struct___105 *task;
};

struct percpu_rw_semaphore___99 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___99 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___98 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___99 rw_sem[3];
};

struct super_operations___98;

struct dquot_operations___98;

struct quotactl_ops___98;

struct super_block___98 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___98 *s_type;
	const struct super_operations___98 *s_op;
	const struct dquot_operations___98 *dq_op;
	const struct quotactl_ops___98 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___98 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___98 s_dquot;
	struct sb_writers___98 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___98 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___98 {
	struct dentry___98 *mnt_root;
	struct super_block___98 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct kiocb___98 {
	struct file___98 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___98 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___48 *ki_waitq;
	};
};

struct iattr___98 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___98 *ia_file;
};

struct dquot___98 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___98 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___98 {
	int qf_fmt_id;
	const struct quota_format_ops___98 *qf_ops;
	struct module___95 *qf_owner;
	struct quota_format_type___98 *qf_next;
};

struct quota_format_ops___98 {
	int (*check_quota_file)(struct super_block___98 *, int);
	int (*read_file_info)(struct super_block___98 *, int);
	int (*write_file_info)(struct super_block___98 *, int);
	int (*free_file_info)(struct super_block___98 *, int);
	int (*read_dqblk)(struct dquot___98 *);
	int (*commit_dqblk)(struct dquot___98 *);
	int (*release_dqblk)(struct dquot___98 *);
	int (*get_next_id)(struct super_block___98 *, struct kqid *);
};

struct dquot_operations___98 {
	int (*write_dquot)(struct dquot___98 *);
	struct dquot___98 * (*alloc_dquot)(struct super_block___98 *, int);
	void (*destroy_dquot)(struct dquot___98 *);
	int (*acquire_dquot)(struct dquot___98 *);
	int (*release_dquot)(struct dquot___98 *);
	int (*mark_dirty)(struct dquot___98 *);
	int (*write_info)(struct super_block___98 *, int);
	qsize_t * (*get_reserved_space)(struct inode___98 *);
	int (*get_projid)(struct inode___98 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___98 *, qsize_t *);
	int (*get_next_id)(struct super_block___98 *, struct kqid *);
};

struct quotactl_ops___98 {
	int (*quota_on)(struct super_block___98 *, int, int, const struct path___98 *);
	int (*quota_off)(struct super_block___98 *, int);
	int (*quota_enable)(struct super_block___98 *, unsigned int);
	int (*quota_disable)(struct super_block___98 *, unsigned int);
	int (*quota_sync)(struct super_block___98 *, int);
	int (*set_info)(struct super_block___98 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___98 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___98 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___98 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___98 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___98 *, unsigned int);
};

struct address_space_operations___98 {
	int (*writepage)(struct page___103 *, struct writeback_control___3 *);
	int (*readpage)(struct file___98 *, struct page___103 *);
	int (*writepages)(struct address_space___98 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___103 *);
	int (*readpages)(struct file___98 *, struct address_space___98 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___98 *, struct address_space___98 *, loff_t, unsigned int, unsigned int, struct page___103 **, void **);
	int (*write_end)(struct file___98 *, struct address_space___98 *, loff_t, unsigned int, unsigned int, struct page___103 *, void *);
	sector_t (*bmap)(struct address_space___98 *, sector_t);
	void (*invalidatepage)(struct page___103 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___103 *, gfp_t);
	void (*freepage)(struct page___103 *);
	ssize_t (*direct_IO)(struct kiocb___98 *, struct iov_iter___59 *);
	int (*migratepage)(struct address_space___98 *, struct page___103 *, struct page___103 *, enum migrate_mode);
	bool (*isolate_page)(struct page___103 *, isolate_mode_t);
	void (*putback_page)(struct page___103 *);
	int (*launder_page)(struct page___103 *);
	int (*is_partially_uptodate)(struct page___103 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___103 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___98 *, struct page___103 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___98 *, sector_t *);
	void (*swap_deactivate)(struct file___98 *);
};

struct bio_vec___57;

struct iov_iter___59 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___57 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___38 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___98 {
	struct dentry___98 * (*lookup)(struct inode___98 *, struct dentry___98 *, unsigned int);
	const char * (*get_link)(struct dentry___98 *, struct inode___98 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___98 *, int);
	struct posix_acl * (*get_acl)(struct inode___98 *, int, bool);
	int (*readlink)(struct dentry___98 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___98 *, struct dentry___98 *, umode_t, bool);
	int (*link)(struct dentry___98 *, struct inode___98 *, struct dentry___98 *);
	int (*unlink)(struct inode___98 *, struct dentry___98 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___98 *, struct dentry___98 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___98 *, struct dentry___98 *, umode_t);
	int (*rmdir)(struct inode___98 *, struct dentry___98 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___98 *, struct dentry___98 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___98 *, struct dentry___98 *, struct inode___98 *, struct dentry___98 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___98 *, struct iattr___98 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___98 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___98 *, char *, size_t);
	int (*fiemap)(struct inode___98 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___98 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___98 *, struct dentry___98 *, struct file___98 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___98 *, struct dentry___98 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___98 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___98 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___98 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___98 {
	void (*fl_copy_lock)(struct file_lock___98 *, struct file_lock___98 *);
	void (*fl_release_private)(struct file_lock___98 *);
};

struct lock_manager_operations___98;

struct file_lock___98 {
	struct file_lock___98 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___98 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___98 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___98 *fl_ops;
	const struct lock_manager_operations___98 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___98 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___98 *);
	int (*lm_grant)(struct file_lock___98 *, int);
	bool (*lm_break)(struct file_lock___98 *);
	int (*lm_change)(struct file_lock___98 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___98 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___98 *);
};

struct fasync_struct___98 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___98 *fa_next;
	struct file___98 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___98 {
	struct inode___98 * (*alloc_inode)(struct super_block___98 *);
	void (*destroy_inode)(struct inode___98 *);
	void (*free_inode)(struct inode___98 *);
	void (*dirty_inode)(struct inode___98 *, int);
	int (*write_inode)(struct inode___98 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___98 *);
	void (*evict_inode)(struct inode___98 *);
	void (*put_super)(struct super_block___98 *);
	int (*sync_fs)(struct super_block___98 *, int);
	int (*freeze_super)(struct super_block___98 *);
	int (*freeze_fs)(struct super_block___98 *);
	int (*thaw_super)(struct super_block___98 *);
	int (*unfreeze_fs)(struct super_block___98 *);
	int (*statfs)(struct dentry___98 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___98 *, int *, char *);
	void (*umount_begin)(struct super_block___98 *);
	int (*show_options)(struct seq_file___92 *, struct dentry___98 *);
	int (*show_devname)(struct seq_file___92 *, struct dentry___98 *);
	int (*show_path)(struct seq_file___92 *, struct dentry___98 *);
	int (*show_stats)(struct seq_file___92 *, struct dentry___98 *);
	ssize_t (*quota_read)(struct super_block___98 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___98 *, int, const char *, size_t, loff_t);
	struct dquot___98 ** (*get_dquots)(struct inode___98 *);
	long int (*nr_cached_objects)(struct super_block___98 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___98 *, struct shrink_control___40 *);
	struct file___98 * (*real_loop)(struct file___98 *);
};

typedef void (*poll_queue_proc___71)(struct file___98 *, wait_queue_head_t *, struct poll_table_struct___71 *);

struct poll_table_struct___71 {
	poll_queue_proc___71 _qproc;
	__poll_t _key;
};

struct seq_operations___92;

struct seq_file___92 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___92 *op;
	int poll_event;
	const struct file___98 *file;
	void *private;
};

struct fc_log___18;

struct p_log___18 {
	const char *prefix;
	struct fc_log___18 *log;
};

struct fs_context_operations___18;

struct fs_context___18 {
	const struct fs_context_operations___18 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___98 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___98 *root;
	struct user_namespace___14 *user_ns;
	struct net___23 *net_ns;
	const struct cred___13 *cred;
	struct p_log___18 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___18;

typedef int fs_param_type___14(struct p_log___18 *, const struct fs_parameter_spec___14 *, struct fs_parameter___18 *, struct fs_parse_result *);

struct fs_parameter_spec___14 {
	const char *name;
	fs_param_type___14 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct kernfs_root___97;

struct kernfs_elem_dir___97 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___97 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___97;

struct kernfs_root___97 {
	struct kernfs_node___97 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___97 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___97 {
	struct kernfs_node___97 *target_kn;
};

struct kernfs_ops___97;

struct kernfs_elem_attr___97 {
	const struct kernfs_ops___97 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___97 *notify_next;
};

struct kernfs_node___97 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___97 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___97 dir;
		struct kernfs_elem_symlink___97 symlink;
		struct kernfs_elem_attr___97 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___97;

struct kernfs_ops___97 {
	int (*open)(struct kernfs_open_file___97 *);
	void (*release)(struct kernfs_open_file___97 *);
	int (*seq_show)(struct seq_file___92 *, void *);
	void * (*seq_start)(struct seq_file___92 *, loff_t *);
	void * (*seq_next)(struct seq_file___92 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___92 *, void *);
	ssize_t (*read)(struct kernfs_open_file___97 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___97 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___97 *, struct poll_table_struct___71 *);
	int (*mmap)(struct kernfs_open_file___97 *, struct vm_area_struct___103 *);
};

struct kernfs_syscall_ops___97 {
	int (*show_options)(struct seq_file___92 *, struct kernfs_root___97 *);
	int (*mkdir)(struct kernfs_node___97 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___97 *);
	int (*rename)(struct kernfs_node___97 *, struct kernfs_node___97 *, const char *);
	int (*show_path)(struct seq_file___92 *, struct kernfs_node___97 *, struct kernfs_root___97 *);
};

struct kernfs_open_file___97 {
	struct kernfs_node___97 *kn;
	struct file___98 *file;
	struct seq_file___92 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___97 *vm_ops;
};

struct bin_attribute___97;

struct attribute_group___97 {
	const char *name;
	umode_t (*is_visible)(struct kobject___97 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___97 *, struct bin_attribute___97 *, int);
	struct attribute **attrs;
	struct bin_attribute___97 **bin_attrs;
};

struct bin_attribute___97 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___98 * (*f_mapping)();
	ssize_t (*read)(struct file___98 *, struct kobject___97 *, struct bin_attribute___97 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___98 *, struct kobject___97 *, struct bin_attribute___97 *, char *, loff_t, size_t);
	int (*mmap)(struct file___98 *, struct kobject___97 *, struct bin_attribute___97 *, struct vm_area_struct___103 *);
};

struct sysfs_ops___97 {
	ssize_t (*show)(struct kobject___97 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___97 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___97;

struct kset___97 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___97 kobj;
	const struct kset_uevent_ops___97 *uevent_ops;
};

struct kobj_type___97 {
	void (*release)(struct kobject___97 *);
	const struct sysfs_ops___97 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___97 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___97 *);
	const void * (*namespace)(struct kobject___97 *);
	void (*get_ownership)(struct kobject___97 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___97 {
	int (* const filter)(struct kset___97 *, struct kobject___97 *);
	const char * (* const name)(struct kset___97 *, struct kobject___97 *);
	int (* const uevent)(struct kset___97 *, struct kobject___97 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___94 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___94 *);
	int (*get)(char *, const struct kernel_param___94 *);
	void (*free)(void *);
};

struct kparam_array___94;

struct kernel_param___94 {
	const char *name;
	struct module___95 *mod;
	const struct kernel_param_ops___94 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___94 *arr;
	};
};

struct kparam_array___94 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___94 *ops;
	void *elem;
};

struct module_attribute___94 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___94 *, struct module_kobject___94 *, char *);
	ssize_t (*store)(struct module_attribute___94 *, struct module_kobject___94 *, const char *, size_t);
	void (*setup)(struct module___95 *, const char *);
	int (*test)(struct module___95 *);
	void (*free)(struct module___95 *);
};

struct dev_pagemap_ops___97 {
	void (*page_free)(struct page___103 *);
	void (*kill)(struct dev_pagemap___97 *);
	void (*cleanup)(struct dev_pagemap___97 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___97 *);
};

struct fs_parameter___18 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___98 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___18 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___95 *owner;
	char *buffer[8];
};

struct fs_context_operations___18 {
	void (*free)(struct fs_context___18 *);
	int (*dup)(struct fs_context___18 *, struct fs_context___18 *);
	int (*parse_param)(struct fs_context___18 *, struct fs_parameter___18 *);
	int (*parse_monolithic)(struct fs_context___18 *, void *);
	int (*get_tree)(struct fs_context___18 *);
	int (*reconfigure)(struct fs_context___18 *);
};

struct mount___6;

struct mnt_namespace___6 {
	struct ns_common___14 ns;
	struct mount___6 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct seq_operations___92 {
	void * (*start)(struct seq_file___92 *, loff_t *);
	void (*stop)(struct seq_file___92 *, void *);
	void * (*next)(struct seq_file___92 *, void *, loff_t *);
	int (*show)(struct seq_file___92 *, void *);
};

struct bio_vec___57 {
	struct page___103 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fwnode_operations___82;

struct fwnode_handle___82 {
	struct fwnode_handle___82 *secondary;
	const struct fwnode_operations___82 *ops;
	struct device___82 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___82;

struct fwnode_endpoint___82;

struct fwnode_operations___82 {
	struct fwnode_handle___82 * (*get)(struct fwnode_handle___82 *);
	void (*put)(struct fwnode_handle___82 *);
	bool (*device_is_available)(const struct fwnode_handle___82 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___82 *, const struct device___82 *);
	bool (*property_present)(const struct fwnode_handle___82 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___82 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___82 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___82 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*get_parent)(const struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*get_next_child_node)(const struct fwnode_handle___82 *, struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*get_named_child_node)(const struct fwnode_handle___82 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___82 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___82 *);
	struct fwnode_handle___82 * (*graph_get_next_endpoint)(const struct fwnode_handle___82 *, struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*graph_get_remote_endpoint)(const struct fwnode_handle___82 *);
	struct fwnode_handle___82 * (*graph_get_port_parent)(struct fwnode_handle___82 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___82 *, struct fwnode_endpoint___82 *);
	int (*add_links)(struct fwnode_handle___82 *);
};

struct wakeup_source___82;

struct dev_pm_info___82 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___82 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___82 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___82;

struct bus_type___82;

struct device_driver___82;

struct dev_pm_domain___82;

struct class___82;

struct device___82 {
	struct kobject___97 kobj;
	struct device___82 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___82 *type;
	struct bus_type___82 *bus;
	struct device_driver___82 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___82 power;
	struct dev_pm_domain___82 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___82 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___82 *class;
	const struct attribute_group___97 **groups;
	void (*release)(struct device___82 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___82 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___82 *local_fwnode;
};

struct fwnode_reference_args___82 {
	struct fwnode_handle___82 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___82 {
	int (*prepare)(struct device___82 *);
	void (*complete)(struct device___82 *);
	int (*suspend)(struct device___82 *);
	int (*resume)(struct device___82 *);
	int (*freeze)(struct device___82 *);
	int (*thaw)(struct device___82 *);
	int (*poweroff)(struct device___82 *);
	int (*restore)(struct device___82 *);
	int (*suspend_late)(struct device___82 *);
	int (*resume_early)(struct device___82 *);
	int (*freeze_late)(struct device___82 *);
	int (*thaw_early)(struct device___82 *);
	int (*poweroff_late)(struct device___82 *);
	int (*restore_early)(struct device___82 *);
	int (*suspend_noirq)(struct device___82 *);
	int (*resume_noirq)(struct device___82 *);
	int (*freeze_noirq)(struct device___82 *);
	int (*thaw_noirq)(struct device___82 *);
	int (*poweroff_noirq)(struct device___82 *);
	int (*restore_noirq)(struct device___82 *);
	int (*runtime_suspend)(struct device___82 *);
	int (*runtime_resume)(struct device___82 *);
	int (*runtime_idle)(struct device___82 *);
};

struct wakeup_source___82 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___82 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___82 {
	struct dev_pm_ops___82 ops;
	int (*start)(struct device___82 *);
	void (*detach)(struct device___82 *, bool);
	int (*activate)(struct device___82 *);
	void (*sync)(struct device___82 *);
	void (*dismiss)(struct device___82 *);
};

struct bus_type___82 {
	const char *name;
	const char *dev_name;
	struct device___82 *dev_root;
	const struct attribute_group___97 **bus_groups;
	const struct attribute_group___97 **dev_groups;
	const struct attribute_group___97 **drv_groups;
	int (*match)(struct device___82 *, struct device_driver___82 *);
	int (*uevent)(struct device___82 *, struct kobj_uevent_env *);
	int (*probe)(struct device___82 *);
	void (*sync_state)(struct device___82 *);
	void (*remove)(struct device___82 *);
	void (*shutdown)(struct device___82 *);
	int (*online)(struct device___82 *);
	int (*offline)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	int (*num_vf)(struct device___82 *);
	int (*dma_configure)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___82 {
	const char *name;
	struct bus_type___82 *bus;
	struct module___95 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___82 *);
	void (*sync_state)(struct device___82 *);
	int (*remove)(struct device___82 *);
	void (*shutdown)(struct device___82 *);
	int (*suspend)(struct device___82 *, pm_message_t);
	int (*resume)(struct device___82 *);
	const struct attribute_group___97 **groups;
	const struct attribute_group___97 **dev_groups;
	const struct dev_pm_ops___82 *pm;
	void (*coredump)(struct device___82 *);
	struct driver_private *p;
};

struct device_type___82 {
	const char *name;
	const struct attribute_group___97 **groups;
	int (*uevent)(struct device___82 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___82 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___82 *);
	const struct dev_pm_ops___82 *pm;
};

struct class___82 {
	const char *name;
	struct module___95 *owner;
	const struct attribute_group___97 **class_groups;
	const struct attribute_group___97 **dev_groups;
	struct kobject___97 *dev_kobj;
	int (*dev_uevent)(struct device___82 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___82 *, umode_t *);
	void (*class_release)(struct class___82 *);
	void (*dev_release)(struct device___82 *);
	int (*shutdown_pre)(struct device___82 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___82 *);
	void (*get_ownership)(struct device___82 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___82 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___38;

struct pipe_buffer___38 {
	struct page___103 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___38 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___38 {
	int (*confirm)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
	void (*release)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
	bool (*try_steal)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
	bool (*get)(struct pipe_inode_info___38 *, struct pipe_buffer___38 *);
};

struct mountpoint___6;

struct mount___6 {
	struct hlist_node mnt_hash;
	struct mount___6 *mnt_parent;
	struct dentry___98 *mnt_mountpoint;
	struct vfsmount___98 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___6 *mnt_master;
	struct mnt_namespace___6 *mnt_ns;
	struct mountpoint___6 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___6 {
	struct hlist_node m_hash;
	struct dentry___98 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

enum legacy_fs_param {
	LEGACY_FS_UNSET_PARAMS = 0,
	LEGACY_FS_MONOLITHIC_PARAMS = 1,
	LEGACY_FS_INDIVIDUAL_PARAMS = 2,
};

struct legacy_fs_context {
	char *legacy_data;
	size_t data_size;
	enum legacy_fs_param param_type;
};

enum fsconfig_command {
	FSCONFIG_SET_FLAG = 0,
	FSCONFIG_SET_STRING = 1,
	FSCONFIG_SET_BINARY = 2,
	FSCONFIG_SET_PATH = 3,
	FSCONFIG_SET_PATH_EMPTY = 4,
	FSCONFIG_SET_FD = 5,
	FSCONFIG_CMD_CREATE = 6,
	FSCONFIG_CMD_RECONFIGURE = 7,
};

struct dentry___99;

struct super_block___99;

struct file_system_type___99 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___99 * (*mount)(struct file_system_type___99 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___99 *);
	struct module___8 *owner;
	struct file_system_type___99 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___99;

struct kiocb___99;

struct vm_area_struct___104;

struct inode___99;

struct file_lock___99;

struct page___104;

struct file_operations___99 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___99 *, loff_t, int);
	ssize_t (*read)(struct file___99 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___99 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___99 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___99 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___99 *, bool);
	int (*iterate)(struct file___99 *, struct dir_context *);
	int (*iterate_shared)(struct file___99 *, struct dir_context *);
	__poll_t (*poll)(struct file___99 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___99 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___99 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___99 *, struct vm_area_struct___104 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___99 *, struct file___99 *);
	int (*flush)(struct file___99 *, fl_owner_t);
	int (*release)(struct inode___99 *, struct file___99 *);
	int (*fsync)(struct file___99 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___99 *, int);
	int (*lock)(struct file___99 *, int, struct file_lock___99 *);
	ssize_t (*sendpage)(struct file___99 *, struct page___104 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___99 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___99 *, long unsigned int);
	int (*flock)(struct file___99 *, int, struct file_lock___99 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___99 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___99 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___99 *, long int, struct file_lock___99 **, void **);
	long int (*fallocate)(struct file___99 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___99 *);
	ssize_t (*copy_file_range)(struct file___99 *, loff_t, struct file___99 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___99 *, loff_t, struct file___99 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___99 *, loff_t, loff_t, int);
};

struct vmacache___104 {
	u64 seqnum;
	struct vm_area_struct___104 *vmas[4];
};

struct page_frag___104 {
	struct page___104 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___105;

struct fs_struct___14;

struct signal_struct___100;

struct task_struct___106 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___106 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___105 *mm;
	struct mm_struct___105 *active_mm;
	struct vmacache___104 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___106 *real_parent;
	struct task_struct___106 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___106 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___90 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___14 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___100 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___106 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___46 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___104 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___106 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___59 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___99 {
	struct dentry___99 *mnt_root;
	struct super_block___99 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct dentry_operations___99;

struct dentry___99 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___99 *d_parent;
	struct qstr d_name;
	struct inode___99 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___99 *d_op;
	struct super_block___99 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct quota_format_type___99;

struct mem_dqinfo___99 {
	struct quota_format_type___99 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___99;

struct quota_info___99 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___99 *files[3];
	struct mem_dqinfo___99 info[3];
	const struct quota_format_ops___99 *ops[3];
};

struct rcuwait___100 {
	struct task_struct___106 *task;
};

struct percpu_rw_semaphore___100 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___100 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___99 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___100 rw_sem[3];
};

struct super_operations___99;

struct dquot_operations___99;

struct quotactl_ops___99;

struct super_block___99 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___99 *s_type;
	const struct super_operations___99 *s_op;
	const struct dquot_operations___99 *dq_op;
	const struct quotactl_ops___99 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___99 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___99 s_dquot;
	struct sb_writers___99 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___99 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct address_space_operations___99;

struct address_space___99 {
	struct inode___99 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___99 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___99;

struct inode___99 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___99 *i_op;
	struct super_block___99 *i_sb;
	struct address_space___99 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___99 *i_fop;
		void (*free_inode)(struct inode___99 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___99 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct path___99;

struct dentry_operations___99 {
	int (*d_revalidate)(struct dentry___99 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___99 *, unsigned int);
	int (*d_hash)(const struct dentry___99 *, struct qstr *);
	int (*d_compare)(const struct dentry___99 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___99 *);
	int (*d_init)(struct dentry___99 *);
	void (*d_release)(struct dentry___99 *);
	void (*d_prune)(struct dentry___99 *);
	void (*d_iput)(struct dentry___99 *, struct inode___99 *);
	char * (*d_dname)(struct dentry___99 *, char *, int);
	struct vfsmount___99 * (*d_automount)(struct path___99 *);
	int (*d_manage)(const struct path___99 *, bool);
	struct dentry___99 * (*d_real)(struct dentry___99 *, const struct inode___99 *);
	long: 64;
	long: 64;
	long: 64;
};

struct path___99 {
	struct vfsmount___99 *mnt;
	struct dentry___99 *dentry;
};

typedef struct page___104 *pgtable_t___104;

struct dev_pagemap___98;

struct page___104 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___99 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___104 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___104 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___105 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___98 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___98;

struct vm_area_struct___104 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___104 *vm_next;
	struct vm_area_struct___104 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___105 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___98 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___99 *vm_file;
	struct file___99 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___100 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___106 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___106 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___90 *pids[4];
	struct pid___90 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___105 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___104;

struct mm_struct___105 {
	struct {
		struct vm_area_struct___104 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___99 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___104 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___106 *owner;
		struct user_namespace *user_ns;
		struct file___99 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fs_struct___14 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___99 root;
	struct path___99 pwd;
};

struct dev_pagemap_ops___98;

struct dev_pagemap___98 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___98 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___99 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___99 f_path;
	struct inode___99 *f_inode;
	const struct file_operations___99 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___90 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___99 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___98;

struct vm_operations_struct___98 {
	void (*open)(struct vm_area_struct___104 *);
	void (*close)(struct vm_area_struct___104 *);
	int (*may_split)(struct vm_area_struct___104 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___104 *);
	int (*mprotect)(struct vm_area_struct___104 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___98 *);
	vm_fault_t (*huge_fault)(struct vm_fault___98 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___98 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___104 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___98 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___98 *);
	int (*access)(struct vm_area_struct___104 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___104 *);
	int (*set_policy)(struct vm_area_struct___104 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___104 *, long unsigned int);
	struct page___104 * (*find_special_page)(struct vm_area_struct___104 *, long unsigned int);
};

struct core_thread___104 {
	struct task_struct___106 *task;
	struct core_thread___104 *next;
};

struct core_state___104 {
	atomic_t nr_threads;
	struct core_thread___104 dumper;
	struct completion startup;
};

struct vm_fault___98 {
	const struct {
		struct vm_area_struct___104 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___104 *cow_page;
	struct page___104 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___104 prealloc_pte;
};

struct kiocb___99 {
	struct file___99 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___99 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___48 *ki_waitq;
	};
};

struct iattr___99 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___99 *ia_file;
};

struct dquot___99 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___99 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___99 {
	int qf_fmt_id;
	const struct quota_format_ops___99 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___99 *qf_next;
};

struct quota_format_ops___99 {
	int (*check_quota_file)(struct super_block___99 *, int);
	int (*read_file_info)(struct super_block___99 *, int);
	int (*write_file_info)(struct super_block___99 *, int);
	int (*free_file_info)(struct super_block___99 *, int);
	int (*read_dqblk)(struct dquot___99 *);
	int (*commit_dqblk)(struct dquot___99 *);
	int (*release_dqblk)(struct dquot___99 *);
	int (*get_next_id)(struct super_block___99 *, struct kqid *);
};

struct dquot_operations___99 {
	int (*write_dquot)(struct dquot___99 *);
	struct dquot___99 * (*alloc_dquot)(struct super_block___99 *, int);
	void (*destroy_dquot)(struct dquot___99 *);
	int (*acquire_dquot)(struct dquot___99 *);
	int (*release_dquot)(struct dquot___99 *);
	int (*mark_dirty)(struct dquot___99 *);
	int (*write_info)(struct super_block___99 *, int);
	qsize_t * (*get_reserved_space)(struct inode___99 *);
	int (*get_projid)(struct inode___99 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___99 *, qsize_t *);
	int (*get_next_id)(struct super_block___99 *, struct kqid *);
};

struct quotactl_ops___99 {
	int (*quota_on)(struct super_block___99 *, int, int, const struct path___99 *);
	int (*quota_off)(struct super_block___99 *, int);
	int (*quota_enable)(struct super_block___99 *, unsigned int);
	int (*quota_disable)(struct super_block___99 *, unsigned int);
	int (*quota_sync)(struct super_block___99 *, int);
	int (*set_info)(struct super_block___99 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___99 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___99 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___99 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___99 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___99 *, unsigned int);
};

struct address_space_operations___99 {
	int (*writepage)(struct page___104 *, struct writeback_control___3 *);
	int (*readpage)(struct file___99 *, struct page___104 *);
	int (*writepages)(struct address_space___99 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___104 *);
	int (*readpages)(struct file___99 *, struct address_space___99 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___99 *, struct address_space___99 *, loff_t, unsigned int, unsigned int, struct page___104 **, void **);
	int (*write_end)(struct file___99 *, struct address_space___99 *, loff_t, unsigned int, unsigned int, struct page___104 *, void *);
	sector_t (*bmap)(struct address_space___99 *, sector_t);
	void (*invalidatepage)(struct page___104 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___104 *, gfp_t);
	void (*freepage)(struct page___104 *);
	ssize_t (*direct_IO)(struct kiocb___99 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___99 *, struct page___104 *, struct page___104 *, enum migrate_mode);
	bool (*isolate_page)(struct page___104 *, isolate_mode_t);
	void (*putback_page)(struct page___104 *);
	int (*launder_page)(struct page___104 *);
	int (*is_partially_uptodate)(struct page___104 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___104 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___99 *, struct page___104 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___99 *, sector_t *);
	void (*swap_deactivate)(struct file___99 *);
};

struct inode_operations___99 {
	struct dentry___99 * (*lookup)(struct inode___99 *, struct dentry___99 *, unsigned int);
	const char * (*get_link)(struct dentry___99 *, struct inode___99 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___99 *, int);
	struct posix_acl * (*get_acl)(struct inode___99 *, int, bool);
	int (*readlink)(struct dentry___99 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___99 *, struct dentry___99 *, umode_t, bool);
	int (*link)(struct dentry___99 *, struct inode___99 *, struct dentry___99 *);
	int (*unlink)(struct inode___99 *, struct dentry___99 *);
	int (*symlink)(struct user_namespace *, struct inode___99 *, struct dentry___99 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___99 *, struct dentry___99 *, umode_t);
	int (*rmdir)(struct inode___99 *, struct dentry___99 *);
	int (*mknod)(struct user_namespace *, struct inode___99 *, struct dentry___99 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___99 *, struct dentry___99 *, struct inode___99 *, struct dentry___99 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___99 *, struct iattr___99 *);
	int (*getattr)(struct user_namespace *, const struct path___99 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___99 *, char *, size_t);
	int (*fiemap)(struct inode___99 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___99 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___99 *, struct dentry___99 *, struct file___99 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___99 *, struct dentry___99 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___99 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___99 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___99 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___99 {
	void (*fl_copy_lock)(struct file_lock___99 *, struct file_lock___99 *);
	void (*fl_release_private)(struct file_lock___99 *);
};

struct fasync_struct___99;

struct lock_manager_operations___99;

struct file_lock___99 {
	struct file_lock___99 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___99 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___99 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___99 *fl_ops;
	const struct lock_manager_operations___99 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___99 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___99 *);
	int (*lm_grant)(struct file_lock___99 *, int);
	bool (*lm_break)(struct file_lock___99 *);
	int (*lm_change)(struct file_lock___99 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___99 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___99 *);
};

struct fasync_struct___99 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___99 *fa_next;
	struct file___99 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___99 {
	struct inode___99 * (*alloc_inode)(struct super_block___99 *);
	void (*destroy_inode)(struct inode___99 *);
	void (*free_inode)(struct inode___99 *);
	void (*dirty_inode)(struct inode___99 *, int);
	int (*write_inode)(struct inode___99 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___99 *);
	void (*evict_inode)(struct inode___99 *);
	void (*put_super)(struct super_block___99 *);
	int (*sync_fs)(struct super_block___99 *, int);
	int (*freeze_super)(struct super_block___99 *);
	int (*freeze_fs)(struct super_block___99 *);
	int (*thaw_super)(struct super_block___99 *);
	int (*unfreeze_fs)(struct super_block___99 *);
	int (*statfs)(struct dentry___99 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___99 *, int *, char *);
	void (*umount_begin)(struct super_block___99 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___99 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___99 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___99 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___99 *);
	ssize_t (*quota_read)(struct super_block___99 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___99 *, int, const char *, size_t, loff_t);
	struct dquot___99 ** (*get_dquots)(struct inode___99 *);
	long int (*nr_cached_objects)(struct super_block___99 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___99 *, struct shrink_control___40 *);
	struct file___99 * (*real_loop)(struct file___99 *);
};

struct dev_pagemap_ops___98 {
	void (*page_free)(struct page___104 *);
	void (*kill)(struct dev_pagemap___98 *);
	void (*cleanup)(struct dev_pagemap___98 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___98 *);
};

struct dentry___100;

struct super_block___100;

struct file_system_type___100 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___100 * (*mount)(struct file_system_type___100 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___100 *);
	struct module___8 *owner;
	struct file_system_type___100 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___100;

struct kiocb___100;

struct vm_area_struct___105;

struct inode___100;

struct file_lock___100;

struct page___105;

struct file_operations___100 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___100 *, loff_t, int);
	ssize_t (*read)(struct file___100 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___100 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___100 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___100 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___100 *, bool);
	int (*iterate)(struct file___100 *, struct dir_context *);
	int (*iterate_shared)(struct file___100 *, struct dir_context *);
	__poll_t (*poll)(struct file___100 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___100 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___100 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___100 *, struct vm_area_struct___105 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___100 *, struct file___100 *);
	int (*flush)(struct file___100 *, fl_owner_t);
	int (*release)(struct inode___100 *, struct file___100 *);
	int (*fsync)(struct file___100 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___100 *, int);
	int (*lock)(struct file___100 *, int, struct file_lock___100 *);
	ssize_t (*sendpage)(struct file___100 *, struct page___105 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___100 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___100 *, long unsigned int);
	int (*flock)(struct file___100 *, int, struct file_lock___100 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___100 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___100 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___100 *, long int, struct file_lock___100 **, void **);
	long int (*fallocate)(struct file___100 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___100 *);
	ssize_t (*copy_file_range)(struct file___100 *, loff_t, struct file___100 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___100 *, loff_t, struct file___100 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___100 *, loff_t, loff_t, int);
};

struct vmacache___105 {
	u64 seqnum;
	struct vm_area_struct___105 *vmas[4];
};

struct page_frag___105 {
	struct page___105 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___106;

struct fs_struct___15;

struct signal_struct___101;

struct vm_struct___98;

struct task_struct___107 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___107 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___106 *mm;
	struct mm_struct___106 *active_mm;
	struct vmacache___105 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___107 *real_parent;
	struct task_struct___107 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___107 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___90 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___15 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___101 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___107 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___46 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___105 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___107 *oom_reaper_list;
	struct vm_struct___98 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___59 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___100;

struct dentry___100 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___100 *d_parent;
	struct qstr d_name;
	struct inode___100 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___100 *d_op;
	struct super_block___100 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___100;

struct address_space___100 {
	struct inode___100 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___100 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___100;

struct inode___100 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___100 *i_op;
	struct super_block___100 *i_sb;
	struct address_space___100 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___100 *i_fop;
		void (*free_inode)(struct inode___100 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___100 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___100;

struct path___100;

struct dentry_operations___100 {
	int (*d_revalidate)(struct dentry___100 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___100 *, unsigned int);
	int (*d_hash)(const struct dentry___100 *, struct qstr *);
	int (*d_compare)(const struct dentry___100 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___100 *);
	int (*d_init)(struct dentry___100 *);
	void (*d_release)(struct dentry___100 *);
	void (*d_prune)(struct dentry___100 *);
	void (*d_iput)(struct dentry___100 *, struct inode___100 *);
	char * (*d_dname)(struct dentry___100 *, char *, int);
	struct vfsmount___100 * (*d_automount)(struct path___100 *);
	int (*d_manage)(const struct path___100 *, bool);
	struct dentry___100 * (*d_real)(struct dentry___100 *, const struct inode___100 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___100;

struct mem_dqinfo___100 {
	struct quota_format_type___100 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___100;

struct quota_info___100 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___100 *files[3];
	struct mem_dqinfo___100 info[3];
	const struct quota_format_ops___100 *ops[3];
};

struct rcuwait___101 {
	struct task_struct___107 *task;
};

struct percpu_rw_semaphore___101 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___101 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___100 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___101 rw_sem[3];
};

struct super_operations___100;

struct dquot_operations___100;

struct quotactl_ops___100;

struct super_block___100 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___100 *s_type;
	const struct super_operations___100 *s_op;
	const struct dquot_operations___100 *dq_op;
	const struct quotactl_ops___100 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___100 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___100 s_dquot;
	struct sb_writers___100 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___100 *s_d_op;
	int cleancache_poolid;
	struct shrinker___40 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___100 {
	struct dentry___100 *mnt_root;
	struct super_block___100 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___100 {
	struct vfsmount___100 *mnt;
	struct dentry___100 *dentry;
};

typedef struct page___105 *pgtable_t___105;

struct dev_pagemap___99;

struct page___105 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___100 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___105 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___105 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___106 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___99 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___99;

struct vm_area_struct___105 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___105 *vm_next;
	struct vm_area_struct___105 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___106 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___99 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___100 *vm_file;
	struct file___100 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___101 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___107 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___107 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___90 *pids[4];
	struct pid___90 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___106 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___105;

struct mm_struct___106 {
	struct {
		struct vm_area_struct___105 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___100 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___105 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___107 *owner;
		struct user_namespace *user_ns;
		struct file___100 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fs_struct___15 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___100 root;
	struct path___100 pwd;
};

struct vm_struct___98 {
	struct vm_struct___98 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___105 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___99;

struct dev_pagemap___99 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___99 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___100 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___100 f_path;
	struct inode___100 *f_inode;
	const struct file_operations___100 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___90 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___100 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___99;

struct vm_operations_struct___99 {
	void (*open)(struct vm_area_struct___105 *);
	void (*close)(struct vm_area_struct___105 *);
	int (*may_split)(struct vm_area_struct___105 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___105 *);
	int (*mprotect)(struct vm_area_struct___105 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___99 *);
	vm_fault_t (*huge_fault)(struct vm_fault___99 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___99 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___105 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___99 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___99 *);
	int (*access)(struct vm_area_struct___105 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___105 *);
	int (*set_policy)(struct vm_area_struct___105 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___105 *, long unsigned int);
	struct page___105 * (*find_special_page)(struct vm_area_struct___105 *, long unsigned int);
};

struct core_thread___105 {
	struct task_struct___107 *task;
	struct core_thread___105 *next;
};

struct core_state___105 {
	atomic_t nr_threads;
	struct core_thread___105 dumper;
	struct completion startup;
};

struct vm_fault___99 {
	const struct {
		struct vm_area_struct___105 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___105 *cow_page;
	struct page___105 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___105 prealloc_pte;
};

struct kiocb___100 {
	struct file___100 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___100 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___48 *ki_waitq;
	};
};

struct iattr___100 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___100 *ia_file;
};

struct dquot___100 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___100 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___100 {
	int qf_fmt_id;
	const struct quota_format_ops___100 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___100 *qf_next;
};

struct quota_format_ops___100 {
	int (*check_quota_file)(struct super_block___100 *, int);
	int (*read_file_info)(struct super_block___100 *, int);
	int (*write_file_info)(struct super_block___100 *, int);
	int (*free_file_info)(struct super_block___100 *, int);
	int (*read_dqblk)(struct dquot___100 *);
	int (*commit_dqblk)(struct dquot___100 *);
	int (*release_dqblk)(struct dquot___100 *);
	int (*get_next_id)(struct super_block___100 *, struct kqid *);
};

struct dquot_operations___100 {
	int (*write_dquot)(struct dquot___100 *);
	struct dquot___100 * (*alloc_dquot)(struct super_block___100 *, int);
	void (*destroy_dquot)(struct dquot___100 *);
	int (*acquire_dquot)(struct dquot___100 *);
	int (*release_dquot)(struct dquot___100 *);
	int (*mark_dirty)(struct dquot___100 *);
	int (*write_info)(struct super_block___100 *, int);
	qsize_t * (*get_reserved_space)(struct inode___100 *);
	int (*get_projid)(struct inode___100 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___100 *, qsize_t *);
	int (*get_next_id)(struct super_block___100 *, struct kqid *);
};

struct quotactl_ops___100 {
	int (*quota_on)(struct super_block___100 *, int, int, const struct path___100 *);
	int (*quota_off)(struct super_block___100 *, int);
	int (*quota_enable)(struct super_block___100 *, unsigned int);
	int (*quota_disable)(struct super_block___100 *, unsigned int);
	int (*quota_sync)(struct super_block___100 *, int);
	int (*set_info)(struct super_block___100 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___100 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___100 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___100 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___100 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___100 *, unsigned int);
};

struct address_space_operations___100 {
	int (*writepage)(struct page___105 *, struct writeback_control___3 *);
	int (*readpage)(struct file___100 *, struct page___105 *);
	int (*writepages)(struct address_space___100 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___105 *);
	int (*readpages)(struct file___100 *, struct address_space___100 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___100 *, struct address_space___100 *, loff_t, unsigned int, unsigned int, struct page___105 **, void **);
	int (*write_end)(struct file___100 *, struct address_space___100 *, loff_t, unsigned int, unsigned int, struct page___105 *, void *);
	sector_t (*bmap)(struct address_space___100 *, sector_t);
	void (*invalidatepage)(struct page___105 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___105 *, gfp_t);
	void (*freepage)(struct page___105 *);
	ssize_t (*direct_IO)(struct kiocb___100 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___100 *, struct page___105 *, struct page___105 *, enum migrate_mode);
	bool (*isolate_page)(struct page___105 *, isolate_mode_t);
	void (*putback_page)(struct page___105 *);
	int (*launder_page)(struct page___105 *);
	int (*is_partially_uptodate)(struct page___105 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___105 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___100 *, struct page___105 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___100 *, sector_t *);
	void (*swap_deactivate)(struct file___100 *);
};

struct inode_operations___100 {
	struct dentry___100 * (*lookup)(struct inode___100 *, struct dentry___100 *, unsigned int);
	const char * (*get_link)(struct dentry___100 *, struct inode___100 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___100 *, int);
	struct posix_acl * (*get_acl)(struct inode___100 *, int, bool);
	int (*readlink)(struct dentry___100 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___100 *, struct dentry___100 *, umode_t, bool);
	int (*link)(struct dentry___100 *, struct inode___100 *, struct dentry___100 *);
	int (*unlink)(struct inode___100 *, struct dentry___100 *);
	int (*symlink)(struct user_namespace *, struct inode___100 *, struct dentry___100 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___100 *, struct dentry___100 *, umode_t);
	int (*rmdir)(struct inode___100 *, struct dentry___100 *);
	int (*mknod)(struct user_namespace *, struct inode___100 *, struct dentry___100 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___100 *, struct dentry___100 *, struct inode___100 *, struct dentry___100 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___100 *, struct iattr___100 *);
	int (*getattr)(struct user_namespace *, const struct path___100 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___100 *, char *, size_t);
	int (*fiemap)(struct inode___100 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___100 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___100 *, struct dentry___100 *, struct file___100 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___100 *, struct dentry___100 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___100 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___100 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___100 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___100 {
	void (*fl_copy_lock)(struct file_lock___100 *, struct file_lock___100 *);
	void (*fl_release_private)(struct file_lock___100 *);
};

struct fasync_struct___100;

struct lock_manager_operations___100;

struct file_lock___100 {
	struct file_lock___100 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___100 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___100 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___100 *fl_ops;
	const struct lock_manager_operations___100 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___100 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___100 *);
	int (*lm_grant)(struct file_lock___100 *, int);
	bool (*lm_break)(struct file_lock___100 *);
	int (*lm_change)(struct file_lock___100 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___100 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___100 *);
};

struct fasync_struct___100 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___100 *fa_next;
	struct file___100 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___100 {
	struct inode___100 * (*alloc_inode)(struct super_block___100 *);
	void (*destroy_inode)(struct inode___100 *);
	void (*free_inode)(struct inode___100 *);
	void (*dirty_inode)(struct inode___100 *, int);
	int (*write_inode)(struct inode___100 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___100 *);
	void (*evict_inode)(struct inode___100 *);
	void (*put_super)(struct super_block___100 *);
	int (*sync_fs)(struct super_block___100 *, int);
	int (*freeze_super)(struct super_block___100 *);
	int (*freeze_fs)(struct super_block___100 *);
	int (*thaw_super)(struct super_block___100 *);
	int (*unfreeze_fs)(struct super_block___100 *);
	int (*statfs)(struct dentry___100 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___100 *, int *, char *);
	void (*umount_begin)(struct super_block___100 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___100 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___100 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___100 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___100 *);
	ssize_t (*quota_read)(struct super_block___100 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___100 *, int, const char *, size_t, loff_t);
	struct dquot___100 ** (*get_dquots)(struct inode___100 *);
	long int (*nr_cached_objects)(struct super_block___100 *, struct shrink_control___40 *);
	long int (*free_cached_objects)(struct super_block___100 *, struct shrink_control___40 *);
	struct file___100 * (*real_loop)(struct file___100 *);
};

struct fd___22 {
	struct file___100 *file;
	unsigned int flags;
};

struct dev_pagemap_ops___99 {
	void (*page_free)(struct page___105 *);
	void (*kill)(struct dev_pagemap___99 *);
	void (*cleanup)(struct dev_pagemap___99 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___99 *);
};

typedef int filler_t___4(void *, struct page___61 *);

struct dentry___101;

struct super_block___101;

struct module___96;

struct file_system_type___101 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___101 * (*mount)(struct file_system_type___101 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___101 *);
	struct module___96 *owner;
	struct file_system_type___101 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___101;

struct kiocb___101;

struct iov_iter___60;

struct poll_table_struct___72;

struct vm_area_struct___106;

struct inode___101;

struct file_lock___101;

struct page___106;

struct seq_file___93;

struct file_operations___101 {
	struct module___96 *owner;
	loff_t (*llseek)(struct file___101 *, loff_t, int);
	ssize_t (*read)(struct file___101 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___101 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___101 *, struct iov_iter___60 *);
	ssize_t (*write_iter)(struct kiocb___101 *, struct iov_iter___60 *);
	int (*iopoll)(struct kiocb___101 *, bool);
	int (*iterate)(struct file___101 *, struct dir_context *);
	int (*iterate_shared)(struct file___101 *, struct dir_context *);
	__poll_t (*poll)(struct file___101 *, struct poll_table_struct___72 *);
	long int (*unlocked_ioctl)(struct file___101 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___101 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___101 *, struct vm_area_struct___106 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___101 *, struct file___101 *);
	int (*flush)(struct file___101 *, fl_owner_t);
	int (*release)(struct inode___101 *, struct file___101 *);
	int (*fsync)(struct file___101 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___101 *, int);
	int (*lock)(struct file___101 *, int, struct file_lock___101 *);
	ssize_t (*sendpage)(struct file___101 *, struct page___106 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___101 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___101 *, long unsigned int);
	int (*flock)(struct file___101 *, int, struct file_lock___101 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___101 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___101 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___101 *, long int, struct file_lock___101 **, void **);
	long int (*fallocate)(struct file___101 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___93 *, struct file___101 *);
	ssize_t (*copy_file_range)(struct file___101 *, loff_t, struct file___101 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___101 *, loff_t, struct file___101 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___101 *, loff_t, loff_t, int);
};

struct vmacache___106 {
	u64 seqnum;
	struct vm_area_struct___106 *vmas[4];
};

struct page_frag___106 {
	struct page___106 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___60;

struct debug_info___60 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___60 *hbp_break[16];
	struct perf_event___60 *hbp_watch[16];
};

struct thread_struct___60 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___60 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___107;

struct pid___91;

struct nsproxy___96;

struct signal_struct___102;

struct bio_list___47;

struct backing_dev_info___46;

struct io_context___47;

struct css_set___81;

struct perf_event_context___60;

struct mem_cgroup___41;

struct request_queue___47;

struct vm_struct___99;

struct task_struct___108 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___108 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___107 *mm;
	struct mm_struct___107 *active_mm;
	struct vmacache___106 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___108 *real_parent;
	struct task_struct___108 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___108 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___91 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___96 *nsproxy;
	struct signal_struct___102 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___108 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___47 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___46 *backing_dev_info;
	struct io_context___47 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___81 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___60 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___106 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___41 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___41 *active_memcg;
	struct request_queue___47 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___108 *oom_reaper_list;
	struct vm_struct___99 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___98;

struct kobj_type___98;

struct kernfs_node___98;

struct kobject___98 {
	const char *name;
	struct list_head entry;
	struct kobject___98 *parent;
	struct kset___98 *kset;
	struct kobj_type___98 *ktype;
	struct kernfs_node___98 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___95 {
	struct kobject___98 kobj;
	struct module___96 *mod;
	struct kobject___98 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___95 {
	struct module___96 *mod;
	struct latch_tree_node node;
};

struct module_layout___95 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___95 mtn;
};

struct module_attribute___95;

struct kernel_param___95;

struct trace_event_call___54;

struct module___96 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___95 mkobj;
	struct module_attribute___95 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___98 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___95 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___95 core_layout;
	struct module_layout___95 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___54 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___60 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___108 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___60)(struct perf_event___60 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___60;

struct fasync_struct___101;

struct pid_namespace___91;

struct perf_cgroup___60;

struct perf_event___60 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___60 *group_leader;
	struct pmu___60 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___60 hw;
	struct perf_event_context___60 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___60 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___108 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___101 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___60 *aux_event;
	void (*destroy)(struct perf_event___60 *);
	struct callback_head callback_head;
	struct pid_namespace___91 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___60 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___60 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___54 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___60 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___91 {
	int nr;
	struct pid_namespace___91 *ns;
};

struct pid_namespace___91 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___108 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___91 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___91 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___91 numbers[1];
};

typedef struct page___106 *pgtable_t___106;

struct address_space___101;

struct dev_pagemap___100;

struct page___106 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___101 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___106 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___106 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___107 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___100 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___100;

struct vm_area_struct___106 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___106 *vm_next;
	struct vm_area_struct___106 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___107 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___100 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___101 *vm_file;
	struct file___101 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___102 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___108 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___108 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___91 *pids[4];
	struct pid___91 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___107 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___106;

struct mm_struct___107 {
	struct {
		struct vm_area_struct___106 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___101 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___106 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___108 *owner;
		struct user_namespace___14 *user_ns;
		struct file___101 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___81;

struct nsproxy___96 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___91 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___81 *cgroup_ns;
};

struct bio___47;

struct bio_list___47 {
	struct bio___47 *head;
	struct bio___47 *tail;
};

struct cgroup_subsys_state___81;

struct bdi_writeback___46 {
	struct backing_dev_info___46 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___81 *memcg_css;
	struct cgroup_subsys_state___81 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___83;

struct backing_dev_info___46 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___46 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___83 *dev;
	char dev_name[64];
	struct device___83 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___101 *debug_dir;
};

struct io_cq___47;

struct io_context___47 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___47 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___81;

struct css_set___81 {
	struct cgroup_subsys_state___81 *subsys[14];
	refcount_t refcount;
	struct css_set___81 *dom_cset;
	struct cgroup___81 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___81 *mg_src_cgrp;
	struct cgroup___81 *mg_dst_cgrp;
	struct css_set___81 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___60 {
	struct pmu___60 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___108 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___60 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___81;

struct cgroup_subsys_state___81 {
	struct cgroup___81 *cgroup;
	struct cgroup_subsys___81 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___81 *parent;
};

struct cgroup_file___81 {
	struct kernfs_node___98 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___41;

struct mem_cgroup_per_node___41;

struct mem_cgroup___41 {
	struct cgroup_subsys_state___81 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___81 events_file;
	struct cgroup_file___81 events_local_file;
	struct cgroup_file___81 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___41 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___108 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___41 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___47;

struct blk_integrity___47 {
	const struct blk_integrity_profile___47 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___47 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___47 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___47;

struct elevator_queue___47;

struct blk_mq_ops___46;

struct blk_mq_hw_ctx___46;

struct gendisk___47;

struct blkcg_gq___46;

struct blk_trace___2;

struct blk_mq_tag_set___46;

struct request_queue___47 {
	struct request___47 *last_merge;
	struct elevator_queue___47 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___46 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___46 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___47 *disk;
	struct kobject___98 kobj;
	struct kobject___98 *mq_kobj;
	struct blk_integrity___47 integrity;
	struct device___83 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___46 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___2 *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___46 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___47 bio_split;
	struct dentry___101 *debugfs_dir;
	struct dentry___101 *sched_debugfs_dir;
	struct dentry___101 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___99 {
	struct vm_struct___99 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___106 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___101;

struct address_space___101 {
	struct inode___101 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___101 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___100;

struct dev_pagemap___100 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___100 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___101;

struct path___101 {
	struct vfsmount___101 *mnt;
	struct dentry___101 *dentry;
};

struct fown_struct___91 {
	rwlock_t lock;
	struct pid___91 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___101 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___101 f_path;
	struct inode___101 *f_inode;
	const struct file_operations___101 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___91 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___101 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___100;

struct vm_operations_struct___100 {
	void (*open)(struct vm_area_struct___106 *);
	void (*close)(struct vm_area_struct___106 *);
	int (*may_split)(struct vm_area_struct___106 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___106 *);
	int (*mprotect)(struct vm_area_struct___106 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___100 *);
	vm_fault_t (*huge_fault)(struct vm_fault___100 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___100 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___106 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___100 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___100 *);
	int (*access)(struct vm_area_struct___106 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___106 *);
	int (*set_policy)(struct vm_area_struct___106 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___106 *, long unsigned int);
	struct page___106 * (*find_special_page)(struct vm_area_struct___106 *, long unsigned int);
};

struct core_thread___106 {
	struct task_struct___108 *task;
	struct core_thread___106 *next;
};

struct core_state___106 {
	atomic_t nr_threads;
	struct core_thread___106 dumper;
	struct completion startup;
};

struct vm_fault___100 {
	const struct {
		struct vm_area_struct___106 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___106 *cow_page;
	struct page___106 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___106 prealloc_pte;
};

struct psi_group___81 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___108 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___81;

struct cgroup_rstat_cpu___81;

struct cgroup___81 {
	struct cgroup_subsys_state___81 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___98 *kn;
	struct cgroup_file___81 procs_file;
	struct cgroup_file___81 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___81 *subsys[14];
	struct cgroup_root___81 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___81 *dom_cgrp;
	struct cgroup___81 *old_dom_cgrp;
	struct cgroup_rstat_cpu___81 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___81 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___47;

struct lruvec___47 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___47 *pgdat;
};

struct zone___47 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___47 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___47 {
	struct zone___47 *zone;
	int zone_idx;
};

struct zonelist___47 {
	struct zoneref___47 _zonerefs[321];
};

struct pglist_data___47 {
	struct zone___47 node_zones[5];
	struct zonelist___47 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___108 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___108 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___47 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___101;

struct dentry___101 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___101 *d_parent;
	struct qstr d_name;
	struct inode___101 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___101 *d_op;
	struct super_block___101 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___101;

struct inode___101 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___101 *i_op;
	struct super_block___101 *i_sb;
	struct address_space___101 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___46 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___101 *i_fop;
		void (*free_inode)(struct inode___101 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___101 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___101 {
	int (*d_revalidate)(struct dentry___101 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___101 *, unsigned int);
	int (*d_hash)(const struct dentry___101 *, struct qstr *);
	int (*d_compare)(const struct dentry___101 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___101 *);
	int (*d_init)(struct dentry___101 *);
	void (*d_release)(struct dentry___101 *);
	void (*d_prune)(struct dentry___101 *);
	void (*d_iput)(struct dentry___101 *, struct inode___101 *);
	char * (*d_dname)(struct dentry___101 *, char *, int);
	struct vfsmount___101 * (*d_automount)(struct path___101 *);
	int (*d_manage)(const struct path___101 *, bool);
	struct dentry___101 * (*d_real)(struct dentry___101 *, const struct inode___101 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___101;

struct mem_dqinfo___101 {
	struct quota_format_type___101 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___101;

struct quota_info___101 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___101 *files[3];
	struct mem_dqinfo___101 info[3];
	const struct quota_format_ops___101 *ops[3];
};

struct rcuwait___102 {
	struct task_struct___108 *task;
};

struct percpu_rw_semaphore___102 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___102 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___101 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___102 rw_sem[3];
};

struct shrink_control___41;

struct shrinker___41 {
	long unsigned int (*count_objects)(struct shrinker___41 *, struct shrink_control___41 *);
	long unsigned int (*scan_objects)(struct shrinker___41 *, struct shrink_control___41 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___101;

struct dquot_operations___101;

struct quotactl_ops___101;

struct fscrypt_operations___5;

struct block_device___48;

struct super_block___101 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___101 *s_type;
	const struct super_operations___101 *s_op;
	const struct dquot_operations___101 *dq_op;
	const struct quotactl_ops___101 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___101 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___5 *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___48 *s_bdev;
	struct backing_dev_info___46 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___101 s_dquot;
	struct sb_writers___101 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___101 *s_d_op;
	int cleancache_poolid;
	struct shrinker___41 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___101 {
	struct dentry___101 *mnt_root;
	struct super_block___101 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___41 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___41 *memcg;
};

struct io_cq___47 {
	struct request_queue___47 *q;
	struct io_context___47 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___2;

typedef int get_block_t(struct inode___101 *, sector_t, struct buffer_head___2 *, int);

typedef void bh_end_io_t___2(struct buffer_head___2 *, int);

struct buffer_head___2 {
	long unsigned int b_state;
	struct buffer_head___2 *b_this_page;
	struct page___106 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___48 *b_bdev;
	bh_end_io_t___2 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___101 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___49;

struct kiocb___101 {
	struct file___101 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___101 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___49 *ki_waitq;
	};
};

struct iattr___101 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___101 *ia_file;
};

struct dquot___101 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___101 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___101 {
	int qf_fmt_id;
	const struct quota_format_ops___101 *qf_ops;
	struct module___96 *qf_owner;
	struct quota_format_type___101 *qf_next;
};

struct quota_format_ops___101 {
	int (*check_quota_file)(struct super_block___101 *, int);
	int (*read_file_info)(struct super_block___101 *, int);
	int (*write_file_info)(struct super_block___101 *, int);
	int (*free_file_info)(struct super_block___101 *, int);
	int (*read_dqblk)(struct dquot___101 *);
	int (*commit_dqblk)(struct dquot___101 *);
	int (*release_dqblk)(struct dquot___101 *);
	int (*get_next_id)(struct super_block___101 *, struct kqid *);
};

struct dquot_operations___101 {
	int (*write_dquot)(struct dquot___101 *);
	struct dquot___101 * (*alloc_dquot)(struct super_block___101 *, int);
	void (*destroy_dquot)(struct dquot___101 *);
	int (*acquire_dquot)(struct dquot___101 *);
	int (*release_dquot)(struct dquot___101 *);
	int (*mark_dirty)(struct dquot___101 *);
	int (*write_info)(struct super_block___101 *, int);
	qsize_t * (*get_reserved_space)(struct inode___101 *);
	int (*get_projid)(struct inode___101 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___101 *, qsize_t *);
	int (*get_next_id)(struct super_block___101 *, struct kqid *);
};

struct quotactl_ops___101 {
	int (*quota_on)(struct super_block___101 *, int, int, const struct path___101 *);
	int (*quota_off)(struct super_block___101 *, int);
	int (*quota_enable)(struct super_block___101 *, unsigned int);
	int (*quota_disable)(struct super_block___101 *, unsigned int);
	int (*quota_sync)(struct super_block___101 *, int);
	int (*set_info)(struct super_block___101 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___101 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___101 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___101 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___101 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___101 *, unsigned int);
};

struct wait_page_queue___49 {
	struct page___106 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___46;

struct readahead_control___49;

struct swap_info_struct___26;

struct address_space_operations___101 {
	int (*writepage)(struct page___106 *, struct writeback_control___46 *);
	int (*readpage)(struct file___101 *, struct page___106 *);
	int (*writepages)(struct address_space___101 *, struct writeback_control___46 *);
	int (*set_page_dirty)(struct page___106 *);
	int (*readpages)(struct file___101 *, struct address_space___101 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___49 *);
	int (*write_begin)(struct file___101 *, struct address_space___101 *, loff_t, unsigned int, unsigned int, struct page___106 **, void **);
	int (*write_end)(struct file___101 *, struct address_space___101 *, loff_t, unsigned int, unsigned int, struct page___106 *, void *);
	sector_t (*bmap)(struct address_space___101 *, sector_t);
	void (*invalidatepage)(struct page___106 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___106 *, gfp_t);
	void (*freepage)(struct page___106 *);
	ssize_t (*direct_IO)(struct kiocb___101 *, struct iov_iter___60 *);
	int (*migratepage)(struct address_space___101 *, struct page___106 *, struct page___106 *, enum migrate_mode);
	bool (*isolate_page)(struct page___106 *, isolate_mode_t);
	void (*putback_page)(struct page___106 *);
	int (*launder_page)(struct page___106 *);
	int (*is_partially_uptodate)(struct page___106 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___106 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___101 *, struct page___106 *);
	int (*swap_activate)(struct swap_info_struct___26 *, struct file___101 *, sector_t *);
	void (*swap_deactivate)(struct file___101 *);
};

struct writeback_control___46 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___46 *wb;
	struct inode___101 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___49 {
	struct file___101 *file;
	struct address_space___101 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___58;

struct iov_iter___60 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___58 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___26 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___48 *bdev;
	struct file___101 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___101 {
	struct dentry___101 * (*lookup)(struct inode___101 *, struct dentry___101 *, unsigned int);
	const char * (*get_link)(struct dentry___101 *, struct inode___101 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___101 *, int);
	struct posix_acl * (*get_acl)(struct inode___101 *, int, bool);
	int (*readlink)(struct dentry___101 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___101 *, struct dentry___101 *, umode_t, bool);
	int (*link)(struct dentry___101 *, struct inode___101 *, struct dentry___101 *);
	int (*unlink)(struct inode___101 *, struct dentry___101 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___101 *, struct dentry___101 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___101 *, struct dentry___101 *, umode_t);
	int (*rmdir)(struct inode___101 *, struct dentry___101 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___101 *, struct dentry___101 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___101 *, struct dentry___101 *, struct inode___101 *, struct dentry___101 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___101 *, struct iattr___101 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___101 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___101 *, char *, size_t);
	int (*fiemap)(struct inode___101 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___101 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___101 *, struct dentry___101 *, struct file___101 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___101 *, struct dentry___101 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___101 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___101 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___101 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___101 {
	void (*fl_copy_lock)(struct file_lock___101 *, struct file_lock___101 *);
	void (*fl_release_private)(struct file_lock___101 *);
};

struct lock_manager_operations___101;

struct file_lock___101 {
	struct file_lock___101 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___101 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___101 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___101 *fl_ops;
	const struct lock_manager_operations___101 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___101 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___101 *);
	int (*lm_grant)(struct file_lock___101 *, int);
	bool (*lm_break)(struct file_lock___101 *);
	int (*lm_change)(struct file_lock___101 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___101 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___101 *);
};

struct fasync_struct___101 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___101 *fa_next;
	struct file___101 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___101 {
	struct inode___101 * (*alloc_inode)(struct super_block___101 *);
	void (*destroy_inode)(struct inode___101 *);
	void (*free_inode)(struct inode___101 *);
	void (*dirty_inode)(struct inode___101 *, int);
	int (*write_inode)(struct inode___101 *, struct writeback_control___46 *);
	int (*drop_inode)(struct inode___101 *);
	void (*evict_inode)(struct inode___101 *);
	void (*put_super)(struct super_block___101 *);
	int (*sync_fs)(struct super_block___101 *, int);
	int (*freeze_super)(struct super_block___101 *);
	int (*freeze_fs)(struct super_block___101 *);
	int (*thaw_super)(struct super_block___101 *);
	int (*unfreeze_fs)(struct super_block___101 *);
	int (*statfs)(struct dentry___101 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___101 *, int *, char *);
	void (*umount_begin)(struct super_block___101 *);
	int (*show_options)(struct seq_file___93 *, struct dentry___101 *);
	int (*show_devname)(struct seq_file___93 *, struct dentry___101 *);
	int (*show_path)(struct seq_file___93 *, struct dentry___101 *);
	int (*show_stats)(struct seq_file___93 *, struct dentry___101 *);
	ssize_t (*quota_read)(struct super_block___101 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___101 *, int, const char *, size_t, loff_t);
	struct dquot___101 ** (*get_dquots)(struct inode___101 *);
	long int (*nr_cached_objects)(struct super_block___101 *, struct shrink_control___41 *);
	long int (*free_cached_objects)(struct super_block___101 *, struct shrink_control___41 *);
	struct file___101 * (*real_loop)(struct file___101 *);
};

struct fscrypt_operations___5 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___101 *, void *, size_t);
	int (*set_context)(struct inode___101 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___101 *);
	bool (*empty_dir)(struct inode___101 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___101 *);
	void (*get_ino_and_lblk_bits)(struct super_block___101 *, int *, int *);
	int (*get_num_devices)(struct super_block___101 *);
	void (*get_devices)(struct super_block___101 *, struct request_queue___47 **);
};

struct wakeup_source___83;

struct dev_pm_info___83 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___83 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___83 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___83;

struct bus_type___83;

struct device_driver___83;

struct dev_pm_domain___83;

struct fwnode_handle___83;

struct class___83;

struct attribute_group___98;

struct device___83 {
	struct kobject___98 kobj;
	struct device___83 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___83 *type;
	struct bus_type___83 *bus;
	struct device_driver___83 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___83 power;
	struct dev_pm_domain___83 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___83 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___83 *class;
	const struct attribute_group___98 **groups;
	void (*release)(struct device___83 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___48 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___101 *bd_inode;
	struct super_block___101 *bd_super;
	void *bd_claiming;
	struct device___83 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___98 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___47 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___101 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___72)(struct file___101 *, wait_queue_head_t *, struct poll_table_struct___72 *);

struct poll_table_struct___72 {
	poll_queue_proc___72 _qproc;
	__poll_t _key;
};

struct seq_operations___93;

struct seq_file___93 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___93 *op;
	int poll_event;
	const struct file___101 *file;
	void *private;
};

typedef void bio_end_io_t___47(struct bio___47 *);

struct bio_vec___58 {
	struct page___106 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___47;

struct bio___47 {
	struct bio___47 *bi_next;
	struct block_device___48 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___47 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___46 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___47 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___58 *bi_io_vec;
	struct bio_set___47 *bi_pool;
	struct bio_vec___58 bi_inline_vecs[0];
};

struct kernfs_root___98;

struct kernfs_elem_dir___98 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___98 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___98;

struct kernfs_root___98 {
	struct kernfs_node___98 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___98 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___98 {
	struct kernfs_node___98 *target_kn;
};

struct kernfs_ops___98;

struct kernfs_elem_attr___98 {
	const struct kernfs_ops___98 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___98 *notify_next;
};

struct kernfs_node___98 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___98 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___98 dir;
		struct kernfs_elem_symlink___98 symlink;
		struct kernfs_elem_attr___98 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___98;

struct kernfs_ops___98 {
	int (*open)(struct kernfs_open_file___98 *);
	void (*release)(struct kernfs_open_file___98 *);
	int (*seq_show)(struct seq_file___93 *, void *);
	void * (*seq_start)(struct seq_file___93 *, loff_t *);
	void * (*seq_next)(struct seq_file___93 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___93 *, void *);
	ssize_t (*read)(struct kernfs_open_file___98 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___98 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___98 *, struct poll_table_struct___72 *);
	int (*mmap)(struct kernfs_open_file___98 *, struct vm_area_struct___106 *);
};

struct kernfs_syscall_ops___98 {
	int (*show_options)(struct seq_file___93 *, struct kernfs_root___98 *);
	int (*mkdir)(struct kernfs_node___98 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___98 *);
	int (*rename)(struct kernfs_node___98 *, struct kernfs_node___98 *, const char *);
	int (*show_path)(struct seq_file___93 *, struct kernfs_node___98 *, struct kernfs_root___98 *);
};

struct kernfs_open_file___98 {
	struct kernfs_node___98 *kn;
	struct file___101 *file;
	struct seq_file___93 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___100 *vm_ops;
};

struct bin_attribute___98;

struct attribute_group___98 {
	const char *name;
	umode_t (*is_visible)(struct kobject___98 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___98 *, struct bin_attribute___98 *, int);
	struct attribute **attrs;
	struct bin_attribute___98 **bin_attrs;
};

struct bin_attribute___98 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___101 * (*f_mapping)();
	ssize_t (*read)(struct file___101 *, struct kobject___98 *, struct bin_attribute___98 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___101 *, struct kobject___98 *, struct bin_attribute___98 *, char *, loff_t, size_t);
	int (*mmap)(struct file___101 *, struct kobject___98 *, struct bin_attribute___98 *, struct vm_area_struct___106 *);
};

struct sysfs_ops___98 {
	ssize_t (*show)(struct kobject___98 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___98 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___98;

struct kset___98 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___98 kobj;
	const struct kset_uevent_ops___98 *uevent_ops;
};

struct kobj_type___98 {
	void (*release)(struct kobject___98 *);
	const struct sysfs_ops___98 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___98 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___98 *);
	const void * (*namespace)(struct kobject___98 *);
	void (*get_ownership)(struct kobject___98 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___98 {
	int (* const filter)(struct kset___98 *, struct kobject___98 *);
	const char * (* const name)(struct kset___98 *, struct kobject___98 *);
	int (* const uevent)(struct kset___98 *, struct kobject___98 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___83 {
	int (*prepare)(struct device___83 *);
	void (*complete)(struct device___83 *);
	int (*suspend)(struct device___83 *);
	int (*resume)(struct device___83 *);
	int (*freeze)(struct device___83 *);
	int (*thaw)(struct device___83 *);
	int (*poweroff)(struct device___83 *);
	int (*restore)(struct device___83 *);
	int (*suspend_late)(struct device___83 *);
	int (*resume_early)(struct device___83 *);
	int (*freeze_late)(struct device___83 *);
	int (*thaw_early)(struct device___83 *);
	int (*poweroff_late)(struct device___83 *);
	int (*restore_early)(struct device___83 *);
	int (*suspend_noirq)(struct device___83 *);
	int (*resume_noirq)(struct device___83 *);
	int (*freeze_noirq)(struct device___83 *);
	int (*thaw_noirq)(struct device___83 *);
	int (*poweroff_noirq)(struct device___83 *);
	int (*restore_noirq)(struct device___83 *);
	int (*runtime_suspend)(struct device___83 *);
	int (*runtime_resume)(struct device___83 *);
	int (*runtime_idle)(struct device___83 *);
};

struct wakeup_source___83 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___83 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___83 {
	struct dev_pm_ops___83 ops;
	int (*start)(struct device___83 *);
	void (*detach)(struct device___83 *, bool);
	int (*activate)(struct device___83 *);
	void (*sync)(struct device___83 *);
	void (*dismiss)(struct device___83 *);
};

struct bus_type___83 {
	const char *name;
	const char *dev_name;
	struct device___83 *dev_root;
	const struct attribute_group___98 **bus_groups;
	const struct attribute_group___98 **dev_groups;
	const struct attribute_group___98 **drv_groups;
	int (*match)(struct device___83 *, struct device_driver___83 *);
	int (*uevent)(struct device___83 *, struct kobj_uevent_env *);
	int (*probe)(struct device___83 *);
	void (*sync_state)(struct device___83 *);
	void (*remove)(struct device___83 *);
	void (*shutdown)(struct device___83 *);
	int (*online)(struct device___83 *);
	int (*offline)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	int (*num_vf)(struct device___83 *);
	int (*dma_configure)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___83 {
	const char *name;
	struct bus_type___83 *bus;
	struct module___96 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___83 *);
	void (*sync_state)(struct device___83 *);
	int (*remove)(struct device___83 *);
	void (*shutdown)(struct device___83 *);
	int (*suspend)(struct device___83 *, pm_message_t);
	int (*resume)(struct device___83 *);
	const struct attribute_group___98 **groups;
	const struct attribute_group___98 **dev_groups;
	const struct dev_pm_ops___83 *pm;
	void (*coredump)(struct device___83 *);
	struct driver_private *p;
};

struct device_type___83 {
	const char *name;
	const struct attribute_group___98 **groups;
	int (*uevent)(struct device___83 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___83 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___83 *);
	const struct dev_pm_ops___83 *pm;
};

struct class___83 {
	const char *name;
	struct module___96 *owner;
	const struct attribute_group___98 **class_groups;
	const struct attribute_group___98 **dev_groups;
	struct kobject___98 *dev_kobj;
	int (*dev_uevent)(struct device___83 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___83 *, umode_t *);
	void (*class_release)(struct class___83 *);
	void (*dev_release)(struct device___83 *);
	int (*shutdown_pre)(struct device___83 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___83 *);
	void (*get_ownership)(struct device___83 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___83 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___83;

struct fwnode_handle___83 {
	struct fwnode_handle___83 *secondary;
	const struct fwnode_operations___83 *ops;
	struct device___83 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___100 {
	void (*page_free)(struct page___106 *);
	void (*kill)(struct dev_pagemap___100 *);
	void (*cleanup)(struct dev_pagemap___100 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___100 *);
};

struct seq_operations___93 {
	void * (*start)(struct seq_file___93 *, loff_t *);
	void (*stop)(struct seq_file___93 *, void *);
	void * (*next)(struct seq_file___93 *, void *, loff_t *);
	int (*show)(struct seq_file___93 *, void *);
};

struct fwnode_reference_args___83;

struct fwnode_endpoint___83;

struct fwnode_operations___83 {
	struct fwnode_handle___83 * (*get)(struct fwnode_handle___83 *);
	void (*put)(struct fwnode_handle___83 *);
	bool (*device_is_available)(const struct fwnode_handle___83 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___83 *, const struct device___83 *);
	bool (*property_present)(const struct fwnode_handle___83 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___83 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___83 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___83 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*get_parent)(const struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*get_next_child_node)(const struct fwnode_handle___83 *, struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*get_named_child_node)(const struct fwnode_handle___83 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___83 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___83 *);
	struct fwnode_handle___83 * (*graph_get_next_endpoint)(const struct fwnode_handle___83 *, struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*graph_get_remote_endpoint)(const struct fwnode_handle___83 *);
	struct fwnode_handle___83 * (*graph_get_port_parent)(struct fwnode_handle___83 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___83 *, struct fwnode_endpoint___83 *);
	int (*add_links)(struct fwnode_handle___83 *);
};

struct fwnode_endpoint___83 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___83 *local_fwnode;
};

struct fwnode_reference_args___83 {
	struct fwnode_handle___83 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___81 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___81 *root_cset;
};

struct kernel_param_ops___95 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___95 *);
	int (*get)(char *, const struct kernel_param___95 *);
	void (*free)(void *);
};

struct kparam_array___95;

struct kernel_param___95 {
	const char *name;
	struct module___96 *mod;
	const struct kernel_param_ops___95 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___95 *arr;
	};
};

struct kparam_array___95 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___95 *ops;
	void *elem;
};

struct module_attribute___95 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___95 *, struct module_kobject___95 *, char *);
	ssize_t (*store)(struct module_attribute___95 *, struct module_kobject___95 *, const char *, size_t);
	void (*setup)(struct module___96 *, const char *);
	int (*test)(struct module___96 *);
	void (*free)(struct module___96 *);
};

struct trace_event_class___54;

struct trace_event_call___54 {
	struct list_head list;
	struct trace_event_class___54 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___54 *, struct perf_event___60 *);
};

struct cftype___81;

struct cgroup_subsys___81 {
	struct cgroup_subsys_state___81 * (*css_alloc)(struct cgroup_subsys_state___81 *);
	int (*css_online)(struct cgroup_subsys_state___81 *);
	void (*css_offline)(struct cgroup_subsys_state___81 *);
	void (*css_released)(struct cgroup_subsys_state___81 *);
	void (*css_free)(struct cgroup_subsys_state___81 *);
	void (*css_reset)(struct cgroup_subsys_state___81 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___81 *, int);
	int (*css_extra_stat_show)(struct seq_file___93 *, struct cgroup_subsys_state___81 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___108 *, struct css_set___81 *);
	void (*cancel_fork)(struct task_struct___108 *, struct css_set___81 *);
	void (*fork)(struct task_struct___108 *);
	void (*exit)(struct task_struct___108 *);
	void (*release)(struct task_struct___108 *);
	void (*bind)(struct cgroup_subsys_state___81 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___81 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___81 *dfl_cftypes;
	struct cftype___81 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___81 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___81 *updated_children;
	struct cgroup___81 *updated_next;
};

struct cgroup_root___81 {
	struct kernfs_root___98 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___81 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___81 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___81 *ss;
	struct list_head node;
	struct kernfs_ops___98 *kf_ops;
	int (*open)(struct kernfs_open_file___98 *);
	void (*release)(struct kernfs_open_file___98 *);
	u64 (*read_u64)(struct cgroup_subsys_state___81 *, struct cftype___81 *);
	s64 (*read_s64)(struct cgroup_subsys_state___81 *, struct cftype___81 *);
	int (*seq_show)(struct seq_file___93 *, void *);
	void * (*seq_start)(struct seq_file___93 *, loff_t *);
	void * (*seq_next)(struct seq_file___93 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___93 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___81 *, struct cftype___81 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___81 *, struct cftype___81 *, s64);
	ssize_t (*write)(struct kernfs_open_file___98 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___98 *, struct poll_table_struct___72 *);
};

struct perf_cpu_context___60;

struct perf_output_handle___60;

struct pmu___60 {
	struct list_head entry;
	struct module___96 *module;
	struct device___83 *dev;
	const struct attribute_group___98 **attr_groups;
	const struct attribute_group___98 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___60 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___60 *);
	void (*pmu_disable)(struct pmu___60 *);
	int (*event_init)(struct perf_event___60 *);
	void (*event_mapped)(struct perf_event___60 *, struct mm_struct___107 *);
	void (*event_unmapped)(struct perf_event___60 *, struct mm_struct___107 *);
	int (*add)(struct perf_event___60 *, int);
	void (*del)(struct perf_event___60 *, int);
	void (*start)(struct perf_event___60 *, int);
	void (*stop)(struct perf_event___60 *, int);
	void (*read)(struct perf_event___60 *);
	void (*start_txn)(struct pmu___60 *, unsigned int);
	int (*commit_txn)(struct pmu___60 *);
	void (*cancel_txn)(struct pmu___60 *);
	int (*event_idx)(struct perf_event___60 *);
	void (*sched_task)(struct perf_event_context___60 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___60 *, struct perf_event_context___60 *);
	void * (*setup_aux)(struct perf_event___60 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___60 *, struct perf_output_handle___60 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___60 *);
	int (*aux_output_match)(struct perf_event___60 *);
	int (*filter_match)(struct perf_event___60 *);
	int (*check_period)(struct perf_event___60 *, u64);
};

struct perf_cpu_context___60 {
	struct perf_event_context___60 ctx;
	struct perf_event_context___60 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___60 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___60 **heap;
	struct perf_event___60 *heap_default[2];
};

struct perf_output_handle___60 {
	struct perf_event___60 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___60 {
	struct cgroup_subsys_state___81 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___54 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___54 *);
	};
};

struct trace_event_class___54 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___54 *, enum trace_reg, void *);
	struct trace_event_fields___54 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___54 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___54 *);
};

struct block_device_operations___47;

struct gendisk___47 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___48 *part0;
	const struct block_device_operations___47 *fops;
	struct request_queue___47 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___46 *bdi;
	struct kobject___98 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___98 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___47 {
	struct bio___47 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___58 *bip_vec;
	struct bio_vec___58 bip_inline_vecs[0];
};

struct blkcg___46;

struct blkg_policy_data___46;

struct blkcg_gq___46 {
	struct request_queue___47 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___46 *blkcg;
	struct blkcg_gq___46 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___46 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___47 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___47(struct request___47 *);

typedef void integrity_complete_fn___47(struct request___47 *, unsigned int);

struct blk_integrity_profile___47 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___47 *prepare_fn;
	integrity_complete_fn___47 *complete_fn;
	const char *name;
};

struct block_device_operations___47 {
	blk_qc_t (*submit_bio)(struct bio___47 *);
	int (*open)(struct block_device___48 *, fmode_t);
	void (*release)(struct gendisk___47 *, fmode_t);
	int (*rw_page)(struct block_device___48 *, sector_t, struct page___106 *, unsigned int);
	int (*ioctl)(struct block_device___48 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___48 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___47 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___47 *);
	int (*getgeo)(struct block_device___48 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___48 *, bool);
	void (*swap_slot_free_notify)(struct block_device___48 *, long unsigned int);
	int (*report_zones)(struct gendisk___47 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___47 *, umode_t *);
	struct module___96 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___47 *, sector_t *);
};

typedef void rq_end_io_fn___47(struct request___47 *, blk_status_t);

struct request___47 {
	struct request_queue___47 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___46 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___47 *bio;
	struct bio___47 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___58 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___47 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___47 *saved_end_io;
		} flush;
	};
	struct gendisk___47 *rq_disk;
	struct block_device___48 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___47 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___46 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___47 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___98 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___101 *debugfs_dir;
	struct dentry___101 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___47;

struct elevator_mq_ops___47 {
	int (*init_sched)(struct request_queue___47 *, struct elevator_type___47 *);
	void (*exit_sched)(struct elevator_queue___47 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___46 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___46 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___46 *);
	bool (*allow_merge)(struct request_queue___47 *, struct request___47 *, struct bio___47 *);
	bool (*bio_merge)(struct request_queue___47 *, struct bio___47 *, unsigned int);
	int (*request_merge)(struct request_queue___47 *, struct request___47 **, struct bio___47 *);
	void (*request_merged)(struct request_queue___47 *, struct request___47 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___47 *, struct request___47 *, struct request___47 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___47 *);
	void (*finish_request)(struct request___47 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___46 *, struct list_head *, bool);
	struct request___47 * (*dispatch_request)(struct blk_mq_hw_ctx___46 *);
	bool (*has_work)(struct blk_mq_hw_ctx___46 *);
	void (*completed_request)(struct request___47 *, u64);
	void (*requeue_request)(struct request___47 *);
	struct request___47 * (*former_request)(struct request_queue___47 *, struct request___47 *);
	struct request___47 * (*next_request)(struct request_queue___47 *, struct request___47 *);
	void (*init_icq)(struct io_cq___47 *);
	void (*exit_icq)(struct io_cq___47 *);
};

struct elv_fs_entry___47;

struct elevator_type___47 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___47 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___47 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___96 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___47 {
	struct elevator_type___47 *type;
	void *elevator_data;
	struct kobject___98 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___47 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___47 *, char *);
	ssize_t (*store)(struct elevator_queue___47 *, const char *, size_t);
};

struct blk_mq_queue_data___46;

struct blk_mq_ops___46 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___46 *, const struct blk_mq_queue_data___46 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___46 *);
	int (*get_budget)(struct request_queue___47 *);
	void (*put_budget)(struct request_queue___47 *, int);
	void (*set_rq_budget_token)(struct request___47 *, int);
	int (*get_rq_budget_token)(struct request___47 *);
	enum blk_eh_timer_return (*timeout)(struct request___47 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___46 *);
	void (*complete)(struct request___47 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___46 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___46 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___46 *, struct request___47 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___46 *, struct request___47 *, unsigned int);
	void (*initialize_rq_fn)(struct request___47 *);
	void (*cleanup_rq)(struct request___47 *);
	bool (*busy)(struct request_queue___47 *);
	int (*map_queues)(struct blk_mq_tag_set___46 *);
	void (*show_rq)(struct seq_file___93 *, struct request___47 *);
};

struct rchan___3;

struct blk_trace___2 {
	int trace_state;
	struct rchan___3 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___101 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_mq_tag_set___46 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___46 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct dax_device;

struct iomap_page_ops;

struct iomap___2 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___48 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops *page_ops;
};

struct iomap_page_ops {
	int (*page_prepare)(struct inode___101 *, loff_t, unsigned int);
	void (*page_done)(struct inode___101 *, loff_t, unsigned int, struct page___106 *);
};

struct blk_mq_queue_data___46 {
	struct request___47 *rq;
	bool last;
};

struct blkcg_policy_data___46;

struct blkcg___46 {
	struct cgroup_subsys_state___81 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___46 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___46 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___46 {
	struct blkcg___46 *blkcg;
	int plid;
};

struct blkg_policy_data___46 {
	struct blkcg_gq___46 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___41 {
	struct mem_cgroup___41 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___41 {
	struct lruvec___47 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___41 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___41 *memcg;
};

struct obj_cgroup___41 {
	struct percpu_ref refcnt;
	struct mem_cgroup___41 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pagevec___5 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___106 *pages[15];
};

struct rchan_buf___3 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___3 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___101 *dentry;
	struct kref kref;
	struct page___106 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___3;

struct rchan___3 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___3 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___3 **buf;
	int is_global;
	struct list_head list;
	struct dentry___101 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___3 {
	int (*subbuf_start)(struct rchan_buf___3 *, void *, void *, size_t);
	struct dentry___101 * (*create_buf_file)(const char *, struct dentry___101 *, umode_t, struct rchan_buf___3 *, int *);
	int (*remove_buf_file)(struct dentry___101 *);
};

struct decrypt_bh_ctx {
	struct work_struct work;
	struct buffer_head___2 *bh;
};

struct bh_lru {
	struct buffer_head___2 *bhs[16];
};

struct bh_accounting {
	int nr;
	int ratelimit;
};

typedef int dio_iodone_t(struct kiocb___101 *, loff_t, ssize_t, void *);

typedef void dio_submit_t(struct bio___47 *, struct inode___101 *, loff_t);

enum {
	DIO_LOCKING = 1,
	DIO_SKIP_HOLES = 2,
};

struct dio_submit {
	struct bio___47 *bio;
	unsigned int blkbits;
	unsigned int blkfactor;
	unsigned int start_zero_done;
	int pages_in_io;
	sector_t block_in_file;
	unsigned int blocks_available;
	int reap_counter;
	sector_t final_block_in_request;
	int boundary;
	get_block_t *get_block;
	dio_submit_t *submit_io;
	loff_t logical_offset_in_bio;
	sector_t final_block_in_bio;
	sector_t next_block_for_io;
	struct page___106 *cur_page;
	unsigned int cur_page_offset;
	unsigned int cur_page_len;
	sector_t cur_page_block;
	loff_t cur_page_fs_offset;
	struct iov_iter___60 *iter;
	unsigned int head;
	unsigned int tail;
	size_t from;
	size_t to;
};

struct dio {
	int flags;
	int op;
	int op_flags;
	blk_qc_t bio_cookie;
	struct gendisk___47 *bio_disk;
	struct inode___101 *inode;
	loff_t i_size;
	dio_iodone_t *end_io;
	void *private;
	spinlock_t bio_lock;
	int page_errors;
	int is_async;
	bool defer_completion;
	bool should_dirty;
	int io_error;
	long unsigned int refcount;
	struct bio___47 *bio_list;
	struct task_struct___108 *waiter;
	struct kiocb___101 *iocb;
	ssize_t result;
	union {
		struct page___106 *pages[64];
		struct work_struct complete_work;
	};
	long: 64;
};

struct dentry___102;

struct super_block___102;

struct module___97;

struct file_system_type___102 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___102 * (*mount)(struct file_system_type___102 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___102 *);
	struct module___97 *owner;
	struct file_system_type___102 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___102;

struct kiocb___102;

struct iov_iter___61;

struct vm_area_struct___107;

struct inode___102;

struct file_lock___102;

struct page___107;

struct seq_file___94;

struct file_operations___102 {
	struct module___97 *owner;
	loff_t (*llseek)(struct file___102 *, loff_t, int);
	ssize_t (*read)(struct file___102 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___102 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___102 *, struct iov_iter___61 *);
	ssize_t (*write_iter)(struct kiocb___102 *, struct iov_iter___61 *);
	int (*iopoll)(struct kiocb___102 *, bool);
	int (*iterate)(struct file___102 *, struct dir_context *);
	int (*iterate_shared)(struct file___102 *, struct dir_context *);
	__poll_t (*poll)(struct file___102 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___102 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___102 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___102 *, struct vm_area_struct___107 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___102 *, struct file___102 *);
	int (*flush)(struct file___102 *, fl_owner_t);
	int (*release)(struct inode___102 *, struct file___102 *);
	int (*fsync)(struct file___102 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___102 *, int);
	int (*lock)(struct file___102 *, int, struct file_lock___102 *);
	ssize_t (*sendpage)(struct file___102 *, struct page___107 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___102 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___102 *, long unsigned int);
	int (*flock)(struct file___102 *, int, struct file_lock___102 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___102 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___102 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___102 *, long int, struct file_lock___102 **, void **);
	long int (*fallocate)(struct file___102 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___94 *, struct file___102 *);
	ssize_t (*copy_file_range)(struct file___102 *, loff_t, struct file___102 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___102 *, loff_t, struct file___102 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___102 *, loff_t, loff_t, int);
};

struct vmacache___107 {
	u64 seqnum;
	struct vm_area_struct___107 *vmas[4];
};

struct page_frag___107 {
	struct page___107 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___108;

struct pid___92;

struct nsproxy___97;

struct signal_struct___103;

struct bio_list___48;

struct backing_dev_info___47;

struct io_context___48;

struct css_set___82;

struct mem_cgroup___42;

struct request_queue___48;

struct vm_struct___100;

struct task_struct___109 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___109 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___108 *mm;
	struct mm_struct___108 *active_mm;
	struct vmacache___107 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___109 *real_parent;
	struct task_struct___109 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___109 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___92 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___97 *nsproxy;
	struct signal_struct___103 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___109 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___48 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___47 *backing_dev_info;
	struct io_context___48 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___82 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___107 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___42 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___42 *active_memcg;
	struct request_queue___48 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___109 *oom_reaper_list;
	struct vm_struct___100 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___99;

struct kobj_type___99;

struct kernfs_node___99;

struct kobject___99 {
	const char *name;
	struct list_head entry;
	struct kobject___99 *parent;
	struct kset___99 *kset;
	struct kobj_type___99 *ktype;
	struct kernfs_node___99 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___96 {
	struct kobject___99 kobj;
	struct module___97 *mod;
	struct kobject___99 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___96 {
	struct module___97 *mod;
	struct latch_tree_node node;
};

struct module_layout___96 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___96 mtn;
};

struct module_attribute___96;

struct kernel_param___96;

struct module___97 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___96 mkobj;
	struct module_attribute___96 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___99 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___96 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___96 core_layout;
	struct module_layout___96 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___107 *pgtable_t___107;

struct address_space___102;

struct dev_pagemap___101;

struct page___107 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___102 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___107 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___107 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___108 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___101 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___101;

struct vm_area_struct___107 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___107 *vm_next;
	struct vm_area_struct___107 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___108 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___101 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___102 *vm_file;
	struct file___102 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___107;

struct mm_struct___108 {
	struct {
		struct vm_area_struct___107 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___102 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___107 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___109 *owner;
		struct user_namespace___14 *user_ns;
		struct file___102 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___102;

struct address_space___102 {
	struct inode___102 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___102 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___101;

struct dev_pagemap___101 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___101 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___102;

struct path___102 {
	struct vfsmount___102 *mnt;
	struct dentry___102 *dentry;
};

struct fown_struct___92 {
	rwlock_t lock;
	struct pid___92 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___102 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___102 f_path;
	struct inode___102 *f_inode;
	const struct file_operations___102 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___102 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___101;

struct vm_operations_struct___101 {
	void (*open)(struct vm_area_struct___107 *);
	void (*close)(struct vm_area_struct___107 *);
	int (*may_split)(struct vm_area_struct___107 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___107 *);
	int (*mprotect)(struct vm_area_struct___107 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___101 *);
	vm_fault_t (*huge_fault)(struct vm_fault___101 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___101 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___107 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___101 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___101 *);
	int (*access)(struct vm_area_struct___107 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___107 *);
	int (*set_policy)(struct vm_area_struct___107 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___107 *, long unsigned int);
	struct page___107 * (*find_special_page)(struct vm_area_struct___107 *, long unsigned int);
};

struct core_thread___107 {
	struct task_struct___109 *task;
	struct core_thread___107 *next;
};

struct core_state___107 {
	atomic_t nr_threads;
	struct core_thread___107 dumper;
	struct completion startup;
};

struct vm_fault___101 {
	const struct {
		struct vm_area_struct___107 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___107 *cow_page;
	struct page___107 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___107 prealloc_pte;
};

struct pglist_data___48;

struct lruvec___48 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___48 *pgdat;
};

struct zone___48 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___48 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___48 {
	struct zone___48 *zone;
	int zone_idx;
};

struct zonelist___48 {
	struct zoneref___48 _zonerefs[321];
};

struct pglist_data___48 {
	struct zone___48 node_zones[5];
	struct zonelist___48 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___109 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___109 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___48 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___42 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___42 *memcg;
};

struct cgroup___82;

struct cgroup_subsys___82;

struct cgroup_subsys_state___82 {
	struct cgroup___82 *cgroup;
	struct cgroup_subsys___82 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___82 *parent;
};

struct cgroup_file___82 {
	struct kernfs_node___99 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___42;

struct mem_cgroup_per_node___42;

struct mem_cgroup___42 {
	struct cgroup_subsys_state___82 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___82 events_file;
	struct cgroup_file___82 events_local_file;
	struct cgroup_file___82 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___42 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___109 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___42 *nodeinfo[0];
	long: 64;
};

struct shrinker___42 {
	long unsigned int (*count_objects)(struct shrinker___42 *, struct shrink_control___42 *);
	long unsigned int (*scan_objects)(struct shrinker___42 *, struct shrink_control___42 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___101 {
	void (*page_free)(struct page___107 *);
	void (*kill)(struct dev_pagemap___101 *);
	void (*cleanup)(struct dev_pagemap___101 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___101 *);
};

struct pid_namespace___92;

struct upid___92 {
	int nr;
	struct pid_namespace___92 *ns;
};

struct pid_namespace___92 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___109 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___92 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___92 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___92 numbers[1];
};

struct signal_struct___103 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___109 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___109 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___92 *pids[4];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___108 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___82;

struct nsproxy___97 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___92 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___82 *cgroup_ns;
};

struct bio___48;

struct bio_list___48 {
	struct bio___48 *head;
	struct bio___48 *tail;
};

struct bdi_writeback___47 {
	struct backing_dev_info___47 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___82 *memcg_css;
	struct cgroup_subsys_state___82 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___84;

struct backing_dev_info___47 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___47 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___84 *dev;
	char dev_name[64];
	struct device___84 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___102 *debug_dir;
};

struct io_cq___48;

struct io_context___48 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___48 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___82 {
	struct cgroup_subsys_state___82 *subsys[14];
	refcount_t refcount;
	struct css_set___82 *dom_cset;
	struct cgroup___82 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___82 *mg_src_cgrp;
	struct cgroup___82 *mg_dst_cgrp;
	struct css_set___82 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___48;

struct blk_integrity___48 {
	const struct blk_integrity_profile___48 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___48 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___48 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___48;

struct elevator_queue___48;

struct blk_mq_ops___47;

struct blk_mq_hw_ctx___47;

struct gendisk___48;

struct blkcg_gq___47;

struct blk_mq_tag_set___47;

struct request_queue___48 {
	struct request___48 *last_merge;
	struct elevator_queue___48 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___47 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___47 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___48 *disk;
	struct kobject___99 kobj;
	struct kobject___99 *mq_kobj;
	struct blk_integrity___48 integrity;
	struct device___84 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___47 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___47 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___48 bio_split;
	struct dentry___102 *debugfs_dir;
	struct dentry___102 *sched_debugfs_dir;
	struct dentry___102 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___100 {
	struct vm_struct___100 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___107 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___102;

struct dentry___102 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___102 *d_parent;
	struct qstr d_name;
	struct inode___102 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___102 *d_op;
	struct super_block___102 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___102;

struct inode___102 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___102 *i_op;
	struct super_block___102 *i_sb;
	struct address_space___102 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___47 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___102 *i_fop;
		void (*free_inode)(struct inode___102 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___102 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___102 {
	int (*d_revalidate)(struct dentry___102 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___102 *, unsigned int);
	int (*d_hash)(const struct dentry___102 *, struct qstr *);
	int (*d_compare)(const struct dentry___102 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___102 *);
	int (*d_init)(struct dentry___102 *);
	void (*d_release)(struct dentry___102 *);
	void (*d_prune)(struct dentry___102 *);
	void (*d_iput)(struct dentry___102 *, struct inode___102 *);
	char * (*d_dname)(struct dentry___102 *, char *, int);
	struct vfsmount___102 * (*d_automount)(struct path___102 *);
	int (*d_manage)(const struct path___102 *, bool);
	struct dentry___102 * (*d_real)(struct dentry___102 *, const struct inode___102 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___102;

struct mem_dqinfo___102 {
	struct quota_format_type___102 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___102;

struct quota_info___102 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___102 *files[3];
	struct mem_dqinfo___102 info[3];
	const struct quota_format_ops___102 *ops[3];
};

struct rcuwait___103 {
	struct task_struct___109 *task;
};

struct percpu_rw_semaphore___103 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___103 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___102 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___103 rw_sem[3];
};

struct super_operations___102;

struct dquot_operations___102;

struct quotactl_ops___102;

struct export_operations___5;

struct block_device___49;

struct super_block___102 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___102 *s_type;
	const struct super_operations___102 *s_op;
	const struct dquot_operations___102 *dq_op;
	const struct quotactl_ops___102 *s_qcop;
	const struct export_operations___5 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___102 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___49 *s_bdev;
	struct backing_dev_info___47 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___102 s_dquot;
	struct sb_writers___102 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___102 *s_d_op;
	int cleancache_poolid;
	struct shrinker___42 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___102 {
	struct dentry___102 *mnt_root;
	struct super_block___102 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct psi_group___82 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___109 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___82;

struct cgroup_rstat_cpu___82;

struct cgroup___82 {
	struct cgroup_subsys_state___82 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___99 *kn;
	struct cgroup_file___82 procs_file;
	struct cgroup_file___82 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___82 *subsys[14];
	struct cgroup_root___82 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___82 *dom_cgrp;
	struct cgroup___82 *old_dom_cgrp;
	struct cgroup_rstat_cpu___82 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___82 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___48 {
	struct request_queue___48 *q;
	struct io_context___48 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___3;

typedef int get_block_t___2(struct inode___102 *, sector_t, struct buffer_head___3 *, int);

typedef void bh_end_io_t___3(struct buffer_head___3 *, int);

struct buffer_head___3 {
	long unsigned int b_state;
	struct buffer_head___3 *b_this_page;
	struct page___107 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___49 *b_bdev;
	bh_end_io_t___3 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___102 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___50;

struct kiocb___102 {
	struct file___102 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___102 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___102 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___102 *ia_file;
};

struct dquot___102 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___102 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___102 {
	int qf_fmt_id;
	const struct quota_format_ops___102 *qf_ops;
	struct module___97 *qf_owner;
	struct quota_format_type___102 *qf_next;
};

struct quota_format_ops___102 {
	int (*check_quota_file)(struct super_block___102 *, int);
	int (*read_file_info)(struct super_block___102 *, int);
	int (*write_file_info)(struct super_block___102 *, int);
	int (*free_file_info)(struct super_block___102 *, int);
	int (*read_dqblk)(struct dquot___102 *);
	int (*commit_dqblk)(struct dquot___102 *);
	int (*release_dqblk)(struct dquot___102 *);
	int (*get_next_id)(struct super_block___102 *, struct kqid *);
};

struct dquot_operations___102 {
	int (*write_dquot)(struct dquot___102 *);
	struct dquot___102 * (*alloc_dquot)(struct super_block___102 *, int);
	void (*destroy_dquot)(struct dquot___102 *);
	int (*acquire_dquot)(struct dquot___102 *);
	int (*release_dquot)(struct dquot___102 *);
	int (*mark_dirty)(struct dquot___102 *);
	int (*write_info)(struct super_block___102 *, int);
	qsize_t * (*get_reserved_space)(struct inode___102 *);
	int (*get_projid)(struct inode___102 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___102 *, qsize_t *);
	int (*get_next_id)(struct super_block___102 *, struct kqid *);
};

struct quotactl_ops___102 {
	int (*quota_on)(struct super_block___102 *, int, int, const struct path___102 *);
	int (*quota_off)(struct super_block___102 *, int);
	int (*quota_enable)(struct super_block___102 *, unsigned int);
	int (*quota_disable)(struct super_block___102 *, unsigned int);
	int (*quota_sync)(struct super_block___102 *, int);
	int (*set_info)(struct super_block___102 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___102 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___102 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___102 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___102 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___102 *, unsigned int);
};

struct wait_page_queue___50 {
	struct page___107 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___47;

struct readahead_control___50;

struct swap_info_struct___27;

struct address_space_operations___102 {
	int (*writepage)(struct page___107 *, struct writeback_control___47 *);
	int (*readpage)(struct file___102 *, struct page___107 *);
	int (*writepages)(struct address_space___102 *, struct writeback_control___47 *);
	int (*set_page_dirty)(struct page___107 *);
	int (*readpages)(struct file___102 *, struct address_space___102 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___50 *);
	int (*write_begin)(struct file___102 *, struct address_space___102 *, loff_t, unsigned int, unsigned int, struct page___107 **, void **);
	int (*write_end)(struct file___102 *, struct address_space___102 *, loff_t, unsigned int, unsigned int, struct page___107 *, void *);
	sector_t (*bmap)(struct address_space___102 *, sector_t);
	void (*invalidatepage)(struct page___107 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___107 *, gfp_t);
	void (*freepage)(struct page___107 *);
	ssize_t (*direct_IO)(struct kiocb___102 *, struct iov_iter___61 *);
	int (*migratepage)(struct address_space___102 *, struct page___107 *, struct page___107 *, enum migrate_mode);
	bool (*isolate_page)(struct page___107 *, isolate_mode_t);
	void (*putback_page)(struct page___107 *);
	int (*launder_page)(struct page___107 *);
	int (*is_partially_uptodate)(struct page___107 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___107 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___102 *, struct page___107 *);
	int (*swap_activate)(struct swap_info_struct___27 *, struct file___102 *, sector_t *);
	void (*swap_deactivate)(struct file___102 *);
};

struct writeback_control___47 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___47 *wb;
	struct inode___102 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___50 {
	struct file___102 *file;
	struct address_space___102 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___59;

struct iov_iter___61 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___59 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___27 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___49 *bdev;
	struct file___102 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___102 {
	struct dentry___102 * (*lookup)(struct inode___102 *, struct dentry___102 *, unsigned int);
	const char * (*get_link)(struct dentry___102 *, struct inode___102 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___102 *, int);
	struct posix_acl * (*get_acl)(struct inode___102 *, int, bool);
	int (*readlink)(struct dentry___102 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___102 *, struct dentry___102 *, umode_t, bool);
	int (*link)(struct dentry___102 *, struct inode___102 *, struct dentry___102 *);
	int (*unlink)(struct inode___102 *, struct dentry___102 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___102 *, struct dentry___102 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___102 *, struct dentry___102 *, umode_t);
	int (*rmdir)(struct inode___102 *, struct dentry___102 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___102 *, struct dentry___102 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___102 *, struct dentry___102 *, struct inode___102 *, struct dentry___102 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___102 *, struct iattr___102 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___102 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___102 *, char *, size_t);
	int (*fiemap)(struct inode___102 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___102 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___102 *, struct dentry___102 *, struct file___102 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___102 *, struct dentry___102 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___102 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___102 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___102 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___102 {
	void (*fl_copy_lock)(struct file_lock___102 *, struct file_lock___102 *);
	void (*fl_release_private)(struct file_lock___102 *);
};

struct fasync_struct___102;

struct lock_manager_operations___102;

struct file_lock___102 {
	struct file_lock___102 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___102 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___102 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___102 *fl_ops;
	const struct lock_manager_operations___102 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___102 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___102 *);
	int (*lm_grant)(struct file_lock___102 *, int);
	bool (*lm_break)(struct file_lock___102 *);
	int (*lm_change)(struct file_lock___102 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___102 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___102 *);
};

struct fasync_struct___102 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___102 *fa_next;
	struct file___102 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___102 {
	struct inode___102 * (*alloc_inode)(struct super_block___102 *);
	void (*destroy_inode)(struct inode___102 *);
	void (*free_inode)(struct inode___102 *);
	void (*dirty_inode)(struct inode___102 *, int);
	int (*write_inode)(struct inode___102 *, struct writeback_control___47 *);
	int (*drop_inode)(struct inode___102 *);
	void (*evict_inode)(struct inode___102 *);
	void (*put_super)(struct super_block___102 *);
	int (*sync_fs)(struct super_block___102 *, int);
	int (*freeze_super)(struct super_block___102 *);
	int (*freeze_fs)(struct super_block___102 *);
	int (*thaw_super)(struct super_block___102 *);
	int (*unfreeze_fs)(struct super_block___102 *);
	int (*statfs)(struct dentry___102 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___102 *, int *, char *);
	void (*umount_begin)(struct super_block___102 *);
	int (*show_options)(struct seq_file___94 *, struct dentry___102 *);
	int (*show_devname)(struct seq_file___94 *, struct dentry___102 *);
	int (*show_path)(struct seq_file___94 *, struct dentry___102 *);
	int (*show_stats)(struct seq_file___94 *, struct dentry___102 *);
	ssize_t (*quota_read)(struct super_block___102 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___102 *, int, const char *, size_t, loff_t);
	struct dquot___102 ** (*get_dquots)(struct inode___102 *);
	long int (*nr_cached_objects)(struct super_block___102 *, struct shrink_control___42 *);
	long int (*free_cached_objects)(struct super_block___102 *, struct shrink_control___42 *);
	struct file___102 * (*real_loop)(struct file___102 *);
};

struct export_operations___5 {
	int (*encode_fh)(struct inode___102 *, __u32 *, int *, struct inode___102 *);
	struct dentry___102 * (*fh_to_dentry)(struct super_block___102 *, struct fid *, int, int);
	struct dentry___102 * (*fh_to_parent)(struct super_block___102 *, struct fid *, int, int);
	int (*get_name)(struct dentry___102 *, char *, struct dentry___102 *);
	struct dentry___102 * (*get_parent)(struct dentry___102 *);
	int (*commit_metadata)(struct inode___102 *);
	int (*get_uuid)(struct super_block___102 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___102 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___102 *, struct iomap *, int, struct iattr___102 *);
	u64 (*fetch_iversion)(struct inode___102 *);
	long unsigned int flags;
};

struct wakeup_source___84;

struct dev_pm_info___84 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___84 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___84 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___84;

struct bus_type___84;

struct device_driver___84;

struct dev_pm_domain___84;

struct fwnode_handle___84;

struct class___84;

struct attribute_group___99;

struct device___84 {
	struct kobject___99 kobj;
	struct device___84 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___84 *type;
	struct bus_type___84 *bus;
	struct device_driver___84 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___84 power;
	struct dev_pm_domain___84 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___84 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___84 *class;
	const struct attribute_group___99 **groups;
	void (*release)(struct device___84 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___49 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___102 *bd_inode;
	struct super_block___102 *bd_super;
	void *bd_claiming;
	struct device___84 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___99 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___48 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___102 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___94;

struct seq_file___94 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___94 *op;
	int poll_event;
	const struct file___102 *file;
	void *private;
};

typedef void bio_end_io_t___48(struct bio___48 *);

struct bio_vec___59 {
	struct page___107 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___48;

struct bio___48 {
	struct bio___48 *bi_next;
	struct block_device___49 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___48 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___47 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___48 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___59 *bi_io_vec;
	struct bio_set___48 *bi_pool;
	struct bio_vec___59 bi_inline_vecs[0];
};

struct fwnode_operations___84;

struct fwnode_handle___84 {
	struct fwnode_handle___84 *secondary;
	const struct fwnode_operations___84 *ops;
	struct device___84 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___84;

struct fwnode_endpoint___84;

struct fwnode_operations___84 {
	struct fwnode_handle___84 * (*get)(struct fwnode_handle___84 *);
	void (*put)(struct fwnode_handle___84 *);
	bool (*device_is_available)(const struct fwnode_handle___84 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___84 *, const struct device___84 *);
	bool (*property_present)(const struct fwnode_handle___84 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___84 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___84 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___84 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*get_parent)(const struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*get_next_child_node)(const struct fwnode_handle___84 *, struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*get_named_child_node)(const struct fwnode_handle___84 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___84 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___84 *);
	struct fwnode_handle___84 * (*graph_get_next_endpoint)(const struct fwnode_handle___84 *, struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*graph_get_remote_endpoint)(const struct fwnode_handle___84 *);
	struct fwnode_handle___84 * (*graph_get_port_parent)(struct fwnode_handle___84 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___84 *, struct fwnode_endpoint___84 *);
	int (*add_links)(struct fwnode_handle___84 *);
};

struct fwnode_endpoint___84 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___84 *local_fwnode;
};

struct fwnode_reference_args___84 {
	struct fwnode_handle___84 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___99;

struct kernfs_elem_dir___99 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___99 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___99;

struct kernfs_root___99 {
	struct kernfs_node___99 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___99 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___99 {
	struct kernfs_node___99 *target_kn;
};

struct kernfs_ops___99;

struct kernfs_elem_attr___99 {
	const struct kernfs_ops___99 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___99 *notify_next;
};

struct kernfs_node___99 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___99 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___99 dir;
		struct kernfs_elem_symlink___99 symlink;
		struct kernfs_elem_attr___99 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___99;

struct kernfs_ops___99 {
	int (*open)(struct kernfs_open_file___99 *);
	void (*release)(struct kernfs_open_file___99 *);
	int (*seq_show)(struct seq_file___94 *, void *);
	void * (*seq_start)(struct seq_file___94 *, loff_t *);
	void * (*seq_next)(struct seq_file___94 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___94 *, void *);
	ssize_t (*read)(struct kernfs_open_file___99 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___99 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___99 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___99 *, struct vm_area_struct___107 *);
};

struct kernfs_syscall_ops___99 {
	int (*show_options)(struct seq_file___94 *, struct kernfs_root___99 *);
	int (*mkdir)(struct kernfs_node___99 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___99 *);
	int (*rename)(struct kernfs_node___99 *, struct kernfs_node___99 *, const char *);
	int (*show_path)(struct seq_file___94 *, struct kernfs_node___99 *, struct kernfs_root___99 *);
};

struct kernfs_open_file___99 {
	struct kernfs_node___99 *kn;
	struct file___102 *file;
	struct seq_file___94 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___101 *vm_ops;
};

struct bin_attribute___99;

struct attribute_group___99 {
	const char *name;
	umode_t (*is_visible)(struct kobject___99 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___99 *, struct bin_attribute___99 *, int);
	struct attribute **attrs;
	struct bin_attribute___99 **bin_attrs;
};

struct bin_attribute___99 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___102 * (*f_mapping)();
	ssize_t (*read)(struct file___102 *, struct kobject___99 *, struct bin_attribute___99 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___102 *, struct kobject___99 *, struct bin_attribute___99 *, char *, loff_t, size_t);
	int (*mmap)(struct file___102 *, struct kobject___99 *, struct bin_attribute___99 *, struct vm_area_struct___107 *);
};

struct sysfs_ops___99 {
	ssize_t (*show)(struct kobject___99 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___99 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___99;

struct kset___99 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___99 kobj;
	const struct kset_uevent_ops___99 *uevent_ops;
};

struct kobj_type___99 {
	void (*release)(struct kobject___99 *);
	const struct sysfs_ops___99 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___99 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___99 *);
	const void * (*namespace)(struct kobject___99 *);
	void (*get_ownership)(struct kobject___99 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___99 {
	int (* const filter)(struct kset___99 *, struct kobject___99 *);
	const char * (* const name)(struct kset___99 *, struct kobject___99 *);
	int (* const uevent)(struct kset___99 *, struct kobject___99 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___96 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___96 *);
	int (*get)(char *, const struct kernel_param___96 *);
	void (*free)(void *);
};

struct kparam_array___96;

struct kernel_param___96 {
	const char *name;
	struct module___97 *mod;
	const struct kernel_param_ops___96 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___96 *arr;
	};
};

struct kparam_array___96 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___96 *ops;
	void *elem;
};

struct module_attribute___96 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___96 *, struct module_kobject___96 *, char *);
	ssize_t (*store)(struct module_attribute___96 *, struct module_kobject___96 *, const char *, size_t);
	void (*setup)(struct module___97 *, const char *);
	int (*test)(struct module___97 *);
	void (*free)(struct module___97 *);
};

struct cgroup_namespace___82 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___82 *root_cset;
};

struct bvec_iter_all {
	struct bio_vec___59 bv;
	int idx;
	unsigned int done;
};

struct dev_pm_ops___84 {
	int (*prepare)(struct device___84 *);
	void (*complete)(struct device___84 *);
	int (*suspend)(struct device___84 *);
	int (*resume)(struct device___84 *);
	int (*freeze)(struct device___84 *);
	int (*thaw)(struct device___84 *);
	int (*poweroff)(struct device___84 *);
	int (*restore)(struct device___84 *);
	int (*suspend_late)(struct device___84 *);
	int (*resume_early)(struct device___84 *);
	int (*freeze_late)(struct device___84 *);
	int (*thaw_early)(struct device___84 *);
	int (*poweroff_late)(struct device___84 *);
	int (*restore_early)(struct device___84 *);
	int (*suspend_noirq)(struct device___84 *);
	int (*resume_noirq)(struct device___84 *);
	int (*freeze_noirq)(struct device___84 *);
	int (*thaw_noirq)(struct device___84 *);
	int (*poweroff_noirq)(struct device___84 *);
	int (*restore_noirq)(struct device___84 *);
	int (*runtime_suspend)(struct device___84 *);
	int (*runtime_resume)(struct device___84 *);
	int (*runtime_idle)(struct device___84 *);
};

struct wakeup_source___84 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___84 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___84 {
	struct dev_pm_ops___84 ops;
	int (*start)(struct device___84 *);
	void (*detach)(struct device___84 *, bool);
	int (*activate)(struct device___84 *);
	void (*sync)(struct device___84 *);
	void (*dismiss)(struct device___84 *);
};

struct bus_type___84 {
	const char *name;
	const char *dev_name;
	struct device___84 *dev_root;
	const struct attribute_group___99 **bus_groups;
	const struct attribute_group___99 **dev_groups;
	const struct attribute_group___99 **drv_groups;
	int (*match)(struct device___84 *, struct device_driver___84 *);
	int (*uevent)(struct device___84 *, struct kobj_uevent_env *);
	int (*probe)(struct device___84 *);
	void (*sync_state)(struct device___84 *);
	void (*remove)(struct device___84 *);
	void (*shutdown)(struct device___84 *);
	int (*online)(struct device___84 *);
	int (*offline)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	int (*num_vf)(struct device___84 *);
	int (*dma_configure)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___84 {
	const char *name;
	struct bus_type___84 *bus;
	struct module___97 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___84 *);
	void (*sync_state)(struct device___84 *);
	int (*remove)(struct device___84 *);
	void (*shutdown)(struct device___84 *);
	int (*suspend)(struct device___84 *, pm_message_t);
	int (*resume)(struct device___84 *);
	const struct attribute_group___99 **groups;
	const struct attribute_group___99 **dev_groups;
	const struct dev_pm_ops___84 *pm;
	void (*coredump)(struct device___84 *);
	struct driver_private *p;
};

struct device_type___84 {
	const char *name;
	const struct attribute_group___99 **groups;
	int (*uevent)(struct device___84 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___84 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___84 *);
	const struct dev_pm_ops___84 *pm;
};

struct class___84 {
	const char *name;
	struct module___97 *owner;
	const struct attribute_group___99 **class_groups;
	const struct attribute_group___99 **dev_groups;
	struct kobject___99 *dev_kobj;
	int (*dev_uevent)(struct device___84 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___84 *, umode_t *);
	void (*class_release)(struct class___84 *);
	void (*dev_release)(struct device___84 *);
	int (*shutdown_pre)(struct device___84 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___84 *);
	void (*get_ownership)(struct device___84 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___84 *pm;
	struct subsys_private *p;
};

struct block_device_operations___48;

struct gendisk___48 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___49 *part0;
	const struct block_device_operations___48 *fops;
	struct request_queue___48 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___47 *bdi;
	struct kobject___99 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___99 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___48 {
	struct bio___48 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___59 *bip_vec;
	struct bio_vec___59 bip_inline_vecs[0];
};

struct blkcg___47;

struct blkg_policy_data___47;

struct blkcg_gq___47 {
	struct request_queue___48 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___47 *blkcg;
	struct blkcg_gq___47 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___47 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___48 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___48(struct request___48 *);

typedef void integrity_complete_fn___48(struct request___48 *, unsigned int);

struct blk_integrity_profile___48 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___48 *prepare_fn;
	integrity_complete_fn___48 *complete_fn;
	const char *name;
};

struct block_device_operations___48 {
	blk_qc_t (*submit_bio)(struct bio___48 *);
	int (*open)(struct block_device___49 *, fmode_t);
	void (*release)(struct gendisk___48 *, fmode_t);
	int (*rw_page)(struct block_device___49 *, sector_t, struct page___107 *, unsigned int);
	int (*ioctl)(struct block_device___49 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___49 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___48 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___48 *);
	int (*getgeo)(struct block_device___49 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___49 *, bool);
	void (*swap_slot_free_notify)(struct block_device___49 *, long unsigned int);
	int (*report_zones)(struct gendisk___48 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___48 *, umode_t *);
	struct module___97 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___48 *, sector_t *);
};

typedef void rq_end_io_fn___48(struct request___48 *, blk_status_t);

struct request___48 {
	struct request_queue___48 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___47 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___48 *bio;
	struct bio___48 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___59 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___48 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___48 *saved_end_io;
		} flush;
	};
	struct gendisk___48 *rq_disk;
	struct block_device___49 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___48 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___47 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___48 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___99 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___102 *debugfs_dir;
	struct dentry___102 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___48;

struct elevator_mq_ops___48 {
	int (*init_sched)(struct request_queue___48 *, struct elevator_type___48 *);
	void (*exit_sched)(struct elevator_queue___48 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___47 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___47 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___47 *);
	bool (*allow_merge)(struct request_queue___48 *, struct request___48 *, struct bio___48 *);
	bool (*bio_merge)(struct request_queue___48 *, struct bio___48 *, unsigned int);
	int (*request_merge)(struct request_queue___48 *, struct request___48 **, struct bio___48 *);
	void (*request_merged)(struct request_queue___48 *, struct request___48 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___48 *, struct request___48 *, struct request___48 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___48 *);
	void (*finish_request)(struct request___48 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___47 *, struct list_head *, bool);
	struct request___48 * (*dispatch_request)(struct blk_mq_hw_ctx___47 *);
	bool (*has_work)(struct blk_mq_hw_ctx___47 *);
	void (*completed_request)(struct request___48 *, u64);
	void (*requeue_request)(struct request___48 *);
	struct request___48 * (*former_request)(struct request_queue___48 *, struct request___48 *);
	struct request___48 * (*next_request)(struct request_queue___48 *, struct request___48 *);
	void (*init_icq)(struct io_cq___48 *);
	void (*exit_icq)(struct io_cq___48 *);
};

struct elv_fs_entry___48;

struct elevator_type___48 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___48 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___48 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___97 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___48 {
	struct elevator_type___48 *type;
	void *elevator_data;
	struct kobject___99 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___48 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___48 *, char *);
	ssize_t (*store)(struct elevator_queue___48 *, const char *, size_t);
};

struct blk_mq_queue_data___47;

struct blk_mq_ops___47 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___47 *, const struct blk_mq_queue_data___47 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___47 *);
	int (*get_budget)(struct request_queue___48 *);
	void (*put_budget)(struct request_queue___48 *, int);
	void (*set_rq_budget_token)(struct request___48 *, int);
	int (*get_rq_budget_token)(struct request___48 *);
	enum blk_eh_timer_return (*timeout)(struct request___48 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___47 *);
	void (*complete)(struct request___48 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___47 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___47 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___47 *, struct request___48 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___47 *, struct request___48 *, unsigned int);
	void (*initialize_rq_fn)(struct request___48 *);
	void (*cleanup_rq)(struct request___48 *);
	bool (*busy)(struct request_queue___48 *);
	int (*map_queues)(struct blk_mq_tag_set___47 *);
	void (*show_rq)(struct seq_file___94 *, struct request___48 *);
};

struct blk_mq_tag_set___47 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___47 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___94 {
	void * (*start)(struct seq_file___94 *, loff_t *);
	void (*stop)(struct seq_file___94 *, void *);
	void * (*next)(struct seq_file___94 *, void *, loff_t *);
	int (*show)(struct seq_file___94 *, void *);
};

struct cftype___82;

struct cgroup_subsys___82 {
	struct cgroup_subsys_state___82 * (*css_alloc)(struct cgroup_subsys_state___82 *);
	int (*css_online)(struct cgroup_subsys_state___82 *);
	void (*css_offline)(struct cgroup_subsys_state___82 *);
	void (*css_released)(struct cgroup_subsys_state___82 *);
	void (*css_free)(struct cgroup_subsys_state___82 *);
	void (*css_reset)(struct cgroup_subsys_state___82 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___82 *, int);
	int (*css_extra_stat_show)(struct seq_file___94 *, struct cgroup_subsys_state___82 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___109 *, struct css_set___82 *);
	void (*cancel_fork)(struct task_struct___109 *, struct css_set___82 *);
	void (*fork)(struct task_struct___109 *);
	void (*exit)(struct task_struct___109 *);
	void (*release)(struct task_struct___109 *);
	void (*bind)(struct cgroup_subsys_state___82 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___82 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___82 *dfl_cftypes;
	struct cftype___82 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___82 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___82 *updated_children;
	struct cgroup___82 *updated_next;
};

struct cgroup_root___82 {
	struct kernfs_root___99 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___82 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___82 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___82 *ss;
	struct list_head node;
	struct kernfs_ops___99 *kf_ops;
	int (*open)(struct kernfs_open_file___99 *);
	void (*release)(struct kernfs_open_file___99 *);
	u64 (*read_u64)(struct cgroup_subsys_state___82 *, struct cftype___82 *);
	s64 (*read_s64)(struct cgroup_subsys_state___82 *, struct cftype___82 *);
	int (*seq_show)(struct seq_file___94 *, void *);
	void * (*seq_start)(struct seq_file___94 *, loff_t *);
	void * (*seq_next)(struct seq_file___94 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___94 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___82 *, struct cftype___82 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___82 *, struct cftype___82 *, s64);
	ssize_t (*write)(struct kernfs_open_file___99 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___99 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___47 {
	struct request___48 *rq;
	bool last;
};

struct blkcg_policy_data___47;

struct blkcg___47 {
	struct cgroup_subsys_state___82 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___47 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___47 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___47 {
	struct blkcg___47 *blkcg;
	int plid;
};

struct blkg_policy_data___47 {
	struct blkcg_gq___47 *blkg;
	int plid;
};

typedef int (*writepage_t___2)(struct page___107 *, struct writeback_control___47 *, void *);

struct mem_cgroup_reclaim_iter___42 {
	struct mem_cgroup___42 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___42 {
	struct lruvec___48 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___42 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___42 *memcg;
};

struct obj_cgroup___42 {
	struct percpu_ref refcnt;
	struct mem_cgroup___42 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct mpage_readpage_args {
	struct bio___48 *bio;
	struct page___107 *page;
	unsigned int nr_pages;
	bool is_readahead;
	sector_t last_block_in_bio;
	struct buffer_head___3 map_bh;
	long unsigned int first_logical_block;
	get_block_t___2 *get_block;
};

struct mpage_data {
	struct bio___48 *bio;
	sector_t last_block_in_bio;
	get_block_t___2 *get_block;
	unsigned int use_writepage;
};

struct file___103;

struct kiocb___103;

struct poll_table_struct___73;

struct vm_area_struct___108;

struct inode___103;

struct file_lock___103;

struct page___108;

struct seq_file___95;

struct file_operations___103 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___103 *, loff_t, int);
	ssize_t (*read)(struct file___103 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___103 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___103 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___103 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___103 *, bool);
	int (*iterate)(struct file___103 *, struct dir_context *);
	int (*iterate_shared)(struct file___103 *, struct dir_context *);
	__poll_t (*poll)(struct file___103 *, struct poll_table_struct___73 *);
	long int (*unlocked_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___103 *, struct vm_area_struct___108 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___103 *, struct file___103 *);
	int (*flush)(struct file___103 *, fl_owner_t);
	int (*release)(struct inode___103 *, struct file___103 *);
	int (*fsync)(struct file___103 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___103 *, int);
	int (*lock)(struct file___103 *, int, struct file_lock___103 *);
	ssize_t (*sendpage)(struct file___103 *, struct page___108 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___103 *, long unsigned int);
	int (*flock)(struct file___103 *, int, struct file_lock___103 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___103 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___103 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___103 *, long int, struct file_lock___103 **, void **);
	long int (*fallocate)(struct file___103 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___95 *, struct file___103 *);
	ssize_t (*copy_file_range)(struct file___103 *, loff_t, struct file___103 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___103 *, loff_t, struct file___103 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___103 *, loff_t, loff_t, int);
};

typedef u32 nlink_t;

struct dentry___103;

struct super_block___103;

struct file_system_type___103 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___103 * (*mount)(struct file_system_type___103 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___103 *);
	struct module___8 *owner;
	struct file_system_type___103 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct vmacache___108 {
	u64 seqnum;
	struct vm_area_struct___108 *vmas[4];
};

struct page_frag___108 {
	struct page___108 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___109;

struct fs_struct___16;

struct nsproxy___98;

struct signal_struct___104;

struct task_struct___110 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___110 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___109 *mm;
	struct mm_struct___109 *active_mm;
	struct vmacache___108 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___110 *real_parent;
	struct task_struct___110 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___110 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___92 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___16 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___98 *nsproxy;
	struct signal_struct___104 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___110 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___48 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___108 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___110 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___108 *pgtable_t___108;

struct address_space___103;

struct dev_pagemap___102;

struct page___108 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___103 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___108 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___108 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___109 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___102 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___102;

struct vm_area_struct___108 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___108 *vm_next;
	struct vm_area_struct___108 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___109 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___102 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___103 *vm_file;
	struct file___103 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___104 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___110 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___110 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___92 *pids[4];
	struct pid___92 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___109 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___15;

struct core_state___108;

struct mm_struct___109 {
	struct {
		struct vm_area_struct___108 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___15 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___108 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___110 *owner;
		struct user_namespace *user_ns;
		struct file___103 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vfsmount___103;

struct path___103 {
	struct vfsmount___103 *mnt;
	struct dentry___103 *dentry;
};

struct fs_struct___16 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___103 root;
	struct path___103 pwd;
};

struct mnt_namespace___7;

struct nsproxy___98 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___7 *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct proc_ns_operations___15;

struct ns_common___15 {
	atomic_long_t stashed;
	const struct proc_ns_operations___15 *ops;
	unsigned int inum;
	refcount_t count;
};

struct mount___7;

struct mnt_namespace___7 {
	struct ns_common___15 ns;
	struct mount___7 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct nsset___14 {
	unsigned int flags;
	struct nsproxy___98 *nsproxy;
	struct fs_struct___16 *fs;
	const struct cred___13 *cred;
};

struct file___103 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___103 f_path;
	struct inode___103 *f_inode;
	const struct file_operations___103 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___92 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___103 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct dentry_operations___103;

struct dentry___103 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___103 *d_parent;
	struct qstr d_name;
	struct inode___103 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___103 *d_op;
	struct super_block___103 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___103;

struct address_space___103 {
	struct inode___103 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___103 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___103;

struct inode___103 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___103 *i_op;
	struct super_block___103 *i_sb;
	struct address_space___103 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___103 *i_fop;
		void (*free_inode)(struct inode___103 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___103 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___103 {
	int (*d_revalidate)(struct dentry___103 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___103 *, unsigned int);
	int (*d_hash)(const struct dentry___103 *, struct qstr *);
	int (*d_compare)(const struct dentry___103 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___103 *);
	int (*d_init)(struct dentry___103 *);
	void (*d_release)(struct dentry___103 *);
	void (*d_prune)(struct dentry___103 *);
	void (*d_iput)(struct dentry___103 *, struct inode___103 *);
	char * (*d_dname)(struct dentry___103 *, char *, int);
	struct vfsmount___103 * (*d_automount)(struct path___103 *);
	int (*d_manage)(const struct path___103 *, bool);
	struct dentry___103 * (*d_real)(struct dentry___103 *, const struct inode___103 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___103;

struct mem_dqinfo___103 {
	struct quota_format_type___103 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___103;

struct quota_info___103 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___103 *files[3];
	struct mem_dqinfo___103 info[3];
	const struct quota_format_ops___103 *ops[3];
};

struct rcuwait___104 {
	struct task_struct___110 *task;
};

struct percpu_rw_semaphore___104 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___104 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___103 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___104 rw_sem[3];
};

struct super_operations___103;

struct dquot_operations___103;

struct quotactl_ops___103;

struct super_block___103 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___103 *s_type;
	const struct super_operations___103 *s_op;
	const struct dquot_operations___103 *dq_op;
	const struct quotactl_ops___103 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___103 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___103 s_dquot;
	struct sb_writers___103 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___103 *s_d_op;
	int cleancache_poolid;
	struct shrinker___42 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___103 {
	struct dentry___103 *mnt_root;
	struct super_block___103 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct dev_pagemap_ops___102;

struct dev_pagemap___102 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___102 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___102;

struct vm_operations_struct___102 {
	void (*open)(struct vm_area_struct___108 *);
	void (*close)(struct vm_area_struct___108 *);
	int (*may_split)(struct vm_area_struct___108 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___108 *);
	int (*mprotect)(struct vm_area_struct___108 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___102 *);
	vm_fault_t (*huge_fault)(struct vm_fault___102 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___102 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___108 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___102 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___102 *);
	int (*access)(struct vm_area_struct___108 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___108 *);
	int (*set_policy)(struct vm_area_struct___108 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___108 *, long unsigned int);
	struct page___108 * (*find_special_page)(struct vm_area_struct___108 *, long unsigned int);
};

struct core_thread___108 {
	struct task_struct___110 *task;
	struct core_thread___108 *next;
};

struct core_state___108 {
	atomic_t nr_threads;
	struct core_thread___108 dumper;
	struct completion startup;
};

struct linux_binprm___16;

struct coredump_params___15;

struct linux_binfmt___15 {
	struct list_head lh;
	struct module___8 *module;
	int (*load_binary)(struct linux_binprm___16 *);
	int (*load_shlib)(struct file___103 *);
	int (*core_dump)(struct coredump_params___15 *);
	long unsigned int min_coredump;
};

struct vm_fault___102 {
	const struct {
		struct vm_area_struct___108 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___108 *cow_page;
	struct page___108 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___108 prealloc_pte;
};

struct kiocb___103 {
	struct file___103 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___103 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___103 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___103 *ia_file;
};

struct dquot___103 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___103 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___103 {
	int qf_fmt_id;
	const struct quota_format_ops___103 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___103 *qf_next;
};

struct quota_format_ops___103 {
	int (*check_quota_file)(struct super_block___103 *, int);
	int (*read_file_info)(struct super_block___103 *, int);
	int (*write_file_info)(struct super_block___103 *, int);
	int (*free_file_info)(struct super_block___103 *, int);
	int (*read_dqblk)(struct dquot___103 *);
	int (*commit_dqblk)(struct dquot___103 *);
	int (*release_dqblk)(struct dquot___103 *);
	int (*get_next_id)(struct super_block___103 *, struct kqid *);
};

struct dquot_operations___103 {
	int (*write_dquot)(struct dquot___103 *);
	struct dquot___103 * (*alloc_dquot)(struct super_block___103 *, int);
	void (*destroy_dquot)(struct dquot___103 *);
	int (*acquire_dquot)(struct dquot___103 *);
	int (*release_dquot)(struct dquot___103 *);
	int (*mark_dirty)(struct dquot___103 *);
	int (*write_info)(struct super_block___103 *, int);
	qsize_t * (*get_reserved_space)(struct inode___103 *);
	int (*get_projid)(struct inode___103 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___103 *, qsize_t *);
	int (*get_next_id)(struct super_block___103 *, struct kqid *);
};

struct quotactl_ops___103 {
	int (*quota_on)(struct super_block___103 *, int, int, const struct path___103 *);
	int (*quota_off)(struct super_block___103 *, int);
	int (*quota_enable)(struct super_block___103 *, unsigned int);
	int (*quota_disable)(struct super_block___103 *, unsigned int);
	int (*quota_sync)(struct super_block___103 *, int);
	int (*set_info)(struct super_block___103 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___103 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___103 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___103 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___103 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___103 *, unsigned int);
};

struct address_space_operations___103 {
	int (*writepage)(struct page___108 *, struct writeback_control___3 *);
	int (*readpage)(struct file___103 *, struct page___108 *);
	int (*writepages)(struct address_space___103 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___108 *);
	int (*readpages)(struct file___103 *, struct address_space___103 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___103 *, struct address_space___103 *, loff_t, unsigned int, unsigned int, struct page___108 **, void **);
	int (*write_end)(struct file___103 *, struct address_space___103 *, loff_t, unsigned int, unsigned int, struct page___108 *, void *);
	sector_t (*bmap)(struct address_space___103 *, sector_t);
	void (*invalidatepage)(struct page___108 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___108 *, gfp_t);
	void (*freepage)(struct page___108 *);
	ssize_t (*direct_IO)(struct kiocb___103 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___103 *, struct page___108 *, struct page___108 *, enum migrate_mode);
	bool (*isolate_page)(struct page___108 *, isolate_mode_t);
	void (*putback_page)(struct page___108 *);
	int (*launder_page)(struct page___108 *);
	int (*is_partially_uptodate)(struct page___108 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___108 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___103 *, struct page___108 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___103 *, sector_t *);
	void (*swap_deactivate)(struct file___103 *);
};

struct inode_operations___103 {
	struct dentry___103 * (*lookup)(struct inode___103 *, struct dentry___103 *, unsigned int);
	const char * (*get_link)(struct dentry___103 *, struct inode___103 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___103 *, int);
	struct posix_acl * (*get_acl)(struct inode___103 *, int, bool);
	int (*readlink)(struct dentry___103 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___103 *, struct dentry___103 *, umode_t, bool);
	int (*link)(struct dentry___103 *, struct inode___103 *, struct dentry___103 *);
	int (*unlink)(struct inode___103 *, struct dentry___103 *);
	int (*symlink)(struct user_namespace *, struct inode___103 *, struct dentry___103 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___103 *, struct dentry___103 *, umode_t);
	int (*rmdir)(struct inode___103 *, struct dentry___103 *);
	int (*mknod)(struct user_namespace *, struct inode___103 *, struct dentry___103 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___103 *, struct dentry___103 *, struct inode___103 *, struct dentry___103 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___103 *, struct iattr___103 *);
	int (*getattr)(struct user_namespace *, const struct path___103 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___103 *, char *, size_t);
	int (*fiemap)(struct inode___103 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___103 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___103 *, struct dentry___103 *, struct file___103 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___103 *, struct dentry___103 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___103 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___103 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___103 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___103 {
	void (*fl_copy_lock)(struct file_lock___103 *, struct file_lock___103 *);
	void (*fl_release_private)(struct file_lock___103 *);
};

struct fasync_struct___103;

struct lock_manager_operations___103;

struct file_lock___103 {
	struct file_lock___103 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___103 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___103 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___103 *fl_ops;
	const struct lock_manager_operations___103 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___103 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___103 *);
	int (*lm_grant)(struct file_lock___103 *, int);
	bool (*lm_break)(struct file_lock___103 *);
	int (*lm_change)(struct file_lock___103 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___103 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___103 *);
};

struct fasync_struct___103 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___103 *fa_next;
	struct file___103 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___103 {
	struct inode___103 * (*alloc_inode)(struct super_block___103 *);
	void (*destroy_inode)(struct inode___103 *);
	void (*free_inode)(struct inode___103 *);
	void (*dirty_inode)(struct inode___103 *, int);
	int (*write_inode)(struct inode___103 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___103 *);
	void (*evict_inode)(struct inode___103 *);
	void (*put_super)(struct super_block___103 *);
	int (*sync_fs)(struct super_block___103 *, int);
	int (*freeze_super)(struct super_block___103 *);
	int (*freeze_fs)(struct super_block___103 *);
	int (*thaw_super)(struct super_block___103 *);
	int (*unfreeze_fs)(struct super_block___103 *);
	int (*statfs)(struct dentry___103 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___103 *, int *, char *);
	void (*umount_begin)(struct super_block___103 *);
	int (*show_options)(struct seq_file___95 *, struct dentry___103 *);
	int (*show_devname)(struct seq_file___95 *, struct dentry___103 *);
	int (*show_path)(struct seq_file___95 *, struct dentry___103 *);
	int (*show_stats)(struct seq_file___95 *, struct dentry___103 *);
	ssize_t (*quota_read)(struct super_block___103 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___103 *, int, const char *, size_t, loff_t);
	struct dquot___103 ** (*get_dquots)(struct inode___103 *);
	long int (*nr_cached_objects)(struct super_block___103 *, struct shrink_control___42 *);
	long int (*free_cached_objects)(struct super_block___103 *, struct shrink_control___42 *);
	struct file___103 * (*real_loop)(struct file___103 *);
};

typedef void (*poll_queue_proc___73)(struct file___103 *, wait_queue_head_t *, struct poll_table_struct___73 *);

struct poll_table_struct___73 {
	poll_queue_proc___73 _qproc;
	__poll_t _key;
};

struct seq_operations___95;

struct seq_file___95 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___95 *op;
	int poll_event;
	const struct file___103 *file;
	void *private;
};

struct dev_pagemap_ops___102 {
	void (*page_free)(struct page___108 *);
	void (*kill)(struct dev_pagemap___102 *);
	void (*cleanup)(struct dev_pagemap___102 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___102 *);
};

struct proc_ops___8 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___103 *, struct file___103 *);
	ssize_t (*proc_read)(struct file___103 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___103 *, struct iov_iter___4 *);
	ssize_t (*proc_write)(struct file___103 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___103 *, loff_t, int);
	int (*proc_release)(struct inode___103 *, struct file___103 *);
	__poll_t (*proc_poll)(struct file___103 *, struct poll_table_struct___73 *);
	long int (*proc_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___103 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___103 *, struct vm_area_struct___108 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___103 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

typedef int (*proc_write_t)(struct file___103 *, char *, size_t);

struct proc_ns_operations___15 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___15 * (*get)(struct task_struct___110 *);
	void (*put)(struct ns_common___15 *);
	int (*install)(struct nsset___14 *, struct ns_common___15 *);
	struct user_namespace * (*owner)(struct ns_common___15 *);
	struct ns_common___15 * (*get_parent)(struct ns_common___15 *);
};

struct linux_binprm___16 {
	struct vm_area_struct___108 *vma;
	long unsigned int vma_pages;
	struct mm_struct___109 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___103 *executable;
	struct file___103 *interpreter;
	struct file___103 *file;
	struct cred___13 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___15 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___103 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct seq_operations___95 {
	void * (*start)(struct seq_file___95 *, loff_t *);
	void (*stop)(struct seq_file___95 *, void *);
	void * (*next)(struct seq_file___95 *, void *, loff_t *);
	int (*show)(struct seq_file___95 *, void *);
};

struct proc_dir_entry___2 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___103 *proc_iops;
	union {
		const struct proc_ops___8 *proc_ops;
		const struct file_operations___103 *proc_dir_ops;
	};
	const struct dentry_operations___103 *proc_dops;
	union {
		const struct seq_operations___95 *seq_ops;
		int (*single_show)(struct seq_file___95 *, void *);
	};
	proc_write_t write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___2 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

union proc_op {
	int (*proc_get_link)(struct dentry___103 *, struct path___103 *);
	int (*proc_show)(struct seq_file___95 *, struct pid_namespace *, struct pid___92 *, struct task_struct___110 *);
	const char *lsm;
};

struct proc_inode {
	struct pid___92 *pid;
	unsigned int fd;
	union proc_op op;
	struct proc_dir_entry___2 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___15 *ns_ops;
	struct inode___103 vfs_inode;
};

typedef struct poll_table_struct___73 poll_table___18;

struct mountpoint___7;

struct mount___7 {
	struct hlist_node mnt_hash;
	struct mount___7 *mnt_parent;
	struct dentry___103 *mnt_mountpoint;
	struct vfsmount___103 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___7 *mnt_master;
	struct mnt_namespace___7 *mnt_ns;
	struct mountpoint___7 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___7 {
	struct hlist_node m_hash;
	struct dentry___103 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct proc_mounts___2 {
	struct mnt_namespace___7 *ns;
	struct path___103 root;
	int (*show)(struct seq_file___95 *, struct vfsmount___103 *);
	struct mount___7 cursor;
};

struct proc_fs_opts {
	int flag;
	const char *str;
};

struct dentry___104;

struct super_block___104;

struct module___98;

struct file_system_type___104 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___104 * (*mount)(struct file_system_type___104 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___104 *);
	struct module___98 *owner;
	struct file_system_type___104 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___104;

struct kiocb___104;

struct poll_table_struct___74;

struct vm_area_struct___109;

struct inode___104;

struct file_lock___104;

struct page___109;

struct seq_file___96;

struct file_operations___104 {
	struct module___98 *owner;
	loff_t (*llseek)(struct file___104 *, loff_t, int);
	ssize_t (*read)(struct file___104 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___104 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___104 *, struct iov_iter___61 *);
	ssize_t (*write_iter)(struct kiocb___104 *, struct iov_iter___61 *);
	int (*iopoll)(struct kiocb___104 *, bool);
	int (*iterate)(struct file___104 *, struct dir_context *);
	int (*iterate_shared)(struct file___104 *, struct dir_context *);
	__poll_t (*poll)(struct file___104 *, struct poll_table_struct___74 *);
	long int (*unlocked_ioctl)(struct file___104 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___104 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___104 *, struct vm_area_struct___109 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___104 *, struct file___104 *);
	int (*flush)(struct file___104 *, fl_owner_t);
	int (*release)(struct inode___104 *, struct file___104 *);
	int (*fsync)(struct file___104 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___104 *, int);
	int (*lock)(struct file___104 *, int, struct file_lock___104 *);
	ssize_t (*sendpage)(struct file___104 *, struct page___109 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___104 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___104 *, long unsigned int);
	int (*flock)(struct file___104 *, int, struct file_lock___104 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___104 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___104 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___104 *, long int, struct file_lock___104 **, void **);
	long int (*fallocate)(struct file___104 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___96 *, struct file___104 *);
	ssize_t (*copy_file_range)(struct file___104 *, loff_t, struct file___104 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___104 *, loff_t, struct file___104 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___104 *, loff_t, loff_t, int);
};

struct vmacache___109 {
	u64 seqnum;
	struct vm_area_struct___109 *vmas[4];
};

struct page_frag___109 {
	struct page___109 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___110;

struct pid___93;

struct nsproxy___99;

struct signal_struct___105;

struct task_struct___111 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___111 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___110 *mm;
	struct mm_struct___110 *active_mm;
	struct vmacache___109 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___111 *real_parent;
	struct task_struct___111 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___111 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___93 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___99 *nsproxy;
	struct signal_struct___105 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___111 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___48 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___109 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___111 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___100;

struct kobj_type___100;

struct kernfs_node___100;

struct kobject___100 {
	const char *name;
	struct list_head entry;
	struct kobject___100 *parent;
	struct kset___100 *kset;
	struct kobj_type___100 *ktype;
	struct kernfs_node___100 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___97 {
	struct kobject___100 kobj;
	struct module___98 *mod;
	struct kobject___100 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___97 {
	struct module___98 *mod;
	struct latch_tree_node node;
};

struct module_layout___97 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___97 mtn;
};

struct module_attribute___97;

struct kernel_param___97;

struct module___98 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___97 mkobj;
	struct module_attribute___97 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___100 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___97 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___97 core_layout;
	struct module_layout___97 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___104;

struct dentry___104 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___104 *d_parent;
	struct qstr d_name;
	struct inode___104 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___104 *d_op;
	struct super_block___104 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___104;

struct address_space___104 {
	struct inode___104 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___104 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___104;

struct inode___104 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___104 *i_op;
	struct super_block___104 *i_sb;
	struct address_space___104 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___104 *i_fop;
		void (*free_inode)(struct inode___104 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___104 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___104;

struct path___104;

struct dentry_operations___104 {
	int (*d_revalidate)(struct dentry___104 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___104 *, unsigned int);
	int (*d_hash)(const struct dentry___104 *, struct qstr *);
	int (*d_compare)(const struct dentry___104 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___104 *);
	int (*d_init)(struct dentry___104 *);
	void (*d_release)(struct dentry___104 *);
	void (*d_prune)(struct dentry___104 *);
	void (*d_iput)(struct dentry___104 *, struct inode___104 *);
	char * (*d_dname)(struct dentry___104 *, char *, int);
	struct vfsmount___104 * (*d_automount)(struct path___104 *);
	int (*d_manage)(const struct path___104 *, bool);
	struct dentry___104 * (*d_real)(struct dentry___104 *, const struct inode___104 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___104;

struct mem_dqinfo___104 {
	struct quota_format_type___104 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___104;

struct quota_info___104 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___104 *files[3];
	struct mem_dqinfo___104 info[3];
	const struct quota_format_ops___104 *ops[3];
};

struct rcuwait___105 {
	struct task_struct___111 *task;
};

struct percpu_rw_semaphore___105 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___105 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___104 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___105 rw_sem[3];
};

struct super_operations___104;

struct dquot_operations___104;

struct quotactl_ops___104;

struct super_block___104 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___104 *s_type;
	const struct super_operations___104 *s_op;
	const struct dquot_operations___104 *dq_op;
	const struct quotactl_ops___104 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___104 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___104 s_dquot;
	struct sb_writers___104 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___104 *s_d_op;
	int cleancache_poolid;
	struct shrinker___42 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___104 {
	struct dentry___104 *mnt_root;
	struct super_block___104 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___104 {
	struct vfsmount___104 *mnt;
	struct dentry___104 *dentry;
};

struct pid_namespace___93;

struct upid___93 {
	int nr;
	struct pid_namespace___93 *ns;
};

struct pid_namespace___93 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___111 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___93 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___93 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___93 numbers[1];
};

typedef struct page___109 *pgtable_t___109;

struct dev_pagemap___103;

struct page___109 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___104 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___109 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___109 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___110 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___103 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___103;

struct vm_area_struct___109 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___109 *vm_next;
	struct vm_area_struct___109 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___110 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___103 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___104 *vm_file;
	struct file___104 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___105 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___111 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___111 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___93 *pids[4];
	struct pid___93 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___110 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___109;

struct mm_struct___110 {
	struct {
		struct vm_area_struct___109 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___104 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___109 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___111 *owner;
		struct user_namespace___14 *user_ns;
		struct file___104 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct mnt_namespace___8;

struct nsproxy___99 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___8 *mnt_ns;
	struct pid_namespace___93 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct dev_pagemap_ops___103;

struct dev_pagemap___103 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___103 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___93 {
	rwlock_t lock;
	struct pid___93 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___104 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___104 f_path;
	struct inode___104 *f_inode;
	const struct file_operations___104 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___93 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___104 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___103;

struct vm_operations_struct___103 {
	void (*open)(struct vm_area_struct___109 *);
	void (*close)(struct vm_area_struct___109 *);
	int (*may_split)(struct vm_area_struct___109 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___109 *);
	int (*mprotect)(struct vm_area_struct___109 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___103 *);
	vm_fault_t (*huge_fault)(struct vm_fault___103 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___103 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___109 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___103 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___103 *);
	int (*access)(struct vm_area_struct___109 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___109 *);
	int (*set_policy)(struct vm_area_struct___109 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___109 *, long unsigned int);
	struct page___109 * (*find_special_page)(struct vm_area_struct___109 *, long unsigned int);
};

struct core_thread___109 {
	struct task_struct___111 *task;
	struct core_thread___109 *next;
};

struct core_state___109 {
	atomic_t nr_threads;
	struct core_thread___109 dumper;
	struct completion startup;
};

struct vm_fault___103 {
	const struct {
		struct vm_area_struct___109 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___109 *cow_page;
	struct page___109 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___109 prealloc_pte;
};

struct kiocb___104 {
	struct file___104 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___104 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___104 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___104 *ia_file;
};

struct dquot___104 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___104 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___104 {
	int qf_fmt_id;
	const struct quota_format_ops___104 *qf_ops;
	struct module___98 *qf_owner;
	struct quota_format_type___104 *qf_next;
};

struct quota_format_ops___104 {
	int (*check_quota_file)(struct super_block___104 *, int);
	int (*read_file_info)(struct super_block___104 *, int);
	int (*write_file_info)(struct super_block___104 *, int);
	int (*free_file_info)(struct super_block___104 *, int);
	int (*read_dqblk)(struct dquot___104 *);
	int (*commit_dqblk)(struct dquot___104 *);
	int (*release_dqblk)(struct dquot___104 *);
	int (*get_next_id)(struct super_block___104 *, struct kqid *);
};

struct dquot_operations___104 {
	int (*write_dquot)(struct dquot___104 *);
	struct dquot___104 * (*alloc_dquot)(struct super_block___104 *, int);
	void (*destroy_dquot)(struct dquot___104 *);
	int (*acquire_dquot)(struct dquot___104 *);
	int (*release_dquot)(struct dquot___104 *);
	int (*mark_dirty)(struct dquot___104 *);
	int (*write_info)(struct super_block___104 *, int);
	qsize_t * (*get_reserved_space)(struct inode___104 *);
	int (*get_projid)(struct inode___104 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___104 *, qsize_t *);
	int (*get_next_id)(struct super_block___104 *, struct kqid *);
};

struct quotactl_ops___104 {
	int (*quota_on)(struct super_block___104 *, int, int, const struct path___104 *);
	int (*quota_off)(struct super_block___104 *, int);
	int (*quota_enable)(struct super_block___104 *, unsigned int);
	int (*quota_disable)(struct super_block___104 *, unsigned int);
	int (*quota_sync)(struct super_block___104 *, int);
	int (*set_info)(struct super_block___104 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___104 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___104 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___104 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___104 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___104 *, unsigned int);
};

struct address_space_operations___104 {
	int (*writepage)(struct page___109 *, struct writeback_control___3 *);
	int (*readpage)(struct file___104 *, struct page___109 *);
	int (*writepages)(struct address_space___104 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___109 *);
	int (*readpages)(struct file___104 *, struct address_space___104 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___104 *, struct address_space___104 *, loff_t, unsigned int, unsigned int, struct page___109 **, void **);
	int (*write_end)(struct file___104 *, struct address_space___104 *, loff_t, unsigned int, unsigned int, struct page___109 *, void *);
	sector_t (*bmap)(struct address_space___104 *, sector_t);
	void (*invalidatepage)(struct page___109 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___109 *, gfp_t);
	void (*freepage)(struct page___109 *);
	ssize_t (*direct_IO)(struct kiocb___104 *, struct iov_iter___61 *);
	int (*migratepage)(struct address_space___104 *, struct page___109 *, struct page___109 *, enum migrate_mode);
	bool (*isolate_page)(struct page___109 *, isolate_mode_t);
	void (*putback_page)(struct page___109 *);
	int (*launder_page)(struct page___109 *);
	int (*is_partially_uptodate)(struct page___109 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___109 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___104 *, struct page___109 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___104 *, sector_t *);
	void (*swap_deactivate)(struct file___104 *);
};

struct inode_operations___104 {
	struct dentry___104 * (*lookup)(struct inode___104 *, struct dentry___104 *, unsigned int);
	const char * (*get_link)(struct dentry___104 *, struct inode___104 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___104 *, int);
	struct posix_acl * (*get_acl)(struct inode___104 *, int, bool);
	int (*readlink)(struct dentry___104 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___104 *, struct dentry___104 *, umode_t, bool);
	int (*link)(struct dentry___104 *, struct inode___104 *, struct dentry___104 *);
	int (*unlink)(struct inode___104 *, struct dentry___104 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___104 *, struct dentry___104 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___104 *, struct dentry___104 *, umode_t);
	int (*rmdir)(struct inode___104 *, struct dentry___104 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___104 *, struct dentry___104 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___104 *, struct dentry___104 *, struct inode___104 *, struct dentry___104 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___104 *, struct iattr___104 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___104 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___104 *, char *, size_t);
	int (*fiemap)(struct inode___104 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___104 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___104 *, struct dentry___104 *, struct file___104 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___104 *, struct dentry___104 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___104 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___104 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___104 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___104 {
	void (*fl_copy_lock)(struct file_lock___104 *, struct file_lock___104 *);
	void (*fl_release_private)(struct file_lock___104 *);
};

struct fasync_struct___104;

struct lock_manager_operations___104;

struct file_lock___104 {
	struct file_lock___104 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___104 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___104 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___104 *fl_ops;
	const struct lock_manager_operations___104 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___104 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___104 *);
	int (*lm_grant)(struct file_lock___104 *, int);
	bool (*lm_break)(struct file_lock___104 *);
	int (*lm_change)(struct file_lock___104 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___104 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___104 *);
};

struct fasync_struct___104 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___104 *fa_next;
	struct file___104 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___104 {
	struct inode___104 * (*alloc_inode)(struct super_block___104 *);
	void (*destroy_inode)(struct inode___104 *);
	void (*free_inode)(struct inode___104 *);
	void (*dirty_inode)(struct inode___104 *, int);
	int (*write_inode)(struct inode___104 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___104 *);
	void (*evict_inode)(struct inode___104 *);
	void (*put_super)(struct super_block___104 *);
	int (*sync_fs)(struct super_block___104 *, int);
	int (*freeze_super)(struct super_block___104 *);
	int (*freeze_fs)(struct super_block___104 *);
	int (*thaw_super)(struct super_block___104 *);
	int (*unfreeze_fs)(struct super_block___104 *);
	int (*statfs)(struct dentry___104 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___104 *, int *, char *);
	void (*umount_begin)(struct super_block___104 *);
	int (*show_options)(struct seq_file___96 *, struct dentry___104 *);
	int (*show_devname)(struct seq_file___96 *, struct dentry___104 *);
	int (*show_path)(struct seq_file___96 *, struct dentry___104 *);
	int (*show_stats)(struct seq_file___96 *, struct dentry___104 *);
	ssize_t (*quota_read)(struct super_block___104 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___104 *, int, const char *, size_t, loff_t);
	struct dquot___104 ** (*get_dquots)(struct inode___104 *);
	long int (*nr_cached_objects)(struct super_block___104 *, struct shrink_control___42 *);
	long int (*free_cached_objects)(struct super_block___104 *, struct shrink_control___42 *);
	struct file___104 * (*real_loop)(struct file___104 *);
};

typedef void (*poll_queue_proc___74)(struct file___104 *, wait_queue_head_t *, struct poll_table_struct___74 *);

struct poll_table_struct___74 {
	poll_queue_proc___74 _qproc;
	__poll_t _key;
};

struct seq_operations___96;

struct seq_file___96 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___96 *op;
	int poll_event;
	const struct file___104 *file;
	void *private;
};

struct kernfs_root___100;

struct kernfs_elem_dir___100 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___100 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___100;

struct kernfs_root___100 {
	struct kernfs_node___100 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___100 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___100 {
	struct kernfs_node___100 *target_kn;
};

struct kernfs_ops___100;

struct kernfs_elem_attr___100 {
	const struct kernfs_ops___100 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___100 *notify_next;
};

struct kernfs_node___100 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___100 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___100 dir;
		struct kernfs_elem_symlink___100 symlink;
		struct kernfs_elem_attr___100 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___100;

struct kernfs_ops___100 {
	int (*open)(struct kernfs_open_file___100 *);
	void (*release)(struct kernfs_open_file___100 *);
	int (*seq_show)(struct seq_file___96 *, void *);
	void * (*seq_start)(struct seq_file___96 *, loff_t *);
	void * (*seq_next)(struct seq_file___96 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___96 *, void *);
	ssize_t (*read)(struct kernfs_open_file___100 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___100 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___100 *, struct poll_table_struct___74 *);
	int (*mmap)(struct kernfs_open_file___100 *, struct vm_area_struct___109 *);
};

struct kernfs_syscall_ops___100 {
	int (*show_options)(struct seq_file___96 *, struct kernfs_root___100 *);
	int (*mkdir)(struct kernfs_node___100 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___100 *);
	int (*rename)(struct kernfs_node___100 *, struct kernfs_node___100 *, const char *);
	int (*show_path)(struct seq_file___96 *, struct kernfs_node___100 *, struct kernfs_root___100 *);
};

struct kernfs_open_file___100 {
	struct kernfs_node___100 *kn;
	struct file___104 *file;
	struct seq_file___96 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___103 *vm_ops;
};

struct bin_attribute___100;

struct attribute_group___100 {
	const char *name;
	umode_t (*is_visible)(struct kobject___100 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___100 *, struct bin_attribute___100 *, int);
	struct attribute **attrs;
	struct bin_attribute___100 **bin_attrs;
};

struct bin_attribute___100 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___104 * (*f_mapping)();
	ssize_t (*read)(struct file___104 *, struct kobject___100 *, struct bin_attribute___100 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___104 *, struct kobject___100 *, struct bin_attribute___100 *, char *, loff_t, size_t);
	int (*mmap)(struct file___104 *, struct kobject___100 *, struct bin_attribute___100 *, struct vm_area_struct___109 *);
};

struct sysfs_ops___100 {
	ssize_t (*show)(struct kobject___100 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___100 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___100;

struct kset___100 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___100 kobj;
	const struct kset_uevent_ops___100 *uevent_ops;
};

struct kobj_type___100 {
	void (*release)(struct kobject___100 *);
	const struct sysfs_ops___100 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___100 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___100 *);
	const void * (*namespace)(struct kobject___100 *);
	void (*get_ownership)(struct kobject___100 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___100 {
	int (* const filter)(struct kset___100 *, struct kobject___100 *);
	const char * (* const name)(struct kset___100 *, struct kobject___100 *);
	int (* const uevent)(struct kset___100 *, struct kobject___100 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___97 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___97 *);
	int (*get)(char *, const struct kernel_param___97 *);
	void (*free)(void *);
};

struct kparam_array___97;

struct kernel_param___97 {
	const char *name;
	struct module___98 *mod;
	const struct kernel_param_ops___97 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___97 *arr;
	};
};

struct kparam_array___97 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___97 *ops;
	void *elem;
};

struct module_attribute___97 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___97 *, struct module_kobject___97 *, char *);
	ssize_t (*store)(struct module_attribute___97 *, struct module_kobject___97 *, const char *, size_t);
	void (*setup)(struct module___98 *, const char *);
	int (*test)(struct module___98 *);
	void (*free)(struct module___98 *);
};

struct mount___8;

struct mnt_namespace___8 {
	struct ns_common___14 ns;
	struct mount___8 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct seq_operations___96 {
	void * (*start)(struct seq_file___96 *, loff_t *);
	void (*stop)(struct seq_file___96 *, void *);
	void * (*next)(struct seq_file___96 *, void *, loff_t *);
	int (*show)(struct seq_file___96 *, void *);
};

struct fsnotify_group___2;

struct fsnotify_iter_info___2;

struct fsnotify_mark___2;

struct fsnotify_ops___2 {
	int (*handle_event)(struct fsnotify_group___2 *, u32, const void *, int, struct inode___104 *, const struct qstr *, u32, struct fsnotify_iter_info___2 *);
	int (*handle_inode_event)(struct fsnotify_mark___2 *, u32, struct inode___104 *, struct inode___104 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___2 *);
	void (*freeing_mark)(struct fsnotify_mark___2 *, struct fsnotify_group___2 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___2 *);
};

struct fsnotify_group___2 {
	const struct fsnotify_ops___2 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___104 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___2 {
	struct fsnotify_mark___2 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___2 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___2 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct dev_pagemap_ops___103 {
	void (*page_free)(struct page___109 *);
	void (*kill)(struct dev_pagemap___103 *);
	void (*cleanup)(struct dev_pagemap___103 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___103 *);
};

struct mountpoint___8;

struct mount___8 {
	struct hlist_node mnt_hash;
	struct mount___8 *mnt_parent;
	struct dentry___104 *mnt_mountpoint;
	struct vfsmount___104 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___8 *mnt_master;
	struct mnt_namespace___8 *mnt_ns;
	struct mountpoint___8 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___8 {
	struct hlist_node m_hash;
	struct dentry___104 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct dentry___105;

struct super_block___105;

struct module___99;

struct file_system_type___105 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___105 * (*mount)(struct file_system_type___105 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___105 *);
	struct module___99 *owner;
	struct file_system_type___105 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___105;

struct kiocb___105;

struct iov_iter___62;

struct poll_table_struct___75;

struct vm_area_struct___110;

struct inode___105;

struct file_lock___105;

struct page___110;

struct seq_file___97;

struct file_operations___105 {
	struct module___99 *owner;
	loff_t (*llseek)(struct file___105 *, loff_t, int);
	ssize_t (*read)(struct file___105 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___105 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___105 *, struct iov_iter___62 *);
	ssize_t (*write_iter)(struct kiocb___105 *, struct iov_iter___62 *);
	int (*iopoll)(struct kiocb___105 *, bool);
	int (*iterate)(struct file___105 *, struct dir_context *);
	int (*iterate_shared)(struct file___105 *, struct dir_context *);
	__poll_t (*poll)(struct file___105 *, struct poll_table_struct___75 *);
	long int (*unlocked_ioctl)(struct file___105 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___105 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___105 *, struct vm_area_struct___110 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___105 *, struct file___105 *);
	int (*flush)(struct file___105 *, fl_owner_t);
	int (*release)(struct inode___105 *, struct file___105 *);
	int (*fsync)(struct file___105 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___105 *, int);
	int (*lock)(struct file___105 *, int, struct file_lock___105 *);
	ssize_t (*sendpage)(struct file___105 *, struct page___110 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___105 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___105 *, long unsigned int);
	int (*flock)(struct file___105 *, int, struct file_lock___105 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___105 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___105 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___105 *, long int, struct file_lock___105 **, void **);
	long int (*fallocate)(struct file___105 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___97 *, struct file___105 *);
	ssize_t (*copy_file_range)(struct file___105 *, loff_t, struct file___105 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___105 *, loff_t, struct file___105 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___105 *, loff_t, loff_t, int);
};

struct vmacache___110 {
	u64 seqnum;
	struct vm_area_struct___110 *vmas[4];
};

struct page_frag___110 {
	struct page___110 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___111;

struct pid___94;

struct nsproxy___100;

struct signal_struct___106;

struct bio_list___49;

struct backing_dev_info___48;

struct io_context___49;

struct css_set___83;

struct mem_cgroup___43;

struct request_queue___49;

struct vm_struct___101;

struct task_struct___112 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___112 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___111 *mm;
	struct mm_struct___111 *active_mm;
	struct vmacache___110 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___112 *real_parent;
	struct task_struct___112 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___112 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___94 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___100 *nsproxy;
	struct signal_struct___106 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___112 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___49 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___48 *backing_dev_info;
	struct io_context___49 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___83 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___110 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___43 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___43 *active_memcg;
	struct request_queue___49 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___112 *oom_reaper_list;
	struct vm_struct___101 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___101;

struct kobj_type___101;

struct kernfs_node___101;

struct kobject___101 {
	const char *name;
	struct list_head entry;
	struct kobject___101 *parent;
	struct kset___101 *kset;
	struct kobj_type___101 *ktype;
	struct kernfs_node___101 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___98 {
	struct kobject___101 kobj;
	struct module___99 *mod;
	struct kobject___101 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___98 {
	struct module___99 *mod;
	struct latch_tree_node node;
};

struct module_layout___98 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___98 mtn;
};

struct module_attribute___98;

struct kernel_param___98;

struct module___99 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___98 mkobj;
	struct module_attribute___98 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___101 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___98 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___98 core_layout;
	struct module_layout___98 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___110 *pgtable_t___110;

struct address_space___105;

struct dev_pagemap___104;

struct page___110 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___105 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___110 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___110 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___111 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___104 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___104;

struct vm_area_struct___110 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___110 *vm_next;
	struct vm_area_struct___110 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___111 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___104 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___105 *vm_file;
	struct file___105 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___110;

struct mm_struct___111 {
	struct {
		struct vm_area_struct___110 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___105 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___110 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___112 *owner;
		struct user_namespace___14 *user_ns;
		struct file___105 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___105;

struct address_space___105 {
	struct inode___105 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___105 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___104;

struct dev_pagemap___104 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___104 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___105;

struct path___105 {
	struct vfsmount___105 *mnt;
	struct dentry___105 *dentry;
};

struct fown_struct___94 {
	rwlock_t lock;
	struct pid___94 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___105 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___105 f_path;
	struct inode___105 *f_inode;
	const struct file_operations___105 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___94 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___105 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___104;

struct vm_operations_struct___104 {
	void (*open)(struct vm_area_struct___110 *);
	void (*close)(struct vm_area_struct___110 *);
	int (*may_split)(struct vm_area_struct___110 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___110 *);
	int (*mprotect)(struct vm_area_struct___110 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___104 *);
	vm_fault_t (*huge_fault)(struct vm_fault___104 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___104 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___110 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___104 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___104 *);
	int (*access)(struct vm_area_struct___110 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___110 *);
	int (*set_policy)(struct vm_area_struct___110 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___110 *, long unsigned int);
	struct page___110 * (*find_special_page)(struct vm_area_struct___110 *, long unsigned int);
};

struct core_thread___110 {
	struct task_struct___112 *task;
	struct core_thread___110 *next;
};

struct core_state___110 {
	atomic_t nr_threads;
	struct core_thread___110 dumper;
	struct completion startup;
};

struct vm_fault___104 {
	const struct {
		struct vm_area_struct___110 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___110 *cow_page;
	struct page___110 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___110 prealloc_pte;
};

struct pglist_data___49;

struct lruvec___49 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___49 *pgdat;
};

struct zone___49 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___49 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___49 {
	struct zone___49 *zone;
	int zone_idx;
};

struct zonelist___49 {
	struct zoneref___49 _zonerefs[321];
};

struct pglist_data___49 {
	struct zone___49 node_zones[5];
	struct zonelist___49 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___112 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___112 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___49 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___94;

struct upid___94 {
	int nr;
	struct pid_namespace___94 *ns;
};

struct pid_namespace___94 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___112 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___94 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___94 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___94 numbers[1];
};

struct signal_struct___106 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___112 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___112 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___94 *pids[4];
	struct pid___94 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___111 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct mnt_namespace___9;

struct cgroup_namespace___83;

struct nsproxy___100 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___9 *mnt_ns;
	struct pid_namespace___94 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___83 *cgroup_ns;
};

struct bio___49;

struct bio_list___49 {
	struct bio___49 *head;
	struct bio___49 *tail;
};

struct cgroup_subsys_state___83;

struct bdi_writeback___48 {
	struct backing_dev_info___48 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___83 *memcg_css;
	struct cgroup_subsys_state___83 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___85;

struct backing_dev_info___48 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___48 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___85 *dev;
	char dev_name[64];
	struct device___85 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___105 *debug_dir;
};

struct io_cq___49;

struct io_context___49 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___49 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___83;

struct css_set___83 {
	struct cgroup_subsys_state___83 *subsys[14];
	refcount_t refcount;
	struct css_set___83 *dom_cset;
	struct cgroup___83 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___83 *mg_src_cgrp;
	struct cgroup___83 *mg_dst_cgrp;
	struct css_set___83 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___83;

struct cgroup_subsys_state___83 {
	struct cgroup___83 *cgroup;
	struct cgroup_subsys___83 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___83 *parent;
};

struct cgroup_file___83 {
	struct kernfs_node___101 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___43;

struct mem_cgroup_per_node___43;

struct mem_cgroup___43 {
	struct cgroup_subsys_state___83 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___83 events_file;
	struct cgroup_file___83 events_local_file;
	struct cgroup_file___83 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___43 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___112 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___43 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___49;

struct blk_integrity___49 {
	const struct blk_integrity_profile___49 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___49 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___49 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___49;

struct elevator_queue___49;

struct blk_mq_ops___48;

struct blk_mq_hw_ctx___48;

struct gendisk___49;

struct blkcg_gq___48;

struct blk_mq_tag_set___48;

struct request_queue___49 {
	struct request___49 *last_merge;
	struct elevator_queue___49 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___48 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___48 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___49 *disk;
	struct kobject___101 kobj;
	struct kobject___101 *mq_kobj;
	struct blk_integrity___49 integrity;
	struct device___85 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___48 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___48 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___49 bio_split;
	struct dentry___105 *debugfs_dir;
	struct dentry___105 *sched_debugfs_dir;
	struct dentry___105 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___101 {
	struct vm_struct___101 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___110 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___105;

struct dentry___105 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___105 *d_parent;
	struct qstr d_name;
	struct inode___105 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___105 *d_op;
	struct super_block___105 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___105;

struct inode___105 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___105 *i_op;
	struct super_block___105 *i_sb;
	struct address_space___105 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___48 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___105 *i_fop;
		void (*free_inode)(struct inode___105 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___105 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___105 {
	int (*d_revalidate)(struct dentry___105 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___105 *, unsigned int);
	int (*d_hash)(const struct dentry___105 *, struct qstr *);
	int (*d_compare)(const struct dentry___105 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___105 *);
	int (*d_init)(struct dentry___105 *);
	void (*d_release)(struct dentry___105 *);
	void (*d_prune)(struct dentry___105 *);
	void (*d_iput)(struct dentry___105 *, struct inode___105 *);
	char * (*d_dname)(struct dentry___105 *, char *, int);
	struct vfsmount___105 * (*d_automount)(struct path___105 *);
	int (*d_manage)(const struct path___105 *, bool);
	struct dentry___105 * (*d_real)(struct dentry___105 *, const struct inode___105 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___105;

struct mem_dqinfo___105 {
	struct quota_format_type___105 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___105;

struct quota_info___105 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___105 *files[3];
	struct mem_dqinfo___105 info[3];
	const struct quota_format_ops___105 *ops[3];
};

struct rcuwait___106 {
	struct task_struct___112 *task;
};

struct percpu_rw_semaphore___106 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___106 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___105 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___106 rw_sem[3];
};

struct shrink_control___43;

struct shrinker___43 {
	long unsigned int (*count_objects)(struct shrinker___43 *, struct shrink_control___43 *);
	long unsigned int (*scan_objects)(struct shrinker___43 *, struct shrink_control___43 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___105;

struct dquot_operations___105;

struct quotactl_ops___105;

struct block_device___50;

struct super_block___105 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___105 *s_type;
	const struct super_operations___105 *s_op;
	const struct dquot_operations___105 *dq_op;
	const struct quotactl_ops___105 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___105 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___50 *s_bdev;
	struct backing_dev_info___48 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___105 s_dquot;
	struct sb_writers___105 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___105 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___105 {
	struct dentry___105 *mnt_root;
	struct super_block___105 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___43 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___43 *memcg;
};

struct psi_group___83 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___112 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___83;

struct cgroup_rstat_cpu___83;

struct cgroup___83 {
	struct cgroup_subsys_state___83 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___101 *kn;
	struct cgroup_file___83 procs_file;
	struct cgroup_file___83 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___83 *subsys[14];
	struct cgroup_root___83 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___83 *dom_cgrp;
	struct cgroup___83 *old_dom_cgrp;
	struct cgroup_rstat_cpu___83 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___83 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___49 {
	struct request_queue___49 *q;
	struct io_context___49 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___105 {
	struct file___105 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___105 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___105 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___105 *ia_file;
};

struct dquot___105 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___105 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___105 {
	int qf_fmt_id;
	const struct quota_format_ops___105 *qf_ops;
	struct module___99 *qf_owner;
	struct quota_format_type___105 *qf_next;
};

struct quota_format_ops___105 {
	int (*check_quota_file)(struct super_block___105 *, int);
	int (*read_file_info)(struct super_block___105 *, int);
	int (*write_file_info)(struct super_block___105 *, int);
	int (*free_file_info)(struct super_block___105 *, int);
	int (*read_dqblk)(struct dquot___105 *);
	int (*commit_dqblk)(struct dquot___105 *);
	int (*release_dqblk)(struct dquot___105 *);
	int (*get_next_id)(struct super_block___105 *, struct kqid *);
};

struct dquot_operations___105 {
	int (*write_dquot)(struct dquot___105 *);
	struct dquot___105 * (*alloc_dquot)(struct super_block___105 *, int);
	void (*destroy_dquot)(struct dquot___105 *);
	int (*acquire_dquot)(struct dquot___105 *);
	int (*release_dquot)(struct dquot___105 *);
	int (*mark_dirty)(struct dquot___105 *);
	int (*write_info)(struct super_block___105 *, int);
	qsize_t * (*get_reserved_space)(struct inode___105 *);
	int (*get_projid)(struct inode___105 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___105 *, qsize_t *);
	int (*get_next_id)(struct super_block___105 *, struct kqid *);
};

struct quotactl_ops___105 {
	int (*quota_on)(struct super_block___105 *, int, int, const struct path___105 *);
	int (*quota_off)(struct super_block___105 *, int);
	int (*quota_enable)(struct super_block___105 *, unsigned int);
	int (*quota_disable)(struct super_block___105 *, unsigned int);
	int (*quota_sync)(struct super_block___105 *, int);
	int (*set_info)(struct super_block___105 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___105 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___105 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___105 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___105 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___105 *, unsigned int);
};

struct writeback_control___48;

struct address_space_operations___105 {
	int (*writepage)(struct page___110 *, struct writeback_control___48 *);
	int (*readpage)(struct file___105 *, struct page___110 *);
	int (*writepages)(struct address_space___105 *, struct writeback_control___48 *);
	int (*set_page_dirty)(struct page___110 *);
	int (*readpages)(struct file___105 *, struct address_space___105 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___105 *, struct address_space___105 *, loff_t, unsigned int, unsigned int, struct page___110 **, void **);
	int (*write_end)(struct file___105 *, struct address_space___105 *, loff_t, unsigned int, unsigned int, struct page___110 *, void *);
	sector_t (*bmap)(struct address_space___105 *, sector_t);
	void (*invalidatepage)(struct page___110 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___110 *, gfp_t);
	void (*freepage)(struct page___110 *);
	ssize_t (*direct_IO)(struct kiocb___105 *, struct iov_iter___62 *);
	int (*migratepage)(struct address_space___105 *, struct page___110 *, struct page___110 *, enum migrate_mode);
	bool (*isolate_page)(struct page___110 *, isolate_mode_t);
	void (*putback_page)(struct page___110 *);
	int (*launder_page)(struct page___110 *);
	int (*is_partially_uptodate)(struct page___110 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___110 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___105 *, struct page___110 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___105 *, sector_t *);
	void (*swap_deactivate)(struct file___105 *);
};

struct writeback_control___48 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___48 *wb;
	struct inode___105 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___60;

struct iov_iter___62 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___60 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___105 {
	struct dentry___105 * (*lookup)(struct inode___105 *, struct dentry___105 *, unsigned int);
	const char * (*get_link)(struct dentry___105 *, struct inode___105 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___105 *, int);
	struct posix_acl * (*get_acl)(struct inode___105 *, int, bool);
	int (*readlink)(struct dentry___105 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___105 *, struct dentry___105 *, umode_t, bool);
	int (*link)(struct dentry___105 *, struct inode___105 *, struct dentry___105 *);
	int (*unlink)(struct inode___105 *, struct dentry___105 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___105 *, struct dentry___105 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___105 *, struct dentry___105 *, umode_t);
	int (*rmdir)(struct inode___105 *, struct dentry___105 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___105 *, struct dentry___105 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___105 *, struct dentry___105 *, struct inode___105 *, struct dentry___105 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___105 *, struct iattr___105 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___105 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___105 *, char *, size_t);
	int (*fiemap)(struct inode___105 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___105 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___105 *, struct dentry___105 *, struct file___105 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___105 *, struct dentry___105 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___105 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___105 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___105 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___105 {
	void (*fl_copy_lock)(struct file_lock___105 *, struct file_lock___105 *);
	void (*fl_release_private)(struct file_lock___105 *);
};

struct fasync_struct___105;

struct lock_manager_operations___105;

struct file_lock___105 {
	struct file_lock___105 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___105 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___105 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___105 *fl_ops;
	const struct lock_manager_operations___105 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___105 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___105 *);
	int (*lm_grant)(struct file_lock___105 *, int);
	bool (*lm_break)(struct file_lock___105 *);
	int (*lm_change)(struct file_lock___105 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___105 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___105 *);
};

struct fasync_struct___105 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___105 *fa_next;
	struct file___105 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___105 {
	struct inode___105 * (*alloc_inode)(struct super_block___105 *);
	void (*destroy_inode)(struct inode___105 *);
	void (*free_inode)(struct inode___105 *);
	void (*dirty_inode)(struct inode___105 *, int);
	int (*write_inode)(struct inode___105 *, struct writeback_control___48 *);
	int (*drop_inode)(struct inode___105 *);
	void (*evict_inode)(struct inode___105 *);
	void (*put_super)(struct super_block___105 *);
	int (*sync_fs)(struct super_block___105 *, int);
	int (*freeze_super)(struct super_block___105 *);
	int (*freeze_fs)(struct super_block___105 *);
	int (*thaw_super)(struct super_block___105 *);
	int (*unfreeze_fs)(struct super_block___105 *);
	int (*statfs)(struct dentry___105 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___105 *, int *, char *);
	void (*umount_begin)(struct super_block___105 *);
	int (*show_options)(struct seq_file___97 *, struct dentry___105 *);
	int (*show_devname)(struct seq_file___97 *, struct dentry___105 *);
	int (*show_path)(struct seq_file___97 *, struct dentry___105 *);
	int (*show_stats)(struct seq_file___97 *, struct dentry___105 *);
	ssize_t (*quota_read)(struct super_block___105 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___105 *, int, const char *, size_t, loff_t);
	struct dquot___105 ** (*get_dquots)(struct inode___105 *);
	long int (*nr_cached_objects)(struct super_block___105 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___105 *, struct shrink_control___43 *);
	struct file___105 * (*real_loop)(struct file___105 *);
};

struct wakeup_source___85;

struct dev_pm_info___85 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___85 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___85 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___85;

struct bus_type___85;

struct device_driver___85;

struct dev_pm_domain___85;

struct fwnode_handle___85;

struct class___85;

struct attribute_group___101;

struct device___85 {
	struct kobject___101 kobj;
	struct device___85 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___85 *type;
	struct bus_type___85 *bus;
	struct device_driver___85 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___85 power;
	struct dev_pm_domain___85 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___85 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___85 *class;
	const struct attribute_group___101 **groups;
	void (*release)(struct device___85 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___50 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___105 *bd_inode;
	struct super_block___105 *bd_super;
	void *bd_claiming;
	struct device___85 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___101 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___49 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___105 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___75)(struct file___105 *, wait_queue_head_t *, struct poll_table_struct___75 *);

struct poll_table_struct___75 {
	poll_queue_proc___75 _qproc;
	__poll_t _key;
};

struct seq_operations___97;

struct seq_file___97 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___97 *op;
	int poll_event;
	const struct file___105 *file;
	void *private;
};

typedef void bio_end_io_t___49(struct bio___49 *);

struct bio_vec___60 {
	struct page___110 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___49;

struct bio___49 {
	struct bio___49 *bi_next;
	struct block_device___50 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___49 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___48 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___49 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___60 *bi_io_vec;
	struct bio_set___49 *bi_pool;
	struct bio_vec___60 bi_inline_vecs[0];
};

struct seq_operations___97 {
	void * (*start)(struct seq_file___97 *, loff_t *);
	void (*stop)(struct seq_file___97 *, void *);
	void * (*next)(struct seq_file___97 *, void *, loff_t *);
	int (*show)(struct seq_file___97 *, void *);
};

struct kernfs_root___101;

struct kernfs_elem_dir___101 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___101 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___101;

struct kernfs_root___101 {
	struct kernfs_node___101 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___101 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___101 {
	struct kernfs_node___101 *target_kn;
};

struct kernfs_ops___101;

struct kernfs_elem_attr___101 {
	const struct kernfs_ops___101 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___101 *notify_next;
};

struct kernfs_node___101 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___101 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___101 dir;
		struct kernfs_elem_symlink___101 symlink;
		struct kernfs_elem_attr___101 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___101;

struct kernfs_ops___101 {
	int (*open)(struct kernfs_open_file___101 *);
	void (*release)(struct kernfs_open_file___101 *);
	int (*seq_show)(struct seq_file___97 *, void *);
	void * (*seq_start)(struct seq_file___97 *, loff_t *);
	void * (*seq_next)(struct seq_file___97 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___97 *, void *);
	ssize_t (*read)(struct kernfs_open_file___101 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___101 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___101 *, struct poll_table_struct___75 *);
	int (*mmap)(struct kernfs_open_file___101 *, struct vm_area_struct___110 *);
};

struct kernfs_syscall_ops___101 {
	int (*show_options)(struct seq_file___97 *, struct kernfs_root___101 *);
	int (*mkdir)(struct kernfs_node___101 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___101 *);
	int (*rename)(struct kernfs_node___101 *, struct kernfs_node___101 *, const char *);
	int (*show_path)(struct seq_file___97 *, struct kernfs_node___101 *, struct kernfs_root___101 *);
};

struct kernfs_open_file___101 {
	struct kernfs_node___101 *kn;
	struct file___105 *file;
	struct seq_file___97 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___104 *vm_ops;
};

struct mount___9;

struct mnt_namespace___9 {
	struct ns_common___14 ns;
	struct mount___9 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___83 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___83 *root_cset;
};

struct fwnode_operations___85;

struct fwnode_handle___85 {
	struct fwnode_handle___85 *secondary;
	const struct fwnode_operations___85 *ops;
	struct device___85 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___85;

struct fwnode_endpoint___85;

struct fwnode_operations___85 {
	struct fwnode_handle___85 * (*get)(struct fwnode_handle___85 *);
	void (*put)(struct fwnode_handle___85 *);
	bool (*device_is_available)(const struct fwnode_handle___85 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___85 *, const struct device___85 *);
	bool (*property_present)(const struct fwnode_handle___85 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___85 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___85 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___85 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*get_parent)(const struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*get_next_child_node)(const struct fwnode_handle___85 *, struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*get_named_child_node)(const struct fwnode_handle___85 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___85 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___85 *);
	struct fwnode_handle___85 * (*graph_get_next_endpoint)(const struct fwnode_handle___85 *, struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*graph_get_remote_endpoint)(const struct fwnode_handle___85 *);
	struct fwnode_handle___85 * (*graph_get_port_parent)(struct fwnode_handle___85 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___85 *, struct fwnode_endpoint___85 *);
	int (*add_links)(struct fwnode_handle___85 *);
};

struct fwnode_endpoint___85 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___85 *local_fwnode;
};

struct fwnode_reference_args___85 {
	struct fwnode_handle___85 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___101;

struct attribute_group___101 {
	const char *name;
	umode_t (*is_visible)(struct kobject___101 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___101 *, struct bin_attribute___101 *, int);
	struct attribute **attrs;
	struct bin_attribute___101 **bin_attrs;
};

struct bin_attribute___101 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___105 * (*f_mapping)();
	ssize_t (*read)(struct file___105 *, struct kobject___101 *, struct bin_attribute___101 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___105 *, struct kobject___101 *, struct bin_attribute___101 *, char *, loff_t, size_t);
	int (*mmap)(struct file___105 *, struct kobject___101 *, struct bin_attribute___101 *, struct vm_area_struct___110 *);
};

struct sysfs_ops___101 {
	ssize_t (*show)(struct kobject___101 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___101 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___101;

struct kset___101 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___101 kobj;
	const struct kset_uevent_ops___101 *uevent_ops;
};

struct kobj_type___101 {
	void (*release)(struct kobject___101 *);
	const struct sysfs_ops___101 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___101 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___101 *);
	const void * (*namespace)(struct kobject___101 *);
	void (*get_ownership)(struct kobject___101 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___101 {
	int (* const filter)(struct kset___101 *, struct kobject___101 *);
	const char * (* const name)(struct kset___101 *, struct kobject___101 *);
	int (* const uevent)(struct kset___101 *, struct kobject___101 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___98 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___98 *);
	int (*get)(char *, const struct kernel_param___98 *);
	void (*free)(void *);
};

struct kparam_array___98;

struct kernel_param___98 {
	const char *name;
	struct module___99 *mod;
	const struct kernel_param_ops___98 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___98 *arr;
	};
};

struct kparam_array___98 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___98 *ops;
	void *elem;
};

struct module_attribute___98 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___98 *, struct module_kobject___98 *, char *);
	ssize_t (*store)(struct module_attribute___98 *, struct module_kobject___98 *, const char *, size_t);
	void (*setup)(struct module___99 *, const char *);
	int (*test)(struct module___99 *);
	void (*free)(struct module___99 *);
};

struct dev_pagemap_ops___104 {
	void (*page_free)(struct page___110 *);
	void (*kill)(struct dev_pagemap___104 *);
	void (*cleanup)(struct dev_pagemap___104 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___104 *);
};

struct cftype___83;

struct cgroup_subsys___83 {
	struct cgroup_subsys_state___83 * (*css_alloc)(struct cgroup_subsys_state___83 *);
	int (*css_online)(struct cgroup_subsys_state___83 *);
	void (*css_offline)(struct cgroup_subsys_state___83 *);
	void (*css_released)(struct cgroup_subsys_state___83 *);
	void (*css_free)(struct cgroup_subsys_state___83 *);
	void (*css_reset)(struct cgroup_subsys_state___83 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___83 *, int);
	int (*css_extra_stat_show)(struct seq_file___97 *, struct cgroup_subsys_state___83 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___112 *, struct css_set___83 *);
	void (*cancel_fork)(struct task_struct___112 *, struct css_set___83 *);
	void (*fork)(struct task_struct___112 *);
	void (*exit)(struct task_struct___112 *);
	void (*release)(struct task_struct___112 *);
	void (*bind)(struct cgroup_subsys_state___83 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___83 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___83 *dfl_cftypes;
	struct cftype___83 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___83 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___83 *updated_children;
	struct cgroup___83 *updated_next;
};

struct cgroup_root___83 {
	struct kernfs_root___101 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___83 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___83 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___83 *ss;
	struct list_head node;
	struct kernfs_ops___101 *kf_ops;
	int (*open)(struct kernfs_open_file___101 *);
	void (*release)(struct kernfs_open_file___101 *);
	u64 (*read_u64)(struct cgroup_subsys_state___83 *, struct cftype___83 *);
	s64 (*read_s64)(struct cgroup_subsys_state___83 *, struct cftype___83 *);
	int (*seq_show)(struct seq_file___97 *, void *);
	void * (*seq_start)(struct seq_file___97 *, loff_t *);
	void * (*seq_next)(struct seq_file___97 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___97 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___83 *, struct cftype___83 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___83 *, struct cftype___83 *, s64);
	ssize_t (*write)(struct kernfs_open_file___101 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___101 *, struct poll_table_struct___75 *);
};

struct dev_pm_ops___85 {
	int (*prepare)(struct device___85 *);
	void (*complete)(struct device___85 *);
	int (*suspend)(struct device___85 *);
	int (*resume)(struct device___85 *);
	int (*freeze)(struct device___85 *);
	int (*thaw)(struct device___85 *);
	int (*poweroff)(struct device___85 *);
	int (*restore)(struct device___85 *);
	int (*suspend_late)(struct device___85 *);
	int (*resume_early)(struct device___85 *);
	int (*freeze_late)(struct device___85 *);
	int (*thaw_early)(struct device___85 *);
	int (*poweroff_late)(struct device___85 *);
	int (*restore_early)(struct device___85 *);
	int (*suspend_noirq)(struct device___85 *);
	int (*resume_noirq)(struct device___85 *);
	int (*freeze_noirq)(struct device___85 *);
	int (*thaw_noirq)(struct device___85 *);
	int (*poweroff_noirq)(struct device___85 *);
	int (*restore_noirq)(struct device___85 *);
	int (*runtime_suspend)(struct device___85 *);
	int (*runtime_resume)(struct device___85 *);
	int (*runtime_idle)(struct device___85 *);
};

struct wakeup_source___85 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___85 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___85 {
	struct dev_pm_ops___85 ops;
	int (*start)(struct device___85 *);
	void (*detach)(struct device___85 *, bool);
	int (*activate)(struct device___85 *);
	void (*sync)(struct device___85 *);
	void (*dismiss)(struct device___85 *);
};

struct bus_type___85 {
	const char *name;
	const char *dev_name;
	struct device___85 *dev_root;
	const struct attribute_group___101 **bus_groups;
	const struct attribute_group___101 **dev_groups;
	const struct attribute_group___101 **drv_groups;
	int (*match)(struct device___85 *, struct device_driver___85 *);
	int (*uevent)(struct device___85 *, struct kobj_uevent_env *);
	int (*probe)(struct device___85 *);
	void (*sync_state)(struct device___85 *);
	void (*remove)(struct device___85 *);
	void (*shutdown)(struct device___85 *);
	int (*online)(struct device___85 *);
	int (*offline)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	int (*num_vf)(struct device___85 *);
	int (*dma_configure)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___85 {
	const char *name;
	struct bus_type___85 *bus;
	struct module___99 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___85 *);
	void (*sync_state)(struct device___85 *);
	int (*remove)(struct device___85 *);
	void (*shutdown)(struct device___85 *);
	int (*suspend)(struct device___85 *, pm_message_t);
	int (*resume)(struct device___85 *);
	const struct attribute_group___101 **groups;
	const struct attribute_group___101 **dev_groups;
	const struct dev_pm_ops___85 *pm;
	void (*coredump)(struct device___85 *);
	struct driver_private *p;
};

struct device_type___85 {
	const char *name;
	const struct attribute_group___101 **groups;
	int (*uevent)(struct device___85 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___85 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___85 *);
	const struct dev_pm_ops___85 *pm;
};

struct class___85 {
	const char *name;
	struct module___99 *owner;
	const struct attribute_group___101 **class_groups;
	const struct attribute_group___101 **dev_groups;
	struct kobject___101 *dev_kobj;
	int (*dev_uevent)(struct device___85 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___85 *, umode_t *);
	void (*class_release)(struct class___85 *);
	void (*dev_release)(struct device___85 *);
	int (*shutdown_pre)(struct device___85 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___85 *);
	void (*get_ownership)(struct device___85 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___85 *pm;
	struct subsys_private *p;
};

struct block_device_operations___49;

struct gendisk___49 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___50 *part0;
	const struct block_device_operations___49 *fops;
	struct request_queue___49 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___48 *bdi;
	struct kobject___101 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___101 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___49 {
	struct bio___49 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___60 *bip_vec;
	struct bio_vec___60 bip_inline_vecs[0];
};

struct blkcg___48;

struct blkg_policy_data___48;

struct blkcg_gq___48 {
	struct request_queue___49 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___48 *blkcg;
	struct blkcg_gq___48 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___48 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___49 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___49(struct request___49 *);

typedef void integrity_complete_fn___49(struct request___49 *, unsigned int);

struct blk_integrity_profile___49 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___49 *prepare_fn;
	integrity_complete_fn___49 *complete_fn;
	const char *name;
};

struct block_device_operations___49 {
	blk_qc_t (*submit_bio)(struct bio___49 *);
	int (*open)(struct block_device___50 *, fmode_t);
	void (*release)(struct gendisk___49 *, fmode_t);
	int (*rw_page)(struct block_device___50 *, sector_t, struct page___110 *, unsigned int);
	int (*ioctl)(struct block_device___50 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___50 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___49 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___49 *);
	int (*getgeo)(struct block_device___50 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___50 *, bool);
	void (*swap_slot_free_notify)(struct block_device___50 *, long unsigned int);
	int (*report_zones)(struct gendisk___49 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___49 *, umode_t *);
	struct module___99 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___49 *, sector_t *);
};

typedef void rq_end_io_fn___49(struct request___49 *, blk_status_t);

struct request___49 {
	struct request_queue___49 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___48 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___49 *bio;
	struct bio___49 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___60 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___49 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___49 *saved_end_io;
		} flush;
	};
	struct gendisk___49 *rq_disk;
	struct block_device___50 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___49 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___48 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___49 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___101 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___105 *debugfs_dir;
	struct dentry___105 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___49;

struct elevator_mq_ops___49 {
	int (*init_sched)(struct request_queue___49 *, struct elevator_type___49 *);
	void (*exit_sched)(struct elevator_queue___49 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___48 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___48 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___48 *);
	bool (*allow_merge)(struct request_queue___49 *, struct request___49 *, struct bio___49 *);
	bool (*bio_merge)(struct request_queue___49 *, struct bio___49 *, unsigned int);
	int (*request_merge)(struct request_queue___49 *, struct request___49 **, struct bio___49 *);
	void (*request_merged)(struct request_queue___49 *, struct request___49 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___49 *, struct request___49 *, struct request___49 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___49 *);
	void (*finish_request)(struct request___49 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___48 *, struct list_head *, bool);
	struct request___49 * (*dispatch_request)(struct blk_mq_hw_ctx___48 *);
	bool (*has_work)(struct blk_mq_hw_ctx___48 *);
	void (*completed_request)(struct request___49 *, u64);
	void (*requeue_request)(struct request___49 *);
	struct request___49 * (*former_request)(struct request_queue___49 *, struct request___49 *);
	struct request___49 * (*next_request)(struct request_queue___49 *, struct request___49 *);
	void (*init_icq)(struct io_cq___49 *);
	void (*exit_icq)(struct io_cq___49 *);
};

struct elv_fs_entry___49;

struct elevator_type___49 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___49 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___49 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___99 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___49 {
	struct elevator_type___49 *type;
	void *elevator_data;
	struct kobject___101 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___49 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___49 *, char *);
	ssize_t (*store)(struct elevator_queue___49 *, const char *, size_t);
};

struct blk_mq_queue_data___48;

struct blk_mq_ops___48 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___48 *, const struct blk_mq_queue_data___48 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___48 *);
	int (*get_budget)(struct request_queue___49 *);
	void (*put_budget)(struct request_queue___49 *, int);
	void (*set_rq_budget_token)(struct request___49 *, int);
	int (*get_rq_budget_token)(struct request___49 *);
	enum blk_eh_timer_return (*timeout)(struct request___49 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___48 *);
	void (*complete)(struct request___49 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___48 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___48 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___48 *, struct request___49 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___48 *, struct request___49 *, unsigned int);
	void (*initialize_rq_fn)(struct request___49 *);
	void (*cleanup_rq)(struct request___49 *);
	bool (*busy)(struct request_queue___49 *);
	int (*map_queues)(struct blk_mq_tag_set___48 *);
	void (*show_rq)(struct seq_file___97 *, struct request___49 *);
};

struct blk_mq_tag_set___48 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___48 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___48 {
	struct request___49 *rq;
	bool last;
};

struct blkcg_policy_data___48;

struct blkcg___48 {
	struct cgroup_subsys_state___83 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___48 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___48 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___48 {
	struct blkcg___48 *blkcg;
	int plid;
};

struct blkg_policy_data___48 {
	struct blkcg_gq___48 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___43 {
	struct mem_cgroup___43 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___43 {
	struct lruvec___49 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___43 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___43 *memcg;
};

struct obj_cgroup___43 {
	struct percpu_ref refcnt;
	struct mem_cgroup___43 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fsnotify_group___3;

struct fsnotify_iter_info___3;

struct fsnotify_mark___3;

struct fsnotify_ops___3 {
	int (*handle_event)(struct fsnotify_group___3 *, u32, const void *, int, struct inode___105 *, const struct qstr *, u32, struct fsnotify_iter_info___3 *);
	int (*handle_inode_event)(struct fsnotify_mark___3 *, u32, struct inode___105 *, struct inode___105 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___3 *);
	void (*freeing_mark)(struct fsnotify_mark___3 *, struct fsnotify_group___3 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___3 *);
};

struct fsnotify_group___3 {
	const struct fsnotify_ops___3 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___105 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___43 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___3 {
	struct fsnotify_mark___3 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___3 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___3 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct mountpoint___9;

struct mount___9 {
	struct hlist_node mnt_hash;
	struct mount___9 *mnt_parent;
	struct dentry___105 *mnt_mountpoint;
	struct vfsmount___105 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___9 *mnt_master;
	struct mnt_namespace___9 *mnt_ns;
	struct mountpoint___9 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___9 {
	struct hlist_node m_hash;
	struct dentry___105 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct dentry___106;

struct super_block___106;

struct module___100;

struct file_system_type___106 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___106 * (*mount)(struct file_system_type___106 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___106 *);
	struct module___100 *owner;
	struct file_system_type___106 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___106;

struct kiocb___106;

struct poll_table_struct___76;

struct vm_area_struct___111;

struct inode___106;

struct file_lock___106;

struct page___111;

struct seq_file___98;

struct file_operations___106 {
	struct module___100 *owner;
	loff_t (*llseek)(struct file___106 *, loff_t, int);
	ssize_t (*read)(struct file___106 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___106 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___106 *, struct iov_iter___62 *);
	ssize_t (*write_iter)(struct kiocb___106 *, struct iov_iter___62 *);
	int (*iopoll)(struct kiocb___106 *, bool);
	int (*iterate)(struct file___106 *, struct dir_context *);
	int (*iterate_shared)(struct file___106 *, struct dir_context *);
	__poll_t (*poll)(struct file___106 *, struct poll_table_struct___76 *);
	long int (*unlocked_ioctl)(struct file___106 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___106 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___106 *, struct vm_area_struct___111 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___106 *, struct file___106 *);
	int (*flush)(struct file___106 *, fl_owner_t);
	int (*release)(struct inode___106 *, struct file___106 *);
	int (*fsync)(struct file___106 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___106 *, int);
	int (*lock)(struct file___106 *, int, struct file_lock___106 *);
	ssize_t (*sendpage)(struct file___106 *, struct page___111 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___106 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___106 *, long unsigned int);
	int (*flock)(struct file___106 *, int, struct file_lock___106 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___106 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___106 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___106 *, long int, struct file_lock___106 **, void **);
	long int (*fallocate)(struct file___106 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___98 *, struct file___106 *);
	ssize_t (*copy_file_range)(struct file___106 *, loff_t, struct file___106 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___106 *, loff_t, struct file___106 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___106 *, loff_t, loff_t, int);
};

struct vmacache___111 {
	u64 seqnum;
	struct vm_area_struct___111 *vmas[4];
};

struct page_frag___111 {
	struct page___111 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___112;

struct pid___95;

struct nsproxy___101;

struct signal_struct___107;

struct task_struct___113 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___113 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___112 *mm;
	struct mm_struct___112 *active_mm;
	struct vmacache___111 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___113 *real_parent;
	struct task_struct___113 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___113 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___95 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___101 *nsproxy;
	struct signal_struct___107 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___113 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___111 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___113 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___102;

struct kobj_type___102;

struct kernfs_node___102;

struct kobject___102 {
	const char *name;
	struct list_head entry;
	struct kobject___102 *parent;
	struct kset___102 *kset;
	struct kobj_type___102 *ktype;
	struct kernfs_node___102 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___99 {
	struct kobject___102 kobj;
	struct module___100 *mod;
	struct kobject___102 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___99 {
	struct module___100 *mod;
	struct latch_tree_node node;
};

struct module_layout___99 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___99 mtn;
};

struct module_attribute___99;

struct kernel_param___99;

struct module___100 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___99 mkobj;
	struct module_attribute___99 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___102 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___99 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___99 core_layout;
	struct module_layout___99 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___106;

struct dentry___106 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___106 *d_parent;
	struct qstr d_name;
	struct inode___106 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___106 *d_op;
	struct super_block___106 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___106;

struct address_space___106 {
	struct inode___106 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___106 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___106;

struct inode___106 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___106 *i_op;
	struct super_block___106 *i_sb;
	struct address_space___106 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___106 *i_fop;
		void (*free_inode)(struct inode___106 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___106 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___106;

struct path___106;

struct dentry_operations___106 {
	int (*d_revalidate)(struct dentry___106 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___106 *, unsigned int);
	int (*d_hash)(const struct dentry___106 *, struct qstr *);
	int (*d_compare)(const struct dentry___106 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___106 *);
	int (*d_init)(struct dentry___106 *);
	void (*d_release)(struct dentry___106 *);
	void (*d_prune)(struct dentry___106 *);
	void (*d_iput)(struct dentry___106 *, struct inode___106 *);
	char * (*d_dname)(struct dentry___106 *, char *, int);
	struct vfsmount___106 * (*d_automount)(struct path___106 *);
	int (*d_manage)(const struct path___106 *, bool);
	struct dentry___106 * (*d_real)(struct dentry___106 *, const struct inode___106 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___106;

struct mem_dqinfo___106 {
	struct quota_format_type___106 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___106;

struct quota_info___106 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___106 *files[3];
	struct mem_dqinfo___106 info[3];
	const struct quota_format_ops___106 *ops[3];
};

struct rcuwait___107 {
	struct task_struct___113 *task;
};

struct percpu_rw_semaphore___107 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___107 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___106 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___107 rw_sem[3];
};

struct super_operations___106;

struct dquot_operations___106;

struct quotactl_ops___106;

struct super_block___106 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___106 *s_type;
	const struct super_operations___106 *s_op;
	const struct dquot_operations___106 *dq_op;
	const struct quotactl_ops___106 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___106 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___106 s_dquot;
	struct sb_writers___106 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___106 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___106 {
	struct dentry___106 *mnt_root;
	struct super_block___106 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___106 {
	struct vfsmount___106 *mnt;
	struct dentry___106 *dentry;
};

struct pid_namespace___95;

struct upid___95 {
	int nr;
	struct pid_namespace___95 *ns;
};

struct pid_namespace___95 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___113 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___95 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___95 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___95 numbers[1];
};

typedef struct page___111 *pgtable_t___111;

struct dev_pagemap___105;

struct page___111 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___106 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___111 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___111 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___112 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___105 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___105;

struct vm_area_struct___111 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___111 *vm_next;
	struct vm_area_struct___111 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___112 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___105 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___106 *vm_file;
	struct file___106 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___107 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___113 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___113 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___95 *pids[4];
	struct pid___95 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___112 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___111;

struct mm_struct___112 {
	struct {
		struct vm_area_struct___111 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___106 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___111 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___113 *owner;
		struct user_namespace___14 *user_ns;
		struct file___106 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct mnt_namespace___10;

struct nsproxy___101 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___10 *mnt_ns;
	struct pid_namespace___95 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct dev_pagemap_ops___105;

struct dev_pagemap___105 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___105 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___95 {
	rwlock_t lock;
	struct pid___95 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___106 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___106 f_path;
	struct inode___106 *f_inode;
	const struct file_operations___106 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___95 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___106 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___105;

struct vm_operations_struct___105 {
	void (*open)(struct vm_area_struct___111 *);
	void (*close)(struct vm_area_struct___111 *);
	int (*may_split)(struct vm_area_struct___111 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___111 *);
	int (*mprotect)(struct vm_area_struct___111 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___105 *);
	vm_fault_t (*huge_fault)(struct vm_fault___105 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___105 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___111 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___105 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___105 *);
	int (*access)(struct vm_area_struct___111 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___111 *);
	int (*set_policy)(struct vm_area_struct___111 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___111 *, long unsigned int);
	struct page___111 * (*find_special_page)(struct vm_area_struct___111 *, long unsigned int);
};

struct core_thread___111 {
	struct task_struct___113 *task;
	struct core_thread___111 *next;
};

struct core_state___111 {
	atomic_t nr_threads;
	struct core_thread___111 dumper;
	struct completion startup;
};

struct vm_fault___105 {
	const struct {
		struct vm_area_struct___111 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___111 *cow_page;
	struct page___111 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___111 prealloc_pte;
};

struct kiocb___106 {
	struct file___106 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___106 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___106 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___106 *ia_file;
};

struct dquot___106 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___106 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___106 {
	int qf_fmt_id;
	const struct quota_format_ops___106 *qf_ops;
	struct module___100 *qf_owner;
	struct quota_format_type___106 *qf_next;
};

struct quota_format_ops___106 {
	int (*check_quota_file)(struct super_block___106 *, int);
	int (*read_file_info)(struct super_block___106 *, int);
	int (*write_file_info)(struct super_block___106 *, int);
	int (*free_file_info)(struct super_block___106 *, int);
	int (*read_dqblk)(struct dquot___106 *);
	int (*commit_dqblk)(struct dquot___106 *);
	int (*release_dqblk)(struct dquot___106 *);
	int (*get_next_id)(struct super_block___106 *, struct kqid *);
};

struct dquot_operations___106 {
	int (*write_dquot)(struct dquot___106 *);
	struct dquot___106 * (*alloc_dquot)(struct super_block___106 *, int);
	void (*destroy_dquot)(struct dquot___106 *);
	int (*acquire_dquot)(struct dquot___106 *);
	int (*release_dquot)(struct dquot___106 *);
	int (*mark_dirty)(struct dquot___106 *);
	int (*write_info)(struct super_block___106 *, int);
	qsize_t * (*get_reserved_space)(struct inode___106 *);
	int (*get_projid)(struct inode___106 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___106 *, qsize_t *);
	int (*get_next_id)(struct super_block___106 *, struct kqid *);
};

struct quotactl_ops___106 {
	int (*quota_on)(struct super_block___106 *, int, int, const struct path___106 *);
	int (*quota_off)(struct super_block___106 *, int);
	int (*quota_enable)(struct super_block___106 *, unsigned int);
	int (*quota_disable)(struct super_block___106 *, unsigned int);
	int (*quota_sync)(struct super_block___106 *, int);
	int (*set_info)(struct super_block___106 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___106 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___106 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___106 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___106 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___106 *, unsigned int);
};

struct address_space_operations___106 {
	int (*writepage)(struct page___111 *, struct writeback_control___3 *);
	int (*readpage)(struct file___106 *, struct page___111 *);
	int (*writepages)(struct address_space___106 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___111 *);
	int (*readpages)(struct file___106 *, struct address_space___106 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___106 *, struct address_space___106 *, loff_t, unsigned int, unsigned int, struct page___111 **, void **);
	int (*write_end)(struct file___106 *, struct address_space___106 *, loff_t, unsigned int, unsigned int, struct page___111 *, void *);
	sector_t (*bmap)(struct address_space___106 *, sector_t);
	void (*invalidatepage)(struct page___111 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___111 *, gfp_t);
	void (*freepage)(struct page___111 *);
	ssize_t (*direct_IO)(struct kiocb___106 *, struct iov_iter___62 *);
	int (*migratepage)(struct address_space___106 *, struct page___111 *, struct page___111 *, enum migrate_mode);
	bool (*isolate_page)(struct page___111 *, isolate_mode_t);
	void (*putback_page)(struct page___111 *);
	int (*launder_page)(struct page___111 *);
	int (*is_partially_uptodate)(struct page___111 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___111 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___106 *, struct page___111 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___106 *, sector_t *);
	void (*swap_deactivate)(struct file___106 *);
};

struct inode_operations___106 {
	struct dentry___106 * (*lookup)(struct inode___106 *, struct dentry___106 *, unsigned int);
	const char * (*get_link)(struct dentry___106 *, struct inode___106 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___106 *, int);
	struct posix_acl * (*get_acl)(struct inode___106 *, int, bool);
	int (*readlink)(struct dentry___106 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___106 *, struct dentry___106 *, umode_t, bool);
	int (*link)(struct dentry___106 *, struct inode___106 *, struct dentry___106 *);
	int (*unlink)(struct inode___106 *, struct dentry___106 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___106 *, struct dentry___106 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___106 *, struct dentry___106 *, umode_t);
	int (*rmdir)(struct inode___106 *, struct dentry___106 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___106 *, struct dentry___106 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___106 *, struct dentry___106 *, struct inode___106 *, struct dentry___106 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___106 *, struct iattr___106 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___106 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___106 *, char *, size_t);
	int (*fiemap)(struct inode___106 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___106 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___106 *, struct dentry___106 *, struct file___106 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___106 *, struct dentry___106 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___106 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___106 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___106 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___106 {
	void (*fl_copy_lock)(struct file_lock___106 *, struct file_lock___106 *);
	void (*fl_release_private)(struct file_lock___106 *);
};

struct fasync_struct___106;

struct lock_manager_operations___106;

struct file_lock___106 {
	struct file_lock___106 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___106 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___106 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___106 *fl_ops;
	const struct lock_manager_operations___106 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___106 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___106 *);
	int (*lm_grant)(struct file_lock___106 *, int);
	bool (*lm_break)(struct file_lock___106 *);
	int (*lm_change)(struct file_lock___106 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___106 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___106 *);
};

struct fasync_struct___106 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___106 *fa_next;
	struct file___106 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___106 {
	struct inode___106 * (*alloc_inode)(struct super_block___106 *);
	void (*destroy_inode)(struct inode___106 *);
	void (*free_inode)(struct inode___106 *);
	void (*dirty_inode)(struct inode___106 *, int);
	int (*write_inode)(struct inode___106 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___106 *);
	void (*evict_inode)(struct inode___106 *);
	void (*put_super)(struct super_block___106 *);
	int (*sync_fs)(struct super_block___106 *, int);
	int (*freeze_super)(struct super_block___106 *);
	int (*freeze_fs)(struct super_block___106 *);
	int (*thaw_super)(struct super_block___106 *);
	int (*unfreeze_fs)(struct super_block___106 *);
	int (*statfs)(struct dentry___106 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___106 *, int *, char *);
	void (*umount_begin)(struct super_block___106 *);
	int (*show_options)(struct seq_file___98 *, struct dentry___106 *);
	int (*show_devname)(struct seq_file___98 *, struct dentry___106 *);
	int (*show_path)(struct seq_file___98 *, struct dentry___106 *);
	int (*show_stats)(struct seq_file___98 *, struct dentry___106 *);
	ssize_t (*quota_read)(struct super_block___106 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___106 *, int, const char *, size_t, loff_t);
	struct dquot___106 ** (*get_dquots)(struct inode___106 *);
	long int (*nr_cached_objects)(struct super_block___106 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___106 *, struct shrink_control___43 *);
	struct file___106 * (*real_loop)(struct file___106 *);
};

typedef void (*poll_queue_proc___76)(struct file___106 *, wait_queue_head_t *, struct poll_table_struct___76 *);

struct poll_table_struct___76 {
	poll_queue_proc___76 _qproc;
	__poll_t _key;
};

struct seq_operations___98;

struct seq_file___98 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___98 *op;
	int poll_event;
	const struct file___106 *file;
	void *private;
};

struct kernfs_root___102;

struct kernfs_elem_dir___102 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___102 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___102;

struct kernfs_root___102 {
	struct kernfs_node___102 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___102 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___102 {
	struct kernfs_node___102 *target_kn;
};

struct kernfs_ops___102;

struct kernfs_elem_attr___102 {
	const struct kernfs_ops___102 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___102 *notify_next;
};

struct kernfs_node___102 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___102 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___102 dir;
		struct kernfs_elem_symlink___102 symlink;
		struct kernfs_elem_attr___102 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___102;

struct kernfs_ops___102 {
	int (*open)(struct kernfs_open_file___102 *);
	void (*release)(struct kernfs_open_file___102 *);
	int (*seq_show)(struct seq_file___98 *, void *);
	void * (*seq_start)(struct seq_file___98 *, loff_t *);
	void * (*seq_next)(struct seq_file___98 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___98 *, void *);
	ssize_t (*read)(struct kernfs_open_file___102 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___102 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___102 *, struct poll_table_struct___76 *);
	int (*mmap)(struct kernfs_open_file___102 *, struct vm_area_struct___111 *);
};

struct kernfs_syscall_ops___102 {
	int (*show_options)(struct seq_file___98 *, struct kernfs_root___102 *);
	int (*mkdir)(struct kernfs_node___102 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___102 *);
	int (*rename)(struct kernfs_node___102 *, struct kernfs_node___102 *, const char *);
	int (*show_path)(struct seq_file___98 *, struct kernfs_node___102 *, struct kernfs_root___102 *);
};

struct kernfs_open_file___102 {
	struct kernfs_node___102 *kn;
	struct file___106 *file;
	struct seq_file___98 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___105 *vm_ops;
};

struct bin_attribute___102;

struct attribute_group___102 {
	const char *name;
	umode_t (*is_visible)(struct kobject___102 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___102 *, struct bin_attribute___102 *, int);
	struct attribute **attrs;
	struct bin_attribute___102 **bin_attrs;
};

struct bin_attribute___102 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___106 * (*f_mapping)();
	ssize_t (*read)(struct file___106 *, struct kobject___102 *, struct bin_attribute___102 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___106 *, struct kobject___102 *, struct bin_attribute___102 *, char *, loff_t, size_t);
	int (*mmap)(struct file___106 *, struct kobject___102 *, struct bin_attribute___102 *, struct vm_area_struct___111 *);
};

struct sysfs_ops___102 {
	ssize_t (*show)(struct kobject___102 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___102 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___102;

struct kset___102 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___102 kobj;
	const struct kset_uevent_ops___102 *uevent_ops;
};

struct kobj_type___102 {
	void (*release)(struct kobject___102 *);
	const struct sysfs_ops___102 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___102 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___102 *);
	const void * (*namespace)(struct kobject___102 *);
	void (*get_ownership)(struct kobject___102 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___102 {
	int (* const filter)(struct kset___102 *, struct kobject___102 *);
	const char * (* const name)(struct kset___102 *, struct kobject___102 *);
	int (* const uevent)(struct kset___102 *, struct kobject___102 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___99 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___99 *);
	int (*get)(char *, const struct kernel_param___99 *);
	void (*free)(void *);
};

struct kparam_array___99;

struct kernel_param___99 {
	const char *name;
	struct module___100 *mod;
	const struct kernel_param_ops___99 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___99 *arr;
	};
};

struct kparam_array___99 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___99 *ops;
	void *elem;
};

struct module_attribute___99 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___99 *, struct module_kobject___99 *, char *);
	ssize_t (*store)(struct module_attribute___99 *, struct module_kobject___99 *, const char *, size_t);
	void (*setup)(struct module___100 *, const char *);
	int (*test)(struct module___100 *);
	void (*free)(struct module___100 *);
};

struct mount___10;

struct mnt_namespace___10 {
	struct ns_common___14 ns;
	struct mount___10 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct seq_operations___98 {
	void * (*start)(struct seq_file___98 *, loff_t *);
	void (*stop)(struct seq_file___98 *, void *);
	void * (*next)(struct seq_file___98 *, void *, loff_t *);
	int (*show)(struct seq_file___98 *, void *);
};

struct fsnotify_group___4;

struct fsnotify_iter_info___4;

struct fsnotify_mark___4;

struct fsnotify_ops___4 {
	int (*handle_event)(struct fsnotify_group___4 *, u32, const void *, int, struct inode___106 *, const struct qstr *, u32, struct fsnotify_iter_info___4 *);
	int (*handle_inode_event)(struct fsnotify_mark___4 *, u32, struct inode___106 *, struct inode___106 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___4 *);
	void (*freeing_mark)(struct fsnotify_mark___4 *, struct fsnotify_group___4 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___4 *);
};

struct fsnotify_group___4 {
	const struct fsnotify_ops___4 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___106 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___4 {
	struct fsnotify_mark___4 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___4 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___4 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct dev_pagemap_ops___105 {
	void (*page_free)(struct page___111 *);
	void (*kill)(struct dev_pagemap___105 *);
	void (*cleanup)(struct dev_pagemap___105 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___105 *);
};

struct mountpoint___10;

struct mount___10 {
	struct hlist_node mnt_hash;
	struct mount___10 *mnt_parent;
	struct dentry___106 *mnt_mountpoint;
	struct vfsmount___106 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___10 *mnt_master;
	struct mnt_namespace___10 *mnt_ns;
	struct mountpoint___10 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___10 {
	struct hlist_node m_hash;
	struct dentry___106 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct vfsmount___107;

struct dentry___107;

struct path___107 {
	struct vfsmount___107 *mnt;
	struct dentry___107 *dentry;
};

struct pid___96;

struct fown_struct___96 {
	rwlock_t lock;
	struct pid___96 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___107;

struct file_operations___107;

struct address_space___107;

struct file___107 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___107 f_path;
	struct inode___107 *f_inode;
	const struct file_operations___107 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___96 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___107 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct super_block___107;

struct file_system_type___107 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___107 * (*mount)(struct file_system_type___107 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___107 *);
	struct module___8 *owner;
	struct file_system_type___107 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___107;

struct poll_table_struct___77;

struct vm_area_struct___112;

struct file_lock___107;

struct page___112;

struct seq_file___99;

struct file_operations___107 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___107 *, loff_t, int);
	ssize_t (*read)(struct file___107 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___107 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___107 *, struct iov_iter___62 *);
	ssize_t (*write_iter)(struct kiocb___107 *, struct iov_iter___62 *);
	int (*iopoll)(struct kiocb___107 *, bool);
	int (*iterate)(struct file___107 *, struct dir_context *);
	int (*iterate_shared)(struct file___107 *, struct dir_context *);
	__poll_t (*poll)(struct file___107 *, struct poll_table_struct___77 *);
	long int (*unlocked_ioctl)(struct file___107 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___107 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___107 *, struct vm_area_struct___112 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___107 *, struct file___107 *);
	int (*flush)(struct file___107 *, fl_owner_t);
	int (*release)(struct inode___107 *, struct file___107 *);
	int (*fsync)(struct file___107 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___107 *, int);
	int (*lock)(struct file___107 *, int, struct file_lock___107 *);
	ssize_t (*sendpage)(struct file___107 *, struct page___112 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___107 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___107 *, long unsigned int);
	int (*flock)(struct file___107 *, int, struct file_lock___107 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___107 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___107 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___107 *, long int, struct file_lock___107 **, void **);
	long int (*fallocate)(struct file___107 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___99 *, struct file___107 *);
	ssize_t (*copy_file_range)(struct file___107 *, loff_t, struct file___107 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___107 *, loff_t, struct file___107 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___107 *, loff_t, loff_t, int);
};

struct vmacache___112 {
	u64 seqnum;
	struct vm_area_struct___112 *vmas[4];
};

struct page_frag___112 {
	struct page___112 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___113;

struct nsproxy___102;

struct signal_struct___108;

struct task_struct___114 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___114 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___113 *mm;
	struct mm_struct___113 *active_mm;
	struct vmacache___112 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___114 *real_parent;
	struct task_struct___114 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___114 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___96 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___102 *nsproxy;
	struct signal_struct___108 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___114 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___112 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___114 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___107;

struct dentry___107 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___107 *d_parent;
	struct qstr d_name;
	struct inode___107 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___107 *d_op;
	struct super_block___107 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___107;

struct address_space___107 {
	struct inode___107 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___107 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___107;

struct inode___107 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___107 *i_op;
	struct super_block___107 *i_sb;
	struct address_space___107 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___107 *i_fop;
		void (*free_inode)(struct inode___107 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___107 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___107 {
	int (*d_revalidate)(struct dentry___107 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___107 *, unsigned int);
	int (*d_hash)(const struct dentry___107 *, struct qstr *);
	int (*d_compare)(const struct dentry___107 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___107 *);
	int (*d_init)(struct dentry___107 *);
	void (*d_release)(struct dentry___107 *);
	void (*d_prune)(struct dentry___107 *);
	void (*d_iput)(struct dentry___107 *, struct inode___107 *);
	char * (*d_dname)(struct dentry___107 *, char *, int);
	struct vfsmount___107 * (*d_automount)(struct path___107 *);
	int (*d_manage)(const struct path___107 *, bool);
	struct dentry___107 * (*d_real)(struct dentry___107 *, const struct inode___107 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___107;

struct mem_dqinfo___107 {
	struct quota_format_type___107 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___107;

struct quota_info___107 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___107 *files[3];
	struct mem_dqinfo___107 info[3];
	const struct quota_format_ops___107 *ops[3];
};

struct rcuwait___108 {
	struct task_struct___114 *task;
};

struct percpu_rw_semaphore___108 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___108 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___107 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___108 rw_sem[3];
};

struct super_operations___107;

struct dquot_operations___107;

struct quotactl_ops___107;

struct export_operations___6;

struct super_block___107 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___107 *s_type;
	const struct super_operations___107 *s_op;
	const struct dquot_operations___107 *dq_op;
	const struct quotactl_ops___107 *s_qcop;
	const struct export_operations___6 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___107 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___107 s_dquot;
	struct sb_writers___107 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___107 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___107 {
	struct dentry___107 *mnt_root;
	struct super_block___107 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct pid_namespace___96;

struct upid___96 {
	int nr;
	struct pid_namespace___96 *ns;
};

struct pid_namespace___96 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___114 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___96 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___96 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___96 numbers[1];
};

typedef struct page___112 *pgtable_t___112;

struct dev_pagemap___106;

struct page___112 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___107 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___112 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___112 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___113 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___106 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___106;

struct vm_area_struct___112 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___112 *vm_next;
	struct vm_area_struct___112 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___113 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___106 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___107 *vm_file;
	struct file___107 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___108 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___114 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___114 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___96 *pids[4];
	struct pid___96 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___113 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___112;

struct mm_struct___113 {
	struct {
		struct vm_area_struct___112 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___107 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___112 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___114 *owner;
		struct user_namespace___14 *user_ns;
		struct file___107 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct mnt_namespace___11;

struct nsproxy___102 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___11 *mnt_ns;
	struct pid_namespace___96 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct dev_pagemap_ops___106;

struct dev_pagemap___106 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___106 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___106;

struct vm_operations_struct___106 {
	void (*open)(struct vm_area_struct___112 *);
	void (*close)(struct vm_area_struct___112 *);
	int (*may_split)(struct vm_area_struct___112 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___112 *);
	int (*mprotect)(struct vm_area_struct___112 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___106 *);
	vm_fault_t (*huge_fault)(struct vm_fault___106 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___106 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___112 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___106 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___106 *);
	int (*access)(struct vm_area_struct___112 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___112 *);
	int (*set_policy)(struct vm_area_struct___112 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___112 *, long unsigned int);
	struct page___112 * (*find_special_page)(struct vm_area_struct___112 *, long unsigned int);
};

struct core_thread___112 {
	struct task_struct___114 *task;
	struct core_thread___112 *next;
};

struct core_state___112 {
	atomic_t nr_threads;
	struct core_thread___112 dumper;
	struct completion startup;
};

struct vm_fault___106 {
	const struct {
		struct vm_area_struct___112 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___112 *cow_page;
	struct page___112 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___112 prealloc_pte;
};

struct kiocb___107 {
	struct file___107 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___107 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___107 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___107 *ia_file;
};

struct dquot___107 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___107 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___107 {
	int qf_fmt_id;
	const struct quota_format_ops___107 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___107 *qf_next;
};

struct quota_format_ops___107 {
	int (*check_quota_file)(struct super_block___107 *, int);
	int (*read_file_info)(struct super_block___107 *, int);
	int (*write_file_info)(struct super_block___107 *, int);
	int (*free_file_info)(struct super_block___107 *, int);
	int (*read_dqblk)(struct dquot___107 *);
	int (*commit_dqblk)(struct dquot___107 *);
	int (*release_dqblk)(struct dquot___107 *);
	int (*get_next_id)(struct super_block___107 *, struct kqid *);
};

struct dquot_operations___107 {
	int (*write_dquot)(struct dquot___107 *);
	struct dquot___107 * (*alloc_dquot)(struct super_block___107 *, int);
	void (*destroy_dquot)(struct dquot___107 *);
	int (*acquire_dquot)(struct dquot___107 *);
	int (*release_dquot)(struct dquot___107 *);
	int (*mark_dirty)(struct dquot___107 *);
	int (*write_info)(struct super_block___107 *, int);
	qsize_t * (*get_reserved_space)(struct inode___107 *);
	int (*get_projid)(struct inode___107 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___107 *, qsize_t *);
	int (*get_next_id)(struct super_block___107 *, struct kqid *);
};

struct quotactl_ops___107 {
	int (*quota_on)(struct super_block___107 *, int, int, const struct path___107 *);
	int (*quota_off)(struct super_block___107 *, int);
	int (*quota_enable)(struct super_block___107 *, unsigned int);
	int (*quota_disable)(struct super_block___107 *, unsigned int);
	int (*quota_sync)(struct super_block___107 *, int);
	int (*set_info)(struct super_block___107 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___107 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___107 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___107 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___107 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___107 *, unsigned int);
};

struct address_space_operations___107 {
	int (*writepage)(struct page___112 *, struct writeback_control___3 *);
	int (*readpage)(struct file___107 *, struct page___112 *);
	int (*writepages)(struct address_space___107 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___112 *);
	int (*readpages)(struct file___107 *, struct address_space___107 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___107 *, struct address_space___107 *, loff_t, unsigned int, unsigned int, struct page___112 **, void **);
	int (*write_end)(struct file___107 *, struct address_space___107 *, loff_t, unsigned int, unsigned int, struct page___112 *, void *);
	sector_t (*bmap)(struct address_space___107 *, sector_t);
	void (*invalidatepage)(struct page___112 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___112 *, gfp_t);
	void (*freepage)(struct page___112 *);
	ssize_t (*direct_IO)(struct kiocb___107 *, struct iov_iter___62 *);
	int (*migratepage)(struct address_space___107 *, struct page___112 *, struct page___112 *, enum migrate_mode);
	bool (*isolate_page)(struct page___112 *, isolate_mode_t);
	void (*putback_page)(struct page___112 *);
	int (*launder_page)(struct page___112 *);
	int (*is_partially_uptodate)(struct page___112 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___112 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___107 *, struct page___112 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___107 *, sector_t *);
	void (*swap_deactivate)(struct file___107 *);
};

struct inode_operations___107 {
	struct dentry___107 * (*lookup)(struct inode___107 *, struct dentry___107 *, unsigned int);
	const char * (*get_link)(struct dentry___107 *, struct inode___107 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___107 *, int);
	struct posix_acl * (*get_acl)(struct inode___107 *, int, bool);
	int (*readlink)(struct dentry___107 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___107 *, struct dentry___107 *, umode_t, bool);
	int (*link)(struct dentry___107 *, struct inode___107 *, struct dentry___107 *);
	int (*unlink)(struct inode___107 *, struct dentry___107 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___107 *, struct dentry___107 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___107 *, struct dentry___107 *, umode_t);
	int (*rmdir)(struct inode___107 *, struct dentry___107 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___107 *, struct dentry___107 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___107 *, struct dentry___107 *, struct inode___107 *, struct dentry___107 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___107 *, struct iattr___107 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___107 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___107 *, char *, size_t);
	int (*fiemap)(struct inode___107 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___107 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___107 *, struct dentry___107 *, struct file___107 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___107 *, struct dentry___107 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___107 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___107 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___107 *, struct fileattr *);
	long: 64;
};

struct file_handle {
	__u32 handle_bytes;
	int handle_type;
	unsigned char f_handle[0];
};

struct file_lock_operations___107 {
	void (*fl_copy_lock)(struct file_lock___107 *, struct file_lock___107 *);
	void (*fl_release_private)(struct file_lock___107 *);
};

struct fasync_struct___107;

struct lock_manager_operations___107;

struct file_lock___107 {
	struct file_lock___107 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___107 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___107 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___107 *fl_ops;
	const struct lock_manager_operations___107 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___107 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___107 *);
	int (*lm_grant)(struct file_lock___107 *, int);
	bool (*lm_break)(struct file_lock___107 *);
	int (*lm_change)(struct file_lock___107 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___107 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___107 *);
};

struct fasync_struct___107 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___107 *fa_next;
	struct file___107 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___107 {
	struct inode___107 * (*alloc_inode)(struct super_block___107 *);
	void (*destroy_inode)(struct inode___107 *);
	void (*free_inode)(struct inode___107 *);
	void (*dirty_inode)(struct inode___107 *, int);
	int (*write_inode)(struct inode___107 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___107 *);
	void (*evict_inode)(struct inode___107 *);
	void (*put_super)(struct super_block___107 *);
	int (*sync_fs)(struct super_block___107 *, int);
	int (*freeze_super)(struct super_block___107 *);
	int (*freeze_fs)(struct super_block___107 *);
	int (*thaw_super)(struct super_block___107 *);
	int (*unfreeze_fs)(struct super_block___107 *);
	int (*statfs)(struct dentry___107 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___107 *, int *, char *);
	void (*umount_begin)(struct super_block___107 *);
	int (*show_options)(struct seq_file___99 *, struct dentry___107 *);
	int (*show_devname)(struct seq_file___99 *, struct dentry___107 *);
	int (*show_path)(struct seq_file___99 *, struct dentry___107 *);
	int (*show_stats)(struct seq_file___99 *, struct dentry___107 *);
	ssize_t (*quota_read)(struct super_block___107 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___107 *, int, const char *, size_t, loff_t);
	struct dquot___107 ** (*get_dquots)(struct inode___107 *);
	long int (*nr_cached_objects)(struct super_block___107 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___107 *, struct shrink_control___43 *);
	struct file___107 * (*real_loop)(struct file___107 *);
};

struct export_operations___6 {
	int (*encode_fh)(struct inode___107 *, __u32 *, int *, struct inode___107 *);
	struct dentry___107 * (*fh_to_dentry)(struct super_block___107 *, struct fid *, int, int);
	struct dentry___107 * (*fh_to_parent)(struct super_block___107 *, struct fid *, int, int);
	int (*get_name)(struct dentry___107 *, char *, struct dentry___107 *);
	struct dentry___107 * (*get_parent)(struct dentry___107 *);
	int (*commit_metadata)(struct inode___107 *);
	int (*get_uuid)(struct super_block___107 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___107 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___107 *, struct iomap *, int, struct iattr___107 *);
	u64 (*fetch_iversion)(struct inode___107 *);
	long unsigned int flags;
};

typedef void (*poll_queue_proc___77)(struct file___107 *, wait_queue_head_t *, struct poll_table_struct___77 *);

struct poll_table_struct___77 {
	poll_queue_proc___77 _qproc;
	__poll_t _key;
};

struct seq_operations___99;

struct seq_file___99 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___99 *op;
	int poll_event;
	const struct file___107 *file;
	void *private;
};

struct mount___11;

struct mnt_namespace___11 {
	struct ns_common___14 ns;
	struct mount___11 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct seq_operations___99 {
	void * (*start)(struct seq_file___99 *, loff_t *);
	void (*stop)(struct seq_file___99 *, void *);
	void * (*next)(struct seq_file___99 *, void *, loff_t *);
	int (*show)(struct seq_file___99 *, void *);
};

struct fsnotify_group___5;

struct fsnotify_iter_info___5;

struct fsnotify_mark___5;

struct fsnotify_ops___5 {
	int (*handle_event)(struct fsnotify_group___5 *, u32, const void *, int, struct inode___107 *, const struct qstr *, u32, struct fsnotify_iter_info___5 *);
	int (*handle_inode_event)(struct fsnotify_mark___5 *, u32, struct inode___107 *, struct inode___107 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___5 *);
	void (*freeing_mark)(struct fsnotify_mark___5 *, struct fsnotify_group___5 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___5 *);
};

struct fsnotify_group___5 {
	const struct fsnotify_ops___5 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___107 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___5 {
	struct fsnotify_mark___5 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___5 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___5 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct inotify_inode_mark {
	struct fsnotify_mark___5 fsn_mark;
	int wd;
};

struct dev_pagemap_ops___106 {
	void (*page_free)(struct page___112 *);
	void (*kill)(struct dev_pagemap___106 *);
	void (*cleanup)(struct dev_pagemap___106 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___106 *);
};

struct mountpoint___11;

struct mount___11 {
	struct hlist_node mnt_hash;
	struct mount___11 *mnt_parent;
	struct dentry___107 *mnt_mountpoint;
	struct vfsmount___107 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___11 *mnt_master;
	struct mnt_namespace___11 *mnt_ns;
	struct mountpoint___11 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___11 {
	struct hlist_node m_hash;
	struct dentry___107 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct dentry___108;

struct super_block___108;

struct module___101;

struct file_system_type___108 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___108 * (*mount)(struct file_system_type___108 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___108 *);
	struct module___101 *owner;
	struct file_system_type___108 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___108;

struct kiocb___108;

struct vm_area_struct___113;

struct inode___108;

struct file_lock___108;

struct page___113;

struct file_operations___108 {
	struct module___101 *owner;
	loff_t (*llseek)(struct file___108 *, loff_t, int);
	ssize_t (*read)(struct file___108 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___108 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___108 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___108 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___108 *, bool);
	int (*iterate)(struct file___108 *, struct dir_context *);
	int (*iterate_shared)(struct file___108 *, struct dir_context *);
	__poll_t (*poll)(struct file___108 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___108 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___108 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___108 *, struct vm_area_struct___113 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___108 *, struct file___108 *);
	int (*flush)(struct file___108 *, fl_owner_t);
	int (*release)(struct inode___108 *, struct file___108 *);
	int (*fsync)(struct file___108 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___108 *, int);
	int (*lock)(struct file___108 *, int, struct file_lock___108 *);
	ssize_t (*sendpage)(struct file___108 *, struct page___113 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___108 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___108 *, long unsigned int);
	int (*flock)(struct file___108 *, int, struct file_lock___108 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___108 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___108 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___108 *, long int, struct file_lock___108 **, void **);
	long int (*fallocate)(struct file___108 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___108 *);
	ssize_t (*copy_file_range)(struct file___108 *, loff_t, struct file___108 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___108 *, loff_t, struct file___108 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___108 *, loff_t, loff_t, int);
};

struct vmacache___113 {
	u64 seqnum;
	struct vm_area_struct___113 *vmas[4];
};

struct page_frag___113 {
	struct page___113 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___114;

struct files_struct___11;

struct signal_struct___109;

struct task_struct___115 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___115 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___114 *mm;
	struct mm_struct___114 *active_mm;
	struct vmacache___113 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___115 *real_parent;
	struct task_struct___115 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___115 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___96 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___11 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___102 *nsproxy;
	struct signal_struct___109 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___115 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___113 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___115 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___103;

struct kobj_type___103;

struct kernfs_node___103;

struct kobject___103 {
	const char *name;
	struct list_head entry;
	struct kobject___103 *parent;
	struct kset___103 *kset;
	struct kobj_type___103 *ktype;
	struct kernfs_node___103 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___100 {
	struct kobject___103 kobj;
	struct module___101 *mod;
	struct kobject___103 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___100 {
	struct module___101 *mod;
	struct latch_tree_node node;
};

struct module_layout___100 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___100 mtn;
};

struct module_attribute___100;

struct kernel_param___100;

struct module___101 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___100 mkobj;
	struct module_attribute___100 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___103 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___100 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___100 core_layout;
	struct module_layout___100 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___108;

struct dentry___108 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___108 *d_parent;
	struct qstr d_name;
	struct inode___108 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___108 *d_op;
	struct super_block___108 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___108;

struct address_space___108 {
	struct inode___108 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___108 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___108;

struct inode___108 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___108 *i_op;
	struct super_block___108 *i_sb;
	struct address_space___108 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___108 *i_fop;
		void (*free_inode)(struct inode___108 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___108 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___108;

struct path___108;

struct dentry_operations___108 {
	int (*d_revalidate)(struct dentry___108 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___108 *, unsigned int);
	int (*d_hash)(const struct dentry___108 *, struct qstr *);
	int (*d_compare)(const struct dentry___108 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___108 *);
	int (*d_init)(struct dentry___108 *);
	void (*d_release)(struct dentry___108 *);
	void (*d_prune)(struct dentry___108 *);
	void (*d_iput)(struct dentry___108 *, struct inode___108 *);
	char * (*d_dname)(struct dentry___108 *, char *, int);
	struct vfsmount___108 * (*d_automount)(struct path___108 *);
	int (*d_manage)(const struct path___108 *, bool);
	struct dentry___108 * (*d_real)(struct dentry___108 *, const struct inode___108 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___108;

struct mem_dqinfo___108 {
	struct quota_format_type___108 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___108;

struct quota_info___108 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___108 *files[3];
	struct mem_dqinfo___108 info[3];
	const struct quota_format_ops___108 *ops[3];
};

struct rcuwait___109 {
	struct task_struct___115 *task;
};

struct percpu_rw_semaphore___109 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___109 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___108 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___109 rw_sem[3];
};

struct super_operations___108;

struct dquot_operations___108;

struct quotactl_ops___108;

struct super_block___108 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___108 *s_type;
	const struct super_operations___108 *s_op;
	const struct dquot_operations___108 *dq_op;
	const struct quotactl_ops___108 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___108 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___108 s_dquot;
	struct sb_writers___108 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___108 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___108 {
	struct dentry___108 *mnt_root;
	struct super_block___108 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___108 {
	struct vfsmount___108 *mnt;
	struct dentry___108 *dentry;
};

typedef struct page___113 *pgtable_t___113;

struct dev_pagemap___107;

struct page___113 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___108 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___113 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___113 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___114 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___107 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___107;

struct vm_area_struct___113 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___113 *vm_next;
	struct vm_area_struct___113 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___114 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___107 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___108 *vm_file;
	struct file___108 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___109 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___115 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___115 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___96 *pids[4];
	struct pid___96 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___114 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___113;

struct mm_struct___114 {
	struct {
		struct vm_area_struct___113 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___108 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___113 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___115 *owner;
		struct user_namespace___14 *user_ns;
		struct file___108 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___11 {
	unsigned int max_fds;
	struct file___108 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___11 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___11 *fdt;
	struct fdtable___11 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___108 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___107;

struct dev_pagemap___107 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___107 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___108 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___108 f_path;
	struct inode___108 *f_inode;
	const struct file_operations___108 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___96 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___108 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___107;

struct vm_operations_struct___107 {
	void (*open)(struct vm_area_struct___113 *);
	void (*close)(struct vm_area_struct___113 *);
	int (*may_split)(struct vm_area_struct___113 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___113 *);
	int (*mprotect)(struct vm_area_struct___113 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___107 *);
	vm_fault_t (*huge_fault)(struct vm_fault___107 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___107 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___113 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___107 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___107 *);
	int (*access)(struct vm_area_struct___113 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___113 *);
	int (*set_policy)(struct vm_area_struct___113 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___113 *, long unsigned int);
	struct page___113 * (*find_special_page)(struct vm_area_struct___113 *, long unsigned int);
};

struct core_thread___113 {
	struct task_struct___115 *task;
	struct core_thread___113 *next;
};

struct core_state___113 {
	atomic_t nr_threads;
	struct core_thread___113 dumper;
	struct completion startup;
};

struct vm_fault___107 {
	const struct {
		struct vm_area_struct___113 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___113 *cow_page;
	struct page___113 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___113 prealloc_pte;
};

struct kiocb___108 {
	struct file___108 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___108 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___108 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___108 *ia_file;
};

struct dquot___108 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___108 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___108 {
	int qf_fmt_id;
	const struct quota_format_ops___108 *qf_ops;
	struct module___101 *qf_owner;
	struct quota_format_type___108 *qf_next;
};

struct quota_format_ops___108 {
	int (*check_quota_file)(struct super_block___108 *, int);
	int (*read_file_info)(struct super_block___108 *, int);
	int (*write_file_info)(struct super_block___108 *, int);
	int (*free_file_info)(struct super_block___108 *, int);
	int (*read_dqblk)(struct dquot___108 *);
	int (*commit_dqblk)(struct dquot___108 *);
	int (*release_dqblk)(struct dquot___108 *);
	int (*get_next_id)(struct super_block___108 *, struct kqid *);
};

struct dquot_operations___108 {
	int (*write_dquot)(struct dquot___108 *);
	struct dquot___108 * (*alloc_dquot)(struct super_block___108 *, int);
	void (*destroy_dquot)(struct dquot___108 *);
	int (*acquire_dquot)(struct dquot___108 *);
	int (*release_dquot)(struct dquot___108 *);
	int (*mark_dirty)(struct dquot___108 *);
	int (*write_info)(struct super_block___108 *, int);
	qsize_t * (*get_reserved_space)(struct inode___108 *);
	int (*get_projid)(struct inode___108 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___108 *, qsize_t *);
	int (*get_next_id)(struct super_block___108 *, struct kqid *);
};

struct quotactl_ops___108 {
	int (*quota_on)(struct super_block___108 *, int, int, const struct path___108 *);
	int (*quota_off)(struct super_block___108 *, int);
	int (*quota_enable)(struct super_block___108 *, unsigned int);
	int (*quota_disable)(struct super_block___108 *, unsigned int);
	int (*quota_sync)(struct super_block___108 *, int);
	int (*set_info)(struct super_block___108 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___108 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___108 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___108 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___108 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___108 *, unsigned int);
};

struct address_space_operations___108 {
	int (*writepage)(struct page___113 *, struct writeback_control___3 *);
	int (*readpage)(struct file___108 *, struct page___113 *);
	int (*writepages)(struct address_space___108 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___113 *);
	int (*readpages)(struct file___108 *, struct address_space___108 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___108 *, struct address_space___108 *, loff_t, unsigned int, unsigned int, struct page___113 **, void **);
	int (*write_end)(struct file___108 *, struct address_space___108 *, loff_t, unsigned int, unsigned int, struct page___113 *, void *);
	sector_t (*bmap)(struct address_space___108 *, sector_t);
	void (*invalidatepage)(struct page___113 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___113 *, gfp_t);
	void (*freepage)(struct page___113 *);
	ssize_t (*direct_IO)(struct kiocb___108 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___108 *, struct page___113 *, struct page___113 *, enum migrate_mode);
	bool (*isolate_page)(struct page___113 *, isolate_mode_t);
	void (*putback_page)(struct page___113 *);
	int (*launder_page)(struct page___113 *);
	int (*is_partially_uptodate)(struct page___113 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___113 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___108 *, struct page___113 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___108 *, sector_t *);
	void (*swap_deactivate)(struct file___108 *);
};

struct inode_operations___108 {
	struct dentry___108 * (*lookup)(struct inode___108 *, struct dentry___108 *, unsigned int);
	const char * (*get_link)(struct dentry___108 *, struct inode___108 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___108 *, int);
	struct posix_acl * (*get_acl)(struct inode___108 *, int, bool);
	int (*readlink)(struct dentry___108 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___108 *, struct dentry___108 *, umode_t, bool);
	int (*link)(struct dentry___108 *, struct inode___108 *, struct dentry___108 *);
	int (*unlink)(struct inode___108 *, struct dentry___108 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___108 *, struct dentry___108 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___108 *, struct dentry___108 *, umode_t);
	int (*rmdir)(struct inode___108 *, struct dentry___108 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___108 *, struct dentry___108 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___108 *, struct dentry___108 *, struct inode___108 *, struct dentry___108 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___108 *, struct iattr___108 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___108 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___108 *, char *, size_t);
	int (*fiemap)(struct inode___108 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___108 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___108 *, struct dentry___108 *, struct file___108 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___108 *, struct dentry___108 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___108 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___108 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___108 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___108 {
	void (*fl_copy_lock)(struct file_lock___108 *, struct file_lock___108 *);
	void (*fl_release_private)(struct file_lock___108 *);
};

struct fasync_struct___108;

struct lock_manager_operations___108;

struct file_lock___108 {
	struct file_lock___108 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___108 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___108 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___108 *fl_ops;
	const struct lock_manager_operations___108 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___108 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___108 *);
	int (*lm_grant)(struct file_lock___108 *, int);
	bool (*lm_break)(struct file_lock___108 *);
	int (*lm_change)(struct file_lock___108 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___108 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___108 *);
};

struct fasync_struct___108 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___108 *fa_next;
	struct file___108 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___108 {
	struct inode___108 * (*alloc_inode)(struct super_block___108 *);
	void (*destroy_inode)(struct inode___108 *);
	void (*free_inode)(struct inode___108 *);
	void (*dirty_inode)(struct inode___108 *, int);
	int (*write_inode)(struct inode___108 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___108 *);
	void (*evict_inode)(struct inode___108 *);
	void (*put_super)(struct super_block___108 *);
	int (*sync_fs)(struct super_block___108 *, int);
	int (*freeze_super)(struct super_block___108 *);
	int (*freeze_fs)(struct super_block___108 *);
	int (*thaw_super)(struct super_block___108 *);
	int (*unfreeze_fs)(struct super_block___108 *);
	int (*statfs)(struct dentry___108 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___108 *, int *, char *);
	void (*umount_begin)(struct super_block___108 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___108 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___108 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___108 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___108 *);
	ssize_t (*quota_read)(struct super_block___108 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___108 *, int, const char *, size_t, loff_t);
	struct dquot___108 ** (*get_dquots)(struct inode___108 *);
	long int (*nr_cached_objects)(struct super_block___108 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___108 *, struct shrink_control___43 *);
	struct file___108 * (*real_loop)(struct file___108 *);
};

struct kernfs_root___103;

struct kernfs_elem_dir___103 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___103 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___103;

struct kernfs_root___103 {
	struct kernfs_node___103 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___103 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___103 {
	struct kernfs_node___103 *target_kn;
};

struct kernfs_ops___103;

struct kernfs_elem_attr___103 {
	const struct kernfs_ops___103 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___103 *notify_next;
};

struct kernfs_node___103 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___103 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___103 dir;
		struct kernfs_elem_symlink___103 symlink;
		struct kernfs_elem_attr___103 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___103;

struct kernfs_ops___103 {
	int (*open)(struct kernfs_open_file___103 *);
	void (*release)(struct kernfs_open_file___103 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___103 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___103 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___103 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___103 *, struct vm_area_struct___113 *);
};

struct kernfs_syscall_ops___103 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___103 *);
	int (*mkdir)(struct kernfs_node___103 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___103 *);
	int (*rename)(struct kernfs_node___103 *, struct kernfs_node___103 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___103 *, struct kernfs_root___103 *);
};

struct kernfs_open_file___103 {
	struct kernfs_node___103 *kn;
	struct file___108 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___107 *vm_ops;
};

struct bin_attribute___103;

struct attribute_group___103 {
	const char *name;
	umode_t (*is_visible)(struct kobject___103 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___103 *, struct bin_attribute___103 *, int);
	struct attribute **attrs;
	struct bin_attribute___103 **bin_attrs;
};

struct bin_attribute___103 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___108 * (*f_mapping)();
	ssize_t (*read)(struct file___108 *, struct kobject___103 *, struct bin_attribute___103 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___108 *, struct kobject___103 *, struct bin_attribute___103 *, char *, loff_t, size_t);
	int (*mmap)(struct file___108 *, struct kobject___103 *, struct bin_attribute___103 *, struct vm_area_struct___113 *);
};

struct sysfs_ops___103 {
	ssize_t (*show)(struct kobject___103 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___103 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___103;

struct kset___103 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___103 kobj;
	const struct kset_uevent_ops___103 *uevent_ops;
};

struct kobj_type___103 {
	void (*release)(struct kobject___103 *);
	const struct sysfs_ops___103 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___103 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___103 *);
	const void * (*namespace)(struct kobject___103 *);
	void (*get_ownership)(struct kobject___103 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___103 {
	int (* const filter)(struct kset___103 *, struct kobject___103 *);
	const char * (* const name)(struct kset___103 *, struct kobject___103 *);
	int (* const uevent)(struct kset___103 *, struct kobject___103 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___100 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___100 *);
	int (*get)(char *, const struct kernel_param___100 *);
	void (*free)(void *);
};

struct kparam_array___100;

struct kernel_param___100 {
	const char *name;
	struct module___101 *mod;
	const struct kernel_param_ops___100 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___100 *arr;
	};
};

struct kparam_array___100 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___100 *ops;
	void *elem;
};

struct module_attribute___100 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___100 *, struct module_kobject___100 *, char *);
	ssize_t (*store)(struct module_attribute___100 *, struct module_kobject___100 *, const char *, size_t);
	void (*setup)(struct module___101 *, const char *);
	int (*test)(struct module___101 *);
	void (*free)(struct module___101 *);
};

struct dnotify_struct {
	struct dnotify_struct *dn_next;
	__u32 dn_mask;
	int dn_fd;
	struct file___108 *dn_filp;
	fl_owner_t dn_owner;
};

struct dev_pagemap_ops___107 {
	void (*page_free)(struct page___113 *);
	void (*kill)(struct dev_pagemap___107 *);
	void (*cleanup)(struct dev_pagemap___107 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___107 *);
};

struct fsnotify_group___6;

struct fsnotify_iter_info___6;

struct fsnotify_mark___6;

struct fsnotify_ops___6 {
	int (*handle_event)(struct fsnotify_group___6 *, u32, const void *, int, struct inode___108 *, const struct qstr *, u32, struct fsnotify_iter_info___6 *);
	int (*handle_inode_event)(struct fsnotify_mark___6 *, u32, struct inode___108 *, struct inode___108 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___6 *);
	void (*freeing_mark)(struct fsnotify_mark___6 *, struct fsnotify_group___6 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___6 *);
};

struct fsnotify_group___6 {
	const struct fsnotify_ops___6 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___108 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___6 {
	struct fsnotify_mark___6 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___6 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___6 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct dnotify_mark {
	struct fsnotify_mark___6 fsn_mark;
	struct dnotify_struct *dn;
};

struct inotify_event_info {
	struct fsnotify_event fse;
	u32 mask;
	int wd;
	u32 sync_cookie;
	int name_len;
	char name[0];
};

struct inotify_inode_mark___2 {
	struct fsnotify_mark___2 fsn_mark;
	int wd;
};

struct fsnotify_group___7;

struct fsnotify_iter_info___7;

struct fsnotify_mark___7;

struct fsnotify_ops___7 {
	int (*handle_event)(struct fsnotify_group___7 *, u32, const void *, int, struct inode___2 *, const struct qstr *, u32, struct fsnotify_iter_info___7 *);
	int (*handle_inode_event)(struct fsnotify_mark___7 *, u32, struct inode___2 *, struct inode___2 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___7 *);
	void (*freeing_mark)(struct fsnotify_mark___7 *, struct fsnotify_group___7 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___7 *);
};

struct fsnotify_group___7 {
	const struct fsnotify_ops___7 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___75 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___33 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___7 {
	struct fsnotify_mark___7 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___7 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___7 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct inotify_event {
	__s32 wd;
	__u32 mask;
	__u32 cookie;
	__u32 len;
	char name[0];
};

struct inotify_inode_mark___3 {
	struct fsnotify_mark___7 fsn_mark;
	int wd;
};

struct dentry___109;

struct super_block___109;

struct file_system_type___109 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___109 * (*mount)(struct file_system_type___109 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___109 *);
	struct module___8 *owner;
	struct file_system_type___109 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___109;

struct kiocb___109;

struct vm_area_struct___114;

struct inode___109;

struct file_lock___109;

struct page___114;

struct file_operations___109 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___109 *, loff_t, int);
	ssize_t (*read)(struct file___109 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___109 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___109 *, struct iov_iter___62 *);
	ssize_t (*write_iter)(struct kiocb___109 *, struct iov_iter___62 *);
	int (*iopoll)(struct kiocb___109 *, bool);
	int (*iterate)(struct file___109 *, struct dir_context *);
	int (*iterate_shared)(struct file___109 *, struct dir_context *);
	__poll_t (*poll)(struct file___109 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___109 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___109 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___109 *, struct vm_area_struct___114 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___109 *, struct file___109 *);
	int (*flush)(struct file___109 *, fl_owner_t);
	int (*release)(struct inode___109 *, struct file___109 *);
	int (*fsync)(struct file___109 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___109 *, int);
	int (*lock)(struct file___109 *, int, struct file_lock___109 *);
	ssize_t (*sendpage)(struct file___109 *, struct page___114 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___109 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___109 *, long unsigned int);
	int (*flock)(struct file___109 *, int, struct file_lock___109 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___109 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___109 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___109 *, long int, struct file_lock___109 **, void **);
	long int (*fallocate)(struct file___109 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___109 *);
	ssize_t (*copy_file_range)(struct file___109 *, loff_t, struct file___109 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___109 *, loff_t, struct file___109 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___109 *, loff_t, loff_t, int);
};

struct vmacache___114 {
	u64 seqnum;
	struct vm_area_struct___114 *vmas[4];
};

struct page_frag___114 {
	struct page___114 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___115;

struct pid___97;

struct files_struct___12;

struct nsproxy___103;

struct signal_struct___110;

struct task_struct___116 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___116 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___115 *mm;
	struct mm_struct___115 *active_mm;
	struct vmacache___114 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___116 *real_parent;
	struct task_struct___116 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___116 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___97 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___12 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___103 *nsproxy;
	struct signal_struct___110 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___116 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___49 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___114 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___116 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___60 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___109;

struct dentry___109 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___109 *d_parent;
	struct qstr d_name;
	struct inode___109 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___109 *d_op;
	struct super_block___109 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___109;

struct address_space___109 {
	struct inode___109 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___109 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___109;

struct inode___109 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___109 *i_op;
	struct super_block___109 *i_sb;
	struct address_space___109 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___109 *i_fop;
		void (*free_inode)(struct inode___109 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___109 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___109;

struct path___109;

struct dentry_operations___109 {
	int (*d_revalidate)(struct dentry___109 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___109 *, unsigned int);
	int (*d_hash)(const struct dentry___109 *, struct qstr *);
	int (*d_compare)(const struct dentry___109 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___109 *);
	int (*d_init)(struct dentry___109 *);
	void (*d_release)(struct dentry___109 *);
	void (*d_prune)(struct dentry___109 *);
	void (*d_iput)(struct dentry___109 *, struct inode___109 *);
	char * (*d_dname)(struct dentry___109 *, char *, int);
	struct vfsmount___109 * (*d_automount)(struct path___109 *);
	int (*d_manage)(const struct path___109 *, bool);
	struct dentry___109 * (*d_real)(struct dentry___109 *, const struct inode___109 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___109;

struct mem_dqinfo___109 {
	struct quota_format_type___109 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___109;

struct quota_info___109 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___109 *files[3];
	struct mem_dqinfo___109 info[3];
	const struct quota_format_ops___109 *ops[3];
};

struct rcuwait___110 {
	struct task_struct___116 *task;
};

struct percpu_rw_semaphore___110 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___110 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___109 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___110 rw_sem[3];
};

struct super_operations___109;

struct dquot_operations___109;

struct quotactl_ops___109;

struct export_operations___7;

struct super_block___109 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___109 *s_type;
	const struct super_operations___109 *s_op;
	const struct dquot_operations___109 *dq_op;
	const struct quotactl_ops___109 *s_qcop;
	const struct export_operations___7 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___109 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___109 s_dquot;
	struct sb_writers___109 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___109 *s_d_op;
	int cleancache_poolid;
	struct shrinker___43 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___109 {
	struct dentry___109 *mnt_root;
	struct super_block___109 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___109 {
	struct vfsmount___109 *mnt;
	struct dentry___109 *dentry;
};

struct pid_namespace___97;

struct upid___97 {
	int nr;
	struct pid_namespace___97 *ns;
};

struct pid_namespace___97 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___116 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___97 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___97 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___97 numbers[1];
};

typedef struct page___114 *pgtable_t___114;

struct dev_pagemap___108;

struct page___114 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___109 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___114 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___114 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___115 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___108 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___108;

struct vm_area_struct___114 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___114 *vm_next;
	struct vm_area_struct___114 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___115 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___108 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___109 *vm_file;
	struct file___109 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___110 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___116 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___116 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___97 *pids[4];
	struct pid___97 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___115 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___114;

struct mm_struct___115 {
	struct {
		struct vm_area_struct___114 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___109 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___114 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___116 *owner;
		struct user_namespace___14 *user_ns;
		struct file___109 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___12 {
	unsigned int max_fds;
	struct file___109 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___12 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___12 *fdt;
	struct fdtable___12 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___109 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nsproxy___103 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___97 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct dev_pagemap_ops___108;

struct dev_pagemap___108 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___108 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___97 {
	rwlock_t lock;
	struct pid___97 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___109 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___109 f_path;
	struct inode___109 *f_inode;
	const struct file_operations___109 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___97 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___109 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___108;

struct vm_operations_struct___108 {
	void (*open)(struct vm_area_struct___114 *);
	void (*close)(struct vm_area_struct___114 *);
	int (*may_split)(struct vm_area_struct___114 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___114 *);
	int (*mprotect)(struct vm_area_struct___114 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___108 *);
	vm_fault_t (*huge_fault)(struct vm_fault___108 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___108 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___114 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___108 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___108 *);
	int (*access)(struct vm_area_struct___114 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___114 *);
	int (*set_policy)(struct vm_area_struct___114 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___114 *, long unsigned int);
	struct page___114 * (*find_special_page)(struct vm_area_struct___114 *, long unsigned int);
};

struct core_thread___114 {
	struct task_struct___116 *task;
	struct core_thread___114 *next;
};

struct core_state___114 {
	atomic_t nr_threads;
	struct core_thread___114 dumper;
	struct completion startup;
};

struct vm_fault___108 {
	const struct {
		struct vm_area_struct___114 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___114 *cow_page;
	struct page___114 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___114 prealloc_pte;
};

struct kiocb___109 {
	struct file___109 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___109 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___50 *ki_waitq;
	};
};

struct iattr___109 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___109 *ia_file;
};

struct dquot___109 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___109 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___109 {
	int qf_fmt_id;
	const struct quota_format_ops___109 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___109 *qf_next;
};

struct quota_format_ops___109 {
	int (*check_quota_file)(struct super_block___109 *, int);
	int (*read_file_info)(struct super_block___109 *, int);
	int (*write_file_info)(struct super_block___109 *, int);
	int (*free_file_info)(struct super_block___109 *, int);
	int (*read_dqblk)(struct dquot___109 *);
	int (*commit_dqblk)(struct dquot___109 *);
	int (*release_dqblk)(struct dquot___109 *);
	int (*get_next_id)(struct super_block___109 *, struct kqid *);
};

struct dquot_operations___109 {
	int (*write_dquot)(struct dquot___109 *);
	struct dquot___109 * (*alloc_dquot)(struct super_block___109 *, int);
	void (*destroy_dquot)(struct dquot___109 *);
	int (*acquire_dquot)(struct dquot___109 *);
	int (*release_dquot)(struct dquot___109 *);
	int (*mark_dirty)(struct dquot___109 *);
	int (*write_info)(struct super_block___109 *, int);
	qsize_t * (*get_reserved_space)(struct inode___109 *);
	int (*get_projid)(struct inode___109 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___109 *, qsize_t *);
	int (*get_next_id)(struct super_block___109 *, struct kqid *);
};

struct quotactl_ops___109 {
	int (*quota_on)(struct super_block___109 *, int, int, const struct path___109 *);
	int (*quota_off)(struct super_block___109 *, int);
	int (*quota_enable)(struct super_block___109 *, unsigned int);
	int (*quota_disable)(struct super_block___109 *, unsigned int);
	int (*quota_sync)(struct super_block___109 *, int);
	int (*set_info)(struct super_block___109 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___109 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___109 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___109 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___109 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___109 *, unsigned int);
};

struct address_space_operations___109 {
	int (*writepage)(struct page___114 *, struct writeback_control___3 *);
	int (*readpage)(struct file___109 *, struct page___114 *);
	int (*writepages)(struct address_space___109 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___114 *);
	int (*readpages)(struct file___109 *, struct address_space___109 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___109 *, struct address_space___109 *, loff_t, unsigned int, unsigned int, struct page___114 **, void **);
	int (*write_end)(struct file___109 *, struct address_space___109 *, loff_t, unsigned int, unsigned int, struct page___114 *, void *);
	sector_t (*bmap)(struct address_space___109 *, sector_t);
	void (*invalidatepage)(struct page___114 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___114 *, gfp_t);
	void (*freepage)(struct page___114 *);
	ssize_t (*direct_IO)(struct kiocb___109 *, struct iov_iter___62 *);
	int (*migratepage)(struct address_space___109 *, struct page___114 *, struct page___114 *, enum migrate_mode);
	bool (*isolate_page)(struct page___114 *, isolate_mode_t);
	void (*putback_page)(struct page___114 *);
	int (*launder_page)(struct page___114 *);
	int (*is_partially_uptodate)(struct page___114 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___114 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___109 *, struct page___114 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___109 *, sector_t *);
	void (*swap_deactivate)(struct file___109 *);
};

struct inode_operations___109 {
	struct dentry___109 * (*lookup)(struct inode___109 *, struct dentry___109 *, unsigned int);
	const char * (*get_link)(struct dentry___109 *, struct inode___109 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___109 *, int);
	struct posix_acl * (*get_acl)(struct inode___109 *, int, bool);
	int (*readlink)(struct dentry___109 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___109 *, struct dentry___109 *, umode_t, bool);
	int (*link)(struct dentry___109 *, struct inode___109 *, struct dentry___109 *);
	int (*unlink)(struct inode___109 *, struct dentry___109 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___109 *, struct dentry___109 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___109 *, struct dentry___109 *, umode_t);
	int (*rmdir)(struct inode___109 *, struct dentry___109 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___109 *, struct dentry___109 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___109 *, struct dentry___109 *, struct inode___109 *, struct dentry___109 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___109 *, struct iattr___109 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___109 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___109 *, char *, size_t);
	int (*fiemap)(struct inode___109 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___109 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___109 *, struct dentry___109 *, struct file___109 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___109 *, struct dentry___109 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___109 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___109 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___109 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___109 {
	void (*fl_copy_lock)(struct file_lock___109 *, struct file_lock___109 *);
	void (*fl_release_private)(struct file_lock___109 *);
};

struct fasync_struct___109;

struct lock_manager_operations___109;

struct file_lock___109 {
	struct file_lock___109 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___109 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___109 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___109 *fl_ops;
	const struct lock_manager_operations___109 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___109 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___109 *);
	int (*lm_grant)(struct file_lock___109 *, int);
	bool (*lm_break)(struct file_lock___109 *);
	int (*lm_change)(struct file_lock___109 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___109 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___109 *);
};

struct fasync_struct___109 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___109 *fa_next;
	struct file___109 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___109 {
	struct inode___109 * (*alloc_inode)(struct super_block___109 *);
	void (*destroy_inode)(struct inode___109 *);
	void (*free_inode)(struct inode___109 *);
	void (*dirty_inode)(struct inode___109 *, int);
	int (*write_inode)(struct inode___109 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___109 *);
	void (*evict_inode)(struct inode___109 *);
	void (*put_super)(struct super_block___109 *);
	int (*sync_fs)(struct super_block___109 *, int);
	int (*freeze_super)(struct super_block___109 *);
	int (*freeze_fs)(struct super_block___109 *);
	int (*thaw_super)(struct super_block___109 *);
	int (*unfreeze_fs)(struct super_block___109 *);
	int (*statfs)(struct dentry___109 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___109 *, int *, char *);
	void (*umount_begin)(struct super_block___109 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___109 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___109 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___109 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___109 *);
	ssize_t (*quota_read)(struct super_block___109 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___109 *, int, const char *, size_t, loff_t);
	struct dquot___109 ** (*get_dquots)(struct inode___109 *);
	long int (*nr_cached_objects)(struct super_block___109 *, struct shrink_control___43 *);
	long int (*free_cached_objects)(struct super_block___109 *, struct shrink_control___43 *);
	struct file___109 * (*real_loop)(struct file___109 *);
};

struct export_operations___7 {
	int (*encode_fh)(struct inode___109 *, __u32 *, int *, struct inode___109 *);
	struct dentry___109 * (*fh_to_dentry)(struct super_block___109 *, struct fid *, int, int);
	struct dentry___109 * (*fh_to_parent)(struct super_block___109 *, struct fid *, int, int);
	int (*get_name)(struct dentry___109 *, char *, struct dentry___109 *);
	struct dentry___109 * (*get_parent)(struct dentry___109 *);
	int (*commit_metadata)(struct inode___109 *);
	int (*get_uuid)(struct super_block___109 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___109 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___109 *, struct iomap *, int, struct iattr___109 *);
	u64 (*fetch_iversion)(struct inode___109 *);
	long unsigned int flags;
};

struct fsnotify_group___8;

struct fsnotify_iter_info___8;

struct fsnotify_mark___8;

struct fsnotify_ops___8 {
	int (*handle_event)(struct fsnotify_group___8 *, u32, const void *, int, struct inode___109 *, const struct qstr *, u32, struct fsnotify_iter_info___8 *);
	int (*handle_inode_event)(struct fsnotify_mark___8 *, u32, struct inode___109 *, struct inode___109 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___8 *);
	void (*freeing_mark)(struct fsnotify_mark___8 *, struct fsnotify_group___8 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___8 *);
};

struct fsnotify_group___8 {
	const struct fsnotify_ops___8 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___109 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___2 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___8 {
	struct fsnotify_mark___8 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___8 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___8 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

struct dev_pagemap_ops___108 {
	void (*page_free)(struct page___114 *);
	void (*kill)(struct dev_pagemap___108 *);
	void (*cleanup)(struct dev_pagemap___108 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___108 *);
};

enum {
	FAN_EVENT_INIT = 0,
	FAN_EVENT_REPORTED = 1,
	FAN_EVENT_ANSWERED = 2,
	FAN_EVENT_CANCELED = 3,
};

struct fanotify_fh {
	u8 type;
	u8 len;
	u8 flags;
	u8 pad;
	unsigned char buf[0];
};

struct fanotify_info {
	u8 dir_fh_totlen;
	u8 file_fh_totlen;
	u8 name_len;
	u8 pad;
	unsigned char buf[0];
};

enum fanotify_event_type {
	FANOTIFY_EVENT_TYPE_FID = 0,
	FANOTIFY_EVENT_TYPE_FID_NAME = 1,
	FANOTIFY_EVENT_TYPE_PATH = 2,
	FANOTIFY_EVENT_TYPE_PATH_PERM = 3,
	FANOTIFY_EVENT_TYPE_OVERFLOW = 4,
	__FANOTIFY_EVENT_TYPE_NUM = 5,
};

struct fanotify_event {
	struct fsnotify_event fse;
	struct hlist_node merge_list;
	u32 mask;
	struct {
		unsigned int type: 3;
		unsigned int hash: 29;
	};
	struct pid___97 *pid;
};

struct fanotify_fid_event {
	struct fanotify_event fae;
	__kernel_fsid_t fsid;
	struct fanotify_fh object_fh;
	unsigned char _inline_fh_buf[12];
};

struct fanotify_name_event {
	struct fanotify_event fae;
	__kernel_fsid_t fsid;
	struct fanotify_info info;
};

struct fanotify_path_event {
	struct fanotify_event fae;
	struct path___109 path;
};

struct fanotify_perm_event {
	struct fanotify_event fae;
	struct path___109 path;
	short unsigned int response;
	short unsigned int state;
	int fd;
};

struct dentry___110;

struct super_block___110;

struct module___102;

struct file_system_type___110 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___110 * (*mount)(struct file_system_type___110 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___110 *);
	struct module___102 *owner;
	struct file_system_type___110 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___110;

struct kiocb___110;

struct iov_iter___63;

struct poll_table_struct___78;

struct vm_area_struct___115;

struct inode___110;

struct file_lock___110;

struct page___115;

struct seq_file___100;

struct file_operations___110 {
	struct module___102 *owner;
	loff_t (*llseek)(struct file___110 *, loff_t, int);
	ssize_t (*read)(struct file___110 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___110 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___110 *, struct iov_iter___63 *);
	ssize_t (*write_iter)(struct kiocb___110 *, struct iov_iter___63 *);
	int (*iopoll)(struct kiocb___110 *, bool);
	int (*iterate)(struct file___110 *, struct dir_context *);
	int (*iterate_shared)(struct file___110 *, struct dir_context *);
	__poll_t (*poll)(struct file___110 *, struct poll_table_struct___78 *);
	long int (*unlocked_ioctl)(struct file___110 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___110 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___110 *, struct vm_area_struct___115 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___110 *, struct file___110 *);
	int (*flush)(struct file___110 *, fl_owner_t);
	int (*release)(struct inode___110 *, struct file___110 *);
	int (*fsync)(struct file___110 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___110 *, int);
	int (*lock)(struct file___110 *, int, struct file_lock___110 *);
	ssize_t (*sendpage)(struct file___110 *, struct page___115 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___110 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___110 *, long unsigned int);
	int (*flock)(struct file___110 *, int, struct file_lock___110 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___110 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___110 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___110 *, long int, struct file_lock___110 **, void **);
	long int (*fallocate)(struct file___110 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___100 *, struct file___110 *);
	ssize_t (*copy_file_range)(struct file___110 *, loff_t, struct file___110 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___110 *, loff_t, struct file___110 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___110 *, loff_t, loff_t, int);
};

struct vmacache___115 {
	u64 seqnum;
	struct vm_area_struct___115 *vmas[4];
};

struct page_frag___115 {
	struct page___115 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___61;

struct debug_info___61 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___61 *hbp_break[16];
	struct perf_event___61 *hbp_watch[16];
};

struct thread_struct___61 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___61 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___116;

struct pid___98;

struct files_struct___13;

struct nsproxy___104;

struct signal_struct___111;

struct bio_list___50;

struct backing_dev_info___49;

struct io_context___50;

struct css_set___84;

struct perf_event_context___61;

struct mem_cgroup___44;

struct request_queue___50;

struct vm_struct___102;

struct task_struct___117 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___117 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___116 *mm;
	struct mm_struct___116 *active_mm;
	struct vmacache___115 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___117 *real_parent;
	struct task_struct___117 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___117 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___98 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___13 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___104 *nsproxy;
	struct signal_struct___111 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___117 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___50 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___49 *backing_dev_info;
	struct io_context___50 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___84 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___61 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___115 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___44 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___44 *active_memcg;
	struct request_queue___50 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___117 *oom_reaper_list;
	struct vm_struct___102 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___61 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___104;

struct kobj_type___104;

struct kernfs_node___104;

struct kobject___104 {
	const char *name;
	struct list_head entry;
	struct kobject___104 *parent;
	struct kset___104 *kset;
	struct kobj_type___104 *ktype;
	struct kernfs_node___104 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___101 {
	struct kobject___104 kobj;
	struct module___102 *mod;
	struct kobject___104 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___101 {
	struct module___102 *mod;
	struct latch_tree_node node;
};

struct module_layout___101 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___101 mtn;
};

struct module_attribute___101;

struct kernel_param___101;

struct trace_event_call___55;

struct module___102 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___101 mkobj;
	struct module_attribute___101 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___104 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___101 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___101 core_layout;
	struct module_layout___101 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___55 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___61 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___117 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___61)(struct perf_event___61 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___61;

struct fasync_struct___110;

struct pid_namespace___98;

struct perf_cgroup___61;

struct perf_event___61 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___61 *group_leader;
	struct pmu___61 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___61 hw;
	struct perf_event_context___61 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___61 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___117 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___110 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___61 *aux_event;
	void (*destroy)(struct perf_event___61 *);
	struct callback_head callback_head;
	struct pid_namespace___98 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___61 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___61 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___55 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___61 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct fanotify_event_metadata {
	__u32 event_len;
	__u8 vers;
	__u8 reserved;
	__u16 metadata_len;
	__u64 mask;
	__s32 fd;
	__s32 pid;
};

struct fanotify_event_info_header {
	__u8 info_type;
	__u8 pad;
	__u16 len;
};

struct fanotify_event_info_fid {
	struct fanotify_event_info_header hdr;
	__kernel_fsid_t fsid;
	unsigned char handle[0];
};

struct fanotify_event_info_pidfd {
	struct fanotify_event_info_header hdr;
	__s32 pidfd;
};

struct fanotify_response {
	__s32 fd;
	__u32 response;
};

struct upid___98 {
	int nr;
	struct pid_namespace___98 *ns;
};

struct pid_namespace___98 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___117 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___98 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___98 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___98 numbers[1];
};

typedef struct page___115 *pgtable_t___115;

struct address_space___110;

struct dev_pagemap___109;

struct page___115 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___110 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___115 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___115 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___116 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___109 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___109;

struct vm_area_struct___115 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___115 *vm_next;
	struct vm_area_struct___115 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___116 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___109 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___110 *vm_file;
	struct file___110 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___111 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___117 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___117 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___98 *pids[4];
	struct pid___98 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___116 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___115;

struct mm_struct___116 {
	struct {
		struct vm_area_struct___115 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___110 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___115 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___117 *owner;
		struct user_namespace___14 *user_ns;
		struct file___110 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___13 {
	unsigned int max_fds;
	struct file___110 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___13 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___13 *fdt;
	struct fdtable___13 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___110 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mnt_namespace___12;

struct cgroup_namespace___84;

struct nsproxy___104 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___12 *mnt_ns;
	struct pid_namespace___98 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___84 *cgroup_ns;
};

struct bio___50;

struct bio_list___50 {
	struct bio___50 *head;
	struct bio___50 *tail;
};

struct cgroup_subsys_state___84;

struct bdi_writeback___49 {
	struct backing_dev_info___49 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___84 *memcg_css;
	struct cgroup_subsys_state___84 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___86;

struct backing_dev_info___49 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___49 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___86 *dev;
	char dev_name[64];
	struct device___86 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___110 *debug_dir;
};

struct io_cq___50;

struct io_context___50 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___50 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___84;

struct css_set___84 {
	struct cgroup_subsys_state___84 *subsys[14];
	refcount_t refcount;
	struct css_set___84 *dom_cset;
	struct cgroup___84 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___84 *mg_src_cgrp;
	struct cgroup___84 *mg_dst_cgrp;
	struct css_set___84 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___61 {
	struct pmu___61 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___117 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___61 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___84;

struct cgroup_subsys_state___84 {
	struct cgroup___84 *cgroup;
	struct cgroup_subsys___84 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___84 *parent;
};

struct cgroup_file___84 {
	struct kernfs_node___104 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___44;

struct mem_cgroup_per_node___44;

struct mem_cgroup___44 {
	struct cgroup_subsys_state___84 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___84 events_file;
	struct cgroup_file___84 events_local_file;
	struct cgroup_file___84 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___44 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___117 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___44 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___50;

struct blk_integrity___50 {
	const struct blk_integrity_profile___50 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___50 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___50 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___50;

struct elevator_queue___50;

struct blk_mq_ops___49;

struct blk_mq_hw_ctx___49;

struct gendisk___50;

struct blkcg_gq___49;

struct blk_mq_tag_set___49;

struct request_queue___50 {
	struct request___50 *last_merge;
	struct elevator_queue___50 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___49 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___49 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___50 *disk;
	struct kobject___104 kobj;
	struct kobject___104 *mq_kobj;
	struct blk_integrity___50 integrity;
	struct device___86 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___49 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___49 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___50 bio_split;
	struct dentry___110 *debugfs_dir;
	struct dentry___110 *sched_debugfs_dir;
	struct dentry___110 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___102 {
	struct vm_struct___102 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___115 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___110;

struct dentry___110 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___110 *d_parent;
	struct qstr d_name;
	struct inode___110 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___110 *d_op;
	struct super_block___110 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___110;

struct address_space___110 {
	struct inode___110 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___110 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___110;

struct inode___110 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___110 *i_op;
	struct super_block___110 *i_sb;
	struct address_space___110 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___49 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___110 *i_fop;
		void (*free_inode)(struct inode___110 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___110 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___17 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___110;

struct path___110;

struct dentry_operations___110 {
	int (*d_revalidate)(struct dentry___110 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___110 *, unsigned int);
	int (*d_hash)(const struct dentry___110 *, struct qstr *);
	int (*d_compare)(const struct dentry___110 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___110 *);
	int (*d_init)(struct dentry___110 *);
	void (*d_release)(struct dentry___110 *);
	void (*d_prune)(struct dentry___110 *);
	void (*d_iput)(struct dentry___110 *, struct inode___110 *);
	char * (*d_dname)(struct dentry___110 *, char *, int);
	struct vfsmount___110 * (*d_automount)(struct path___110 *);
	int (*d_manage)(const struct path___110 *, bool);
	struct dentry___110 * (*d_real)(struct dentry___110 *, const struct inode___110 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___110;

struct mem_dqinfo___110 {
	struct quota_format_type___110 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___110;

struct quota_info___110 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___110 *files[3];
	struct mem_dqinfo___110 info[3];
	const struct quota_format_ops___110 *ops[3];
};

struct rcuwait___111 {
	struct task_struct___117 *task;
};

struct percpu_rw_semaphore___111 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___111 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___110 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___111 rw_sem[3];
};

struct shrink_control___44;

struct shrinker___44 {
	long unsigned int (*count_objects)(struct shrinker___44 *, struct shrink_control___44 *);
	long unsigned int (*scan_objects)(struct shrinker___44 *, struct shrink_control___44 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___110;

struct dquot_operations___110;

struct quotactl_ops___110;

struct export_operations___8;

struct block_device___51;

struct super_block___110 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___110 *s_type;
	const struct super_operations___110 *s_op;
	const struct dquot_operations___110 *dq_op;
	const struct quotactl_ops___110 *s_qcop;
	const struct export_operations___8 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___110 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___51 *s_bdev;
	struct backing_dev_info___49 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___110 s_dquot;
	struct sb_writers___110 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___110 *s_d_op;
	int cleancache_poolid;
	struct shrinker___44 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___110 {
	struct dentry___110 *mnt_root;
	struct super_block___110 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___110 {
	struct vfsmount___110 *mnt;
	struct dentry___110 *dentry;
};

struct shrink_control___44 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___44 *memcg;
};

struct dev_pagemap_ops___109;

struct dev_pagemap___109 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___109 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___98 {
	rwlock_t lock;
	struct pid___98 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___110 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___110 f_path;
	struct inode___110 *f_inode;
	const struct file_operations___110 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___110 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___109;

struct vm_operations_struct___109 {
	void (*open)(struct vm_area_struct___115 *);
	void (*close)(struct vm_area_struct___115 *);
	int (*may_split)(struct vm_area_struct___115 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___115 *);
	int (*mprotect)(struct vm_area_struct___115 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___109 *);
	vm_fault_t (*huge_fault)(struct vm_fault___109 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___109 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___115 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___109 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___109 *);
	int (*access)(struct vm_area_struct___115 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___115 *);
	int (*set_policy)(struct vm_area_struct___115 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___115 *, long unsigned int);
	struct page___115 * (*find_special_page)(struct vm_area_struct___115 *, long unsigned int);
};

struct core_thread___115 {
	struct task_struct___117 *task;
	struct core_thread___115 *next;
};

struct core_state___115 {
	atomic_t nr_threads;
	struct core_thread___115 dumper;
	struct completion startup;
};

struct vm_fault___109 {
	const struct {
		struct vm_area_struct___115 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___115 *cow_page;
	struct page___115 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___115 prealloc_pte;
};

struct pglist_data___50;

struct lruvec___50 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___50 *pgdat;
};

struct zone___50 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___50 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___50 {
	struct zone___50 *zone;
	int zone_idx;
};

struct zonelist___50 {
	struct zoneref___50 _zonerefs[321];
};

struct pglist_data___50 {
	struct zone___50 node_zones[5];
	struct zonelist___50 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___117 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___117 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___50 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___84 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___117 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___84;

struct cgroup_rstat_cpu___84;

struct cgroup___84 {
	struct cgroup_subsys_state___84 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___104 *kn;
	struct cgroup_file___84 procs_file;
	struct cgroup_file___84 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___84 *subsys[14];
	struct cgroup_root___84 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___84 *dom_cgrp;
	struct cgroup___84 *old_dom_cgrp;
	struct cgroup_rstat_cpu___84 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___84 psi;
	struct cgroup_bpf___4 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___50 {
	struct request_queue___50 *q;
	struct io_context___50 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___110 {
	struct file___110 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___110 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___22 *ki_waitq;
	};
};

struct iattr___110 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___110 *ia_file;
};

struct dquot___110 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___110 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___110 {
	int qf_fmt_id;
	const struct quota_format_ops___110 *qf_ops;
	struct module___102 *qf_owner;
	struct quota_format_type___110 *qf_next;
};

struct quota_format_ops___110 {
	int (*check_quota_file)(struct super_block___110 *, int);
	int (*read_file_info)(struct super_block___110 *, int);
	int (*write_file_info)(struct super_block___110 *, int);
	int (*free_file_info)(struct super_block___110 *, int);
	int (*read_dqblk)(struct dquot___110 *);
	int (*commit_dqblk)(struct dquot___110 *);
	int (*release_dqblk)(struct dquot___110 *);
	int (*get_next_id)(struct super_block___110 *, struct kqid *);
};

struct dquot_operations___110 {
	int (*write_dquot)(struct dquot___110 *);
	struct dquot___110 * (*alloc_dquot)(struct super_block___110 *, int);
	void (*destroy_dquot)(struct dquot___110 *);
	int (*acquire_dquot)(struct dquot___110 *);
	int (*release_dquot)(struct dquot___110 *);
	int (*mark_dirty)(struct dquot___110 *);
	int (*write_info)(struct super_block___110 *, int);
	qsize_t * (*get_reserved_space)(struct inode___110 *);
	int (*get_projid)(struct inode___110 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___110 *, qsize_t *);
	int (*get_next_id)(struct super_block___110 *, struct kqid *);
};

struct quotactl_ops___110 {
	int (*quota_on)(struct super_block___110 *, int, int, const struct path___110 *);
	int (*quota_off)(struct super_block___110 *, int);
	int (*quota_enable)(struct super_block___110 *, unsigned int);
	int (*quota_disable)(struct super_block___110 *, unsigned int);
	int (*quota_sync)(struct super_block___110 *, int);
	int (*set_info)(struct super_block___110 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___110 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___110 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___110 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___110 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___110 *, unsigned int);
};

struct writeback_control___49;

struct address_space_operations___110 {
	int (*writepage)(struct page___115 *, struct writeback_control___49 *);
	int (*readpage)(struct file___110 *, struct page___115 *);
	int (*writepages)(struct address_space___110 *, struct writeback_control___49 *);
	int (*set_page_dirty)(struct page___115 *);
	int (*readpages)(struct file___110 *, struct address_space___110 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___110 *, struct address_space___110 *, loff_t, unsigned int, unsigned int, struct page___115 **, void **);
	int (*write_end)(struct file___110 *, struct address_space___110 *, loff_t, unsigned int, unsigned int, struct page___115 *, void *);
	sector_t (*bmap)(struct address_space___110 *, sector_t);
	void (*invalidatepage)(struct page___115 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___115 *, gfp_t);
	void (*freepage)(struct page___115 *);
	ssize_t (*direct_IO)(struct kiocb___110 *, struct iov_iter___63 *);
	int (*migratepage)(struct address_space___110 *, struct page___115 *, struct page___115 *, enum migrate_mode);
	bool (*isolate_page)(struct page___115 *, isolate_mode_t);
	void (*putback_page)(struct page___115 *);
	int (*launder_page)(struct page___115 *);
	int (*is_partially_uptodate)(struct page___115 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___115 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___110 *, struct page___115 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___110 *, sector_t *);
	void (*swap_deactivate)(struct file___110 *);
};

struct writeback_control___49 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___49 *wb;
	struct inode___110 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___61;

struct iov_iter___63 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___61 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___110 {
	struct dentry___110 * (*lookup)(struct inode___110 *, struct dentry___110 *, unsigned int);
	const char * (*get_link)(struct dentry___110 *, struct inode___110 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___110 *, int);
	struct posix_acl * (*get_acl)(struct inode___110 *, int, bool);
	int (*readlink)(struct dentry___110 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___110 *, struct dentry___110 *, umode_t, bool);
	int (*link)(struct dentry___110 *, struct inode___110 *, struct dentry___110 *);
	int (*unlink)(struct inode___110 *, struct dentry___110 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___110 *, struct dentry___110 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___110 *, struct dentry___110 *, umode_t);
	int (*rmdir)(struct inode___110 *, struct dentry___110 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___110 *, struct dentry___110 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___110 *, struct dentry___110 *, struct inode___110 *, struct dentry___110 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___110 *, struct iattr___110 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___110 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___110 *, char *, size_t);
	int (*fiemap)(struct inode___110 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___110 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___110 *, struct dentry___110 *, struct file___110 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___110 *, struct dentry___110 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___110 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___110 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___110 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___110 {
	void (*fl_copy_lock)(struct file_lock___110 *, struct file_lock___110 *);
	void (*fl_release_private)(struct file_lock___110 *);
};

struct lock_manager_operations___110;

struct file_lock___110 {
	struct file_lock___110 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___110 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___110 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___110 *fl_ops;
	const struct lock_manager_operations___110 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___110 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___110 *);
	int (*lm_grant)(struct file_lock___110 *, int);
	bool (*lm_break)(struct file_lock___110 *);
	int (*lm_change)(struct file_lock___110 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___110 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___110 *);
};

struct fasync_struct___110 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___110 *fa_next;
	struct file___110 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___110 {
	struct inode___110 * (*alloc_inode)(struct super_block___110 *);
	void (*destroy_inode)(struct inode___110 *);
	void (*free_inode)(struct inode___110 *);
	void (*dirty_inode)(struct inode___110 *, int);
	int (*write_inode)(struct inode___110 *, struct writeback_control___49 *);
	int (*drop_inode)(struct inode___110 *);
	void (*evict_inode)(struct inode___110 *);
	void (*put_super)(struct super_block___110 *);
	int (*sync_fs)(struct super_block___110 *, int);
	int (*freeze_super)(struct super_block___110 *);
	int (*freeze_fs)(struct super_block___110 *);
	int (*thaw_super)(struct super_block___110 *);
	int (*unfreeze_fs)(struct super_block___110 *);
	int (*statfs)(struct dentry___110 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___110 *, int *, char *);
	void (*umount_begin)(struct super_block___110 *);
	int (*show_options)(struct seq_file___100 *, struct dentry___110 *);
	int (*show_devname)(struct seq_file___100 *, struct dentry___110 *);
	int (*show_path)(struct seq_file___100 *, struct dentry___110 *);
	int (*show_stats)(struct seq_file___100 *, struct dentry___110 *);
	ssize_t (*quota_read)(struct super_block___110 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___110 *, int, const char *, size_t, loff_t);
	struct dquot___110 ** (*get_dquots)(struct inode___110 *);
	long int (*nr_cached_objects)(struct super_block___110 *, struct shrink_control___44 *);
	long int (*free_cached_objects)(struct super_block___110 *, struct shrink_control___44 *);
	struct file___110 * (*real_loop)(struct file___110 *);
};

struct export_operations___8 {
	int (*encode_fh)(struct inode___110 *, __u32 *, int *, struct inode___110 *);
	struct dentry___110 * (*fh_to_dentry)(struct super_block___110 *, struct fid *, int, int);
	struct dentry___110 * (*fh_to_parent)(struct super_block___110 *, struct fid *, int, int);
	int (*get_name)(struct dentry___110 *, char *, struct dentry___110 *);
	struct dentry___110 * (*get_parent)(struct dentry___110 *);
	int (*commit_metadata)(struct inode___110 *);
	int (*get_uuid)(struct super_block___110 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___110 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___110 *, struct iomap *, int, struct iattr___110 *);
	u64 (*fetch_iversion)(struct inode___110 *);
	long unsigned int flags;
};

struct wakeup_source___86;

struct dev_pm_info___86 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___86 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___86 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___86;

struct bus_type___86;

struct device_driver___86;

struct dev_pm_domain___86;

struct fwnode_handle___86;

struct class___86;

struct attribute_group___104;

struct device___86 {
	struct kobject___104 kobj;
	struct device___86 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___86 *type;
	struct bus_type___86 *bus;
	struct device_driver___86 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___86 power;
	struct dev_pm_domain___86 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___86 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___86 *class;
	const struct attribute_group___104 **groups;
	void (*release)(struct device___86 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___51 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___110 *bd_inode;
	struct super_block___110 *bd_super;
	void *bd_claiming;
	struct device___86 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___104 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___50 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___110 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___78)(struct file___110 *, wait_queue_head_t *, struct poll_table_struct___78 *);

struct poll_table_struct___78 {
	poll_queue_proc___78 _qproc;
	__poll_t _key;
};

struct seq_operations___100;

struct seq_file___100 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___100 *op;
	int poll_event;
	const struct file___110 *file;
	void *private;
};

typedef void bio_end_io_t___50(struct bio___50 *);

struct bio_vec___61 {
	struct page___115 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___50;

struct bio___50 {
	struct bio___50 *bi_next;
	struct block_device___51 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___50 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___49 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___50 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___61 *bi_io_vec;
	struct bio_set___50 *bi_pool;
	struct bio_vec___61 bi_inline_vecs[0];
};

struct fd___23 {
	struct file___110 *file;
	unsigned int flags;
};

struct mount___12;

struct mnt_namespace___12 {
	struct ns_common___14 ns;
	struct mount___12 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___84 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___84 *root_cset;
};

struct seq_operations___100 {
	void * (*start)(struct seq_file___100 *, loff_t *);
	void (*stop)(struct seq_file___100 *, void *);
	void * (*next)(struct seq_file___100 *, void *, loff_t *);
	int (*show)(struct seq_file___100 *, void *);
};

struct fsnotify_group___9;

struct fsnotify_iter_info___9;

struct fsnotify_mark___9;

struct fsnotify_ops___9 {
	int (*handle_event)(struct fsnotify_group___9 *, u32, const void *, int, struct inode___110 *, const struct qstr *, u32, struct fsnotify_iter_info___9 *);
	int (*handle_inode_event)(struct fsnotify_mark___9 *, u32, struct inode___110 *, struct inode___110 *, const struct qstr *, u32);
	void (*free_group_priv)(struct fsnotify_group___9 *);
	void (*freeing_mark)(struct fsnotify_mark___9 *, struct fsnotify_group___9 *);
	void (*free_event)(struct fsnotify_event *);
	void (*free_mark)(struct fsnotify_mark___9 *);
};

struct fsnotify_group___9 {
	const struct fsnotify_ops___9 *ops;
	refcount_t refcnt;
	spinlock_t notification_lock;
	struct list_head notification_list;
	wait_queue_head_t notification_waitq;
	unsigned int q_len;
	unsigned int max_events;
	unsigned int priority;
	bool shutdown;
	struct mutex mark_mutex;
	atomic_t user_waits;
	struct list_head marks_list;
	struct fasync_struct___110 *fsn_fa;
	struct fsnotify_event *overflow_event;
	struct mem_cgroup___44 *memcg;
	union {
		void *private;
		struct inotify_group_private_data inotify_data;
		struct fanotify_group_private_data fanotify_data;
	};
};

struct fsnotify_iter_info___9 {
	struct fsnotify_mark___9 *marks[4];
	unsigned int report_mask;
	int srcu_idx;
};

struct fsnotify_mark___9 {
	__u32 mask;
	refcount_t refcnt;
	struct fsnotify_group___9 *group;
	struct list_head g_list;
	spinlock_t lock;
	struct hlist_node obj_list;
	struct fsnotify_mark_connector *connector;
	__u32 ignored_mask;
	unsigned int flags;
};

typedef struct poll_table_struct___78 poll_table___19;

struct dev_pagemap_ops___109 {
	void (*page_free)(struct page___115 *);
	void (*kill)(struct dev_pagemap___109 *);
	void (*cleanup)(struct dev_pagemap___109 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___109 *);
};

struct kernfs_root___104;

struct kernfs_elem_dir___104 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___104 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___104;

struct kernfs_root___104 {
	struct kernfs_node___104 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___104 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___104 {
	struct kernfs_node___104 *target_kn;
};

struct kernfs_ops___104;

struct kernfs_elem_attr___104 {
	const struct kernfs_ops___104 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___104 *notify_next;
};

struct kernfs_node___104 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___104 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___104 dir;
		struct kernfs_elem_symlink___104 symlink;
		struct kernfs_elem_attr___104 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___104;

struct kernfs_ops___104 {
	int (*open)(struct kernfs_open_file___104 *);
	void (*release)(struct kernfs_open_file___104 *);
	int (*seq_show)(struct seq_file___100 *, void *);
	void * (*seq_start)(struct seq_file___100 *, loff_t *);
	void * (*seq_next)(struct seq_file___100 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___100 *, void *);
	ssize_t (*read)(struct kernfs_open_file___104 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___104 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___104 *, struct poll_table_struct___78 *);
	int (*mmap)(struct kernfs_open_file___104 *, struct vm_area_struct___115 *);
};

struct kernfs_syscall_ops___104 {
	int (*show_options)(struct seq_file___100 *, struct kernfs_root___104 *);
	int (*mkdir)(struct kernfs_node___104 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___104 *);
	int (*rename)(struct kernfs_node___104 *, struct kernfs_node___104 *, const char *);
	int (*show_path)(struct seq_file___100 *, struct kernfs_node___104 *, struct kernfs_root___104 *);
};

struct kernfs_open_file___104 {
	struct kernfs_node___104 *kn;
	struct file___110 *file;
	struct seq_file___100 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___109 *vm_ops;
};

struct bin_attribute___104;

struct attribute_group___104 {
	const char *name;
	umode_t (*is_visible)(struct kobject___104 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___104 *, struct bin_attribute___104 *, int);
	struct attribute **attrs;
	struct bin_attribute___104 **bin_attrs;
};

struct bin_attribute___104 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___110 * (*f_mapping)();
	ssize_t (*read)(struct file___110 *, struct kobject___104 *, struct bin_attribute___104 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___110 *, struct kobject___104 *, struct bin_attribute___104 *, char *, loff_t, size_t);
	int (*mmap)(struct file___110 *, struct kobject___104 *, struct bin_attribute___104 *, struct vm_area_struct___115 *);
};

struct sysfs_ops___104 {
	ssize_t (*show)(struct kobject___104 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___104 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___104;

struct kset___104 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___104 kobj;
	const struct kset_uevent_ops___104 *uevent_ops;
};

struct kobj_type___104 {
	void (*release)(struct kobject___104 *);
	const struct sysfs_ops___104 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___104 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___104 *);
	const void * (*namespace)(struct kobject___104 *);
	void (*get_ownership)(struct kobject___104 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___104 {
	int (* const filter)(struct kset___104 *, struct kobject___104 *);
	const char * (* const name)(struct kset___104 *, struct kobject___104 *);
	int (* const uevent)(struct kset___104 *, struct kobject___104 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___86 {
	int (*prepare)(struct device___86 *);
	void (*complete)(struct device___86 *);
	int (*suspend)(struct device___86 *);
	int (*resume)(struct device___86 *);
	int (*freeze)(struct device___86 *);
	int (*thaw)(struct device___86 *);
	int (*poweroff)(struct device___86 *);
	int (*restore)(struct device___86 *);
	int (*suspend_late)(struct device___86 *);
	int (*resume_early)(struct device___86 *);
	int (*freeze_late)(struct device___86 *);
	int (*thaw_early)(struct device___86 *);
	int (*poweroff_late)(struct device___86 *);
	int (*restore_early)(struct device___86 *);
	int (*suspend_noirq)(struct device___86 *);
	int (*resume_noirq)(struct device___86 *);
	int (*freeze_noirq)(struct device___86 *);
	int (*thaw_noirq)(struct device___86 *);
	int (*poweroff_noirq)(struct device___86 *);
	int (*restore_noirq)(struct device___86 *);
	int (*runtime_suspend)(struct device___86 *);
	int (*runtime_resume)(struct device___86 *);
	int (*runtime_idle)(struct device___86 *);
};

struct wakeup_source___86 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___86 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___86 {
	struct dev_pm_ops___86 ops;
	int (*start)(struct device___86 *);
	void (*detach)(struct device___86 *, bool);
	int (*activate)(struct device___86 *);
	void (*sync)(struct device___86 *);
	void (*dismiss)(struct device___86 *);
};

struct bus_type___86 {
	const char *name;
	const char *dev_name;
	struct device___86 *dev_root;
	const struct attribute_group___104 **bus_groups;
	const struct attribute_group___104 **dev_groups;
	const struct attribute_group___104 **drv_groups;
	int (*match)(struct device___86 *, struct device_driver___86 *);
	int (*uevent)(struct device___86 *, struct kobj_uevent_env *);
	int (*probe)(struct device___86 *);
	void (*sync_state)(struct device___86 *);
	void (*remove)(struct device___86 *);
	void (*shutdown)(struct device___86 *);
	int (*online)(struct device___86 *);
	int (*offline)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	int (*num_vf)(struct device___86 *);
	int (*dma_configure)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___86 {
	const char *name;
	struct bus_type___86 *bus;
	struct module___102 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___86 *);
	void (*sync_state)(struct device___86 *);
	int (*remove)(struct device___86 *);
	void (*shutdown)(struct device___86 *);
	int (*suspend)(struct device___86 *, pm_message_t);
	int (*resume)(struct device___86 *);
	const struct attribute_group___104 **groups;
	const struct attribute_group___104 **dev_groups;
	const struct dev_pm_ops___86 *pm;
	void (*coredump)(struct device___86 *);
	struct driver_private *p;
};

struct device_type___86 {
	const char *name;
	const struct attribute_group___104 **groups;
	int (*uevent)(struct device___86 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___86 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___86 *);
	const struct dev_pm_ops___86 *pm;
};

struct class___86 {
	const char *name;
	struct module___102 *owner;
	const struct attribute_group___104 **class_groups;
	const struct attribute_group___104 **dev_groups;
	struct kobject___104 *dev_kobj;
	int (*dev_uevent)(struct device___86 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___86 *, umode_t *);
	void (*class_release)(struct class___86 *);
	void (*dev_release)(struct device___86 *);
	int (*shutdown_pre)(struct device___86 *);
	const struct kobj_ns_type_operations___3 *ns_type;
	const void * (*namespace)(struct device___86 *);
	void (*get_ownership)(struct device___86 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___86 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___86;

struct fwnode_handle___86 {
	struct fwnode_handle___86 *secondary;
	const struct fwnode_operations___86 *ops;
	struct device___86 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___86;

struct fwnode_endpoint___86;

struct fwnode_operations___86 {
	struct fwnode_handle___86 * (*get)(struct fwnode_handle___86 *);
	void (*put)(struct fwnode_handle___86 *);
	bool (*device_is_available)(const struct fwnode_handle___86 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___86 *, const struct device___86 *);
	bool (*property_present)(const struct fwnode_handle___86 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___86 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___86 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___86 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*get_parent)(const struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*get_next_child_node)(const struct fwnode_handle___86 *, struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*get_named_child_node)(const struct fwnode_handle___86 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___86 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___86 *);
	struct fwnode_handle___86 * (*graph_get_next_endpoint)(const struct fwnode_handle___86 *, struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*graph_get_remote_endpoint)(const struct fwnode_handle___86 *);
	struct fwnode_handle___86 * (*graph_get_port_parent)(struct fwnode_handle___86 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___86 *, struct fwnode_endpoint___86 *);
	int (*add_links)(struct fwnode_handle___86 *);
};

struct fwnode_endpoint___86 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___86 *local_fwnode;
};

struct fwnode_reference_args___86 {
	struct fwnode_handle___86 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___101 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___101 *);
	int (*get)(char *, const struct kernel_param___101 *);
	void (*free)(void *);
};

struct kparam_array___101;

struct kernel_param___101 {
	const char *name;
	struct module___102 *mod;
	const struct kernel_param_ops___101 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___101 *arr;
	};
};

struct kparam_array___101 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___101 *ops;
	void *elem;
};

struct module_attribute___101 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___101 *, struct module_kobject___101 *, char *);
	ssize_t (*store)(struct module_attribute___101 *, struct module_kobject___101 *, const char *, size_t);
	void (*setup)(struct module___102 *, const char *);
	int (*test)(struct module___102 *);
	void (*free)(struct module___102 *);
};

struct trace_event_class___55;

struct trace_event_call___55 {
	struct list_head list;
	struct trace_event_class___55 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___4 *prog_array;
	int (*perf_perm)(struct trace_event_call___55 *, struct perf_event___61 *);
};

struct cftype___84;

struct cgroup_subsys___84 {
	struct cgroup_subsys_state___84 * (*css_alloc)(struct cgroup_subsys_state___84 *);
	int (*css_online)(struct cgroup_subsys_state___84 *);
	void (*css_offline)(struct cgroup_subsys_state___84 *);
	void (*css_released)(struct cgroup_subsys_state___84 *);
	void (*css_free)(struct cgroup_subsys_state___84 *);
	void (*css_reset)(struct cgroup_subsys_state___84 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___84 *, int);
	int (*css_extra_stat_show)(struct seq_file___100 *, struct cgroup_subsys_state___84 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___117 *, struct css_set___84 *);
	void (*cancel_fork)(struct task_struct___117 *, struct css_set___84 *);
	void (*fork)(struct task_struct___117 *);
	void (*exit)(struct task_struct___117 *);
	void (*release)(struct task_struct___117 *);
	void (*bind)(struct cgroup_subsys_state___84 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___84 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___84 *dfl_cftypes;
	struct cftype___84 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___84 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___84 *updated_children;
	struct cgroup___84 *updated_next;
};

struct cgroup_root___84 {
	struct kernfs_root___104 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___84 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___84 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___84 *ss;
	struct list_head node;
	struct kernfs_ops___104 *kf_ops;
	int (*open)(struct kernfs_open_file___104 *);
	void (*release)(struct kernfs_open_file___104 *);
	u64 (*read_u64)(struct cgroup_subsys_state___84 *, struct cftype___84 *);
	s64 (*read_s64)(struct cgroup_subsys_state___84 *, struct cftype___84 *);
	int (*seq_show)(struct seq_file___100 *, void *);
	void * (*seq_start)(struct seq_file___100 *, loff_t *);
	void * (*seq_next)(struct seq_file___100 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___100 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___84 *, struct cftype___84 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___84 *, struct cftype___84 *, s64);
	ssize_t (*write)(struct kernfs_open_file___104 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___104 *, struct poll_table_struct___78 *);
};

struct perf_cpu_context___61;

struct perf_output_handle___61;

struct pmu___61 {
	struct list_head entry;
	struct module___102 *module;
	struct device___86 *dev;
	const struct attribute_group___104 **attr_groups;
	const struct attribute_group___104 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___61 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___61 *);
	void (*pmu_disable)(struct pmu___61 *);
	int (*event_init)(struct perf_event___61 *);
	void (*event_mapped)(struct perf_event___61 *, struct mm_struct___116 *);
	void (*event_unmapped)(struct perf_event___61 *, struct mm_struct___116 *);
	int (*add)(struct perf_event___61 *, int);
	void (*del)(struct perf_event___61 *, int);
	void (*start)(struct perf_event___61 *, int);
	void (*stop)(struct perf_event___61 *, int);
	void (*read)(struct perf_event___61 *);
	void (*start_txn)(struct pmu___61 *, unsigned int);
	int (*commit_txn)(struct pmu___61 *);
	void (*cancel_txn)(struct pmu___61 *);
	int (*event_idx)(struct perf_event___61 *);
	void (*sched_task)(struct perf_event_context___61 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___61 *, struct perf_event_context___61 *);
	void * (*setup_aux)(struct perf_event___61 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___61 *, struct perf_output_handle___61 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___61 *);
	int (*aux_output_match)(struct perf_event___61 *);
	int (*filter_match)(struct perf_event___61 *);
	int (*check_period)(struct perf_event___61 *, u64);
};

struct perf_cpu_context___61 {
	struct perf_event_context___61 ctx;
	struct perf_event_context___61 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___61 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___61 **heap;
	struct perf_event___61 *heap_default[2];
};

struct perf_output_handle___61 {
	struct perf_event___61 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___61 {
	struct cgroup_subsys_state___84 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___55 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___55 *);
	};
};

struct trace_event_class___55 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___55 *, enum trace_reg, void *);
	struct trace_event_fields___55 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___55 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___55 *);
};

struct syscall_metadata___29 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___55 *enter_event;
	struct trace_event_call___55 *exit_event;
};

struct block_device_operations___50;

struct gendisk___50 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___51 *part0;
	const struct block_device_operations___50 *fops;
	struct request_queue___50 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___49 *bdi;
	struct kobject___104 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___104 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___50 {
	struct bio___50 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___61 *bip_vec;
	struct bio_vec___61 bip_inline_vecs[0];
};

struct blkcg___49;

struct blkg_policy_data___49;

struct blkcg_gq___49 {
	struct request_queue___50 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___49 *blkcg;
	struct blkcg_gq___49 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___49 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___50 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___50(struct request___50 *);

typedef void integrity_complete_fn___50(struct request___50 *, unsigned int);

struct blk_integrity_profile___50 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___50 *prepare_fn;
	integrity_complete_fn___50 *complete_fn;
	const char *name;
};

struct block_device_operations___50 {
	blk_qc_t (*submit_bio)(struct bio___50 *);
	int (*open)(struct block_device___51 *, fmode_t);
	void (*release)(struct gendisk___50 *, fmode_t);
	int (*rw_page)(struct block_device___51 *, sector_t, struct page___115 *, unsigned int);
	int (*ioctl)(struct block_device___51 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___51 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___50 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___50 *);
	int (*getgeo)(struct block_device___51 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___51 *, bool);
	void (*swap_slot_free_notify)(struct block_device___51 *, long unsigned int);
	int (*report_zones)(struct gendisk___50 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___50 *, umode_t *);
	struct module___102 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___50 *, sector_t *);
};

typedef void rq_end_io_fn___50(struct request___50 *, blk_status_t);

struct request___50 {
	struct request_queue___50 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___49 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___50 *bio;
	struct bio___50 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___61 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___50 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___50 *saved_end_io;
		} flush;
	};
	struct gendisk___50 *rq_disk;
	struct block_device___51 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___50 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___49 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___50 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___104 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___110 *debugfs_dir;
	struct dentry___110 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___50;

struct elevator_mq_ops___50 {
	int (*init_sched)(struct request_queue___50 *, struct elevator_type___50 *);
	void (*exit_sched)(struct elevator_queue___50 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___49 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___49 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___49 *);
	bool (*allow_merge)(struct request_queue___50 *, struct request___50 *, struct bio___50 *);
	bool (*bio_merge)(struct request_queue___50 *, struct bio___50 *, unsigned int);
	int (*request_merge)(struct request_queue___50 *, struct request___50 **, struct bio___50 *);
	void (*request_merged)(struct request_queue___50 *, struct request___50 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___50 *, struct request___50 *, struct request___50 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___50 *);
	void (*finish_request)(struct request___50 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___49 *, struct list_head *, bool);
	struct request___50 * (*dispatch_request)(struct blk_mq_hw_ctx___49 *);
	bool (*has_work)(struct blk_mq_hw_ctx___49 *);
	void (*completed_request)(struct request___50 *, u64);
	void (*requeue_request)(struct request___50 *);
	struct request___50 * (*former_request)(struct request_queue___50 *, struct request___50 *);
	struct request___50 * (*next_request)(struct request_queue___50 *, struct request___50 *);
	void (*init_icq)(struct io_cq___50 *);
	void (*exit_icq)(struct io_cq___50 *);
};

struct elv_fs_entry___50;

struct elevator_type___50 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___50 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___50 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___102 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___50 {
	struct elevator_type___50 *type;
	void *elevator_data;
	struct kobject___104 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___50 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___50 *, char *);
	ssize_t (*store)(struct elevator_queue___50 *, const char *, size_t);
};

struct blk_mq_queue_data___49;

struct blk_mq_ops___49 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___49 *, const struct blk_mq_queue_data___49 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___49 *);
	int (*get_budget)(struct request_queue___50 *);
	void (*put_budget)(struct request_queue___50 *, int);
	void (*set_rq_budget_token)(struct request___50 *, int);
	int (*get_rq_budget_token)(struct request___50 *);
	enum blk_eh_timer_return (*timeout)(struct request___50 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___49 *);
	void (*complete)(struct request___50 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___49 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___49 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___49 *, struct request___50 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___49 *, struct request___50 *, unsigned int);
	void (*initialize_rq_fn)(struct request___50 *);
	void (*cleanup_rq)(struct request___50 *);
	bool (*busy)(struct request_queue___50 *);
	int (*map_queues)(struct blk_mq_tag_set___49 *);
	void (*show_rq)(struct seq_file___100 *, struct request___50 *);
};

struct blk_mq_tag_set___49 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___49 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___49 {
	struct request___50 *rq;
	bool last;
};

struct blkcg_policy_data___49;

struct blkcg___49 {
	struct cgroup_subsys_state___84 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___49 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___49 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___49 {
	struct blkcg___49 *blkcg;
	int plid;
};

struct blkg_policy_data___49 {
	struct blkcg_gq___49 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___44 {
	struct mem_cgroup___44 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___44 {
	struct lruvec___50 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___44 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___44 *memcg;
};

struct obj_cgroup___44 {
	struct percpu_ref refcnt;
	struct mem_cgroup___44 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct mountpoint___12;

struct mount___12 {
	struct hlist_node mnt_hash;
	struct mount___12 *mnt_parent;
	struct dentry___110 *mnt_mountpoint;
	struct vfsmount___110 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___12 *mnt_master;
	struct mnt_namespace___12 *mnt_ns;
	struct mountpoint___12 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___12 {
	struct hlist_node m_hash;
	struct dentry___110 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct fanotify_event___2 {
	struct fsnotify_event fse;
	struct hlist_node merge_list;
	u32 mask;
	struct {
		unsigned int type: 3;
		unsigned int hash: 29;
	};
	struct pid___98 *pid;
};

struct fanotify_fid_event___2 {
	struct fanotify_event___2 fae;
	__kernel_fsid_t fsid;
	struct fanotify_fh object_fh;
	unsigned char _inline_fh_buf[12];
};

struct fanotify_name_event___2 {
	struct fanotify_event___2 fae;
	__kernel_fsid_t fsid;
	struct fanotify_info info;
};

struct fanotify_path_event___2 {
	struct fanotify_event___2 fae;
	struct path___110 path;
};

struct fanotify_perm_event___2 {
	struct fanotify_event___2 fae;
	struct path___110 path;
	short unsigned int response;
	short unsigned int state;
	int fd;
};

struct epoll_event {
	__poll_t events;
	__u64 data;
};

struct epoll_filefd {
	struct file___91 *file;
	int fd;
} __attribute__((packed));

struct epitem;

struct eppoll_entry {
	struct eppoll_entry *next;
	struct epitem *base;
	wait_queue_entry_t wait;
	wait_queue_head_t *whead;
};

struct eventpoll;

struct epitem {
	union {
		struct rb_node rbn;
		struct callback_head rcu;
	};
	struct list_head rdllink;
	struct epitem *next;
	struct epoll_filefd ffd;
	struct eppoll_entry *pwqlist;
	struct eventpoll *ep;
	struct hlist_node fllink;
	struct wakeup_source___77 *ws;
	struct epoll_event event;
};

struct eventpoll {
	struct mutex mtx;
	wait_queue_head_t wq;
	wait_queue_head_t poll_wait;
	struct list_head rdllist;
	rwlock_t lock;
	struct rb_root_cached rbr;
	struct epitem *ovflist;
	struct wakeup_source___77 *ws;
	struct user_struct *user;
	struct file___91 *file;
	u64 gen;
	struct hlist_head refs;
	unsigned int napi_id;
};

struct ep_pqueue {
	poll_table___17 pt;
	struct epitem *epi;
};

struct epitems_head {
	struct hlist_head epitems;
	struct epitems_head *next;
};

struct fs_context___19;

struct dentry___111;

struct super_block___111;

struct module___103;

struct file_system_type___111 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___19 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___111 * (*mount)(struct file_system_type___111 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___111 *);
	struct module___103 *owner;
	struct file_system_type___111 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___111;

struct kiocb___111;

struct poll_table_struct___79;

struct vm_area_struct___116;

struct inode___111;

struct file_lock___111;

struct page___116;

struct file_operations___111 {
	struct module___103 *owner;
	loff_t (*llseek)(struct file___111 *, loff_t, int);
	ssize_t (*read)(struct file___111 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___111 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___111 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___111 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___111 *, bool);
	int (*iterate)(struct file___111 *, struct dir_context *);
	int (*iterate_shared)(struct file___111 *, struct dir_context *);
	__poll_t (*poll)(struct file___111 *, struct poll_table_struct___79 *);
	long int (*unlocked_ioctl)(struct file___111 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___111 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___111 *, struct vm_area_struct___116 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___111 *, struct file___111 *);
	int (*flush)(struct file___111 *, fl_owner_t);
	int (*release)(struct inode___111 *, struct file___111 *);
	int (*fsync)(struct file___111 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___111 *, int);
	int (*lock)(struct file___111 *, int, struct file_lock___111 *);
	ssize_t (*sendpage)(struct file___111 *, struct page___116 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___111 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___111 *, long unsigned int);
	int (*flock)(struct file___111 *, int, struct file_lock___111 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___111 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___111 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___111 *, long int, struct file_lock___111 **, void **);
	long int (*fallocate)(struct file___111 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___111 *);
	ssize_t (*copy_file_range)(struct file___111 *, loff_t, struct file___111 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___111 *, loff_t, struct file___111 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___111 *, loff_t, loff_t, int);
};

struct vmacache___116 {
	u64 seqnum;
	struct vm_area_struct___116 *vmas[4];
};

struct page_frag___116 {
	struct page___116 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___117;

struct signal_struct___112;

struct task_struct___118 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___118 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___117 *mm;
	struct mm_struct___117 *active_mm;
	struct vmacache___116 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___118 *real_parent;
	struct task_struct___118 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___118 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___41 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___112 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___118 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___22 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___116 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___118 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___31 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___105;

struct kobj_type___105;

struct kernfs_node___105;

struct kobject___105 {
	const char *name;
	struct list_head entry;
	struct kobject___105 *parent;
	struct kset___105 *kset;
	struct kobj_type___105 *ktype;
	struct kernfs_node___105 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___102 {
	struct kobject___105 kobj;
	struct module___103 *mod;
	struct kobject___105 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___102 {
	struct module___103 *mod;
	struct latch_tree_node node;
};

struct module_layout___102 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___102 mtn;
};

struct module_attribute___102;

struct kernel_param___102;

struct module___103 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___102 mkobj;
	struct module_attribute___102 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___105 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___102 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___102 core_layout;
	struct module_layout___102 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___116 *pgtable_t___116;

struct address_space___111;

struct dev_pagemap___110;

struct page___116 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___111 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___12 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___116 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___116 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___117 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___110 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___110;

struct vm_area_struct___116 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___116 *vm_next;
	struct vm_area_struct___116 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___117 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___110 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___111 *vm_file;
	struct file___111 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___112 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___118 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___118 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___41 *pids[4];
	struct pid___41 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___117 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___116;

struct mm_struct___117 {
	struct {
		struct vm_area_struct___116 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___111 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___116 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___118 *owner;
		struct user_namespace *user_ns;
		struct file___111 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___111;

struct address_space___111 {
	struct inode___111 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___111 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___110;

struct dev_pagemap___110 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___110 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___111;

struct path___111 {
	struct vfsmount___111 *mnt;
	struct dentry___111 *dentry;
};

struct file___111 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___111 f_path;
	struct inode___111 *f_inode;
	const struct file_operations___111 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___98 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___111 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___110;

struct vm_operations_struct___110 {
	void (*open)(struct vm_area_struct___116 *);
	void (*close)(struct vm_area_struct___116 *);
	int (*may_split)(struct vm_area_struct___116 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___116 *);
	int (*mprotect)(struct vm_area_struct___116 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___110 *);
	vm_fault_t (*huge_fault)(struct vm_fault___110 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___110 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___116 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___110 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___110 *);
	int (*access)(struct vm_area_struct___116 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___116 *);
	int (*set_policy)(struct vm_area_struct___116 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___116 *, long unsigned int);
	struct page___116 * (*find_special_page)(struct vm_area_struct___116 *, long unsigned int);
};

struct core_thread___116 {
	struct task_struct___118 *task;
	struct core_thread___116 *next;
};

struct core_state___116 {
	atomic_t nr_threads;
	struct core_thread___116 dumper;
	struct completion startup;
};

struct vm_fault___110 {
	const struct {
		struct vm_area_struct___116 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___116 *cow_page;
	struct page___116 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___116 prealloc_pte;
};

struct dentry_operations___111;

struct dentry___111 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___111 *d_parent;
	struct qstr d_name;
	struct inode___111 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___111 *d_op;
	struct super_block___111 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___111;

struct inode___111 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___111 *i_op;
	struct super_block___111 *i_sb;
	struct address_space___111 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___111 *i_fop;
		void (*free_inode)(struct inode___111 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___111 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___17 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___111 {
	int (*d_revalidate)(struct dentry___111 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___111 *, unsigned int);
	int (*d_hash)(const struct dentry___111 *, struct qstr *);
	int (*d_compare)(const struct dentry___111 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___111 *);
	int (*d_init)(struct dentry___111 *);
	void (*d_release)(struct dentry___111 *);
	void (*d_prune)(struct dentry___111 *);
	void (*d_iput)(struct dentry___111 *, struct inode___111 *);
	char * (*d_dname)(struct dentry___111 *, char *, int);
	struct vfsmount___111 * (*d_automount)(struct path___111 *);
	int (*d_manage)(const struct path___111 *, bool);
	struct dentry___111 * (*d_real)(struct dentry___111 *, const struct inode___111 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___111;

struct mem_dqinfo___111 {
	struct quota_format_type___111 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___111;

struct quota_info___111 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___111 *files[3];
	struct mem_dqinfo___111 info[3];
	const struct quota_format_ops___111 *ops[3];
};

struct rcuwait___112 {
	struct task_struct___118 *task;
};

struct percpu_rw_semaphore___112 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___112 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___111 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___112 rw_sem[3];
};

struct super_operations___111;

struct dquot_operations___111;

struct quotactl_ops___111;

struct super_block___111 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___111 *s_type;
	const struct super_operations___111 *s_op;
	const struct dquot_operations___111 *dq_op;
	const struct quotactl_ops___111 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___111 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___111 s_dquot;
	struct sb_writers___111 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___111 *s_d_op;
	int cleancache_poolid;
	struct shrinker___20 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___111 {
	struct dentry___111 *mnt_root;
	struct super_block___111 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___111 {
	struct file___111 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___111 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___22 *ki_waitq;
	};
};

struct iattr___111 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___111 *ia_file;
};

struct dquot___111 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___111 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___111 {
	int qf_fmt_id;
	const struct quota_format_ops___111 *qf_ops;
	struct module___103 *qf_owner;
	struct quota_format_type___111 *qf_next;
};

struct quota_format_ops___111 {
	int (*check_quota_file)(struct super_block___111 *, int);
	int (*read_file_info)(struct super_block___111 *, int);
	int (*write_file_info)(struct super_block___111 *, int);
	int (*free_file_info)(struct super_block___111 *, int);
	int (*read_dqblk)(struct dquot___111 *);
	int (*commit_dqblk)(struct dquot___111 *);
	int (*release_dqblk)(struct dquot___111 *);
	int (*get_next_id)(struct super_block___111 *, struct kqid *);
};

struct dquot_operations___111 {
	int (*write_dquot)(struct dquot___111 *);
	struct dquot___111 * (*alloc_dquot)(struct super_block___111 *, int);
	void (*destroy_dquot)(struct dquot___111 *);
	int (*acquire_dquot)(struct dquot___111 *);
	int (*release_dquot)(struct dquot___111 *);
	int (*mark_dirty)(struct dquot___111 *);
	int (*write_info)(struct super_block___111 *, int);
	qsize_t * (*get_reserved_space)(struct inode___111 *);
	int (*get_projid)(struct inode___111 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___111 *, qsize_t *);
	int (*get_next_id)(struct super_block___111 *, struct kqid *);
};

struct quotactl_ops___111 {
	int (*quota_on)(struct super_block___111 *, int, int, const struct path___111 *);
	int (*quota_off)(struct super_block___111 *, int);
	int (*quota_enable)(struct super_block___111 *, unsigned int);
	int (*quota_disable)(struct super_block___111 *, unsigned int);
	int (*quota_sync)(struct super_block___111 *, int);
	int (*set_info)(struct super_block___111 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___111 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___111 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___111 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___111 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___111 *, unsigned int);
};

struct address_space_operations___111 {
	int (*writepage)(struct page___116 *, struct writeback_control___3 *);
	int (*readpage)(struct file___111 *, struct page___116 *);
	int (*writepages)(struct address_space___111 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___116 *);
	int (*readpages)(struct file___111 *, struct address_space___111 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___111 *, struct address_space___111 *, loff_t, unsigned int, unsigned int, struct page___116 **, void **);
	int (*write_end)(struct file___111 *, struct address_space___111 *, loff_t, unsigned int, unsigned int, struct page___116 *, void *);
	sector_t (*bmap)(struct address_space___111 *, sector_t);
	void (*invalidatepage)(struct page___116 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___116 *, gfp_t);
	void (*freepage)(struct page___116 *);
	ssize_t (*direct_IO)(struct kiocb___111 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___111 *, struct page___116 *, struct page___116 *, enum migrate_mode);
	bool (*isolate_page)(struct page___116 *, isolate_mode_t);
	void (*putback_page)(struct page___116 *);
	int (*launder_page)(struct page___116 *);
	int (*is_partially_uptodate)(struct page___116 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___116 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___111 *, struct page___116 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___111 *, sector_t *);
	void (*swap_deactivate)(struct file___111 *);
};

struct inode_operations___111 {
	struct dentry___111 * (*lookup)(struct inode___111 *, struct dentry___111 *, unsigned int);
	const char * (*get_link)(struct dentry___111 *, struct inode___111 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___111 *, int);
	struct posix_acl * (*get_acl)(struct inode___111 *, int, bool);
	int (*readlink)(struct dentry___111 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___111 *, struct dentry___111 *, umode_t, bool);
	int (*link)(struct dentry___111 *, struct inode___111 *, struct dentry___111 *);
	int (*unlink)(struct inode___111 *, struct dentry___111 *);
	int (*symlink)(struct user_namespace *, struct inode___111 *, struct dentry___111 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___111 *, struct dentry___111 *, umode_t);
	int (*rmdir)(struct inode___111 *, struct dentry___111 *);
	int (*mknod)(struct user_namespace *, struct inode___111 *, struct dentry___111 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___111 *, struct dentry___111 *, struct inode___111 *, struct dentry___111 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___111 *, struct iattr___111 *);
	int (*getattr)(struct user_namespace *, const struct path___111 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___111 *, char *, size_t);
	int (*fiemap)(struct inode___111 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___111 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___111 *, struct dentry___111 *, struct file___111 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___111 *, struct dentry___111 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___111 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___111 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___111 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___111 {
	void (*fl_copy_lock)(struct file_lock___111 *, struct file_lock___111 *);
	void (*fl_release_private)(struct file_lock___111 *);
};

struct fasync_struct___111;

struct lock_manager_operations___111;

struct file_lock___111 {
	struct file_lock___111 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___111 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___111 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___111 *fl_ops;
	const struct lock_manager_operations___111 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___111 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___111 *);
	int (*lm_grant)(struct file_lock___111 *, int);
	bool (*lm_break)(struct file_lock___111 *);
	int (*lm_change)(struct file_lock___111 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___111 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___111 *);
};

struct fasync_struct___111 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___111 *fa_next;
	struct file___111 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___111 {
	struct inode___111 * (*alloc_inode)(struct super_block___111 *);
	void (*destroy_inode)(struct inode___111 *);
	void (*free_inode)(struct inode___111 *);
	void (*dirty_inode)(struct inode___111 *, int);
	int (*write_inode)(struct inode___111 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___111 *);
	void (*evict_inode)(struct inode___111 *);
	void (*put_super)(struct super_block___111 *);
	int (*sync_fs)(struct super_block___111 *, int);
	int (*freeze_super)(struct super_block___111 *);
	int (*freeze_fs)(struct super_block___111 *);
	int (*thaw_super)(struct super_block___111 *);
	int (*unfreeze_fs)(struct super_block___111 *);
	int (*statfs)(struct dentry___111 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___111 *, int *, char *);
	void (*umount_begin)(struct super_block___111 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___111 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___111 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___111 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___111 *);
	ssize_t (*quota_read)(struct super_block___111 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___111 *, int, const char *, size_t, loff_t);
	struct dquot___111 ** (*get_dquots)(struct inode___111 *);
	long int (*nr_cached_objects)(struct super_block___111 *, struct shrink_control___20 *);
	long int (*free_cached_objects)(struct super_block___111 *, struct shrink_control___20 *);
	struct file___111 * (*real_loop)(struct file___111 *);
};

typedef void (*poll_queue_proc___79)(struct file___111 *, wait_queue_head_t *, struct poll_table_struct___79 *);

struct poll_table_struct___79 {
	poll_queue_proc___79 _qproc;
	__poll_t _key;
};

struct fc_log___19;

struct p_log___19 {
	const char *prefix;
	struct fc_log___19 *log;
};

struct fs_context_operations___19;

struct fs_context___19 {
	const struct fs_context_operations___19 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___111 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___111 *root;
	struct user_namespace *user_ns;
	struct net *net_ns;
	const struct cred___3 *cred;
	struct p_log___19 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___105;

struct kernfs_elem_dir___105 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___105 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___105;

struct kernfs_root___105 {
	struct kernfs_node___105 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___105 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___105 {
	struct kernfs_node___105 *target_kn;
};

struct kernfs_ops___105;

struct kernfs_elem_attr___105 {
	const struct kernfs_ops___105 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___105 *notify_next;
};

struct kernfs_node___105 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___105 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___105 dir;
		struct kernfs_elem_symlink___105 symlink;
		struct kernfs_elem_attr___105 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___105;

struct kernfs_ops___105 {
	int (*open)(struct kernfs_open_file___105 *);
	void (*release)(struct kernfs_open_file___105 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___105 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___105 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___105 *, struct poll_table_struct___79 *);
	int (*mmap)(struct kernfs_open_file___105 *, struct vm_area_struct___116 *);
};

struct kernfs_syscall_ops___105 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___105 *);
	int (*mkdir)(struct kernfs_node___105 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___105 *);
	int (*rename)(struct kernfs_node___105 *, struct kernfs_node___105 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___105 *, struct kernfs_root___105 *);
};

struct kernfs_open_file___105 {
	struct kernfs_node___105 *kn;
	struct file___111 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___110 *vm_ops;
};

struct bin_attribute___105;

struct attribute_group___105 {
	const char *name;
	umode_t (*is_visible)(struct kobject___105 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___105 *, struct bin_attribute___105 *, int);
	struct attribute **attrs;
	struct bin_attribute___105 **bin_attrs;
};

struct bin_attribute___105 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___111 * (*f_mapping)();
	ssize_t (*read)(struct file___111 *, struct kobject___105 *, struct bin_attribute___105 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___111 *, struct kobject___105 *, struct bin_attribute___105 *, char *, loff_t, size_t);
	int (*mmap)(struct file___111 *, struct kobject___105 *, struct bin_attribute___105 *, struct vm_area_struct___116 *);
};

struct sysfs_ops___105 {
	ssize_t (*show)(struct kobject___105 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___105 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___105;

struct kset___105 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___105 kobj;
	const struct kset_uevent_ops___105 *uevent_ops;
};

struct kobj_type___105 {
	void (*release)(struct kobject___105 *);
	const struct sysfs_ops___105 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___105 **default_groups;
	const struct kobj_ns_type_operations___3 * (*child_ns_type)(struct kobject___105 *);
	const void * (*namespace)(struct kobject___105 *);
	void (*get_ownership)(struct kobject___105 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___105 {
	int (* const filter)(struct kset___105 *, struct kobject___105 *);
	const char * (* const name)(struct kset___105 *, struct kobject___105 *);
	int (* const uevent)(struct kset___105 *, struct kobject___105 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___102 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___102 *);
	int (*get)(char *, const struct kernel_param___102 *);
	void (*free)(void *);
};

struct kparam_array___102;

struct kernel_param___102 {
	const char *name;
	struct module___103 *mod;
	const struct kernel_param_ops___102 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___102 *arr;
	};
};

struct kparam_array___102 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___102 *ops;
	void *elem;
};

struct module_attribute___102 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___102 *, struct module_kobject___102 *, char *);
	ssize_t (*store)(struct module_attribute___102 *, struct module_kobject___102 *, const char *, size_t);
	void (*setup)(struct module___103 *, const char *);
	int (*test)(struct module___103 *);
	void (*free)(struct module___103 *);
};

struct dev_pagemap_ops___110 {
	void (*page_free)(struct page___116 *);
	void (*kill)(struct dev_pagemap___110 *);
	void (*cleanup)(struct dev_pagemap___110 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___110 *);
};

struct fs_parameter___19 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___111 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___19 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___103 *owner;
	char *buffer[8];
};

struct fs_context_operations___19 {
	void (*free)(struct fs_context___19 *);
	int (*dup)(struct fs_context___19 *, struct fs_context___19 *);
	int (*parse_param)(struct fs_context___19 *, struct fs_parameter___19 *);
	int (*parse_monolithic)(struct fs_context___19 *, void *);
	int (*get_tree)(struct fs_context___19 *);
	int (*reconfigure)(struct fs_context___19 *);
};

struct pseudo_fs_context___7 {
	const struct super_operations___111 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___111 *dops;
	long unsigned int magic;
};

typedef struct poll_table_struct___23 poll_table___20;

struct signalfd_siginfo {
	__u32 ssi_signo;
	__s32 ssi_errno;
	__s32 ssi_code;
	__u32 ssi_pid;
	__u32 ssi_uid;
	__s32 ssi_fd;
	__u32 ssi_tid;
	__u32 ssi_band;
	__u32 ssi_overrun;
	__u32 ssi_trapno;
	__s32 ssi_status;
	__s32 ssi_int;
	__u64 ssi_ptr;
	__u64 ssi_utime;
	__u64 ssi_stime;
	__u64 ssi_addr;
	__u16 ssi_addr_lsb;
	__u16 __pad2;
	__s32 ssi_syscall;
	__u64 ssi_call_addr;
	__u32 ssi_arch;
	__u8 __pad[28];
};

struct signalfd_ctx {
	sigset_t sigmask;
};

struct timerfd_ctx {
	union {
		struct hrtimer tmr;
		struct alarm alarm;
	} t;
	ktime_t tintv;
	ktime_t moffs;
	wait_queue_head_t wqh;
	u64 ticks;
	int clockid;
	short unsigned int expired;
	short unsigned int settime_flags;
	struct callback_head rcu;
	struct list_head clist;
	spinlock_t cancel_lock;
	bool might_cancel;
};

struct eventfd_ctx___2 {
	struct kref kref;
	wait_queue_head_t wqh;
	__u64 count;
	unsigned int flags;
	int id;
};

struct userfaultfd_ctx {
	wait_queue_head_t fault_pending_wqh;
	wait_queue_head_t fault_wqh;
	wait_queue_head_t fd_wqh;
	wait_queue_head_t event_wqh;
	seqcount_spinlock_t refile_seq;
	refcount_t refcount;
	unsigned int flags;
	unsigned int features;
	bool released;
	atomic_t mmap_changing;
	struct mm_struct___46 *mm;
};

typedef struct poll_table_struct___33 poll_table___21;

struct uffd_msg {
	__u8 event;
	__u8 reserved1;
	__u16 reserved2;
	__u32 reserved3;
	union {
		struct {
			__u64 flags;
			__u64 address;
			union {
				__u32 ptid;
			} feat;
		} pagefault;
		struct {
			__u32 ufd;
		} fork;
		struct {
			__u64 from;
			__u64 to;
			__u64 len;
		} remap;
		struct {
			__u64 start;
			__u64 end;
		} remove;
		struct {
			__u64 reserved1;
			__u64 reserved2;
			__u64 reserved3;
		} reserved;
	} arg;
};

struct uffdio_api {
	__u64 api;
	__u64 features;
	__u64 ioctls;
};

struct uffdio_range {
	__u64 start;
	__u64 len;
};

struct uffdio_register {
	struct uffdio_range range;
	__u64 mode;
	__u64 ioctls;
};

struct uffdio_copy {
	__u64 dst;
	__u64 src;
	__u64 len;
	__u64 mode;
	__s64 copy;
};

struct uffdio_zeropage {
	struct uffdio_range range;
	__u64 mode;
	__s64 zeropage;
};

struct uffdio_writeprotect {
	struct uffdio_range range;
	__u64 mode;
};

struct uffdio_continue {
	struct uffdio_range range;
	__u64 mode;
	__s64 mapped;
};

struct userfaultfd_fork_ctx {
	struct userfaultfd_ctx *orig;
	struct userfaultfd_ctx *new;
	struct list_head list;
};

struct userfaultfd_unmap_ctx {
	struct userfaultfd_ctx *ctx;
	long unsigned int start;
	long unsigned int end;
	struct list_head list;
};

struct userfaultfd_wait_queue {
	struct uffd_msg msg;
	wait_queue_entry_t wq;
	struct userfaultfd_ctx *ctx;
	bool waken;
};

struct userfaultfd_wake_range {
	long unsigned int start;
	long unsigned int len;
};

typedef u32 compat_aio_context_t;

struct hrtimer_sleeper___4 {
	struct hrtimer timer;
	struct task_struct___79 *task;
};

struct kioctx;

struct kioctx_table {
	struct callback_head rcu;
	unsigned int nr;
	struct kioctx *table[0];
};

typedef __kernel_ulong_t aio_context_t;

enum {
	IOCB_CMD_PREAD = 0,
	IOCB_CMD_PWRITE = 1,
	IOCB_CMD_FSYNC = 2,
	IOCB_CMD_FDSYNC = 3,
	IOCB_CMD_POLL = 5,
	IOCB_CMD_NOOP = 6,
	IOCB_CMD_PREADV = 7,
	IOCB_CMD_PWRITEV = 8,
};

struct io_event {
	__u64 data;
	__u64 obj;
	__s64 res;
	__s64 res2;
};

struct iocb {
	__u64 aio_data;
	__u32 aio_key;
	__kernel_rwf_t aio_rw_flags;
	__u16 aio_lio_opcode;
	__s16 aio_reqprio;
	__u32 aio_fildes;
	__u64 aio_buf;
	__u64 aio_nbytes;
	__s64 aio_offset;
	__u64 aio_reserved2;
	__u32 aio_flags;
	__u32 aio_resfd;
};

typedef int kiocb_cancel_fn(struct kiocb___72 *);

struct pseudo_fs_context___8 {
	const struct super_operations___72 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___72 *dops;
	long unsigned int magic;
};

struct aio_ring {
	unsigned int id;
	unsigned int nr;
	unsigned int head;
	unsigned int tail;
	unsigned int magic;
	unsigned int compat_features;
	unsigned int incompat_features;
	unsigned int header_length;
	struct io_event io_events[0];
};

struct kioctx_cpu;

struct ctx_rq_wait;

struct kioctx {
	struct percpu_ref users;
	atomic_t dead;
	struct percpu_ref reqs;
	long unsigned int user_id;
	struct kioctx_cpu *cpu;
	unsigned int req_batch;
	unsigned int max_reqs;
	unsigned int nr_events;
	long unsigned int mmap_base;
	long unsigned int mmap_size;
	struct page___77 **ring_pages;
	long int nr_pages;
	struct rcu_work free_rwork;
	struct ctx_rq_wait *rq_wait;
	long: 64;
	long: 64;
	long: 64;
	struct {
		atomic_t reqs_available;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		spinlock_t ctx_lock;
		struct list_head active_reqs;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		struct mutex ring_lock;
		wait_queue_head_t wait;
		long: 64;
	};
	struct {
		unsigned int tail;
		unsigned int completed_events;
		spinlock_t completion_lock;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct page___77 *internal_pages[8];
	struct file___72 *aio_ring_file;
	unsigned int id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kioctx_cpu {
	unsigned int reqs_available;
};

struct ctx_rq_wait {
	struct completion comp;
	atomic_t count;
};

struct fsync_iocb {
	struct file___72 *file;
	struct work_struct work;
	bool datasync;
	struct cred___11 *creds;
};

struct poll_iocb {
	struct file___72 *file;
	struct wait_queue_head *head;
	__poll_t events;
	bool cancelled;
	bool work_scheduled;
	bool work_need_resched;
	struct wait_queue_entry wait;
	struct work_struct work;
};

struct aio_kiocb {
	union {
		struct file___72 *ki_filp;
		struct kiocb___72 rw;
		struct fsync_iocb fsync;
		struct poll_iocb poll;
	};
	struct kioctx *ki_ctx;
	kiocb_cancel_fn *ki_cancel;
	struct io_event ki_res;
	struct list_head ki_list;
	refcount_t ki_refcnt;
	struct eventfd_ctx *ki_eventfd;
};

struct aio_poll_table {
	struct poll_table_struct___54 pt;
	struct aio_kiocb *iocb;
	bool queued;
	int error;
};

struct __aio_sigset {
	const sigset_t *sigmask;
	size_t sigsetsize;
};

struct __compat_aio_sigset {
	compat_uptr_t sigmask;
	compat_size_t sigsetsize;
};

struct dentry___112;

struct super_block___112;

struct module___104;

struct file_system_type___112 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___112 * (*mount)(struct file_system_type___112 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___112 *);
	struct module___104 *owner;
	struct file_system_type___112 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___112;

struct kiocb___112;

struct iov_iter___64;

struct poll_table_struct___80;

struct vm_area_struct___117;

struct inode___112;

struct file_lock___112;

struct page___117;

struct pipe_inode_info___39;

struct seq_file___101;

struct file_operations___112 {
	struct module___104 *owner;
	loff_t (*llseek)(struct file___112 *, loff_t, int);
	ssize_t (*read)(struct file___112 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___112 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___112 *, struct iov_iter___64 *);
	ssize_t (*write_iter)(struct kiocb___112 *, struct iov_iter___64 *);
	int (*iopoll)(struct kiocb___112 *, bool);
	int (*iterate)(struct file___112 *, struct dir_context *);
	int (*iterate_shared)(struct file___112 *, struct dir_context *);
	__poll_t (*poll)(struct file___112 *, struct poll_table_struct___80 *);
	long int (*unlocked_ioctl)(struct file___112 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___112 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___112 *, struct vm_area_struct___117 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___112 *, struct file___112 *);
	int (*flush)(struct file___112 *, fl_owner_t);
	int (*release)(struct inode___112 *, struct file___112 *);
	int (*fsync)(struct file___112 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___112 *, int);
	int (*lock)(struct file___112 *, int, struct file_lock___112 *);
	ssize_t (*sendpage)(struct file___112 *, struct page___117 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___112 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___112 *, long unsigned int);
	int (*flock)(struct file___112 *, int, struct file_lock___112 *);
	ssize_t (*splice_write)(struct pipe_inode_info___39 *, struct file___112 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___112 *, loff_t *, struct pipe_inode_info___39 *, size_t, unsigned int);
	int (*setlease)(struct file___112 *, long int, struct file_lock___112 **, void **);
	long int (*fallocate)(struct file___112 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___101 *, struct file___112 *);
	ssize_t (*copy_file_range)(struct file___112 *, loff_t, struct file___112 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___112 *, loff_t, struct file___112 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___112 *, loff_t, loff_t, int);
};

struct vmacache___117 {
	u64 seqnum;
	struct vm_area_struct___117 *vmas[4];
};

struct page_frag___117 {
	struct page___117 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___62;

struct debug_info___62 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___62 *hbp_break[16];
	struct perf_event___62 *hbp_watch[16];
};

struct thread_struct___62 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___62 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___118;

struct pid___99;

struct files_struct___14;

struct nsproxy___105;

struct signal_struct___113;

struct bio_list___51;

struct backing_dev_info___50;

struct io_context___51;

struct css_set___85;

struct perf_event_context___62;

struct mem_cgroup___45;

struct request_queue___51;

struct vm_struct___103;

struct task_struct___119 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___119 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___118 *mm;
	struct mm_struct___118 *active_mm;
	struct vmacache___117 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___119 *real_parent;
	struct task_struct___119 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___119 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___99 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___3 *ptracer_cred;
	const struct cred___3 *real_cred;
	const struct cred___3 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___14 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___105 *nsproxy;
	struct signal_struct___113 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___119 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___51 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___50 *backing_dev_info;
	struct io_context___51 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___85 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___62 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___39 *splice_pipe;
	struct page_frag___117 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___45 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___45 *active_memcg;
	struct request_queue___51 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___119 *oom_reaper_list;
	struct vm_struct___103 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___106;

struct kobj_type___106;

struct kernfs_node___106;

struct kobject___106 {
	const char *name;
	struct list_head entry;
	struct kobject___106 *parent;
	struct kset___106 *kset;
	struct kobj_type___106 *ktype;
	struct kernfs_node___106 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___103 {
	struct kobject___106 kobj;
	struct module___104 *mod;
	struct kobject___106 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___103 {
	struct module___104 *mod;
	struct latch_tree_node node;
};

struct module_layout___103 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___103 mtn;
};

struct module_attribute___103;

struct kernel_param___103;

struct trace_event_call___56;

struct module___104 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___103 mkobj;
	struct module_attribute___103 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___106 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___103 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___103 core_layout;
	struct module_layout___103 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___56 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___62 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___119 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___62)(struct perf_event___62 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___62;

struct fasync_struct___112;

struct pid_namespace___99;

struct bpf_prog___21;

struct perf_cgroup___62;

struct perf_event___62 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___62 *group_leader;
	struct pmu___62 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___62 hw;
	struct perf_event_context___62 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___62 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___119 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___112 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___62 *aux_event;
	void (*destroy)(struct perf_event___62 *);
	struct callback_head callback_head;
	struct pid_namespace___99 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___62 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___62 orig_overflow_handler;
	struct bpf_prog___21 *prog;
	u64 bpf_cookie;
	struct trace_event_call___56 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___62 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___112;

struct dentry___112 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___112 *d_parent;
	struct qstr d_name;
	struct inode___112 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___112 *d_op;
	struct super_block___112 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___112;

struct address_space___112 {
	struct inode___112 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___112 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___112;

struct bdi_writeback___50;

struct inode___112 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___112 *i_op;
	struct super_block___112 *i_sb;
	struct address_space___112 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___50 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___112 *i_fop;
		void (*free_inode)(struct inode___112 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___112 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___112;

struct path___112;

struct dentry_operations___112 {
	int (*d_revalidate)(struct dentry___112 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___112 *, unsigned int);
	int (*d_hash)(const struct dentry___112 *, struct qstr *);
	int (*d_compare)(const struct dentry___112 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___112 *);
	int (*d_init)(struct dentry___112 *);
	void (*d_release)(struct dentry___112 *);
	void (*d_prune)(struct dentry___112 *);
	void (*d_iput)(struct dentry___112 *, struct inode___112 *);
	char * (*d_dname)(struct dentry___112 *, char *, int);
	struct vfsmount___112 * (*d_automount)(struct path___112 *);
	int (*d_manage)(const struct path___112 *, bool);
	struct dentry___112 * (*d_real)(struct dentry___112 *, const struct inode___112 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___112;

struct mem_dqinfo___112 {
	struct quota_format_type___112 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___112;

struct quota_info___112 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___112 *files[3];
	struct mem_dqinfo___112 info[3];
	const struct quota_format_ops___112 *ops[3];
};

struct rcuwait___113 {
	struct task_struct___119 *task;
};

struct percpu_rw_semaphore___113 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___113 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___112 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___113 rw_sem[3];
};

struct shrink_control___45;

struct shrinker___45 {
	long unsigned int (*count_objects)(struct shrinker___45 *, struct shrink_control___45 *);
	long unsigned int (*scan_objects)(struct shrinker___45 *, struct shrink_control___45 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___112;

struct dquot_operations___112;

struct quotactl_ops___112;

struct block_device___52;

struct super_block___112 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___112 *s_type;
	const struct super_operations___112 *s_op;
	const struct dquot_operations___112 *dq_op;
	const struct quotactl_ops___112 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___112 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___52 *s_bdev;
	struct backing_dev_info___50 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___112 s_dquot;
	struct sb_writers___112 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___112 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___112 {
	struct dentry___112 *mnt_root;
	struct super_block___112 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct path___112 {
	struct vfsmount___112 *mnt;
	struct dentry___112 *dentry;
};

typedef s32 compat_ssize_t;

struct upid___99 {
	int nr;
	struct pid_namespace___99 *ns;
};

struct pid_namespace___99 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___119 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___99 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___99 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___99 numbers[1];
};

typedef struct page___117 *pgtable_t___117;

struct page_pool___32;

struct dev_pagemap___111;

struct page___117 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___112 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___117 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___117 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___118 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___111 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___111;

struct vm_area_struct___117 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___117 *vm_next;
	struct vm_area_struct___117 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___118 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___111 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___112 *vm_file;
	struct file___112 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___113 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___119 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___119 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___99 *pids[4];
	struct pid___99 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___118 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___117;

struct mm_struct___118 {
	struct {
		struct vm_area_struct___117 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___112 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___117 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___119 *owner;
		struct user_namespace___4 *user_ns;
		struct file___112 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___14 {
	unsigned int max_fds;
	struct file___112 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___14 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___14 *fdt;
	struct fdtable___14 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___112 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct io_wq;

struct io_wq_work_node;

struct io_wq_work_list {
	struct io_wq_work_node *first;
	struct io_wq_work_node *last;
};

struct io_ring_ctx;

struct io_uring_task {
	int cached_refs;
	struct xarray xa;
	struct wait_queue_head wait;
	const struct io_ring_ctx *last;
	struct io_wq *io_wq;
	struct percpu_counter inflight;
	atomic_t inflight_tracked;
	atomic_t in_idle;
	spinlock_t task_lock;
	struct io_wq_work_list task_list;
	struct callback_head task_work;
	bool task_running;
};

struct net___24;

struct cgroup_namespace___85;

struct nsproxy___105 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___99 *pid_ns_for_children;
	struct net___24 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___85 *cgroup_ns;
};

struct bio___51;

struct bio_list___51 {
	struct bio___51 *head;
	struct bio___51 *tail;
};

struct cgroup_subsys_state___85;

struct bdi_writeback___50 {
	struct backing_dev_info___50 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___85 *memcg_css;
	struct cgroup_subsys_state___85 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___87;

struct backing_dev_info___50 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___50 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___87 *dev;
	char dev_name[64];
	struct device___87 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___112 *debug_dir;
};

struct io_cq___51;

struct io_context___51 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___51 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___85;

struct css_set___85 {
	struct cgroup_subsys_state___85 *subsys[14];
	refcount_t refcount;
	struct css_set___85 *dom_cset;
	struct cgroup___85 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___85 *mg_src_cgrp;
	struct cgroup___85 *mg_dst_cgrp;
	struct css_set___85 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___62 {
	struct pmu___62 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___119 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___62 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___39;

struct pipe_inode_info___39 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___117 *tmp_page;
	struct fasync_struct___112 *fasync_readers;
	struct fasync_struct___112 *fasync_writers;
	struct pipe_buffer___39 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___85;

struct cgroup_subsys_state___85 {
	struct cgroup___85 *cgroup;
	struct cgroup_subsys___85 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___85 *parent;
};

struct cgroup_file___85 {
	struct kernfs_node___106 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___45;

struct mem_cgroup_per_node___45;

struct mem_cgroup___45 {
	struct cgroup_subsys_state___85 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___85 events_file;
	struct cgroup_file___85 events_local_file;
	struct cgroup_file___85 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___45 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___119 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___45 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___51;

struct blk_integrity___51 {
	const struct blk_integrity_profile___51 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___51 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___51 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___51;

struct elevator_queue___51;

struct blk_mq_ops___50;

struct blk_mq_hw_ctx___50;

struct gendisk___51;

struct blkcg_gq___50;

struct blk_mq_tag_set___50;

struct request_queue___51 {
	struct request___51 *last_merge;
	struct elevator_queue___51 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___50 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___50 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___51 *disk;
	struct kobject___106 kobj;
	struct kobject___106 *mq_kobj;
	struct blk_integrity___51 integrity;
	struct device___87 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___50 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___50 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___51 bio_split;
	struct dentry___112 *debugfs_dir;
	struct dentry___112 *sched_debugfs_dir;
	struct dentry___112 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___103 {
	struct vm_struct___103 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___117 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___45 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___45 *memcg;
};

struct page_pool_params___32 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___87 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___32 {
	u32 count;
	struct page___117 *cache[128];
};

struct page_pool___32 {
	struct page_pool_params___32 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___117 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___32 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___111;

struct dev_pagemap___111 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___111 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___99 {
	rwlock_t lock;
	struct pid___99 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___112 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___112 f_path;
	struct inode___112 *f_inode;
	const struct file_operations___112 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___99 f_owner;
	const struct cred___3 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___112 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___111;

struct vm_operations_struct___111 {
	void (*open)(struct vm_area_struct___117 *);
	void (*close)(struct vm_area_struct___117 *);
	int (*may_split)(struct vm_area_struct___117 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___117 *);
	int (*mprotect)(struct vm_area_struct___117 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___111 *);
	vm_fault_t (*huge_fault)(struct vm_fault___111 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___111 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___117 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___111 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___111 *);
	int (*access)(struct vm_area_struct___117 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___117 *);
	int (*set_policy)(struct vm_area_struct___117 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___117 *, long unsigned int);
	struct page___117 * (*find_special_page)(struct vm_area_struct___117 *, long unsigned int);
};

struct core_thread___117 {
	struct task_struct___119 *task;
	struct core_thread___117 *next;
};

struct core_state___117 {
	atomic_t nr_threads;
	struct core_thread___117 dumper;
	struct completion startup;
};

struct vm_fault___111 {
	const struct {
		struct vm_area_struct___117 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___117 *cow_page;
	struct page___117 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___117 prealloc_pte;
};

struct pglist_data___51;

struct lruvec___51 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___51 *pgdat;
};

struct zone___51 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___51 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___51 {
	struct zone___51 *zone;
	int zone_idx;
};

struct zonelist___51 {
	struct zoneref___51 _zonerefs[321];
};

struct pglist_data___51 {
	struct zone___51 node_zones[5];
	struct zonelist___51 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___119 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___119 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___51 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct xa_limit {
	u32 max;
	u32 min;
};

struct psi_group___85 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___119 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___21;

struct cgroup_bpf___21 {
	struct bpf_prog_array___21 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___21 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___85;

struct cgroup_rstat_cpu___85;

struct cgroup___85 {
	struct cgroup_subsys_state___85 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___106 *kn;
	struct cgroup_file___85 procs_file;
	struct cgroup_file___85 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___85 *subsys[14];
	struct cgroup_root___85 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___85 *dom_cgrp;
	struct cgroup___85 *old_dom_cgrp;
	struct cgroup_rstat_cpu___85 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___85 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___51 {
	struct request_queue___51 *q;
	struct io_context___51 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___51;

struct kiocb___112 {
	struct file___112 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___112 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___51 *ki_waitq;
	};
};

struct iattr___112 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___112 *ia_file;
};

struct dquot___112 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___112 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___112 {
	int qf_fmt_id;
	const struct quota_format_ops___112 *qf_ops;
	struct module___104 *qf_owner;
	struct quota_format_type___112 *qf_next;
};

struct quota_format_ops___112 {
	int (*check_quota_file)(struct super_block___112 *, int);
	int (*read_file_info)(struct super_block___112 *, int);
	int (*write_file_info)(struct super_block___112 *, int);
	int (*free_file_info)(struct super_block___112 *, int);
	int (*read_dqblk)(struct dquot___112 *);
	int (*commit_dqblk)(struct dquot___112 *);
	int (*release_dqblk)(struct dquot___112 *);
	int (*get_next_id)(struct super_block___112 *, struct kqid *);
};

struct dquot_operations___112 {
	int (*write_dquot)(struct dquot___112 *);
	struct dquot___112 * (*alloc_dquot)(struct super_block___112 *, int);
	void (*destroy_dquot)(struct dquot___112 *);
	int (*acquire_dquot)(struct dquot___112 *);
	int (*release_dquot)(struct dquot___112 *);
	int (*mark_dirty)(struct dquot___112 *);
	int (*write_info)(struct super_block___112 *, int);
	qsize_t * (*get_reserved_space)(struct inode___112 *);
	int (*get_projid)(struct inode___112 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___112 *, qsize_t *);
	int (*get_next_id)(struct super_block___112 *, struct kqid *);
};

struct quotactl_ops___112 {
	int (*quota_on)(struct super_block___112 *, int, int, const struct path___112 *);
	int (*quota_off)(struct super_block___112 *, int);
	int (*quota_enable)(struct super_block___112 *, unsigned int);
	int (*quota_disable)(struct super_block___112 *, unsigned int);
	int (*quota_sync)(struct super_block___112 *, int);
	int (*set_info)(struct super_block___112 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___112 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___112 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___112 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___112 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___112 *, unsigned int);
};

struct wait_page_queue___51 {
	struct page___117 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___50;

struct readahead_control___51;

struct address_space_operations___112 {
	int (*writepage)(struct page___117 *, struct writeback_control___50 *);
	int (*readpage)(struct file___112 *, struct page___117 *);
	int (*writepages)(struct address_space___112 *, struct writeback_control___50 *);
	int (*set_page_dirty)(struct page___117 *);
	int (*readpages)(struct file___112 *, struct address_space___112 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___51 *);
	int (*write_begin)(struct file___112 *, struct address_space___112 *, loff_t, unsigned int, unsigned int, struct page___117 **, void **);
	int (*write_end)(struct file___112 *, struct address_space___112 *, loff_t, unsigned int, unsigned int, struct page___117 *, void *);
	sector_t (*bmap)(struct address_space___112 *, sector_t);
	void (*invalidatepage)(struct page___117 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___117 *, gfp_t);
	void (*freepage)(struct page___117 *);
	ssize_t (*direct_IO)(struct kiocb___112 *, struct iov_iter___64 *);
	int (*migratepage)(struct address_space___112 *, struct page___117 *, struct page___117 *, enum migrate_mode);
	bool (*isolate_page)(struct page___117 *, isolate_mode_t);
	void (*putback_page)(struct page___117 *);
	int (*launder_page)(struct page___117 *);
	int (*is_partially_uptodate)(struct page___117 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___117 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___112 *, struct page___117 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___112 *, sector_t *);
	void (*swap_deactivate)(struct file___112 *);
};

struct writeback_control___50 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___50 *wb;
	struct inode___112 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___51 {
	struct file___112 *file;
	struct address_space___112 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___62;

struct iov_iter___64 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___62 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___39 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___112 {
	struct dentry___112 * (*lookup)(struct inode___112 *, struct dentry___112 *, unsigned int);
	const char * (*get_link)(struct dentry___112 *, struct inode___112 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___112 *, int);
	struct posix_acl * (*get_acl)(struct inode___112 *, int, bool);
	int (*readlink)(struct dentry___112 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___112 *, struct dentry___112 *, umode_t, bool);
	int (*link)(struct dentry___112 *, struct inode___112 *, struct dentry___112 *);
	int (*unlink)(struct inode___112 *, struct dentry___112 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___112 *, struct dentry___112 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___112 *, struct dentry___112 *, umode_t);
	int (*rmdir)(struct inode___112 *, struct dentry___112 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___112 *, struct dentry___112 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___112 *, struct dentry___112 *, struct inode___112 *, struct dentry___112 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___112 *, struct iattr___112 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___112 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___112 *, char *, size_t);
	int (*fiemap)(struct inode___112 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___112 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___112 *, struct dentry___112 *, struct file___112 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___112 *, struct dentry___112 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___112 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___112 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___112 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___112 {
	void (*fl_copy_lock)(struct file_lock___112 *, struct file_lock___112 *);
	void (*fl_release_private)(struct file_lock___112 *);
};

struct lock_manager_operations___112;

struct file_lock___112 {
	struct file_lock___112 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___112 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___112 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___112 *fl_ops;
	const struct lock_manager_operations___112 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___112 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___112 *);
	int (*lm_grant)(struct file_lock___112 *, int);
	bool (*lm_break)(struct file_lock___112 *);
	int (*lm_change)(struct file_lock___112 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___112 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___112 *);
};

struct fasync_struct___112 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___112 *fa_next;
	struct file___112 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___112 {
	struct inode___112 * (*alloc_inode)(struct super_block___112 *);
	void (*destroy_inode)(struct inode___112 *);
	void (*free_inode)(struct inode___112 *);
	void (*dirty_inode)(struct inode___112 *, int);
	int (*write_inode)(struct inode___112 *, struct writeback_control___50 *);
	int (*drop_inode)(struct inode___112 *);
	void (*evict_inode)(struct inode___112 *);
	void (*put_super)(struct super_block___112 *);
	int (*sync_fs)(struct super_block___112 *, int);
	int (*freeze_super)(struct super_block___112 *);
	int (*freeze_fs)(struct super_block___112 *);
	int (*thaw_super)(struct super_block___112 *);
	int (*unfreeze_fs)(struct super_block___112 *);
	int (*statfs)(struct dentry___112 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___112 *, int *, char *);
	void (*umount_begin)(struct super_block___112 *);
	int (*show_options)(struct seq_file___101 *, struct dentry___112 *);
	int (*show_devname)(struct seq_file___101 *, struct dentry___112 *);
	int (*show_path)(struct seq_file___101 *, struct dentry___112 *);
	int (*show_stats)(struct seq_file___101 *, struct dentry___112 *);
	ssize_t (*quota_read)(struct super_block___112 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___112 *, int, const char *, size_t, loff_t);
	struct dquot___112 ** (*get_dquots)(struct inode___112 *);
	long int (*nr_cached_objects)(struct super_block___112 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___112 *, struct shrink_control___45 *);
	struct file___112 * (*real_loop)(struct file___112 *);
};

struct wakeup_source___87;

struct dev_pm_info___87 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___87 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___87 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___87;

struct bus_type___87;

struct device_driver___87;

struct dev_pm_domain___87;

struct fwnode_handle___87;

struct class___87;

struct attribute_group___106;

struct device___87 {
	struct kobject___106 kobj;
	struct device___87 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___87 *type;
	struct bus_type___87 *bus;
	struct device_driver___87 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___87 power;
	struct dev_pm_domain___87 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___87 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___87 *class;
	const struct attribute_group___106 **groups;
	void (*release)(struct device___87 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___52 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___112 *bd_inode;
	struct super_block___112 *bd_super;
	void *bd_claiming;
	struct device___87 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___106 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___51 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___112 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___80)(struct file___112 *, wait_queue_head_t *, struct poll_table_struct___80 *);

struct poll_table_struct___80 {
	poll_queue_proc___80 _qproc;
	__poll_t _key;
};

struct seq_operations___101;

struct seq_file___101 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___101 *op;
	int poll_event;
	const struct file___112 *file;
	void *private;
};

typedef void bio_end_io_t___51(struct bio___51 *);

struct bio_vec___62 {
	struct page___117 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___51;

struct bio___51 {
	struct bio___51 *bi_next;
	struct block_device___52 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___51 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___50 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___51 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___62 *bi_io_vec;
	struct bio_set___51 *bi_pool;
	struct bio_vec___62 bi_inline_vecs[0];
};

struct kernfs_root___106;

struct kernfs_elem_dir___106 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___106 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___106;

struct kernfs_root___106 {
	struct kernfs_node___106 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___106 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___106 {
	struct kernfs_node___106 *target_kn;
};

struct kernfs_ops___106;

struct kernfs_elem_attr___106 {
	const struct kernfs_ops___106 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___106 *notify_next;
};

struct kernfs_node___106 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___106 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___106 dir;
		struct kernfs_elem_symlink___106 symlink;
		struct kernfs_elem_attr___106 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___106;

struct kernfs_ops___106 {
	int (*open)(struct kernfs_open_file___106 *);
	void (*release)(struct kernfs_open_file___106 *);
	int (*seq_show)(struct seq_file___101 *, void *);
	void * (*seq_start)(struct seq_file___101 *, loff_t *);
	void * (*seq_next)(struct seq_file___101 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___101 *, void *);
	ssize_t (*read)(struct kernfs_open_file___106 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___106 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___106 *, struct poll_table_struct___80 *);
	int (*mmap)(struct kernfs_open_file___106 *, struct vm_area_struct___117 *);
};

struct kernfs_syscall_ops___106 {
	int (*show_options)(struct seq_file___101 *, struct kernfs_root___106 *);
	int (*mkdir)(struct kernfs_node___106 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___106 *);
	int (*rename)(struct kernfs_node___106 *, struct kernfs_node___106 *, const char *);
	int (*show_path)(struct seq_file___101 *, struct kernfs_node___106 *, struct kernfs_root___106 *);
};

struct kernfs_open_file___106 {
	struct kernfs_node___106 *kn;
	struct file___112 *file;
	struct seq_file___101 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___111 *vm_ops;
};

struct sock___15;

struct kobj_ns_type_operations___14 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___15 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___24 *net;
} possible_net_t___21;

struct proto___14;

struct sock_common___14 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___14 *skc_prot;
	possible_net_t___21 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___15 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___23;

struct sk_buff_head___21 {
	struct sk_buff___23 *next;
	struct sk_buff___23 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___14 {
	struct cgroup___85 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___14;

struct socket_wq___14;

struct dst_entry___14;

struct socket___14;

struct net_device___25;

struct sock___15 {
	struct sock_common___14 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___21 sk_error_queue;
	struct sk_buff___23 *sk_rx_skb_cache;
	struct sk_buff_head___21 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___23 *head;
		struct sk_buff___23 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___14 *sk_filter;
	union {
		struct socket_wq___14 *sk_wq;
		struct socket_wq___14 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___14 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___14 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___23 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___23 *sk_tx_skb_cache;
	struct sk_buff_head___21 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___117 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___14 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___99 *sk_peer_pid;
	const struct cred___3 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___14 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___14 sk_cgrp_data;
	struct mem_cgroup___45 *sk_memcg;
	void (*sk_state_change)(struct sock___15 *);
	void (*sk_data_ready)(struct sock___15 *);
	void (*sk_write_space)(struct sock___15 *);
	void (*sk_error_report)(struct sock___15 *);
	int (*sk_backlog_rcv)(struct sock___15 *, struct sk_buff___23 *);
	struct sk_buff___23 * (*sk_validate_xmit_skb)(struct sock___15 *, struct net_device___25 *, struct sk_buff___23 *);
	void (*sk_destruct)(struct sock___15 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___106;

struct attribute_group___106 {
	const char *name;
	umode_t (*is_visible)(struct kobject___106 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___106 *, struct bin_attribute___106 *, int);
	struct attribute **attrs;
	struct bin_attribute___106 **bin_attrs;
};

struct bin_attribute___106 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___112 * (*f_mapping)();
	ssize_t (*read)(struct file___112 *, struct kobject___106 *, struct bin_attribute___106 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___112 *, struct kobject___106 *, struct bin_attribute___106 *, char *, loff_t, size_t);
	int (*mmap)(struct file___112 *, struct kobject___106 *, struct bin_attribute___106 *, struct vm_area_struct___117 *);
};

struct sysfs_ops___106 {
	ssize_t (*show)(struct kobject___106 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___106 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___106;

struct kset___106 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___106 kobj;
	const struct kset_uevent_ops___106 *uevent_ops;
};

struct kobj_type___106 {
	void (*release)(struct kobject___106 *);
	const struct sysfs_ops___106 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___106 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___106 *);
	const void * (*namespace)(struct kobject___106 *);
	void (*get_ownership)(struct kobject___106 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___106 {
	int (* const filter)(struct kset___106 *, struct kobject___106 *);
	const char * (* const name)(struct kset___106 *, struct kobject___106 *);
	int (* const uevent)(struct kset___106 *, struct kobject___106 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___87 {
	int (*prepare)(struct device___87 *);
	void (*complete)(struct device___87 *);
	int (*suspend)(struct device___87 *);
	int (*resume)(struct device___87 *);
	int (*freeze)(struct device___87 *);
	int (*thaw)(struct device___87 *);
	int (*poweroff)(struct device___87 *);
	int (*restore)(struct device___87 *);
	int (*suspend_late)(struct device___87 *);
	int (*resume_early)(struct device___87 *);
	int (*freeze_late)(struct device___87 *);
	int (*thaw_early)(struct device___87 *);
	int (*poweroff_late)(struct device___87 *);
	int (*restore_early)(struct device___87 *);
	int (*suspend_noirq)(struct device___87 *);
	int (*resume_noirq)(struct device___87 *);
	int (*freeze_noirq)(struct device___87 *);
	int (*thaw_noirq)(struct device___87 *);
	int (*poweroff_noirq)(struct device___87 *);
	int (*restore_noirq)(struct device___87 *);
	int (*runtime_suspend)(struct device___87 *);
	int (*runtime_resume)(struct device___87 *);
	int (*runtime_idle)(struct device___87 *);
};

struct wakeup_source___87 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___87 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___87 {
	struct dev_pm_ops___87 ops;
	int (*start)(struct device___87 *);
	void (*detach)(struct device___87 *, bool);
	int (*activate)(struct device___87 *);
	void (*sync)(struct device___87 *);
	void (*dismiss)(struct device___87 *);
};

struct bus_type___87 {
	const char *name;
	const char *dev_name;
	struct device___87 *dev_root;
	const struct attribute_group___106 **bus_groups;
	const struct attribute_group___106 **dev_groups;
	const struct attribute_group___106 **drv_groups;
	int (*match)(struct device___87 *, struct device_driver___87 *);
	int (*uevent)(struct device___87 *, struct kobj_uevent_env *);
	int (*probe)(struct device___87 *);
	void (*sync_state)(struct device___87 *);
	void (*remove)(struct device___87 *);
	void (*shutdown)(struct device___87 *);
	int (*online)(struct device___87 *);
	int (*offline)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	int (*num_vf)(struct device___87 *);
	int (*dma_configure)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___87 {
	const char *name;
	struct bus_type___87 *bus;
	struct module___104 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___87 *);
	void (*sync_state)(struct device___87 *);
	int (*remove)(struct device___87 *);
	void (*shutdown)(struct device___87 *);
	int (*suspend)(struct device___87 *, pm_message_t);
	int (*resume)(struct device___87 *);
	const struct attribute_group___106 **groups;
	const struct attribute_group___106 **dev_groups;
	const struct dev_pm_ops___87 *pm;
	void (*coredump)(struct device___87 *);
	struct driver_private *p;
};

struct device_type___87 {
	const char *name;
	const struct attribute_group___106 **groups;
	int (*uevent)(struct device___87 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___87 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___87 *);
	const struct dev_pm_ops___87 *pm;
};

struct class___87 {
	const char *name;
	struct module___104 *owner;
	const struct attribute_group___106 **class_groups;
	const struct attribute_group___106 **dev_groups;
	struct kobject___106 *dev_kobj;
	int (*dev_uevent)(struct device___87 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___87 *, umode_t *);
	void (*class_release)(struct class___87 *);
	void (*dev_release)(struct device___87 *);
	int (*shutdown_pre)(struct device___87 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___87 *);
	void (*get_ownership)(struct device___87 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___87 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___87;

struct fwnode_handle___87 {
	struct fwnode_handle___87 *secondary;
	const struct fwnode_operations___87 *ops;
	struct device___87 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___111 {
	void (*page_free)(struct page___117 *);
	void (*kill)(struct dev_pagemap___111 *);
	void (*cleanup)(struct dev_pagemap___111 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___111 *);
};

struct seq_operations___101 {
	void * (*start)(struct seq_file___101 *, loff_t *);
	void (*stop)(struct seq_file___101 *, void *);
	void * (*next)(struct seq_file___101 *, void *, loff_t *);
	int (*show)(struct seq_file___101 *, void *);
};

typedef struct poll_table_struct___80 poll_table___22;

struct fwnode_reference_args___87;

struct fwnode_endpoint___87;

struct fwnode_operations___87 {
	struct fwnode_handle___87 * (*get)(struct fwnode_handle___87 *);
	void (*put)(struct fwnode_handle___87 *);
	bool (*device_is_available)(const struct fwnode_handle___87 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___87 *, const struct device___87 *);
	bool (*property_present)(const struct fwnode_handle___87 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___87 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___87 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___87 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*get_parent)(const struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*get_next_child_node)(const struct fwnode_handle___87 *, struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*get_named_child_node)(const struct fwnode_handle___87 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___87 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___87 *);
	struct fwnode_handle___87 * (*graph_get_next_endpoint)(const struct fwnode_handle___87 *, struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*graph_get_remote_endpoint)(const struct fwnode_handle___87 *);
	struct fwnode_handle___87 * (*graph_get_port_parent)(struct fwnode_handle___87 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___87 *, struct fwnode_endpoint___87 *);
	int (*add_links)(struct fwnode_handle___87 *);
};

struct fwnode_endpoint___87 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___87 *local_fwnode;
};

struct fwnode_reference_args___87 {
	struct fwnode_handle___87 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___14;

struct fqdir___23;

struct fib_notifier_ops___14;

struct netns_ipv4___23 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___14 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___15 *fibnl;
	struct sock___15 **icmp_sk;
	struct sock___15 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___15 **tcp_sk;
	struct fqdir___23 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___14 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___14 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___14 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___14;

struct dst_ops___23 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___23 *);
	struct dst_entry___14 * (*check)(struct dst_entry___14 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___14 *);
	unsigned int (*mtu)(const struct dst_entry___14 *);
	u32 * (*cow_metrics)(struct dst_entry___14 *, long unsigned int);
	void (*destroy)(struct dst_entry___14 *);
	void (*ifdown)(struct dst_entry___14 *, struct net_device___25 *, int);
	struct dst_entry___14 * (*negative_advice)(struct dst_entry___14 *);
	void (*link_failure)(struct sk_buff___23 *);
	void (*update_pmtu)(struct dst_entry___14 *, struct sock___15 *, struct sk_buff___23 *, u32, bool);
	void (*redirect)(struct dst_entry___14 *, struct sock___15 *, struct sk_buff___23 *);
	int (*local_out)(struct net___24 *, struct sock___15 *, struct sk_buff___23 *);
	struct neighbour___14 * (*neigh_lookup)(const struct dst_entry___14 *, struct sk_buff___23 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___14 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___23 {
	struct dst_ops___23 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___23 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___14 *fib6_rules_ops;
	struct sock___15 **icmp_sk;
	struct sock___15 *ndisc_sk;
	struct sock___15 *tcp_sk;
	struct sock___15 *igmp_sk;
	struct sock___15 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___14 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___14 *notifier_ops;
	struct fib_notifier_ops___14 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___23 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___23 *fqdir;
};

struct netns_sctp___14 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___15 *ctl_sock;
	struct sock___15 *udp4_sock;
	struct sock___15 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___21 {
	struct bpf_prog_array___21 *run_array[2];
	struct bpf_prog___21 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___23 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___15 *nlsk;
	struct sock___15 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___23 xfrm4_dst_ops;
	struct dst_ops___23 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___24 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct idr netns_ids;
	struct ns_common___5 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___15 *rtnl;
	struct sock___15 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___25 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___23 ipv4;
	struct netns_ipv6___23 ipv6;
	struct netns_ieee802154_lowpan___23 ieee802154_lowpan;
	struct netns_sctp___14 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___21 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___21 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___23 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___15 *crypto_nlsk;
	struct sock___15 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___85 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___85 *root_cset;
};

struct kernel_param_ops___103 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___103 *);
	int (*get)(char *, const struct kernel_param___103 *);
	void (*free)(void *);
};

struct kparam_array___103;

struct kernel_param___103 {
	const char *name;
	struct module___104 *mod;
	const struct kernel_param_ops___103 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___103 *arr;
	};
};

struct kparam_array___103 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___103 *ops;
	void *elem;
};

struct module_attribute___103 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___103 *, struct module_kobject___103 *, char *);
	ssize_t (*store)(struct module_attribute___103 *, struct module_kobject___103 *, const char *, size_t);
	void (*setup)(struct module___104 *, const char *);
	int (*test)(struct module___104 *);
	void (*free)(struct module___104 *);
};

struct trace_event_class___56;

struct trace_event_call___56 {
	struct list_head list;
	struct trace_event_class___56 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___56 *, struct perf_event___62 *);
};

struct iov_iter_state {
	size_t iov_offset;
	size_t count;
	long unsigned int nr_segs;
};

struct msghdr___14 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___64 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___112 *msg_iocb;
};

struct user_msghdr {
	void *msg_name;
	int msg_namelen;
	struct iovec *msg_iov;
	__kernel_size_t msg_iovlen;
	void *msg_control;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
};

struct fd___24 {
	struct file___112 *file;
	unsigned int flags;
};

struct bpf_iter_aux_info___22;

typedef int (*bpf_iter_init_seq_priv_t___22)(void *, struct bpf_iter_aux_info___22 *);

struct bpf_map___22;

struct bpf_iter_aux_info___22 {
	struct bpf_map___22 *map;
};

struct bpf_iter_seq_info___22 {
	const struct seq_operations___101 *seq_ops;
	bpf_iter_init_seq_priv_t___22 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___22;

struct bpf_map_ops___22 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___22 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___22 *, struct file___112 *);
	void (*map_free)(struct bpf_map___22 *);
	int (*map_get_next_key)(struct bpf_map___22 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___22 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___22 *, void *);
	int (*map_lookup_batch)(struct bpf_map___22 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___22 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___22 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___22 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___22 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___22 *, void *);
	int (*map_update_elem)(struct bpf_map___22 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___22 *, void *);
	int (*map_push_elem)(struct bpf_map___22 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___22 *, void *);
	int (*map_peek_elem)(struct bpf_map___22 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___22 *, struct file___112 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___22 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___22 *, void *, struct seq_file___101 *);
	int (*map_check_btf)(const struct bpf_map___22 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___22 *, struct bpf_prog_aux___22 *);
	void (*map_poke_untrack)(struct bpf_map___22 *, struct bpf_prog_aux___22 *);
	void (*map_poke_run)(struct bpf_map___22 *, u32, struct bpf_prog___21 *, struct bpf_prog___21 *);
	int (*map_direct_value_addr)(const struct bpf_map___22 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___22 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___22 *, struct vm_area_struct___117 *);
	__poll_t (*map_poll)(struct bpf_map___22 *, struct file___112 *, struct poll_table_struct___80 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___22 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___22 *, const struct bpf_map___22 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___22 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___22 *iter_seq_info;
};

struct bpf_map___22 {
	const struct bpf_map_ops___22 *ops;
	struct bpf_map___22 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___45 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___22;

struct bpf_jit_poke_descriptor___22;

struct bpf_prog_ops___21;

struct btf_mod_pair___22;

struct bpf_prog_offload___21;

struct bpf_prog_aux___22 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___21 *dst_prog;
	struct bpf_trampoline___22 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___21 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___22 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___21 *ops;
	struct bpf_map___22 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___22 *used_btfs;
	struct bpf_prog___21 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___22 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___21 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___21 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___22 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___21;

struct bpf_map_dev_ops___21 {
	int (*map_get_next_key)(struct bpf_offloaded_map___21 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___21 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___21 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___21 *, void *);
};

struct bpf_offloaded_map___21 {
	struct bpf_map___22 map;
	struct net_device___25 *netdev;
	const struct bpf_map_dev_ops___21 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___21(struct sk_buff___23 **);

struct bpf_xdp_entity___21 {
	struct bpf_prog___21 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___21;

struct net_device_ops___21;

struct l3mdev_ops___14;

struct xfrmdev_ops___21;

struct header_ops___21;

struct netdev_rx_queue___21;

struct mini_Qdisc___21;

struct netdev_queue___21;

struct Qdisc___21;

struct rtnl_link_ops___21;

struct dcbnl_rtnl_ops___21;

struct net_device___25 {
	char name[16];
	struct netdev_name_node___21 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___21 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___14 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___21 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___21 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___106 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___21 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___21 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___21 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___21 *miniq_ingress;
	struct netdev_queue___21 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___21 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___21 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___21 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___21 = 0,
		NETREG_REGISTERED___21 = 1,
		NETREG_UNREGISTERING___21 = 2,
		NETREG_UNREGISTERED___21 = 3,
		NETREG_RELEASED___21 = 4,
		NETREG_DUMMY___21 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___21 = 0,
		RTNL_LINK_INITIALIZING___21 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___25 *);
	struct netpoll_info *npinfo;
	possible_net_t___21 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___87 dev;
	const struct attribute_group___106 *sysfs_groups[4];
	const struct attribute_group___106 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___21 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___21 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___21 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___21 {
	int (*test_run)(struct bpf_prog___21 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___21 {
	struct bpf_prog___21 *prog;
	struct net_device___25 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___22 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___21 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___104 *mod;
};

struct bpf_jit_poke_descriptor___22 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___22 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___22 {
	struct btf *btf;
	struct module___104 *module;
};

struct bpf_prog_array_item___21 {
	struct bpf_prog___21 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___21 {
	struct callback_head rcu;
	struct bpf_prog_array_item___21 items[0];
};

struct sk_buff___23 {
	union {
		struct {
			struct sk_buff___23 *next;
			struct sk_buff___23 *prev;
			union {
				struct net_device___25 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___15 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___23 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___85;

struct cgroup_subsys___85 {
	struct cgroup_subsys_state___85 * (*css_alloc)(struct cgroup_subsys_state___85 *);
	int (*css_online)(struct cgroup_subsys_state___85 *);
	void (*css_offline)(struct cgroup_subsys_state___85 *);
	void (*css_released)(struct cgroup_subsys_state___85 *);
	void (*css_free)(struct cgroup_subsys_state___85 *);
	void (*css_reset)(struct cgroup_subsys_state___85 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___85 *, int);
	int (*css_extra_stat_show)(struct seq_file___101 *, struct cgroup_subsys_state___85 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___119 *, struct css_set___85 *);
	void (*cancel_fork)(struct task_struct___119 *, struct css_set___85 *);
	void (*fork)(struct task_struct___119 *);
	void (*exit)(struct task_struct___119 *);
	void (*release)(struct task_struct___119 *);
	void (*bind)(struct cgroup_subsys_state___85 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___85 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___85 *dfl_cftypes;
	struct cftype___85 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___85 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___85 *updated_children;
	struct cgroup___85 *updated_next;
};

struct cgroup_root___85 {
	struct kernfs_root___106 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___85 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___85 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___85 *ss;
	struct list_head node;
	struct kernfs_ops___106 *kf_ops;
	int (*open)(struct kernfs_open_file___106 *);
	void (*release)(struct kernfs_open_file___106 *);
	u64 (*read_u64)(struct cgroup_subsys_state___85 *, struct cftype___85 *);
	s64 (*read_s64)(struct cgroup_subsys_state___85 *, struct cftype___85 *);
	int (*seq_show)(struct seq_file___101 *, void *);
	void * (*seq_start)(struct seq_file___101 *, loff_t *);
	void * (*seq_next)(struct seq_file___101 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___101 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___85 *, struct cftype___85 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___85 *, struct cftype___85 *, s64);
	ssize_t (*write)(struct kernfs_open_file___106 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___106 *, struct poll_table_struct___80 *);
};

struct perf_cpu_context___62;

struct perf_output_handle___62;

struct pmu___62 {
	struct list_head entry;
	struct module___104 *module;
	struct device___87 *dev;
	const struct attribute_group___106 **attr_groups;
	const struct attribute_group___106 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___62 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___62 *);
	void (*pmu_disable)(struct pmu___62 *);
	int (*event_init)(struct perf_event___62 *);
	void (*event_mapped)(struct perf_event___62 *, struct mm_struct___118 *);
	void (*event_unmapped)(struct perf_event___62 *, struct mm_struct___118 *);
	int (*add)(struct perf_event___62 *, int);
	void (*del)(struct perf_event___62 *, int);
	void (*start)(struct perf_event___62 *, int);
	void (*stop)(struct perf_event___62 *, int);
	void (*read)(struct perf_event___62 *);
	void (*start_txn)(struct pmu___62 *, unsigned int);
	int (*commit_txn)(struct pmu___62 *);
	void (*cancel_txn)(struct pmu___62 *);
	int (*event_idx)(struct perf_event___62 *);
	void (*sched_task)(struct perf_event_context___62 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___62 *, struct perf_event_context___62 *);
	void * (*setup_aux)(struct perf_event___62 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___62 *, struct perf_output_handle___62 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___62 *);
	int (*aux_output_match)(struct perf_event___62 *);
	int (*filter_match)(struct perf_event___62 *);
	int (*check_period)(struct perf_event___62 *, u64);
};

struct perf_cpu_context___62 {
	struct perf_event_context___62 ctx;
	struct perf_event_context___62 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___62 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___62 **heap;
	struct perf_event___62 *heap_default[2];
};

struct perf_output_handle___62 {
	struct perf_event___62 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___62 {
	struct cgroup_subsys_state___85 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___56 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___56 *);
	};
};

struct trace_event_class___56 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___56 *, enum trace_reg, void *);
	struct trace_event_fields___56 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___56 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___56 *);
};

struct trace_event_file___24;

struct trace_event_buffer___23 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___24 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___24 {
	struct list_head list;
	struct trace_event_call___56 *event_call;
	struct event_filter *filter;
	struct dentry___112 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct syscall_metadata___30 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___56 *enter_event;
	struct trace_event_call___56 *exit_event;
};

struct compat_msghdr {
	compat_uptr_t msg_name;
	compat_int_t msg_namelen;
	compat_uptr_t msg_iov;
	compat_size_t msg_iovlen;
	compat_uptr_t msg_control;
	compat_size_t msg_controllen;
	compat_uint_t msg_flags;
};

struct block_device_operations___51;

struct gendisk___51 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___52 *part0;
	const struct block_device_operations___51 *fops;
	struct request_queue___51 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___50 *bdi;
	struct kobject___106 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___106 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___51 {
	struct bio___51 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___62 *bip_vec;
	struct bio_vec___62 bip_inline_vecs[0];
};

struct blkcg___50;

struct blkg_policy_data___50;

struct blkcg_gq___50 {
	struct request_queue___51 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___50 *blkcg;
	struct blkcg_gq___50 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___50 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___51 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___51(struct request___51 *);

typedef void integrity_complete_fn___51(struct request___51 *, unsigned int);

struct blk_integrity_profile___51 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___51 *prepare_fn;
	integrity_complete_fn___51 *complete_fn;
	const char *name;
};

struct block_device_operations___51 {
	blk_qc_t (*submit_bio)(struct bio___51 *);
	int (*open)(struct block_device___52 *, fmode_t);
	void (*release)(struct gendisk___51 *, fmode_t);
	int (*rw_page)(struct block_device___52 *, sector_t, struct page___117 *, unsigned int);
	int (*ioctl)(struct block_device___52 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___52 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___51 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___51 *);
	int (*getgeo)(struct block_device___52 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___52 *, bool);
	void (*swap_slot_free_notify)(struct block_device___52 *, long unsigned int);
	int (*report_zones)(struct gendisk___51 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___51 *, umode_t *);
	struct module___104 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___51 *, sector_t *);
};

typedef void rq_end_io_fn___51(struct request___51 *, blk_status_t);

struct request___51 {
	struct request_queue___51 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___50 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___51 *bio;
	struct bio___51 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___62 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___51 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___51 *saved_end_io;
		} flush;
	};
	struct gendisk___51 *rq_disk;
	struct block_device___52 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___51 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___50 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___51 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___106 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___112 *debugfs_dir;
	struct dentry___112 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___51;

struct elevator_mq_ops___51 {
	int (*init_sched)(struct request_queue___51 *, struct elevator_type___51 *);
	void (*exit_sched)(struct elevator_queue___51 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___50 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___50 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___50 *);
	bool (*allow_merge)(struct request_queue___51 *, struct request___51 *, struct bio___51 *);
	bool (*bio_merge)(struct request_queue___51 *, struct bio___51 *, unsigned int);
	int (*request_merge)(struct request_queue___51 *, struct request___51 **, struct bio___51 *);
	void (*request_merged)(struct request_queue___51 *, struct request___51 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___51 *, struct request___51 *, struct request___51 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___51 *);
	void (*finish_request)(struct request___51 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___50 *, struct list_head *, bool);
	struct request___51 * (*dispatch_request)(struct blk_mq_hw_ctx___50 *);
	bool (*has_work)(struct blk_mq_hw_ctx___50 *);
	void (*completed_request)(struct request___51 *, u64);
	void (*requeue_request)(struct request___51 *);
	struct request___51 * (*former_request)(struct request_queue___51 *, struct request___51 *);
	struct request___51 * (*next_request)(struct request_queue___51 *, struct request___51 *);
	void (*init_icq)(struct io_cq___51 *);
	void (*exit_icq)(struct io_cq___51 *);
};

struct elv_fs_entry___51;

struct elevator_type___51 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___51 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___51 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___104 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___51 {
	struct elevator_type___51 *type;
	void *elevator_data;
	struct kobject___106 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___51 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___51 *, char *);
	ssize_t (*store)(struct elevator_queue___51 *, const char *, size_t);
};

struct blk_mq_queue_data___50;

struct blk_mq_ops___50 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___50 *, const struct blk_mq_queue_data___50 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___50 *);
	int (*get_budget)(struct request_queue___51 *);
	void (*put_budget)(struct request_queue___51 *, int);
	void (*set_rq_budget_token)(struct request___51 *, int);
	int (*get_rq_budget_token)(struct request___51 *);
	enum blk_eh_timer_return (*timeout)(struct request___51 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___50 *);
	void (*complete)(struct request___51 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___50 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___50 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___50 *, struct request___51 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___50 *, struct request___51 *, unsigned int);
	void (*initialize_rq_fn)(struct request___51 *);
	void (*cleanup_rq)(struct request___51 *);
	bool (*busy)(struct request_queue___51 *);
	int (*map_queues)(struct blk_mq_tag_set___50 *);
	void (*show_rq)(struct seq_file___101 *, struct request___51 *);
};

struct blk_mq_tag_set___50 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___50 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct socket_wq___14 {
	wait_queue_head_t wait;
	struct fasync_struct___112 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___14;

struct socket___14 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___112 *file;
	struct sock___15 *sk;
	const struct proto_ops___14 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___14 wq;
};

typedef int (*sk_read_actor_t___14)(read_descriptor_t *, struct sk_buff___23 *, unsigned int, size_t);

struct proto_ops___14 {
	int family;
	struct module___104 *owner;
	int (*release)(struct socket___14 *);
	int (*bind)(struct socket___14 *, struct sockaddr *, int);
	int (*connect)(struct socket___14 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___14 *, struct socket___14 *);
	int (*accept)(struct socket___14 *, struct socket___14 *, int, bool);
	int (*getname)(struct socket___14 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___112 *, struct socket___14 *, struct poll_table_struct___80 *);
	int (*ioctl)(struct socket___14 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___14 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___14 *, void *, bool, bool);
	int (*listen)(struct socket___14 *, int);
	int (*shutdown)(struct socket___14 *, int);
	int (*setsockopt)(struct socket___14 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___14 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___101 *, struct socket___14 *);
	int (*sendmsg)(struct socket___14 *, struct msghdr___14 *, size_t);
	int (*recvmsg)(struct socket___14 *, struct msghdr___14 *, size_t, int);
	int (*mmap)(struct file___112 *, struct socket___14 *, struct vm_area_struct___117 *);
	ssize_t (*sendpage)(struct socket___14 *, struct page___117 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___14 *, loff_t *, struct pipe_inode_info___39 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___15 *, int);
	int (*peek_len)(struct socket___14 *);
	int (*read_sock)(struct sock___15 *, read_descriptor_t *, sk_read_actor_t___14);
	int (*sendpage_locked)(struct sock___15 *, struct page___117 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___15 *, struct msghdr___14 *, size_t);
	int (*set_rcvlowat)(struct sock___15 *, int);
};

struct inet_frags___23;

struct fqdir___23 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___23 *f;
	struct net___24 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___23;

struct inet_frags___23 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___23 *, const void *);
	void (*destructor)(struct inet_frag_queue___23 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___23 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___23 *fragments_tail;
	struct sk_buff___23 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___23 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___14;

struct fib_lookup_arg___14;

struct fib_rules_ops___14 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___14 *, struct flowi *, int, struct fib_lookup_arg___14 *);
	bool (*suppress)(struct fib_rule___14 *, int, struct fib_lookup_arg___14 *);
	int (*match)(struct fib_rule___14 *, struct flowi *, int);
	int (*configure)(struct fib_rule___14 *, struct sk_buff___23 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___14 *);
	int (*compare)(struct fib_rule___14 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___14 *, struct sk_buff___23 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___14 *);
	void (*flush_cache)(struct fib_rules_ops___14 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___104 *owner;
	struct net___24 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___14 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___24 *);
	int (*fib_dump)(struct net___24 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___104 *owner;
	struct callback_head rcu;
};

struct dst_entry___14 {
	struct net_device___25 *dev;
	struct dst_ops___23 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___23 *);
	int (*output)(struct net___24 *, struct sock___15 *, struct sk_buff___23 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___14;

struct neigh_parms___14;

struct neigh_ops___14;

struct neighbour___14 {
	struct neighbour___14 *next;
	struct neigh_table___14 *tbl;
	struct neigh_parms___14 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___21 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___14 *, struct sk_buff___23 *);
	const struct neigh_ops___14 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___25 *dev;
	u8 primary_key[0];
};

struct pipe_buf_operations___39;

struct pipe_buffer___39 {
	struct page___117 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___39 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___39 {
	int (*confirm)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
	void (*release)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
	bool (*try_steal)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
	bool (*get)(struct pipe_inode_info___39 *, struct pipe_buffer___39 *);
};

struct dcbnl_rtnl_ops___21 {
	int (*ieee_getets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___25 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___25 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___25 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___25 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___25 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___25 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___25 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___25 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___25 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___25 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___25 *);
	u8 (*setstate)(struct net_device___25 *, u8);
	void (*getpermhwaddr)(struct net_device___25 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___25 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___25 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___25 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___25 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___25 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___25 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___25 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___25 *, int, u8 *);
	void (*setpfccfg)(struct net_device___25 *, int, u8);
	void (*getpfccfg)(struct net_device___25 *, int, u8 *);
	u8 (*setall)(struct net_device___25 *);
	u8 (*getcap)(struct net_device___25 *, int, u8 *);
	int (*getnumtcs)(struct net_device___25 *, int, u8 *);
	int (*setnumtcs)(struct net_device___25 *, int, u8);
	u8 (*getpfcstate)(struct net_device___25 *);
	void (*setpfcstate)(struct net_device___25 *, u8);
	void (*getbcncfg)(struct net_device___25 *, int, u32 *);
	void (*setbcncfg)(struct net_device___25 *, int, u32);
	void (*getbcnrp)(struct net_device___25 *, int, u8 *);
	void (*setbcnrp)(struct net_device___25 *, int, u8);
	int (*setapp)(struct net_device___25 *, u8, u16, u8);
	int (*getapp)(struct net_device___25 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___25 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___25 *, int, u8);
	u8 (*getdcbx)(struct net_device___25 *);
	u8 (*setdcbx)(struct net_device___25 *, u8);
	int (*peer_getappinfo)(struct net_device___25 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___25 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___25 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___25 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___25 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___25 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___21 {
	struct net_device___25 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___21 {
	struct net_device___25 *dev;
};

struct xdp_buff___21 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___21 *rxq;
	struct xdp_txq_info___21 *txq;
	u32 frame_sz;
};

struct xdp_frame___21 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___25 *dev_rx;
};

struct scm_fp_list {
	short int count;
	short int max;
	struct user_struct *user;
	struct file___112 *fp[253];
};

struct netlink_callback___21 {
	struct sk_buff___23 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___23 *, struct netlink_callback___21 *);
	int (*done)(struct netlink_callback___21 *);
	void *data;
	struct module___104 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___21 {
	int (*create)(struct sk_buff___23 *, struct net_device___25 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___23 *, unsigned char *);
	int (*cache)(const struct neighbour___14 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___25 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___23 *);
};

struct netdev_queue___21 {
	struct net_device___25 *dev;
	struct Qdisc___21 *qdisc;
	struct Qdisc___21 *qdisc_sleeping;
	struct kobject___106 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___25 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___21 {
	struct sk_buff___23 *head;
	struct sk_buff___23 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___21;

struct Qdisc___21 {
	int (*enqueue)(struct sk_buff___23 *, struct Qdisc___21 *, struct sk_buff___23 **);
	struct sk_buff___23 * (*dequeue)(struct Qdisc___21 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___21 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___21 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___21 gso_skb;
	struct qdisc_skb_head___21 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___21 *next_sched;
	struct sk_buff_head___21 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___21 {
	struct xdp_rxq_info___21 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___106 kobj;
	struct net_device___25 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___21 {
	enum net_device_path_type type;
	const struct net_device___25 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___21 = 0,
				DEV_PATH_BR_VLAN_TAG___21 = 1,
				DEV_PATH_BR_VLAN_UNTAG___21 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___21 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___21 {
	const struct net_device___25 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___21 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___21 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___21 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___21 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___23 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___21 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___25 *dev;
	const char *name;
};

struct net_device_ops___21 {
	int (*ndo_init)(struct net_device___25 *);
	void (*ndo_uninit)(struct net_device___25 *);
	int (*ndo_open)(struct net_device___25 *);
	int (*ndo_stop)(struct net_device___25 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___23 *, struct net_device___25 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___23 *, struct net_device___25 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___25 *, struct sk_buff___23 *, struct net_device___25 *);
	void (*ndo_change_rx_flags)(struct net_device___25 *, int);
	void (*ndo_set_rx_mode)(struct net_device___25 *);
	int (*ndo_set_mac_address)(struct net_device___25 *, void *);
	int (*ndo_validate_addr)(struct net_device___25 *);
	int (*ndo_do_ioctl)(struct net_device___25 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___25 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___25 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___25 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___25 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___25 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___25 *, int);
	int (*ndo_neigh_setup)(struct net_device___25 *, struct neigh_parms___14 *);
	void (*ndo_tx_timeout)(struct net_device___25 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___25 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___25 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___25 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___25 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___25 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___25 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___25 *);
	int (*ndo_netpoll_setup)(struct net_device___25 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___25 *);
	int (*ndo_set_vf_mac)(struct net_device___25 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___25 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___25 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___25 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___25 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___25 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___25 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___25 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___25 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___25 *, int, struct sk_buff___23 *);
	int (*ndo_get_vf_guid)(struct net_device___25 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___25 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___25 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___25 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___25 *);
	int (*ndo_fcoe_disable)(struct net_device___25 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___25 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___25 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___25 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___25 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___25 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___25 *, const struct sk_buff___23 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___25 *, struct net_device___25 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___25 *, struct net_device___25 *);
	struct net_device___25 * (*ndo_get_xmit_slave)(struct net_device___25 *, struct sk_buff___23 *, bool);
	struct net_device___25 * (*ndo_sk_get_lower_dev)(struct net_device___25 *, struct sock___15 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___25 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___25 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___25 *, struct neighbour___14 *);
	void (*ndo_neigh_destroy)(struct net_device___25 *, struct neighbour___14 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___23 *, struct netlink_callback___21 *, struct net_device___25 *, struct net_device___25 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___23 *, struct nlattr **, struct net_device___25 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___25 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___23 *, u32, u32, struct net_device___25 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___25 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___25 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___25 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___25 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___25 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___25 *, struct net_device___25 *);
	void (*ndo_dfwd_del_station)(struct net_device___25 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___25 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___25 *);
	int (*ndo_change_proto_down)(struct net_device___25 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___25 *, struct sk_buff___23 *);
	void (*ndo_set_rx_headroom)(struct net_device___25 *, int);
	int (*ndo_bpf)(struct net_device___25 *, struct netdev_bpf___21 *);
	int (*ndo_xdp_xmit)(struct net_device___25 *, int, struct xdp_frame___21 **, u32);
	struct net_device___25 * (*ndo_xdp_get_xmit_slave)(struct net_device___25 *, struct xdp_buff___21 *);
	int (*ndo_xsk_wakeup)(struct net_device___25 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___25 *);
	int (*ndo_tunnel_ctl)(struct net_device___25 *, struct ip_tunnel_parm *, int);
	struct net_device___25 * (*ndo_get_peer_dev)(struct net_device___25 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___21 *, struct net_device_path___21 *);
};

struct neigh_parms___14 {
	possible_net_t___21 net;
	struct net_device___25 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___14 *);
	struct neigh_table___14 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___14 {
	u32 (*l3mdev_fib_table)(const struct net_device___25 *);
	struct sk_buff___23 * (*l3mdev_l3_rcv)(struct net_device___25 *, struct sk_buff___23 *, u16);
	struct sk_buff___23 * (*l3mdev_l3_out)(struct net_device___25 *, struct sock___15 *, struct sk_buff___23 *, u16);
	struct dst_entry___14 * (*l3mdev_link_scope_lookup)(const struct net_device___25 *, struct flowi6 *);
};

struct tcf_proto___21;

struct tcf_block___21;

struct mini_Qdisc___21 {
	struct tcf_proto___21 *filter_list;
	struct tcf_block___21 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___21 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___25 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___25 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___24 *, struct net_device___25 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___25 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___25 *, struct list_head *);
	size_t (*get_size)(const struct net_device___25 *);
	int (*fill_info)(struct sk_buff___23 *, const struct net_device___25 *);
	size_t (*get_xstats_size)(const struct net_device___25 *);
	int (*fill_xstats)(struct sk_buff___23 *, const struct net_device___25 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___25 *, struct net_device___25 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___25 *, const struct net_device___25 *);
	int (*fill_slave_info)(struct sk_buff___23 *, const struct net_device___25 *, const struct net_device___25 *);
	struct net___24 * (*get_link_net)(const struct net_device___25 *);
	size_t (*get_linkxstats_size)(const struct net_device___25 *, int);
	int (*fill_linkxstats)(struct sk_buff___23 *, const struct net_device___25 *, int *, int);
};

struct blk_mq_queue_data___50 {
	struct request___51 *rq;
	bool last;
};

struct blkcg_policy_data___50;

struct blkcg___50 {
	struct cgroup_subsys_state___85 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___50 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___50 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___50 {
	struct blkcg___50 *blkcg;
	int plid;
};

struct blkg_policy_data___50 {
	struct blkcg_gq___50 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___45 {
	struct mem_cgroup___45 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___45 {
	struct lruvec___51 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___45 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___45 *memcg;
};

struct obj_cgroup___45 {
	struct percpu_ref refcnt;
	struct mem_cgroup___45 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___21 {
	spinlock_t *lock;
	struct sk_buff___23 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___21;

struct Qdisc_ops___21 {
	struct Qdisc_ops___21 *next;
	const struct Qdisc_class_ops___21 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___23 *, struct Qdisc___21 *, struct sk_buff___23 **);
	struct sk_buff___23 * (*dequeue)(struct Qdisc___21 *);
	struct sk_buff___23 * (*peek)(struct Qdisc___21 *);
	int (*init)(struct Qdisc___21 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___21 *);
	void (*destroy)(struct Qdisc___21 *);
	int (*change)(struct Qdisc___21 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___21 *);
	int (*change_tx_queue_len)(struct Qdisc___21 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___21 *, unsigned int);
	int (*dump)(struct Qdisc___21 *, struct sk_buff___23 *);
	int (*dump_stats)(struct Qdisc___21 *, struct gnet_dump___21 *);
	void (*ingress_block_set)(struct Qdisc___21 *, u32);
	void (*egress_block_set)(struct Qdisc___21 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___21 *);
	u32 (*egress_block_get)(struct Qdisc___21 *);
	struct module___104 *owner;
};

struct Qdisc_class_ops___21 {
	unsigned int flags;
	struct netdev_queue___21 * (*select_queue)(struct Qdisc___21 *, struct tcmsg *);
	int (*graft)(struct Qdisc___21 *, long unsigned int, struct Qdisc___21 *, struct Qdisc___21 **, struct netlink_ext_ack *);
	struct Qdisc___21 * (*leaf)(struct Qdisc___21 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___21 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___21 *, u32);
	int (*change)(struct Qdisc___21 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___21 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___21 *, struct qdisc_walker *);
	struct tcf_block___21 * (*tcf_block)(struct Qdisc___21 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___21 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___21 *, long unsigned int);
	int (*dump)(struct Qdisc___21 *, long unsigned int, struct sk_buff___23 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___21 *, long unsigned int, struct gnet_dump___21 *);
};

struct tcf_chain___21;

struct tcf_block___21 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___24 *net;
	struct Qdisc___21 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___21 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___21;

struct tcf_proto_ops___21;

struct tcf_proto___21 {
	struct tcf_proto___21 *next;
	void *root;
	int (*classify)(struct sk_buff___23 *, const struct tcf_proto___21 *, struct tcf_result___21 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___21 *ops;
	struct tcf_chain___21 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___21 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___21 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___21 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___23 *, const struct tcf_proto___21 *, struct tcf_result___21 *);
	int (*init)(struct tcf_proto___21 *);
	void (*destroy)(struct tcf_proto___21 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___21 *, u32);
	void (*put)(struct tcf_proto___21 *, void *);
	int (*change)(struct net___24 *, struct sk_buff___23 *, struct tcf_proto___21 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___21 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___21 *);
	void (*walk)(struct tcf_proto___21 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___21 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___21 *, void *);
	void (*hw_del)(struct tcf_proto___21 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___24 *, struct tcf_chain___21 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___24 *, struct tcf_proto___21 *, void *, struct sk_buff___23 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___24 *, struct tcf_proto___21 *, void *, struct sk_buff___23 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___23 *, struct net___24 *, void *);
	struct module___104 *owner;
	int flags;
};

struct tcf_chain___21 {
	struct mutex filter_chain_lock;
	struct tcf_proto___21 *filter_chain;
	struct list_head list;
	struct tcf_block___21 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___21 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___14 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___21 *prog;
};

struct pneigh_entry___14;

struct neigh_hash_table___14;

struct neigh_table___14 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___25 *, __u32 *);
	bool (*key_eq)(const struct neighbour___14 *, const void *);
	int (*constructor)(struct neighbour___14 *);
	int (*pconstructor)(struct pneigh_entry___14 *);
	void (*pdestructor)(struct pneigh_entry___14 *);
	void (*proxy_redo)(struct sk_buff___23 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___25 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___14 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___21 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___14 *nht;
	struct pneigh_entry___14 **phash_buckets;
};

struct neigh_ops___14 {
	int family;
	void (*solicit)(struct neighbour___14 *, struct sk_buff___23 *);
	void (*error_report)(struct neighbour___14 *, struct sk_buff___23 *);
	int (*output)(struct neighbour___14 *, struct sk_buff___23 *);
	int (*connected_output)(struct neighbour___14 *, struct sk_buff___23 *);
};

struct pneigh_entry___14 {
	struct pneigh_entry___14 *next;
	possible_net_t___21 net;
	struct net_device___25 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___14 {
	struct neighbour___14 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___14 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___14 *ctarget;
	struct net___24 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___14 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___14 *rule;
	u32 table;
	int flags;
};

struct proto___14 {
	void (*close)(struct sock___15 *, long int);
	int (*pre_connect)(struct sock___15 *, struct sockaddr *, int);
	int (*connect)(struct sock___15 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___15 *, int);
	struct sock___15 * (*accept)(struct sock___15 *, int, int *, bool);
	int (*ioctl)(struct sock___15 *, int, long unsigned int);
	int (*init)(struct sock___15 *);
	void (*destroy)(struct sock___15 *);
	void (*shutdown)(struct sock___15 *, int);
	int (*setsockopt)(struct sock___15 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___15 *, int, int, char *, int *);
	void (*keepalive)(struct sock___15 *, int);
	int (*compat_ioctl)(struct sock___15 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___15 *, struct msghdr___14 *, size_t);
	int (*recvmsg)(struct sock___15 *, struct msghdr___14 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___15 *, struct page___117 *, int, size_t, int);
	int (*bind)(struct sock___15 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___15 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___15 *, struct sk_buff___23 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___15 *);
	int (*hash)(struct sock___15 *);
	void (*unhash)(struct sock___15 *);
	void (*rehash)(struct sock___15 *);
	int (*get_port)(struct sock___15 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___15 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___15 *, int);
	bool (*sock_is_readable)(struct sock___15 *);
	void (*enter_memory_pressure)(struct sock___15 *);
	void (*leave_memory_pressure)(struct sock___15 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___104 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___15 *, int);
};

struct unix_skb_parms {
	struct pid___99 *pid;
	kuid_t uid;
	kgid_t gid;
	struct scm_fp_list *fp;
	struct lsmblob lsmblob;
	u32 consumed;
};

struct wait_page_key___2 {
	struct page___117 *page;
	int bit_nr;
	int page_match;
};

struct trace_event_raw_io_uring_create {
	struct trace_entry ent;
	int fd;
	void *ctx;
	u32 sq_entries;
	u32 cq_entries;
	u32 flags;
	char __data[0];
};

struct trace_event_raw_io_uring_register {
	struct trace_entry ent;
	void *ctx;
	unsigned int opcode;
	unsigned int nr_files;
	unsigned int nr_bufs;
	bool eventfd;
	long int ret;
	char __data[0];
};

struct trace_event_raw_io_uring_file_get {
	struct trace_entry ent;
	void *ctx;
	int fd;
	char __data[0];
};

struct io_wq_work;

struct trace_event_raw_io_uring_queue_async_work {
	struct trace_entry ent;
	void *ctx;
	int rw;
	void *req;
	struct io_wq_work *work;
	unsigned int flags;
	char __data[0];
};

struct io_wq_work_node {
	struct io_wq_work_node *next;
};

struct io_wq_work {
	struct io_wq_work_node list;
	unsigned int flags;
};

struct trace_event_raw_io_uring_defer {
	struct trace_entry ent;
	void *ctx;
	void *req;
	long long unsigned int data;
	char __data[0];
};

struct trace_event_raw_io_uring_link {
	struct trace_entry ent;
	void *ctx;
	void *req;
	void *target_req;
	char __data[0];
};

struct trace_event_raw_io_uring_cqring_wait {
	struct trace_entry ent;
	void *ctx;
	int min_events;
	char __data[0];
};

struct trace_event_raw_io_uring_fail_link {
	struct trace_entry ent;
	void *req;
	void *link;
	char __data[0];
};

struct trace_event_raw_io_uring_complete {
	struct trace_entry ent;
	void *ctx;
	u64 user_data;
	int res;
	unsigned int cflags;
	char __data[0];
};

struct trace_event_raw_io_uring_submit_sqe {
	struct trace_entry ent;
	void *ctx;
	void *req;
	u8 opcode;
	u64 user_data;
	u32 flags;
	bool force_nonblock;
	bool sq_thread;
	char __data[0];
};

struct trace_event_raw_io_uring_poll_arm {
	struct trace_entry ent;
	void *ctx;
	void *req;
	u8 opcode;
	u64 user_data;
	int mask;
	int events;
	char __data[0];
};

struct trace_event_raw_io_uring_poll_wake {
	struct trace_entry ent;
	void *ctx;
	u8 opcode;
	u64 user_data;
	int mask;
	char __data[0];
};

struct trace_event_raw_io_uring_task_add {
	struct trace_entry ent;
	void *ctx;
	u8 opcode;
	u64 user_data;
	int mask;
	char __data[0];
};

struct trace_event_raw_io_uring_task_run {
	struct trace_entry ent;
	void *ctx;
	void *req;
	u8 opcode;
	u64 user_data;
	char __data[0];
};

struct trace_event_data_offsets_io_uring_create {};

struct trace_event_data_offsets_io_uring_register {};

struct trace_event_data_offsets_io_uring_file_get {};

struct trace_event_data_offsets_io_uring_queue_async_work {};

struct trace_event_data_offsets_io_uring_defer {};

struct trace_event_data_offsets_io_uring_link {};

struct trace_event_data_offsets_io_uring_cqring_wait {};

struct trace_event_data_offsets_io_uring_fail_link {};

struct trace_event_data_offsets_io_uring_complete {};

struct trace_event_data_offsets_io_uring_submit_sqe {};

struct trace_event_data_offsets_io_uring_poll_arm {};

struct trace_event_data_offsets_io_uring_poll_wake {};

struct trace_event_data_offsets_io_uring_task_add {};

struct trace_event_data_offsets_io_uring_task_run {};

typedef void (*btf_trace_io_uring_create)(void *, int, void *, u32, u32, u32);

typedef void (*btf_trace_io_uring_register)(void *, void *, unsigned int, unsigned int, unsigned int, bool, long int);

typedef void (*btf_trace_io_uring_file_get)(void *, void *, int);

typedef void (*btf_trace_io_uring_queue_async_work)(void *, void *, int, void *, struct io_wq_work *, unsigned int);

typedef void (*btf_trace_io_uring_defer)(void *, void *, void *, long long unsigned int);

typedef void (*btf_trace_io_uring_link)(void *, void *, void *, void *);

typedef void (*btf_trace_io_uring_cqring_wait)(void *, void *, int);

typedef void (*btf_trace_io_uring_fail_link)(void *, void *, void *);

typedef void (*btf_trace_io_uring_complete)(void *, void *, u64, int, unsigned int);

typedef void (*btf_trace_io_uring_submit_sqe)(void *, void *, void *, u8, u64, u32, bool, bool);

typedef void (*btf_trace_io_uring_poll_arm)(void *, void *, void *, u8, u64, int, int);

typedef void (*btf_trace_io_uring_poll_wake)(void *, void *, u8, u64, int);

typedef void (*btf_trace_io_uring_task_add)(void *, void *, u8, u64, int);

typedef void (*btf_trace_io_uring_task_run)(void *, void *, void *, u8, u64);

struct io_uring_sqe {
	__u8 opcode;
	__u8 flags;
	__u16 ioprio;
	__s32 fd;
	union {
		__u64 off;
		__u64 addr2;
	};
	union {
		__u64 addr;
		__u64 splice_off_in;
	};
	__u32 len;
	union {
		__kernel_rwf_t rw_flags;
		__u32 fsync_flags;
		__u16 poll_events;
		__u32 poll32_events;
		__u32 sync_range_flags;
		__u32 msg_flags;
		__u32 timeout_flags;
		__u32 accept_flags;
		__u32 cancel_flags;
		__u32 open_flags;
		__u32 statx_flags;
		__u32 fadvise_advice;
		__u32 splice_flags;
		__u32 rename_flags;
		__u32 unlink_flags;
		__u32 hardlink_flags;
	};
	__u64 user_data;
	union {
		__u16 buf_index;
		__u16 buf_group;
	};
	__u16 personality;
	union {
		__s32 splice_fd_in;
		__u32 file_index;
	};
	__u64 __pad2[2];
};

enum {
	IOSQE_FIXED_FILE_BIT = 0,
	IOSQE_IO_DRAIN_BIT = 1,
	IOSQE_IO_LINK_BIT = 2,
	IOSQE_IO_HARDLINK_BIT = 3,
	IOSQE_ASYNC_BIT = 4,
	IOSQE_BUFFER_SELECT_BIT = 5,
};

enum {
	IORING_OP_NOP = 0,
	IORING_OP_READV = 1,
	IORING_OP_WRITEV = 2,
	IORING_OP_FSYNC = 3,
	IORING_OP_READ_FIXED = 4,
	IORING_OP_WRITE_FIXED = 5,
	IORING_OP_POLL_ADD = 6,
	IORING_OP_POLL_REMOVE = 7,
	IORING_OP_SYNC_FILE_RANGE = 8,
	IORING_OP_SENDMSG = 9,
	IORING_OP_RECVMSG = 10,
	IORING_OP_TIMEOUT = 11,
	IORING_OP_TIMEOUT_REMOVE = 12,
	IORING_OP_ACCEPT = 13,
	IORING_OP_ASYNC_CANCEL = 14,
	IORING_OP_LINK_TIMEOUT = 15,
	IORING_OP_CONNECT = 16,
	IORING_OP_FALLOCATE = 17,
	IORING_OP_OPENAT = 18,
	IORING_OP_CLOSE = 19,
	IORING_OP_FILES_UPDATE = 20,
	IORING_OP_STATX = 21,
	IORING_OP_READ = 22,
	IORING_OP_WRITE = 23,
	IORING_OP_FADVISE = 24,
	IORING_OP_MADVISE = 25,
	IORING_OP_SEND = 26,
	IORING_OP_RECV = 27,
	IORING_OP_OPENAT2 = 28,
	IORING_OP_EPOLL_CTL = 29,
	IORING_OP_SPLICE = 30,
	IORING_OP_PROVIDE_BUFFERS = 31,
	IORING_OP_REMOVE_BUFFERS = 32,
	IORING_OP_TEE = 33,
	IORING_OP_SHUTDOWN = 34,
	IORING_OP_RENAMEAT = 35,
	IORING_OP_UNLINKAT = 36,
	IORING_OP_MKDIRAT = 37,
	IORING_OP_SYMLINKAT = 38,
	IORING_OP_LINKAT = 39,
	IORING_OP_LAST = 40,
};

struct io_uring_cqe {
	__u64 user_data;
	__s32 res;
	__u32 flags;
};

enum {
	IORING_CQE_BUFFER_SHIFT = 16,
};

struct io_sqring_offsets {
	__u32 head;
	__u32 tail;
	__u32 ring_mask;
	__u32 ring_entries;
	__u32 flags;
	__u32 dropped;
	__u32 array;
	__u32 resv1;
	__u64 resv2;
};

struct io_cqring_offsets {
	__u32 head;
	__u32 tail;
	__u32 ring_mask;
	__u32 ring_entries;
	__u32 overflow;
	__u32 cqes;
	__u32 flags;
	__u32 resv1;
	__u64 resv2;
};

struct io_uring_params {
	__u32 sq_entries;
	__u32 cq_entries;
	__u32 flags;
	__u32 sq_thread_cpu;
	__u32 sq_thread_idle;
	__u32 features;
	__u32 wq_fd;
	__u32 resv[3];
	struct io_sqring_offsets sq_off;
	struct io_cqring_offsets cq_off;
};

enum {
	IORING_REGISTER_BUFFERS = 0,
	IORING_UNREGISTER_BUFFERS = 1,
	IORING_REGISTER_FILES = 2,
	IORING_UNREGISTER_FILES = 3,
	IORING_REGISTER_EVENTFD = 4,
	IORING_UNREGISTER_EVENTFD = 5,
	IORING_REGISTER_FILES_UPDATE = 6,
	IORING_REGISTER_EVENTFD_ASYNC = 7,
	IORING_REGISTER_PROBE = 8,
	IORING_REGISTER_PERSONALITY = 9,
	IORING_UNREGISTER_PERSONALITY = 10,
	IORING_REGISTER_RESTRICTIONS = 11,
	IORING_REGISTER_ENABLE_RINGS = 12,
	IORING_REGISTER_FILES2 = 13,
	IORING_REGISTER_FILES_UPDATE2 = 14,
	IORING_REGISTER_BUFFERS2 = 15,
	IORING_REGISTER_BUFFERS_UPDATE = 16,
	IORING_REGISTER_IOWQ_AFF = 17,
	IORING_UNREGISTER_IOWQ_AFF = 18,
	IORING_REGISTER_IOWQ_MAX_WORKERS = 19,
	IORING_REGISTER_LAST = 20,
};

struct io_uring_rsrc_register {
	__u32 nr;
	__u32 resv;
	__u64 resv2;
	__u64 data;
	__u64 tags;
};

struct io_uring_rsrc_update2 {
	__u32 offset;
	__u32 resv;
	__u64 data;
	__u64 tags;
	__u32 nr;
	__u32 resv2;
};

struct io_uring_probe_op {
	__u8 op;
	__u8 resv;
	__u16 flags;
	__u32 resv2;
};

struct io_uring_probe {
	__u8 last_op;
	__u8 ops_len;
	__u16 resv;
	__u32 resv2[3];
	struct io_uring_probe_op ops[0];
};

struct io_uring_restriction {
	__u16 opcode;
	union {
		__u8 register_op;
		__u8 sqe_op;
		__u8 sqe_flags;
	};
	__u8 resv;
	__u32 resv2[3];
};

enum {
	IORING_RESTRICTION_REGISTER_OP = 0,
	IORING_RESTRICTION_SQE_OP = 1,
	IORING_RESTRICTION_SQE_FLAGS_ALLOWED = 2,
	IORING_RESTRICTION_SQE_FLAGS_REQUIRED = 3,
	IORING_RESTRICTION_LAST = 4,
};

struct io_uring_getevents_arg {
	__u64 sigmask;
	__u32 sigmask_sz;
	__u32 pad;
	__u64 ts;
};

enum {
	IO_WQ_WORK_CANCEL = 1,
	IO_WQ_WORK_HASHED = 2,
	IO_WQ_WORK_UNBOUND = 4,
	IO_WQ_WORK_CONCURRENT = 16,
	IO_WQ_HASH_SHIFT = 24,
};

enum io_wq_cancel {
	IO_WQ_CANCEL_OK = 0,
	IO_WQ_CANCEL_RUNNING = 1,
	IO_WQ_CANCEL_NOTFOUND = 2,
};

typedef struct io_wq_work *free_work_fn(struct io_wq_work *);

typedef void io_wq_work_fn(struct io_wq_work *);

struct io_wq_hash {
	refcount_t refs;
	long unsigned int map;
	struct wait_queue_head wait;
};

struct io_wq_data {
	struct io_wq_hash *hash;
	struct task_struct___119 *task;
	io_wq_work_fn *do_work;
	free_work_fn *free_work;
};

typedef bool work_cancel_fn(struct io_wq_work *, void *);

struct io_uring {
	u32 head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tail;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct io_rings {
	struct io_uring sq;
	struct io_uring cq;
	u32 sq_ring_mask;
	u32 cq_ring_mask;
	u32 sq_ring_entries;
	u32 cq_ring_entries;
	u32 sq_dropped;
	u32 sq_flags;
	u32 cq_flags;
	u32 cq_overflow;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct io_uring_cqe cqes[0];
};

enum io_uring_cmd_flags {
	IO_URING_F_NONBLOCK = 1,
	IO_URING_F_COMPLETE_DEFER = 2,
};

struct io_mapped_ubuf {
	u64 ubuf;
	u64 ubuf_end;
	unsigned int nr_bvecs;
	long unsigned int acct_pages;
	struct bio_vec___62 bvec[0];
};

struct io_overflow_cqe {
	struct io_uring_cqe cqe;
	struct list_head list;
};

struct io_fixed_file {
	long unsigned int file_ptr;
};

struct io_rsrc_put {
	struct list_head list;
	u64 tag;
	union {
		void *rsrc;
		struct file___112 *file;
		struct io_mapped_ubuf *buf;
	};
};

struct io_file_table {
	struct io_fixed_file *files;
};

struct io_rsrc_data;

struct io_rsrc_node {
	struct percpu_ref refs;
	struct list_head node;
	struct list_head rsrc_list;
	struct io_rsrc_data *rsrc_data;
	struct llist_node llist;
	bool done;
};

typedef void rsrc_put_fn(struct io_ring_ctx *, struct io_rsrc_put *);

struct io_rsrc_data {
	struct io_ring_ctx *ctx;
	u64 **tags;
	unsigned int nr;
	rsrc_put_fn *do_put;
	atomic_t refs;
	struct completion done;
	bool quiesce;
};

struct io_kiocb;

struct io_submit_link {
	struct io_kiocb *head;
	struct io_kiocb *last;
};

struct io_submit_state {
	struct blk_plug plug;
	struct io_submit_link link;
	void *reqs[32];
	unsigned int free_reqs;
	bool plug_started;
	struct io_kiocb *compl_reqs[32];
	unsigned int compl_nr;
	struct list_head free_list;
	unsigned int ios_left;
};

struct io_restriction {
	long unsigned int register_op[1];
	long unsigned int sqe_op[1];
	u8 sqe_flags_allowed;
	u8 sqe_flags_required;
	bool registered;
};

struct io_sq_data;

struct io_ring_ctx {
	struct {
		struct percpu_ref refs;
		struct io_rings *rings;
		unsigned int flags;
		unsigned int compat: 1;
		unsigned int drain_next: 1;
		unsigned int eventfd_async: 1;
		unsigned int restricted: 1;
		unsigned int off_timeout_used: 1;
		unsigned int drain_active: 1;
		long: 63;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		struct mutex uring_lock;
		u32 *sq_array;
		struct io_uring_sqe *sq_sqes;
		unsigned int cached_sq_head;
		unsigned int sq_entries;
		struct list_head defer_list;
		struct io_rsrc_node *rsrc_node;
		struct io_file_table file_table;
		unsigned int nr_user_files;
		unsigned int nr_user_bufs;
		struct io_mapped_ubuf **user_bufs;
		struct io_submit_state submit_state;
		struct list_head timeout_list;
		struct list_head ltimeout_list;
		struct list_head cq_overflow_list;
		struct xarray io_buffers;
		struct xarray personalities;
		u32 pers_next;
		unsigned int sq_thread_idle;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct list_head locked_free_list;
	unsigned int locked_free_nr;
	const struct cred___3 *sq_creds;
	struct io_sq_data *sq_data;
	struct wait_queue_head sqo_sq_wait;
	struct list_head sqd_list;
	long unsigned int check_cq_overflow;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct {
		unsigned int cached_cq_tail;
		unsigned int cq_entries;
		struct eventfd_ctx *cq_ev_fd;
		struct wait_queue_head poll_wait;
		struct wait_queue_head cq_wait;
		unsigned int cq_extra;
		atomic_t cq_timeouts;
		unsigned int cq_last_tm_flush;
		long: 32;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct {
		spinlock_t completion_lock;
		spinlock_t timeout_lock;
		struct list_head iopoll_list;
		struct hlist_head *cancel_hash;
		unsigned int cancel_hash_bits;
		bool poll_multi_queue;
		long: 24;
		long: 64;
		long: 64;
		long: 64;
	};
	struct io_restriction restrictions;
	struct {
		struct io_rsrc_node *rsrc_backup_node;
		struct io_mapped_ubuf *dummy_ubuf;
		struct io_rsrc_data *file_data;
		struct io_rsrc_data *buf_data;
		struct delayed_work rsrc_put_work;
		struct llist_head rsrc_put_llist;
		struct list_head rsrc_ref_list;
		spinlock_t rsrc_ref_lock;
	};
	struct {
		struct socket___14 *ring_sock;
		struct io_wq_hash *hash_map;
		struct user_struct *user;
		struct mm_struct___118 *mm_account;
		struct llist_head fallback_llist;
		struct delayed_work fallback_work;
		struct work_struct exit_work;
		struct list_head tctx_list;
		struct completion ref_comp;
		u32 iowq_limits[2];
		bool iowq_limits_set;
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct io_buffer {
	struct list_head list;
	__u64 addr;
	__u32 len;
	__u16 bid;
};

enum {
	IO_SQ_THREAD_SHOULD_STOP = 0,
	IO_SQ_THREAD_SHOULD_PARK = 1,
};

struct io_sq_data {
	refcount_t refs;
	atomic_t park_pending;
	struct mutex lock;
	struct list_head ctx_list;
	struct task_struct___119 *thread;
	struct wait_queue_head wait;
	unsigned int sq_thread_idle;
	int sq_cpu;
	pid_t task_pid;
	pid_t task_tgid;
	long unsigned int state;
	struct completion exited;
};

struct io_rw {
	struct kiocb___112 kiocb;
	u64 addr;
	u64 len;
};

struct io_poll_iocb {
	struct file___112 *file;
	struct wait_queue_head *head;
	__poll_t events;
	bool done;
	bool canceled;
	struct wait_queue_entry wait;
};

struct io_poll_update {
	struct file___112 *file;
	u64 old_user_data;
	u64 new_user_data;
	__poll_t events;
	bool update_events;
	bool update_user_data;
};

struct io_accept {
	struct file___112 *file;
	struct sockaddr *addr;
	int *addr_len;
	int flags;
	u32 file_slot;
	long unsigned int nofile;
};

struct io_sync {
	struct file___112 *file;
	loff_t len;
	loff_t off;
	int flags;
	int mode;
};

struct io_cancel {
	struct file___112 *file;
	u64 addr;
};

struct io_timeout {
	struct file___112 *file;
	u32 off;
	u32 target_seq;
	struct list_head list;
	struct io_kiocb *head;
	struct io_kiocb *prev;
};

struct io_timeout_rem {
	struct file___112 *file;
	u64 addr;
	struct timespec64 ts;
	u32 flags;
	bool ltimeout;
};

struct io_connect {
	struct file___112 *file;
	struct sockaddr *addr;
	int addr_len;
};

struct io_sr_msg {
	struct file___112 *file;
	union {
		struct compat_msghdr *umsg_compat;
		struct user_msghdr *umsg;
		void *buf;
	};
	int msg_flags;
	int bgid;
	size_t len;
	struct io_buffer *kbuf;
};

struct io_open {
	struct file___112 *file;
	int dfd;
	u32 file_slot;
	struct filename *filename;
	struct open_how how;
	long unsigned int nofile;
};

struct io_close {
	struct file___112 *file;
	int fd;
	u32 file_slot;
};

struct io_rsrc_update {
	struct file___112 *file;
	u64 arg;
	u32 nr_args;
	u32 offset;
};

struct io_fadvise {
	struct file___112 *file;
	u64 offset;
	u32 len;
	u32 advice;
};

struct io_madvise {
	struct file___112 *file;
	u64 addr;
	u32 len;
	u32 advice;
};

struct io_epoll {
	struct file___112 *file;
	int epfd;
	int op;
	int fd;
	struct epoll_event event;
};

struct io_splice {
	struct file___112 *file_out;
	loff_t off_out;
	loff_t off_in;
	u64 len;
	int splice_fd_in;
	unsigned int flags;
};

struct io_provide_buf {
	struct file___112 *file;
	__u64 addr;
	__u32 len;
	__u32 bgid;
	__u16 nbufs;
	__u16 bid;
};

struct io_statx {
	struct file___112 *file;
	int dfd;
	unsigned int mask;
	unsigned int flags;
	const char *filename;
	struct statx *buffer;
};

struct io_shutdown {
	struct file___112 *file;
	int how;
};

struct io_rename {
	struct file___112 *file;
	int old_dfd;
	int new_dfd;
	struct filename *oldpath;
	struct filename *newpath;
	int flags;
};

struct io_unlink {
	struct file___112 *file;
	int dfd;
	int flags;
	struct filename *filename;
};

struct io_mkdir {
	struct file___112 *file;
	int dfd;
	umode_t mode;
	struct filename *filename;
};

struct io_symlink {
	struct file___112 *file;
	int new_dfd;
	struct filename *oldpath;
	struct filename *newpath;
};

struct io_hardlink {
	struct file___112 *file;
	int old_dfd;
	int new_dfd;
	struct filename *oldpath;
	struct filename *newpath;
	int flags;
};

struct io_completion {
	struct file___112 *file;
	u32 cflags;
};

typedef void (*io_req_tw_func_t)(struct io_kiocb *, bool *);

struct io_task_work {
	union {
		struct io_wq_work_node node;
		struct llist_node fallback_node;
	};
	io_req_tw_func_t func;
};

struct async_poll;

struct io_kiocb {
	union {
		struct file___112 *file;
		struct io_rw rw;
		struct io_poll_iocb poll;
		struct io_poll_update poll_update;
		struct io_accept accept;
		struct io_sync sync;
		struct io_cancel cancel;
		struct io_timeout timeout;
		struct io_timeout_rem timeout_rem;
		struct io_connect connect;
		struct io_sr_msg sr_msg;
		struct io_open open;
		struct io_close close;
		struct io_rsrc_update rsrc_update;
		struct io_fadvise fadvise;
		struct io_madvise madvise;
		struct io_epoll epoll;
		struct io_splice splice;
		struct io_provide_buf pbuf;
		struct io_statx statx;
		struct io_shutdown shutdown;
		struct io_rename rename;
		struct io_unlink unlink;
		struct io_mkdir mkdir;
		struct io_symlink symlink;
		struct io_hardlink hardlink;
		struct io_completion compl;
	};
	void *async_data;
	u8 opcode;
	u8 iopoll_completed;
	u16 buf_index;
	u32 result;
	struct io_ring_ctx *ctx;
	unsigned int flags;
	atomic_t refs;
	struct task_struct___119 *task;
	u64 user_data;
	struct io_kiocb *link;
	struct percpu_ref *fixed_rsrc_refs;
	struct list_head inflight_entry;
	struct io_task_work io_task_work;
	struct hlist_node hash_node;
	struct async_poll *apoll;
	struct io_wq_work work;
	const struct cred___3 *creds;
	struct io_mapped_ubuf *imu;
};

struct io_timeout_data {
	struct io_kiocb *req;
	struct hrtimer timer;
	struct timespec64 ts;
	enum hrtimer_mode mode;
	u32 flags;
};

struct io_async_connect {
	struct __kernel_sockaddr_storage address;
};

struct io_async_msghdr {
	struct iovec fast_iov[8];
	struct iovec *free_iov;
	struct sockaddr *uaddr;
	struct msghdr___14 msg;
	struct __kernel_sockaddr_storage addr;
};

struct io_async_rw {
	struct iovec fast_iov[8];
	const struct iovec *free_iovec;
	struct iov_iter___64 iter;
	struct iov_iter_state iter_state;
	size_t bytes_done;
	struct wait_page_queue___51 wpq;
};

enum {
	REQ_F_FIXED_FILE_BIT = 0,
	REQ_F_IO_DRAIN_BIT = 1,
	REQ_F_LINK_BIT = 2,
	REQ_F_HARDLINK_BIT = 3,
	REQ_F_FORCE_ASYNC_BIT = 4,
	REQ_F_BUFFER_SELECT_BIT = 5,
	REQ_F_FAIL_BIT = 8,
	REQ_F_INFLIGHT_BIT = 9,
	REQ_F_CUR_POS_BIT = 10,
	REQ_F_NOWAIT_BIT = 11,
	REQ_F_LINK_TIMEOUT_BIT = 12,
	REQ_F_NEED_CLEANUP_BIT = 13,
	REQ_F_POLLED_BIT = 14,
	REQ_F_BUFFER_SELECTED_BIT = 15,
	REQ_F_COMPLETE_INLINE_BIT = 16,
	REQ_F_REISSUE_BIT = 17,
	REQ_F_CREDS_BIT = 18,
	REQ_F_REFCOUNT_BIT = 19,
	REQ_F_ARM_LTIMEOUT_BIT = 20,
	REQ_F_NOWAIT_READ_BIT = 21,
	REQ_F_NOWAIT_WRITE_BIT = 22,
	REQ_F_ISREG_BIT = 23,
	__REQ_F_LAST_BIT = 24,
};

enum {
	REQ_F_FIXED_FILE = 1,
	REQ_F_IO_DRAIN = 2,
	REQ_F_LINK = 4,
	REQ_F_HARDLINK = 8,
	REQ_F_FORCE_ASYNC = 16,
	REQ_F_BUFFER_SELECT = 32,
	REQ_F_FAIL = 256,
	REQ_F_INFLIGHT = 512,
	REQ_F_CUR_POS = 1024,
	REQ_F_NOWAIT = 2048,
	REQ_F_LINK_TIMEOUT = 4096,
	REQ_F_NEED_CLEANUP = 8192,
	REQ_F_POLLED = 16384,
	REQ_F_BUFFER_SELECTED = 32768,
	REQ_F_COMPLETE_INLINE = 65536,
	REQ_F_REISSUE = 131072,
	REQ_F_NOWAIT_READ = 2097152,
	REQ_F_NOWAIT_WRITE = 4194304,
	REQ_F_ISREG = 8388608,
	REQ_F_CREDS = 262144,
	REQ_F_REFCOUNT = 524288,
	REQ_F_ARM_LTIMEOUT = 1048576,
};

struct async_poll {
	struct io_poll_iocb poll;
	struct io_poll_iocb *double_poll;
};

enum {
	IORING_RSRC_FILE = 0,
	IORING_RSRC_BUFFER = 1,
};

struct io_tctx_node {
	struct list_head ctx_node;
	struct task_struct___119 *task;
	struct io_ring_ctx *ctx;
};

struct io_defer_entry {
	struct list_head list;
	struct io_kiocb *req;
	u32 seq;
};

struct io_op_def {
	unsigned int needs_file: 1;
	unsigned int hash_reg_file: 1;
	unsigned int unbound_nonreg_file: 1;
	unsigned int not_supported: 1;
	unsigned int pollin: 1;
	unsigned int pollout: 1;
	unsigned int buffer_select: 1;
	unsigned int needs_async_setup: 1;
	unsigned int plug: 1;
	short unsigned int async_size;
};

struct req_batch {
	struct task_struct___119 *task;
	int task_refs;
	int ctx_refs;
};

struct io_poll_table {
	struct poll_table_struct___80 pt;
	struct io_kiocb *req;
	int nr_entries;
	int error;
};

enum {
	IO_APOLL_OK = 0,
	IO_APOLL_ABORTED = 1,
	IO_APOLL_READY = 2,
};

struct io_cancel_data {
	struct io_ring_ctx *ctx;
	u64 user_data;
};

struct io_wait_queue {
	struct wait_queue_entry wq;
	struct io_ring_ctx *ctx;
	unsigned int cq_tail;
	unsigned int nr_timeouts;
};

struct io_tctx_exit {
	struct callback_head task_work;
	struct completion completion;
	struct io_ring_ctx *ctx;
};

struct io_task_cancel {
	struct task_struct___119 *task;
	bool all;
};

struct creds;

enum {
	IO_WQ_BOUND = 0,
	IO_WQ_UNBOUND = 1,
};

struct io_wq_data___2 {
	struct io_wq_hash *hash;
	struct task_struct___46 *task;
	io_wq_work_fn *do_work;
	free_work_fn *free_work;
};

enum {
	IO_WORKER_F_UP = 1,
	IO_WORKER_F_RUNNING = 2,
	IO_WORKER_F_FREE = 4,
	IO_WORKER_F_BOUND = 8,
};

enum {
	IO_WQ_BIT_EXIT = 0,
};

enum {
	IO_ACCT_STALLED_BIT = 0,
};

struct io_wqe;

struct io_worker {
	refcount_t ref;
	unsigned int flags;
	struct hlist_nulls_node nulls_node;
	struct list_head all_list;
	struct task_struct___46 *task;
	struct io_wqe *wqe;
	struct io_wq_work *cur_work;
	spinlock_t lock;
	struct completion ref_done;
	long unsigned int create_state;
	struct callback_head create_work;
	int create_index;
	union {
		struct callback_head rcu;
		struct work_struct work;
	};
};

struct io_wqe_acct {
	unsigned int nr_workers;
	unsigned int max_workers;
	int index;
	atomic_t nr_running;
	struct io_wq_work_list work_list;
	long unsigned int flags;
};

struct io_wq___2;

struct io_wqe {
	raw_spinlock_t lock;
	struct io_wqe_acct acct[2];
	int node;
	struct hlist_nulls_head free_list;
	struct list_head all_list;
	struct wait_queue_entry wait;
	struct io_wq___2 *wq;
	struct io_wq_work *hash_tail[64];
	cpumask_var_t cpu_mask;
};

enum {
	IO_WQ_ACCT_BOUND = 0,
	IO_WQ_ACCT_UNBOUND = 1,
	IO_WQ_ACCT_NR = 2,
};

struct io_wq___2 {
	long unsigned int state;
	free_work_fn *free_work;
	io_wq_work_fn *do_work;
	struct io_wq_hash *hash;
	atomic_t worker_refs;
	struct completion worker_done;
	struct hlist_node cpuhp_node;
	struct task_struct___46 *task;
	struct io_wqe *wqes[0];
};

struct io_cb_cancel_data {
	work_cancel_fn *fn;
	void *data;
	int nr_running;
	int nr_pending;
	bool cancel_all;
};

struct online_data {
	unsigned int cpu;
	bool online;
};

struct iomap_page_ops___2;

struct iomap___3 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___19 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops___2 *page_ops;
};

struct iomap_page_ops___2 {
	int (*page_prepare)(struct inode___38 *, loff_t, unsigned int);
	void (*page_done)(struct inode___38 *, loff_t, unsigned int, struct page___39 *);
};

struct iomap_ops {
	int (*iomap_begin)(struct inode___38 *, loff_t, loff_t, unsigned int, struct iomap___3 *, struct iomap___3 *);
	int (*iomap_end)(struct inode___38 *, loff_t, loff_t, ssize_t, unsigned int, struct iomap___3 *);
};

struct iomap_iter {
	struct inode___38 *inode;
	loff_t pos;
	u64 len;
	s64 processed;
	unsigned int flags;
	struct iomap___3 iomap;
	struct iomap___3 srcmap;
};

struct trace_event_raw_dax_pmd_fault_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_start;
	long unsigned int vm_end;
	long unsigned int vm_flags;
	long unsigned int address;
	long unsigned int pgoff;
	long unsigned int max_pgoff;
	dev_t dev;
	unsigned int flags;
	int result;
	char __data[0];
};

struct trace_event_raw_dax_pmd_load_hole_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	struct page___39 *zero_page;
	void *radix_entry;
	dev_t dev;
	char __data[0];
};

struct trace_event_raw_dax_pmd_insert_mapping_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	long int length;
	u64 pfn_val;
	void *radix_entry;
	dev_t dev;
	int write;
	char __data[0];
};

struct trace_event_raw_dax_pte_fault_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	long unsigned int pgoff;
	dev_t dev;
	unsigned int flags;
	int result;
	char __data[0];
};

struct trace_event_raw_dax_insert_mapping {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int vm_flags;
	long unsigned int address;
	void *radix_entry;
	dev_t dev;
	int write;
	char __data[0];
};

struct trace_event_raw_dax_writeback_range_class {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int start_index;
	long unsigned int end_index;
	dev_t dev;
	char __data[0];
};

struct trace_event_raw_dax_writeback_one {
	struct trace_entry ent;
	long unsigned int ino;
	long unsigned int pgoff;
	long unsigned int pglen;
	dev_t dev;
	char __data[0];
};

struct trace_event_data_offsets_dax_pmd_fault_class {};

struct trace_event_data_offsets_dax_pmd_load_hole_class {};

struct trace_event_data_offsets_dax_pmd_insert_mapping_class {};

struct trace_event_data_offsets_dax_pte_fault_class {};

struct trace_event_data_offsets_dax_insert_mapping {};

struct trace_event_data_offsets_dax_writeback_range_class {};

struct trace_event_data_offsets_dax_writeback_one {};

typedef void (*btf_trace_dax_pmd_fault)(void *, struct inode___38 *, struct vm_fault___37 *, long unsigned int, int);

typedef void (*btf_trace_dax_pmd_fault_done)(void *, struct inode___38 *, struct vm_fault___37 *, long unsigned int, int);

typedef void (*btf_trace_dax_pmd_load_hole)(void *, struct inode___38 *, struct vm_fault___37 *, struct page___39 *, void *);

typedef void (*btf_trace_dax_pmd_load_hole_fallback)(void *, struct inode___38 *, struct vm_fault___37 *, struct page___39 *, void *);

typedef void (*btf_trace_dax_pmd_insert_mapping)(void *, struct inode___38 *, struct vm_fault___37 *, long int, pfn_t, void *);

typedef void (*btf_trace_dax_pte_fault)(void *, struct inode___38 *, struct vm_fault___37 *, int);

typedef void (*btf_trace_dax_pte_fault_done)(void *, struct inode___38 *, struct vm_fault___37 *, int);

typedef void (*btf_trace_dax_load_hole)(void *, struct inode___38 *, struct vm_fault___37 *, int);

typedef void (*btf_trace_dax_insert_pfn_mkwrite_no_entry)(void *, struct inode___38 *, struct vm_fault___37 *, int);

typedef void (*btf_trace_dax_insert_pfn_mkwrite)(void *, struct inode___38 *, struct vm_fault___37 *, int);

typedef void (*btf_trace_dax_insert_mapping)(void *, struct inode___38 *, struct vm_fault___37 *, void *);

typedef void (*btf_trace_dax_writeback_range)(void *, struct inode___38 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_dax_writeback_range_done)(void *, struct inode___38 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_dax_writeback_one)(void *, struct inode___38 *, long unsigned int, long unsigned int);

struct exceptional_entry_key {
	struct xarray *xa;
	long unsigned int entry_start;
};

struct wait_exceptional_entry_queue {
	wait_queue_entry_t wait;
	struct exceptional_entry_key key;
};

enum dax_wake_mode {
	WAKE_ALL = 0,
	WAKE_NEXT = 1,
};

struct crypto_skcipher;

struct fscrypt_blk_crypto_key;

struct fscrypt_prepared_key {
	struct crypto_skcipher *tfm;
	struct fscrypt_blk_crypto_key *blk_key;
};

struct fscrypt_mode;

struct fscrypt_direct_key;

struct fscrypt_info {
	struct fscrypt_prepared_key ci_enc_key;
	bool ci_owns_key;
	bool ci_inlinecrypt;
	struct fscrypt_mode *ci_mode;
	struct inode___90 *ci_inode;
	struct key___2 *ci_master_key;
	struct list_head ci_master_key_link;
	struct fscrypt_direct_key *ci_direct_key;
	siphash_key_t___2 ci_dirhash_key;
	bool ci_dirhash_key_initialized;
	union fscrypt_policy ci_policy;
	u8 ci_nonce[16];
	u32 ci_hashed_ino;
};

struct crypto_async_request___2;

typedef void (*crypto_completion_t___2)(struct crypto_async_request___2 *, int);

struct crypto_tfm___4;

struct crypto_async_request___2 {
	struct list_head list;
	crypto_completion_t___2 complete;
	void *data;
	struct crypto_tfm___4 *tfm;
	u32 flags;
};

struct crypto_alg___4;

struct crypto_tfm___4 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___4 *);
	struct crypto_alg___4 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___3 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___4 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___4 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___4 *, u8 *, const u8 *);
};

struct compress_alg___3 {
	int (*coa_compress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___4 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___4 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___3 cipher;
		struct compress_alg___3 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___4 *);
	void (*cra_exit)(struct crypto_tfm___4 *);
	void (*cra_destroy)(struct crypto_alg___4 *);
	struct module___88 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct skcipher_request {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___2 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___4 base;
};

struct fscrypt_mode {
	const char *friendly_name;
	const char *cipher_str;
	int keysize;
	int security_strength;
	int ivsize;
	int logged_impl_name;
	enum blk_crypto_mode_num blk_crypto_mode;
};

typedef enum {
	FS_DECRYPT = 0,
	FS_ENCRYPT = 1,
} fscrypt_direction_t;

union fscrypt_iv {
	struct {
		__le64 lblk_num;
		u8 nonce[16];
	};
	u8 raw[32];
	__le64 dun[4];
};

struct fscrypt_str {
	unsigned char *name;
	u32 len;
};

struct fscrypt_name {
	const struct qstr *usr_fname;
	struct fscrypt_str disk_name;
	u32 hash;
	u32 minor_hash;
	struct fscrypt_str crypto_buf;
	bool is_nokey_name;
};

struct fscrypt_nokey_name {
	u32 dirhash[2];
	u8 bytes[149];
	u8 sha256[32];
};

struct crypto_shash___2;

struct shash_desc___2 {
	struct crypto_shash___2 *tfm;
	void *__ctx[0];
};

struct crypto_shash___2 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___4 base;
};

struct shash_alg {
	int (*init)(struct shash_desc___2 *);
	int (*update)(struct shash_desc___2 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___2 *, u8 *);
	int (*finup)(struct shash_desc___2 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___2 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___2 *, void *);
	int (*import)(struct shash_desc___2 *, const void *);
	int (*setkey)(struct crypto_shash___2 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___2 *);
	void (*exit_tfm)(struct crypto_shash___2 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___4 base;
};

struct fscrypt_hkdf {
	struct crypto_shash___2 *hmac_tfm;
};

struct fscrypt_key_specifier {
	__u32 type;
	__u32 __reserved;
	union {
		__u8 __reserved[32];
		__u8 descriptor[8];
		__u8 identifier[16];
	} u;
};

struct fscrypt_symlink_data {
	__le16 len;
	char encrypted_path[1];
} __attribute__((packed));

struct fscrypt_master_key_secret {
	struct fscrypt_hkdf hkdf;
	u32 size;
	u8 raw[64];
};

struct fscrypt_master_key {
	struct fscrypt_master_key_secret mk_secret;
	struct fscrypt_key_specifier mk_spec;
	struct key___2 *mk_users;
	refcount_t mk_refcount;
	struct list_head mk_decrypted_inodes;
	spinlock_t mk_decrypted_inodes_lock;
	struct fscrypt_prepared_key mk_direct_keys[10];
	struct fscrypt_prepared_key mk_iv_ino_lblk_64_keys[10];
	struct fscrypt_prepared_key mk_iv_ino_lblk_32_keys[10];
	siphash_key_t___2 mk_ino_hash_key;
	bool mk_ino_hash_key_initialized;
};

struct dentry___113;

struct super_block___113;

struct module___105;

struct file_system_type___113 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___113 * (*mount)(struct file_system_type___113 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___113 *);
	struct module___105 *owner;
	struct file_system_type___113 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___113;

struct kiocb___113;

struct iov_iter___65;

struct vm_area_struct___118;

struct inode___113;

struct file_lock___113;

struct page___118;

struct seq_file___102;

struct file_operations___113 {
	struct module___105 *owner;
	loff_t (*llseek)(struct file___113 *, loff_t, int);
	ssize_t (*read)(struct file___113 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___113 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___113 *, struct iov_iter___65 *);
	ssize_t (*write_iter)(struct kiocb___113 *, struct iov_iter___65 *);
	int (*iopoll)(struct kiocb___113 *, bool);
	int (*iterate)(struct file___113 *, struct dir_context *);
	int (*iterate_shared)(struct file___113 *, struct dir_context *);
	__poll_t (*poll)(struct file___113 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___113 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___113 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___113 *, struct vm_area_struct___118 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___113 *, struct file___113 *);
	int (*flush)(struct file___113 *, fl_owner_t);
	int (*release)(struct inode___113 *, struct file___113 *);
	int (*fsync)(struct file___113 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___113 *, int);
	int (*lock)(struct file___113 *, int, struct file_lock___113 *);
	ssize_t (*sendpage)(struct file___113 *, struct page___118 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___113 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___113 *, long unsigned int);
	int (*flock)(struct file___113 *, int, struct file_lock___113 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___113 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___113 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___113 *, long int, struct file_lock___113 **, void **);
	long int (*fallocate)(struct file___113 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___102 *, struct file___113 *);
	ssize_t (*copy_file_range)(struct file___113 *, loff_t, struct file___113 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___113 *, loff_t, struct file___113 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___113 *, loff_t, loff_t, int);
};

struct vmacache___118 {
	u64 seqnum;
	struct vm_area_struct___118 *vmas[4];
};

struct page_frag___118 {
	struct page___118 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___119;

struct pid___100;

struct cred___14;

struct key___3;

struct nsproxy___106;

struct signal_struct___114;

struct bio_list___52;

struct io_context___52;

struct request_queue___52;

struct vm_struct___104;

struct task_struct___120 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___120 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___119 *mm;
	struct mm_struct___119 *active_mm;
	struct vmacache___118 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___120 *real_parent;
	struct task_struct___120 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___120 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___100 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___106 *nsproxy;
	struct signal_struct___114 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___120 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___52 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___52 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___118 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___52 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___120 *oom_reaper_list;
	struct vm_struct___104 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___107;

struct kobj_type___107;

struct kernfs_node___107;

struct kobject___107 {
	const char *name;
	struct list_head entry;
	struct kobject___107 *parent;
	struct kset___107 *kset;
	struct kobj_type___107 *ktype;
	struct kernfs_node___107 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___104 {
	struct kobject___107 kobj;
	struct module___105 *mod;
	struct kobject___107 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___104 {
	struct module___105 *mod;
	struct latch_tree_node node;
};

struct module_layout___104 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___104 mtn;
};

struct module_attribute___104;

struct kernel_param___104;

struct module___105 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___104 mkobj;
	struct module_attribute___104 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___107 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___104 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___104 core_layout;
	struct module_layout___104 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___118 *pgtable_t___118;

struct address_space___113;

struct dev_pagemap___112;

struct page___118 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___113 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___118 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___118 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___119 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___112 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___112;

struct vm_area_struct___118 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___118 *vm_next;
	struct vm_area_struct___118 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___119 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___112 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___113 *vm_file;
	struct file___113 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___118;

struct mm_struct___119 {
	struct {
		struct vm_area_struct___118 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___113 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___118 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___120 *owner;
		struct user_namespace *user_ns;
		struct file___113 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___113;

struct address_space___113 {
	struct inode___113 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___113 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___112;

struct dev_pagemap___112 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___112 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___113;

struct path___113 {
	struct vfsmount___113 *mnt;
	struct dentry___113 *dentry;
};

struct fown_struct___100 {
	rwlock_t lock;
	struct pid___100 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___113 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___113 f_path;
	struct inode___113 *f_inode;
	const struct file_operations___113 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___100 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___113 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___112;

struct vm_operations_struct___112 {
	void (*open)(struct vm_area_struct___118 *);
	void (*close)(struct vm_area_struct___118 *);
	int (*may_split)(struct vm_area_struct___118 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___118 *);
	int (*mprotect)(struct vm_area_struct___118 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___112 *);
	vm_fault_t (*huge_fault)(struct vm_fault___112 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___112 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___118 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___112 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___112 *);
	int (*access)(struct vm_area_struct___118 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___118 *);
	int (*set_policy)(struct vm_area_struct___118 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___118 *, long unsigned int);
	struct page___118 * (*find_special_page)(struct vm_area_struct___118 *, long unsigned int);
};

struct core_thread___118 {
	struct task_struct___120 *task;
	struct core_thread___118 *next;
};

struct core_state___118 {
	atomic_t nr_threads;
	struct core_thread___118 dumper;
	struct completion startup;
};

struct vm_fault___112 {
	const struct {
		struct vm_area_struct___118 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___118 *cow_page;
	struct page___118 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___118 prealloc_pte;
};

struct crypto_tfm___2 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___2 *);
	struct crypto_alg___2 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___4 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___2 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___2 *, u8 *, const u8 *);
};

struct compress_alg___4 {
	int (*coa_compress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___2 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___2 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___4 cipher;
		struct compress_alg___4 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___2 *);
	void (*cra_exit)(struct crypto_tfm___2 *);
	void (*cra_destroy)(struct crypto_alg___2 *);
	struct module___105 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_skcipher___2 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___2 base;
};

struct key_type___2;

struct keyring_index_key___2 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___2 *type;
	struct key_tag *domain_tag;
	const char *description;
};

typedef int (*request_key_actor_t___2)(struct key___3 *, void *);

struct key_match_data___2;

struct key_restriction___3;

struct kernel_pkey_params___2;

struct key_type___2 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___3 *, struct key_preparsed_payload *);
	int (*update)(struct key___3 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___2 *);
	void (*match_free)(struct key_match_data___2 *);
	void (*revoke)(struct key___3 *);
	void (*destroy)(struct key___3 *);
	void (*describe)(const struct key___3 *, struct seq_file___102 *);
	long int (*read)(const struct key___3 *, char *, size_t);
	request_key_actor_t___2 request_key;
	struct key_restriction___3 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___2 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___2 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___2 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___3)(struct key___3 *, const struct key_type___2 *, const union key_payload *, struct key___3 *);

struct key___3 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___2 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___2 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___3 *restrict_link;
};

struct key_restriction___3 {
	key_restrict_link_func_t___3 check;
	struct key___3 *key;
	struct key_type___2 *keytype;
};

enum key_state {
	KEY_IS_UNINSTANTIATED = 0,
	KEY_IS_POSITIVE = 1,
};

struct key_match_data___2 {
	bool (*cmp)(const struct key___3 *, const struct key_match_data___2 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct seq_operations___102;

struct seq_file___102 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___102 *op;
	int poll_event;
	const struct file___113 *file;
	void *private;
};

struct key___4;

struct kernel_pkey_params___2 {
	struct key___4 *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___113;

struct dentry___113 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___113 *d_parent;
	struct qstr d_name;
	struct inode___113 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___113 *d_op;
	struct super_block___113 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___113;

struct fscrypt_info___2;

struct inode___113 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___113 *i_op;
	struct super_block___113 *i_sb;
	struct address_space___113 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___113 *i_fop;
		void (*free_inode)(struct inode___113 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___113 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info___2 *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___113 {
	int (*d_revalidate)(struct dentry___113 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___113 *, unsigned int);
	int (*d_hash)(const struct dentry___113 *, struct qstr *);
	int (*d_compare)(const struct dentry___113 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___113 *);
	int (*d_init)(struct dentry___113 *);
	void (*d_release)(struct dentry___113 *);
	void (*d_prune)(struct dentry___113 *);
	void (*d_iput)(struct dentry___113 *, struct inode___113 *);
	char * (*d_dname)(struct dentry___113 *, char *, int);
	struct vfsmount___113 * (*d_automount)(struct path___113 *);
	int (*d_manage)(const struct path___113 *, bool);
	struct dentry___113 * (*d_real)(struct dentry___113 *, const struct inode___113 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___113;

struct mem_dqinfo___113 {
	struct quota_format_type___113 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___113;

struct quota_info___113 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___113 *files[3];
	struct mem_dqinfo___113 info[3];
	const struct quota_format_ops___113 *ops[3];
};

struct rcuwait___114 {
	struct task_struct___120 *task;
};

struct percpu_rw_semaphore___114 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___114 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___113 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___114 rw_sem[3];
};

struct super_operations___113;

struct dquot_operations___113;

struct quotactl_ops___113;

struct fscrypt_operations___6;

struct block_device___53;

struct super_block___113 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___113 *s_type;
	const struct super_operations___113 *s_op;
	const struct dquot_operations___113 *dq_op;
	const struct quotactl_ops___113 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___113 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___6 *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___53 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___113 s_dquot;
	struct sb_writers___113 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___113 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___113 {
	struct dentry___113 *mnt_root;
	struct super_block___113 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct pid_namespace___100;

struct upid___100 {
	int nr;
	struct pid_namespace___100 *ns;
};

struct pid_namespace___100 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___120 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___100 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___100 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___100 numbers[1];
};

struct signal_struct___114 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___120 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___120 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___100 *pids[4];
	struct pid___100 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___119 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___14 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct nsproxy___106 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___100 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___52;

struct bio_list___52 {
	struct bio___52 *head;
	struct bio___52 *tail;
};

struct io_cq___52;

struct io_context___52 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___52 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___52;

struct blk_integrity___52 {
	const struct blk_integrity_profile___52 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___52 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___52 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___52;

struct elevator_queue___52;

struct gendisk___52;

struct device___88;

struct request_queue___52 {
	struct request___52 *last_merge;
	struct elevator_queue___52 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___52 *disk;
	struct kobject___107 kobj;
	struct kobject___107 *mq_kobj;
	struct blk_integrity___52 integrity;
	struct device___88 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___52 bio_split;
	struct dentry___113 *debugfs_dir;
	struct dentry___113 *sched_debugfs_dir;
	struct dentry___113 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___104 {
	struct vm_struct___104 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___118 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct io_cq___52 {
	struct request_queue___52 *q;
	struct io_context___52 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___113 {
	struct file___113 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___113 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___51 *ki_waitq;
	};
};

struct iattr___113 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___113 *ia_file;
};

struct dquot___113 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___113 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___113 {
	int qf_fmt_id;
	const struct quota_format_ops___113 *qf_ops;
	struct module___105 *qf_owner;
	struct quota_format_type___113 *qf_next;
};

struct quota_format_ops___113 {
	int (*check_quota_file)(struct super_block___113 *, int);
	int (*read_file_info)(struct super_block___113 *, int);
	int (*write_file_info)(struct super_block___113 *, int);
	int (*free_file_info)(struct super_block___113 *, int);
	int (*read_dqblk)(struct dquot___113 *);
	int (*commit_dqblk)(struct dquot___113 *);
	int (*release_dqblk)(struct dquot___113 *);
	int (*get_next_id)(struct super_block___113 *, struct kqid *);
};

struct dquot_operations___113 {
	int (*write_dquot)(struct dquot___113 *);
	struct dquot___113 * (*alloc_dquot)(struct super_block___113 *, int);
	void (*destroy_dquot)(struct dquot___113 *);
	int (*acquire_dquot)(struct dquot___113 *);
	int (*release_dquot)(struct dquot___113 *);
	int (*mark_dirty)(struct dquot___113 *);
	int (*write_info)(struct super_block___113 *, int);
	qsize_t * (*get_reserved_space)(struct inode___113 *);
	int (*get_projid)(struct inode___113 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___113 *, qsize_t *);
	int (*get_next_id)(struct super_block___113 *, struct kqid *);
};

struct quotactl_ops___113 {
	int (*quota_on)(struct super_block___113 *, int, int, const struct path___113 *);
	int (*quota_off)(struct super_block___113 *, int);
	int (*quota_enable)(struct super_block___113 *, unsigned int);
	int (*quota_disable)(struct super_block___113 *, unsigned int);
	int (*quota_sync)(struct super_block___113 *, int);
	int (*set_info)(struct super_block___113 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___113 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___113 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___113 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___113 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___113 *, unsigned int);
};

struct address_space_operations___113 {
	int (*writepage)(struct page___118 *, struct writeback_control___3 *);
	int (*readpage)(struct file___113 *, struct page___118 *);
	int (*writepages)(struct address_space___113 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___118 *);
	int (*readpages)(struct file___113 *, struct address_space___113 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___113 *, struct address_space___113 *, loff_t, unsigned int, unsigned int, struct page___118 **, void **);
	int (*write_end)(struct file___113 *, struct address_space___113 *, loff_t, unsigned int, unsigned int, struct page___118 *, void *);
	sector_t (*bmap)(struct address_space___113 *, sector_t);
	void (*invalidatepage)(struct page___118 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___118 *, gfp_t);
	void (*freepage)(struct page___118 *);
	ssize_t (*direct_IO)(struct kiocb___113 *, struct iov_iter___65 *);
	int (*migratepage)(struct address_space___113 *, struct page___118 *, struct page___118 *, enum migrate_mode);
	bool (*isolate_page)(struct page___118 *, isolate_mode_t);
	void (*putback_page)(struct page___118 *);
	int (*launder_page)(struct page___118 *);
	int (*is_partially_uptodate)(struct page___118 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___118 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___113 *, struct page___118 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___113 *, sector_t *);
	void (*swap_deactivate)(struct file___113 *);
};

struct bio_vec___63;

struct iov_iter___65 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___63 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___113 {
	struct dentry___113 * (*lookup)(struct inode___113 *, struct dentry___113 *, unsigned int);
	const char * (*get_link)(struct dentry___113 *, struct inode___113 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___113 *, int);
	struct posix_acl * (*get_acl)(struct inode___113 *, int, bool);
	int (*readlink)(struct dentry___113 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___113 *, struct dentry___113 *, umode_t, bool);
	int (*link)(struct dentry___113 *, struct inode___113 *, struct dentry___113 *);
	int (*unlink)(struct inode___113 *, struct dentry___113 *);
	int (*symlink)(struct user_namespace *, struct inode___113 *, struct dentry___113 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___113 *, struct dentry___113 *, umode_t);
	int (*rmdir)(struct inode___113 *, struct dentry___113 *);
	int (*mknod)(struct user_namespace *, struct inode___113 *, struct dentry___113 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___113 *, struct dentry___113 *, struct inode___113 *, struct dentry___113 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___113 *, struct iattr___113 *);
	int (*getattr)(struct user_namespace *, const struct path___113 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___113 *, char *, size_t);
	int (*fiemap)(struct inode___113 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___113 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___113 *, struct dentry___113 *, struct file___113 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___113 *, struct dentry___113 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___113 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___113 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___113 *, struct fileattr *);
	long: 64;
};

struct fscrypt_prepared_key___2 {
	struct crypto_skcipher___2 *tfm;
	struct fscrypt_blk_crypto_key *blk_key;
};

struct fscrypt_info___2 {
	struct fscrypt_prepared_key___2 ci_enc_key;
	bool ci_owns_key;
	bool ci_inlinecrypt;
	struct fscrypt_mode *ci_mode;
	struct inode___113 *ci_inode;
	struct key___3 *ci_master_key;
	struct list_head ci_master_key_link;
	struct fscrypt_direct_key *ci_direct_key;
	siphash_key_t___2 ci_dirhash_key;
	bool ci_dirhash_key_initialized;
	union fscrypt_policy ci_policy;
	u8 ci_nonce[16];
	u32 ci_hashed_ino;
};

struct file_lock_operations___113 {
	void (*fl_copy_lock)(struct file_lock___113 *, struct file_lock___113 *);
	void (*fl_release_private)(struct file_lock___113 *);
};

struct fasync_struct___113;

struct lock_manager_operations___113;

struct file_lock___113 {
	struct file_lock___113 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___113 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___113 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___113 *fl_ops;
	const struct lock_manager_operations___113 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___113 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___113 *);
	int (*lm_grant)(struct file_lock___113 *, int);
	bool (*lm_break)(struct file_lock___113 *);
	int (*lm_change)(struct file_lock___113 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___113 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___113 *);
};

struct fasync_struct___113 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___113 *fa_next;
	struct file___113 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___113 {
	struct inode___113 * (*alloc_inode)(struct super_block___113 *);
	void (*destroy_inode)(struct inode___113 *);
	void (*free_inode)(struct inode___113 *);
	void (*dirty_inode)(struct inode___113 *, int);
	int (*write_inode)(struct inode___113 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___113 *);
	void (*evict_inode)(struct inode___113 *);
	void (*put_super)(struct super_block___113 *);
	int (*sync_fs)(struct super_block___113 *, int);
	int (*freeze_super)(struct super_block___113 *);
	int (*freeze_fs)(struct super_block___113 *);
	int (*thaw_super)(struct super_block___113 *);
	int (*unfreeze_fs)(struct super_block___113 *);
	int (*statfs)(struct dentry___113 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___113 *, int *, char *);
	void (*umount_begin)(struct super_block___113 *);
	int (*show_options)(struct seq_file___102 *, struct dentry___113 *);
	int (*show_devname)(struct seq_file___102 *, struct dentry___113 *);
	int (*show_path)(struct seq_file___102 *, struct dentry___113 *);
	int (*show_stats)(struct seq_file___102 *, struct dentry___113 *);
	ssize_t (*quota_read)(struct super_block___113 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___113 *, int, const char *, size_t, loff_t);
	struct dquot___113 ** (*get_dquots)(struct inode___113 *);
	long int (*nr_cached_objects)(struct super_block___113 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___113 *, struct shrink_control___45 *);
	struct file___113 * (*real_loop)(struct file___113 *);
};

struct fscrypt_operations___6 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___113 *, void *, size_t);
	int (*set_context)(struct inode___113 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___113 *);
	bool (*empty_dir)(struct inode___113 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___113 *);
	void (*get_ino_and_lblk_bits)(struct super_block___113 *, int *, int *);
	int (*get_num_devices)(struct super_block___113 *);
	void (*get_devices)(struct super_block___113 *, struct request_queue___52 **);
};

struct wakeup_source___88;

struct dev_pm_info___88 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___88 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___88 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___88;

struct bus_type___88;

struct device_driver___88;

struct dev_pm_domain___88;

struct fwnode_handle___88;

struct class___88;

struct attribute_group___107;

struct device___88 {
	struct kobject___107 kobj;
	struct device___88 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___88 *type;
	struct bus_type___88 *bus;
	struct device_driver___88 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___88 power;
	struct dev_pm_domain___88 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___88 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___88 *class;
	const struct attribute_group___107 **groups;
	void (*release)(struct device___88 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___53 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___113 *bd_inode;
	struct super_block___113 *bd_super;
	void *bd_claiming;
	struct device___88 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___107 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___52 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___113 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___52(struct bio___52 *);

struct bio_vec___63 {
	struct page___118 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___52;

struct bio___52 {
	struct bio___52 *bi_next;
	struct block_device___53 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___52 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___52 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___63 *bi_io_vec;
	struct bio_set___52 *bi_pool;
	struct bio_vec___63 bi_inline_vecs[0];
};

struct seq_operations___102 {
	void * (*start)(struct seq_file___102 *, loff_t *);
	void (*stop)(struct seq_file___102 *, void *);
	void * (*next)(struct seq_file___102 *, void *, loff_t *);
	int (*show)(struct seq_file___102 *, void *);
};

struct dev_pagemap_ops___112 {
	void (*page_free)(struct page___118 *);
	void (*kill)(struct dev_pagemap___112 *);
	void (*cleanup)(struct dev_pagemap___112 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___112 *);
};

struct fscrypt_provisioning_key_payload {
	__u32 type;
	__u32 __reserved;
	__u8 raw[0];
};

struct fscrypt_add_key_arg {
	struct fscrypt_key_specifier key_spec;
	__u32 raw_size;
	__u32 key_id;
	__u32 __reserved[8];
	__u8 raw[0];
};

struct fscrypt_remove_key_arg {
	struct fscrypt_key_specifier key_spec;
	__u32 removal_status_flags;
	__u32 __reserved[5];
};

struct fscrypt_get_key_status_arg {
	struct fscrypt_key_specifier key_spec;
	__u32 __reserved[6];
	__u32 status;
	__u32 status_flags;
	__u32 user_count;
	__u32 __out_reserved[13];
};

struct crypto_shash___3 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___2 base;
};

struct fwnode_operations___88;

struct fwnode_handle___88 {
	struct fwnode_handle___88 *secondary;
	const struct fwnode_operations___88 *ops;
	struct device___88 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___88;

struct fwnode_endpoint___88;

struct fwnode_operations___88 {
	struct fwnode_handle___88 * (*get)(struct fwnode_handle___88 *);
	void (*put)(struct fwnode_handle___88 *);
	bool (*device_is_available)(const struct fwnode_handle___88 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___88 *, const struct device___88 *);
	bool (*property_present)(const struct fwnode_handle___88 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___88 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___88 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___88 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*get_parent)(const struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*get_next_child_node)(const struct fwnode_handle___88 *, struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*get_named_child_node)(const struct fwnode_handle___88 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___88 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___88 *);
	struct fwnode_handle___88 * (*graph_get_next_endpoint)(const struct fwnode_handle___88 *, struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*graph_get_remote_endpoint)(const struct fwnode_handle___88 *);
	struct fwnode_handle___88 * (*graph_get_port_parent)(struct fwnode_handle___88 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___88 *, struct fwnode_endpoint___88 *);
	int (*add_links)(struct fwnode_handle___88 *);
};

struct fwnode_endpoint___88 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___88 *local_fwnode;
};

struct fwnode_reference_args___88 {
	struct fwnode_handle___88 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___107;

struct kernfs_elem_dir___107 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___107 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___107;

struct kernfs_root___107 {
	struct kernfs_node___107 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___107 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___107 {
	struct kernfs_node___107 *target_kn;
};

struct kernfs_ops___107;

struct kernfs_elem_attr___107 {
	const struct kernfs_ops___107 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___107 *notify_next;
};

struct kernfs_node___107 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___107 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___107 dir;
		struct kernfs_elem_symlink___107 symlink;
		struct kernfs_elem_attr___107 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___107;

struct kernfs_ops___107 {
	int (*open)(struct kernfs_open_file___107 *);
	void (*release)(struct kernfs_open_file___107 *);
	int (*seq_show)(struct seq_file___102 *, void *);
	void * (*seq_start)(struct seq_file___102 *, loff_t *);
	void * (*seq_next)(struct seq_file___102 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___102 *, void *);
	ssize_t (*read)(struct kernfs_open_file___107 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___107 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___107 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___107 *, struct vm_area_struct___118 *);
};

struct kernfs_syscall_ops___107 {
	int (*show_options)(struct seq_file___102 *, struct kernfs_root___107 *);
	int (*mkdir)(struct kernfs_node___107 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___107 *);
	int (*rename)(struct kernfs_node___107 *, struct kernfs_node___107 *, const char *);
	int (*show_path)(struct seq_file___102 *, struct kernfs_node___107 *, struct kernfs_root___107 *);
};

struct kernfs_open_file___107 {
	struct kernfs_node___107 *kn;
	struct file___113 *file;
	struct seq_file___102 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___112 *vm_ops;
};

struct bin_attribute___107;

struct attribute_group___107 {
	const char *name;
	umode_t (*is_visible)(struct kobject___107 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___107 *, struct bin_attribute___107 *, int);
	struct attribute **attrs;
	struct bin_attribute___107 **bin_attrs;
};

struct bin_attribute___107 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___113 * (*f_mapping)();
	ssize_t (*read)(struct file___113 *, struct kobject___107 *, struct bin_attribute___107 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___113 *, struct kobject___107 *, struct bin_attribute___107 *, char *, loff_t, size_t);
	int (*mmap)(struct file___113 *, struct kobject___107 *, struct bin_attribute___107 *, struct vm_area_struct___118 *);
};

struct sysfs_ops___107 {
	ssize_t (*show)(struct kobject___107 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___107 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___107;

struct kset___107 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___107 kobj;
	const struct kset_uevent_ops___107 *uevent_ops;
};

struct kobj_type___107 {
	void (*release)(struct kobject___107 *);
	const struct sysfs_ops___107 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___107 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___107 *);
	const void * (*namespace)(struct kobject___107 *);
	void (*get_ownership)(struct kobject___107 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___107 {
	int (* const filter)(struct kset___107 *, struct kobject___107 *);
	const char * (* const name)(struct kset___107 *, struct kobject___107 *);
	int (* const uevent)(struct kset___107 *, struct kobject___107 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___104 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___104 *);
	int (*get)(char *, const struct kernel_param___104 *);
	void (*free)(void *);
};

struct kparam_array___104;

struct kernel_param___104 {
	const char *name;
	struct module___105 *mod;
	const struct kernel_param_ops___104 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___104 *arr;
	};
};

struct kparam_array___104 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___104 *ops;
	void *elem;
};

struct module_attribute___104 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___104 *, struct module_kobject___104 *, char *);
	ssize_t (*store)(struct module_attribute___104 *, struct module_kobject___104 *, const char *, size_t);
	void (*setup)(struct module___105 *, const char *);
	int (*test)(struct module___105 *);
	void (*free)(struct module___105 *);
};

struct dev_pm_ops___88 {
	int (*prepare)(struct device___88 *);
	void (*complete)(struct device___88 *);
	int (*suspend)(struct device___88 *);
	int (*resume)(struct device___88 *);
	int (*freeze)(struct device___88 *);
	int (*thaw)(struct device___88 *);
	int (*poweroff)(struct device___88 *);
	int (*restore)(struct device___88 *);
	int (*suspend_late)(struct device___88 *);
	int (*resume_early)(struct device___88 *);
	int (*freeze_late)(struct device___88 *);
	int (*thaw_early)(struct device___88 *);
	int (*poweroff_late)(struct device___88 *);
	int (*restore_early)(struct device___88 *);
	int (*suspend_noirq)(struct device___88 *);
	int (*resume_noirq)(struct device___88 *);
	int (*freeze_noirq)(struct device___88 *);
	int (*thaw_noirq)(struct device___88 *);
	int (*poweroff_noirq)(struct device___88 *);
	int (*restore_noirq)(struct device___88 *);
	int (*runtime_suspend)(struct device___88 *);
	int (*runtime_resume)(struct device___88 *);
	int (*runtime_idle)(struct device___88 *);
};

struct wakeup_source___88 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___88 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___88 {
	struct dev_pm_ops___88 ops;
	int (*start)(struct device___88 *);
	void (*detach)(struct device___88 *, bool);
	int (*activate)(struct device___88 *);
	void (*sync)(struct device___88 *);
	void (*dismiss)(struct device___88 *);
};

struct bus_type___88 {
	const char *name;
	const char *dev_name;
	struct device___88 *dev_root;
	const struct attribute_group___107 **bus_groups;
	const struct attribute_group___107 **dev_groups;
	const struct attribute_group___107 **drv_groups;
	int (*match)(struct device___88 *, struct device_driver___88 *);
	int (*uevent)(struct device___88 *, struct kobj_uevent_env *);
	int (*probe)(struct device___88 *);
	void (*sync_state)(struct device___88 *);
	void (*remove)(struct device___88 *);
	void (*shutdown)(struct device___88 *);
	int (*online)(struct device___88 *);
	int (*offline)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	int (*num_vf)(struct device___88 *);
	int (*dma_configure)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___88 {
	const char *name;
	struct bus_type___88 *bus;
	struct module___105 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___88 *);
	void (*sync_state)(struct device___88 *);
	int (*remove)(struct device___88 *);
	void (*shutdown)(struct device___88 *);
	int (*suspend)(struct device___88 *, pm_message_t);
	int (*resume)(struct device___88 *);
	const struct attribute_group___107 **groups;
	const struct attribute_group___107 **dev_groups;
	const struct dev_pm_ops___88 *pm;
	void (*coredump)(struct device___88 *);
	struct driver_private *p;
};

struct device_type___88 {
	const char *name;
	const struct attribute_group___107 **groups;
	int (*uevent)(struct device___88 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___88 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___88 *);
	const struct dev_pm_ops___88 *pm;
};

struct class___88 {
	const char *name;
	struct module___105 *owner;
	const struct attribute_group___107 **class_groups;
	const struct attribute_group___107 **dev_groups;
	struct kobject___107 *dev_kobj;
	int (*dev_uevent)(struct device___88 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___88 *, umode_t *);
	void (*class_release)(struct class___88 *);
	void (*dev_release)(struct device___88 *);
	int (*shutdown_pre)(struct device___88 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___88 *);
	void (*get_ownership)(struct device___88 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___88 *pm;
	struct subsys_private *p;
};

struct block_device_operations___52;

struct gendisk___52 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___53 *part0;
	const struct block_device_operations___52 *fops;
	struct request_queue___52 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___107 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___107 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___52 {
	struct bio___52 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___63 *bip_vec;
	struct bio_vec___63 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___52(struct request___52 *);

typedef void integrity_complete_fn___52(struct request___52 *, unsigned int);

struct blk_integrity_profile___52 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___52 *prepare_fn;
	integrity_complete_fn___52 *complete_fn;
	const char *name;
};

struct block_device_operations___52 {
	blk_qc_t (*submit_bio)(struct bio___52 *);
	int (*open)(struct block_device___53 *, fmode_t);
	void (*release)(struct gendisk___52 *, fmode_t);
	int (*rw_page)(struct block_device___53 *, sector_t, struct page___118 *, unsigned int);
	int (*ioctl)(struct block_device___53 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___53 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___52 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___52 *);
	int (*getgeo)(struct block_device___53 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___53 *, bool);
	void (*swap_slot_free_notify)(struct block_device___53 *, long unsigned int);
	int (*report_zones)(struct gendisk___52 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___52 *, umode_t *);
	struct module___105 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___52 *, sector_t *);
};

typedef void rq_end_io_fn___52(struct request___52 *, blk_status_t);

struct request___52 {
	struct request_queue___52 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___52 *bio;
	struct bio___52 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___63 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___52 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___52 *saved_end_io;
		} flush;
	};
	struct gendisk___52 *rq_disk;
	struct block_device___53 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___52 *end_io;
	void *end_io_data;
};

struct elevator_type___52;

struct elevator_mq_ops___52 {
	int (*init_sched)(struct request_queue___52 *, struct elevator_type___52 *);
	void (*exit_sched)(struct elevator_queue___52 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
	bool (*allow_merge)(struct request_queue___52 *, struct request___52 *, struct bio___52 *);
	bool (*bio_merge)(struct request_queue___52 *, struct bio___52 *, unsigned int);
	int (*request_merge)(struct request_queue___52 *, struct request___52 **, struct bio___52 *);
	void (*request_merged)(struct request_queue___52 *, struct request___52 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___52 *, struct request___52 *, struct request___52 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___52 *);
	void (*finish_request)(struct request___52 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___52 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___52 *, u64);
	void (*requeue_request)(struct request___52 *);
	struct request___52 * (*former_request)(struct request_queue___52 *, struct request___52 *);
	struct request___52 * (*next_request)(struct request_queue___52 *, struct request___52 *);
	void (*init_icq)(struct io_cq___52 *);
	void (*exit_icq)(struct io_cq___52 *);
};

struct elv_fs_entry___52;

struct elevator_type___52 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___52 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___52 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___105 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___52 {
	struct elevator_type___52 *type;
	void *elevator_data;
	struct kobject___107 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___52 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___52 *, char *);
	ssize_t (*store)(struct elevator_queue___52 *, const char *, size_t);
};

struct fscrypt_hkdf___2 {
	struct crypto_shash___3 *hmac_tfm;
};

struct fscrypt_master_key_secret___2 {
	struct fscrypt_hkdf___2 hkdf;
	u32 size;
	u8 raw[64];
};

struct fscrypt_master_key___2 {
	struct fscrypt_master_key_secret___2 mk_secret;
	struct fscrypt_key_specifier mk_spec;
	struct key___3 *mk_users;
	refcount_t mk_refcount;
	struct list_head mk_decrypted_inodes;
	spinlock_t mk_decrypted_inodes_lock;
	struct fscrypt_prepared_key___2 mk_direct_keys[10];
	struct fscrypt_prepared_key___2 mk_iv_ino_lblk_64_keys[10];
	struct fscrypt_prepared_key___2 mk_iv_ino_lblk_32_keys[10];
	siphash_key_t___2 mk_ino_hash_key;
	bool mk_ino_hash_key_initialized;
};

struct skcipher_alg {
	int (*setkey)(struct crypto_skcipher___2 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request *);
	int (*decrypt)(struct skcipher_request *);
	int (*init)(struct crypto_skcipher___2 *);
	void (*exit)(struct crypto_skcipher___2 *);
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
	unsigned int chunksize;
	unsigned int walksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___2 base;
};

typedef int (*key_restrict_link_func_t___4)(struct key___3 *, const struct key_type *, const union key_payload *, struct key___3 *);

struct fscrypt_context_v1 {
	u8 version;
	u8 contents_encryption_mode;
	u8 filenames_encryption_mode;
	u8 flags;
	u8 master_key_descriptor[8];
	u8 nonce[16];
};

struct fscrypt_context_v2 {
	u8 version;
	u8 contents_encryption_mode;
	u8 filenames_encryption_mode;
	u8 flags;
	u8 __reserved[4];
	u8 master_key_identifier[16];
	u8 nonce[16];
};

union fscrypt_context {
	u8 version;
	struct fscrypt_context_v1 v1;
	struct fscrypt_context_v2 v2;
};

struct crypto_template;

struct crypto_spawn;

struct crypto_instance {
	struct crypto_alg___2 alg;
	struct crypto_template *tmpl;
	union {
		struct hlist_node list;
		struct crypto_spawn *spawns;
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_spawn {
	struct list_head list;
	struct crypto_alg___2 *alg;
	union {
		struct crypto_instance *inst;
		struct crypto_spawn *next;
	};
	const struct crypto_type *frontend;
	u32 mask;
	bool dead;
	bool registered;
};

struct rtattr;

struct crypto_template {
	struct list_head list;
	struct hlist_head instances;
	struct module___105 *module;
	int (*create)(struct crypto_template *, struct rtattr **);
	char name[128];
};

struct user_key_payload {
	struct callback_head rcu;
	short unsigned int datalen;
	long: 48;
	char data[0];
};

struct fscrypt_key {
	__u32 mode;
	__u8 raw[64];
	__u32 size;
};

struct fscrypt_direct_key {
	struct hlist_node dk_node;
	refcount_t dk_refcount;
	const struct fscrypt_mode *dk_mode;
	struct fscrypt_prepared_key___2 dk_key;
	u8 dk_descriptor[8];
	u8 dk_raw[64];
};

struct fscrypt_get_policy_ex_arg {
	__u64 policy_size;
	union {
		__u8 version;
		struct fscrypt_policy_v1 v1;
		struct fscrypt_policy_v2 v2;
	} policy;
};

struct fscrypt_dummy_policy {
	const union fscrypt_policy *policy;
};

struct bvec_iter_all___2 {
	struct bio_vec___53 bv;
	int idx;
	unsigned int done;
};

struct fscrypt_blk_crypto_key {
	struct blk_crypto_key base;
	int num_devs;
	struct request_queue___43 *devs[0];
};

struct fsverity_hash_alg;

struct merkle_tree_params {
	struct fsverity_hash_alg *hash_alg;
	const u8 *hashstate;
	unsigned int digest_size;
	unsigned int block_size;
	unsigned int hashes_per_block;
	unsigned int log_blocksize;
	unsigned int log_arity;
	unsigned int num_levels;
	u64 tree_size;
	long unsigned int level0_blocks;
	u64 level_start[8];
};

struct fsverity_info {
	struct merkle_tree_params tree_params;
	u8 root_hash[64];
	u8 file_digest[64];
	const struct inode___3 *inode;
};

struct fsverity_enable_arg {
	__u32 version;
	__u32 hash_algorithm;
	__u32 block_size;
	__u32 salt_size;
	__u64 salt_ptr;
	__u32 sig_size;
	__u32 __reserved1;
	__u64 sig_ptr;
	__u64 __reserved2[11];
};

struct fsverity_descriptor {
	__u8 version;
	__u8 hash_algorithm;
	__u8 log_blocksize;
	__u8 salt_size;
	__le32 sig_size;
	__le64 data_size;
	__u8 root_hash[64];
	__u8 salt[32];
	__u8 __reserved[144];
	__u8 signature[0];
};

struct crypto_ahash;

struct fsverity_hash_alg {
	struct crypto_ahash *tfm;
	const char *name;
	unsigned int digest_size;
	unsigned int block_size;
	mempool_t req_pool;
};

struct ahash_request;

struct crypto_ahash {
	int (*init)(struct ahash_request *);
	int (*update)(struct ahash_request *);
	int (*final)(struct ahash_request *);
	int (*finup)(struct ahash_request *);
	int (*digest)(struct ahash_request *);
	int (*export)(struct ahash_request *, void *);
	int (*import)(struct ahash_request *, const void *);
	int (*setkey)(struct crypto_ahash *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___3 base;
};

struct ahash_request {
	struct crypto_async_request base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct dentry___114;

struct super_block___114;

struct file_system_type___114 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___114 * (*mount)(struct file_system_type___114 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___114 *);
	struct module___8 *owner;
	struct file_system_type___114 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___114;

struct kiocb___114;

struct vm_area_struct___119;

struct inode___114;

struct file_lock___114;

struct page___119;

struct file_operations___114 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___114 *, loff_t, int);
	ssize_t (*read)(struct file___114 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___114 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___114 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___114 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___114 *, bool);
	int (*iterate)(struct file___114 *, struct dir_context *);
	int (*iterate_shared)(struct file___114 *, struct dir_context *);
	__poll_t (*poll)(struct file___114 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___114 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___114 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___114 *, struct vm_area_struct___119 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___114 *, struct file___114 *);
	int (*flush)(struct file___114 *, fl_owner_t);
	int (*release)(struct inode___114 *, struct file___114 *);
	int (*fsync)(struct file___114 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___114 *, int);
	int (*lock)(struct file___114 *, int, struct file_lock___114 *);
	ssize_t (*sendpage)(struct file___114 *, struct page___119 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___114 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___114 *, long unsigned int);
	int (*flock)(struct file___114 *, int, struct file_lock___114 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___114 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___114 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___114 *, long int, struct file_lock___114 **, void **);
	long int (*fallocate)(struct file___114 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___114 *);
	ssize_t (*copy_file_range)(struct file___114 *, loff_t, struct file___114 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___114 *, loff_t, struct file___114 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___114 *, loff_t, loff_t, int);
};

struct vmacache___119 {
	u64 seqnum;
	struct vm_area_struct___119 *vmas[4];
};

struct page_frag___119 {
	struct page___119 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___120;

struct signal_struct___115;

struct vm_struct___105;

struct task_struct___121 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___121 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___120 *mm;
	struct mm_struct___120 *active_mm;
	struct vmacache___119 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___121 *real_parent;
	struct task_struct___121 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___121 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___100 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___115 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___121 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___52 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___119 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___121 *oom_reaper_list;
	struct vm_struct___105 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___114;

struct dentry___114 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___114 *d_parent;
	struct qstr d_name;
	struct inode___114 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___114 *d_op;
	struct super_block___114 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___114;

struct address_space___114 {
	struct inode___114 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___114 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___114;

struct fsverity_info___2;

struct inode___114 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___114 *i_op;
	struct super_block___114 *i_sb;
	struct address_space___114 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___114 *i_fop;
		void (*free_inode)(struct inode___114 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___114 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info___2 *i_verity_info;
	void *i_private;
};

struct vfsmount___114;

struct path___114;

struct dentry_operations___114 {
	int (*d_revalidate)(struct dentry___114 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___114 *, unsigned int);
	int (*d_hash)(const struct dentry___114 *, struct qstr *);
	int (*d_compare)(const struct dentry___114 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___114 *);
	int (*d_init)(struct dentry___114 *);
	void (*d_release)(struct dentry___114 *);
	void (*d_prune)(struct dentry___114 *);
	void (*d_iput)(struct dentry___114 *, struct inode___114 *);
	char * (*d_dname)(struct dentry___114 *, char *, int);
	struct vfsmount___114 * (*d_automount)(struct path___114 *);
	int (*d_manage)(const struct path___114 *, bool);
	struct dentry___114 * (*d_real)(struct dentry___114 *, const struct inode___114 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___114;

struct mem_dqinfo___114 {
	struct quota_format_type___114 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___114;

struct quota_info___114 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___114 *files[3];
	struct mem_dqinfo___114 info[3];
	const struct quota_format_ops___114 *ops[3];
};

struct rcuwait___115 {
	struct task_struct___121 *task;
};

struct percpu_rw_semaphore___115 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___115 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___114 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___115 rw_sem[3];
};

struct super_operations___114;

struct dquot_operations___114;

struct quotactl_ops___114;

struct fsverity_operations___2;

struct super_block___114 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___114 *s_type;
	const struct super_operations___114 *s_op;
	const struct dquot_operations___114 *dq_op;
	const struct quotactl_ops___114 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___114 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___2 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___114 s_dquot;
	struct sb_writers___114 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___114 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___114 {
	struct dentry___114 *mnt_root;
	struct super_block___114 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___114 {
	struct vfsmount___114 *mnt;
	struct dentry___114 *dentry;
};

typedef struct page___119 *pgtable_t___119;

struct dev_pagemap___113;

struct page___119 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___114 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___119 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___119 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___120 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___113 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___113;

struct vm_area_struct___119 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___119 *vm_next;
	struct vm_area_struct___119 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___120 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___113 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___114 *vm_file;
	struct file___114 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___115 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___121 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___121 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___100 *pids[4];
	struct pid___100 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___120 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___119;

struct mm_struct___120 {
	struct {
		struct vm_area_struct___119 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___114 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___119 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___121 *owner;
		struct user_namespace *user_ns;
		struct file___114 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct vm_struct___105 {
	struct vm_struct___105 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___119 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___113;

struct dev_pagemap___113 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___113 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___114 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___114 f_path;
	struct inode___114 *f_inode;
	const struct file_operations___114 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___100 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___114 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___113;

struct vm_operations_struct___113 {
	void (*open)(struct vm_area_struct___119 *);
	void (*close)(struct vm_area_struct___119 *);
	int (*may_split)(struct vm_area_struct___119 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___119 *);
	int (*mprotect)(struct vm_area_struct___119 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___113 *);
	vm_fault_t (*huge_fault)(struct vm_fault___113 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___113 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___119 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___113 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___113 *);
	int (*access)(struct vm_area_struct___119 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___119 *);
	int (*set_policy)(struct vm_area_struct___119 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___119 *, long unsigned int);
	struct page___119 * (*find_special_page)(struct vm_area_struct___119 *, long unsigned int);
};

struct core_thread___119 {
	struct task_struct___121 *task;
	struct core_thread___119 *next;
};

struct core_state___119 {
	atomic_t nr_threads;
	struct core_thread___119 dumper;
	struct completion startup;
};

struct vm_fault___113 {
	const struct {
		struct vm_area_struct___119 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___119 *cow_page;
	struct page___119 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___119 prealloc_pte;
};

struct kiocb___114 {
	struct file___114 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___114 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___51 *ki_waitq;
	};
};

struct iattr___114 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___114 *ia_file;
};

struct dquot___114 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___114 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___114 {
	int qf_fmt_id;
	const struct quota_format_ops___114 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___114 *qf_next;
};

struct quota_format_ops___114 {
	int (*check_quota_file)(struct super_block___114 *, int);
	int (*read_file_info)(struct super_block___114 *, int);
	int (*write_file_info)(struct super_block___114 *, int);
	int (*free_file_info)(struct super_block___114 *, int);
	int (*read_dqblk)(struct dquot___114 *);
	int (*commit_dqblk)(struct dquot___114 *);
	int (*release_dqblk)(struct dquot___114 *);
	int (*get_next_id)(struct super_block___114 *, struct kqid *);
};

struct dquot_operations___114 {
	int (*write_dquot)(struct dquot___114 *);
	struct dquot___114 * (*alloc_dquot)(struct super_block___114 *, int);
	void (*destroy_dquot)(struct dquot___114 *);
	int (*acquire_dquot)(struct dquot___114 *);
	int (*release_dquot)(struct dquot___114 *);
	int (*mark_dirty)(struct dquot___114 *);
	int (*write_info)(struct super_block___114 *, int);
	qsize_t * (*get_reserved_space)(struct inode___114 *);
	int (*get_projid)(struct inode___114 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___114 *, qsize_t *);
	int (*get_next_id)(struct super_block___114 *, struct kqid *);
};

struct quotactl_ops___114 {
	int (*quota_on)(struct super_block___114 *, int, int, const struct path___114 *);
	int (*quota_off)(struct super_block___114 *, int);
	int (*quota_enable)(struct super_block___114 *, unsigned int);
	int (*quota_disable)(struct super_block___114 *, unsigned int);
	int (*quota_sync)(struct super_block___114 *, int);
	int (*set_info)(struct super_block___114 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___114 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___114 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___114 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___114 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___114 *, unsigned int);
};

struct address_space_operations___114 {
	int (*writepage)(struct page___119 *, struct writeback_control___3 *);
	int (*readpage)(struct file___114 *, struct page___119 *);
	int (*writepages)(struct address_space___114 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___119 *);
	int (*readpages)(struct file___114 *, struct address_space___114 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___114 *, struct address_space___114 *, loff_t, unsigned int, unsigned int, struct page___119 **, void **);
	int (*write_end)(struct file___114 *, struct address_space___114 *, loff_t, unsigned int, unsigned int, struct page___119 *, void *);
	sector_t (*bmap)(struct address_space___114 *, sector_t);
	void (*invalidatepage)(struct page___119 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___119 *, gfp_t);
	void (*freepage)(struct page___119 *);
	ssize_t (*direct_IO)(struct kiocb___114 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___114 *, struct page___119 *, struct page___119 *, enum migrate_mode);
	bool (*isolate_page)(struct page___119 *, isolate_mode_t);
	void (*putback_page)(struct page___119 *);
	int (*launder_page)(struct page___119 *);
	int (*is_partially_uptodate)(struct page___119 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___119 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___114 *, struct page___119 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___114 *, sector_t *);
	void (*swap_deactivate)(struct file___114 *);
};

struct inode_operations___114 {
	struct dentry___114 * (*lookup)(struct inode___114 *, struct dentry___114 *, unsigned int);
	const char * (*get_link)(struct dentry___114 *, struct inode___114 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___114 *, int);
	struct posix_acl * (*get_acl)(struct inode___114 *, int, bool);
	int (*readlink)(struct dentry___114 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___114 *, struct dentry___114 *, umode_t, bool);
	int (*link)(struct dentry___114 *, struct inode___114 *, struct dentry___114 *);
	int (*unlink)(struct inode___114 *, struct dentry___114 *);
	int (*symlink)(struct user_namespace *, struct inode___114 *, struct dentry___114 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___114 *, struct dentry___114 *, umode_t);
	int (*rmdir)(struct inode___114 *, struct dentry___114 *);
	int (*mknod)(struct user_namespace *, struct inode___114 *, struct dentry___114 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___114 *, struct dentry___114 *, struct inode___114 *, struct dentry___114 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___114 *, struct iattr___114 *);
	int (*getattr)(struct user_namespace *, const struct path___114 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___114 *, char *, size_t);
	int (*fiemap)(struct inode___114 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___114 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___114 *, struct dentry___114 *, struct file___114 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___114 *, struct dentry___114 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___114 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___114 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___114 *, struct fileattr *);
	long: 64;
};

struct fsverity_info___2 {
	struct merkle_tree_params tree_params;
	u8 root_hash[64];
	u8 file_digest[64];
	const struct inode___114 *inode;
};

struct file_lock_operations___114 {
	void (*fl_copy_lock)(struct file_lock___114 *, struct file_lock___114 *);
	void (*fl_release_private)(struct file_lock___114 *);
};

struct fasync_struct___114;

struct lock_manager_operations___114;

struct file_lock___114 {
	struct file_lock___114 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___114 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___114 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___114 *fl_ops;
	const struct lock_manager_operations___114 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___114 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___114 *);
	int (*lm_grant)(struct file_lock___114 *, int);
	bool (*lm_break)(struct file_lock___114 *);
	int (*lm_change)(struct file_lock___114 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___114 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___114 *);
};

struct fasync_struct___114 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___114 *fa_next;
	struct file___114 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___114 {
	struct inode___114 * (*alloc_inode)(struct super_block___114 *);
	void (*destroy_inode)(struct inode___114 *);
	void (*free_inode)(struct inode___114 *);
	void (*dirty_inode)(struct inode___114 *, int);
	int (*write_inode)(struct inode___114 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___114 *);
	void (*evict_inode)(struct inode___114 *);
	void (*put_super)(struct super_block___114 *);
	int (*sync_fs)(struct super_block___114 *, int);
	int (*freeze_super)(struct super_block___114 *);
	int (*freeze_fs)(struct super_block___114 *);
	int (*thaw_super)(struct super_block___114 *);
	int (*unfreeze_fs)(struct super_block___114 *);
	int (*statfs)(struct dentry___114 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___114 *, int *, char *);
	void (*umount_begin)(struct super_block___114 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___114 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___114 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___114 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___114 *);
	ssize_t (*quota_read)(struct super_block___114 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___114 *, int, const char *, size_t, loff_t);
	struct dquot___114 ** (*get_dquots)(struct inode___114 *);
	long int (*nr_cached_objects)(struct super_block___114 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___114 *, struct shrink_control___45 *);
	struct file___114 * (*real_loop)(struct file___114 *);
};

struct fsverity_operations___2 {
	int (*begin_enable_verity)(struct file___114 *);
	int (*end_enable_verity)(struct file___114 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___114 *, void *, size_t);
	struct page___119 * (*read_merkle_tree_page)(struct inode___114 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___114 *, const void *, u64, int);
};

struct hash_alg_common {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___3 base;
};

struct dev_pagemap_ops___113 {
	void (*page_free)(struct page___119 *);
	void (*kill)(struct dev_pagemap___113 *);
	void (*cleanup)(struct dev_pagemap___113 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___113 *);
};

struct dentry___115;

struct super_block___115;

struct file_system_type___115 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___115 * (*mount)(struct file_system_type___115 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___115 *);
	struct module___8 *owner;
	struct file_system_type___115 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___115;

struct kiocb___115;

struct vm_area_struct___120;

struct inode___115;

struct file_lock___115;

struct page___120;

struct file_operations___115 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___115 *, loff_t, int);
	ssize_t (*read)(struct file___115 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___115 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___115 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___115 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___115 *, bool);
	int (*iterate)(struct file___115 *, struct dir_context *);
	int (*iterate_shared)(struct file___115 *, struct dir_context *);
	__poll_t (*poll)(struct file___115 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___115 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___115 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___115 *, struct vm_area_struct___120 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___115 *, struct file___115 *);
	int (*flush)(struct file___115 *, fl_owner_t);
	int (*release)(struct inode___115 *, struct file___115 *);
	int (*fsync)(struct file___115 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___115 *, int);
	int (*lock)(struct file___115 *, int, struct file_lock___115 *);
	ssize_t (*sendpage)(struct file___115 *, struct page___120 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___115 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___115 *, long unsigned int);
	int (*flock)(struct file___115 *, int, struct file_lock___115 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___115 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___115 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___115 *, long int, struct file_lock___115 **, void **);
	long int (*fallocate)(struct file___115 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___115 *);
	ssize_t (*copy_file_range)(struct file___115 *, loff_t, struct file___115 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___115 *, loff_t, struct file___115 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___115 *, loff_t, loff_t, int);
};

struct vmacache___120 {
	u64 seqnum;
	struct vm_area_struct___120 *vmas[4];
};

struct page_frag___120 {
	struct page___120 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___121;

struct signal_struct___116;

struct task_struct___122 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___122 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___121 *mm;
	struct mm_struct___121 *active_mm;
	struct vmacache___120 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___122 *real_parent;
	struct task_struct___122 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___122 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___100 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___116 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___122 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___52 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___120 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___122 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___115;

struct dentry___115 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___115 *d_parent;
	struct qstr d_name;
	struct inode___115 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___115 *d_op;
	struct super_block___115 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___115;

struct address_space___115 {
	struct inode___115 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___115 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___115;

struct fsverity_info___3;

struct inode___115 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___115 *i_op;
	struct super_block___115 *i_sb;
	struct address_space___115 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___115 *i_fop;
		void (*free_inode)(struct inode___115 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___115 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info___3 *i_verity_info;
	void *i_private;
};

struct vfsmount___115;

struct path___115;

struct dentry_operations___115 {
	int (*d_revalidate)(struct dentry___115 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___115 *, unsigned int);
	int (*d_hash)(const struct dentry___115 *, struct qstr *);
	int (*d_compare)(const struct dentry___115 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___115 *);
	int (*d_init)(struct dentry___115 *);
	void (*d_release)(struct dentry___115 *);
	void (*d_prune)(struct dentry___115 *);
	void (*d_iput)(struct dentry___115 *, struct inode___115 *);
	char * (*d_dname)(struct dentry___115 *, char *, int);
	struct vfsmount___115 * (*d_automount)(struct path___115 *);
	int (*d_manage)(const struct path___115 *, bool);
	struct dentry___115 * (*d_real)(struct dentry___115 *, const struct inode___115 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___115;

struct mem_dqinfo___115 {
	struct quota_format_type___115 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___115;

struct quota_info___115 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___115 *files[3];
	struct mem_dqinfo___115 info[3];
	const struct quota_format_ops___115 *ops[3];
};

struct rcuwait___116 {
	struct task_struct___122 *task;
};

struct percpu_rw_semaphore___116 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___116 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___115 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___116 rw_sem[3];
};

struct super_operations___115;

struct dquot_operations___115;

struct quotactl_ops___115;

struct fsverity_operations___3;

struct super_block___115 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___115 *s_type;
	const struct super_operations___115 *s_op;
	const struct dquot_operations___115 *dq_op;
	const struct quotactl_ops___115 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___115 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___3 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___115 s_dquot;
	struct sb_writers___115 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___115 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___115 {
	struct dentry___115 *mnt_root;
	struct super_block___115 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___115 {
	struct vfsmount___115 *mnt;
	struct dentry___115 *dentry;
};

typedef struct page___120 *pgtable_t___120;

struct page___120 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___115 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___120 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___120 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___121 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___113 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___120 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___120 *vm_next;
	struct vm_area_struct___120 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___121 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___115 *vm_file;
	struct file___115 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___116 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___122 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___122 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___100 *pids[4];
	struct pid___100 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___121 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___120;

struct mm_struct___121 {
	struct {
		struct vm_area_struct___120 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___115 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___120 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___122 *owner;
		struct user_namespace *user_ns;
		struct file___115 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct file___115 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___115 f_path;
	struct inode___115 *f_inode;
	const struct file_operations___115 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___100 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___115 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct core_thread___120 {
	struct task_struct___122 *task;
	struct core_thread___120 *next;
};

struct core_state___120 {
	atomic_t nr_threads;
	struct core_thread___120 dumper;
	struct completion startup;
};

struct kiocb___115 {
	struct file___115 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___115 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___51 *ki_waitq;
	};
};

struct iattr___115 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___115 *ia_file;
};

struct dquot___115 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___115 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___115 {
	int qf_fmt_id;
	const struct quota_format_ops___115 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___115 *qf_next;
};

struct quota_format_ops___115 {
	int (*check_quota_file)(struct super_block___115 *, int);
	int (*read_file_info)(struct super_block___115 *, int);
	int (*write_file_info)(struct super_block___115 *, int);
	int (*free_file_info)(struct super_block___115 *, int);
	int (*read_dqblk)(struct dquot___115 *);
	int (*commit_dqblk)(struct dquot___115 *);
	int (*release_dqblk)(struct dquot___115 *);
	int (*get_next_id)(struct super_block___115 *, struct kqid *);
};

struct dquot_operations___115 {
	int (*write_dquot)(struct dquot___115 *);
	struct dquot___115 * (*alloc_dquot)(struct super_block___115 *, int);
	void (*destroy_dquot)(struct dquot___115 *);
	int (*acquire_dquot)(struct dquot___115 *);
	int (*release_dquot)(struct dquot___115 *);
	int (*mark_dirty)(struct dquot___115 *);
	int (*write_info)(struct super_block___115 *, int);
	qsize_t * (*get_reserved_space)(struct inode___115 *);
	int (*get_projid)(struct inode___115 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___115 *, qsize_t *);
	int (*get_next_id)(struct super_block___115 *, struct kqid *);
};

struct quotactl_ops___115 {
	int (*quota_on)(struct super_block___115 *, int, int, const struct path___115 *);
	int (*quota_off)(struct super_block___115 *, int);
	int (*quota_enable)(struct super_block___115 *, unsigned int);
	int (*quota_disable)(struct super_block___115 *, unsigned int);
	int (*quota_sync)(struct super_block___115 *, int);
	int (*set_info)(struct super_block___115 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___115 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___115 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___115 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___115 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___115 *, unsigned int);
};

struct address_space_operations___115 {
	int (*writepage)(struct page___120 *, struct writeback_control___3 *);
	int (*readpage)(struct file___115 *, struct page___120 *);
	int (*writepages)(struct address_space___115 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___120 *);
	int (*readpages)(struct file___115 *, struct address_space___115 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___115 *, struct address_space___115 *, loff_t, unsigned int, unsigned int, struct page___120 **, void **);
	int (*write_end)(struct file___115 *, struct address_space___115 *, loff_t, unsigned int, unsigned int, struct page___120 *, void *);
	sector_t (*bmap)(struct address_space___115 *, sector_t);
	void (*invalidatepage)(struct page___120 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___120 *, gfp_t);
	void (*freepage)(struct page___120 *);
	ssize_t (*direct_IO)(struct kiocb___115 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___115 *, struct page___120 *, struct page___120 *, enum migrate_mode);
	bool (*isolate_page)(struct page___120 *, isolate_mode_t);
	void (*putback_page)(struct page___120 *);
	int (*launder_page)(struct page___120 *);
	int (*is_partially_uptodate)(struct page___120 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___120 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___115 *, struct page___120 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___115 *, sector_t *);
	void (*swap_deactivate)(struct file___115 *);
};

struct inode_operations___115 {
	struct dentry___115 * (*lookup)(struct inode___115 *, struct dentry___115 *, unsigned int);
	const char * (*get_link)(struct dentry___115 *, struct inode___115 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___115 *, int);
	struct posix_acl * (*get_acl)(struct inode___115 *, int, bool);
	int (*readlink)(struct dentry___115 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___115 *, struct dentry___115 *, umode_t, bool);
	int (*link)(struct dentry___115 *, struct inode___115 *, struct dentry___115 *);
	int (*unlink)(struct inode___115 *, struct dentry___115 *);
	int (*symlink)(struct user_namespace *, struct inode___115 *, struct dentry___115 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___115 *, struct dentry___115 *, umode_t);
	int (*rmdir)(struct inode___115 *, struct dentry___115 *);
	int (*mknod)(struct user_namespace *, struct inode___115 *, struct dentry___115 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___115 *, struct dentry___115 *, struct inode___115 *, struct dentry___115 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___115 *, struct iattr___115 *);
	int (*getattr)(struct user_namespace *, const struct path___115 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___115 *, char *, size_t);
	int (*fiemap)(struct inode___115 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___115 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___115 *, struct dentry___115 *, struct file___115 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___115 *, struct dentry___115 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___115 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___115 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___115 *, struct fileattr *);
	long: 64;
};

struct fsverity_info___3 {
	struct merkle_tree_params tree_params;
	u8 root_hash[64];
	u8 file_digest[64];
	const struct inode___115 *inode;
};

struct file_lock_operations___115 {
	void (*fl_copy_lock)(struct file_lock___115 *, struct file_lock___115 *);
	void (*fl_release_private)(struct file_lock___115 *);
};

struct fasync_struct___115;

struct lock_manager_operations___115;

struct file_lock___115 {
	struct file_lock___115 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___115 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___115 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___115 *fl_ops;
	const struct lock_manager_operations___115 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___115 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___115 *);
	int (*lm_grant)(struct file_lock___115 *, int);
	bool (*lm_break)(struct file_lock___115 *);
	int (*lm_change)(struct file_lock___115 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___115 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___115 *);
};

struct fasync_struct___115 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___115 *fa_next;
	struct file___115 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___115 {
	struct inode___115 * (*alloc_inode)(struct super_block___115 *);
	void (*destroy_inode)(struct inode___115 *);
	void (*free_inode)(struct inode___115 *);
	void (*dirty_inode)(struct inode___115 *, int);
	int (*write_inode)(struct inode___115 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___115 *);
	void (*evict_inode)(struct inode___115 *);
	void (*put_super)(struct super_block___115 *);
	int (*sync_fs)(struct super_block___115 *, int);
	int (*freeze_super)(struct super_block___115 *);
	int (*freeze_fs)(struct super_block___115 *);
	int (*thaw_super)(struct super_block___115 *);
	int (*unfreeze_fs)(struct super_block___115 *);
	int (*statfs)(struct dentry___115 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___115 *, int *, char *);
	void (*umount_begin)(struct super_block___115 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___115 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___115 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___115 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___115 *);
	ssize_t (*quota_read)(struct super_block___115 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___115 *, int, const char *, size_t, loff_t);
	struct dquot___115 ** (*get_dquots)(struct inode___115 *);
	long int (*nr_cached_objects)(struct super_block___115 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___115 *, struct shrink_control___45 *);
	struct file___115 * (*real_loop)(struct file___115 *);
};

struct fsverity_operations___3 {
	int (*begin_enable_verity)(struct file___115 *);
	int (*end_enable_verity)(struct file___115 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___115 *, void *, size_t);
	struct page___120 * (*read_merkle_tree_page)(struct inode___115 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___115 *, const void *, u64, int);
};

struct fsverity_digest {
	__u16 digest_algorithm;
	__u16 digest_size;
	__u8 digest[0];
};

struct dentry___116;

struct super_block___116;

struct module___106;

struct file_system_type___116 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___116 * (*mount)(struct file_system_type___116 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___116 *);
	struct module___106 *owner;
	struct file_system_type___116 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___116;

struct kiocb___116;

struct iov_iter___66;

struct vm_area_struct___121;

struct inode___116;

struct file_lock___116;

struct page___121;

struct seq_file___103;

struct file_operations___116 {
	struct module___106 *owner;
	loff_t (*llseek)(struct file___116 *, loff_t, int);
	ssize_t (*read)(struct file___116 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___116 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___116 *, struct iov_iter___66 *);
	ssize_t (*write_iter)(struct kiocb___116 *, struct iov_iter___66 *);
	int (*iopoll)(struct kiocb___116 *, bool);
	int (*iterate)(struct file___116 *, struct dir_context *);
	int (*iterate_shared)(struct file___116 *, struct dir_context *);
	__poll_t (*poll)(struct file___116 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___116 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___116 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___116 *, struct vm_area_struct___121 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___116 *, struct file___116 *);
	int (*flush)(struct file___116 *, fl_owner_t);
	int (*release)(struct inode___116 *, struct file___116 *);
	int (*fsync)(struct file___116 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___116 *, int);
	int (*lock)(struct file___116 *, int, struct file_lock___116 *);
	ssize_t (*sendpage)(struct file___116 *, struct page___121 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___116 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___116 *, long unsigned int);
	int (*flock)(struct file___116 *, int, struct file_lock___116 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___116 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___116 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___116 *, long int, struct file_lock___116 **, void **);
	long int (*fallocate)(struct file___116 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___103 *, struct file___116 *);
	ssize_t (*copy_file_range)(struct file___116 *, loff_t, struct file___116 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___116 *, loff_t, struct file___116 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___116 *, loff_t, loff_t, int);
};

struct vmacache___121 {
	u64 seqnum;
	struct vm_area_struct___121 *vmas[4];
};

struct page_frag___121 {
	struct page___121 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___122;

struct pid___101;

struct nsproxy___107;

struct signal_struct___117;

struct bio_list___53;

struct backing_dev_info___51;

struct io_context___53;

struct css_set___86;

struct request_queue___53;

struct vm_struct___106;

struct task_struct___123 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___123 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___122 *mm;
	struct mm_struct___122 *active_mm;
	struct vmacache___121 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___123 *real_parent;
	struct task_struct___123 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___123 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___101 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___107 *nsproxy;
	struct signal_struct___117 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___123 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___53 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___51 *backing_dev_info;
	struct io_context___53 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___86 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___121 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___53 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___123 *oom_reaper_list;
	struct vm_struct___106 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___108;

struct kobj_type___108;

struct kernfs_node___108;

struct kobject___108 {
	const char *name;
	struct list_head entry;
	struct kobject___108 *parent;
	struct kset___108 *kset;
	struct kobj_type___108 *ktype;
	struct kernfs_node___108 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___105 {
	struct kobject___108 kobj;
	struct module___106 *mod;
	struct kobject___108 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___105 {
	struct module___106 *mod;
	struct latch_tree_node node;
};

struct module_layout___105 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___105 mtn;
};

struct module_attribute___105;

struct kernel_param___105;

struct module___106 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___105 mkobj;
	struct module_attribute___105 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___108 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___105 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___105 core_layout;
	struct module_layout___105 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___116;

struct dentry___116 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___116 *d_parent;
	struct qstr d_name;
	struct inode___116 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___116 *d_op;
	struct super_block___116 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___116;

struct address_space___116 {
	struct inode___116 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___116 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___116;

struct bdi_writeback___51;

struct fsverity_info___4;

struct inode___116 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___116 *i_op;
	struct super_block___116 *i_sb;
	struct address_space___116 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___51 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___116 *i_fop;
		void (*free_inode)(struct inode___116 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___116 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info___4 *i_verity_info;
	void *i_private;
};

struct vfsmount___116;

struct path___116;

struct dentry_operations___116 {
	int (*d_revalidate)(struct dentry___116 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___116 *, unsigned int);
	int (*d_hash)(const struct dentry___116 *, struct qstr *);
	int (*d_compare)(const struct dentry___116 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___116 *);
	int (*d_init)(struct dentry___116 *);
	void (*d_release)(struct dentry___116 *);
	void (*d_prune)(struct dentry___116 *);
	void (*d_iput)(struct dentry___116 *, struct inode___116 *);
	char * (*d_dname)(struct dentry___116 *, char *, int);
	struct vfsmount___116 * (*d_automount)(struct path___116 *);
	int (*d_manage)(const struct path___116 *, bool);
	struct dentry___116 * (*d_real)(struct dentry___116 *, const struct inode___116 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___116;

struct mem_dqinfo___116 {
	struct quota_format_type___116 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___116;

struct quota_info___116 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___116 *files[3];
	struct mem_dqinfo___116 info[3];
	const struct quota_format_ops___116 *ops[3];
};

struct rcuwait___117 {
	struct task_struct___123 *task;
};

struct percpu_rw_semaphore___117 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___117 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___116 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___117 rw_sem[3];
};

struct super_operations___116;

struct dquot_operations___116;

struct quotactl_ops___116;

struct fsverity_operations___4;

struct block_device___54;

struct super_block___116 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___116 *s_type;
	const struct super_operations___116 *s_op;
	const struct dquot_operations___116 *dq_op;
	const struct quotactl_ops___116 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___116 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations___4 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___54 *s_bdev;
	struct backing_dev_info___51 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___116 s_dquot;
	struct sb_writers___116 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___116 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___116 {
	struct dentry___116 *mnt_root;
	struct super_block___116 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct path___116 {
	struct vfsmount___116 *mnt;
	struct dentry___116 *dentry;
};

struct pid_namespace___101;

struct upid___101 {
	int nr;
	struct pid_namespace___101 *ns;
};

struct pid_namespace___101 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___123 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___101 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___101 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___101 numbers[1];
};

typedef struct page___121 *pgtable_t___121;

struct dev_pagemap___114;

struct page___121 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___116 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___121 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___121 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___122 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___114 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___114;

struct vm_area_struct___121 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___121 *vm_next;
	struct vm_area_struct___121 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___122 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___114 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___116 *vm_file;
	struct file___116 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___117 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___123 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___123 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___101 *pids[4];
	struct pid___101 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___122 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___121;

struct mm_struct___122 {
	struct {
		struct vm_area_struct___121 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___116 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___121 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___123 *owner;
		struct user_namespace___4 *user_ns;
		struct file___116 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___86;

struct nsproxy___107 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___101 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___86 *cgroup_ns;
};

struct bio___53;

struct bio_list___53 {
	struct bio___53 *head;
	struct bio___53 *tail;
};

struct cgroup_subsys_state___86;

struct bdi_writeback___51 {
	struct backing_dev_info___51 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___86 *memcg_css;
	struct cgroup_subsys_state___86 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___89;

struct backing_dev_info___51 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___51 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___89 *dev;
	char dev_name[64];
	struct device___89 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___116 *debug_dir;
};

struct io_cq___53;

struct io_context___53 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___53 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___86;

struct css_set___86 {
	struct cgroup_subsys_state___86 *subsys[14];
	refcount_t refcount;
	struct css_set___86 *dom_cset;
	struct cgroup___86 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___86 *mg_src_cgrp;
	struct cgroup___86 *mg_dst_cgrp;
	struct css_set___86 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___53;

struct blk_integrity___53 {
	const struct blk_integrity_profile___53 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___53 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___53 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___53;

struct elevator_queue___53;

struct blk_mq_ops___51;

struct blk_mq_hw_ctx___51;

struct gendisk___53;

struct blkcg_gq___51;

struct blk_mq_tag_set___51;

struct request_queue___53 {
	struct request___53 *last_merge;
	struct elevator_queue___53 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___51 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___51 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___53 *disk;
	struct kobject___108 kobj;
	struct kobject___108 *mq_kobj;
	struct blk_integrity___53 integrity;
	struct device___89 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___51 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___51 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___53 bio_split;
	struct dentry___116 *debugfs_dir;
	struct dentry___116 *sched_debugfs_dir;
	struct dentry___116 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___106 {
	struct vm_struct___106 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___121 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___114;

struct dev_pagemap___114 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___114 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___101 {
	rwlock_t lock;
	struct pid___101 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___116 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___116 f_path;
	struct inode___116 *f_inode;
	const struct file_operations___116 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___101 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___116 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___114;

struct vm_operations_struct___114 {
	void (*open)(struct vm_area_struct___121 *);
	void (*close)(struct vm_area_struct___121 *);
	int (*may_split)(struct vm_area_struct___121 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___121 *);
	int (*mprotect)(struct vm_area_struct___121 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___114 *);
	vm_fault_t (*huge_fault)(struct vm_fault___114 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___114 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___121 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___114 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___114 *);
	int (*access)(struct vm_area_struct___121 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___121 *);
	int (*set_policy)(struct vm_area_struct___121 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___121 *, long unsigned int);
	struct page___121 * (*find_special_page)(struct vm_area_struct___121 *, long unsigned int);
};

struct core_thread___121 {
	struct task_struct___123 *task;
	struct core_thread___121 *next;
};

struct core_state___121 {
	atomic_t nr_threads;
	struct core_thread___121 dumper;
	struct completion startup;
};

struct vm_fault___114 {
	const struct {
		struct vm_area_struct___121 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___121 *cow_page;
	struct page___121 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___121 prealloc_pte;
};

struct cgroup_subsys___86;

struct cgroup_subsys_state___86 {
	struct cgroup___86 *cgroup;
	struct cgroup_subsys___86 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___86 *parent;
};

struct cgroup_file___86 {
	struct kernfs_node___108 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___86 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___123 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___86;

struct cgroup_rstat_cpu___86;

struct cgroup___86 {
	struct cgroup_subsys_state___86 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___108 *kn;
	struct cgroup_file___86 procs_file;
	struct cgroup_file___86 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___86 *subsys[14];
	struct cgroup_root___86 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___86 *dom_cgrp;
	struct cgroup___86 *old_dom_cgrp;
	struct cgroup_rstat_cpu___86 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___86 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___53 {
	struct request_queue___53 *q;
	struct io_context___53 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___116 {
	struct file___116 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___116 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___51 *ki_waitq;
	};
};

struct iattr___116 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___116 *ia_file;
};

struct dquot___116 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___116 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___116 {
	int qf_fmt_id;
	const struct quota_format_ops___116 *qf_ops;
	struct module___106 *qf_owner;
	struct quota_format_type___116 *qf_next;
};

struct quota_format_ops___116 {
	int (*check_quota_file)(struct super_block___116 *, int);
	int (*read_file_info)(struct super_block___116 *, int);
	int (*write_file_info)(struct super_block___116 *, int);
	int (*free_file_info)(struct super_block___116 *, int);
	int (*read_dqblk)(struct dquot___116 *);
	int (*commit_dqblk)(struct dquot___116 *);
	int (*release_dqblk)(struct dquot___116 *);
	int (*get_next_id)(struct super_block___116 *, struct kqid *);
};

struct dquot_operations___116 {
	int (*write_dquot)(struct dquot___116 *);
	struct dquot___116 * (*alloc_dquot)(struct super_block___116 *, int);
	void (*destroy_dquot)(struct dquot___116 *);
	int (*acquire_dquot)(struct dquot___116 *);
	int (*release_dquot)(struct dquot___116 *);
	int (*mark_dirty)(struct dquot___116 *);
	int (*write_info)(struct super_block___116 *, int);
	qsize_t * (*get_reserved_space)(struct inode___116 *);
	int (*get_projid)(struct inode___116 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___116 *, qsize_t *);
	int (*get_next_id)(struct super_block___116 *, struct kqid *);
};

struct quotactl_ops___116 {
	int (*quota_on)(struct super_block___116 *, int, int, const struct path___116 *);
	int (*quota_off)(struct super_block___116 *, int);
	int (*quota_enable)(struct super_block___116 *, unsigned int);
	int (*quota_disable)(struct super_block___116 *, unsigned int);
	int (*quota_sync)(struct super_block___116 *, int);
	int (*set_info)(struct super_block___116 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___116 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___116 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___116 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___116 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___116 *, unsigned int);
};

struct writeback_control___51;

struct address_space_operations___116 {
	int (*writepage)(struct page___121 *, struct writeback_control___51 *);
	int (*readpage)(struct file___116 *, struct page___121 *);
	int (*writepages)(struct address_space___116 *, struct writeback_control___51 *);
	int (*set_page_dirty)(struct page___121 *);
	int (*readpages)(struct file___116 *, struct address_space___116 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___116 *, struct address_space___116 *, loff_t, unsigned int, unsigned int, struct page___121 **, void **);
	int (*write_end)(struct file___116 *, struct address_space___116 *, loff_t, unsigned int, unsigned int, struct page___121 *, void *);
	sector_t (*bmap)(struct address_space___116 *, sector_t);
	void (*invalidatepage)(struct page___121 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___121 *, gfp_t);
	void (*freepage)(struct page___121 *);
	ssize_t (*direct_IO)(struct kiocb___116 *, struct iov_iter___66 *);
	int (*migratepage)(struct address_space___116 *, struct page___121 *, struct page___121 *, enum migrate_mode);
	bool (*isolate_page)(struct page___121 *, isolate_mode_t);
	void (*putback_page)(struct page___121 *);
	int (*launder_page)(struct page___121 *);
	int (*is_partially_uptodate)(struct page___121 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___121 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___116 *, struct page___121 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___116 *, sector_t *);
	void (*swap_deactivate)(struct file___116 *);
};

struct writeback_control___51 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___51 *wb;
	struct inode___116 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___64;

struct iov_iter___66 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___64 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___116 {
	struct dentry___116 * (*lookup)(struct inode___116 *, struct dentry___116 *, unsigned int);
	const char * (*get_link)(struct dentry___116 *, struct inode___116 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___116 *, int);
	struct posix_acl * (*get_acl)(struct inode___116 *, int, bool);
	int (*readlink)(struct dentry___116 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___116 *, struct dentry___116 *, umode_t, bool);
	int (*link)(struct dentry___116 *, struct inode___116 *, struct dentry___116 *);
	int (*unlink)(struct inode___116 *, struct dentry___116 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___116 *, struct dentry___116 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___116 *, struct dentry___116 *, umode_t);
	int (*rmdir)(struct inode___116 *, struct dentry___116 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___116 *, struct dentry___116 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___116 *, struct dentry___116 *, struct inode___116 *, struct dentry___116 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___116 *, struct iattr___116 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___116 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___116 *, char *, size_t);
	int (*fiemap)(struct inode___116 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___116 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___116 *, struct dentry___116 *, struct file___116 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___116 *, struct dentry___116 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___116 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___116 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___116 *, struct fileattr *);
	long: 64;
};

struct fsverity_info___4 {
	struct merkle_tree_params tree_params;
	u8 root_hash[64];
	u8 file_digest[64];
	const struct inode___116 *inode;
};

struct file_lock_operations___116 {
	void (*fl_copy_lock)(struct file_lock___116 *, struct file_lock___116 *);
	void (*fl_release_private)(struct file_lock___116 *);
};

struct fasync_struct___116;

struct lock_manager_operations___116;

struct file_lock___116 {
	struct file_lock___116 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___116 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___116 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___116 *fl_ops;
	const struct lock_manager_operations___116 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___116 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___116 *);
	int (*lm_grant)(struct file_lock___116 *, int);
	bool (*lm_break)(struct file_lock___116 *);
	int (*lm_change)(struct file_lock___116 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___116 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___116 *);
};

struct fasync_struct___116 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___116 *fa_next;
	struct file___116 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___116 {
	struct inode___116 * (*alloc_inode)(struct super_block___116 *);
	void (*destroy_inode)(struct inode___116 *);
	void (*free_inode)(struct inode___116 *);
	void (*dirty_inode)(struct inode___116 *, int);
	int (*write_inode)(struct inode___116 *, struct writeback_control___51 *);
	int (*drop_inode)(struct inode___116 *);
	void (*evict_inode)(struct inode___116 *);
	void (*put_super)(struct super_block___116 *);
	int (*sync_fs)(struct super_block___116 *, int);
	int (*freeze_super)(struct super_block___116 *);
	int (*freeze_fs)(struct super_block___116 *);
	int (*thaw_super)(struct super_block___116 *);
	int (*unfreeze_fs)(struct super_block___116 *);
	int (*statfs)(struct dentry___116 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___116 *, int *, char *);
	void (*umount_begin)(struct super_block___116 *);
	int (*show_options)(struct seq_file___103 *, struct dentry___116 *);
	int (*show_devname)(struct seq_file___103 *, struct dentry___116 *);
	int (*show_path)(struct seq_file___103 *, struct dentry___116 *);
	int (*show_stats)(struct seq_file___103 *, struct dentry___116 *);
	ssize_t (*quota_read)(struct super_block___116 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___116 *, int, const char *, size_t, loff_t);
	struct dquot___116 ** (*get_dquots)(struct inode___116 *);
	long int (*nr_cached_objects)(struct super_block___116 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___116 *, struct shrink_control___45 *);
	struct file___116 * (*real_loop)(struct file___116 *);
};

struct fsverity_operations___4 {
	int (*begin_enable_verity)(struct file___116 *);
	int (*end_enable_verity)(struct file___116 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___116 *, void *, size_t);
	struct page___121 * (*read_merkle_tree_page)(struct inode___116 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___116 *, const void *, u64, int);
};

struct wakeup_source___89;

struct dev_pm_info___89 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___89 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___89 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___89;

struct bus_type___89;

struct device_driver___89;

struct dev_pm_domain___89;

struct fwnode_handle___89;

struct class___89;

struct attribute_group___108;

struct device___89 {
	struct kobject___108 kobj;
	struct device___89 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___89 *type;
	struct bus_type___89 *bus;
	struct device_driver___89 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___89 power;
	struct dev_pm_domain___89 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___89 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___89 *class;
	const struct attribute_group___108 **groups;
	void (*release)(struct device___89 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___54 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___116 *bd_inode;
	struct super_block___116 *bd_super;
	void *bd_claiming;
	struct device___89 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___108 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___53 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___116 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___103;

struct seq_file___103 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___103 *op;
	int poll_event;
	const struct file___116 *file;
	void *private;
};

typedef void bio_end_io_t___53(struct bio___53 *);

struct bio_vec___64 {
	struct page___121 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___53;

struct bio___53 {
	struct bio___53 *bi_next;
	struct block_device___54 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___53 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___51 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___53 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___64 *bi_io_vec;
	struct bio_set___53 *bi_pool;
	struct bio_vec___64 bi_inline_vecs[0];
};

struct fsverity_read_metadata_arg {
	__u64 metadata_type;
	__u64 offset;
	__u64 length;
	__u64 buf_ptr;
	__u64 __reserved;
};

struct dev_pagemap_ops___114 {
	void (*page_free)(struct page___121 *);
	void (*kill)(struct dev_pagemap___114 *);
	void (*cleanup)(struct dev_pagemap___114 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___114 *);
};

struct fwnode_operations___89;

struct fwnode_handle___89 {
	struct fwnode_handle___89 *secondary;
	const struct fwnode_operations___89 *ops;
	struct device___89 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___89;

struct fwnode_endpoint___89;

struct fwnode_operations___89 {
	struct fwnode_handle___89 * (*get)(struct fwnode_handle___89 *);
	void (*put)(struct fwnode_handle___89 *);
	bool (*device_is_available)(const struct fwnode_handle___89 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___89 *, const struct device___89 *);
	bool (*property_present)(const struct fwnode_handle___89 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___89 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___89 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___89 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*get_parent)(const struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*get_next_child_node)(const struct fwnode_handle___89 *, struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*get_named_child_node)(const struct fwnode_handle___89 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___89 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___89 *);
	struct fwnode_handle___89 * (*graph_get_next_endpoint)(const struct fwnode_handle___89 *, struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*graph_get_remote_endpoint)(const struct fwnode_handle___89 *);
	struct fwnode_handle___89 * (*graph_get_port_parent)(struct fwnode_handle___89 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___89 *, struct fwnode_endpoint___89 *);
	int (*add_links)(struct fwnode_handle___89 *);
};

struct fwnode_endpoint___89 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___89 *local_fwnode;
};

struct fwnode_reference_args___89 {
	struct fwnode_handle___89 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___108;

struct kernfs_elem_dir___108 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___108 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___108;

struct kernfs_root___108 {
	struct kernfs_node___108 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___108 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___108 {
	struct kernfs_node___108 *target_kn;
};

struct kernfs_ops___108;

struct kernfs_elem_attr___108 {
	const struct kernfs_ops___108 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___108 *notify_next;
};

struct kernfs_node___108 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___108 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___108 dir;
		struct kernfs_elem_symlink___108 symlink;
		struct kernfs_elem_attr___108 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___108;

struct kernfs_ops___108 {
	int (*open)(struct kernfs_open_file___108 *);
	void (*release)(struct kernfs_open_file___108 *);
	int (*seq_show)(struct seq_file___103 *, void *);
	void * (*seq_start)(struct seq_file___103 *, loff_t *);
	void * (*seq_next)(struct seq_file___103 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___103 *, void *);
	ssize_t (*read)(struct kernfs_open_file___108 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___108 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___108 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___108 *, struct vm_area_struct___121 *);
};

struct kernfs_syscall_ops___108 {
	int (*show_options)(struct seq_file___103 *, struct kernfs_root___108 *);
	int (*mkdir)(struct kernfs_node___108 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___108 *);
	int (*rename)(struct kernfs_node___108 *, struct kernfs_node___108 *, const char *);
	int (*show_path)(struct seq_file___103 *, struct kernfs_node___108 *, struct kernfs_root___108 *);
};

struct kernfs_open_file___108 {
	struct kernfs_node___108 *kn;
	struct file___116 *file;
	struct seq_file___103 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___114 *vm_ops;
};

struct bin_attribute___108;

struct attribute_group___108 {
	const char *name;
	umode_t (*is_visible)(struct kobject___108 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___108 *, struct bin_attribute___108 *, int);
	struct attribute **attrs;
	struct bin_attribute___108 **bin_attrs;
};

struct bin_attribute___108 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___116 * (*f_mapping)();
	ssize_t (*read)(struct file___116 *, struct kobject___108 *, struct bin_attribute___108 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___116 *, struct kobject___108 *, struct bin_attribute___108 *, char *, loff_t, size_t);
	int (*mmap)(struct file___116 *, struct kobject___108 *, struct bin_attribute___108 *, struct vm_area_struct___121 *);
};

struct sysfs_ops___108 {
	ssize_t (*show)(struct kobject___108 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___108 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___108;

struct kset___108 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___108 kobj;
	const struct kset_uevent_ops___108 *uevent_ops;
};

struct kobj_type___108 {
	void (*release)(struct kobject___108 *);
	const struct sysfs_ops___108 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___108 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___108 *);
	const void * (*namespace)(struct kobject___108 *);
	void (*get_ownership)(struct kobject___108 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___108 {
	int (* const filter)(struct kset___108 *, struct kobject___108 *);
	const char * (* const name)(struct kset___108 *, struct kobject___108 *);
	int (* const uevent)(struct kset___108 *, struct kobject___108 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___105 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___105 *);
	int (*get)(char *, const struct kernel_param___105 *);
	void (*free)(void *);
};

struct kparam_array___105;

struct kernel_param___105 {
	const char *name;
	struct module___106 *mod;
	const struct kernel_param_ops___105 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___105 *arr;
	};
};

struct kparam_array___105 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___105 *ops;
	void *elem;
};

struct module_attribute___105 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___105 *, struct module_kobject___105 *, char *);
	ssize_t (*store)(struct module_attribute___105 *, struct module_kobject___105 *, const char *, size_t);
	void (*setup)(struct module___106 *, const char *);
	int (*test)(struct module___106 *);
	void (*free)(struct module___106 *);
};

struct cgroup_namespace___86 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___86 *root_cset;
};

struct dev_pm_ops___89 {
	int (*prepare)(struct device___89 *);
	void (*complete)(struct device___89 *);
	int (*suspend)(struct device___89 *);
	int (*resume)(struct device___89 *);
	int (*freeze)(struct device___89 *);
	int (*thaw)(struct device___89 *);
	int (*poweroff)(struct device___89 *);
	int (*restore)(struct device___89 *);
	int (*suspend_late)(struct device___89 *);
	int (*resume_early)(struct device___89 *);
	int (*freeze_late)(struct device___89 *);
	int (*thaw_early)(struct device___89 *);
	int (*poweroff_late)(struct device___89 *);
	int (*restore_early)(struct device___89 *);
	int (*suspend_noirq)(struct device___89 *);
	int (*resume_noirq)(struct device___89 *);
	int (*freeze_noirq)(struct device___89 *);
	int (*thaw_noirq)(struct device___89 *);
	int (*poweroff_noirq)(struct device___89 *);
	int (*restore_noirq)(struct device___89 *);
	int (*runtime_suspend)(struct device___89 *);
	int (*runtime_resume)(struct device___89 *);
	int (*runtime_idle)(struct device___89 *);
};

struct wakeup_source___89 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___89 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___89 {
	struct dev_pm_ops___89 ops;
	int (*start)(struct device___89 *);
	void (*detach)(struct device___89 *, bool);
	int (*activate)(struct device___89 *);
	void (*sync)(struct device___89 *);
	void (*dismiss)(struct device___89 *);
};

struct bus_type___89 {
	const char *name;
	const char *dev_name;
	struct device___89 *dev_root;
	const struct attribute_group___108 **bus_groups;
	const struct attribute_group___108 **dev_groups;
	const struct attribute_group___108 **drv_groups;
	int (*match)(struct device___89 *, struct device_driver___89 *);
	int (*uevent)(struct device___89 *, struct kobj_uevent_env *);
	int (*probe)(struct device___89 *);
	void (*sync_state)(struct device___89 *);
	void (*remove)(struct device___89 *);
	void (*shutdown)(struct device___89 *);
	int (*online)(struct device___89 *);
	int (*offline)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	int (*num_vf)(struct device___89 *);
	int (*dma_configure)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___89 {
	const char *name;
	struct bus_type___89 *bus;
	struct module___106 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___89 *);
	void (*sync_state)(struct device___89 *);
	int (*remove)(struct device___89 *);
	void (*shutdown)(struct device___89 *);
	int (*suspend)(struct device___89 *, pm_message_t);
	int (*resume)(struct device___89 *);
	const struct attribute_group___108 **groups;
	const struct attribute_group___108 **dev_groups;
	const struct dev_pm_ops___89 *pm;
	void (*coredump)(struct device___89 *);
	struct driver_private *p;
};

struct device_type___89 {
	const char *name;
	const struct attribute_group___108 **groups;
	int (*uevent)(struct device___89 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___89 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___89 *);
	const struct dev_pm_ops___89 *pm;
};

struct class___89 {
	const char *name;
	struct module___106 *owner;
	const struct attribute_group___108 **class_groups;
	const struct attribute_group___108 **dev_groups;
	struct kobject___108 *dev_kobj;
	int (*dev_uevent)(struct device___89 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___89 *, umode_t *);
	void (*class_release)(struct class___89 *);
	void (*dev_release)(struct device___89 *);
	int (*shutdown_pre)(struct device___89 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___89 *);
	void (*get_ownership)(struct device___89 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___89 *pm;
	struct subsys_private *p;
};

struct block_device_operations___53;

struct gendisk___53 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___54 *part0;
	const struct block_device_operations___53 *fops;
	struct request_queue___53 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___51 *bdi;
	struct kobject___108 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___108 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___53 {
	struct bio___53 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___64 *bip_vec;
	struct bio_vec___64 bip_inline_vecs[0];
};

struct blkcg___51;

struct blkg_policy_data___51;

struct blkcg_gq___51 {
	struct request_queue___53 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___51 *blkcg;
	struct blkcg_gq___51 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___51 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___53 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___53(struct request___53 *);

typedef void integrity_complete_fn___53(struct request___53 *, unsigned int);

struct blk_integrity_profile___53 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___53 *prepare_fn;
	integrity_complete_fn___53 *complete_fn;
	const char *name;
};

struct block_device_operations___53 {
	blk_qc_t (*submit_bio)(struct bio___53 *);
	int (*open)(struct block_device___54 *, fmode_t);
	void (*release)(struct gendisk___53 *, fmode_t);
	int (*rw_page)(struct block_device___54 *, sector_t, struct page___121 *, unsigned int);
	int (*ioctl)(struct block_device___54 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___54 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___53 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___53 *);
	int (*getgeo)(struct block_device___54 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___54 *, bool);
	void (*swap_slot_free_notify)(struct block_device___54 *, long unsigned int);
	int (*report_zones)(struct gendisk___53 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___53 *, umode_t *);
	struct module___106 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___53 *, sector_t *);
};

typedef void rq_end_io_fn___53(struct request___53 *, blk_status_t);

struct request___53 {
	struct request_queue___53 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___51 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___53 *bio;
	struct bio___53 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___64 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___53 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___53 *saved_end_io;
		} flush;
	};
	struct gendisk___53 *rq_disk;
	struct block_device___54 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___53 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___51 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___53 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___108 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___116 *debugfs_dir;
	struct dentry___116 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___53;

struct elevator_mq_ops___53 {
	int (*init_sched)(struct request_queue___53 *, struct elevator_type___53 *);
	void (*exit_sched)(struct elevator_queue___53 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___51 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___51 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___51 *);
	bool (*allow_merge)(struct request_queue___53 *, struct request___53 *, struct bio___53 *);
	bool (*bio_merge)(struct request_queue___53 *, struct bio___53 *, unsigned int);
	int (*request_merge)(struct request_queue___53 *, struct request___53 **, struct bio___53 *);
	void (*request_merged)(struct request_queue___53 *, struct request___53 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___53 *, struct request___53 *, struct request___53 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___53 *);
	void (*finish_request)(struct request___53 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___51 *, struct list_head *, bool);
	struct request___53 * (*dispatch_request)(struct blk_mq_hw_ctx___51 *);
	bool (*has_work)(struct blk_mq_hw_ctx___51 *);
	void (*completed_request)(struct request___53 *, u64);
	void (*requeue_request)(struct request___53 *);
	struct request___53 * (*former_request)(struct request_queue___53 *, struct request___53 *);
	struct request___53 * (*next_request)(struct request_queue___53 *, struct request___53 *);
	void (*init_icq)(struct io_cq___53 *);
	void (*exit_icq)(struct io_cq___53 *);
};

struct elv_fs_entry___53;

struct elevator_type___53 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___53 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___53 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___106 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___53 {
	struct elevator_type___53 *type;
	void *elevator_data;
	struct kobject___108 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___53 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___53 *, char *);
	ssize_t (*store)(struct elevator_queue___53 *, const char *, size_t);
};

struct blk_mq_queue_data___51;

struct blk_mq_ops___51 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___51 *, const struct blk_mq_queue_data___51 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___51 *);
	int (*get_budget)(struct request_queue___53 *);
	void (*put_budget)(struct request_queue___53 *, int);
	void (*set_rq_budget_token)(struct request___53 *, int);
	int (*get_rq_budget_token)(struct request___53 *);
	enum blk_eh_timer_return (*timeout)(struct request___53 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___51 *);
	void (*complete)(struct request___53 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___51 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___51 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___51 *, struct request___53 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___51 *, struct request___53 *, unsigned int);
	void (*initialize_rq_fn)(struct request___53 *);
	void (*cleanup_rq)(struct request___53 *);
	bool (*busy)(struct request_queue___53 *);
	int (*map_queues)(struct blk_mq_tag_set___51 *);
	void (*show_rq)(struct seq_file___103 *, struct request___53 *);
};

struct blk_mq_tag_set___51 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___51 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___103 {
	void * (*start)(struct seq_file___103 *, loff_t *);
	void (*stop)(struct seq_file___103 *, void *);
	void * (*next)(struct seq_file___103 *, void *, loff_t *);
	int (*show)(struct seq_file___103 *, void *);
};

struct cftype___86;

struct cgroup_subsys___86 {
	struct cgroup_subsys_state___86 * (*css_alloc)(struct cgroup_subsys_state___86 *);
	int (*css_online)(struct cgroup_subsys_state___86 *);
	void (*css_offline)(struct cgroup_subsys_state___86 *);
	void (*css_released)(struct cgroup_subsys_state___86 *);
	void (*css_free)(struct cgroup_subsys_state___86 *);
	void (*css_reset)(struct cgroup_subsys_state___86 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___86 *, int);
	int (*css_extra_stat_show)(struct seq_file___103 *, struct cgroup_subsys_state___86 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___123 *, struct css_set___86 *);
	void (*cancel_fork)(struct task_struct___123 *, struct css_set___86 *);
	void (*fork)(struct task_struct___123 *);
	void (*exit)(struct task_struct___123 *);
	void (*release)(struct task_struct___123 *);
	void (*bind)(struct cgroup_subsys_state___86 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___86 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___86 *dfl_cftypes;
	struct cftype___86 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___86 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___86 *updated_children;
	struct cgroup___86 *updated_next;
};

struct cgroup_root___86 {
	struct kernfs_root___108 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___86 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___86 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___86 *ss;
	struct list_head node;
	struct kernfs_ops___108 *kf_ops;
	int (*open)(struct kernfs_open_file___108 *);
	void (*release)(struct kernfs_open_file___108 *);
	u64 (*read_u64)(struct cgroup_subsys_state___86 *, struct cftype___86 *);
	s64 (*read_s64)(struct cgroup_subsys_state___86 *, struct cftype___86 *);
	int (*seq_show)(struct seq_file___103 *, void *);
	void * (*seq_start)(struct seq_file___103 *, loff_t *);
	void * (*seq_next)(struct seq_file___103 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___103 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___86 *, struct cftype___86 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___86 *, struct cftype___86 *, s64);
	ssize_t (*write)(struct kernfs_open_file___108 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___108 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___51 {
	struct request___53 *rq;
	bool last;
};

struct blkcg_policy_data___51;

struct blkcg___51 {
	struct cgroup_subsys_state___86 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___51 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___51 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___51 {
	struct blkcg___51 *blkcg;
	int plid;
};

struct blkg_policy_data___51 {
	struct blkcg_gq___51 *blkg;
	int plid;
};

struct bvec_iter_all___3 {
	struct bio_vec___19 bv;
	int idx;
	unsigned int done;
};

struct fsverity_formatted_digest {
	char magic[8];
	__le16 digest_algorithm;
	__le16 digest_size;
	__u8 digest[0];
};

struct flock64 {
	short int l_type;
	short int l_whence;
	__kernel_loff_t l_start;
	__kernel_loff_t l_len;
	__kernel_pid_t l_pid;
};

struct trace_event_file___25;

struct trace_event_buffer___24 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___25 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___25 {
	struct list_head list;
	struct trace_event_call___45 *event_call;
	struct event_filter *filter;
	struct dentry___85 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_locks_get_lock_context {
	struct trace_entry ent;
	long unsigned int i_ino;
	dev_t s_dev;
	unsigned char type;
	struct file_lock_context *ctx;
	char __data[0];
};

struct trace_event_raw_filelock_lock {
	struct trace_entry ent;
	struct file_lock___85 *fl;
	long unsigned int i_ino;
	dev_t s_dev;
	struct file_lock___85 *fl_blocker;
	fl_owner_t fl_owner;
	unsigned int fl_pid;
	unsigned int fl_flags;
	unsigned char fl_type;
	loff_t fl_start;
	loff_t fl_end;
	int ret;
	char __data[0];
};

struct trace_event_raw_filelock_lease {
	struct trace_entry ent;
	struct file_lock___85 *fl;
	long unsigned int i_ino;
	dev_t s_dev;
	struct file_lock___85 *fl_blocker;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	char __data[0];
};

struct trace_event_raw_generic_add_lease {
	struct trace_entry ent;
	long unsigned int i_ino;
	int wcount;
	int rcount;
	int icount;
	dev_t s_dev;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	char __data[0];
};

struct trace_event_raw_leases_conflict {
	struct trace_entry ent;
	void *lease;
	void *breaker;
	unsigned int l_fl_flags;
	unsigned int b_fl_flags;
	unsigned char l_fl_type;
	unsigned char b_fl_type;
	bool conflict;
	char __data[0];
};

struct trace_event_data_offsets_locks_get_lock_context {};

struct trace_event_data_offsets_filelock_lock {};

struct trace_event_data_offsets_filelock_lease {};

struct trace_event_data_offsets_generic_add_lease {};

struct trace_event_data_offsets_leases_conflict {};

typedef void (*btf_trace_locks_get_lock_context)(void *, struct inode___85 *, int, struct file_lock_context *);

typedef void (*btf_trace_posix_lock_inode)(void *, struct inode___85 *, struct file_lock___85 *, int);

typedef void (*btf_trace_fcntl_setlk)(void *, struct inode___85 *, struct file_lock___85 *, int);

typedef void (*btf_trace_locks_remove_posix)(void *, struct inode___85 *, struct file_lock___85 *, int);

typedef void (*btf_trace_flock_lock_inode)(void *, struct inode___85 *, struct file_lock___85 *, int);

typedef void (*btf_trace_break_lease_noblock)(void *, struct inode___85 *, struct file_lock___85 *);

typedef void (*btf_trace_break_lease_block)(void *, struct inode___85 *, struct file_lock___85 *);

typedef void (*btf_trace_break_lease_unblock)(void *, struct inode___85 *, struct file_lock___85 *);

typedef void (*btf_trace_generic_delete_lease)(void *, struct inode___85 *, struct file_lock___85 *);

typedef void (*btf_trace_time_out_leases)(void *, struct inode___85 *, struct file_lock___85 *);

typedef void (*btf_trace_generic_add_lease)(void *, struct inode___85 *, struct file_lock___85 *);

typedef void (*btf_trace_leases_conflict)(void *, bool, struct file_lock___85 *, struct file_lock___85 *);

struct file_lock_list_struct {
	spinlock_t lock;
	struct hlist_head hlist;
};

struct proc_fs_info___2 {
	struct pid_namespace___77 *pid_ns;
	struct dentry___85 *proc_self;
	struct dentry___85 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

struct locks_iterator {
	int li_cpu;
	loff_t li_pos;
};

typedef unsigned int __kernel_uid_t;

typedef unsigned int __kernel_gid_t;

struct dentry___117;

struct super_block___117;

struct module___107;

struct file_system_type___117 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___117 * (*mount)(struct file_system_type___117 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___117 *);
	struct module___107 *owner;
	struct file_system_type___117 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___117;

struct kiocb___117;

struct vm_area_struct___122;

struct inode___117;

struct file_lock___117;

struct page___122;

struct seq_file___104;

struct file_operations___117 {
	struct module___107 *owner;
	loff_t (*llseek)(struct file___117 *, loff_t, int);
	ssize_t (*read)(struct file___117 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___117 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___117 *, struct iov_iter___66 *);
	ssize_t (*write_iter)(struct kiocb___117 *, struct iov_iter___66 *);
	int (*iopoll)(struct kiocb___117 *, bool);
	int (*iterate)(struct file___117 *, struct dir_context *);
	int (*iterate_shared)(struct file___117 *, struct dir_context *);
	__poll_t (*poll)(struct file___117 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___117 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___117 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___117 *, struct vm_area_struct___122 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___117 *, struct file___117 *);
	int (*flush)(struct file___117 *, fl_owner_t);
	int (*release)(struct inode___117 *, struct file___117 *);
	int (*fsync)(struct file___117 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___117 *, int);
	int (*lock)(struct file___117 *, int, struct file_lock___117 *);
	ssize_t (*sendpage)(struct file___117 *, struct page___122 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___117 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___117 *, long unsigned int);
	int (*flock)(struct file___117 *, int, struct file_lock___117 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___117 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___117 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___117 *, long int, struct file_lock___117 **, void **);
	long int (*fallocate)(struct file___117 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___104 *, struct file___117 *);
	ssize_t (*copy_file_range)(struct file___117 *, loff_t, struct file___117 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___117 *, loff_t, struct file___117 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___117 *, loff_t, loff_t, int);
};

struct vmacache___122 {
	u64 seqnum;
	struct vm_area_struct___122 *vmas[4];
};

struct page_frag___122 {
	struct page___122 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___123;

struct pid___102;

struct nsproxy___108;

struct signal_struct___118;

struct css_set___87;

struct vm_struct___107;

struct task_struct___124 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___124 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___123 *mm;
	struct mm_struct___123 *active_mm;
	struct vmacache___122 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___124 *real_parent;
	struct task_struct___124 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___124 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___102 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___108 *nsproxy;
	struct signal_struct___118 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___124 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___53 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___87 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___122 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___124 *oom_reaper_list;
	struct vm_struct___107 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___62 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___109;

struct kobj_type___109;

struct kernfs_node___109;

struct kobject___109 {
	const char *name;
	struct list_head entry;
	struct kobject___109 *parent;
	struct kset___109 *kset;
	struct kobj_type___109 *ktype;
	struct kernfs_node___109 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___106 {
	struct kobject___109 kobj;
	struct module___107 *mod;
	struct kobject___109 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___106 {
	struct module___107 *mod;
	struct latch_tree_node node;
};

struct module_layout___106 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___106 mtn;
};

struct module_attribute___106;

struct kernel_param___106;

struct module___107 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___106 mkobj;
	struct module_attribute___106 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___109 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___106 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___106 core_layout;
	struct module_layout___106 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___102;

struct upid___102 {
	int nr;
	struct pid_namespace___102 *ns;
};

struct pid_namespace___102 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___124 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___102 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___102 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___102 numbers[1];
};

typedef struct page___122 *pgtable_t___122;

struct address_space___117;

struct dev_pagemap___115;

struct page___122 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___117 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___122 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___122 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___123 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___115 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___115;

struct vm_area_struct___122 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___122 *vm_next;
	struct vm_area_struct___122 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___123 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___115 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___117 *vm_file;
	struct file___117 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___118 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___124 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___124 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___102 *pids[4];
	struct pid___102 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___123 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___16;

struct core_state___122;

struct mm_struct___123 {
	struct {
		struct vm_area_struct___122 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___117 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___16 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___122 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___124 *owner;
		struct user_namespace___4 *user_ns;
		struct file___117 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___87;

struct nsproxy___108 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___102 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___87 *cgroup_ns;
};

struct cgroup_subsys_state___87;

struct cgroup___87;

struct css_set___87 {
	struct cgroup_subsys_state___87 *subsys[14];
	refcount_t refcount;
	struct css_set___87 *dom_cset;
	struct cgroup___87 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___87 *mg_src_cgrp;
	struct cgroup___87 *mg_dst_cgrp;
	struct css_set___87 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___107 {
	struct vm_struct___107 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___122 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___117;

struct address_space___117 {
	struct inode___117 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___117 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___115;

struct dev_pagemap___115 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___115 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___117;

struct path___117 {
	struct vfsmount___117 *mnt;
	struct dentry___117 *dentry;
};

struct fown_struct___102 {
	rwlock_t lock;
	struct pid___102 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___117 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___117 f_path;
	struct inode___117 *f_inode;
	const struct file_operations___117 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___102 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___117 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___115;

struct vm_operations_struct___115 {
	void (*open)(struct vm_area_struct___122 *);
	void (*close)(struct vm_area_struct___122 *);
	int (*may_split)(struct vm_area_struct___122 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___122 *);
	int (*mprotect)(struct vm_area_struct___122 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___115 *);
	vm_fault_t (*huge_fault)(struct vm_fault___115 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___115 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___122 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___115 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___115 *);
	int (*access)(struct vm_area_struct___122 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___122 *);
	int (*set_policy)(struct vm_area_struct___122 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___122 *, long unsigned int);
	struct page___122 * (*find_special_page)(struct vm_area_struct___122 *, long unsigned int);
};

struct core_thread___122 {
	struct task_struct___124 *task;
	struct core_thread___122 *next;
};

struct core_state___122 {
	atomic_t nr_threads;
	struct core_thread___122 dumper;
	struct completion startup;
};

struct linux_binprm___17;

struct coredump_params___16;

struct linux_binfmt___16 {
	struct list_head lh;
	struct module___107 *module;
	int (*load_binary)(struct linux_binprm___17 *);
	int (*load_shlib)(struct file___117 *);
	int (*core_dump)(struct coredump_params___16 *);
	long unsigned int min_coredump;
};

struct vm_fault___115 {
	const struct {
		struct vm_area_struct___122 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___122 *cow_page;
	struct page___122 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___122 prealloc_pte;
};

struct dentry_operations___117;

struct dentry___117 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___117 *d_parent;
	struct qstr d_name;
	struct inode___117 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___117 *d_op;
	struct super_block___117 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___117;

struct inode___117 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___117 *i_op;
	struct super_block___117 *i_sb;
	struct address_space___117 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___117 *i_fop;
		void (*free_inode)(struct inode___117 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___117 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___39 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___117 {
	int (*d_revalidate)(struct dentry___117 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___117 *, unsigned int);
	int (*d_hash)(const struct dentry___117 *, struct qstr *);
	int (*d_compare)(const struct dentry___117 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___117 *);
	int (*d_init)(struct dentry___117 *);
	void (*d_release)(struct dentry___117 *);
	void (*d_prune)(struct dentry___117 *);
	void (*d_iput)(struct dentry___117 *, struct inode___117 *);
	char * (*d_dname)(struct dentry___117 *, char *, int);
	struct vfsmount___117 * (*d_automount)(struct path___117 *);
	int (*d_manage)(const struct path___117 *, bool);
	struct dentry___117 * (*d_real)(struct dentry___117 *, const struct inode___117 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___117;

struct mem_dqinfo___117 {
	struct quota_format_type___117 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___117;

struct quota_info___117 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___117 *files[3];
	struct mem_dqinfo___117 info[3];
	const struct quota_format_ops___117 *ops[3];
};

struct rcuwait___118 {
	struct task_struct___124 *task;
};

struct percpu_rw_semaphore___118 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___118 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___117 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___118 rw_sem[3];
};

struct super_operations___117;

struct dquot_operations___117;

struct quotactl_ops___117;

struct super_block___117 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___117 *s_type;
	const struct super_operations___117 *s_op;
	const struct dquot_operations___117 *dq_op;
	const struct quotactl_ops___117 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___117 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___117 s_dquot;
	struct sb_writers___117 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___117 *s_d_op;
	int cleancache_poolid;
	struct shrinker___45 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___117 {
	struct dentry___117 *mnt_root;
	struct super_block___117 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct cgroup_subsys___87;

struct cgroup_subsys_state___87 {
	struct cgroup___87 *cgroup;
	struct cgroup_subsys___87 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___87 *parent;
};

struct cgroup_file___87 {
	struct kernfs_node___109 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___87 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___124 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___87;

struct cgroup_rstat_cpu___87;

struct cgroup___87 {
	struct cgroup_subsys_state___87 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___109 *kn;
	struct cgroup_file___87 procs_file;
	struct cgroup_file___87 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___87 *subsys[14];
	struct cgroup_root___87 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___87 *dom_cgrp;
	struct cgroup___87 *old_dom_cgrp;
	struct cgroup_rstat_cpu___87 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___87 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___52;

struct kiocb___117 {
	struct file___117 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___117 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___52 *ki_waitq;
	};
};

struct iattr___117 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___117 *ia_file;
};

struct dquot___117 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___117 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___117 {
	int qf_fmt_id;
	const struct quota_format_ops___117 *qf_ops;
	struct module___107 *qf_owner;
	struct quota_format_type___117 *qf_next;
};

struct quota_format_ops___117 {
	int (*check_quota_file)(struct super_block___117 *, int);
	int (*read_file_info)(struct super_block___117 *, int);
	int (*write_file_info)(struct super_block___117 *, int);
	int (*free_file_info)(struct super_block___117 *, int);
	int (*read_dqblk)(struct dquot___117 *);
	int (*commit_dqblk)(struct dquot___117 *);
	int (*release_dqblk)(struct dquot___117 *);
	int (*get_next_id)(struct super_block___117 *, struct kqid *);
};

struct dquot_operations___117 {
	int (*write_dquot)(struct dquot___117 *);
	struct dquot___117 * (*alloc_dquot)(struct super_block___117 *, int);
	void (*destroy_dquot)(struct dquot___117 *);
	int (*acquire_dquot)(struct dquot___117 *);
	int (*release_dquot)(struct dquot___117 *);
	int (*mark_dirty)(struct dquot___117 *);
	int (*write_info)(struct super_block___117 *, int);
	qsize_t * (*get_reserved_space)(struct inode___117 *);
	int (*get_projid)(struct inode___117 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___117 *, qsize_t *);
	int (*get_next_id)(struct super_block___117 *, struct kqid *);
};

struct quotactl_ops___117 {
	int (*quota_on)(struct super_block___117 *, int, int, const struct path___117 *);
	int (*quota_off)(struct super_block___117 *, int);
	int (*quota_enable)(struct super_block___117 *, unsigned int);
	int (*quota_disable)(struct super_block___117 *, unsigned int);
	int (*quota_sync)(struct super_block___117 *, int);
	int (*set_info)(struct super_block___117 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___117 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___117 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___117 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___117 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___117 *, unsigned int);
};

struct wait_page_queue___52 {
	struct page___122 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___52;

struct address_space_operations___117 {
	int (*writepage)(struct page___122 *, struct writeback_control___3 *);
	int (*readpage)(struct file___117 *, struct page___122 *);
	int (*writepages)(struct address_space___117 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___122 *);
	int (*readpages)(struct file___117 *, struct address_space___117 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___52 *);
	int (*write_begin)(struct file___117 *, struct address_space___117 *, loff_t, unsigned int, unsigned int, struct page___122 **, void **);
	int (*write_end)(struct file___117 *, struct address_space___117 *, loff_t, unsigned int, unsigned int, struct page___122 *, void *);
	sector_t (*bmap)(struct address_space___117 *, sector_t);
	void (*invalidatepage)(struct page___122 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___122 *, gfp_t);
	void (*freepage)(struct page___122 *);
	ssize_t (*direct_IO)(struct kiocb___117 *, struct iov_iter___66 *);
	int (*migratepage)(struct address_space___117 *, struct page___122 *, struct page___122 *, enum migrate_mode);
	bool (*isolate_page)(struct page___122 *, isolate_mode_t);
	void (*putback_page)(struct page___122 *);
	int (*launder_page)(struct page___122 *);
	int (*is_partially_uptodate)(struct page___122 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___122 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___117 *, struct page___122 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___117 *, sector_t *);
	void (*swap_deactivate)(struct file___117 *);
};

struct readahead_control___52 {
	struct file___117 *file;
	struct address_space___117 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___117 {
	struct dentry___117 * (*lookup)(struct inode___117 *, struct dentry___117 *, unsigned int);
	const char * (*get_link)(struct dentry___117 *, struct inode___117 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___117 *, int);
	struct posix_acl * (*get_acl)(struct inode___117 *, int, bool);
	int (*readlink)(struct dentry___117 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___117 *, struct dentry___117 *, umode_t, bool);
	int (*link)(struct dentry___117 *, struct inode___117 *, struct dentry___117 *);
	int (*unlink)(struct inode___117 *, struct dentry___117 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___117 *, struct dentry___117 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___117 *, struct dentry___117 *, umode_t);
	int (*rmdir)(struct inode___117 *, struct dentry___117 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___117 *, struct dentry___117 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___117 *, struct dentry___117 *, struct inode___117 *, struct dentry___117 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___117 *, struct iattr___117 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___117 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___117 *, char *, size_t);
	int (*fiemap)(struct inode___117 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___117 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___117 *, struct dentry___117 *, struct file___117 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___117 *, struct dentry___117 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___117 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___117 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___117 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___117 {
	void (*fl_copy_lock)(struct file_lock___117 *, struct file_lock___117 *);
	void (*fl_release_private)(struct file_lock___117 *);
};

struct fasync_struct___117;

struct lock_manager_operations___117;

struct file_lock___117 {
	struct file_lock___117 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___117 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___117 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___117 *fl_ops;
	const struct lock_manager_operations___117 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___117 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___117 *);
	int (*lm_grant)(struct file_lock___117 *, int);
	bool (*lm_break)(struct file_lock___117 *);
	int (*lm_change)(struct file_lock___117 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___117 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___117 *);
};

struct fasync_struct___117 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___117 *fa_next;
	struct file___117 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___117 {
	struct inode___117 * (*alloc_inode)(struct super_block___117 *);
	void (*destroy_inode)(struct inode___117 *);
	void (*free_inode)(struct inode___117 *);
	void (*dirty_inode)(struct inode___117 *, int);
	int (*write_inode)(struct inode___117 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___117 *);
	void (*evict_inode)(struct inode___117 *);
	void (*put_super)(struct super_block___117 *);
	int (*sync_fs)(struct super_block___117 *, int);
	int (*freeze_super)(struct super_block___117 *);
	int (*freeze_fs)(struct super_block___117 *);
	int (*thaw_super)(struct super_block___117 *);
	int (*unfreeze_fs)(struct super_block___117 *);
	int (*statfs)(struct dentry___117 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___117 *, int *, char *);
	void (*umount_begin)(struct super_block___117 *);
	int (*show_options)(struct seq_file___104 *, struct dentry___117 *);
	int (*show_devname)(struct seq_file___104 *, struct dentry___117 *);
	int (*show_path)(struct seq_file___104 *, struct dentry___117 *);
	int (*show_stats)(struct seq_file___104 *, struct dentry___117 *);
	ssize_t (*quota_read)(struct super_block___117 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___117 *, int, const char *, size_t, loff_t);
	struct dquot___117 ** (*get_dquots)(struct inode___117 *);
	long int (*nr_cached_objects)(struct super_block___117 *, struct shrink_control___45 *);
	long int (*free_cached_objects)(struct super_block___117 *, struct shrink_control___45 *);
	struct file___117 * (*real_loop)(struct file___117 *);
};

struct seq_operations___104;

struct seq_file___104 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___104 *op;
	int poll_event;
	const struct file___117 *file;
	void *private;
};

struct gnu_property {
	u32 pr_type;
	u32 pr_datasz;
};

struct kernfs_root___109;

struct kernfs_elem_dir___109 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___109 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___109;

struct kernfs_root___109 {
	struct kernfs_node___109 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___109 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___109 {
	struct kernfs_node___109 *target_kn;
};

struct kernfs_ops___109;

struct kernfs_elem_attr___109 {
	const struct kernfs_ops___109 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___109 *notify_next;
};

struct kernfs_node___109 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___109 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___109 dir;
		struct kernfs_elem_symlink___109 symlink;
		struct kernfs_elem_attr___109 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___109;

struct kernfs_ops___109 {
	int (*open)(struct kernfs_open_file___109 *);
	void (*release)(struct kernfs_open_file___109 *);
	int (*seq_show)(struct seq_file___104 *, void *);
	void * (*seq_start)(struct seq_file___104 *, loff_t *);
	void * (*seq_next)(struct seq_file___104 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___104 *, void *);
	ssize_t (*read)(struct kernfs_open_file___109 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___109 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___109 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___109 *, struct vm_area_struct___122 *);
};

struct kernfs_syscall_ops___109 {
	int (*show_options)(struct seq_file___104 *, struct kernfs_root___109 *);
	int (*mkdir)(struct kernfs_node___109 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___109 *);
	int (*rename)(struct kernfs_node___109 *, struct kernfs_node___109 *, const char *);
	int (*show_path)(struct seq_file___104 *, struct kernfs_node___109 *, struct kernfs_root___109 *);
};

struct kernfs_open_file___109 {
	struct kernfs_node___109 *kn;
	struct file___117 *file;
	struct seq_file___104 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___115 *vm_ops;
};

struct bin_attribute___109;

struct attribute_group___109 {
	const char *name;
	umode_t (*is_visible)(struct kobject___109 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___109 *, struct bin_attribute___109 *, int);
	struct attribute **attrs;
	struct bin_attribute___109 **bin_attrs;
};

struct bin_attribute___109 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___117 * (*f_mapping)();
	ssize_t (*read)(struct file___117 *, struct kobject___109 *, struct bin_attribute___109 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___117 *, struct kobject___109 *, struct bin_attribute___109 *, char *, loff_t, size_t);
	int (*mmap)(struct file___117 *, struct kobject___109 *, struct bin_attribute___109 *, struct vm_area_struct___122 *);
};

struct sysfs_ops___109 {
	ssize_t (*show)(struct kobject___109 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___109 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___109;

struct kset___109 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___109 kobj;
	const struct kset_uevent_ops___109 *uevent_ops;
};

struct kobj_type___109 {
	void (*release)(struct kobject___109 *);
	const struct sysfs_ops___109 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___109 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___109 *);
	const void * (*namespace)(struct kobject___109 *);
	void (*get_ownership)(struct kobject___109 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___109 {
	int (* const filter)(struct kset___109 *, struct kobject___109 *);
	const char * (* const name)(struct kset___109 *, struct kobject___109 *);
	int (* const uevent)(struct kset___109 *, struct kobject___109 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___106 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___106 *);
	int (*get)(char *, const struct kernel_param___106 *);
	void (*free)(void *);
};

struct kparam_array___106;

struct kernel_param___106 {
	const char *name;
	struct module___107 *mod;
	const struct kernel_param_ops___106 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___106 *arr;
	};
};

struct kparam_array___106 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___106 *ops;
	void *elem;
};

struct module_attribute___106 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___106 *, struct module_kobject___106 *, char *);
	ssize_t (*store)(struct module_attribute___106 *, struct module_kobject___106 *, const char *, size_t);
	void (*setup)(struct module___107 *, const char *);
	int (*test)(struct module___107 *);
	void (*free)(struct module___107 *);
};

struct dev_pagemap_ops___115 {
	void (*page_free)(struct page___122 *);
	void (*kill)(struct dev_pagemap___115 *);
	void (*cleanup)(struct dev_pagemap___115 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___115 *);
};

struct linux_binprm___17 {
	struct vm_area_struct___122 *vma;
	long unsigned int vma_pages;
	struct mm_struct___123 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___117 *executable;
	struct file___117 *interpreter;
	struct file___117 *file;
	struct cred___14 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct core_vma_metadata___3;

struct coredump_params___16 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___117 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata___3 *vma_meta;
};

struct core_vma_metadata___3 {
	long unsigned int start;
	long unsigned int end;
	long unsigned int flags;
	long unsigned int dump_size;
	long unsigned int pgoff;
	struct file___117 *file;
};

struct cgroup_namespace___87 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___87 *root_cset;
};

struct elf_prpsinfo {
	char pr_state;
	char pr_sname;
	char pr_zomb;
	char pr_nice;
	long unsigned int pr_flag;
	__kernel_uid_t pr_uid;
	__kernel_gid_t pr_gid;
	pid_t pr_pid;
	pid_t pr_ppid;
	pid_t pr_pgrp;
	pid_t pr_sid;
	char pr_fname[16];
	char pr_psargs[80];
};

struct seq_operations___104 {
	void * (*start)(struct seq_file___104 *, loff_t *);
	void (*stop)(struct seq_file___104 *, void *);
	void * (*next)(struct seq_file___104 *, void *, loff_t *);
	int (*show)(struct seq_file___104 *, void *);
};

struct cftype___87;

struct cgroup_subsys___87 {
	struct cgroup_subsys_state___87 * (*css_alloc)(struct cgroup_subsys_state___87 *);
	int (*css_online)(struct cgroup_subsys_state___87 *);
	void (*css_offline)(struct cgroup_subsys_state___87 *);
	void (*css_released)(struct cgroup_subsys_state___87 *);
	void (*css_free)(struct cgroup_subsys_state___87 *);
	void (*css_reset)(struct cgroup_subsys_state___87 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___87 *, int);
	int (*css_extra_stat_show)(struct seq_file___104 *, struct cgroup_subsys_state___87 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___124 *, struct css_set___87 *);
	void (*cancel_fork)(struct task_struct___124 *, struct css_set___87 *);
	void (*fork)(struct task_struct___124 *);
	void (*exit)(struct task_struct___124 *);
	void (*release)(struct task_struct___124 *);
	void (*bind)(struct cgroup_subsys_state___87 *);
	bool early_init;
	bool implicit_on_dfl;
	bool threaded;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___87 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___87 *dfl_cftypes;
	struct cftype___87 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___87 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___87 *updated_children;
	struct cgroup___87 *updated_next;
};

struct cgroup_root___87 {
	struct kernfs_root___109 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___87 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___87 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___87 *ss;
	struct list_head node;
	struct kernfs_ops___109 *kf_ops;
	int (*open)(struct kernfs_open_file___109 *);
	void (*release)(struct kernfs_open_file___109 *);
	u64 (*read_u64)(struct cgroup_subsys_state___87 *, struct cftype___87 *);
	s64 (*read_s64)(struct cgroup_subsys_state___87 *, struct cftype___87 *);
	int (*seq_show)(struct seq_file___104 *, void *);
	void * (*seq_start)(struct seq_file___104 *, loff_t *);
	void * (*seq_next)(struct seq_file___104 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___104 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___87 *, struct cftype___87 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___87 *, struct cftype___87 *, s64);
	ssize_t (*write)(struct kernfs_open_file___109 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___109 *, struct poll_table_struct___5 *);
};

struct memelfnote {
	const char *name;
	int type;
	unsigned int datasz;
	void *data;
};

struct user_regset___4;

typedef int user_regset_active_fn___4(struct task_struct___124 *, const struct user_regset___4 *);

typedef int user_regset_get2_fn___4(struct task_struct___124 *, const struct user_regset___4 *, struct membuf);

typedef int user_regset_set_fn___4(struct task_struct___124 *, const struct user_regset___4 *, unsigned int, unsigned int, const void *, const void *);

typedef int user_regset_writeback_fn___4(struct task_struct___124 *, const struct user_regset___4 *, int);

struct user_regset___4 {
	user_regset_get2_fn___4 *regset_get;
	user_regset_set_fn___4 *set;
	user_regset_active_fn___4 *active;
	user_regset_writeback_fn___4 *writeback;
	unsigned int n;
	unsigned int size;
	unsigned int align;
	unsigned int bias;
	unsigned int core_note_type;
};

struct user_regset_view___4 {
	const char *name;
	const struct user_regset___4 *regsets;
	unsigned int n;
	u32 e_flags;
	u16 e_machine;
	u8 ei_osabi;
};

struct elf_thread_core_info {
	struct elf_thread_core_info *next;
	struct task_struct___124 *task;
	struct elf_prstatus prstatus;
	struct memelfnote notes[0];
};

struct elf_note_info {
	struct elf_thread_core_info *thread;
	struct memelfnote psinfo;
	struct memelfnote signote;
	struct memelfnote auxv;
	struct memelfnote files;
	siginfo_t csigdata;
	size_t size;
	int thread_notes;
};

struct elf32_phdr {
	Elf32_Word p_type;
	Elf32_Off p_offset;
	Elf32_Addr p_vaddr;
	Elf32_Addr p_paddr;
	Elf32_Word p_filesz;
	Elf32_Word p_memsz;
	Elf32_Word p_flags;
	Elf32_Word p_align;
};

struct elf32_shdr {
	Elf32_Word sh_name;
	Elf32_Word sh_type;
	Elf32_Word sh_flags;
	Elf32_Addr sh_addr;
	Elf32_Off sh_offset;
	Elf32_Word sh_size;
	Elf32_Word sh_link;
	Elf32_Word sh_info;
	Elf32_Word sh_addralign;
	Elf32_Word sh_entsize;
};

typedef u16 __compat_uid_t;

typedef u16 __compat_gid_t;

typedef unsigned int compat_elf_greg_t;

typedef compat_elf_greg_t compat_elf_gregset_t[18];

struct compat_elf_siginfo {
	compat_int_t si_signo;
	compat_int_t si_code;
	compat_int_t si_errno;
};

struct compat_elf_prstatus_common {
	struct compat_elf_siginfo pr_info;
	short int pr_cursig;
	compat_ulong_t pr_sigpend;
	compat_ulong_t pr_sighold;
	compat_pid_t pr_pid;
	compat_pid_t pr_ppid;
	compat_pid_t pr_pgrp;
	compat_pid_t pr_sid;
	struct old_timeval32 pr_utime;
	struct old_timeval32 pr_stime;
	struct old_timeval32 pr_cutime;
	struct old_timeval32 pr_cstime;
};

struct compat_elf_prpsinfo {
	char pr_state;
	char pr_sname;
	char pr_zomb;
	char pr_nice;
	compat_ulong_t pr_flag;
	__compat_uid_t pr_uid;
	__compat_gid_t pr_gid;
	compat_pid_t pr_pid;
	compat_pid_t pr_ppid;
	compat_pid_t pr_pgrp;
	compat_pid_t pr_sid;
	char pr_fname[16];
	char pr_psargs[80];
};

struct compat_elf_prstatus {
	struct compat_elf_prstatus_common common;
	compat_elf_gregset_t pr_reg;
	compat_int_t pr_fpvalid;
};

struct elf_thread_core_info___2 {
	struct elf_thread_core_info___2 *next;
	struct task_struct___124 *task;
	struct compat_elf_prstatus prstatus;
	struct memelfnote notes[0];
};

struct elf_note_info___2 {
	struct elf_thread_core_info___2 *thread;
	struct memelfnote psinfo;
	struct memelfnote signote;
	struct memelfnote auxv;
	struct memelfnote files;
	compat_siginfo_t csigdata;
	size_t size;
	int thread_notes;
};

struct mb_cache_entry {
	struct list_head e_list;
	struct hlist_bl_node e_hash_list;
	atomic_t e_refcnt;
	u32 e_key;
	u32 e_referenced;
	u32 e_reusable;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 e_value;
};

struct mb_cache {
	struct hlist_bl_head *c_hash;
	int c_bucket_bits;
	long unsigned int c_max_entries;
	spinlock_t c_list_lock;
	struct list_head c_list;
	long unsigned int c_entry_count;
	struct shrinker___45 c_shrink;
	struct work_struct c_shrink_work;
};

struct posix_acl_xattr_entry {
	__le16 e_tag;
	__le16 e_perm;
	__le32 e_id;
};

struct posix_acl_xattr_header {
	__le32 a_version;
};

struct rpc_timer {
	struct list_head list;
	long unsigned int expires;
	struct delayed_work dwork;
};

struct rpc_wait_queue {
	spinlock_t lock;
	struct list_head tasks[4];
	unsigned char maxpriority;
	unsigned char priority;
	unsigned char nr;
	short unsigned int qlen;
	struct rpc_timer timer_list;
	const char *name;
};

struct nfs_seqid_counter {
	ktime_t create_time;
	int owner_id;
	int flags;
	u32 counter;
	spinlock_t lock;
	struct list_head list;
	struct rpc_wait_queue wait;
};

struct nfs4_stateid_struct {
	union {
		char data[16];
		struct {
			__be32 seqid;
			char other[12];
		};
	};
	enum {
		NFS4_INVALID_STATEID_TYPE = 0,
		NFS4_SPECIAL_STATEID_TYPE = 1,
		NFS4_OPEN_STATEID_TYPE = 2,
		NFS4_LOCK_STATEID_TYPE = 3,
		NFS4_DELEGATION_STATEID_TYPE = 4,
		NFS4_LAYOUT_STATEID_TYPE = 5,
		NFS4_PNFS_DS_STATEID_TYPE = 6,
		NFS4_REVOKED_STATEID_TYPE = 7,
	} type;
};

typedef struct nfs4_stateid_struct nfs4_stateid;

struct nfs4_state;

struct nfs4_lock_state {
	struct list_head ls_locks;
	struct nfs4_state *ls_state;
	long unsigned int ls_flags;
	struct nfs_seqid_counter ls_seqid;
	nfs4_stateid ls_stateid;
	refcount_t ls_count;
	fl_owner_t ls_owner;
};

struct xdr_netobj {
	unsigned int len;
	u8 *data;
};

struct xdr_buf {
	struct kvec head[1];
	struct kvec tail[1];
	struct bio_vec___2 *bvec;
	struct page___4 **pages;
	unsigned int page_base;
	unsigned int page_len;
	unsigned int flags;
	unsigned int buflen;
	unsigned int len;
};

struct rpc_rqst;

struct xdr_stream {
	__be32 *p;
	struct xdr_buf *buf;
	__be32 *end;
	struct kvec *iov;
	struct kvec scratch;
	struct page___4 **page_ptr;
	unsigned int nwords;
	struct rpc_rqst *rqst;
};

struct rpc_xprt;

struct rpc_task;

struct rpc_cred;

struct rpc_rqst {
	struct rpc_xprt *rq_xprt;
	struct xdr_buf rq_snd_buf;
	struct xdr_buf rq_rcv_buf;
	struct rpc_task *rq_task;
	struct rpc_cred *rq_cred;
	__be32 rq_xid;
	int rq_cong;
	u32 rq_seqno;
	int rq_enc_pages_num;
	struct page___4 **rq_enc_pages;
	void (*rq_release_snd_buf)(struct rpc_rqst *);
	union {
		struct list_head rq_list;
		struct rb_node rq_recv;
	};
	struct list_head rq_xmit;
	struct list_head rq_xmit2;
	void *rq_buffer;
	size_t rq_callsize;
	void *rq_rbuffer;
	size_t rq_rcvsize;
	size_t rq_xmit_bytes_sent;
	size_t rq_reply_bytes_recvd;
	struct xdr_buf rq_private_buf;
	long unsigned int rq_majortimeo;
	long unsigned int rq_minortimeo;
	long unsigned int rq_timeout;
	ktime_t rq_rtt;
	unsigned int rq_retries;
	unsigned int rq_connect_cookie;
	atomic_t rq_pin;
	u32 rq_bytes_sent;
	ktime_t rq_xtime;
	int rq_ntrans;
	struct list_head rq_bc_list;
	long unsigned int rq_bc_pa_state;
	struct list_head rq_bc_pa_list;
};

typedef void (*kxdreproc_t)(struct rpc_rqst *, struct xdr_stream *, const void *);

typedef int (*kxdrdproc_t)(struct rpc_rqst *, struct xdr_stream *, void *);

struct rpc_procinfo;

struct rpc_message {
	const struct rpc_procinfo *rpc_proc;
	void *rpc_argp;
	void *rpc_resp;
	const struct cred *rpc_cred;
};

struct rpc_procinfo {
	u32 p_proc;
	kxdreproc_t p_encode;
	kxdrdproc_t p_decode;
	unsigned int p_arglen;
	unsigned int p_replen;
	unsigned int p_timer;
	u32 p_statidx;
	const char *p_name;
};

struct rpc_wait {
	struct list_head list;
	struct list_head links;
	struct list_head timer_list;
};

struct rpc_call_ops;

struct rpc_clnt;

struct rpc_task {
	atomic_t tk_count;
	int tk_status;
	struct list_head tk_task;
	void (*tk_callback)(struct rpc_task *);
	void (*tk_action)(struct rpc_task *);
	long unsigned int tk_timeout;
	long unsigned int tk_runstate;
	struct rpc_wait_queue *tk_waitqueue;
	union {
		struct work_struct tk_work;
		struct rpc_wait tk_wait;
	} u;
	int tk_rpc_status;
	struct rpc_message tk_msg;
	void *tk_calldata;
	const struct rpc_call_ops *tk_ops;
	struct rpc_clnt *tk_client;
	struct rpc_xprt *tk_xprt;
	struct rpc_cred *tk_op_cred;
	struct rpc_rqst *tk_rqstp;
	struct workqueue_struct *tk_workqueue;
	ktime_t tk_start;
	pid_t tk_owner;
	short unsigned int tk_flags;
	short unsigned int tk_timeouts;
	short unsigned int tk_pid;
	unsigned char tk_priority: 2;
	unsigned char tk_garb_retry: 2;
	unsigned char tk_cred_retry: 2;
	unsigned char tk_rebind_retry: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rpc_call_ops {
	void (*rpc_call_prepare)(struct rpc_task *, void *);
	void (*rpc_call_done)(struct rpc_task *, void *);
	void (*rpc_count_stats)(struct rpc_task *, void *);
	void (*rpc_release)(void *);
};

struct rpc_iostats;

struct rpc_pipe_dir_head {
	struct list_head pdh_entries;
	struct dentry___3 *pdh_dentry;
};

struct rpc_rtt {
	long unsigned int timeo;
	long unsigned int srtt[5];
	long unsigned int sdrtt[5];
	int ntimeouts[5];
};

struct rpc_timeout {
	long unsigned int to_initval;
	long unsigned int to_maxval;
	long unsigned int to_increment;
	unsigned int to_retries;
	unsigned char to_exponential;
};

struct rpc_sysfs_client;

struct rpc_xprt_switch;

struct rpc_xprt_iter_ops;

struct rpc_xprt_iter {
	struct rpc_xprt_switch *xpi_xpswitch;
	struct rpc_xprt *xpi_cursor;
	const struct rpc_xprt_iter_ops *xpi_ops;
};

struct rpc_auth;

struct rpc_stat;

struct rpc_program;

struct rpc_clnt {
	refcount_t cl_count;
	unsigned int cl_clid;
	struct list_head cl_clients;
	struct list_head cl_tasks;
	spinlock_t cl_lock;
	struct rpc_xprt *cl_xprt;
	const struct rpc_procinfo *cl_procinfo;
	u32 cl_prog;
	u32 cl_vers;
	u32 cl_maxproc;
	struct rpc_auth *cl_auth;
	struct rpc_stat *cl_stats;
	struct rpc_iostats *cl_metrics;
	unsigned int cl_softrtry: 1;
	unsigned int cl_softerr: 1;
	unsigned int cl_discrtry: 1;
	unsigned int cl_noretranstimeo: 1;
	unsigned int cl_autobind: 1;
	unsigned int cl_chatty: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct rpc_rtt *cl_rtt;
	const struct rpc_timeout *cl_timeout;
	atomic_t cl_swapper;
	int cl_nodelen;
	char cl_nodename[65];
	struct rpc_pipe_dir_head cl_pipedir_objects;
	struct rpc_clnt *cl_parent;
	struct rpc_rtt cl_rtt_default;
	struct rpc_timeout cl_timeout_default;
	const struct rpc_program *cl_program;
	const char *cl_principal;
	struct dentry___3 *cl_debugfs;
	struct rpc_sysfs_client *cl_sysfs;
	union {
		struct rpc_xprt_iter cl_xpi;
		struct work_struct cl_work;
	};
	const struct cred *cl_cred;
	unsigned int cl_max_connect;
};

struct svc_xprt;

struct rpc_sysfs_xprt;

struct rpc_xprt_ops;

struct svc_serv;

struct xprt_class;

struct rpc_xprt {
	struct kref kref;
	const struct rpc_xprt_ops *ops;
	unsigned int id;
	const struct rpc_timeout *timeout;
	struct __kernel_sockaddr_storage addr;
	size_t addrlen;
	int prot;
	long unsigned int cong;
	long unsigned int cwnd;
	size_t max_payload;
	struct rpc_wait_queue binding;
	struct rpc_wait_queue sending;
	struct rpc_wait_queue pending;
	struct rpc_wait_queue backlog;
	struct list_head free;
	unsigned int max_reqs;
	unsigned int min_reqs;
	unsigned int num_reqs;
	long unsigned int state;
	unsigned char resvport: 1;
	unsigned char reuseport: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t swapper;
	unsigned int bind_index;
	struct list_head xprt_switch;
	long unsigned int bind_timeout;
	long unsigned int reestablish_timeout;
	unsigned int connect_cookie;
	struct work_struct task_cleanup;
	struct timer_list timer;
	long unsigned int last_used;
	long unsigned int idle_timeout;
	long unsigned int connect_timeout;
	long unsigned int max_reconnect_timeout;
	atomic_long_t queuelen;
	spinlock_t transport_lock;
	spinlock_t reserve_lock;
	spinlock_t queue_lock;
	u32 xid;
	struct rpc_task *snd_task;
	struct list_head xmit_queue;
	atomic_long_t xmit_queuelen;
	struct svc_xprt *bc_xprt;
	struct svc_serv *bc_serv;
	unsigned int bc_alloc_max;
	unsigned int bc_alloc_count;
	atomic_t bc_slot_count;
	spinlock_t bc_pa_lock;
	struct list_head bc_pa_list;
	struct rb_root recv_queue;
	struct {
		long unsigned int bind_count;
		long unsigned int connect_count;
		long unsigned int connect_start;
		long unsigned int connect_time;
		long unsigned int sends;
		long unsigned int recvs;
		long unsigned int bad_xids;
		long unsigned int max_slots;
		long long unsigned int req_u;
		long long unsigned int bklog_u;
		long long unsigned int sending_u;
		long long unsigned int pending_u;
	} stat;
	struct net___2 *xprt_net;
	const char *servername;
	const char *address_strings[6];
	struct dentry___3 *debugfs;
	struct callback_head rcu;
	const struct xprt_class *xprt_class;
	struct rpc_sysfs_xprt *xprt_sysfs;
	bool main;
};

struct rpc_credops;

struct rpc_cred {
	struct hlist_node cr_hash;
	struct list_head cr_lru;
	struct callback_head cr_rcu;
	struct rpc_auth *cr_auth;
	const struct rpc_credops *cr_ops;
	long unsigned int cr_expire;
	long unsigned int cr_flags;
	refcount_t cr_count;
	const struct cred *cr_cred;
};

typedef u32 rpc_authflavor_t;

struct auth_cred {
	const struct cred *cred;
	const char *principal;
};

struct rpc_cred_cache;

struct rpc_authops;

struct rpc_auth {
	unsigned int au_cslack;
	unsigned int au_rslack;
	unsigned int au_verfsize;
	unsigned int au_ralign;
	long unsigned int au_flags;
	const struct rpc_authops *au_ops;
	rpc_authflavor_t au_flavor;
	refcount_t au_count;
	struct rpc_cred_cache *au_credcache;
};

struct rpc_credops {
	const char *cr_name;
	int (*cr_init)(struct rpc_auth *, struct rpc_cred *);
	void (*crdestroy)(struct rpc_cred *);
	int (*crmatch)(struct auth_cred *, struct rpc_cred *, int);
	int (*crmarshal)(struct rpc_task *, struct xdr_stream *);
	int (*crrefresh)(struct rpc_task *);
	int (*crvalidate)(struct rpc_task *, struct xdr_stream *);
	int (*crwrap_req)(struct rpc_task *, struct xdr_stream *);
	int (*crunwrap_resp)(struct rpc_task *, struct xdr_stream *);
	int (*crkey_timeout)(struct rpc_cred *);
	char * (*crstringify_acceptor)(struct rpc_cred *);
	bool (*crneed_reencode)(struct rpc_task *);
};

struct rpc_auth_create_args;

struct rpcsec_gss_info;

struct rpc_authops {
	struct module___5 *owner;
	rpc_authflavor_t au_flavor;
	char *au_name;
	struct rpc_auth * (*create)(const struct rpc_auth_create_args *, struct rpc_clnt *);
	void (*destroy)(struct rpc_auth *);
	int (*hash_cred)(struct auth_cred *, unsigned int);
	struct rpc_cred * (*lookup_cred)(struct rpc_auth *, struct auth_cred *, int);
	struct rpc_cred * (*crcreate)(struct rpc_auth *, struct auth_cred *, int, gfp_t);
	rpc_authflavor_t (*info2flavor)(struct rpcsec_gss_info *);
	int (*flavor2info)(rpc_authflavor_t, struct rpcsec_gss_info *);
	int (*key_timeout)(struct rpc_auth *, struct rpc_cred *);
};

struct rpc_auth_create_args {
	rpc_authflavor_t pseudoflavor;
	const char *target_name;
};

struct rpcsec_gss_oid {
	unsigned int len;
	u8 data[32];
};

struct rpcsec_gss_info {
	struct rpcsec_gss_oid oid;
	u32 qop;
	u32 service;
};

struct rpc_xprt_ops {
	void (*set_buffer_size)(struct rpc_xprt *, size_t, size_t);
	int (*reserve_xprt)(struct rpc_xprt *, struct rpc_task *);
	void (*release_xprt)(struct rpc_xprt *, struct rpc_task *);
	void (*alloc_slot)(struct rpc_xprt *, struct rpc_task *);
	void (*free_slot)(struct rpc_xprt *, struct rpc_rqst *);
	void (*rpcbind)(struct rpc_task *);
	void (*set_port)(struct rpc_xprt *, short unsigned int);
	void (*connect)(struct rpc_xprt *, struct rpc_task *);
	int (*buf_alloc)(struct rpc_task *);
	void (*buf_free)(struct rpc_task *);
	void (*prepare_request)(struct rpc_rqst *);
	int (*send_request)(struct rpc_rqst *);
	void (*wait_for_reply_request)(struct rpc_task *);
	void (*timer)(struct rpc_xprt *, struct rpc_task *);
	void (*release_request)(struct rpc_task *);
	void (*close)(struct rpc_xprt *);
	void (*destroy)(struct rpc_xprt *);
	void (*set_connect_timeout)(struct rpc_xprt *, long unsigned int, long unsigned int);
	void (*print_stats)(struct rpc_xprt *, struct seq_file___4 *);
	int (*enable_swap)(struct rpc_xprt *);
	void (*disable_swap)(struct rpc_xprt *);
	void (*inject_disconnect)(struct rpc_xprt *);
	int (*bc_setup)(struct rpc_xprt *, unsigned int);
	size_t (*bc_maxpayload)(struct rpc_xprt *);
	unsigned int (*bc_num_slots)(struct rpc_xprt *);
	void (*bc_free_rqst)(struct rpc_rqst *);
	void (*bc_destroy)(struct rpc_xprt *, unsigned int);
};

struct svc_program;

struct svc_stat;

struct svc_pool;

struct svc_serv_ops;

struct svc_serv {
	struct svc_program *sv_program;
	struct svc_stat *sv_stats;
	spinlock_t sv_lock;
	unsigned int sv_nrthreads;
	unsigned int sv_maxconn;
	unsigned int sv_max_payload;
	unsigned int sv_max_mesg;
	unsigned int sv_xdrsize;
	struct list_head sv_permsocks;
	struct list_head sv_tempsocks;
	int sv_tmpcnt;
	struct timer_list sv_temptimer;
	char *sv_name;
	unsigned int sv_nrpools;
	struct svc_pool *sv_pools;
	const struct svc_serv_ops *sv_ops;
	struct list_head sv_cb_list;
	spinlock_t sv_cb_lock;
	wait_queue_head_t sv_cb_waitq;
	bool sv_bc_enabled;
};

struct xprt_create;

struct xprt_class {
	struct list_head list;
	int ident;
	struct rpc_xprt * (*setup)(struct xprt_create *);
	struct module___5 *owner;
	char name[32];
	const char *netid[0];
};

struct xprt_create {
	int ident;
	struct net___2 *net;
	struct sockaddr *srcaddr;
	struct sockaddr *dstaddr;
	size_t addrlen;
	const char *servername;
	struct svc_xprt *bc_xprt;
	struct rpc_xprt_switch *bc_xps;
	unsigned int flags;
};

struct rpc_sysfs_xprt_switch;

struct rpc_xprt_switch {
	spinlock_t xps_lock;
	struct kref xps_kref;
	unsigned int xps_id;
	unsigned int xps_nxprts;
	unsigned int xps_nactive;
	unsigned int xps_nunique_destaddr_xprts;
	atomic_long_t xps_queuelen;
	struct list_head xps_xprt_list;
	struct net___2 *xps_net;
	const struct rpc_xprt_iter_ops *xps_iter_ops;
	struct rpc_sysfs_xprt_switch *xps_sysfs;
	struct callback_head xps_rcu;
};

struct rpc_stat {
	const struct rpc_program *program;
	unsigned int netcnt;
	unsigned int netudpcnt;
	unsigned int nettcpcnt;
	unsigned int nettcpconn;
	unsigned int netreconn;
	unsigned int rpccnt;
	unsigned int rpcretrans;
	unsigned int rpcauthrefresh;
	unsigned int rpcgarbage;
};

struct rpc_version;

struct rpc_program {
	const char *name;
	u32 number;
	unsigned int nrvers;
	const struct rpc_version **version;
	struct rpc_stat *stats;
	const char *pipe_dir_name;
};

struct svc_stat {
	struct svc_program *program;
	unsigned int netcnt;
	unsigned int netudpcnt;
	unsigned int nettcpcnt;
	unsigned int nettcpconn;
	unsigned int rpccnt;
	unsigned int rpcbadfmt;
	unsigned int rpcbadauth;
	unsigned int rpcbadclnt;
};

struct svc_version;

struct svc_rqst;

struct svc_process_info;

struct svc_program {
	struct svc_program *pg_next;
	u32 pg_prog;
	unsigned int pg_lovers;
	unsigned int pg_hivers;
	unsigned int pg_nvers;
	const struct svc_version **pg_vers;
	char *pg_name;
	char *pg_class;
	struct svc_stat *pg_stats;
	int (*pg_authenticate)(struct svc_rqst *);
	__be32 (*pg_init_request)(struct svc_rqst *, const struct svc_program *, struct svc_process_info *);
	int (*pg_rpcbind_set)(struct net___2 *, const struct svc_program *, u32, int, short unsigned int, short unsigned int);
};

struct rpc_xprt_iter_ops {
	void (*xpi_rewind)(struct rpc_xprt_iter *);
	struct rpc_xprt * (*xpi_xprt)(struct rpc_xprt_iter *);
	struct rpc_xprt * (*xpi_next)(struct rpc_xprt_iter *);
};

struct rpc_version {
	u32 number;
	unsigned int nrprocs;
	const struct rpc_procinfo *procs;
	unsigned int *counts;
};

struct nfs_fh {
	short unsigned int size;
	unsigned char data[128];
};

enum nfs3_stable_how {
	NFS_UNSTABLE = 0,
	NFS_DATA_SYNC = 1,
	NFS_FILE_SYNC = 2,
	NFS_INVALID_STABLE_HOW = 4294967295,
};

struct nfs4_label {
	uint32_t lfs;
	uint32_t pi;
	u32 len;
	char *label;
};

typedef struct {
	char data[8];
} nfs4_verifier;

enum nfs4_change_attr_type {
	NFS4_CHANGE_TYPE_IS_MONOTONIC_INCR = 0,
	NFS4_CHANGE_TYPE_IS_VERSION_COUNTER = 1,
	NFS4_CHANGE_TYPE_IS_VERSION_COUNTER_NOPNFS = 2,
	NFS4_CHANGE_TYPE_IS_TIME_METADATA = 3,
	NFS4_CHANGE_TYPE_IS_UNDEFINED = 4,
};

struct gss_api_mech;

struct gss_ctx {
	struct gss_api_mech *mech_type;
	void *internal_ctx_id;
	unsigned int slack;
	unsigned int align;
};

struct gss_api_ops;

struct pf_desc;

struct gss_api_mech {
	struct list_head gm_list;
	struct module___5 *gm_owner;
	struct rpcsec_gss_oid gm_oid;
	char *gm_name;
	const struct gss_api_ops *gm_ops;
	int gm_pf_num;
	struct pf_desc *gm_pfs;
	const char *gm_upcall_enctypes;
};

struct auth_domain;

struct pf_desc {
	u32 pseudoflavor;
	u32 qop;
	u32 service;
	char *name;
	char *auth_domain_name;
	struct auth_domain *domain;
	bool datatouch;
};

struct auth_ops;

struct auth_domain {
	struct kref ref;
	struct hlist_node hash;
	char *name;
	struct auth_ops *flavour;
	struct callback_head callback_head;
};

struct gss_api_ops {
	int (*gss_import_sec_context)(const void *, size_t, struct gss_ctx *, time64_t *, gfp_t);
	u32 (*gss_get_mic)(struct gss_ctx *, struct xdr_buf *, struct xdr_netobj *);
	u32 (*gss_verify_mic)(struct gss_ctx *, struct xdr_buf *, struct xdr_netobj *);
	u32 (*gss_wrap)(struct gss_ctx *, int, struct xdr_buf *, struct page___4 **);
	u32 (*gss_unwrap)(struct gss_ctx *, int, int, struct xdr_buf *);
	void (*gss_delete_sec_context)(void *);
};

struct nfs4_string {
	unsigned int len;
	char *data;
};

struct nfs_fsid {
	uint64_t major;
	uint64_t minor;
};

struct nfs4_threshold {
	__u32 bm;
	__u32 l_type;
	__u64 rd_sz;
	__u64 wr_sz;
	__u64 rd_io_sz;
	__u64 wr_io_sz;
};

struct nfs_fattr {
	unsigned int valid;
	umode_t mode;
	__u32 nlink;
	kuid_t uid;
	kgid_t gid;
	dev_t rdev;
	__u64 size;
	union {
		struct {
			__u32 blocksize;
			__u32 blocks;
		} nfs2;
		struct {
			__u64 used;
		} nfs3;
	} du;
	struct nfs_fsid fsid;
	__u64 fileid;
	__u64 mounted_on_fileid;
	struct timespec64 atime;
	struct timespec64 mtime;
	struct timespec64 ctime;
	__u64 change_attr;
	__u64 pre_change_attr;
	__u64 pre_size;
	struct timespec64 pre_mtime;
	struct timespec64 pre_ctime;
	long unsigned int time_start;
	long unsigned int gencount;
	struct nfs4_string *owner_name;
	struct nfs4_string *group_name;
	struct nfs4_threshold *mdsthreshold;
	struct nfs4_label *label;
};

struct nfs_fsinfo {
	struct nfs_fattr *fattr;
	__u32 rtmax;
	__u32 rtpref;
	__u32 rtmult;
	__u32 wtmax;
	__u32 wtpref;
	__u32 wtmult;
	__u32 dtpref;
	__u64 maxfilesize;
	struct timespec64 time_delta;
	__u32 lease_time;
	__u32 nlayouttypes;
	__u32 layouttype[8];
	__u32 blksize;
	__u32 clone_blksize;
	enum nfs4_change_attr_type change_attr_type;
	__u32 xattr_support;
};

struct nfs_fsstat {
	struct nfs_fattr *fattr;
	__u64 tbytes;
	__u64 fbytes;
	__u64 abytes;
	__u64 tfiles;
	__u64 ffiles;
	__u64 afiles;
};

struct nfs_pathconf {
	struct nfs_fattr *fattr;
	__u32 max_link;
	__u32 max_namelen;
};

struct nfs4_change_info {
	u32 atomic;
	u64 before;
	u64 after;
};

struct nfs4_slot;

struct nfs4_sequence_args {
	struct nfs4_slot *sa_slot;
	u8 sa_cache_this;
	u8 sa_privileged;
	long: 56;
	long: 64;
};

struct nfs4_sequence_res {
	struct nfs4_slot *sr_slot;
	long unsigned int sr_timestamp;
	int sr_status;
	u32 sr_status_flags;
	u32 sr_highest_slotid;
	u32 sr_target_highest_slotid;
};

struct nfs_open_context;

struct nfs_lock_context {
	refcount_t count;
	struct list_head list;
	struct nfs_open_context *open_context;
	fl_owner_t lockowner;
	atomic_t io_count;
	struct callback_head callback_head;
};

struct nfs_open_context {
	struct nfs_lock_context lock_context;
	fl_owner_t flock_owner;
	struct dentry___3 *dentry;
	const struct cred *cred;
	struct rpc_cred *ll_cred;
	struct nfs4_state *state;
	fmode_t mode;
	long unsigned int flags;
	int error;
	struct list_head list;
	struct nfs4_threshold *mdsthreshold;
	struct callback_head callback_head;
};

struct nlm_host;

struct nfs_iostats;

struct nfs_auth_info {
	unsigned int flavor_len;
	rpc_authflavor_t flavors[12];
};

struct nfs_fscache_key;

struct fscache_cookie;

struct pnfs_layoutdriver_type;

struct nfs_client;

struct nfs_server {
	struct nfs_client *nfs_client;
	struct list_head client_link;
	struct list_head master_link;
	struct rpc_clnt *client;
	struct rpc_clnt *client_acl;
	struct nlm_host *nlm_host;
	struct nfs_iostats *io_stats;
	atomic_long_t writeback;
	unsigned int flags;
	unsigned int fattr_valid;
	unsigned int caps;
	unsigned int rsize;
	unsigned int rpages;
	unsigned int wsize;
	unsigned int wpages;
	unsigned int wtmult;
	unsigned int dtsize;
	short unsigned int port;
	unsigned int bsize;
	unsigned int gxasize;
	unsigned int sxasize;
	unsigned int lxasize;
	unsigned int acregmin;
	unsigned int acregmax;
	unsigned int acdirmin;
	unsigned int acdirmax;
	unsigned int namelen;
	unsigned int options;
	unsigned int clone_blksize;
	enum nfs4_change_attr_type change_attr_type;
	struct nfs_fsid fsid;
	__u64 maxfilesize;
	struct timespec64 time_delta;
	long unsigned int mount_time;
	struct super_block___3 *super;
	dev_t s_dev;
	struct nfs_auth_info auth_info;
	struct nfs_fscache_key *fscache_key;
	struct fscache_cookie *fscache;
	u32 pnfs_blksize;
	u32 attr_bitmask[3];
	u32 attr_bitmask_nl[3];
	u32 exclcreat_bitmask[3];
	u32 cache_consistency_bitmask[3];
	u32 acl_bitmask;
	u32 fh_expire_type;
	struct pnfs_layoutdriver_type *pnfs_curr_ld;
	struct rpc_wait_queue roc_rpcwaitq;
	void *pnfs_ld_data;
	struct rb_root state_owners;
	struct ida openowner_id;
	struct ida lockowner_id;
	struct list_head state_owners_lru;
	struct list_head layouts;
	struct list_head delegations;
	struct list_head ss_copies;
	long unsigned int mig_gen;
	long unsigned int mig_status;
	void (*destroy)(struct nfs_server *);
	atomic_t active;
	struct __kernel_sockaddr_storage mountd_address;
	size_t mountd_addrlen;
	u32 mountd_version;
	short unsigned int mountd_port;
	short unsigned int mountd_protocol;
	struct rpc_wait_queue uoc_rpcwaitq;
	unsigned int read_hdrsize;
	const struct cred *cred;
	bool has_sec_mnt_opts;
};

struct nfs_subversion;

struct idmap;

struct nfs4_slot_table;

struct nfs4_session;

struct nfs_rpc_ops;

struct nfs4_minor_version_ops;

struct nfs41_server_owner;

struct nfs41_server_scope;

struct nfs41_impl_id;

struct nfs_client {
	refcount_t cl_count;
	atomic_t cl_mds_count;
	int cl_cons_state;
	long unsigned int cl_res_state;
	long unsigned int cl_flags;
	struct __kernel_sockaddr_storage cl_addr;
	size_t cl_addrlen;
	char *cl_hostname;
	char *cl_acceptor;
	struct list_head cl_share_link;
	struct list_head cl_superblocks;
	struct rpc_clnt *cl_rpcclient;
	const struct nfs_rpc_ops *rpc_ops;
	int cl_proto;
	struct nfs_subversion *cl_nfs_mod;
	u32 cl_minorversion;
	unsigned int cl_nconnect;
	unsigned int cl_max_connect;
	const char *cl_principal;
	struct list_head cl_ds_clients;
	u64 cl_clientid;
	nfs4_verifier cl_confirm;
	long unsigned int cl_state;
	spinlock_t cl_lock;
	long unsigned int cl_lease_time;
	long unsigned int cl_last_renewal;
	struct delayed_work cl_renewd;
	struct rpc_wait_queue cl_rpcwaitq;
	struct idmap *cl_idmap;
	const char *cl_owner_id;
	u32 cl_cb_ident;
	const struct nfs4_minor_version_ops *cl_mvops;
	long unsigned int cl_mig_gen;
	struct nfs4_slot_table *cl_slot_tbl;
	u32 cl_seqid;
	u32 cl_exchange_flags;
	struct nfs4_session *cl_session;
	bool cl_preserve_clid;
	struct nfs41_server_owner *cl_serverowner;
	struct nfs41_server_scope *cl_serverscope;
	struct nfs41_impl_id *cl_implid;
	long unsigned int cl_sp4_flags;
	wait_queue_head_t cl_lock_waitq;
	char cl_ipaddr[48];
	struct fscache_cookie *fscache;
	struct net___2 *cl_net;
	struct list_head pending_cb_stateids;
};

struct pnfs_layout_segment;

struct nfs_seqid {
	struct nfs_seqid_counter *sequence;
	struct list_head list;
	struct rpc_task *task;
};

struct nfs_write_verifier {
	char data[8];
};

struct nfs_writeverf {
	struct nfs_write_verifier verifier;
	enum nfs3_stable_how committed;
};

struct nfs_pgio_args {
	struct nfs4_sequence_args seq_args;
	struct nfs_fh *fh;
	struct nfs_open_context *context;
	struct nfs_lock_context *lock_context;
	nfs4_stateid stateid;
	__u64 offset;
	__u32 count;
	unsigned int pgbase;
	struct page___4 **pages;
	union {
		unsigned int replen;
		struct {
			const u32 *bitmask;
			u32 bitmask_store[3];
			enum nfs3_stable_how stable;
		};
	};
};

struct nfs_pgio_res {
	struct nfs4_sequence_res seq_res;
	struct nfs_fattr *fattr;
	__u64 count;
	__u32 op_status;
	union {
		struct {
			unsigned int replen;
			int eof;
		};
		struct {
			struct nfs_writeverf *verf;
			const struct nfs_server *server;
		};
	};
};

struct nfs_commitargs {
	struct nfs4_sequence_args seq_args;
	struct nfs_fh *fh;
	__u64 offset;
	__u32 count;
	const u32 *bitmask;
};

struct nfs_commitres {
	struct nfs4_sequence_res seq_res;
	__u32 op_status;
	struct nfs_fattr *fattr;
	struct nfs_writeverf *verf;
	const struct nfs_server *server;
};

struct nfs_removeargs {
	struct nfs4_sequence_args seq_args;
	const struct nfs_fh *fh;
	struct qstr name;
};

struct nfs_removeres {
	struct nfs4_sequence_res seq_res;
	struct nfs_server *server;
	struct nfs_fattr *dir_attr;
	struct nfs4_change_info cinfo;
};

struct nfs_renameargs {
	struct nfs4_sequence_args seq_args;
	const struct nfs_fh *old_dir;
	const struct nfs_fh *new_dir;
	const struct qstr *old_name;
	const struct qstr *new_name;
};

struct nfs_renameres {
	struct nfs4_sequence_res seq_res;
	struct nfs_server *server;
	struct nfs4_change_info old_cinfo;
	struct nfs_fattr *old_fattr;
	struct nfs4_change_info new_cinfo;
	struct nfs_fattr *new_fattr;
};

struct nfs_entry {
	__u64 ino;
	__u64 cookie;
	__u64 prev_cookie;
	const char *name;
	unsigned int len;
	int eof;
	struct nfs_fh *fh;
	struct nfs_fattr *fattr;
	struct nfs4_label *label;
	unsigned char d_type;
	struct nfs_server *server;
};

struct nfs_readdir_arg {
	struct dentry___3 *dentry;
	const struct cred *cred;
	__be32 *verf;
	u64 cookie;
	struct page___4 **pages;
	unsigned int page_len;
	bool plus;
};

struct nfs_readdir_res {
	__be32 *verf;
};

struct nfs4_pathname {
	unsigned int ncomponents;
	struct nfs4_string components[512];
};

struct nfs4_fs_location {
	unsigned int nservers;
	struct nfs4_string servers[10];
	struct nfs4_pathname rootpath;
};

struct nfs4_fs_locations {
	struct nfs_fattr fattr;
	const struct nfs_server *server;
	struct nfs4_pathname fs_path;
	int nlocations;
	struct nfs4_fs_location locations[10];
};

struct nfstime4 {
	u64 seconds;
	u32 nseconds;
};

struct pnfs_commit_ops;

struct pnfs_ds_commit_info {
	struct list_head commits;
	unsigned int nwritten;
	unsigned int ncommitting;
	const struct pnfs_commit_ops *ops;
};

struct nfs41_server_owner {
	uint64_t minor_id;
	uint32_t major_id_sz;
	char major_id[1024];
};

struct nfs41_server_scope {
	uint32_t server_scope_sz;
	char server_scope[1024];
};

struct nfs41_impl_id {
	char domain[1025];
	char name[1025];
	struct nfstime4 date;
};

struct nfs_page_array {
	struct page___4 **pagevec;
	unsigned int npages;
	struct page___4 *page_array[8];
};

struct nfs_page;

struct nfs_rw_ops;

struct nfs_io_completion;

struct nfs_direct_req;

struct nfs_pgio_completion_ops;

struct nfs_pgio_header {
	struct inode___4 *inode;
	const struct cred *cred;
	struct list_head pages;
	struct nfs_page *req;
	struct nfs_writeverf verf;
	fmode_t rw_mode;
	struct pnfs_layout_segment *lseg;
	loff_t io_start;
	const struct rpc_call_ops *mds_ops;
	void (*release)(struct nfs_pgio_header *);
	const struct nfs_pgio_completion_ops *completion_ops;
	const struct nfs_rw_ops *rw_ops;
	struct nfs_io_completion *io_completion;
	struct nfs_direct_req *dreq;
	int pnfs_error;
	int error;
	unsigned int good_bytes;
	long unsigned int flags;
	struct rpc_task task;
	struct nfs_fattr fattr;
	struct nfs_pgio_args args;
	struct nfs_pgio_res res;
	long unsigned int timestamp;
	int (*pgio_done_cb)(struct rpc_task *, struct nfs_pgio_header *);
	__u64 mds_offset;
	struct nfs_page_array page_array;
	struct nfs_client *ds_clp;
	u32 ds_commit_idx;
	u32 pgio_mirror_idx;
};

struct nfs_pgio_completion_ops {
	void (*error_cleanup)(struct list_head *, int);
	void (*init_hdr)(struct nfs_pgio_header *);
	void (*completion)(struct nfs_pgio_header *);
	void (*reschedule_io)(struct nfs_pgio_header *);
};

struct nfs_mds_commit_info {
	atomic_t rpcs_out;
	atomic_long_t ncommit;
	struct list_head list;
};

struct nfs_commit_data;

struct nfs_commit_info;

struct nfs_commit_completion_ops {
	void (*completion)(struct nfs_commit_data *);
	void (*resched_write)(struct nfs_commit_info *, struct nfs_page *);
};

struct nfs_commit_data {
	struct rpc_task task;
	struct inode___4 *inode;
	const struct cred *cred;
	struct nfs_fattr fattr;
	struct nfs_writeverf verf;
	struct list_head pages;
	struct list_head list;
	struct nfs_direct_req *dreq;
	struct nfs_commitargs args;
	struct nfs_commitres res;
	struct nfs_open_context *context;
	struct pnfs_layout_segment *lseg;
	struct nfs_client *ds_clp;
	int ds_commit_index;
	loff_t lwb;
	const struct rpc_call_ops *mds_ops;
	const struct nfs_commit_completion_ops *completion_ops;
	int (*commit_done_cb)(struct rpc_task *, struct nfs_commit_data *);
	long unsigned int flags;
};

struct nfs_commit_info {
	struct inode___4 *inode;
	struct nfs_mds_commit_info *mds;
	struct pnfs_ds_commit_info *ds;
	struct nfs_direct_req *dreq;
	const struct nfs_commit_completion_ops *completion_ops;
};

struct nfs_unlinkdata {
	struct nfs_removeargs args;
	struct nfs_removeres res;
	struct dentry___3 *dentry;
	wait_queue_head_t wq;
	const struct cred *cred;
	struct nfs_fattr dir_attr;
	long int timeout;
};

struct nfs_renamedata {
	struct nfs_renameargs args;
	struct nfs_renameres res;
	const struct cred *cred;
	struct inode___4 *old_dir;
	struct dentry___3 *old_dentry;
	struct nfs_fattr old_fattr;
	struct inode___4 *new_dir;
	struct dentry___3 *new_dentry;
	struct nfs_fattr new_fattr;
	void (*complete)(struct rpc_task *, struct nfs_renamedata *);
	long int timeout;
	bool cancelled;
};

struct nlmclnt_operations;

struct nfs_client_initdata;

struct nfs_access_entry;

struct nfs_rpc_ops {
	u32 version;
	const struct dentry_operations___2 *dentry_ops;
	const struct inode_operations___2 *dir_inode_ops;
	const struct inode_operations___2 *file_inode_ops;
	const struct file_operations___2 *file_ops;
	const struct nlmclnt_operations *nlmclnt_ops;
	int (*getroot)(struct nfs_server *, struct nfs_fh *, struct nfs_fsinfo *);
	int (*submount)(struct fs_context *, struct nfs_server *);
	int (*try_get_tree)(struct fs_context *);
	int (*getattr)(struct nfs_server *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *, struct inode___4 *);
	int (*setattr)(struct dentry___3 *, struct nfs_fattr *, struct iattr___3 *);
	int (*lookup)(struct inode___4 *, struct dentry___3 *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *);
	int (*lookupp)(struct inode___4 *, struct nfs_fh *, struct nfs_fattr *, struct nfs4_label *);
	int (*access)(struct inode___4 *, struct nfs_access_entry *);
	int (*readlink)(struct inode___4 *, struct page___4 *, unsigned int, unsigned int);
	int (*create)(struct inode___4 *, struct dentry___3 *, struct iattr___3 *, int);
	int (*remove)(struct inode___4 *, struct dentry___3 *);
	void (*unlink_setup)(struct rpc_message *, struct dentry___3 *, struct inode___4 *);
	void (*unlink_rpc_prepare)(struct rpc_task *, struct nfs_unlinkdata *);
	int (*unlink_done)(struct rpc_task *, struct inode___4 *);
	void (*rename_setup)(struct rpc_message *, struct dentry___3 *, struct dentry___3 *);
	void (*rename_rpc_prepare)(struct rpc_task *, struct nfs_renamedata *);
	int (*rename_done)(struct rpc_task *, struct inode___4 *, struct inode___4 *);
	int (*link)(struct inode___4 *, struct inode___4 *, const struct qstr *);
	int (*symlink)(struct inode___4 *, struct dentry___3 *, struct page___4 *, unsigned int, struct iattr___3 *);
	int (*mkdir)(struct inode___4 *, struct dentry___3 *, struct iattr___3 *);
	int (*rmdir)(struct inode___4 *, const struct qstr *);
	int (*readdir)(struct nfs_readdir_arg *, struct nfs_readdir_res *);
	int (*mknod)(struct inode___4 *, struct dentry___3 *, struct iattr___3 *, dev_t);
	int (*statfs)(struct nfs_server *, struct nfs_fh *, struct nfs_fsstat *);
	int (*fsinfo)(struct nfs_server *, struct nfs_fh *, struct nfs_fsinfo *);
	int (*pathconf)(struct nfs_server *, struct nfs_fh *, struct nfs_pathconf *);
	int (*set_capabilities)(struct nfs_server *, struct nfs_fh *);
	int (*decode_dirent)(struct xdr_stream *, struct nfs_entry *, bool);
	int (*pgio_rpc_prepare)(struct rpc_task *, struct nfs_pgio_header *);
	void (*read_setup)(struct nfs_pgio_header *, struct rpc_message *);
	int (*read_done)(struct rpc_task *, struct nfs_pgio_header *);
	void (*write_setup)(struct nfs_pgio_header *, struct rpc_message *, struct rpc_clnt **);
	int (*write_done)(struct rpc_task *, struct nfs_pgio_header *);
	void (*commit_setup)(struct nfs_commit_data *, struct rpc_message *, struct rpc_clnt **);
	void (*commit_rpc_prepare)(struct rpc_task *, struct nfs_commit_data *);
	int (*commit_done)(struct rpc_task *, struct nfs_commit_data *);
	int (*lock)(struct file___3 *, int, struct file_lock___2 *);
	int (*lock_check_bounds)(const struct file_lock___2 *);
	void (*clear_acl_cache)(struct inode___4 *);
	void (*close_context)(struct nfs_open_context *, int);
	struct inode___4 * (*open_context)(struct inode___4 *, struct nfs_open_context *, int, struct iattr___3 *, int *);
	int (*have_delegation)(struct inode___4 *, fmode_t);
	struct nfs_client * (*alloc_client)(const struct nfs_client_initdata *);
	struct nfs_client * (*init_client)(struct nfs_client *, const struct nfs_client_initdata *);
	void (*free_client)(struct nfs_client *);
	struct nfs_server * (*create_server)(struct fs_context *);
	struct nfs_server * (*clone_server)(struct nfs_server *, struct nfs_fh *, struct nfs_fattr *, rpc_authflavor_t);
	int (*discover_trunking)(struct nfs_server *, struct nfs_fh *);
};

struct nfs_access_entry {
	struct rb_node rb_node;
	struct list_head lru;
	const struct cred *cred;
	__u32 mask;
	struct callback_head callback_head;
};

struct nfs4_state_recovery_ops;

struct nfs4_state_maintenance_ops;

struct nfs4_mig_recovery_ops;

struct nfs4_minor_version_ops {
	u32 minor_version;
	unsigned int init_caps;
	int (*init_client)(struct nfs_client *);
	void (*shutdown_client)(struct nfs_client *);
	bool (*match_stateid)(const nfs4_stateid *, const nfs4_stateid *);
	int (*find_root_sec)(struct nfs_server *, struct nfs_fh *, struct nfs_fsinfo *);
	void (*free_lock_state)(struct nfs_server *, struct nfs4_lock_state *);
	int (*test_and_free_expired)(struct nfs_server *, nfs4_stateid *, const struct cred *);
	struct nfs_seqid * (*alloc_seqid)(struct nfs_seqid_counter *, gfp_t);
	void (*session_trunk)(struct rpc_clnt *, struct rpc_xprt *, void *);
	const struct rpc_call_ops *call_sync_ops;
	const struct nfs4_state_recovery_ops *reboot_recovery_ops;
	const struct nfs4_state_recovery_ops *nograce_recovery_ops;
	const struct nfs4_state_maintenance_ops *state_renewal_ops;
	const struct nfs4_mig_recovery_ops *mig_recovery_ops;
};

struct nfs4_state_owner;

struct nfs4_state {
	struct list_head open_states;
	struct list_head inode_states;
	struct list_head lock_states;
	struct nfs4_state_owner *owner;
	struct inode___4 *inode;
	long unsigned int flags;
	spinlock_t state_lock;
	seqlock_t seqlock;
	nfs4_stateid stateid;
	nfs4_stateid open_stateid;
	unsigned int n_rdonly;
	unsigned int n_wronly;
	unsigned int n_rdwr;
	fmode_t state;
	refcount_t count;
	wait_queue_head_t waitq;
	struct callback_head callback_head;
};

struct cache_head {
	struct hlist_node cache_list;
	time64_t expiry_time;
	time64_t last_refresh;
	struct kref ref;
	long unsigned int flags;
};

struct cache_deferred_req;

struct cache_req {
	struct cache_deferred_req * (*defer)(struct cache_req *);
	int thread_wait;
};

struct cache_deferred_req {
	struct hlist_node hash;
	struct list_head recent;
	struct cache_head *item;
	void *owner;
	void (*revisit)(struct cache_deferred_req *, int);
};

struct svc_cred {
	kuid_t cr_uid;
	kgid_t cr_gid;
	struct group_info *cr_group_info;
	u32 cr_flavor;
	char *cr_raw_principal;
	char *cr_principal;
	char *cr_targ_princ;
	struct gss_api_mech *cr_gss_mech;
};

struct auth_ops {
	char *name;
	struct module___5 *owner;
	int flavour;
	int (*accept)(struct svc_rqst *);
	int (*release)(struct svc_rqst *);
	void (*domain_release)(struct auth_domain *);
	int (*set_client)(struct svc_rqst *);
};

struct pagevec___6 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___4 *pages[15];
};

struct svc_cacherep;

struct svc_procedure;

struct svc_deferred_req;

struct svc_rqst {
	struct list_head rq_all;
	struct callback_head rq_rcu_head;
	struct svc_xprt *rq_xprt;
	struct __kernel_sockaddr_storage rq_addr;
	size_t rq_addrlen;
	struct __kernel_sockaddr_storage rq_daddr;
	size_t rq_daddrlen;
	struct svc_serv *rq_server;
	struct svc_pool *rq_pool;
	const struct svc_procedure *rq_procinfo;
	struct auth_ops *rq_authop;
	struct svc_cred rq_cred;
	void *rq_xprt_ctxt;
	struct svc_deferred_req *rq_deferred;
	size_t rq_xprt_hlen;
	struct xdr_buf rq_arg;
	struct xdr_stream rq_arg_stream;
	struct xdr_stream rq_res_stream;
	struct page___4 *rq_scratch_page;
	struct xdr_buf rq_res;
	struct page___4 *rq_pages[260];
	struct page___4 **rq_respages;
	struct page___4 **rq_next_page;
	struct page___4 **rq_page_end;
	struct pagevec___6 rq_pvec;
	struct kvec rq_vec[259];
	struct bio_vec___2 rq_bvec[259];
	__be32 rq_xid;
	u32 rq_prog;
	u32 rq_vers;
	u32 rq_proc;
	u32 rq_prot;
	int rq_cachetype;
	long unsigned int rq_flags;
	ktime_t rq_qtime;
	void *rq_argp;
	void *rq_resp;
	void *rq_auth_data;
	__be32 rq_auth_stat;
	int rq_auth_slack;
	int rq_reserved;
	ktime_t rq_stime;
	struct cache_req rq_chandle;
	struct auth_domain *rq_client;
	struct auth_domain *rq_gssclient;
	struct svc_cacherep *rq_cacherep;
	struct task_struct___4 *rq_task;
	spinlock_t rq_lock;
	struct net___2 *rq_bc_net;
	void **rq_lease_breaker;
};

struct svc_pool_stats {
	atomic_long_t packets;
	long unsigned int sockets_queued;
	atomic_long_t threads_woken;
	atomic_long_t threads_timedout;
};

struct svc_pool {
	unsigned int sp_id;
	spinlock_t sp_lock;
	struct list_head sp_sockets;
	unsigned int sp_nrthreads;
	struct list_head sp_all_threads;
	struct svc_pool_stats sp_stats;
	long unsigned int sp_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct svc_serv_ops {
	void (*svo_shutdown)(struct svc_serv *, struct net___2 *);
	int (*svo_function)(void *);
	void (*svo_enqueue_xprt)(struct svc_xprt *);
	int (*svo_setup)(struct svc_serv *, struct svc_pool *, int);
	struct module___5 *svo_module;
};

struct svc_procedure {
	__be32 (*pc_func)(struct svc_rqst *);
	int (*pc_decode)(struct svc_rqst *, __be32 *);
	int (*pc_encode)(struct svc_rqst *, __be32 *);
	void (*pc_release)(struct svc_rqst *);
	unsigned int pc_argsize;
	unsigned int pc_ressize;
	unsigned int pc_cachetype;
	unsigned int pc_xdrressize;
	const char *pc_name;
};

struct svc_deferred_req {
	u32 prot;
	struct svc_xprt *xprt;
	struct __kernel_sockaddr_storage addr;
	size_t addrlen;
	struct __kernel_sockaddr_storage daddr;
	size_t daddrlen;
	void *xprt_ctxt;
	struct cache_deferred_req handle;
	size_t xprt_hlen;
	int argslen;
	__be32 args[0];
};

struct svc_process_info {
	union {
		int (*dispatch)(struct svc_rqst *, __be32 *);
		struct {
			unsigned int lovers;
			unsigned int hivers;
		} mismatch;
	};
};

struct svc_version {
	u32 vs_vers;
	u32 vs_nproc;
	const struct svc_procedure *vs_proc;
	unsigned int *vs_count;
	u32 vs_xdrsize;
	bool vs_hidden;
	bool vs_rpcb_optnl;
	bool vs_need_cong_ctrl;
	int (*vs_dispatch)(struct svc_rqst *, __be32 *);
};

struct nfs4_ssc_client_ops;

struct nfs_ssc_client_ops;

struct nfs_ssc_client_ops_tbl {
	const struct nfs4_ssc_client_ops *ssc_nfs4_ops;
	const struct nfs_ssc_client_ops *ssc_nfs_ops;
};

struct nfs4_ssc_client_ops {
	struct file___3 * (*sco_open)(struct vfsmount___2 *, struct nfs_fh *, nfs4_stateid *);
	void (*sco_close)(struct file___3 *);
};

struct nfs_ssc_client_ops {
	void (*sco_sb_deactive)(struct super_block___3 *);
};

struct nfs4_state_recovery_ops {
	int owner_flag_bit;
	int state_flag_bit;
	int (*recover_open)(struct nfs4_state_owner *, struct nfs4_state *);
	int (*recover_lock)(struct nfs4_state *, struct file_lock___2 *);
	int (*establish_clid)(struct nfs_client *, const struct cred *);
	int (*reclaim_complete)(struct nfs_client *, const struct cred *);
	int (*detect_trunking)(struct nfs_client *, struct nfs_client **, const struct cred *);
};

struct nfs4_state_maintenance_ops {
	int (*sched_state_renewal)(struct nfs_client *, const struct cred *, unsigned int);
	const struct cred * (*get_state_renewal_cred)(struct nfs_client *);
	int (*renew_lease)(struct nfs_client *, const struct cred *);
};

struct nfs4_mig_recovery_ops {
	int (*get_locations)(struct nfs_server *, struct nfs_fh *, struct nfs4_fs_locations *, struct page___4 *, const struct cred *);
	int (*fsid_present)(struct inode___4 *, const struct cred *);
};

struct nfs4_state_owner {
	struct nfs_server *so_server;
	struct list_head so_lru;
	long unsigned int so_expires;
	struct rb_node so_server_node;
	const struct cred *so_cred;
	spinlock_t so_lock;
	atomic_t so_count;
	long unsigned int so_flags;
	struct list_head so_states;
	struct nfs_seqid_counter so_seqid;
	seqcount_spinlock_t so_reclaim_seqcount;
	struct mutex so_delegreturn_mutex;
};

struct dentry___118;

struct super_block___118;

struct module___108;

struct file_system_type___118 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___118 * (*mount)(struct file_system_type___118 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___118 *);
	struct module___108 *owner;
	struct file_system_type___118 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___118;

struct kiocb___118;

struct iov_iter___67;

struct poll_table_struct___81;

struct vm_area_struct___123;

struct inode___118;

struct file_lock___118;

struct page___123;

struct pipe_inode_info___40;

struct seq_file___105;

struct file_operations___118 {
	struct module___108 *owner;
	loff_t (*llseek)(struct file___118 *, loff_t, int);
	ssize_t (*read)(struct file___118 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___118 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___118 *, struct iov_iter___67 *);
	ssize_t (*write_iter)(struct kiocb___118 *, struct iov_iter___67 *);
	int (*iopoll)(struct kiocb___118 *, bool);
	int (*iterate)(struct file___118 *, struct dir_context *);
	int (*iterate_shared)(struct file___118 *, struct dir_context *);
	__poll_t (*poll)(struct file___118 *, struct poll_table_struct___81 *);
	long int (*unlocked_ioctl)(struct file___118 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___118 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___118 *, struct vm_area_struct___123 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___118 *, struct file___118 *);
	int (*flush)(struct file___118 *, fl_owner_t);
	int (*release)(struct inode___118 *, struct file___118 *);
	int (*fsync)(struct file___118 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___118 *, int);
	int (*lock)(struct file___118 *, int, struct file_lock___118 *);
	ssize_t (*sendpage)(struct file___118 *, struct page___123 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___118 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___118 *, long unsigned int);
	int (*flock)(struct file___118 *, int, struct file_lock___118 *);
	ssize_t (*splice_write)(struct pipe_inode_info___40 *, struct file___118 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___118 *, loff_t *, struct pipe_inode_info___40 *, size_t, unsigned int);
	int (*setlease)(struct file___118 *, long int, struct file_lock___118 **, void **);
	long int (*fallocate)(struct file___118 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___105 *, struct file___118 *);
	ssize_t (*copy_file_range)(struct file___118 *, loff_t, struct file___118 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___118 *, loff_t, struct file___118 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___118 *, loff_t, loff_t, int);
};

struct vmacache___123 {
	u64 seqnum;
	struct vm_area_struct___123 *vmas[4];
};

struct page_frag___123 {
	struct page___123 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___63;

struct debug_info___63 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___63 *hbp_break[16];
	struct perf_event___63 *hbp_watch[16];
};

struct thread_struct___63 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___63 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___124;

struct pid___103;

struct fs_struct___17;

struct files_struct___15;

struct nsproxy___109;

struct signal_struct___119;

struct bio_list___54;

struct backing_dev_info___52;

struct io_context___54;

struct css_set___88;

struct perf_event_context___63;

struct mem_cgroup___46;

struct request_queue___54;

struct vm_struct___108;

struct task_struct___125 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___125 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___124 *mm;
	struct mm_struct___124 *active_mm;
	struct vmacache___123 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___125 *real_parent;
	struct task_struct___125 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___125 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___103 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___17 *fs;
	struct files_struct___15 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___109 *nsproxy;
	struct signal_struct___119 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___125 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___54 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___52 *backing_dev_info;
	struct io_context___54 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___88 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___63 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___40 *splice_pipe;
	struct page_frag___123 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___46 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___46 *active_memcg;
	struct request_queue___54 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___125 *oom_reaper_list;
	struct vm_struct___108 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___63 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___110;

struct kobj_type___110;

struct kernfs_node___110;

struct kobject___110 {
	const char *name;
	struct list_head entry;
	struct kobject___110 *parent;
	struct kset___110 *kset;
	struct kobj_type___110 *ktype;
	struct kernfs_node___110 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___107 {
	struct kobject___110 kobj;
	struct module___108 *mod;
	struct kobject___110 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___107 {
	struct module___108 *mod;
	struct latch_tree_node node;
};

struct module_layout___107 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___107 mtn;
};

struct module_attribute___107;

struct kernel_param___107;

struct trace_event_call___57;

struct module___108 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___107 mkobj;
	struct module_attribute___107 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___110 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___107 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___107 core_layout;
	struct module_layout___107 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___57 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___63 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___125 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___63)(struct perf_event___63 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___63;

struct fasync_struct___118;

struct pid_namespace___103;

struct perf_cgroup___63;

struct perf_event___63 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___63 *group_leader;
	struct pmu___63 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___63 hw;
	struct perf_event_context___63 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___63 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___125 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___118 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___63 *aux_event;
	void (*destroy)(struct perf_event___63 *);
	struct callback_head callback_head;
	struct pid_namespace___103 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___63 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___63 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___57 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___63 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___123 *pgtable_t___123;

struct address_space___118;

struct dev_pagemap___116;

struct page___123 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___118 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___123 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___123 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___124 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___116 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___116;

struct vm_area_struct___123 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___123 *vm_next;
	struct vm_area_struct___123 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___124 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___116 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___118 *vm_file;
	struct file___118 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___17;

struct core_state___123;

struct mm_struct___124 {
	struct {
		struct vm_area_struct___123 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___118 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___17 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___123 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___125 *owner;
		struct user_namespace___4 *user_ns;
		struct file___118 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___118;

struct address_space___118 {
	struct inode___118 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___118 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___116;

struct dev_pagemap___116 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___116 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___118;

struct path___118 {
	struct vfsmount___118 *mnt;
	struct dentry___118 *dentry;
};

struct fown_struct___103 {
	rwlock_t lock;
	struct pid___103 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___118 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___118 f_path;
	struct inode___118 *f_inode;
	const struct file_operations___118 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___103 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___118 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___116;

struct vm_operations_struct___116 {
	void (*open)(struct vm_area_struct___123 *);
	void (*close)(struct vm_area_struct___123 *);
	int (*may_split)(struct vm_area_struct___123 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___123 *);
	int (*mprotect)(struct vm_area_struct___123 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___116 *);
	vm_fault_t (*huge_fault)(struct vm_fault___116 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___116 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___123 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___116 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___116 *);
	int (*access)(struct vm_area_struct___123 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___123 *);
	int (*set_policy)(struct vm_area_struct___123 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___123 *, long unsigned int);
	struct page___123 * (*find_special_page)(struct vm_area_struct___123 *, long unsigned int);
};

struct core_thread___123 {
	struct task_struct___125 *task;
	struct core_thread___123 *next;
};

struct core_state___123 {
	atomic_t nr_threads;
	struct core_thread___123 dumper;
	struct completion startup;
};

struct linux_binprm___18;

struct coredump_params___17;

struct linux_binfmt___17 {
	struct list_head lh;
	struct module___108 *module;
	int (*load_binary)(struct linux_binprm___18 *);
	int (*load_shlib)(struct file___118 *);
	int (*core_dump)(struct coredump_params___17 *);
	long unsigned int min_coredump;
};

struct vm_fault___116 {
	const struct {
		struct vm_area_struct___123 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___123 *cow_page;
	struct page___123 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___123 prealloc_pte;
};

struct pglist_data___52;

struct lruvec___52 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___52 *pgdat;
};

struct zone___52 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___52 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___52 {
	struct zone___52 *zone;
	int zone_idx;
};

struct zonelist___52 {
	struct zoneref___52 _zonerefs[321];
};

struct pglist_data___52 {
	struct zone___52 node_zones[5];
	struct zonelist___52 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___125 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___125 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___52 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___118;

struct dentry___118 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___118 *d_parent;
	struct qstr d_name;
	struct inode___118 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___118 *d_op;
	struct super_block___118 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___118;

struct bdi_writeback___52;

struct inode___118 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___118 *i_op;
	struct super_block___118 *i_sb;
	struct address_space___118 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___52 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___118 *i_fop;
		void (*free_inode)(struct inode___118 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___118 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___118 {
	int (*d_revalidate)(struct dentry___118 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___118 *, unsigned int);
	int (*d_hash)(const struct dentry___118 *, struct qstr *);
	int (*d_compare)(const struct dentry___118 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___118 *);
	int (*d_init)(struct dentry___118 *);
	void (*d_release)(struct dentry___118 *);
	void (*d_prune)(struct dentry___118 *);
	void (*d_iput)(struct dentry___118 *, struct inode___118 *);
	char * (*d_dname)(struct dentry___118 *, char *, int);
	struct vfsmount___118 * (*d_automount)(struct path___118 *);
	int (*d_manage)(const struct path___118 *, bool);
	struct dentry___118 * (*d_real)(struct dentry___118 *, const struct inode___118 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___118;

struct mem_dqinfo___118 {
	struct quota_format_type___118 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___118;

struct quota_info___118 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___118 *files[3];
	struct mem_dqinfo___118 info[3];
	const struct quota_format_ops___118 *ops[3];
};

struct rcuwait___119 {
	struct task_struct___125 *task;
};

struct percpu_rw_semaphore___119 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___119 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___118 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___119 rw_sem[3];
};

struct shrink_control___46;

struct shrinker___46 {
	long unsigned int (*count_objects)(struct shrinker___46 *, struct shrink_control___46 *);
	long unsigned int (*scan_objects)(struct shrinker___46 *, struct shrink_control___46 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___118;

struct dquot_operations___118;

struct quotactl_ops___118;

struct block_device___55;

struct super_block___118 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___118 *s_type;
	const struct super_operations___118 *s_op;
	const struct dquot_operations___118 *dq_op;
	const struct quotactl_ops___118 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___118 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___55 *s_bdev;
	struct backing_dev_info___52 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___118 s_dquot;
	struct sb_writers___118 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___118 *s_d_op;
	int cleancache_poolid;
	struct shrinker___46 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___118 {
	struct dentry___118 *mnt_root;
	struct super_block___118 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct upid___103 {
	int nr;
	struct pid_namespace___103 *ns;
};

struct pid_namespace___103 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___125 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___103 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___103 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___103 numbers[1];
};

struct signal_struct___119 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___125 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___125 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___103 *pids[4];
	struct pid___103 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___124 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fs_struct___17 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___118 root;
	struct path___118 pwd;
};

struct fdtable___15 {
	unsigned int max_fds;
	struct file___118 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___15 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___15 *fdt;
	struct fdtable___15 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___118 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cgroup_namespace___88;

struct nsproxy___109 {
	atomic_t count;
	struct uts_namespace___4 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___103 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___88 *cgroup_ns;
};

struct bio___54;

struct bio_list___54 {
	struct bio___54 *head;
	struct bio___54 *tail;
};

struct cgroup_subsys_state___88;

struct bdi_writeback___52 {
	struct backing_dev_info___52 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___88 *memcg_css;
	struct cgroup_subsys_state___88 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___90;

struct backing_dev_info___52 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___52 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___90 *dev;
	char dev_name[64];
	struct device___90 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___118 *debug_dir;
};

struct io_cq___54;

struct io_context___54 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___54 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___88;

struct css_set___88 {
	struct cgroup_subsys_state___88 *subsys[14];
	refcount_t refcount;
	struct css_set___88 *dom_cset;
	struct cgroup___88 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___88 *mg_src_cgrp;
	struct cgroup___88 *mg_dst_cgrp;
	struct css_set___88 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___63 {
	struct pmu___63 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___125 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___63 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___40;

struct pipe_inode_info___40 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___123 *tmp_page;
	struct fasync_struct___118 *fasync_readers;
	struct fasync_struct___118 *fasync_writers;
	struct pipe_buffer___40 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___88;

struct cgroup_subsys_state___88 {
	struct cgroup___88 *cgroup;
	struct cgroup_subsys___88 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___88 *parent;
};

struct cgroup_file___88 {
	struct kernfs_node___110 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___46;

struct mem_cgroup_per_node___46;

struct mem_cgroup___46 {
	struct cgroup_subsys_state___88 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___88 events_file;
	struct cgroup_file___88 events_local_file;
	struct cgroup_file___88 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___46 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___125 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___46 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___54;

struct blk_integrity___54 {
	const struct blk_integrity_profile___54 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___54 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___54 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___54;

struct elevator_queue___54;

struct blk_mq_ops___52;

struct blk_mq_hw_ctx___52;

struct gendisk___54;

struct blkcg_gq___52;

struct blk_mq_tag_set___52;

struct request_queue___54 {
	struct request___54 *last_merge;
	struct elevator_queue___54 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___52 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___52 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___54 *disk;
	struct kobject___110 kobj;
	struct kobject___110 *mq_kobj;
	struct blk_integrity___54 integrity;
	struct device___90 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___52 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___52 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___54 bio_split;
	struct dentry___118 *debugfs_dir;
	struct dentry___118 *sched_debugfs_dir;
	struct dentry___118 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___108 {
	struct vm_struct___108 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___123 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___46 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___46 *memcg;
};

struct psi_group___88 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___125 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___88;

struct cgroup_rstat_cpu___88;

struct cgroup___88 {
	struct cgroup_subsys_state___88 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___110 *kn;
	struct cgroup_file___88 procs_file;
	struct cgroup_file___88 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___88 *subsys[14];
	struct cgroup_root___88 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___88 *dom_cgrp;
	struct cgroup___88 *old_dom_cgrp;
	struct cgroup_rstat_cpu___88 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___88 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___54 {
	struct request_queue___54 *q;
	struct io_context___54 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___53;

struct kiocb___118 {
	struct file___118 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___118 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___53 *ki_waitq;
	};
};

struct iattr___118 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___118 *ia_file;
};

struct dquot___118 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___118 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___118 {
	int qf_fmt_id;
	const struct quota_format_ops___118 *qf_ops;
	struct module___108 *qf_owner;
	struct quota_format_type___118 *qf_next;
};

struct quota_format_ops___118 {
	int (*check_quota_file)(struct super_block___118 *, int);
	int (*read_file_info)(struct super_block___118 *, int);
	int (*write_file_info)(struct super_block___118 *, int);
	int (*free_file_info)(struct super_block___118 *, int);
	int (*read_dqblk)(struct dquot___118 *);
	int (*commit_dqblk)(struct dquot___118 *);
	int (*release_dqblk)(struct dquot___118 *);
	int (*get_next_id)(struct super_block___118 *, struct kqid *);
};

struct dquot_operations___118 {
	int (*write_dquot)(struct dquot___118 *);
	struct dquot___118 * (*alloc_dquot)(struct super_block___118 *, int);
	void (*destroy_dquot)(struct dquot___118 *);
	int (*acquire_dquot)(struct dquot___118 *);
	int (*release_dquot)(struct dquot___118 *);
	int (*mark_dirty)(struct dquot___118 *);
	int (*write_info)(struct super_block___118 *, int);
	qsize_t * (*get_reserved_space)(struct inode___118 *);
	int (*get_projid)(struct inode___118 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___118 *, qsize_t *);
	int (*get_next_id)(struct super_block___118 *, struct kqid *);
};

struct quotactl_ops___118 {
	int (*quota_on)(struct super_block___118 *, int, int, const struct path___118 *);
	int (*quota_off)(struct super_block___118 *, int);
	int (*quota_enable)(struct super_block___118 *, unsigned int);
	int (*quota_disable)(struct super_block___118 *, unsigned int);
	int (*quota_sync)(struct super_block___118 *, int);
	int (*set_info)(struct super_block___118 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___118 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___118 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___118 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___118 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___118 *, unsigned int);
};

struct wait_page_queue___53 {
	struct page___123 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___52;

struct readahead_control___53;

struct swap_info_struct___28;

struct address_space_operations___118 {
	int (*writepage)(struct page___123 *, struct writeback_control___52 *);
	int (*readpage)(struct file___118 *, struct page___123 *);
	int (*writepages)(struct address_space___118 *, struct writeback_control___52 *);
	int (*set_page_dirty)(struct page___123 *);
	int (*readpages)(struct file___118 *, struct address_space___118 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___53 *);
	int (*write_begin)(struct file___118 *, struct address_space___118 *, loff_t, unsigned int, unsigned int, struct page___123 **, void **);
	int (*write_end)(struct file___118 *, struct address_space___118 *, loff_t, unsigned int, unsigned int, struct page___123 *, void *);
	sector_t (*bmap)(struct address_space___118 *, sector_t);
	void (*invalidatepage)(struct page___123 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___123 *, gfp_t);
	void (*freepage)(struct page___123 *);
	ssize_t (*direct_IO)(struct kiocb___118 *, struct iov_iter___67 *);
	int (*migratepage)(struct address_space___118 *, struct page___123 *, struct page___123 *, enum migrate_mode);
	bool (*isolate_page)(struct page___123 *, isolate_mode_t);
	void (*putback_page)(struct page___123 *);
	int (*launder_page)(struct page___123 *);
	int (*is_partially_uptodate)(struct page___123 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___123 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___118 *, struct page___123 *);
	int (*swap_activate)(struct swap_info_struct___28 *, struct file___118 *, sector_t *);
	void (*swap_deactivate)(struct file___118 *);
};

struct writeback_control___52 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___52 *wb;
	struct inode___118 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___53 {
	struct file___118 *file;
	struct address_space___118 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___65;

struct iov_iter___67 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___65 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___40 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___28 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___55 *bdev;
	struct file___118 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___118 {
	struct dentry___118 * (*lookup)(struct inode___118 *, struct dentry___118 *, unsigned int);
	const char * (*get_link)(struct dentry___118 *, struct inode___118 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___118 *, int);
	struct posix_acl * (*get_acl)(struct inode___118 *, int, bool);
	int (*readlink)(struct dentry___118 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___118 *, struct dentry___118 *, umode_t, bool);
	int (*link)(struct dentry___118 *, struct inode___118 *, struct dentry___118 *);
	int (*unlink)(struct inode___118 *, struct dentry___118 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___118 *, struct dentry___118 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___118 *, struct dentry___118 *, umode_t);
	int (*rmdir)(struct inode___118 *, struct dentry___118 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___118 *, struct dentry___118 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___118 *, struct dentry___118 *, struct inode___118 *, struct dentry___118 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___118 *, struct iattr___118 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___118 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___118 *, char *, size_t);
	int (*fiemap)(struct inode___118 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___118 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___118 *, struct dentry___118 *, struct file___118 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___118 *, struct dentry___118 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___118 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___118 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___118 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___118 {
	void (*fl_copy_lock)(struct file_lock___118 *, struct file_lock___118 *);
	void (*fl_release_private)(struct file_lock___118 *);
};

struct lock_manager_operations___118;

struct file_lock___118 {
	struct file_lock___118 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___118 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___118 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___118 *fl_ops;
	const struct lock_manager_operations___118 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___118 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___118 *);
	int (*lm_grant)(struct file_lock___118 *, int);
	bool (*lm_break)(struct file_lock___118 *);
	int (*lm_change)(struct file_lock___118 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___118 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___118 *);
};

struct fasync_struct___118 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___118 *fa_next;
	struct file___118 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___118 {
	struct inode___118 * (*alloc_inode)(struct super_block___118 *);
	void (*destroy_inode)(struct inode___118 *);
	void (*free_inode)(struct inode___118 *);
	void (*dirty_inode)(struct inode___118 *, int);
	int (*write_inode)(struct inode___118 *, struct writeback_control___52 *);
	int (*drop_inode)(struct inode___118 *);
	void (*evict_inode)(struct inode___118 *);
	void (*put_super)(struct super_block___118 *);
	int (*sync_fs)(struct super_block___118 *, int);
	int (*freeze_super)(struct super_block___118 *);
	int (*freeze_fs)(struct super_block___118 *);
	int (*thaw_super)(struct super_block___118 *);
	int (*unfreeze_fs)(struct super_block___118 *);
	int (*statfs)(struct dentry___118 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___118 *, int *, char *);
	void (*umount_begin)(struct super_block___118 *);
	int (*show_options)(struct seq_file___105 *, struct dentry___118 *);
	int (*show_devname)(struct seq_file___105 *, struct dentry___118 *);
	int (*show_path)(struct seq_file___105 *, struct dentry___118 *);
	int (*show_stats)(struct seq_file___105 *, struct dentry___118 *);
	ssize_t (*quota_read)(struct super_block___118 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___118 *, int, const char *, size_t, loff_t);
	struct dquot___118 ** (*get_dquots)(struct inode___118 *);
	long int (*nr_cached_objects)(struct super_block___118 *, struct shrink_control___46 *);
	long int (*free_cached_objects)(struct super_block___118 *, struct shrink_control___46 *);
	struct file___118 * (*real_loop)(struct file___118 *);
};

struct wakeup_source___90;

struct dev_pm_info___90 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___90 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___90 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___90;

struct bus_type___90;

struct device_driver___90;

struct dev_pm_domain___90;

struct fwnode_handle___90;

struct class___90;

struct attribute_group___110;

struct device___90 {
	struct kobject___110 kobj;
	struct device___90 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___90 *type;
	struct bus_type___90 *bus;
	struct device_driver___90 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___90 power;
	struct dev_pm_domain___90 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___90 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___90 *class;
	const struct attribute_group___110 **groups;
	void (*release)(struct device___90 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___55 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___118 *bd_inode;
	struct super_block___118 *bd_super;
	void *bd_claiming;
	struct device___90 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___110 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___54 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___118 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___81)(struct file___118 *, wait_queue_head_t *, struct poll_table_struct___81 *);

struct poll_table_struct___81 {
	poll_queue_proc___81 _qproc;
	__poll_t _key;
};

struct seq_operations___105;

struct seq_file___105 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___105 *op;
	int poll_event;
	const struct file___118 *file;
	void *private;
};

typedef void bio_end_io_t___54(struct bio___54 *);

struct bio_vec___65 {
	struct page___123 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___54;

struct bio___54 {
	struct bio___54 *bi_next;
	struct block_device___55 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___54 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___52 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___54 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___65 *bi_io_vec;
	struct bio_set___54 *bi_pool;
	struct bio_vec___65 bi_inline_vecs[0];
};

struct dev_pagemap_ops___116 {
	void (*page_free)(struct page___123 *);
	void (*kill)(struct dev_pagemap___116 *);
	void (*cleanup)(struct dev_pagemap___116 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___116 *);
};

struct seq_operations___105 {
	void * (*start)(struct seq_file___105 *, loff_t *);
	void (*stop)(struct seq_file___105 *, void *);
	void * (*next)(struct seq_file___105 *, void *, loff_t *);
	int (*show)(struct seq_file___105 *, void *);
};

struct kernfs_root___110;

struct kernfs_elem_dir___110 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___110 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___110;

struct kernfs_root___110 {
	struct kernfs_node___110 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___110 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___110 {
	struct kernfs_node___110 *target_kn;
};

struct kernfs_ops___110;

struct kernfs_elem_attr___110 {
	const struct kernfs_ops___110 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___110 *notify_next;
};

struct kernfs_node___110 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___110 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___110 dir;
		struct kernfs_elem_symlink___110 symlink;
		struct kernfs_elem_attr___110 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___110;

struct kernfs_ops___110 {
	int (*open)(struct kernfs_open_file___110 *);
	void (*release)(struct kernfs_open_file___110 *);
	int (*seq_show)(struct seq_file___105 *, void *);
	void * (*seq_start)(struct seq_file___105 *, loff_t *);
	void * (*seq_next)(struct seq_file___105 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___105 *, void *);
	ssize_t (*read)(struct kernfs_open_file___110 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___110 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___110 *, struct poll_table_struct___81 *);
	int (*mmap)(struct kernfs_open_file___110 *, struct vm_area_struct___123 *);
};

struct kernfs_syscall_ops___110 {
	int (*show_options)(struct seq_file___105 *, struct kernfs_root___110 *);
	int (*mkdir)(struct kernfs_node___110 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___110 *);
	int (*rename)(struct kernfs_node___110 *, struct kernfs_node___110 *, const char *);
	int (*show_path)(struct seq_file___105 *, struct kernfs_node___110 *, struct kernfs_root___110 *);
};

struct kernfs_open_file___110 {
	struct kernfs_node___110 *kn;
	struct file___118 *file;
	struct seq_file___105 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___116 *vm_ops;
};

struct cgroup_namespace___88 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___88 *root_cset;
};

struct fwnode_operations___90;

struct fwnode_handle___90 {
	struct fwnode_handle___90 *secondary;
	const struct fwnode_operations___90 *ops;
	struct device___90 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___90;

struct fwnode_endpoint___90;

struct fwnode_operations___90 {
	struct fwnode_handle___90 * (*get)(struct fwnode_handle___90 *);
	void (*put)(struct fwnode_handle___90 *);
	bool (*device_is_available)(const struct fwnode_handle___90 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___90 *, const struct device___90 *);
	bool (*property_present)(const struct fwnode_handle___90 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___90 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___90 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___90 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*get_parent)(const struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*get_next_child_node)(const struct fwnode_handle___90 *, struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*get_named_child_node)(const struct fwnode_handle___90 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___90 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___90 *);
	struct fwnode_handle___90 * (*graph_get_next_endpoint)(const struct fwnode_handle___90 *, struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*graph_get_remote_endpoint)(const struct fwnode_handle___90 *);
	struct fwnode_handle___90 * (*graph_get_port_parent)(struct fwnode_handle___90 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___90 *, struct fwnode_endpoint___90 *);
	int (*add_links)(struct fwnode_handle___90 *);
};

struct fwnode_endpoint___90 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___90 *local_fwnode;
};

struct fwnode_reference_args___90 {
	struct fwnode_handle___90 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___110;

struct attribute_group___110 {
	const char *name;
	umode_t (*is_visible)(struct kobject___110 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___110 *, struct bin_attribute___110 *, int);
	struct attribute **attrs;
	struct bin_attribute___110 **bin_attrs;
};

struct bin_attribute___110 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___118 * (*f_mapping)();
	ssize_t (*read)(struct file___118 *, struct kobject___110 *, struct bin_attribute___110 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___118 *, struct kobject___110 *, struct bin_attribute___110 *, char *, loff_t, size_t);
	int (*mmap)(struct file___118 *, struct kobject___110 *, struct bin_attribute___110 *, struct vm_area_struct___123 *);
};

struct sysfs_ops___110 {
	ssize_t (*show)(struct kobject___110 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___110 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___110;

struct kset___110 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___110 kobj;
	const struct kset_uevent_ops___110 *uevent_ops;
};

struct kobj_type___110 {
	void (*release)(struct kobject___110 *);
	const struct sysfs_ops___110 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___110 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___110 *);
	const void * (*namespace)(struct kobject___110 *);
	void (*get_ownership)(struct kobject___110 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___110 {
	int (* const filter)(struct kset___110 *, struct kobject___110 *);
	const char * (* const name)(struct kset___110 *, struct kobject___110 *);
	int (* const uevent)(struct kset___110 *, struct kobject___110 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___107 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___107 *);
	int (*get)(char *, const struct kernel_param___107 *);
	void (*free)(void *);
};

struct kparam_array___107;

struct kernel_param___107 {
	const char *name;
	struct module___108 *mod;
	const struct kernel_param_ops___107 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___107 *arr;
	};
};

struct kparam_array___107 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___107 *ops;
	void *elem;
};

struct module_attribute___107 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___107 *, struct module_kobject___107 *, char *);
	ssize_t (*store)(struct module_attribute___107 *, struct module_kobject___107 *, const char *, size_t);
	void (*setup)(struct module___108 *, const char *);
	int (*test)(struct module___108 *);
	void (*free)(struct module___108 *);
};

struct trace_event_class___57;

struct trace_event_call___57 {
	struct list_head list;
	struct trace_event_class___57 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___57 *, struct perf_event___63 *);
};

struct cftype___88;

struct cgroup_subsys___88 {
	struct cgroup_subsys_state___88 * (*css_alloc)(struct cgroup_subsys_state___88 *);
	int (*css_online)(struct cgroup_subsys_state___88 *);
	void (*css_offline)(struct cgroup_subsys_state___88 *);
	void (*css_released)(struct cgroup_subsys_state___88 *);
	void (*css_free)(struct cgroup_subsys_state___88 *);
	void (*css_reset)(struct cgroup_subsys_state___88 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___88 *, int);
	int (*css_extra_stat_show)(struct seq_file___105 *, struct cgroup_subsys_state___88 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___125 *, struct css_set___88 *);
	void (*cancel_fork)(struct task_struct___125 *, struct css_set___88 *);
	void (*fork)(struct task_struct___125 *);
	void (*exit)(struct task_struct___125 *);
	void (*release)(struct task_struct___125 *);
	void (*bind)(struct cgroup_subsys_state___88 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___88 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___88 *dfl_cftypes;
	struct cftype___88 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___88 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___88 *updated_children;
	struct cgroup___88 *updated_next;
};

struct cgroup_root___88 {
	struct kernfs_root___110 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___88 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___88 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___88 *ss;
	struct list_head node;
	struct kernfs_ops___110 *kf_ops;
	int (*open)(struct kernfs_open_file___110 *);
	void (*release)(struct kernfs_open_file___110 *);
	u64 (*read_u64)(struct cgroup_subsys_state___88 *, struct cftype___88 *);
	s64 (*read_s64)(struct cgroup_subsys_state___88 *, struct cftype___88 *);
	int (*seq_show)(struct seq_file___105 *, void *);
	void * (*seq_start)(struct seq_file___105 *, loff_t *);
	void * (*seq_next)(struct seq_file___105 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___105 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___88 *, struct cftype___88 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___88 *, struct cftype___88 *, s64);
	ssize_t (*write)(struct kernfs_open_file___110 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___110 *, struct poll_table_struct___81 *);
};

struct dev_pm_ops___90 {
	int (*prepare)(struct device___90 *);
	void (*complete)(struct device___90 *);
	int (*suspend)(struct device___90 *);
	int (*resume)(struct device___90 *);
	int (*freeze)(struct device___90 *);
	int (*thaw)(struct device___90 *);
	int (*poweroff)(struct device___90 *);
	int (*restore)(struct device___90 *);
	int (*suspend_late)(struct device___90 *);
	int (*resume_early)(struct device___90 *);
	int (*freeze_late)(struct device___90 *);
	int (*thaw_early)(struct device___90 *);
	int (*poweroff_late)(struct device___90 *);
	int (*restore_early)(struct device___90 *);
	int (*suspend_noirq)(struct device___90 *);
	int (*resume_noirq)(struct device___90 *);
	int (*freeze_noirq)(struct device___90 *);
	int (*thaw_noirq)(struct device___90 *);
	int (*poweroff_noirq)(struct device___90 *);
	int (*restore_noirq)(struct device___90 *);
	int (*runtime_suspend)(struct device___90 *);
	int (*runtime_resume)(struct device___90 *);
	int (*runtime_idle)(struct device___90 *);
};

struct wakeup_source___90 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___90 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___90 {
	struct dev_pm_ops___90 ops;
	int (*start)(struct device___90 *);
	void (*detach)(struct device___90 *, bool);
	int (*activate)(struct device___90 *);
	void (*sync)(struct device___90 *);
	void (*dismiss)(struct device___90 *);
};

struct bus_type___90 {
	const char *name;
	const char *dev_name;
	struct device___90 *dev_root;
	const struct attribute_group___110 **bus_groups;
	const struct attribute_group___110 **dev_groups;
	const struct attribute_group___110 **drv_groups;
	int (*match)(struct device___90 *, struct device_driver___90 *);
	int (*uevent)(struct device___90 *, struct kobj_uevent_env *);
	int (*probe)(struct device___90 *);
	void (*sync_state)(struct device___90 *);
	void (*remove)(struct device___90 *);
	void (*shutdown)(struct device___90 *);
	int (*online)(struct device___90 *);
	int (*offline)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	int (*num_vf)(struct device___90 *);
	int (*dma_configure)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___90 {
	const char *name;
	struct bus_type___90 *bus;
	struct module___108 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___90 *);
	void (*sync_state)(struct device___90 *);
	int (*remove)(struct device___90 *);
	void (*shutdown)(struct device___90 *);
	int (*suspend)(struct device___90 *, pm_message_t);
	int (*resume)(struct device___90 *);
	const struct attribute_group___110 **groups;
	const struct attribute_group___110 **dev_groups;
	const struct dev_pm_ops___90 *pm;
	void (*coredump)(struct device___90 *);
	struct driver_private *p;
};

struct device_type___90 {
	const char *name;
	const struct attribute_group___110 **groups;
	int (*uevent)(struct device___90 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___90 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___90 *);
	const struct dev_pm_ops___90 *pm;
};

struct class___90 {
	const char *name;
	struct module___108 *owner;
	const struct attribute_group___110 **class_groups;
	const struct attribute_group___110 **dev_groups;
	struct kobject___110 *dev_kobj;
	int (*dev_uevent)(struct device___90 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___90 *, umode_t *);
	void (*class_release)(struct class___90 *);
	void (*dev_release)(struct device___90 *);
	int (*shutdown_pre)(struct device___90 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___90 *);
	void (*get_ownership)(struct device___90 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___90 *pm;
	struct subsys_private *p;
};

struct block_device_operations___54;

struct gendisk___54 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___55 *part0;
	const struct block_device_operations___54 *fops;
	struct request_queue___54 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___52 *bdi;
	struct kobject___110 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___110 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___54 {
	struct bio___54 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___65 *bip_vec;
	struct bio_vec___65 bip_inline_vecs[0];
};

struct blkcg___52;

struct blkg_policy_data___52;

struct blkcg_gq___52 {
	struct request_queue___54 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___52 *blkcg;
	struct blkcg_gq___52 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___52 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___54 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___54(struct request___54 *);

typedef void integrity_complete_fn___54(struct request___54 *, unsigned int);

struct blk_integrity_profile___54 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___54 *prepare_fn;
	integrity_complete_fn___54 *complete_fn;
	const char *name;
};

struct block_device_operations___54 {
	blk_qc_t (*submit_bio)(struct bio___54 *);
	int (*open)(struct block_device___55 *, fmode_t);
	void (*release)(struct gendisk___54 *, fmode_t);
	int (*rw_page)(struct block_device___55 *, sector_t, struct page___123 *, unsigned int);
	int (*ioctl)(struct block_device___55 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___55 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___54 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___54 *);
	int (*getgeo)(struct block_device___55 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___55 *, bool);
	void (*swap_slot_free_notify)(struct block_device___55 *, long unsigned int);
	int (*report_zones)(struct gendisk___54 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___54 *, umode_t *);
	struct module___108 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___54 *, sector_t *);
};

typedef void rq_end_io_fn___54(struct request___54 *, blk_status_t);

struct request___54 {
	struct request_queue___54 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___52 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___54 *bio;
	struct bio___54 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___65 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___54 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___54 *saved_end_io;
		} flush;
	};
	struct gendisk___54 *rq_disk;
	struct block_device___55 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___54 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___52 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___54 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___110 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___118 *debugfs_dir;
	struct dentry___118 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___54;

struct elevator_mq_ops___54 {
	int (*init_sched)(struct request_queue___54 *, struct elevator_type___54 *);
	void (*exit_sched)(struct elevator_queue___54 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___52 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___52 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___52 *);
	bool (*allow_merge)(struct request_queue___54 *, struct request___54 *, struct bio___54 *);
	bool (*bio_merge)(struct request_queue___54 *, struct bio___54 *, unsigned int);
	int (*request_merge)(struct request_queue___54 *, struct request___54 **, struct bio___54 *);
	void (*request_merged)(struct request_queue___54 *, struct request___54 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___54 *, struct request___54 *, struct request___54 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___54 *);
	void (*finish_request)(struct request___54 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___52 *, struct list_head *, bool);
	struct request___54 * (*dispatch_request)(struct blk_mq_hw_ctx___52 *);
	bool (*has_work)(struct blk_mq_hw_ctx___52 *);
	void (*completed_request)(struct request___54 *, u64);
	void (*requeue_request)(struct request___54 *);
	struct request___54 * (*former_request)(struct request_queue___54 *, struct request___54 *);
	struct request___54 * (*next_request)(struct request_queue___54 *, struct request___54 *);
	void (*init_icq)(struct io_cq___54 *);
	void (*exit_icq)(struct io_cq___54 *);
};

struct elv_fs_entry___54;

struct elevator_type___54 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___54 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___54 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___108 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___54 {
	struct elevator_type___54 *type;
	void *elevator_data;
	struct kobject___110 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___54 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___54 *, char *);
	ssize_t (*store)(struct elevator_queue___54 *, const char *, size_t);
};

struct blk_mq_queue_data___52;

struct blk_mq_ops___52 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___52 *, const struct blk_mq_queue_data___52 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___52 *);
	int (*get_budget)(struct request_queue___54 *);
	void (*put_budget)(struct request_queue___54 *, int);
	void (*set_rq_budget_token)(struct request___54 *, int);
	int (*get_rq_budget_token)(struct request___54 *);
	enum blk_eh_timer_return (*timeout)(struct request___54 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___52 *);
	void (*complete)(struct request___54 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___52 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___52 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___52 *, struct request___54 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___52 *, struct request___54 *, unsigned int);
	void (*initialize_rq_fn)(struct request___54 *);
	void (*cleanup_rq)(struct request___54 *);
	bool (*busy)(struct request_queue___54 *);
	int (*map_queues)(struct blk_mq_tag_set___52 *);
	void (*show_rq)(struct seq_file___105 *, struct request___54 *);
};

struct blk_mq_tag_set___52 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___52 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___52 {
	struct request___54 *rq;
	bool last;
};

struct blkcg_policy_data___52;

struct blkcg___52 {
	struct cgroup_subsys_state___88 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___52 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___52 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___52 {
	struct blkcg___52 *blkcg;
	int plid;
};

struct blkg_policy_data___52 {
	struct blkcg_gq___52 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___46 {
	struct mem_cgroup___46 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___46 {
	struct lruvec___52 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___46 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___46 *memcg;
};

struct obj_cgroup___46 {
	struct percpu_ref refcnt;
	struct mem_cgroup___46 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct perf_cpu_context___63;

struct perf_output_handle___63;

struct pmu___63 {
	struct list_head entry;
	struct module___108 *module;
	struct device___90 *dev;
	const struct attribute_group___110 **attr_groups;
	const struct attribute_group___110 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___63 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___63 *);
	void (*pmu_disable)(struct pmu___63 *);
	int (*event_init)(struct perf_event___63 *);
	void (*event_mapped)(struct perf_event___63 *, struct mm_struct___124 *);
	void (*event_unmapped)(struct perf_event___63 *, struct mm_struct___124 *);
	int (*add)(struct perf_event___63 *, int);
	void (*del)(struct perf_event___63 *, int);
	void (*start)(struct perf_event___63 *, int);
	void (*stop)(struct perf_event___63 *, int);
	void (*read)(struct perf_event___63 *);
	void (*start_txn)(struct pmu___63 *, unsigned int);
	int (*commit_txn)(struct pmu___63 *);
	void (*cancel_txn)(struct pmu___63 *);
	int (*event_idx)(struct perf_event___63 *);
	void (*sched_task)(struct perf_event_context___63 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___63 *, struct perf_event_context___63 *);
	void * (*setup_aux)(struct perf_event___63 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___63 *, struct perf_output_handle___63 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___63 *);
	int (*aux_output_match)(struct perf_event___63 *);
	int (*filter_match)(struct perf_event___63 *);
	int (*check_period)(struct perf_event___63 *, u64);
};

struct perf_cpu_context___63 {
	struct perf_event_context___63 ctx;
	struct perf_event_context___63 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___63 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___63 **heap;
	struct perf_event___63 *heap_default[2];
};

struct perf_output_handle___63 {
	struct perf_event___63 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___63 {
	struct cgroup_subsys_state___88 css;
	struct perf_cgroup_info *info;
};

struct linux_binprm___18 {
	struct vm_area_struct___123 *vma;
	long unsigned int vma_pages;
	struct mm_struct___124 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___118 *executable;
	struct file___118 *interpreter;
	struct file___118 *file;
	struct cred___14 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct core_vma_metadata___4;

struct coredump_params___17 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___118 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata___4 *vma_meta;
};

struct core_vma_metadata___4 {
	long unsigned int start;
	long unsigned int end;
	long unsigned int flags;
	long unsigned int dump_size;
	long unsigned int pgoff;
	struct file___118 *file;
};

struct trace_event_fields___57 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___57 *);
	};
};

struct trace_event_class___57 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___57 *, enum trace_reg, void *);
	struct trace_event_fields___57 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___57 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___57 *);
};

struct pipe_buf_operations___40;

struct pipe_buffer___40 {
	struct page___123 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___40 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___40 {
	int (*confirm)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
	void (*release)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
	bool (*try_steal)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
	bool (*get)(struct pipe_inode_info___40 *, struct pipe_buffer___40 *);
};

struct core_name {
	char *corename;
	int used;
	int size;
};

struct dentry___119;

struct super_block___119;

struct module___109;

struct file_system_type___119 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___119 * (*mount)(struct file_system_type___119 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___119 *);
	struct module___109 *owner;
	struct file_system_type___119 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___119;

struct kiocb___119;

struct poll_table_struct___82;

struct vm_area_struct___124;

struct inode___119;

struct file_lock___119;

struct page___124;

struct seq_file___106;

struct file_operations___119 {
	struct module___109 *owner;
	loff_t (*llseek)(struct file___119 *, loff_t, int);
	ssize_t (*read)(struct file___119 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___119 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___119 *, struct iov_iter___67 *);
	ssize_t (*write_iter)(struct kiocb___119 *, struct iov_iter___67 *);
	int (*iopoll)(struct kiocb___119 *, bool);
	int (*iterate)(struct file___119 *, struct dir_context *);
	int (*iterate_shared)(struct file___119 *, struct dir_context *);
	__poll_t (*poll)(struct file___119 *, struct poll_table_struct___82 *);
	long int (*unlocked_ioctl)(struct file___119 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___119 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___119 *, struct vm_area_struct___124 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___119 *, struct file___119 *);
	int (*flush)(struct file___119 *, fl_owner_t);
	int (*release)(struct inode___119 *, struct file___119 *);
	int (*fsync)(struct file___119 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___119 *, int);
	int (*lock)(struct file___119 *, int, struct file_lock___119 *);
	ssize_t (*sendpage)(struct file___119 *, struct page___124 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___119 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___119 *, long unsigned int);
	int (*flock)(struct file___119 *, int, struct file_lock___119 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___119 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___119 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___119 *, long int, struct file_lock___119 **, void **);
	long int (*fallocate)(struct file___119 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___106 *, struct file___119 *);
	ssize_t (*copy_file_range)(struct file___119 *, loff_t, struct file___119 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___119 *, loff_t, struct file___119 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___119 *, loff_t, loff_t, int);
};

struct vmacache___124 {
	u64 seqnum;
	struct vm_area_struct___124 *vmas[4];
};

struct page_frag___124 {
	struct page___124 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___64;

struct debug_info___64 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___64 *hbp_break[16];
	struct perf_event___64 *hbp_watch[16];
};

struct thread_struct___64 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___64 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___125;

struct pid___104;

struct fs_struct___18;

struct nsproxy___110;

struct signal_struct___120;

struct css_set___89;

struct perf_event_context___64;

struct vm_struct___109;

struct task_struct___126 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___126 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___125 *mm;
	struct mm_struct___125 *active_mm;
	struct vmacache___124 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___126 *real_parent;
	struct task_struct___126 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___126 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___104 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___14 *ptracer_cred;
	const struct cred___14 *real_cred;
	const struct cred___14 *cred;
	struct key *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___18 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___110 *nsproxy;
	struct signal_struct___120 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___126 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___54 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___89 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___64 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___124 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___126 *oom_reaper_list;
	struct vm_struct___109 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___111;

struct kobj_type___111;

struct kernfs_node___111;

struct kobject___111 {
	const char *name;
	struct list_head entry;
	struct kobject___111 *parent;
	struct kset___111 *kset;
	struct kobj_type___111 *ktype;
	struct kernfs_node___111 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___108 {
	struct kobject___111 kobj;
	struct module___109 *mod;
	struct kobject___111 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___108 {
	struct module___109 *mod;
	struct latch_tree_node node;
};

struct module_layout___108 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___108 mtn;
};

struct module_attribute___108;

struct kernel_param___108;

struct trace_event_call___58;

struct module___109 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___108 mkobj;
	struct module_attribute___108 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___111 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___108 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___108 core_layout;
	struct module_layout___108 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___58 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___64 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___126 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___64)(struct perf_event___64 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___64;

struct fasync_struct___119;

struct pid_namespace___104;

struct perf_cgroup___64;

struct perf_event___64 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___64 *group_leader;
	struct pmu___64 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___64 hw;
	struct perf_event_context___64 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___64 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___126 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___119 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___64 *aux_event;
	void (*destroy)(struct perf_event___64 *);
	struct callback_head callback_head;
	struct pid_namespace___104 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___64 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___64 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___58 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___64 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___119;

struct dentry___119 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___119 *d_parent;
	struct qstr d_name;
	struct inode___119 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___119 *d_op;
	struct super_block___119 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___119;

struct address_space___119 {
	struct inode___119 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___119 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___119;

struct inode___119 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___119 *i_op;
	struct super_block___119 *i_sb;
	struct address_space___119 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___119 *i_fop;
		void (*free_inode)(struct inode___119 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___119 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___119;

struct path___119;

struct dentry_operations___119 {
	int (*d_revalidate)(struct dentry___119 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___119 *, unsigned int);
	int (*d_hash)(const struct dentry___119 *, struct qstr *);
	int (*d_compare)(const struct dentry___119 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___119 *);
	int (*d_init)(struct dentry___119 *);
	void (*d_release)(struct dentry___119 *);
	void (*d_prune)(struct dentry___119 *);
	void (*d_iput)(struct dentry___119 *, struct inode___119 *);
	char * (*d_dname)(struct dentry___119 *, char *, int);
	struct vfsmount___119 * (*d_automount)(struct path___119 *);
	int (*d_manage)(const struct path___119 *, bool);
	struct dentry___119 * (*d_real)(struct dentry___119 *, const struct inode___119 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___119;

struct mem_dqinfo___119 {
	struct quota_format_type___119 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___119;

struct quota_info___119 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___119 *files[3];
	struct mem_dqinfo___119 info[3];
	const struct quota_format_ops___119 *ops[3];
};

struct rcuwait___120 {
	struct task_struct___126 *task;
};

struct percpu_rw_semaphore___120 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___120 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___119 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___120 rw_sem[3];
};

struct super_operations___119;

struct dquot_operations___119;

struct quotactl_ops___119;

struct export_operations___9;

struct super_block___119 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___119 *s_type;
	const struct super_operations___119 *s_op;
	const struct dquot_operations___119 *dq_op;
	const struct quotactl_ops___119 *s_qcop;
	const struct export_operations___9 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___119 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___119 s_dquot;
	struct sb_writers___119 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___119 *s_d_op;
	int cleancache_poolid;
	struct shrinker___46 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___4 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___119 {
	struct dentry___119 *mnt_root;
	struct super_block___119 *mnt_sb;
	int mnt_flags;
	struct user_namespace___4 *mnt_userns;
};

struct path___119 {
	struct vfsmount___119 *mnt;
	struct dentry___119 *dentry;
};

struct upid___104 {
	int nr;
	struct pid_namespace___104 *ns;
};

struct pid_namespace___104 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___126 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___104 *parent;
	struct fs_pin *bacct;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	int reboot;
	struct ns_common___5 ns;
};

struct pid___104 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___104 numbers[1];
};

typedef struct page___124 *pgtable_t___124;

struct dev_pagemap___117;

struct page___124 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___119 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___124 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___124 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___125 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___117 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___117;

struct vm_area_struct___124 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___124 *vm_next;
	struct vm_area_struct___124 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___125 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___117 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___119 *vm_file;
	struct file___119 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___120 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___126 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___126 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___104 *pids[4];
	struct pid___104 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___125 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___124;

struct mm_struct___125 {
	struct {
		struct vm_area_struct___124 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___119 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___124 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___126 *owner;
		struct user_namespace___4 *user_ns;
		struct file___119 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fs_struct___18 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___119 root;
	struct path___119 pwd;
};

struct mnt_namespace___13;

struct cgroup_namespace___89;

struct nsproxy___110 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___13 *mnt_ns;
	struct pid_namespace___104 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___89 *cgroup_ns;
};

struct cgroup_subsys_state___89;

struct cgroup___89;

struct css_set___89 {
	struct cgroup_subsys_state___89 *subsys[14];
	refcount_t refcount;
	struct css_set___89 *dom_cset;
	struct cgroup___89 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___89 *mg_src_cgrp;
	struct cgroup___89 *mg_dst_cgrp;
	struct css_set___89 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___64 {
	struct pmu___64 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___126 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___64 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___109 {
	struct vm_struct___109 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___124 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___117;

struct dev_pagemap___117 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___117 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___104 {
	rwlock_t lock;
	struct pid___104 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___119 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___119 f_path;
	struct inode___119 *f_inode;
	const struct file_operations___119 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___104 f_owner;
	const struct cred___14 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___119 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___117;

struct vm_operations_struct___117 {
	void (*open)(struct vm_area_struct___124 *);
	void (*close)(struct vm_area_struct___124 *);
	int (*may_split)(struct vm_area_struct___124 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___124 *);
	int (*mprotect)(struct vm_area_struct___124 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___117 *);
	vm_fault_t (*huge_fault)(struct vm_fault___117 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___117 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___124 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___117 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___117 *);
	int (*access)(struct vm_area_struct___124 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___124 *);
	int (*set_policy)(struct vm_area_struct___124 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___124 *, long unsigned int);
	struct page___124 * (*find_special_page)(struct vm_area_struct___124 *, long unsigned int);
};

struct core_thread___124 {
	struct task_struct___126 *task;
	struct core_thread___124 *next;
};

struct core_state___124 {
	atomic_t nr_threads;
	struct core_thread___124 dumper;
	struct completion startup;
};

struct vm_fault___117 {
	const struct {
		struct vm_area_struct___124 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___124 *cow_page;
	struct page___124 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___124 prealloc_pte;
};

struct cgroup_subsys___89;

struct cgroup_subsys_state___89 {
	struct cgroup___89 *cgroup;
	struct cgroup_subsys___89 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___89 *parent;
};

struct cgroup_file___89 {
	struct kernfs_node___111 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___89 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___126 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___89;

struct cgroup_rstat_cpu___89;

struct cgroup___89 {
	struct cgroup_subsys_state___89 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___111 *kn;
	struct cgroup_file___89 procs_file;
	struct cgroup_file___89 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___89 *subsys[14];
	struct cgroup_root___89 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___89 *dom_cgrp;
	struct cgroup___89 *old_dom_cgrp;
	struct cgroup_rstat_cpu___89 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___89 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___119 {
	struct file___119 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___119 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___53 *ki_waitq;
	};
};

struct iattr___119 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___119 *ia_file;
};

struct dquot___119 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___119 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___119 {
	int qf_fmt_id;
	const struct quota_format_ops___119 *qf_ops;
	struct module___109 *qf_owner;
	struct quota_format_type___119 *qf_next;
};

struct quota_format_ops___119 {
	int (*check_quota_file)(struct super_block___119 *, int);
	int (*read_file_info)(struct super_block___119 *, int);
	int (*write_file_info)(struct super_block___119 *, int);
	int (*free_file_info)(struct super_block___119 *, int);
	int (*read_dqblk)(struct dquot___119 *);
	int (*commit_dqblk)(struct dquot___119 *);
	int (*release_dqblk)(struct dquot___119 *);
	int (*get_next_id)(struct super_block___119 *, struct kqid *);
};

struct dquot_operations___119 {
	int (*write_dquot)(struct dquot___119 *);
	struct dquot___119 * (*alloc_dquot)(struct super_block___119 *, int);
	void (*destroy_dquot)(struct dquot___119 *);
	int (*acquire_dquot)(struct dquot___119 *);
	int (*release_dquot)(struct dquot___119 *);
	int (*mark_dirty)(struct dquot___119 *);
	int (*write_info)(struct super_block___119 *, int);
	qsize_t * (*get_reserved_space)(struct inode___119 *);
	int (*get_projid)(struct inode___119 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___119 *, qsize_t *);
	int (*get_next_id)(struct super_block___119 *, struct kqid *);
};

struct quotactl_ops___119 {
	int (*quota_on)(struct super_block___119 *, int, int, const struct path___119 *);
	int (*quota_off)(struct super_block___119 *, int);
	int (*quota_enable)(struct super_block___119 *, unsigned int);
	int (*quota_disable)(struct super_block___119 *, unsigned int);
	int (*quota_sync)(struct super_block___119 *, int);
	int (*set_info)(struct super_block___119 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___119 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___119 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___119 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___119 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___119 *, unsigned int);
};

struct address_space_operations___119 {
	int (*writepage)(struct page___124 *, struct writeback_control___3 *);
	int (*readpage)(struct file___119 *, struct page___124 *);
	int (*writepages)(struct address_space___119 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___124 *);
	int (*readpages)(struct file___119 *, struct address_space___119 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___119 *, struct address_space___119 *, loff_t, unsigned int, unsigned int, struct page___124 **, void **);
	int (*write_end)(struct file___119 *, struct address_space___119 *, loff_t, unsigned int, unsigned int, struct page___124 *, void *);
	sector_t (*bmap)(struct address_space___119 *, sector_t);
	void (*invalidatepage)(struct page___124 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___124 *, gfp_t);
	void (*freepage)(struct page___124 *);
	ssize_t (*direct_IO)(struct kiocb___119 *, struct iov_iter___67 *);
	int (*migratepage)(struct address_space___119 *, struct page___124 *, struct page___124 *, enum migrate_mode);
	bool (*isolate_page)(struct page___124 *, isolate_mode_t);
	void (*putback_page)(struct page___124 *);
	int (*launder_page)(struct page___124 *);
	int (*is_partially_uptodate)(struct page___124 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___124 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___119 *, struct page___124 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___119 *, sector_t *);
	void (*swap_deactivate)(struct file___119 *);
};

struct inode_operations___119 {
	struct dentry___119 * (*lookup)(struct inode___119 *, struct dentry___119 *, unsigned int);
	const char * (*get_link)(struct dentry___119 *, struct inode___119 *, struct delayed_call *);
	int (*permission)(struct user_namespace___4 *, struct inode___119 *, int);
	struct posix_acl * (*get_acl)(struct inode___119 *, int, bool);
	int (*readlink)(struct dentry___119 *, char *, int);
	int (*create)(struct user_namespace___4 *, struct inode___119 *, struct dentry___119 *, umode_t, bool);
	int (*link)(struct dentry___119 *, struct inode___119 *, struct dentry___119 *);
	int (*unlink)(struct inode___119 *, struct dentry___119 *);
	int (*symlink)(struct user_namespace___4 *, struct inode___119 *, struct dentry___119 *, const char *);
	int (*mkdir)(struct user_namespace___4 *, struct inode___119 *, struct dentry___119 *, umode_t);
	int (*rmdir)(struct inode___119 *, struct dentry___119 *);
	int (*mknod)(struct user_namespace___4 *, struct inode___119 *, struct dentry___119 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___4 *, struct inode___119 *, struct dentry___119 *, struct inode___119 *, struct dentry___119 *, unsigned int);
	int (*setattr)(struct user_namespace___4 *, struct dentry___119 *, struct iattr___119 *);
	int (*getattr)(struct user_namespace___4 *, const struct path___119 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___119 *, char *, size_t);
	int (*fiemap)(struct inode___119 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___119 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___119 *, struct dentry___119 *, struct file___119 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___4 *, struct inode___119 *, struct dentry___119 *, umode_t);
	int (*set_acl)(struct user_namespace___4 *, struct inode___119 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___4 *, struct dentry___119 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___119 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___119 {
	void (*fl_copy_lock)(struct file_lock___119 *, struct file_lock___119 *);
	void (*fl_release_private)(struct file_lock___119 *);
};

struct lock_manager_operations___119;

struct file_lock___119 {
	struct file_lock___119 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___119 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___119 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___119 *fl_ops;
	const struct lock_manager_operations___119 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___119 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___119 *);
	int (*lm_grant)(struct file_lock___119 *, int);
	bool (*lm_break)(struct file_lock___119 *);
	int (*lm_change)(struct file_lock___119 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___119 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___119 *);
};

struct fasync_struct___119 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___119 *fa_next;
	struct file___119 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___119 {
	struct inode___119 * (*alloc_inode)(struct super_block___119 *);
	void (*destroy_inode)(struct inode___119 *);
	void (*free_inode)(struct inode___119 *);
	void (*dirty_inode)(struct inode___119 *, int);
	int (*write_inode)(struct inode___119 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___119 *);
	void (*evict_inode)(struct inode___119 *);
	void (*put_super)(struct super_block___119 *);
	int (*sync_fs)(struct super_block___119 *, int);
	int (*freeze_super)(struct super_block___119 *);
	int (*freeze_fs)(struct super_block___119 *);
	int (*thaw_super)(struct super_block___119 *);
	int (*unfreeze_fs)(struct super_block___119 *);
	int (*statfs)(struct dentry___119 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___119 *, int *, char *);
	void (*umount_begin)(struct super_block___119 *);
	int (*show_options)(struct seq_file___106 *, struct dentry___119 *);
	int (*show_devname)(struct seq_file___106 *, struct dentry___119 *);
	int (*show_path)(struct seq_file___106 *, struct dentry___119 *);
	int (*show_stats)(struct seq_file___106 *, struct dentry___119 *);
	ssize_t (*quota_read)(struct super_block___119 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___119 *, int, const char *, size_t, loff_t);
	struct dquot___119 ** (*get_dquots)(struct inode___119 *);
	long int (*nr_cached_objects)(struct super_block___119 *, struct shrink_control___46 *);
	long int (*free_cached_objects)(struct super_block___119 *, struct shrink_control___46 *);
	struct file___119 * (*real_loop)(struct file___119 *);
};

struct export_operations___9 {
	int (*encode_fh)(struct inode___119 *, __u32 *, int *, struct inode___119 *);
	struct dentry___119 * (*fh_to_dentry)(struct super_block___119 *, struct fid *, int, int);
	struct dentry___119 * (*fh_to_parent)(struct super_block___119 *, struct fid *, int, int);
	int (*get_name)(struct dentry___119 *, char *, struct dentry___119 *);
	struct dentry___119 * (*get_parent)(struct dentry___119 *);
	int (*commit_metadata)(struct inode___119 *);
	int (*get_uuid)(struct super_block___119 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___119 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___119 *, struct iomap *, int, struct iattr___119 *);
	u64 (*fetch_iversion)(struct inode___119 *);
	long unsigned int flags;
};

typedef void (*poll_queue_proc___82)(struct file___119 *, wait_queue_head_t *, struct poll_table_struct___82 *);

struct poll_table_struct___82 {
	poll_queue_proc___82 _qproc;
	__poll_t _key;
};

struct seq_operations___106;

struct seq_file___106 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___106 *op;
	int poll_event;
	const struct file___119 *file;
	void *private;
};

struct kernfs_root___111;

struct kernfs_elem_dir___111 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___111 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___111;

struct kernfs_root___111 {
	struct kernfs_node___111 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___111 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___111 {
	struct kernfs_node___111 *target_kn;
};

struct kernfs_ops___111;

struct kernfs_elem_attr___111 {
	const struct kernfs_ops___111 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___111 *notify_next;
};

struct kernfs_node___111 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___111 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___111 dir;
		struct kernfs_elem_symlink___111 symlink;
		struct kernfs_elem_attr___111 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___111;

struct kernfs_ops___111 {
	int (*open)(struct kernfs_open_file___111 *);
	void (*release)(struct kernfs_open_file___111 *);
	int (*seq_show)(struct seq_file___106 *, void *);
	void * (*seq_start)(struct seq_file___106 *, loff_t *);
	void * (*seq_next)(struct seq_file___106 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___106 *, void *);
	ssize_t (*read)(struct kernfs_open_file___111 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___111 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___111 *, struct poll_table_struct___82 *);
	int (*mmap)(struct kernfs_open_file___111 *, struct vm_area_struct___124 *);
};

struct kernfs_syscall_ops___111 {
	int (*show_options)(struct seq_file___106 *, struct kernfs_root___111 *);
	int (*mkdir)(struct kernfs_node___111 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___111 *);
	int (*rename)(struct kernfs_node___111 *, struct kernfs_node___111 *, const char *);
	int (*show_path)(struct seq_file___106 *, struct kernfs_node___111 *, struct kernfs_root___111 *);
};

struct kernfs_open_file___111 {
	struct kernfs_node___111 *kn;
	struct file___119 *file;
	struct seq_file___106 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___117 *vm_ops;
};

struct bin_attribute___111;

struct attribute_group___111 {
	const char *name;
	umode_t (*is_visible)(struct kobject___111 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___111 *, struct bin_attribute___111 *, int);
	struct attribute **attrs;
	struct bin_attribute___111 **bin_attrs;
};

struct bin_attribute___111 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___119 * (*f_mapping)();
	ssize_t (*read)(struct file___119 *, struct kobject___111 *, struct bin_attribute___111 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___119 *, struct kobject___111 *, struct bin_attribute___111 *, char *, loff_t, size_t);
	int (*mmap)(struct file___119 *, struct kobject___111 *, struct bin_attribute___111 *, struct vm_area_struct___124 *);
};

struct sysfs_ops___111 {
	ssize_t (*show)(struct kobject___111 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___111 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___111;

struct kset___111 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___111 kobj;
	const struct kset_uevent_ops___111 *uevent_ops;
};

struct kobj_type___111 {
	void (*release)(struct kobject___111 *);
	const struct sysfs_ops___111 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___111 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___111 *);
	const void * (*namespace)(struct kobject___111 *);
	void (*get_ownership)(struct kobject___111 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___111 {
	int (* const filter)(struct kset___111 *, struct kobject___111 *);
	const char * (* const name)(struct kset___111 *, struct kobject___111 *);
	int (* const uevent)(struct kset___111 *, struct kobject___111 *, struct kobj_uevent_env *);
};

struct wakeup_source___91;

struct device___91;

struct dev_pm_info___91 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___91 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___91 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___91;

struct bus_type___91;

struct device_driver___91;

struct dev_pm_domain___91;

struct fwnode_handle___91;

struct class___91;

struct device___91 {
	struct kobject___111 kobj;
	struct device___91 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___91 *type;
	struct bus_type___91 *bus;
	struct device_driver___91 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___91 power;
	struct dev_pm_domain___91 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___91 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___91 *class;
	const struct attribute_group___111 **groups;
	void (*release)(struct device___91 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___91 {
	int (*prepare)(struct device___91 *);
	void (*complete)(struct device___91 *);
	int (*suspend)(struct device___91 *);
	int (*resume)(struct device___91 *);
	int (*freeze)(struct device___91 *);
	int (*thaw)(struct device___91 *);
	int (*poweroff)(struct device___91 *);
	int (*restore)(struct device___91 *);
	int (*suspend_late)(struct device___91 *);
	int (*resume_early)(struct device___91 *);
	int (*freeze_late)(struct device___91 *);
	int (*thaw_early)(struct device___91 *);
	int (*poweroff_late)(struct device___91 *);
	int (*restore_early)(struct device___91 *);
	int (*suspend_noirq)(struct device___91 *);
	int (*resume_noirq)(struct device___91 *);
	int (*freeze_noirq)(struct device___91 *);
	int (*thaw_noirq)(struct device___91 *);
	int (*poweroff_noirq)(struct device___91 *);
	int (*restore_noirq)(struct device___91 *);
	int (*runtime_suspend)(struct device___91 *);
	int (*runtime_resume)(struct device___91 *);
	int (*runtime_idle)(struct device___91 *);
};

struct wakeup_source___91 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___91 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___91 {
	struct dev_pm_ops___91 ops;
	int (*start)(struct device___91 *);
	void (*detach)(struct device___91 *, bool);
	int (*activate)(struct device___91 *);
	void (*sync)(struct device___91 *);
	void (*dismiss)(struct device___91 *);
};

struct bus_type___91 {
	const char *name;
	const char *dev_name;
	struct device___91 *dev_root;
	const struct attribute_group___111 **bus_groups;
	const struct attribute_group___111 **dev_groups;
	const struct attribute_group___111 **drv_groups;
	int (*match)(struct device___91 *, struct device_driver___91 *);
	int (*uevent)(struct device___91 *, struct kobj_uevent_env *);
	int (*probe)(struct device___91 *);
	void (*sync_state)(struct device___91 *);
	void (*remove)(struct device___91 *);
	void (*shutdown)(struct device___91 *);
	int (*online)(struct device___91 *);
	int (*offline)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	int (*num_vf)(struct device___91 *);
	int (*dma_configure)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___91 {
	const char *name;
	struct bus_type___91 *bus;
	struct module___109 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___91 *);
	void (*sync_state)(struct device___91 *);
	int (*remove)(struct device___91 *);
	void (*shutdown)(struct device___91 *);
	int (*suspend)(struct device___91 *, pm_message_t);
	int (*resume)(struct device___91 *);
	const struct attribute_group___111 **groups;
	const struct attribute_group___111 **dev_groups;
	const struct dev_pm_ops___91 *pm;
	void (*coredump)(struct device___91 *);
	struct driver_private *p;
};

struct device_type___91 {
	const char *name;
	const struct attribute_group___111 **groups;
	int (*uevent)(struct device___91 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___91 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___91 *);
	const struct dev_pm_ops___91 *pm;
};

struct class___91 {
	const char *name;
	struct module___109 *owner;
	const struct attribute_group___111 **class_groups;
	const struct attribute_group___111 **dev_groups;
	struct kobject___111 *dev_kobj;
	int (*dev_uevent)(struct device___91 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___91 *, umode_t *);
	void (*class_release)(struct class___91 *);
	void (*dev_release)(struct device___91 *);
	int (*shutdown_pre)(struct device___91 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___91 *);
	void (*get_ownership)(struct device___91 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___91 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___91;

struct fwnode_handle___91 {
	struct fwnode_handle___91 *secondary;
	const struct fwnode_operations___91 *ops;
	struct device___91 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___117 {
	void (*page_free)(struct page___124 *);
	void (*kill)(struct dev_pagemap___117 *);
	void (*cleanup)(struct dev_pagemap___117 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___117 *);
};

struct seq_operations___106 {
	void * (*start)(struct seq_file___106 *, loff_t *);
	void (*stop)(struct seq_file___106 *, void *);
	void * (*next)(struct seq_file___106 *, void *, loff_t *);
	int (*show)(struct seq_file___106 *, void *);
};

struct fwnode_reference_args___91;

struct fwnode_endpoint___91;

struct fwnode_operations___91 {
	struct fwnode_handle___91 * (*get)(struct fwnode_handle___91 *);
	void (*put)(struct fwnode_handle___91 *);
	bool (*device_is_available)(const struct fwnode_handle___91 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___91 *, const struct device___91 *);
	bool (*property_present)(const struct fwnode_handle___91 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___91 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___91 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___91 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*get_parent)(const struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*get_next_child_node)(const struct fwnode_handle___91 *, struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*get_named_child_node)(const struct fwnode_handle___91 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___91 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___91 *);
	struct fwnode_handle___91 * (*graph_get_next_endpoint)(const struct fwnode_handle___91 *, struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*graph_get_remote_endpoint)(const struct fwnode_handle___91 *);
	struct fwnode_handle___91 * (*graph_get_port_parent)(struct fwnode_handle___91 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___91 *, struct fwnode_endpoint___91 *);
	int (*add_links)(struct fwnode_handle___91 *);
};

struct fwnode_endpoint___91 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___91 *local_fwnode;
};

struct fwnode_reference_args___91 {
	struct fwnode_handle___91 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct mount___13;

struct mnt_namespace___13 {
	struct ns_common___5 ns;
	struct mount___13 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct cgroup_namespace___89 {
	struct ns_common___5 ns;
	struct user_namespace___4 *user_ns;
	struct ucounts___4 *ucounts;
	struct css_set___89 *root_cset;
};

struct kernel_param_ops___108 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___108 *);
	int (*get)(char *, const struct kernel_param___108 *);
	void (*free)(void *);
};

struct kparam_array___108;

struct kernel_param___108 {
	const char *name;
	struct module___109 *mod;
	const struct kernel_param_ops___108 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___108 *arr;
	};
};

struct kparam_array___108 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___108 *ops;
	void *elem;
};

struct module_attribute___108 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___108 *, struct module_kobject___108 *, char *);
	ssize_t (*store)(struct module_attribute___108 *, struct module_kobject___108 *, const char *, size_t);
	void (*setup)(struct module___109 *, const char *);
	int (*test)(struct module___109 *);
	void (*free)(struct module___109 *);
};

struct trace_event_class___58;

struct trace_event_call___58 {
	struct list_head list;
	struct trace_event_class___58 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___58 *, struct perf_event___64 *);
};

struct fd___25 {
	struct file___119 *file;
	unsigned int flags;
};

struct cftype___89;

struct cgroup_subsys___89 {
	struct cgroup_subsys_state___89 * (*css_alloc)(struct cgroup_subsys_state___89 *);
	int (*css_online)(struct cgroup_subsys_state___89 *);
	void (*css_offline)(struct cgroup_subsys_state___89 *);
	void (*css_released)(struct cgroup_subsys_state___89 *);
	void (*css_free)(struct cgroup_subsys_state___89 *);
	void (*css_reset)(struct cgroup_subsys_state___89 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___89 *, int);
	int (*css_extra_stat_show)(struct seq_file___106 *, struct cgroup_subsys_state___89 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___126 *, struct css_set___89 *);
	void (*cancel_fork)(struct task_struct___126 *, struct css_set___89 *);
	void (*fork)(struct task_struct___126 *);
	void (*exit)(struct task_struct___126 *);
	void (*release)(struct task_struct___126 *);
	void (*bind)(struct cgroup_subsys_state___89 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___89 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___89 *dfl_cftypes;
	struct cftype___89 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___89 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___89 *updated_children;
	struct cgroup___89 *updated_next;
};

struct cgroup_root___89 {
	struct kernfs_root___111 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___89 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___89 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___89 *ss;
	struct list_head node;
	struct kernfs_ops___111 *kf_ops;
	int (*open)(struct kernfs_open_file___111 *);
	void (*release)(struct kernfs_open_file___111 *);
	u64 (*read_u64)(struct cgroup_subsys_state___89 *, struct cftype___89 *);
	s64 (*read_s64)(struct cgroup_subsys_state___89 *, struct cftype___89 *);
	int (*seq_show)(struct seq_file___106 *, void *);
	void * (*seq_start)(struct seq_file___106 *, loff_t *);
	void * (*seq_next)(struct seq_file___106 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___106 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___89 *, struct cftype___89 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___89 *, struct cftype___89 *, s64);
	ssize_t (*write)(struct kernfs_open_file___111 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___111 *, struct poll_table_struct___82 *);
};

struct perf_cpu_context___64;

struct perf_output_handle___64;

struct pmu___64 {
	struct list_head entry;
	struct module___109 *module;
	struct device___91 *dev;
	const struct attribute_group___111 **attr_groups;
	const struct attribute_group___111 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___64 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___64 *);
	void (*pmu_disable)(struct pmu___64 *);
	int (*event_init)(struct perf_event___64 *);
	void (*event_mapped)(struct perf_event___64 *, struct mm_struct___125 *);
	void (*event_unmapped)(struct perf_event___64 *, struct mm_struct___125 *);
	int (*add)(struct perf_event___64 *, int);
	void (*del)(struct perf_event___64 *, int);
	void (*start)(struct perf_event___64 *, int);
	void (*stop)(struct perf_event___64 *, int);
	void (*read)(struct perf_event___64 *);
	void (*start_txn)(struct pmu___64 *, unsigned int);
	int (*commit_txn)(struct pmu___64 *);
	void (*cancel_txn)(struct pmu___64 *);
	int (*event_idx)(struct perf_event___64 *);
	void (*sched_task)(struct perf_event_context___64 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___64 *, struct perf_event_context___64 *);
	void * (*setup_aux)(struct perf_event___64 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___64 *, struct perf_output_handle___64 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___64 *);
	int (*aux_output_match)(struct perf_event___64 *);
	int (*filter_match)(struct perf_event___64 *);
	int (*check_period)(struct perf_event___64 *, u64);
};

struct perf_cpu_context___64 {
	struct perf_event_context___64 ctx;
	struct perf_event_context___64 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___64 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___64 **heap;
	struct perf_event___64 *heap_default[2];
};

struct perf_output_handle___64 {
	struct perf_event___64 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___64 {
	struct cgroup_subsys_state___89 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___58 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___58 *);
	};
};

struct trace_event_class___58 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___58 *, enum trace_reg, void *);
	struct trace_event_fields___58 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___58 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___58 *);
};

struct syscall_metadata___31 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___58 *enter_event;
	struct trace_event_call___58 *exit_event;
};

struct mountpoint___13;

struct mount___13 {
	struct hlist_node mnt_hash;
	struct mount___13 *mnt_parent;
	struct dentry___119 *mnt_mountpoint;
	struct vfsmount___119 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___13 *mnt_master;
	struct mnt_namespace___13 *mnt_ns;
	struct mountpoint___13 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___13 {
	struct hlist_node m_hash;
	struct dentry___119 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct iomap_iter___2 {
	struct inode___119 *inode;
	loff_t pos;
	u64 len;
	s64 processed;
	unsigned int flags;
	struct iomap___2 iomap;
	struct iomap___2 srcmap;
};

typedef void (*poll_queue_proc___83)(struct file___119 *, wait_queue_head_t *, struct poll_table_struct___5 *);

struct trace_event_raw_iomap_readpage_class {
	struct trace_entry ent;
	dev_t dev;
	u64 ino;
	int nr_pages;
	char __data[0];
};

struct trace_event_raw_iomap_range_class {
	struct trace_entry ent;
	dev_t dev;
	u64 ino;
	loff_t size;
	loff_t offset;
	u64 length;
	char __data[0];
};

struct trace_event_raw_iomap_class {
	struct trace_entry ent;
	dev_t dev;
	u64 ino;
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	dev_t bdev;
	char __data[0];
};

struct trace_event_raw_iomap_iter {
	struct trace_entry ent;
	dev_t dev;
	u64 ino;
	loff_t pos;
	u64 length;
	unsigned int flags;
	const void *ops;
	long unsigned int caller;
	char __data[0];
};

struct trace_event_data_offsets_iomap_readpage_class {};

struct trace_event_data_offsets_iomap_range_class {};

struct trace_event_data_offsets_iomap_class {};

struct trace_event_data_offsets_iomap_iter {};

typedef void (*btf_trace_iomap_readpage)(void *, struct inode___119 *, int);

typedef void (*btf_trace_iomap_readahead)(void *, struct inode___119 *, int);

typedef void (*btf_trace_iomap_writepage)(void *, struct inode___119 *, loff_t, u64);

typedef void (*btf_trace_iomap_releasepage)(void *, struct inode___119 *, loff_t, u64);

typedef void (*btf_trace_iomap_invalidatepage)(void *, struct inode___119 *, loff_t, u64);

typedef void (*btf_trace_iomap_dio_invalidate_fail)(void *, struct inode___119 *, loff_t, u64);

typedef void (*btf_trace_iomap_iter_dstmap)(void *, struct inode___119 *, struct iomap___2 *);

typedef void (*btf_trace_iomap_iter_srcmap)(void *, struct inode___119 *, struct iomap___2 *);

typedef void (*btf_trace_iomap_iter)(void *, struct iomap_iter___2 *, const void *, long unsigned int);

typedef int get_block_t___3(struct inode___118 *, sector_t, struct buffer_head *, int);

enum {
	BIOSET_NEED_BVECS = 1,
	BIOSET_NEED_RESCUER = 2,
	BIOSET_PERCPU_CACHE = 4,
};

struct iomap_ops___2 {
	int (*iomap_begin)(struct inode___118 *, loff_t, loff_t, unsigned int, struct iomap___2 *, struct iomap___2 *);
	int (*iomap_end)(struct inode___118 *, loff_t, loff_t, ssize_t, unsigned int, struct iomap___2 *);
};

struct iomap_iter___3 {
	struct inode___118 *inode;
	loff_t pos;
	u64 len;
	s64 processed;
	unsigned int flags;
	struct iomap___2 iomap;
	struct iomap___2 srcmap;
};

struct iomap_ioend {
	struct list_head io_list;
	u16 io_type;
	u16 io_flags;
	struct inode___118 *io_inode;
	size_t io_size;
	loff_t io_offset;
	struct bio___54 *io_bio;
	struct bio___54 io_inline_bio;
};

struct iomap_writepage_ctx;

struct iomap_writeback_ops {
	int (*map_blocks)(struct iomap_writepage_ctx *, struct inode___118 *, loff_t);
	int (*prepare_ioend)(struct iomap_ioend *, int);
	void (*discard_page)(struct page___123 *, loff_t);
};

struct iomap_writepage_ctx {
	struct iomap___2 iomap;
	struct iomap_ioend *ioend;
	const struct iomap_writeback_ops *ops;
};

typedef int (*writepage_t___3)(struct page___123 *, struct writeback_control___52 *, void *);

struct iomap_page {
	atomic_t read_bytes_pending;
	atomic_t write_bytes_pending;
	spinlock_t uptodate_lock;
	long unsigned int uptodate[0];
};

struct iomap_readpage_ctx {
	struct page___123 *cur_page;
	bool cur_page_in_bio;
	struct bio___54 *bio;
	struct readahead_control___53 *rac;
};

struct iomap_dio_ops {
	int (*end_io)(struct kiocb___8 *, ssize_t, int, unsigned int);
	blk_qc_t (*submit_io)(const struct iomap_iter___3 *, struct bio___4 *, loff_t);
};

struct iomap_dio {
	struct kiocb___8 *iocb;
	const struct iomap_dio_ops *dops;
	loff_t i_size;
	loff_t size;
	atomic_t ref;
	unsigned int flags;
	int error;
	bool wait_for_completion;
	union {
		struct {
			struct iov_iter___5 *iter;
			struct task_struct___10 *waiter;
			struct request_queue___6 *last_queue;
			blk_qc_t cookie;
		} submit;
		struct {
			struct work_struct work;
		} aio;
	};
};

struct iomap_swapfile_info {
	struct iomap___2 iomap;
	struct swap_info_struct___28 *sis;
	uint64_t lowest_ppage;
	uint64_t highest_ppage;
	long unsigned int nr_pages;
	int nr_extents;
	struct file___118 *file;
};

enum {
	QIF_BLIMITS_B = 0,
	QIF_SPACE_B = 1,
	QIF_ILIMITS_B = 2,
	QIF_INODES_B = 3,
	QIF_BTIME_B = 4,
	QIF_ITIME_B = 5,
};

typedef __kernel_uid32_t qid_t;

enum {
	DQF_INFO_DIRTY_B = 17,
};

struct dqstats {
	long unsigned int stat[8];
	struct percpu_counter counter[8];
};

enum {
	_DQUOT_USAGE_ENABLED = 0,
	_DQUOT_LIMITS_ENABLED = 1,
	_DQUOT_SUSPENDED = 2,
	_DQUOT_STATE_FLAGS = 3,
};

struct quota_module_name {
	int qm_fmt_id;
	char *qm_mod_name;
};

struct dquot_warn {
	struct super_block___30 *w_sb;
	struct kqid w_dq_id;
	short int w_type;
};

struct fs_disk_quota {
	__s8 d_version;
	__s8 d_flags;
	__u16 d_fieldmask;
	__u32 d_id;
	__u64 d_blk_hardlimit;
	__u64 d_blk_softlimit;
	__u64 d_ino_hardlimit;
	__u64 d_ino_softlimit;
	__u64 d_bcount;
	__u64 d_icount;
	__s32 d_itimer;
	__s32 d_btimer;
	__u16 d_iwarns;
	__u16 d_bwarns;
	__s8 d_itimer_hi;
	__s8 d_btimer_hi;
	__s8 d_rtbtimer_hi;
	__s8 d_padding2;
	__u64 d_rtb_hardlimit;
	__u64 d_rtb_softlimit;
	__u64 d_rtbcount;
	__s32 d_rtbtimer;
	__u16 d_rtbwarns;
	__s16 d_padding3;
	char d_padding4[8];
};

struct fs_qfilestat {
	__u64 qfs_ino;
	__u64 qfs_nblks;
	__u32 qfs_nextents;
};

typedef struct fs_qfilestat fs_qfilestat_t;

struct fs_quota_stat {
	__s8 qs_version;
	__u16 qs_flags;
	__s8 qs_pad;
	fs_qfilestat_t qs_uquota;
	fs_qfilestat_t qs_gquota;
	__u32 qs_incoredqs;
	__s32 qs_btimelimit;
	__s32 qs_itimelimit;
	__s32 qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
};

struct fs_qfilestatv {
	__u64 qfs_ino;
	__u64 qfs_nblks;
	__u32 qfs_nextents;
	__u32 qfs_pad;
};

struct fs_quota_statv {
	__s8 qs_version;
	__u8 qs_pad1;
	__u16 qs_flags;
	__u32 qs_incoredqs;
	struct fs_qfilestatv qs_uquota;
	struct fs_qfilestatv qs_gquota;
	struct fs_qfilestatv qs_pquota;
	__s32 qs_btimelimit;
	__s32 qs_itimelimit;
	__s32 qs_rtbtimelimit;
	__u16 qs_bwarnlimit;
	__u16 qs_iwarnlimit;
	__u16 qs_rtbwarnlimit;
	__u16 qs_pad3;
	__u32 qs_pad4;
	__u64 qs_pad2[7];
};

struct if_dqblk {
	__u64 dqb_bhardlimit;
	__u64 dqb_bsoftlimit;
	__u64 dqb_curspace;
	__u64 dqb_ihardlimit;
	__u64 dqb_isoftlimit;
	__u64 dqb_curinodes;
	__u64 dqb_btime;
	__u64 dqb_itime;
	__u32 dqb_valid;
};

struct if_nextdqblk {
	__u64 dqb_bhardlimit;
	__u64 dqb_bsoftlimit;
	__u64 dqb_curspace;
	__u64 dqb_ihardlimit;
	__u64 dqb_isoftlimit;
	__u64 dqb_curinodes;
	__u64 dqb_btime;
	__u64 dqb_itime;
	__u32 dqb_valid;
	__u32 dqb_id;
};

struct if_dqinfo {
	__u64 dqi_bgrace;
	__u64 dqi_igrace;
	__u32 dqi_flags;
	__u32 dqi_valid;
};

struct compat_if_dqblk {
	compat_u64 dqb_bhardlimit;
	compat_u64 dqb_bsoftlimit;
	compat_u64 dqb_curspace;
	compat_u64 dqb_ihardlimit;
	compat_u64 dqb_isoftlimit;
	compat_u64 dqb_curinodes;
	compat_u64 dqb_btime;
	compat_u64 dqb_itime;
	compat_uint_t dqb_valid;
};

typedef struct {
	uid_t val;
} kuid_t___2;

typedef struct {
	gid_t val;
} kgid_t___2;

typedef struct {
	projid_t val;
} kprojid_t___2;

struct kqid___2 {
	union {
		kuid_t___2 uid;
		kgid_t___2 gid;
		kprojid_t___2 projid;
	};
	enum quota_type type;
};

enum {
	QUOTA_NL_C_UNSPEC = 0,
	QUOTA_NL_C_WARNING = 1,
	__QUOTA_NL_C_MAX = 2,
};

enum {
	QUOTA_NL_A_UNSPEC = 0,
	QUOTA_NL_A_QTYPE = 1,
	QUOTA_NL_A_EXCESS_ID = 2,
	QUOTA_NL_A_WARNING = 3,
	QUOTA_NL_A_DEV_MAJOR = 4,
	QUOTA_NL_A_DEV_MINOR = 5,
	QUOTA_NL_A_CAUSED_ID = 6,
	QUOTA_NL_A_PAD = 7,
	__QUOTA_NL_A_MAX = 8,
};

struct fs_context___20;

struct fs_parameter_spec___15;

struct dentry___120;

struct super_block___120;

struct module___110;

struct file_system_type___120 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___20 *);
	const struct fs_parameter_spec___15 *parameters;
	struct dentry___120 * (*mount)(struct file_system_type___120 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___120 *);
	struct module___110 *owner;
	struct file_system_type___120 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___120;

struct kiocb___120;

struct iov_iter___68;

struct vm_area_struct___125;

struct inode___120;

struct file_lock___120;

struct page___125;

struct seq_file___107;

struct file_operations___120 {
	struct module___110 *owner;
	loff_t (*llseek)(struct file___120 *, loff_t, int);
	ssize_t (*read)(struct file___120 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___120 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___120 *, struct iov_iter___68 *);
	ssize_t (*write_iter)(struct kiocb___120 *, struct iov_iter___68 *);
	int (*iopoll)(struct kiocb___120 *, bool);
	int (*iterate)(struct file___120 *, struct dir_context *);
	int (*iterate_shared)(struct file___120 *, struct dir_context *);
	__poll_t (*poll)(struct file___120 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___120 *, struct vm_area_struct___125 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___120 *, struct file___120 *);
	int (*flush)(struct file___120 *, fl_owner_t);
	int (*release)(struct inode___120 *, struct file___120 *);
	int (*fsync)(struct file___120 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___120 *, int);
	int (*lock)(struct file___120 *, int, struct file_lock___120 *);
	ssize_t (*sendpage)(struct file___120 *, struct page___125 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___120 *, long unsigned int);
	int (*flock)(struct file___120 *, int, struct file_lock___120 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___120 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___120 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___120 *, long int, struct file_lock___120 **, void **);
	long int (*fallocate)(struct file___120 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___107 *, struct file___120 *);
	ssize_t (*copy_file_range)(struct file___120 *, loff_t, struct file___120 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___120 *, loff_t, struct file___120 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___120 *, loff_t, loff_t, int);
};

struct vmacache___125 {
	u64 seqnum;
	struct vm_area_struct___125 *vmas[4];
};

struct page_frag___125 {
	struct page___125 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___126;

struct pid___105;

struct cred___15;

struct nsproxy___111;

struct signal_struct___121;

struct bio_list___55;

struct backing_dev_info___53;

struct io_context___55;

struct css_set___90;

struct mem_cgroup___47;

struct request_queue___55;

struct vm_struct___110;

struct task_struct___127 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___127 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___126 *mm;
	struct mm_struct___126 *active_mm;
	struct vmacache___125 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___127 *real_parent;
	struct task_struct___127 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___127 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___105 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___15 *ptracer_cred;
	const struct cred___15 *real_cred;
	const struct cred___15 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___111 *nsproxy;
	struct signal_struct___121 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___127 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___55 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___53 *backing_dev_info;
	struct io_context___55 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___90 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___125 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___47 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___47 *active_memcg;
	struct request_queue___55 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___127 *oom_reaper_list;
	struct vm_struct___110 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___112;

struct kobj_type___112;

struct kernfs_node___112;

struct kobject___112 {
	const char *name;
	struct list_head entry;
	struct kobject___112 *parent;
	struct kset___112 *kset;
	struct kobj_type___112 *ktype;
	struct kernfs_node___112 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___109 {
	struct kobject___112 kobj;
	struct module___110 *mod;
	struct kobject___112 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___109 {
	struct module___110 *mod;
	struct latch_tree_node node;
};

struct module_layout___109 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___109 mtn;
};

struct module_attribute___109;

struct kernel_param___109;

struct module___110 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___109 mkobj;
	struct module_attribute___109 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___112 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___109 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___109 core_layout;
	struct module_layout___109 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___125 *pgtable_t___125;

struct address_space___120;

struct dev_pagemap___118;

struct page___125 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___120 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___125 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___125 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___126 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___118 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___118;

struct vm_area_struct___125 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___125 *vm_next;
	struct vm_area_struct___125 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___126 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___118 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___120 *vm_file;
	struct file___120 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___18;

struct core_state___125;

struct user_namespace___15;

struct mm_struct___126 {
	struct {
		struct vm_area_struct___125 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___18 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___125 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___127 *owner;
		struct user_namespace___15 *user_ns;
		struct file___120 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___120;

struct address_space___120 {
	struct inode___120 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___120 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___118;

struct dev_pagemap___118 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___118 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___120;

struct path___120 {
	struct vfsmount___120 *mnt;
	struct dentry___120 *dentry;
};

struct fown_struct___105 {
	rwlock_t lock;
	struct pid___105 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___120 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___120 f_path;
	struct inode___120 *f_inode;
	const struct file_operations___120 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___105 f_owner;
	const struct cred___15 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___120 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___118;

struct vm_operations_struct___118 {
	void (*open)(struct vm_area_struct___125 *);
	void (*close)(struct vm_area_struct___125 *);
	int (*may_split)(struct vm_area_struct___125 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___125 *);
	int (*mprotect)(struct vm_area_struct___125 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___118 *);
	vm_fault_t (*huge_fault)(struct vm_fault___118 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___118 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___125 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___118 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___118 *);
	int (*access)(struct vm_area_struct___125 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___125 *);
	int (*set_policy)(struct vm_area_struct___125 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___125 *, long unsigned int);
	struct page___125 * (*find_special_page)(struct vm_area_struct___125 *, long unsigned int);
};

struct core_thread___125 {
	struct task_struct___127 *task;
	struct core_thread___125 *next;
};

struct core_state___125 {
	atomic_t nr_threads;
	struct core_thread___125 dumper;
	struct completion startup;
};

struct linux_binprm___19;

struct coredump_params___18;

struct linux_binfmt___18 {
	struct list_head lh;
	struct module___110 *module;
	int (*load_binary)(struct linux_binprm___19 *);
	int (*load_shlib)(struct file___120 *);
	int (*core_dump)(struct coredump_params___18 *);
	long unsigned int min_coredump;
};

struct proc_ns_operations___16;

struct ns_common___16 {
	atomic_long_t stashed;
	const struct proc_ns_operations___16 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___15;

struct user_namespace___15 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___15 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___16 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___3 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___3 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___15 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___118 {
	const struct {
		struct vm_area_struct___125 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___125 *cow_page;
	struct page___125 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___125 prealloc_pte;
};

struct pglist_data___53;

struct lruvec___53 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___53 *pgdat;
};

struct zone___53 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___53 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___53 {
	struct zone___53 *zone;
	int zone_idx;
};

struct zonelist___53 {
	struct zoneref___53 _zonerefs[321];
};

struct pglist_data___53 {
	struct zone___53 node_zones[5];
	struct zonelist___53 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___127 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___127 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___53 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___47 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___47 *memcg;
};

struct cgroup___90;

struct cgroup_subsys___90;

struct cgroup_subsys_state___90 {
	struct cgroup___90 *cgroup;
	struct cgroup_subsys___90 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___90 *parent;
};

struct cgroup_file___90 {
	struct kernfs_node___112 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___47;

struct mem_cgroup_per_node___47;

struct mem_cgroup___47 {
	struct cgroup_subsys_state___90 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___90 events_file;
	struct cgroup_file___90 events_local_file;
	struct cgroup_file___90 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___47 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___127 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___47 *nodeinfo[0];
	long: 64;
};

struct shrinker___47 {
	long unsigned int (*count_objects)(struct shrinker___47 *, struct shrink_control___47 *);
	long unsigned int (*scan_objects)(struct shrinker___47 *, struct shrink_control___47 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___118 {
	void (*page_free)(struct page___125 *);
	void (*kill)(struct dev_pagemap___118 *);
	void (*cleanup)(struct dev_pagemap___118 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___118 *);
};

struct pid_namespace___105;

struct upid___105 {
	int nr;
	struct pid_namespace___105 *ns;
};

struct pid_namespace___105 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___127 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___105 *parent;
	struct fs_pin *bacct;
	struct user_namespace___15 *user_ns;
	struct ucounts___15 *ucounts;
	int reboot;
	struct ns_common___16 ns;
};

struct pid___105 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___105 numbers[1];
};

struct ucounts___15 {
	struct hlist_node node;
	struct user_namespace___15 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___121 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___127 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___127 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___105 *pids[4];
	struct pid___105 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___126 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___15 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___15 *user_ns;
	struct ucounts___15 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct cgroup_namespace___90;

struct nsproxy___111 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___105 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___90 *cgroup_ns;
};

struct bio___55;

struct bio_list___55 {
	struct bio___55 *head;
	struct bio___55 *tail;
};

struct bdi_writeback___53 {
	struct backing_dev_info___53 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___90 *memcg_css;
	struct cgroup_subsys_state___90 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___92;

struct backing_dev_info___53 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___53 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___92 *dev;
	char dev_name[64];
	struct device___92 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___120 *debug_dir;
};

struct io_cq___55;

struct io_context___55 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___55 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___90 {
	struct cgroup_subsys_state___90 *subsys[14];
	refcount_t refcount;
	struct css_set___90 *dom_cset;
	struct cgroup___90 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___90 *mg_src_cgrp;
	struct cgroup___90 *mg_dst_cgrp;
	struct css_set___90 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___55;

struct blk_integrity___55 {
	const struct blk_integrity_profile___55 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___55 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___55 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___55;

struct elevator_queue___55;

struct blk_mq_ops___53;

struct blk_mq_hw_ctx___53;

struct gendisk___55;

struct blkcg_gq___53;

struct blk_mq_tag_set___53;

struct request_queue___55 {
	struct request___55 *last_merge;
	struct elevator_queue___55 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___53 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___53 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___55 *disk;
	struct kobject___112 kobj;
	struct kobject___112 *mq_kobj;
	struct blk_integrity___55 integrity;
	struct device___92 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___53 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___53 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___55 bio_split;
	struct dentry___120 *debugfs_dir;
	struct dentry___120 *sched_debugfs_dir;
	struct dentry___120 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___110 {
	struct vm_struct___110 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___125 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___120;

struct dentry___120 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___120 *d_parent;
	struct qstr d_name;
	struct inode___120 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___120 *d_op;
	struct super_block___120 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___120;

struct inode___120 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___120 *i_op;
	struct super_block___120 *i_sb;
	struct address_space___120 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___53 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___120 *i_fop;
		void (*free_inode)(struct inode___120 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___120 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___120 {
	int (*d_revalidate)(struct dentry___120 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___120 *, unsigned int);
	int (*d_hash)(const struct dentry___120 *, struct qstr *);
	int (*d_compare)(const struct dentry___120 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___120 *);
	int (*d_init)(struct dentry___120 *);
	void (*d_release)(struct dentry___120 *);
	void (*d_prune)(struct dentry___120 *);
	void (*d_iput)(struct dentry___120 *, struct inode___120 *);
	char * (*d_dname)(struct dentry___120 *, char *, int);
	struct vfsmount___120 * (*d_automount)(struct path___120 *);
	int (*d_manage)(const struct path___120 *, bool);
	struct dentry___120 * (*d_real)(struct dentry___120 *, const struct inode___120 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___120;

struct mem_dqinfo___120 {
	struct quota_format_type___120 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___120;

struct quota_info___120 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___120 *files[3];
	struct mem_dqinfo___120 info[3];
	const struct quota_format_ops___120 *ops[3];
};

struct rcuwait___121 {
	struct task_struct___127 *task;
};

struct percpu_rw_semaphore___121 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___121 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___120 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___121 rw_sem[3];
};

struct super_operations___120;

struct dquot_operations___120;

struct quotactl_ops___120;

struct xattr_handler___11;

struct block_device___56;

struct super_block___120 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___120 *s_type;
	const struct super_operations___120 *s_op;
	const struct dquot_operations___120 *dq_op;
	const struct quotactl_ops___120 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___120 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___11 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___56 *s_bdev;
	struct backing_dev_info___53 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___120 s_dquot;
	struct sb_writers___120 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___120 *s_d_op;
	int cleancache_poolid;
	struct shrinker___47 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___15 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___120 {
	struct dentry___120 *mnt_root;
	struct super_block___120 *mnt_sb;
	int mnt_flags;
	struct user_namespace___15 *mnt_userns;
};

struct psi_group___90 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___127 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___90;

struct cgroup_rstat_cpu___90;

struct cgroup___90 {
	struct cgroup_subsys_state___90 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___112 *kn;
	struct cgroup_file___90 procs_file;
	struct cgroup_file___90 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___90 *subsys[14];
	struct cgroup_root___90 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___90 *dom_cgrp;
	struct cgroup___90 *old_dom_cgrp;
	struct cgroup_rstat_cpu___90 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___90 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___55 {
	struct request_queue___55 *q;
	struct io_context___55 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___54;

struct kiocb___120 {
	struct file___120 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___120 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___54 *ki_waitq;
	};
};

struct iattr___120 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___120 *ia_file;
};

struct dquot___120 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___120 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___120 {
	int qf_fmt_id;
	const struct quota_format_ops___120 *qf_ops;
	struct module___110 *qf_owner;
	struct quota_format_type___120 *qf_next;
};

struct quota_format_ops___120 {
	int (*check_quota_file)(struct super_block___120 *, int);
	int (*read_file_info)(struct super_block___120 *, int);
	int (*write_file_info)(struct super_block___120 *, int);
	int (*free_file_info)(struct super_block___120 *, int);
	int (*read_dqblk)(struct dquot___120 *);
	int (*commit_dqblk)(struct dquot___120 *);
	int (*release_dqblk)(struct dquot___120 *);
	int (*get_next_id)(struct super_block___120 *, struct kqid *);
};

struct dquot_operations___120 {
	int (*write_dquot)(struct dquot___120 *);
	struct dquot___120 * (*alloc_dquot)(struct super_block___120 *, int);
	void (*destroy_dquot)(struct dquot___120 *);
	int (*acquire_dquot)(struct dquot___120 *);
	int (*release_dquot)(struct dquot___120 *);
	int (*mark_dirty)(struct dquot___120 *);
	int (*write_info)(struct super_block___120 *, int);
	qsize_t * (*get_reserved_space)(struct inode___120 *);
	int (*get_projid)(struct inode___120 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___120 *, qsize_t *);
	int (*get_next_id)(struct super_block___120 *, struct kqid *);
};

struct quotactl_ops___120 {
	int (*quota_on)(struct super_block___120 *, int, int, const struct path___120 *);
	int (*quota_off)(struct super_block___120 *, int);
	int (*quota_enable)(struct super_block___120 *, unsigned int);
	int (*quota_disable)(struct super_block___120 *, unsigned int);
	int (*quota_sync)(struct super_block___120 *, int);
	int (*set_info)(struct super_block___120 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___120 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___120 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___120 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___120 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___120 *, unsigned int);
};

struct wait_page_queue___54 {
	struct page___125 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___53;

struct readahead_control___54;

struct swap_info_struct___29;

struct address_space_operations___120 {
	int (*writepage)(struct page___125 *, struct writeback_control___53 *);
	int (*readpage)(struct file___120 *, struct page___125 *);
	int (*writepages)(struct address_space___120 *, struct writeback_control___53 *);
	int (*set_page_dirty)(struct page___125 *);
	int (*readpages)(struct file___120 *, struct address_space___120 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___54 *);
	int (*write_begin)(struct file___120 *, struct address_space___120 *, loff_t, unsigned int, unsigned int, struct page___125 **, void **);
	int (*write_end)(struct file___120 *, struct address_space___120 *, loff_t, unsigned int, unsigned int, struct page___125 *, void *);
	sector_t (*bmap)(struct address_space___120 *, sector_t);
	void (*invalidatepage)(struct page___125 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___125 *, gfp_t);
	void (*freepage)(struct page___125 *);
	ssize_t (*direct_IO)(struct kiocb___120 *, struct iov_iter___68 *);
	int (*migratepage)(struct address_space___120 *, struct page___125 *, struct page___125 *, enum migrate_mode);
	bool (*isolate_page)(struct page___125 *, isolate_mode_t);
	void (*putback_page)(struct page___125 *);
	int (*launder_page)(struct page___125 *);
	int (*is_partially_uptodate)(struct page___125 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___125 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___120 *, struct page___125 *);
	int (*swap_activate)(struct swap_info_struct___29 *, struct file___120 *, sector_t *);
	void (*swap_deactivate)(struct file___120 *);
};

struct writeback_control___53 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___53 *wb;
	struct inode___120 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___54 {
	struct file___120 *file;
	struct address_space___120 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___66;

struct iov_iter___68 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___66 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___29 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___56 *bdev;
	struct file___120 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___120 {
	struct dentry___120 * (*lookup)(struct inode___120 *, struct dentry___120 *, unsigned int);
	const char * (*get_link)(struct dentry___120 *, struct inode___120 *, struct delayed_call *);
	int (*permission)(struct user_namespace___15 *, struct inode___120 *, int);
	struct posix_acl * (*get_acl)(struct inode___120 *, int, bool);
	int (*readlink)(struct dentry___120 *, char *, int);
	int (*create)(struct user_namespace___15 *, struct inode___120 *, struct dentry___120 *, umode_t, bool);
	int (*link)(struct dentry___120 *, struct inode___120 *, struct dentry___120 *);
	int (*unlink)(struct inode___120 *, struct dentry___120 *);
	int (*symlink)(struct user_namespace___15 *, struct inode___120 *, struct dentry___120 *, const char *);
	int (*mkdir)(struct user_namespace___15 *, struct inode___120 *, struct dentry___120 *, umode_t);
	int (*rmdir)(struct inode___120 *, struct dentry___120 *);
	int (*mknod)(struct user_namespace___15 *, struct inode___120 *, struct dentry___120 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___15 *, struct inode___120 *, struct dentry___120 *, struct inode___120 *, struct dentry___120 *, unsigned int);
	int (*setattr)(struct user_namespace___15 *, struct dentry___120 *, struct iattr___120 *);
	int (*getattr)(struct user_namespace___15 *, const struct path___120 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___120 *, char *, size_t);
	int (*fiemap)(struct inode___120 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___120 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___120 *, struct dentry___120 *, struct file___120 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___15 *, struct inode___120 *, struct dentry___120 *, umode_t);
	int (*set_acl)(struct user_namespace___15 *, struct inode___120 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___15 *, struct dentry___120 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___120 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___120 {
	void (*fl_copy_lock)(struct file_lock___120 *, struct file_lock___120 *);
	void (*fl_release_private)(struct file_lock___120 *);
};

struct fasync_struct___120;

struct lock_manager_operations___120;

struct file_lock___120 {
	struct file_lock___120 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___120 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___120 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___120 *fl_ops;
	const struct lock_manager_operations___120 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___120 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___120 *);
	int (*lm_grant)(struct file_lock___120 *, int);
	bool (*lm_break)(struct file_lock___120 *);
	int (*lm_change)(struct file_lock___120 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___120 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___120 *);
};

struct fasync_struct___120 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___120 *fa_next;
	struct file___120 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___120 {
	struct inode___120 * (*alloc_inode)(struct super_block___120 *);
	void (*destroy_inode)(struct inode___120 *);
	void (*free_inode)(struct inode___120 *);
	void (*dirty_inode)(struct inode___120 *, int);
	int (*write_inode)(struct inode___120 *, struct writeback_control___53 *);
	int (*drop_inode)(struct inode___120 *);
	void (*evict_inode)(struct inode___120 *);
	void (*put_super)(struct super_block___120 *);
	int (*sync_fs)(struct super_block___120 *, int);
	int (*freeze_super)(struct super_block___120 *);
	int (*freeze_fs)(struct super_block___120 *);
	int (*thaw_super)(struct super_block___120 *);
	int (*unfreeze_fs)(struct super_block___120 *);
	int (*statfs)(struct dentry___120 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___120 *, int *, char *);
	void (*umount_begin)(struct super_block___120 *);
	int (*show_options)(struct seq_file___107 *, struct dentry___120 *);
	int (*show_devname)(struct seq_file___107 *, struct dentry___120 *);
	int (*show_path)(struct seq_file___107 *, struct dentry___120 *);
	int (*show_stats)(struct seq_file___107 *, struct dentry___120 *);
	ssize_t (*quota_read)(struct super_block___120 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___120 *, int, const char *, size_t, loff_t);
	struct dquot___120 ** (*get_dquots)(struct inode___120 *);
	long int (*nr_cached_objects)(struct super_block___120 *, struct shrink_control___47 *);
	long int (*free_cached_objects)(struct super_block___120 *, struct shrink_control___47 *);
	struct file___120 * (*real_loop)(struct file___120 *);
};

struct xattr_handler___11 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___120 *);
	int (*get)(const struct xattr_handler___11 *, struct dentry___120 *, struct inode___120 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___11 *, struct user_namespace___15 *, struct dentry___120 *, struct inode___120 *, const char *, const void *, size_t, int);
};

struct wakeup_source___92;

struct dev_pm_info___92 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___92 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___92 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___92;

struct bus_type___92;

struct device_driver___92;

struct dev_pm_domain___92;

struct fwnode_handle___92;

struct class___92;

struct attribute_group___112;

struct device___92 {
	struct kobject___112 kobj;
	struct device___92 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___92 *type;
	struct bus_type___92 *bus;
	struct device_driver___92 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___92 power;
	struct dev_pm_domain___92 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___92 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___92 *class;
	const struct attribute_group___112 **groups;
	void (*release)(struct device___92 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___56 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___120 *bd_inode;
	struct super_block___120 *bd_super;
	void *bd_claiming;
	struct device___92 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___112 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___55 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___120 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___107;

struct seq_file___107 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___107 *op;
	int poll_event;
	const struct file___120 *file;
	void *private;
};

struct fc_log___20;

struct p_log___20 {
	const char *prefix;
	struct fc_log___20 *log;
};

struct fs_context_operations___20;

struct fs_context___20 {
	const struct fs_context_operations___20 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___120 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___120 *root;
	struct user_namespace___15 *user_ns;
	struct net *net_ns;
	const struct cred___15 *cred;
	struct p_log___20 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___20;

typedef int fs_param_type___15(struct p_log___20 *, const struct fs_parameter_spec___15 *, struct fs_parameter___20 *, struct fs_parse_result *);

struct fs_parameter_spec___15 {
	const char *name;
	fs_param_type___15 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___55(struct bio___55 *);

struct bio_vec___66 {
	struct page___125 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___55;

struct bio___55 {
	struct bio___55 *bi_next;
	struct block_device___56 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___55 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___53 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___55 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___66 *bi_io_vec;
	struct bio_set___55 *bi_pool;
	struct bio_vec___66 bi_inline_vecs[0];
};

struct mm_walk___5;

struct mm_walk_ops___5 {
	int (*pgd_entry)(pgd_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*p4d_entry)(p4d_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pud_entry)(pud_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pmd_entry)(pmd_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pte_entry)(pte_t *, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pte_hole)(long unsigned int, long unsigned int, int, struct mm_walk___5 *);
	int (*hugetlb_entry)(pte_t *, long unsigned int, long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*test_walk)(long unsigned int, long unsigned int, struct mm_walk___5 *);
	int (*pre_vma)(long unsigned int, long unsigned int, struct mm_walk___5 *);
	void (*post_vma)(struct mm_walk___5 *);
};

struct mm_walk___5 {
	const struct mm_walk_ops___5 *ops;
	struct mm_struct___126 *mm;
	pgd_t *pgd;
	struct vm_area_struct___125 *vma;
	enum page_walk_action action;
	bool no_vma;
	void *private;
};

struct seq_operations___107 {
	void * (*start)(struct seq_file___107 *, loff_t *);
	void (*stop)(struct seq_file___107 *, void *);
	void * (*next)(struct seq_file___107 *, void *, loff_t *);
	int (*show)(struct seq_file___107 *, void *);
};

struct kernfs_root___112;

struct kernfs_elem_dir___112 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___112 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___112;

struct kernfs_root___112 {
	struct kernfs_node___112 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___112 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___112 {
	struct kernfs_node___112 *target_kn;
};

struct kernfs_ops___112;

struct kernfs_elem_attr___112 {
	const struct kernfs_ops___112 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___112 *notify_next;
};

struct kernfs_node___112 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___112 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___112 dir;
		struct kernfs_elem_symlink___112 symlink;
		struct kernfs_elem_attr___112 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___112;

struct kernfs_ops___112 {
	int (*open)(struct kernfs_open_file___112 *);
	void (*release)(struct kernfs_open_file___112 *);
	int (*seq_show)(struct seq_file___107 *, void *);
	void * (*seq_start)(struct seq_file___107 *, loff_t *);
	void * (*seq_next)(struct seq_file___107 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___107 *, void *);
	ssize_t (*read)(struct kernfs_open_file___112 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___112 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___112 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___112 *, struct vm_area_struct___125 *);
};

struct kernfs_syscall_ops___112 {
	int (*show_options)(struct seq_file___107 *, struct kernfs_root___112 *);
	int (*mkdir)(struct kernfs_node___112 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___112 *);
	int (*rename)(struct kernfs_node___112 *, struct kernfs_node___112 *, const char *);
	int (*show_path)(struct seq_file___107 *, struct kernfs_node___112 *, struct kernfs_root___112 *);
};

struct kernfs_open_file___112 {
	struct kernfs_node___112 *kn;
	struct file___120 *file;
	struct seq_file___107 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___118 *vm_ops;
};

struct nsset___15;

struct proc_ns_operations___16 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___16 * (*get)(struct task_struct___127 *);
	void (*put)(struct ns_common___16 *);
	int (*install)(struct nsset___15 *, struct ns_common___16 *);
	struct user_namespace___15 * (*owner)(struct ns_common___16 *);
	struct ns_common___16 * (*get_parent)(struct ns_common___16 *);
};

struct cgroup_namespace___90 {
	struct ns_common___16 ns;
	struct user_namespace___15 *user_ns;
	struct ucounts___15 *ucounts;
	struct css_set___90 *root_cset;
};

struct nsset___15 {
	unsigned int flags;
	struct nsproxy___111 *nsproxy;
	struct fs_struct *fs;
	const struct cred___15 *cred;
};

struct fwnode_operations___92;

struct fwnode_handle___92 {
	struct fwnode_handle___92 *secondary;
	const struct fwnode_operations___92 *ops;
	struct device___92 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___92;

struct fwnode_endpoint___92;

struct fwnode_operations___92 {
	struct fwnode_handle___92 * (*get)(struct fwnode_handle___92 *);
	void (*put)(struct fwnode_handle___92 *);
	bool (*device_is_available)(const struct fwnode_handle___92 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___92 *, const struct device___92 *);
	bool (*property_present)(const struct fwnode_handle___92 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___92 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___92 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___92 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*get_parent)(const struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*get_next_child_node)(const struct fwnode_handle___92 *, struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*get_named_child_node)(const struct fwnode_handle___92 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___92 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___92 *);
	struct fwnode_handle___92 * (*graph_get_next_endpoint)(const struct fwnode_handle___92 *, struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*graph_get_remote_endpoint)(const struct fwnode_handle___92 *);
	struct fwnode_handle___92 * (*graph_get_port_parent)(struct fwnode_handle___92 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___92 *, struct fwnode_endpoint___92 *);
	int (*add_links)(struct fwnode_handle___92 *);
};

struct fwnode_endpoint___92 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___92 *local_fwnode;
};

struct fwnode_reference_args___92 {
	struct fwnode_handle___92 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___112;

struct attribute_group___112 {
	const char *name;
	umode_t (*is_visible)(struct kobject___112 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___112 *, struct bin_attribute___112 *, int);
	struct attribute **attrs;
	struct bin_attribute___112 **bin_attrs;
};

struct bin_attribute___112 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___120 * (*f_mapping)();
	ssize_t (*read)(struct file___120 *, struct kobject___112 *, struct bin_attribute___112 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___120 *, struct kobject___112 *, struct bin_attribute___112 *, char *, loff_t, size_t);
	int (*mmap)(struct file___120 *, struct kobject___112 *, struct bin_attribute___112 *, struct vm_area_struct___125 *);
};

struct sysfs_ops___112 {
	ssize_t (*show)(struct kobject___112 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___112 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___112;

struct kset___112 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___112 kobj;
	const struct kset_uevent_ops___112 *uevent_ops;
};

struct kobj_type___112 {
	void (*release)(struct kobject___112 *);
	const struct sysfs_ops___112 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___112 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___112 *);
	const void * (*namespace)(struct kobject___112 *);
	void (*get_ownership)(struct kobject___112 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___112 {
	int (* const filter)(struct kset___112 *, struct kobject___112 *);
	const char * (* const name)(struct kset___112 *, struct kobject___112 *);
	int (* const uevent)(struct kset___112 *, struct kobject___112 *, struct kobj_uevent_env *);
};

typedef int (*proc_write_t___2)(struct file___120 *, char *, size_t);

struct proc_ops___9;

struct proc_dir_entry___3 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___120 *proc_iops;
	union {
		const struct proc_ops___9 *proc_ops;
		const struct file_operations___120 *proc_dir_ops;
	};
	const struct dentry_operations___120 *proc_dops;
	union {
		const struct seq_operations___107 *seq_ops;
		int (*single_show)(struct seq_file___107 *, void *);
	};
	proc_write_t___2 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___3 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct kernel_param_ops___109 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___109 *);
	int (*get)(char *, const struct kernel_param___109 *);
	void (*free)(void *);
};

struct kparam_array___109;

struct kernel_param___109 {
	const char *name;
	struct module___110 *mod;
	const struct kernel_param_ops___109 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___109 *arr;
	};
};

struct kparam_array___109 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___109 *ops;
	void *elem;
};

struct module_attribute___109 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___109 *, struct module_kobject___109 *, char *);
	ssize_t (*store)(struct module_attribute___109 *, struct module_kobject___109 *, const char *, size_t);
	void (*setup)(struct module___110 *, const char *);
	int (*test)(struct module___110 *);
	void (*free)(struct module___110 *);
};

struct cftype___90;

struct cgroup_subsys___90 {
	struct cgroup_subsys_state___90 * (*css_alloc)(struct cgroup_subsys_state___90 *);
	int (*css_online)(struct cgroup_subsys_state___90 *);
	void (*css_offline)(struct cgroup_subsys_state___90 *);
	void (*css_released)(struct cgroup_subsys_state___90 *);
	void (*css_free)(struct cgroup_subsys_state___90 *);
	void (*css_reset)(struct cgroup_subsys_state___90 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___90 *, int);
	int (*css_extra_stat_show)(struct seq_file___107 *, struct cgroup_subsys_state___90 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___127 *, struct css_set___90 *);
	void (*cancel_fork)(struct task_struct___127 *, struct css_set___90 *);
	void (*fork)(struct task_struct___127 *);
	void (*exit)(struct task_struct___127 *);
	void (*release)(struct task_struct___127 *);
	void (*bind)(struct cgroup_subsys_state___90 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___90 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___90 *dfl_cftypes;
	struct cftype___90 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___90 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___90 *updated_children;
	struct cgroup___90 *updated_next;
};

struct cgroup_root___90 {
	struct kernfs_root___112 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___90 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___90 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___90 *ss;
	struct list_head node;
	struct kernfs_ops___112 *kf_ops;
	int (*open)(struct kernfs_open_file___112 *);
	void (*release)(struct kernfs_open_file___112 *);
	u64 (*read_u64)(struct cgroup_subsys_state___90 *, struct cftype___90 *);
	s64 (*read_s64)(struct cgroup_subsys_state___90 *, struct cftype___90 *);
	int (*seq_show)(struct seq_file___107 *, void *);
	void * (*seq_start)(struct seq_file___107 *, loff_t *);
	void * (*seq_next)(struct seq_file___107 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___107 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___90 *, struct cftype___90 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___90 *, struct cftype___90 *, s64);
	ssize_t (*write)(struct kernfs_open_file___112 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___112 *, struct poll_table_struct___5 *);
};

struct hstate___7;

struct hugepage_subpool___5 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___7 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___7 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___90 cgroup_files_dfl[7];
	struct cftype___90 cgroup_files_legacy[9];
	char name[32];
};

struct hugetlbfs_sb_info___5 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___7 *hstate;
	struct hugepage_subpool___5 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct dev_pm_ops___92 {
	int (*prepare)(struct device___92 *);
	void (*complete)(struct device___92 *);
	int (*suspend)(struct device___92 *);
	int (*resume)(struct device___92 *);
	int (*freeze)(struct device___92 *);
	int (*thaw)(struct device___92 *);
	int (*poweroff)(struct device___92 *);
	int (*restore)(struct device___92 *);
	int (*suspend_late)(struct device___92 *);
	int (*resume_early)(struct device___92 *);
	int (*freeze_late)(struct device___92 *);
	int (*thaw_early)(struct device___92 *);
	int (*poweroff_late)(struct device___92 *);
	int (*restore_early)(struct device___92 *);
	int (*suspend_noirq)(struct device___92 *);
	int (*resume_noirq)(struct device___92 *);
	int (*freeze_noirq)(struct device___92 *);
	int (*thaw_noirq)(struct device___92 *);
	int (*poweroff_noirq)(struct device___92 *);
	int (*restore_noirq)(struct device___92 *);
	int (*runtime_suspend)(struct device___92 *);
	int (*runtime_resume)(struct device___92 *);
	int (*runtime_idle)(struct device___92 *);
};

struct wakeup_source___92 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___92 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___92 {
	struct dev_pm_ops___92 ops;
	int (*start)(struct device___92 *);
	void (*detach)(struct device___92 *, bool);
	int (*activate)(struct device___92 *);
	void (*sync)(struct device___92 *);
	void (*dismiss)(struct device___92 *);
};

struct bus_type___92 {
	const char *name;
	const char *dev_name;
	struct device___92 *dev_root;
	const struct attribute_group___112 **bus_groups;
	const struct attribute_group___112 **dev_groups;
	const struct attribute_group___112 **drv_groups;
	int (*match)(struct device___92 *, struct device_driver___92 *);
	int (*uevent)(struct device___92 *, struct kobj_uevent_env *);
	int (*probe)(struct device___92 *);
	void (*sync_state)(struct device___92 *);
	void (*remove)(struct device___92 *);
	void (*shutdown)(struct device___92 *);
	int (*online)(struct device___92 *);
	int (*offline)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	int (*num_vf)(struct device___92 *);
	int (*dma_configure)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___92 {
	const char *name;
	struct bus_type___92 *bus;
	struct module___110 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___92 *);
	void (*sync_state)(struct device___92 *);
	int (*remove)(struct device___92 *);
	void (*shutdown)(struct device___92 *);
	int (*suspend)(struct device___92 *, pm_message_t);
	int (*resume)(struct device___92 *);
	const struct attribute_group___112 **groups;
	const struct attribute_group___112 **dev_groups;
	const struct dev_pm_ops___92 *pm;
	void (*coredump)(struct device___92 *);
	struct driver_private *p;
};

struct device_type___92 {
	const char *name;
	const struct attribute_group___112 **groups;
	int (*uevent)(struct device___92 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___92 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___92 *);
	const struct dev_pm_ops___92 *pm;
};

struct class___92 {
	const char *name;
	struct module___110 *owner;
	const struct attribute_group___112 **class_groups;
	const struct attribute_group___112 **dev_groups;
	struct kobject___112 *dev_kobj;
	int (*dev_uevent)(struct device___92 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___92 *, umode_t *);
	void (*class_release)(struct class___92 *);
	void (*dev_release)(struct device___92 *);
	int (*shutdown_pre)(struct device___92 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___92 *);
	void (*get_ownership)(struct device___92 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___92 *pm;
	struct subsys_private *p;
};

struct block_device_operations___55;

struct gendisk___55 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___56 *part0;
	const struct block_device_operations___55 *fops;
	struct request_queue___55 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___53 *bdi;
	struct kobject___112 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___112 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___55 {
	struct bio___55 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___66 *bip_vec;
	struct bio_vec___66 bip_inline_vecs[0];
};

struct blkcg___53;

struct blkg_policy_data___53;

struct blkcg_gq___53 {
	struct request_queue___55 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___53 *blkcg;
	struct blkcg_gq___53 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___53 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___55 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___55(struct request___55 *);

typedef void integrity_complete_fn___55(struct request___55 *, unsigned int);

struct blk_integrity_profile___55 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___55 *prepare_fn;
	integrity_complete_fn___55 *complete_fn;
	const char *name;
};

struct block_device_operations___55 {
	blk_qc_t (*submit_bio)(struct bio___55 *);
	int (*open)(struct block_device___56 *, fmode_t);
	void (*release)(struct gendisk___55 *, fmode_t);
	int (*rw_page)(struct block_device___56 *, sector_t, struct page___125 *, unsigned int);
	int (*ioctl)(struct block_device___56 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___56 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___55 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___55 *);
	int (*getgeo)(struct block_device___56 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___56 *, bool);
	void (*swap_slot_free_notify)(struct block_device___56 *, long unsigned int);
	int (*report_zones)(struct gendisk___55 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___55 *, umode_t *);
	struct module___110 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___55 *, sector_t *);
};

typedef void rq_end_io_fn___55(struct request___55 *, blk_status_t);

struct request___55 {
	struct request_queue___55 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___53 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___55 *bio;
	struct bio___55 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___66 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___55 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___55 *saved_end_io;
		} flush;
	};
	struct gendisk___55 *rq_disk;
	struct block_device___56 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___55 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___53 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___55 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___112 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___120 *debugfs_dir;
	struct dentry___120 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___55;

struct elevator_mq_ops___55 {
	int (*init_sched)(struct request_queue___55 *, struct elevator_type___55 *);
	void (*exit_sched)(struct elevator_queue___55 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___53 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___53 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___53 *);
	bool (*allow_merge)(struct request_queue___55 *, struct request___55 *, struct bio___55 *);
	bool (*bio_merge)(struct request_queue___55 *, struct bio___55 *, unsigned int);
	int (*request_merge)(struct request_queue___55 *, struct request___55 **, struct bio___55 *);
	void (*request_merged)(struct request_queue___55 *, struct request___55 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___55 *, struct request___55 *, struct request___55 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___55 *);
	void (*finish_request)(struct request___55 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___53 *, struct list_head *, bool);
	struct request___55 * (*dispatch_request)(struct blk_mq_hw_ctx___53 *);
	bool (*has_work)(struct blk_mq_hw_ctx___53 *);
	void (*completed_request)(struct request___55 *, u64);
	void (*requeue_request)(struct request___55 *);
	struct request___55 * (*former_request)(struct request_queue___55 *, struct request___55 *);
	struct request___55 * (*next_request)(struct request_queue___55 *, struct request___55 *);
	void (*init_icq)(struct io_cq___55 *);
	void (*exit_icq)(struct io_cq___55 *);
};

struct elv_fs_entry___55;

struct elevator_type___55 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___55 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___55 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___110 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___55 {
	struct elevator_type___55 *type;
	void *elevator_data;
	struct kobject___112 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___55 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___55 *, char *);
	ssize_t (*store)(struct elevator_queue___55 *, const char *, size_t);
};

struct blk_mq_queue_data___53;

struct blk_mq_ops___53 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___53 *, const struct blk_mq_queue_data___53 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___53 *);
	int (*get_budget)(struct request_queue___55 *);
	void (*put_budget)(struct request_queue___55 *, int);
	void (*set_rq_budget_token)(struct request___55 *, int);
	int (*get_rq_budget_token)(struct request___55 *);
	enum blk_eh_timer_return (*timeout)(struct request___55 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___53 *);
	void (*complete)(struct request___55 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___53 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___53 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___53 *, struct request___55 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___53 *, struct request___55 *, unsigned int);
	void (*initialize_rq_fn)(struct request___55 *);
	void (*cleanup_rq)(struct request___55 *);
	bool (*busy)(struct request_queue___55 *);
	int (*map_queues)(struct blk_mq_tag_set___53 *);
	void (*show_rq)(struct seq_file___107 *, struct request___55 *);
};

struct blk_mq_tag_set___53 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___53 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___53 {
	struct request___55 *rq;
	bool last;
};

struct blkcg_policy_data___53;

struct blkcg___53 {
	struct cgroup_subsys_state___90 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___53 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___53 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___53 {
	struct blkcg___53 *blkcg;
	int plid;
};

struct blkg_policy_data___53 {
	struct blkcg_gq___53 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___47 {
	struct mem_cgroup___47 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___47 {
	struct lruvec___53 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___47 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___47 *memcg;
};

struct obj_cgroup___47 {
	struct percpu_ref refcnt;
	struct mem_cgroup___47 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct mmu_notifier_range___11 {
	struct vm_area_struct___125 *vma;
	struct mm_struct___126 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct fs_parameter___20 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___120 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___20 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___110 *owner;
	char *buffer[8];
};

struct fs_context_operations___20 {
	void (*free)(struct fs_context___20 *);
	int (*dup)(struct fs_context___20 *, struct fs_context___20 *);
	int (*parse_param)(struct fs_context___20 *, struct fs_parameter___20 *);
	int (*parse_monolithic)(struct fs_context___20 *, void *);
	int (*get_tree)(struct fs_context___20 *);
	int (*reconfigure)(struct fs_context___20 *);
};

struct proc_ops___9 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___120 *, struct file___120 *);
	ssize_t (*proc_read)(struct file___120 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___120 *, struct iov_iter___68 *);
	ssize_t (*proc_write)(struct file___120 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___120 *, loff_t, int);
	int (*proc_release)(struct inode___120 *, struct file___120 *);
	__poll_t (*proc_poll)(struct file___120 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___120 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___120 *, struct vm_area_struct___125 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___120 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct linux_binprm___19 {
	struct vm_area_struct___125 *vma;
	long unsigned int vma_pages;
	struct mm_struct___126 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___120 *executable;
	struct file___120 *interpreter;
	struct file___120 *file;
	struct cred___15 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___18 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___120 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

union proc_op___2 {
	int (*proc_get_link)(struct dentry___120 *, struct path___120 *);
	int (*proc_show)(struct seq_file___107 *, struct pid_namespace___105 *, struct pid___105 *, struct task_struct___127 *);
	const char *lsm;
};

struct proc_inode___2 {
	struct pid___105 *pid;
	unsigned int fd;
	union proc_op___2 op;
	struct proc_dir_entry___3 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___16 *ns_ops;
	struct inode___120 vfs_inode;
};

struct proc_maps_private {
	struct inode___120 *inode;
	struct task_struct___127 *task;
	struct mm_struct___126 *mm;
	struct vm_area_struct___125 *tail_vma;
	struct mempolicy *task_mempolicy;
};

struct mem_size_stats {
	long unsigned int resident;
	long unsigned int shared_clean;
	long unsigned int shared_dirty;
	long unsigned int private_clean;
	long unsigned int private_dirty;
	long unsigned int referenced;
	long unsigned int anonymous;
	long unsigned int lazyfree;
	long unsigned int anonymous_thp;
	long unsigned int shmem_thp;
	long unsigned int file_thp;
	long unsigned int swap;
	long unsigned int shared_hugetlb;
	long unsigned int private_hugetlb;
	u64 pss;
	u64 pss_anon;
	u64 pss_file;
	u64 pss_shmem;
	u64 pss_locked;
	u64 swap_pss;
	bool check_shmem_swap;
};

enum clear_refs_types {
	CLEAR_REFS_ALL = 1,
	CLEAR_REFS_ANON = 2,
	CLEAR_REFS_MAPPED = 3,
	CLEAR_REFS_SOFT_DIRTY = 4,
	CLEAR_REFS_MM_HIWATER_RSS = 5,
	CLEAR_REFS_LAST = 6,
};

struct clear_refs_private {
	enum clear_refs_types type;
};

typedef struct {
	u64 pme;
} pagemap_entry_t;

struct pagemapread {
	int pos;
	int len;
	pagemap_entry_t *buffer;
	bool show_pfn;
};

struct numa_maps {
	long unsigned int pages;
	long unsigned int anon;
	long unsigned int active;
	long unsigned int writeback;
	long unsigned int mapcount_max;
	long unsigned int dirty;
	long unsigned int swapcache;
	long unsigned int node[64];
};

struct numa_maps_private {
	struct proc_maps_private proc_maps;
	struct numa_maps md;
};

struct dentry___121;

struct super_block___121;

struct module___111;

struct file_system_type___121 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___121 * (*mount)(struct file_system_type___121 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___121 *);
	struct module___111 *owner;
	struct file_system_type___121 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___121;

struct kiocb___121;

struct poll_table_struct___83;

struct vm_area_struct___126;

struct inode___121;

struct file_lock___121;

struct page___126;

struct file_operations___121 {
	struct module___111 *owner;
	loff_t (*llseek)(struct file___121 *, loff_t, int);
	ssize_t (*read)(struct file___121 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___121 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___121 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___121 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___121 *, bool);
	int (*iterate)(struct file___121 *, struct dir_context *);
	int (*iterate_shared)(struct file___121 *, struct dir_context *);
	__poll_t (*poll)(struct file___121 *, struct poll_table_struct___83 *);
	long int (*unlocked_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___121 *, struct vm_area_struct___126 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___121 *, struct file___121 *);
	int (*flush)(struct file___121 *, fl_owner_t);
	int (*release)(struct inode___121 *, struct file___121 *);
	int (*fsync)(struct file___121 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___121 *, int);
	int (*lock)(struct file___121 *, int, struct file_lock___121 *);
	ssize_t (*sendpage)(struct file___121 *, struct page___126 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___121 *, long unsigned int);
	int (*flock)(struct file___121 *, int, struct file_lock___121 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___121 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___121 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___121 *, long int, struct file_lock___121 **, void **);
	long int (*fallocate)(struct file___121 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___60 *, struct file___121 *);
	ssize_t (*copy_file_range)(struct file___121 *, loff_t, struct file___121 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___121 *, loff_t, struct file___121 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___121 *, loff_t, loff_t, int);
};

struct vmacache___126 {
	u64 seqnum;
	struct vm_area_struct___126 *vmas[4];
};

struct page_frag___126 {
	struct page___126 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___127;

struct pid___106;

struct nsproxy___112;

struct signal_struct___122;

struct task_struct___128 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___128 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___127 *mm;
	struct mm_struct___127 *active_mm;
	struct vmacache___126 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___128 *real_parent;
	struct task_struct___128 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___128 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___106 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___15 *ptracer_cred;
	const struct cred___15 *real_cred;
	const struct cred___15 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___112 *nsproxy;
	struct signal_struct___122 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___128 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___126 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___128 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___113;

struct kobj_type___113;

struct kernfs_node___113;

struct kobject___113 {
	const char *name;
	struct list_head entry;
	struct kobject___113 *parent;
	struct kset___113 *kset;
	struct kobj_type___113 *ktype;
	struct kernfs_node___113 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___110 {
	struct kobject___113 kobj;
	struct module___111 *mod;
	struct kobject___113 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___110 {
	struct module___111 *mod;
	struct latch_tree_node node;
};

struct module_layout___110 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___110 mtn;
};

struct module_attribute___110;

struct kernel_param___110;

struct module___111 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___110 mkobj;
	struct module_attribute___110 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___113 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___110 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___110 core_layout;
	struct module_layout___110 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___121;

struct dentry___121 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___121 *d_parent;
	struct qstr d_name;
	struct inode___121 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___121 *d_op;
	struct super_block___121 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___121;

struct address_space___121 {
	struct inode___121 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___121 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___121;

struct inode___121 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___121 *i_op;
	struct super_block___121 *i_sb;
	struct address_space___121 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___121 *i_fop;
		void (*free_inode)(struct inode___121 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___121 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___121;

struct path___121;

struct dentry_operations___121 {
	int (*d_revalidate)(struct dentry___121 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___121 *, unsigned int);
	int (*d_hash)(const struct dentry___121 *, struct qstr *);
	int (*d_compare)(const struct dentry___121 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___121 *);
	int (*d_init)(struct dentry___121 *);
	void (*d_release)(struct dentry___121 *);
	void (*d_prune)(struct dentry___121 *);
	void (*d_iput)(struct dentry___121 *, struct inode___121 *);
	char * (*d_dname)(struct dentry___121 *, char *, int);
	struct vfsmount___121 * (*d_automount)(struct path___121 *);
	int (*d_manage)(const struct path___121 *, bool);
	struct dentry___121 * (*d_real)(struct dentry___121 *, const struct inode___121 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___121;

struct mem_dqinfo___121 {
	struct quota_format_type___121 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___121;

struct quota_info___121 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___121 *files[3];
	struct mem_dqinfo___121 info[3];
	const struct quota_format_ops___121 *ops[3];
};

struct rcuwait___122 {
	struct task_struct___128 *task;
};

struct percpu_rw_semaphore___122 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___122 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___121 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___122 rw_sem[3];
};

struct super_operations___121;

struct dquot_operations___121;

struct quotactl_ops___121;

struct super_block___121 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___121 *s_type;
	const struct super_operations___121 *s_op;
	const struct dquot_operations___121 *dq_op;
	const struct quotactl_ops___121 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___121 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___121 s_dquot;
	struct sb_writers___121 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___121 *s_d_op;
	int cleancache_poolid;
	struct shrinker___47 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___121 {
	struct dentry___121 *mnt_root;
	struct super_block___121 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___121 {
	struct vfsmount___121 *mnt;
	struct dentry___121 *dentry;
};

struct pid_namespace___106;

struct upid___106 {
	int nr;
	struct pid_namespace___106 *ns;
};

struct proc_ns_operations___17;

struct ns_common___17 {
	atomic_long_t stashed;
	const struct proc_ns_operations___17 *ops;
	unsigned int inum;
	refcount_t count;
};

struct pid_namespace___106 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___128 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___106 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___17 ns;
};

struct pid___106 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___106 numbers[1];
};

typedef struct page___126 *pgtable_t___126;

struct dev_pagemap___119;

struct page___126 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___121 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___126 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___126 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___127 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___119 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___119;

struct vm_area_struct___126 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___126 *vm_next;
	struct vm_area_struct___126 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___127 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___119 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___121 *vm_file;
	struct file___121 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___122 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___128 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___128 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___106 *pids[4];
	struct pid___106 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___127 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___19;

struct core_state___126;

struct mm_struct___127 {
	struct {
		struct vm_area_struct___126 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___19 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___126 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___128 *owner;
		struct user_namespace *user_ns;
		struct file___121 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___112 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___106 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct dev_pagemap_ops___119;

struct dev_pagemap___119 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___119 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___106 {
	rwlock_t lock;
	struct pid___106 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___121 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___121 f_path;
	struct inode___121 *f_inode;
	const struct file_operations___121 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___106 f_owner;
	const struct cred___15 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___121 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___119;

struct vm_operations_struct___119 {
	void (*open)(struct vm_area_struct___126 *);
	void (*close)(struct vm_area_struct___126 *);
	int (*may_split)(struct vm_area_struct___126 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___126 *);
	int (*mprotect)(struct vm_area_struct___126 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___119 *);
	vm_fault_t (*huge_fault)(struct vm_fault___119 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___119 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___126 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___119 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___119 *);
	int (*access)(struct vm_area_struct___126 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___126 *);
	int (*set_policy)(struct vm_area_struct___126 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___126 *, long unsigned int);
	struct page___126 * (*find_special_page)(struct vm_area_struct___126 *, long unsigned int);
};

struct core_thread___126 {
	struct task_struct___128 *task;
	struct core_thread___126 *next;
};

struct core_state___126 {
	atomic_t nr_threads;
	struct core_thread___126 dumper;
	struct completion startup;
};

struct linux_binprm___20;

struct coredump_params___19;

struct linux_binfmt___19 {
	struct list_head lh;
	struct module___111 *module;
	int (*load_binary)(struct linux_binprm___20 *);
	int (*load_shlib)(struct file___121 *);
	int (*core_dump)(struct coredump_params___19 *);
	long unsigned int min_coredump;
};

struct vm_fault___119 {
	const struct {
		struct vm_area_struct___126 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___126 *cow_page;
	struct page___126 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___126 prealloc_pte;
};

struct kiocb___121 {
	struct file___121 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___121 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___54 *ki_waitq;
	};
};

struct iattr___121 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___121 *ia_file;
};

struct dquot___121 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___121 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___121 {
	int qf_fmt_id;
	const struct quota_format_ops___121 *qf_ops;
	struct module___111 *qf_owner;
	struct quota_format_type___121 *qf_next;
};

struct quota_format_ops___121 {
	int (*check_quota_file)(struct super_block___121 *, int);
	int (*read_file_info)(struct super_block___121 *, int);
	int (*write_file_info)(struct super_block___121 *, int);
	int (*free_file_info)(struct super_block___121 *, int);
	int (*read_dqblk)(struct dquot___121 *);
	int (*commit_dqblk)(struct dquot___121 *);
	int (*release_dqblk)(struct dquot___121 *);
	int (*get_next_id)(struct super_block___121 *, struct kqid *);
};

struct dquot_operations___121 {
	int (*write_dquot)(struct dquot___121 *);
	struct dquot___121 * (*alloc_dquot)(struct super_block___121 *, int);
	void (*destroy_dquot)(struct dquot___121 *);
	int (*acquire_dquot)(struct dquot___121 *);
	int (*release_dquot)(struct dquot___121 *);
	int (*mark_dirty)(struct dquot___121 *);
	int (*write_info)(struct super_block___121 *, int);
	qsize_t * (*get_reserved_space)(struct inode___121 *);
	int (*get_projid)(struct inode___121 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___121 *, qsize_t *);
	int (*get_next_id)(struct super_block___121 *, struct kqid *);
};

struct quotactl_ops___121 {
	int (*quota_on)(struct super_block___121 *, int, int, const struct path___121 *);
	int (*quota_off)(struct super_block___121 *, int);
	int (*quota_enable)(struct super_block___121 *, unsigned int);
	int (*quota_disable)(struct super_block___121 *, unsigned int);
	int (*quota_sync)(struct super_block___121 *, int);
	int (*set_info)(struct super_block___121 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___121 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___121 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___121 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___121 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___121 *, unsigned int);
};

struct address_space_operations___121 {
	int (*writepage)(struct page___126 *, struct writeback_control___3 *);
	int (*readpage)(struct file___121 *, struct page___126 *);
	int (*writepages)(struct address_space___121 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___126 *);
	int (*readpages)(struct file___121 *, struct address_space___121 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___121 *, struct address_space___121 *, loff_t, unsigned int, unsigned int, struct page___126 **, void **);
	int (*write_end)(struct file___121 *, struct address_space___121 *, loff_t, unsigned int, unsigned int, struct page___126 *, void *);
	sector_t (*bmap)(struct address_space___121 *, sector_t);
	void (*invalidatepage)(struct page___126 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___126 *, gfp_t);
	void (*freepage)(struct page___126 *);
	ssize_t (*direct_IO)(struct kiocb___121 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___121 *, struct page___126 *, struct page___126 *, enum migrate_mode);
	bool (*isolate_page)(struct page___126 *, isolate_mode_t);
	void (*putback_page)(struct page___126 *);
	int (*launder_page)(struct page___126 *);
	int (*is_partially_uptodate)(struct page___126 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___126 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___121 *, struct page___126 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___121 *, sector_t *);
	void (*swap_deactivate)(struct file___121 *);
};

struct inode_operations___121 {
	struct dentry___121 * (*lookup)(struct inode___121 *, struct dentry___121 *, unsigned int);
	const char * (*get_link)(struct dentry___121 *, struct inode___121 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___121 *, int);
	struct posix_acl * (*get_acl)(struct inode___121 *, int, bool);
	int (*readlink)(struct dentry___121 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___121 *, struct dentry___121 *, umode_t, bool);
	int (*link)(struct dentry___121 *, struct inode___121 *, struct dentry___121 *);
	int (*unlink)(struct inode___121 *, struct dentry___121 *);
	int (*symlink)(struct user_namespace *, struct inode___121 *, struct dentry___121 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___121 *, struct dentry___121 *, umode_t);
	int (*rmdir)(struct inode___121 *, struct dentry___121 *);
	int (*mknod)(struct user_namespace *, struct inode___121 *, struct dentry___121 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___121 *, struct dentry___121 *, struct inode___121 *, struct dentry___121 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___121 *, struct iattr___121 *);
	int (*getattr)(struct user_namespace *, const struct path___121 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___121 *, char *, size_t);
	int (*fiemap)(struct inode___121 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___121 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___121 *, struct dentry___121 *, struct file___121 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___121 *, struct dentry___121 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___121 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___121 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___121 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___121 {
	void (*fl_copy_lock)(struct file_lock___121 *, struct file_lock___121 *);
	void (*fl_release_private)(struct file_lock___121 *);
};

struct fasync_struct___121;

struct lock_manager_operations___121;

struct file_lock___121 {
	struct file_lock___121 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___121 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___121 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___121 *fl_ops;
	const struct lock_manager_operations___121 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___121 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___121 *);
	int (*lm_grant)(struct file_lock___121 *, int);
	bool (*lm_break)(struct file_lock___121 *);
	int (*lm_change)(struct file_lock___121 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___121 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___121 *);
};

struct fasync_struct___121 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___121 *fa_next;
	struct file___121 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___121 {
	struct inode___121 * (*alloc_inode)(struct super_block___121 *);
	void (*destroy_inode)(struct inode___121 *);
	void (*free_inode)(struct inode___121 *);
	void (*dirty_inode)(struct inode___121 *, int);
	int (*write_inode)(struct inode___121 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___121 *);
	void (*evict_inode)(struct inode___121 *);
	void (*put_super)(struct super_block___121 *);
	int (*sync_fs)(struct super_block___121 *, int);
	int (*freeze_super)(struct super_block___121 *);
	int (*freeze_fs)(struct super_block___121 *);
	int (*thaw_super)(struct super_block___121 *);
	int (*unfreeze_fs)(struct super_block___121 *);
	int (*statfs)(struct dentry___121 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___121 *, int *, char *);
	void (*umount_begin)(struct super_block___121 *);
	int (*show_options)(struct seq_file___60 *, struct dentry___121 *);
	int (*show_devname)(struct seq_file___60 *, struct dentry___121 *);
	int (*show_path)(struct seq_file___60 *, struct dentry___121 *);
	int (*show_stats)(struct seq_file___60 *, struct dentry___121 *);
	ssize_t (*quota_read)(struct super_block___121 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___121 *, int, const char *, size_t, loff_t);
	struct dquot___121 ** (*get_dquots)(struct inode___121 *);
	long int (*nr_cached_objects)(struct super_block___121 *, struct shrink_control___47 *);
	long int (*free_cached_objects)(struct super_block___121 *, struct shrink_control___47 *);
	struct file___121 * (*real_loop)(struct file___121 *);
};

typedef void (*poll_queue_proc___84)(struct file___121 *, wait_queue_head_t *, struct poll_table_struct___83 *);

struct poll_table_struct___83 {
	poll_queue_proc___84 _qproc;
	__poll_t _key;
};

struct seq_file___60 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___60 *op;
	int poll_event;
	const struct file___121 *file;
	void *private;
};

struct proc_ops___10 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___121 *, struct file___121 *);
	ssize_t (*proc_read)(struct file___121 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___121 *, struct iov_iter___4 *);
	ssize_t (*proc_write)(struct file___121 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___121 *, loff_t, int);
	int (*proc_release)(struct inode___121 *, struct file___121 *);
	__poll_t (*proc_poll)(struct file___121 *, struct poll_table_struct___83 *);
	long int (*proc_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___121 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___121 *, struct vm_area_struct___126 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___121 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct proc_fs_info___3 {
	struct pid_namespace___106 *pid_ns;
	struct dentry___121 *proc_self;
	struct dentry___121 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

typedef int (*proc_write_t___3)(struct file___121 *, char *, size_t);

struct dev_pagemap_ops___119 {
	void (*page_free)(struct page___126 *);
	void (*kill)(struct dev_pagemap___119 *);
	void (*cleanup)(struct dev_pagemap___119 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___119 *);
};

struct nsset___16 {
	unsigned int flags;
	struct nsproxy___112 *nsproxy;
	struct fs_struct *fs;
	const struct cred___15 *cred;
};

struct proc_ns_operations___17 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___17 * (*get)(struct task_struct___128 *);
	void (*put)(struct ns_common___17 *);
	int (*install)(struct nsset___16 *, struct ns_common___17 *);
	struct user_namespace * (*owner)(struct ns_common___17 *);
	struct ns_common___17 * (*get_parent)(struct ns_common___17 *);
};

struct kernfs_root___113;

struct kernfs_elem_dir___113 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___113 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___113;

struct kernfs_root___113 {
	struct kernfs_node___113 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___113 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___113 {
	struct kernfs_node___113 *target_kn;
};

struct kernfs_ops___113;

struct kernfs_elem_attr___113 {
	const struct kernfs_ops___113 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___113 *notify_next;
};

struct kernfs_node___113 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___113 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___113 dir;
		struct kernfs_elem_symlink___113 symlink;
		struct kernfs_elem_attr___113 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___113;

struct kernfs_ops___113 {
	int (*open)(struct kernfs_open_file___113 *);
	void (*release)(struct kernfs_open_file___113 *);
	int (*seq_show)(struct seq_file___60 *, void *);
	void * (*seq_start)(struct seq_file___60 *, loff_t *);
	void * (*seq_next)(struct seq_file___60 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___60 *, void *);
	ssize_t (*read)(struct kernfs_open_file___113 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___113 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___113 *, struct poll_table_struct___83 *);
	int (*mmap)(struct kernfs_open_file___113 *, struct vm_area_struct___126 *);
};

struct kernfs_syscall_ops___113 {
	int (*show_options)(struct seq_file___60 *, struct kernfs_root___113 *);
	int (*mkdir)(struct kernfs_node___113 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___113 *);
	int (*rename)(struct kernfs_node___113 *, struct kernfs_node___113 *, const char *);
	int (*show_path)(struct seq_file___60 *, struct kernfs_node___113 *, struct kernfs_root___113 *);
};

struct kernfs_open_file___113 {
	struct kernfs_node___113 *kn;
	struct file___121 *file;
	struct seq_file___60 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___119 *vm_ops;
};

struct bin_attribute___113;

struct attribute_group___113 {
	const char *name;
	umode_t (*is_visible)(struct kobject___113 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___113 *, struct bin_attribute___113 *, int);
	struct attribute **attrs;
	struct bin_attribute___113 **bin_attrs;
};

struct bin_attribute___113 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___121 * (*f_mapping)();
	ssize_t (*read)(struct file___121 *, struct kobject___113 *, struct bin_attribute___113 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___121 *, struct kobject___113 *, struct bin_attribute___113 *, char *, loff_t, size_t);
	int (*mmap)(struct file___121 *, struct kobject___113 *, struct bin_attribute___113 *, struct vm_area_struct___126 *);
};

struct sysfs_ops___113 {
	ssize_t (*show)(struct kobject___113 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___113 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___113;

struct kset___113 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___113 kobj;
	const struct kset_uevent_ops___113 *uevent_ops;
};

struct kobj_type___113 {
	void (*release)(struct kobject___113 *);
	const struct sysfs_ops___113 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___113 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___113 *);
	const void * (*namespace)(struct kobject___113 *);
	void (*get_ownership)(struct kobject___113 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___113 {
	int (* const filter)(struct kset___113 *, struct kobject___113 *);
	const char * (* const name)(struct kset___113 *, struct kobject___113 *);
	int (* const uevent)(struct kset___113 *, struct kobject___113 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___110 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___110 *);
	int (*get)(char *, const struct kernel_param___110 *);
	void (*free)(void *);
};

struct kparam_array___110;

struct kernel_param___110 {
	const char *name;
	struct module___111 *mod;
	const struct kernel_param_ops___110 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___110 *arr;
	};
};

struct kparam_array___110 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___110 *ops;
	void *elem;
};

struct module_attribute___110 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___110 *, struct module_kobject___110 *, char *);
	ssize_t (*store)(struct module_attribute___110 *, struct module_kobject___110 *, const char *, size_t);
	void (*setup)(struct module___111 *, const char *);
	int (*test)(struct module___111 *);
	void (*free)(struct module___111 *);
};

struct linux_binprm___20 {
	struct vm_area_struct___126 *vma;
	long unsigned int vma_pages;
	struct mm_struct___127 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___121 *executable;
	struct file___121 *interpreter;
	struct file___121 *file;
	struct cred___15 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___19 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___121 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct proc_dir_entry___4 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___121 *proc_iops;
	union {
		const struct proc_ops___10 *proc_ops;
		const struct file_operations___121 *proc_dir_ops;
	};
	const struct dentry_operations___121 *proc_dops;
	union {
		const struct seq_operations___60 *seq_ops;
		int (*single_show)(struct seq_file___60 *, void *);
	};
	proc_write_t___3 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___4 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

union proc_op___3 {
	int (*proc_get_link)(struct dentry___121 *, struct path___121 *);
	int (*proc_show)(struct seq_file___60 *, struct pid_namespace___106 *, struct pid___106 *, struct task_struct___128 *);
	const char *lsm;
};

struct proc_inode___3 {
	struct pid___106 *pid;
	unsigned int fd;
	union proc_op___3 op;
	struct proc_dir_entry___4 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___17 *ns_ops;
	struct inode___121 vfs_inode;
};

struct pde_opener {
	struct list_head lh;
	struct file___121 *file;
	bool closing;
	struct completion *c;
};

enum {
	BIAS = 2147483648,
};

struct fs_context___21;

struct fs_parameter_spec___16;

struct dentry___122;

struct super_block___122;

struct module___112;

struct file_system_type___122 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___21 *);
	const struct fs_parameter_spec___16 *parameters;
	struct dentry___122 * (*mount)(struct file_system_type___122 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___122 *);
	struct module___112 *owner;
	struct file_system_type___122 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___122;

struct kiocb___122;

struct vm_area_struct___127;

struct inode___122;

struct file_lock___122;

struct page___127;

struct file_operations___122 {
	struct module___112 *owner;
	loff_t (*llseek)(struct file___122 *, loff_t, int);
	ssize_t (*read)(struct file___122 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___122 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___122 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___122 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___122 *, bool);
	int (*iterate)(struct file___122 *, struct dir_context *);
	int (*iterate_shared)(struct file___122 *, struct dir_context *);
	__poll_t (*poll)(struct file___122 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___122 *, struct vm_area_struct___127 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___122 *, struct file___122 *);
	int (*flush)(struct file___122 *, fl_owner_t);
	int (*release)(struct inode___122 *, struct file___122 *);
	int (*fsync)(struct file___122 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___122 *, int);
	int (*lock)(struct file___122 *, int, struct file_lock___122 *);
	ssize_t (*sendpage)(struct file___122 *, struct page___127 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___122 *, long unsigned int);
	int (*flock)(struct file___122 *, int, struct file_lock___122 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___122 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___122 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___122 *, long int, struct file_lock___122 **, void **);
	long int (*fallocate)(struct file___122 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___122 *);
	ssize_t (*copy_file_range)(struct file___122 *, loff_t, struct file___122 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___122 *, loff_t, struct file___122 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___122 *, loff_t, loff_t, int);
};

struct vmacache___127 {
	u64 seqnum;
	struct vm_area_struct___127 *vmas[4];
};

struct page_frag___127 {
	struct page___127 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___128;

struct pid___107;

struct cred___16;

struct nsproxy___113;

struct signal_struct___123;

struct task_struct___129 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___129 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___128 *mm;
	struct mm_struct___128 *active_mm;
	struct vmacache___127 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___129 *real_parent;
	struct task_struct___129 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___129 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___107 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___16 *ptracer_cred;
	const struct cred___16 *real_cred;
	const struct cred___16 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___113 *nsproxy;
	struct signal_struct___123 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___129 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___55 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___127 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___129 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___114;

struct kobj_type___114;

struct kernfs_node___114;

struct kobject___114 {
	const char *name;
	struct list_head entry;
	struct kobject___114 *parent;
	struct kset___114 *kset;
	struct kobj_type___114 *ktype;
	struct kernfs_node___114 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___111 {
	struct kobject___114 kobj;
	struct module___112 *mod;
	struct kobject___114 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___111 {
	struct module___112 *mod;
	struct latch_tree_node node;
};

struct module_layout___111 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___111 mtn;
};

struct module_attribute___111;

struct kernel_param___111;

struct module___112 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___111 mkobj;
	struct module_attribute___111 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___114 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___111 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___111 core_layout;
	struct module_layout___111 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___107;

struct upid___107 {
	int nr;
	struct pid_namespace___107 *ns;
};

struct proc_ns_operations___18;

struct ns_common___18 {
	atomic_long_t stashed;
	const struct proc_ns_operations___18 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___16;

struct ucounts___16;

struct pid_namespace___107 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___129 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___107 *parent;
	struct fs_pin *bacct;
	struct user_namespace___16 *user_ns;
	struct ucounts___16 *ucounts;
	int reboot;
	struct ns_common___18 ns;
};

struct pid___107 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___107 numbers[1];
};

struct user_namespace___16 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___16 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___18 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___3 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___3 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___16 *ucounts;
	long int ucount_max[16];
};

typedef struct page___127 *pgtable_t___127;

struct address_space___122;

struct dev_pagemap___120;

struct page___127 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___122 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___127 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___127 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___128 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___120 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___16 {
	struct hlist_node node;
	struct user_namespace___16 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___120;

struct vm_area_struct___127 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___127 *vm_next;
	struct vm_area_struct___127 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___128 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___120 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___122 *vm_file;
	struct file___122 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___123 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___129 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___129 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___107 *pids[4];
	struct pid___107 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___128 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___20;

struct core_state___127;

struct mm_struct___128 {
	struct {
		struct vm_area_struct___127 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___20 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___127 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___129 *owner;
		struct user_namespace___16 *user_ns;
		struct file___122 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___16 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___16 *user_ns;
	struct ucounts___16 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct nsproxy___113 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___107 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct address_space_operations___122;

struct address_space___122 {
	struct inode___122 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___122 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___120;

struct dev_pagemap___120 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___120 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___122;

struct path___122 {
	struct vfsmount___122 *mnt;
	struct dentry___122 *dentry;
};

struct fown_struct___107 {
	rwlock_t lock;
	struct pid___107 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___122 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___122 f_path;
	struct inode___122 *f_inode;
	const struct file_operations___122 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___107 f_owner;
	const struct cred___16 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___122 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___120;

struct vm_operations_struct___120 {
	void (*open)(struct vm_area_struct___127 *);
	void (*close)(struct vm_area_struct___127 *);
	int (*may_split)(struct vm_area_struct___127 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___127 *);
	int (*mprotect)(struct vm_area_struct___127 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___120 *);
	vm_fault_t (*huge_fault)(struct vm_fault___120 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___120 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___127 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___120 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___120 *);
	int (*access)(struct vm_area_struct___127 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___127 *);
	int (*set_policy)(struct vm_area_struct___127 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___127 *, long unsigned int);
	struct page___127 * (*find_special_page)(struct vm_area_struct___127 *, long unsigned int);
};

struct core_thread___127 {
	struct task_struct___129 *task;
	struct core_thread___127 *next;
};

struct core_state___127 {
	atomic_t nr_threads;
	struct core_thread___127 dumper;
	struct completion startup;
};

struct linux_binprm___21;

struct coredump_params___20;

struct linux_binfmt___20 {
	struct list_head lh;
	struct module___112 *module;
	int (*load_binary)(struct linux_binprm___21 *);
	int (*load_shlib)(struct file___122 *);
	int (*core_dump)(struct coredump_params___20 *);
	long unsigned int min_coredump;
};

struct vm_fault___120 {
	const struct {
		struct vm_area_struct___127 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___127 *cow_page;
	struct page___127 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___127 prealloc_pte;
};

struct dentry_operations___122;

struct dentry___122 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___122 *d_parent;
	struct qstr d_name;
	struct inode___122 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___122 *d_op;
	struct super_block___122 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___122;

struct inode___122 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___122 *i_op;
	struct super_block___122 *i_sb;
	struct address_space___122 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___122 *i_fop;
		void (*free_inode)(struct inode___122 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___122 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___122 {
	int (*d_revalidate)(struct dentry___122 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___122 *, unsigned int);
	int (*d_hash)(const struct dentry___122 *, struct qstr *);
	int (*d_compare)(const struct dentry___122 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___122 *);
	int (*d_init)(struct dentry___122 *);
	void (*d_release)(struct dentry___122 *);
	void (*d_prune)(struct dentry___122 *);
	void (*d_iput)(struct dentry___122 *, struct inode___122 *);
	char * (*d_dname)(struct dentry___122 *, char *, int);
	struct vfsmount___122 * (*d_automount)(struct path___122 *);
	int (*d_manage)(const struct path___122 *, bool);
	struct dentry___122 * (*d_real)(struct dentry___122 *, const struct inode___122 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___122;

struct mem_dqinfo___122 {
	struct quota_format_type___122 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___122;

struct quota_info___122 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___122 *files[3];
	struct mem_dqinfo___122 info[3];
	const struct quota_format_ops___122 *ops[3];
};

struct rcuwait___123 {
	struct task_struct___129 *task;
};

struct percpu_rw_semaphore___123 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___123 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___122 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___123 rw_sem[3];
};

struct super_operations___122;

struct dquot_operations___122;

struct quotactl_ops___122;

struct super_block___122 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___122 *s_type;
	const struct super_operations___122 *s_op;
	const struct dquot_operations___122 *dq_op;
	const struct quotactl_ops___122 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___122 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___122 s_dquot;
	struct sb_writers___122 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___122 *s_d_op;
	int cleancache_poolid;
	struct shrinker___47 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___16 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___122 {
	struct dentry___122 *mnt_root;
	struct super_block___122 *mnt_sb;
	int mnt_flags;
	struct user_namespace___16 *mnt_userns;
};

struct kiocb___122 {
	struct file___122 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___122 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___54 *ki_waitq;
	};
};

struct iattr___122 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___122 *ia_file;
};

struct dquot___122 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___122 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___122 {
	int qf_fmt_id;
	const struct quota_format_ops___122 *qf_ops;
	struct module___112 *qf_owner;
	struct quota_format_type___122 *qf_next;
};

struct quota_format_ops___122 {
	int (*check_quota_file)(struct super_block___122 *, int);
	int (*read_file_info)(struct super_block___122 *, int);
	int (*write_file_info)(struct super_block___122 *, int);
	int (*free_file_info)(struct super_block___122 *, int);
	int (*read_dqblk)(struct dquot___122 *);
	int (*commit_dqblk)(struct dquot___122 *);
	int (*release_dqblk)(struct dquot___122 *);
	int (*get_next_id)(struct super_block___122 *, struct kqid *);
};

struct dquot_operations___122 {
	int (*write_dquot)(struct dquot___122 *);
	struct dquot___122 * (*alloc_dquot)(struct super_block___122 *, int);
	void (*destroy_dquot)(struct dquot___122 *);
	int (*acquire_dquot)(struct dquot___122 *);
	int (*release_dquot)(struct dquot___122 *);
	int (*mark_dirty)(struct dquot___122 *);
	int (*write_info)(struct super_block___122 *, int);
	qsize_t * (*get_reserved_space)(struct inode___122 *);
	int (*get_projid)(struct inode___122 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___122 *, qsize_t *);
	int (*get_next_id)(struct super_block___122 *, struct kqid *);
};

struct quotactl_ops___122 {
	int (*quota_on)(struct super_block___122 *, int, int, const struct path___122 *);
	int (*quota_off)(struct super_block___122 *, int);
	int (*quota_enable)(struct super_block___122 *, unsigned int);
	int (*quota_disable)(struct super_block___122 *, unsigned int);
	int (*quota_sync)(struct super_block___122 *, int);
	int (*set_info)(struct super_block___122 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___122 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___122 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___122 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___122 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___122 *, unsigned int);
};

struct address_space_operations___122 {
	int (*writepage)(struct page___127 *, struct writeback_control___3 *);
	int (*readpage)(struct file___122 *, struct page___127 *);
	int (*writepages)(struct address_space___122 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___127 *);
	int (*readpages)(struct file___122 *, struct address_space___122 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___122 *, struct address_space___122 *, loff_t, unsigned int, unsigned int, struct page___127 **, void **);
	int (*write_end)(struct file___122 *, struct address_space___122 *, loff_t, unsigned int, unsigned int, struct page___127 *, void *);
	sector_t (*bmap)(struct address_space___122 *, sector_t);
	void (*invalidatepage)(struct page___127 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___127 *, gfp_t);
	void (*freepage)(struct page___127 *);
	ssize_t (*direct_IO)(struct kiocb___122 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___122 *, struct page___127 *, struct page___127 *, enum migrate_mode);
	bool (*isolate_page)(struct page___127 *, isolate_mode_t);
	void (*putback_page)(struct page___127 *);
	int (*launder_page)(struct page___127 *);
	int (*is_partially_uptodate)(struct page___127 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___127 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___122 *, struct page___127 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___122 *, sector_t *);
	void (*swap_deactivate)(struct file___122 *);
};

struct inode_operations___122 {
	struct dentry___122 * (*lookup)(struct inode___122 *, struct dentry___122 *, unsigned int);
	const char * (*get_link)(struct dentry___122 *, struct inode___122 *, struct delayed_call *);
	int (*permission)(struct user_namespace___16 *, struct inode___122 *, int);
	struct posix_acl * (*get_acl)(struct inode___122 *, int, bool);
	int (*readlink)(struct dentry___122 *, char *, int);
	int (*create)(struct user_namespace___16 *, struct inode___122 *, struct dentry___122 *, umode_t, bool);
	int (*link)(struct dentry___122 *, struct inode___122 *, struct dentry___122 *);
	int (*unlink)(struct inode___122 *, struct dentry___122 *);
	int (*symlink)(struct user_namespace___16 *, struct inode___122 *, struct dentry___122 *, const char *);
	int (*mkdir)(struct user_namespace___16 *, struct inode___122 *, struct dentry___122 *, umode_t);
	int (*rmdir)(struct inode___122 *, struct dentry___122 *);
	int (*mknod)(struct user_namespace___16 *, struct inode___122 *, struct dentry___122 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___16 *, struct inode___122 *, struct dentry___122 *, struct inode___122 *, struct dentry___122 *, unsigned int);
	int (*setattr)(struct user_namespace___16 *, struct dentry___122 *, struct iattr___122 *);
	int (*getattr)(struct user_namespace___16 *, const struct path___122 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___122 *, char *, size_t);
	int (*fiemap)(struct inode___122 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___122 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___122 *, struct dentry___122 *, struct file___122 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___16 *, struct inode___122 *, struct dentry___122 *, umode_t);
	int (*set_acl)(struct user_namespace___16 *, struct inode___122 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___16 *, struct dentry___122 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___122 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___122 {
	void (*fl_copy_lock)(struct file_lock___122 *, struct file_lock___122 *);
	void (*fl_release_private)(struct file_lock___122 *);
};

struct fasync_struct___122;

struct lock_manager_operations___122;

struct file_lock___122 {
	struct file_lock___122 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___122 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___122 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___122 *fl_ops;
	const struct lock_manager_operations___122 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___122 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___122 *);
	int (*lm_grant)(struct file_lock___122 *, int);
	bool (*lm_break)(struct file_lock___122 *);
	int (*lm_change)(struct file_lock___122 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___122 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___122 *);
};

struct fasync_struct___122 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___122 *fa_next;
	struct file___122 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___122 {
	struct inode___122 * (*alloc_inode)(struct super_block___122 *);
	void (*destroy_inode)(struct inode___122 *);
	void (*free_inode)(struct inode___122 *);
	void (*dirty_inode)(struct inode___122 *, int);
	int (*write_inode)(struct inode___122 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___122 *);
	void (*evict_inode)(struct inode___122 *);
	void (*put_super)(struct super_block___122 *);
	int (*sync_fs)(struct super_block___122 *, int);
	int (*freeze_super)(struct super_block___122 *);
	int (*freeze_fs)(struct super_block___122 *);
	int (*thaw_super)(struct super_block___122 *);
	int (*unfreeze_fs)(struct super_block___122 *);
	int (*statfs)(struct dentry___122 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___122 *, int *, char *);
	void (*umount_begin)(struct super_block___122 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___122 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___122 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___122 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___122 *);
	ssize_t (*quota_read)(struct super_block___122 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___122 *, int, const char *, size_t, loff_t);
	struct dquot___122 ** (*get_dquots)(struct inode___122 *);
	long int (*nr_cached_objects)(struct super_block___122 *, struct shrink_control___47 *);
	long int (*free_cached_objects)(struct super_block___122 *, struct shrink_control___47 *);
	struct file___122 * (*real_loop)(struct file___122 *);
};

struct fc_log___21;

struct p_log___21 {
	const char *prefix;
	struct fc_log___21 *log;
};

struct fs_context_operations___21;

struct fs_context___21 {
	const struct fs_context_operations___21 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___122 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___122 *root;
	struct user_namespace___16 *user_ns;
	struct net *net_ns;
	const struct cred___16 *cred;
	struct p_log___21 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___21;

typedef int fs_param_type___16(struct p_log___21 *, const struct fs_parameter_spec___16 *, struct fs_parameter___21 *, struct fs_parse_result *);

struct fs_parameter_spec___16 {
	const char *name;
	fs_param_type___16 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct proc_ops___11 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___122 *, struct file___122 *);
	ssize_t (*proc_read)(struct file___122 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___122 *, struct iov_iter___4 *);
	ssize_t (*proc_write)(struct file___122 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___122 *, loff_t, int);
	int (*proc_release)(struct inode___122 *, struct file___122 *);
	__poll_t (*proc_poll)(struct file___122 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___122 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___122 *, struct vm_area_struct___127 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___122 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct proc_fs_info___4 {
	struct pid_namespace___107 *pid_ns;
	struct dentry___122 *proc_self;
	struct dentry___122 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

typedef int (*proc_write_t___4)(struct file___122 *, char *, size_t);

struct kernfs_root___114;

struct kernfs_elem_dir___114 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___114 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___114;

struct kernfs_root___114 {
	struct kernfs_node___114 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___114 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___114 {
	struct kernfs_node___114 *target_kn;
};

struct kernfs_ops___114;

struct kernfs_elem_attr___114 {
	const struct kernfs_ops___114 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___114 *notify_next;
};

struct kernfs_node___114 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___114 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___114 dir;
		struct kernfs_elem_symlink___114 symlink;
		struct kernfs_elem_attr___114 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___114;

struct kernfs_ops___114 {
	int (*open)(struct kernfs_open_file___114 *);
	void (*release)(struct kernfs_open_file___114 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___114 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___114 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___114 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___114 *, struct vm_area_struct___127 *);
};

struct kernfs_syscall_ops___114 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___114 *);
	int (*mkdir)(struct kernfs_node___114 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___114 *);
	int (*rename)(struct kernfs_node___114 *, struct kernfs_node___114 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___114 *, struct kernfs_root___114 *);
};

struct kernfs_open_file___114 {
	struct kernfs_node___114 *kn;
	struct file___122 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___120 *vm_ops;
};

struct bin_attribute___114;

struct attribute_group___114 {
	const char *name;
	umode_t (*is_visible)(struct kobject___114 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___114 *, struct bin_attribute___114 *, int);
	struct attribute **attrs;
	struct bin_attribute___114 **bin_attrs;
};

struct bin_attribute___114 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___122 * (*f_mapping)();
	ssize_t (*read)(struct file___122 *, struct kobject___114 *, struct bin_attribute___114 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___122 *, struct kobject___114 *, struct bin_attribute___114 *, char *, loff_t, size_t);
	int (*mmap)(struct file___122 *, struct kobject___114 *, struct bin_attribute___114 *, struct vm_area_struct___127 *);
};

struct sysfs_ops___114 {
	ssize_t (*show)(struct kobject___114 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___114 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___114;

struct kset___114 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___114 kobj;
	const struct kset_uevent_ops___114 *uevent_ops;
};

struct kobj_type___114 {
	void (*release)(struct kobject___114 *);
	const struct sysfs_ops___114 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___114 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___114 *);
	const void * (*namespace)(struct kobject___114 *);
	void (*get_ownership)(struct kobject___114 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___114 {
	int (* const filter)(struct kset___114 *, struct kobject___114 *);
	const char * (* const name)(struct kset___114 *, struct kobject___114 *);
	int (* const uevent)(struct kset___114 *, struct kobject___114 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___111 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___111 *);
	int (*get)(char *, const struct kernel_param___111 *);
	void (*free)(void *);
};

struct kparam_array___111;

struct kernel_param___111 {
	const char *name;
	struct module___112 *mod;
	const struct kernel_param_ops___111 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___111 *arr;
	};
};

struct kparam_array___111 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___111 *ops;
	void *elem;
};

struct module_attribute___111 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___111 *, struct module_kobject___111 *, char *);
	ssize_t (*store)(struct module_attribute___111 *, struct module_kobject___111 *, const char *, size_t);
	void (*setup)(struct module___112 *, const char *);
	int (*test)(struct module___112 *);
	void (*free)(struct module___112 *);
};

struct nsset___17 {
	unsigned int flags;
	struct nsproxy___113 *nsproxy;
	struct fs_struct *fs;
	const struct cred___16 *cred;
};

struct proc_ns_operations___18 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___18 * (*get)(struct task_struct___129 *);
	void (*put)(struct ns_common___18 *);
	int (*install)(struct nsset___17 *, struct ns_common___18 *);
	struct user_namespace___16 * (*owner)(struct ns_common___18 *);
	struct ns_common___18 * (*get_parent)(struct ns_common___18 *);
};

struct dev_pagemap_ops___120 {
	void (*page_free)(struct page___127 *);
	void (*kill)(struct dev_pagemap___120 *);
	void (*cleanup)(struct dev_pagemap___120 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___120 *);
};

struct fs_parameter___21 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___122 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___21 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___112 *owner;
	char *buffer[8];
};

struct fs_context_operations___21 {
	void (*free)(struct fs_context___21 *);
	int (*dup)(struct fs_context___21 *, struct fs_context___21 *);
	int (*parse_param)(struct fs_context___21 *, struct fs_parameter___21 *);
	int (*parse_monolithic)(struct fs_context___21 *, void *);
	int (*get_tree)(struct fs_context___21 *);
	int (*reconfigure)(struct fs_context___21 *);
};

struct linux_binprm___21 {
	struct vm_area_struct___127 *vma;
	long unsigned int vma_pages;
	struct mm_struct___128 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___122 *executable;
	struct file___122 *interpreter;
	struct file___122 *file;
	struct cred___16 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___20 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___122 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct proc_dir_entry___5 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___122 *proc_iops;
	union {
		const struct proc_ops___11 *proc_ops;
		const struct file_operations___122 *proc_dir_ops;
	};
	const struct dentry_operations___122 *proc_dops;
	union {
		const struct seq_operations___60 *seq_ops;
		int (*single_show)(struct seq_file___60 *, void *);
	};
	proc_write_t___4 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___5 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct proc_fs_context {
	struct pid_namespace___107 *pid_ns;
	unsigned int mask;
	enum proc_hidepid hidepid;
	int gid;
	enum proc_pidonly pidonly;
};

enum proc_param {
	Opt_gid___2 = 0,
	Opt_hidepid = 1,
	Opt_subset = 2,
};

struct dentry___123;

struct super_block___123;

struct module___113;

struct file_system_type___123 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___123 * (*mount)(struct file_system_type___123 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___123 *);
	struct module___113 *owner;
	struct file_system_type___123 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___123;

struct kiocb___123;

struct iov_iter___69;

struct poll_table_struct___84;

struct vm_area_struct___128;

struct inode___123;

struct file_lock___123;

struct page___128;

struct seq_file___108;

struct file_operations___123 {
	struct module___113 *owner;
	loff_t (*llseek)(struct file___123 *, loff_t, int);
	ssize_t (*read)(struct file___123 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___123 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___123 *, struct iov_iter___69 *);
	ssize_t (*write_iter)(struct kiocb___123 *, struct iov_iter___69 *);
	int (*iopoll)(struct kiocb___123 *, bool);
	int (*iterate)(struct file___123 *, struct dir_context *);
	int (*iterate_shared)(struct file___123 *, struct dir_context *);
	__poll_t (*poll)(struct file___123 *, struct poll_table_struct___84 *);
	long int (*unlocked_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___123 *, struct vm_area_struct___128 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___123 *, struct file___123 *);
	int (*flush)(struct file___123 *, fl_owner_t);
	int (*release)(struct inode___123 *, struct file___123 *);
	int (*fsync)(struct file___123 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___123 *, int);
	int (*lock)(struct file___123 *, int, struct file_lock___123 *);
	ssize_t (*sendpage)(struct file___123 *, struct page___128 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___123 *, long unsigned int);
	int (*flock)(struct file___123 *, int, struct file_lock___123 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___123 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___123 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___123 *, long int, struct file_lock___123 **, void **);
	long int (*fallocate)(struct file___123 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___108 *, struct file___123 *);
	ssize_t (*copy_file_range)(struct file___123 *, loff_t, struct file___123 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___123 *, loff_t, struct file___123 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___123 *, loff_t, loff_t, int);
};

struct vmacache___128 {
	u64 seqnum;
	struct vm_area_struct___128 *vmas[4];
};

struct page_frag___128 {
	struct page___128 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___129;

struct pid___108;

struct cred___17;

struct fs_struct___19;

struct files_struct___16;

struct nsproxy___114;

struct signal_struct___124;

struct bio_list___56;

struct backing_dev_info___54;

struct io_context___56;

struct css_set___91;

struct mem_cgroup___48;

struct request_queue___56;

struct vm_struct___111;

struct task_struct___130 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___130 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___129 *mm;
	struct mm_struct___129 *active_mm;
	struct vmacache___128 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___130 *real_parent;
	struct task_struct___130 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___130 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___108 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___17 *ptracer_cred;
	const struct cred___17 *real_cred;
	const struct cred___17 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___19 *fs;
	struct files_struct___16 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___114 *nsproxy;
	struct signal_struct___124 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___130 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___56 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___54 *backing_dev_info;
	struct io_context___56 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___91 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___128 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___48 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___48 *active_memcg;
	struct request_queue___56 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___130 *oom_reaper_list;
	struct vm_struct___111 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___115;

struct kobj_type___115;

struct kernfs_node___115;

struct kobject___115 {
	const char *name;
	struct list_head entry;
	struct kobject___115 *parent;
	struct kset___115 *kset;
	struct kobj_type___115 *ktype;
	struct kernfs_node___115 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___112 {
	struct kobject___115 kobj;
	struct module___113 *mod;
	struct kobject___115 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___112 {
	struct module___113 *mod;
	struct latch_tree_node node;
};

struct module_layout___112 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___112 mtn;
};

struct module_attribute___112;

struct kernel_param___112;

struct module___113 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___112 mkobj;
	struct module_attribute___112 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___115 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___112 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___112 core_layout;
	struct module_layout___112 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___108;

struct upid___108 {
	int nr;
	struct pid_namespace___108 *ns;
};

struct proc_ns_operations___19;

struct ns_common___19 {
	atomic_long_t stashed;
	const struct proc_ns_operations___19 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___17;

struct ucounts___17;

struct pid_namespace___108 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___130 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___108 *parent;
	struct fs_pin *bacct;
	struct user_namespace___17 *user_ns;
	struct ucounts___17 *ucounts;
	int reboot;
	struct ns_common___19 ns;
};

struct pid___108 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___108 numbers[1];
};

struct user_namespace___17 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___17 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___19 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___3 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___3 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___17 *ucounts;
	long int ucount_max[16];
};

typedef struct page___128 *pgtable_t___128;

struct address_space___123;

struct dev_pagemap___121;

struct page___128 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___123 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___128 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___128 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___129 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___121 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct sigqueue___2 {
	struct list_head list;
	int flags;
	kernel_siginfo_t info;
	struct ucounts___17 *ucounts;
};

struct ucounts___17 {
	struct hlist_node node;
	struct user_namespace___17 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___121;

struct vm_area_struct___128 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___128 *vm_next;
	struct vm_area_struct___128 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___129 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___121 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___123 *vm_file;
	struct file___123 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct cpu_timer___2 {
	struct timerqueue_node node;
	struct timerqueue_head *head;
	struct pid___108 *pid;
	struct list_head elist;
	int firing;
};

struct k_clock___3;

struct k_itimer___3 {
	struct list_head list;
	struct hlist_node t_hash;
	spinlock_t it_lock;
	const struct k_clock___3 *kclock;
	clockid_t it_clock;
	timer_t it_id;
	int it_active;
	s64 it_overrun;
	s64 it_overrun_last;
	int it_requeue_pending;
	int it_sigev_notify;
	ktime_t it_interval;
	struct signal_struct___124 *it_signal;
	union {
		struct pid___108 *it_pid;
		struct task_struct___130 *it_process;
	};
	struct sigqueue___2 *sigq;
	union {
		struct {
			struct hrtimer timer;
		} real;
		struct cpu_timer___2 cpu;
		struct {
			struct alarm alarmtimer;
		} alarm;
	} it;
	struct callback_head rcu;
};

struct signal_struct___124 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___130 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___130 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___108 *pids[4];
	struct pid___108 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___129 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___21;

struct core_state___128;

struct mm_struct___129 {
	struct {
		struct vm_area_struct___128 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___21 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___128 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___130 *owner;
		struct user_namespace___17 *user_ns;
		struct file___123 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___17 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___17 *user_ns;
	struct ucounts___17 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct vfsmount___123;

struct path___123 {
	struct vfsmount___123 *mnt;
	struct dentry___123 *dentry;
};

struct fs_struct___19 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___123 root;
	struct path___123 pwd;
};

struct fdtable___16 {
	unsigned int max_fds;
	struct file___123 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___16 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___16 *fdt;
	struct fdtable___16 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___123 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct time_namespace___6;

struct cgroup_namespace___91;

struct nsproxy___114 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___108 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace___6 *time_ns;
	struct time_namespace___6 *time_ns_for_children;
	struct cgroup_namespace___91 *cgroup_ns;
};

struct bio___56;

struct bio_list___56 {
	struct bio___56 *head;
	struct bio___56 *tail;
};

struct cgroup_subsys_state___91;

struct bdi_writeback___54 {
	struct backing_dev_info___54 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___91 *memcg_css;
	struct cgroup_subsys_state___91 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___93;

struct backing_dev_info___54 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___54 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___93 *dev;
	char dev_name[64];
	struct device___93 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___123 *debug_dir;
};

struct io_cq___56;

struct io_context___56 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___56 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___91;

struct css_set___91 {
	struct cgroup_subsys_state___91 *subsys[14];
	refcount_t refcount;
	struct css_set___91 *dom_cset;
	struct cgroup___91 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___91 *mg_src_cgrp;
	struct cgroup___91 *mg_dst_cgrp;
	struct css_set___91 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___91;

struct cgroup_subsys_state___91 {
	struct cgroup___91 *cgroup;
	struct cgroup_subsys___91 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___91 *parent;
};

struct cgroup_file___91 {
	struct kernfs_node___115 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___48;

struct mem_cgroup_per_node___48;

struct mem_cgroup___48 {
	struct cgroup_subsys_state___91 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___91 events_file;
	struct cgroup_file___91 events_local_file;
	struct cgroup_file___91 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___48 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___130 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___48 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___56;

struct blk_integrity___56 {
	const struct blk_integrity_profile___56 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___56 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___56 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___56;

struct elevator_queue___56;

struct blk_mq_ops___54;

struct blk_mq_hw_ctx___54;

struct gendisk___56;

struct blkcg_gq___54;

struct blk_mq_tag_set___54;

struct request_queue___56 {
	struct request___56 *last_merge;
	struct elevator_queue___56 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___54 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___54 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___56 *disk;
	struct kobject___115 kobj;
	struct kobject___115 *mq_kobj;
	struct blk_integrity___56 integrity;
	struct device___93 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___54 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___54 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___56 bio_split;
	struct dentry___123 *debugfs_dir;
	struct dentry___123 *sched_debugfs_dir;
	struct dentry___123 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___111 {
	struct vm_struct___111 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___128 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___123;

struct address_space___123 {
	struct inode___123 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___123 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___121;

struct dev_pagemap___121 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___121 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___108 {
	rwlock_t lock;
	struct pid___108 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___123 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___123 f_path;
	struct inode___123 *f_inode;
	const struct file_operations___123 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___108 f_owner;
	const struct cred___17 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___123 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___121;

struct vm_operations_struct___121 {
	void (*open)(struct vm_area_struct___128 *);
	void (*close)(struct vm_area_struct___128 *);
	int (*may_split)(struct vm_area_struct___128 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___128 *);
	int (*mprotect)(struct vm_area_struct___128 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___121 *);
	vm_fault_t (*huge_fault)(struct vm_fault___121 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___121 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___128 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___121 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___121 *);
	int (*access)(struct vm_area_struct___128 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___128 *);
	int (*set_policy)(struct vm_area_struct___128 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___128 *, long unsigned int);
	struct page___128 * (*find_special_page)(struct vm_area_struct___128 *, long unsigned int);
};

struct core_thread___128 {
	struct task_struct___130 *task;
	struct core_thread___128 *next;
};

struct core_state___128 {
	atomic_t nr_threads;
	struct core_thread___128 dumper;
	struct completion startup;
};

struct linux_binprm___22;

struct coredump_params___21;

struct linux_binfmt___21 {
	struct list_head lh;
	struct module___113 *module;
	int (*load_binary)(struct linux_binprm___22 *);
	int (*load_shlib)(struct file___123 *);
	int (*core_dump)(struct coredump_params___21 *);
	long unsigned int min_coredump;
};

struct vm_fault___121 {
	const struct {
		struct vm_area_struct___128 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___128 *cow_page;
	struct page___128 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___128 prealloc_pte;
};

struct dentry_operations___123;

struct dentry___123 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___123 *d_parent;
	struct qstr d_name;
	struct inode___123 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___123 *d_op;
	struct super_block___123 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___123;

struct inode___123 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___123 *i_op;
	struct super_block___123 *i_sb;
	struct address_space___123 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___54 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___123 *i_fop;
		void (*free_inode)(struct inode___123 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___123 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___40 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___123 {
	int (*d_revalidate)(struct dentry___123 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___123 *, unsigned int);
	int (*d_hash)(const struct dentry___123 *, struct qstr *);
	int (*d_compare)(const struct dentry___123 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___123 *);
	int (*d_init)(struct dentry___123 *);
	void (*d_release)(struct dentry___123 *);
	void (*d_prune)(struct dentry___123 *);
	void (*d_iput)(struct dentry___123 *, struct inode___123 *);
	char * (*d_dname)(struct dentry___123 *, char *, int);
	struct vfsmount___123 * (*d_automount)(struct path___123 *);
	int (*d_manage)(const struct path___123 *, bool);
	struct dentry___123 * (*d_real)(struct dentry___123 *, const struct inode___123 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___123;

struct mem_dqinfo___123 {
	struct quota_format_type___123 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___123;

struct quota_info___123 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___123 *files[3];
	struct mem_dqinfo___123 info[3];
	const struct quota_format_ops___123 *ops[3];
};

struct rcuwait___124 {
	struct task_struct___130 *task;
};

struct percpu_rw_semaphore___124 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___124 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___123 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___124 rw_sem[3];
};

struct shrink_control___48;

struct shrinker___48 {
	long unsigned int (*count_objects)(struct shrinker___48 *, struct shrink_control___48 *);
	long unsigned int (*scan_objects)(struct shrinker___48 *, struct shrink_control___48 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___123;

struct dquot_operations___123;

struct quotactl_ops___123;

struct block_device___57;

struct super_block___123 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___123 *s_type;
	const struct super_operations___123 *s_op;
	const struct dquot_operations___123 *dq_op;
	const struct quotactl_ops___123 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___123 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___57 *s_bdev;
	struct backing_dev_info___54 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___123 s_dquot;
	struct sb_writers___123 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___123 *s_d_op;
	int cleancache_poolid;
	struct shrinker___48 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___17 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___123 {
	struct dentry___123 *mnt_root;
	struct super_block___123 *mnt_sb;
	int mnt_flags;
	struct user_namespace___17 *mnt_userns;
};

struct shrink_control___48 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___48 *memcg;
};

struct pglist_data___54;

struct lruvec___54 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___54 *pgdat;
};

struct zone___54 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___54 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___54 {
	struct zone___54 *zone;
	int zone_idx;
};

struct zonelist___54 {
	struct zoneref___54 _zonerefs[321];
};

struct pglist_data___54 {
	struct zone___54 node_zones[5];
	struct zonelist___54 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___130 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___130 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___54 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___91 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___130 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___91;

struct cgroup_rstat_cpu___91;

struct cgroup___91 {
	struct cgroup_subsys_state___91 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___115 *kn;
	struct cgroup_file___91 procs_file;
	struct cgroup_file___91 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___91 *subsys[14];
	struct cgroup_root___91 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___91 *dom_cgrp;
	struct cgroup___91 *old_dom_cgrp;
	struct cgroup_rstat_cpu___91 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___91 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___56 {
	struct request_queue___56 *q;
	struct io_context___56 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___55;

struct kiocb___123 {
	struct file___123 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___123 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___55 *ki_waitq;
	};
};

struct iattr___123 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___123 *ia_file;
};

struct dquot___123 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___123 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___123 {
	int qf_fmt_id;
	const struct quota_format_ops___123 *qf_ops;
	struct module___113 *qf_owner;
	struct quota_format_type___123 *qf_next;
};

struct quota_format_ops___123 {
	int (*check_quota_file)(struct super_block___123 *, int);
	int (*read_file_info)(struct super_block___123 *, int);
	int (*write_file_info)(struct super_block___123 *, int);
	int (*free_file_info)(struct super_block___123 *, int);
	int (*read_dqblk)(struct dquot___123 *);
	int (*commit_dqblk)(struct dquot___123 *);
	int (*release_dqblk)(struct dquot___123 *);
	int (*get_next_id)(struct super_block___123 *, struct kqid *);
};

struct dquot_operations___123 {
	int (*write_dquot)(struct dquot___123 *);
	struct dquot___123 * (*alloc_dquot)(struct super_block___123 *, int);
	void (*destroy_dquot)(struct dquot___123 *);
	int (*acquire_dquot)(struct dquot___123 *);
	int (*release_dquot)(struct dquot___123 *);
	int (*mark_dirty)(struct dquot___123 *);
	int (*write_info)(struct super_block___123 *, int);
	qsize_t * (*get_reserved_space)(struct inode___123 *);
	int (*get_projid)(struct inode___123 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___123 *, qsize_t *);
	int (*get_next_id)(struct super_block___123 *, struct kqid *);
};

struct quotactl_ops___123 {
	int (*quota_on)(struct super_block___123 *, int, int, const struct path___123 *);
	int (*quota_off)(struct super_block___123 *, int);
	int (*quota_enable)(struct super_block___123 *, unsigned int);
	int (*quota_disable)(struct super_block___123 *, unsigned int);
	int (*quota_sync)(struct super_block___123 *, int);
	int (*set_info)(struct super_block___123 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___123 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___123 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___123 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___123 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___123 *, unsigned int);
};

struct wait_page_queue___55 {
	struct page___128 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___54;

struct readahead_control___55;

struct swap_info_struct___30;

struct address_space_operations___123 {
	int (*writepage)(struct page___128 *, struct writeback_control___54 *);
	int (*readpage)(struct file___123 *, struct page___128 *);
	int (*writepages)(struct address_space___123 *, struct writeback_control___54 *);
	int (*set_page_dirty)(struct page___128 *);
	int (*readpages)(struct file___123 *, struct address_space___123 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___55 *);
	int (*write_begin)(struct file___123 *, struct address_space___123 *, loff_t, unsigned int, unsigned int, struct page___128 **, void **);
	int (*write_end)(struct file___123 *, struct address_space___123 *, loff_t, unsigned int, unsigned int, struct page___128 *, void *);
	sector_t (*bmap)(struct address_space___123 *, sector_t);
	void (*invalidatepage)(struct page___128 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___128 *, gfp_t);
	void (*freepage)(struct page___128 *);
	ssize_t (*direct_IO)(struct kiocb___123 *, struct iov_iter___69 *);
	int (*migratepage)(struct address_space___123 *, struct page___128 *, struct page___128 *, enum migrate_mode);
	bool (*isolate_page)(struct page___128 *, isolate_mode_t);
	void (*putback_page)(struct page___128 *);
	int (*launder_page)(struct page___128 *);
	int (*is_partially_uptodate)(struct page___128 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___128 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___123 *, struct page___128 *);
	int (*swap_activate)(struct swap_info_struct___30 *, struct file___123 *, sector_t *);
	void (*swap_deactivate)(struct file___123 *);
};

struct writeback_control___54 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___54 *wb;
	struct inode___123 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___55 {
	struct file___123 *file;
	struct address_space___123 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___67;

struct iov_iter___69 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___67 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___30 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___57 *bdev;
	struct file___123 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___123 {
	struct dentry___123 * (*lookup)(struct inode___123 *, struct dentry___123 *, unsigned int);
	const char * (*get_link)(struct dentry___123 *, struct inode___123 *, struct delayed_call *);
	int (*permission)(struct user_namespace___17 *, struct inode___123 *, int);
	struct posix_acl * (*get_acl)(struct inode___123 *, int, bool);
	int (*readlink)(struct dentry___123 *, char *, int);
	int (*create)(struct user_namespace___17 *, struct inode___123 *, struct dentry___123 *, umode_t, bool);
	int (*link)(struct dentry___123 *, struct inode___123 *, struct dentry___123 *);
	int (*unlink)(struct inode___123 *, struct dentry___123 *);
	int (*symlink)(struct user_namespace___17 *, struct inode___123 *, struct dentry___123 *, const char *);
	int (*mkdir)(struct user_namespace___17 *, struct inode___123 *, struct dentry___123 *, umode_t);
	int (*rmdir)(struct inode___123 *, struct dentry___123 *);
	int (*mknod)(struct user_namespace___17 *, struct inode___123 *, struct dentry___123 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___17 *, struct inode___123 *, struct dentry___123 *, struct inode___123 *, struct dentry___123 *, unsigned int);
	int (*setattr)(struct user_namespace___17 *, struct dentry___123 *, struct iattr___123 *);
	int (*getattr)(struct user_namespace___17 *, const struct path___123 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___123 *, char *, size_t);
	int (*fiemap)(struct inode___123 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___123 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___123 *, struct dentry___123 *, struct file___123 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___17 *, struct inode___123 *, struct dentry___123 *, umode_t);
	int (*set_acl)(struct user_namespace___17 *, struct inode___123 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___17 *, struct dentry___123 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___123 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___123 {
	void (*fl_copy_lock)(struct file_lock___123 *, struct file_lock___123 *);
	void (*fl_release_private)(struct file_lock___123 *);
};

struct fasync_struct___123;

struct lock_manager_operations___123;

struct file_lock___123 {
	struct file_lock___123 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___123 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___123 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___123 *fl_ops;
	const struct lock_manager_operations___123 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___123 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___123 *);
	int (*lm_grant)(struct file_lock___123 *, int);
	bool (*lm_break)(struct file_lock___123 *);
	int (*lm_change)(struct file_lock___123 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___123 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___123 *);
};

struct fasync_struct___123 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___123 *fa_next;
	struct file___123 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___123 {
	struct inode___123 * (*alloc_inode)(struct super_block___123 *);
	void (*destroy_inode)(struct inode___123 *);
	void (*free_inode)(struct inode___123 *);
	void (*dirty_inode)(struct inode___123 *, int);
	int (*write_inode)(struct inode___123 *, struct writeback_control___54 *);
	int (*drop_inode)(struct inode___123 *);
	void (*evict_inode)(struct inode___123 *);
	void (*put_super)(struct super_block___123 *);
	int (*sync_fs)(struct super_block___123 *, int);
	int (*freeze_super)(struct super_block___123 *);
	int (*freeze_fs)(struct super_block___123 *);
	int (*thaw_super)(struct super_block___123 *);
	int (*unfreeze_fs)(struct super_block___123 *);
	int (*statfs)(struct dentry___123 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___123 *, int *, char *);
	void (*umount_begin)(struct super_block___123 *);
	int (*show_options)(struct seq_file___108 *, struct dentry___123 *);
	int (*show_devname)(struct seq_file___108 *, struct dentry___123 *);
	int (*show_path)(struct seq_file___108 *, struct dentry___123 *);
	int (*show_stats)(struct seq_file___108 *, struct dentry___123 *);
	ssize_t (*quota_read)(struct super_block___123 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___123 *, int, const char *, size_t, loff_t);
	struct dquot___123 ** (*get_dquots)(struct inode___123 *);
	long int (*nr_cached_objects)(struct super_block___123 *, struct shrink_control___48 *);
	long int (*free_cached_objects)(struct super_block___123 *, struct shrink_control___48 *);
	struct file___123 * (*real_loop)(struct file___123 *);
};

struct wakeup_source___93;

struct dev_pm_info___93 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___93 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___93 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___93;

struct bus_type___93;

struct device_driver___93;

struct dev_pm_domain___93;

struct fwnode_handle___93;

struct class___93;

struct attribute_group___115;

struct device___93 {
	struct kobject___115 kobj;
	struct device___93 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___93 *type;
	struct bus_type___93 *bus;
	struct device_driver___93 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___93 power;
	struct dev_pm_domain___93 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___93 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___93 *class;
	const struct attribute_group___115 **groups;
	void (*release)(struct device___93 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___57 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___123 *bd_inode;
	struct super_block___123 *bd_super;
	void *bd_claiming;
	struct device___93 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___115 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___56 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___123 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___85)(struct file___123 *, wait_queue_head_t *, struct poll_table_struct___84 *);

struct poll_table_struct___84 {
	poll_queue_proc___85 _qproc;
	__poll_t _key;
};

struct seq_operations___108;

struct seq_file___108 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___108 *op;
	int poll_event;
	const struct file___123 *file;
	void *private;
};

typedef void bio_end_io_t___56(struct bio___56 *);

struct bio_vec___67 {
	struct page___128 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___56;

struct bio___56 {
	struct bio___56 *bi_next;
	struct block_device___57 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___56 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___54 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___56 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___67 *bi_io_vec;
	struct bio_set___56 *bi_pool;
	struct bio_vec___67 bi_inline_vecs[0];
};

struct proc_ops___12 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___123 *, struct file___123 *);
	ssize_t (*proc_read)(struct file___123 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___123 *, struct iov_iter___69 *);
	ssize_t (*proc_write)(struct file___123 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___123 *, loff_t, int);
	int (*proc_release)(struct inode___123 *, struct file___123 *);
	__poll_t (*proc_poll)(struct file___123 *, struct poll_table_struct___84 *);
	long int (*proc_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___123 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___123 *, struct vm_area_struct___128 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___123 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct proc_fs_info___5 {
	struct pid_namespace___108 *pid_ns;
	struct dentry___123 *proc_self;
	struct dentry___123 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

typedef int (*proc_write_t___5)(struct file___123 *, char *, size_t);

struct genradix_root;

struct __genradix {
	struct genradix_root *root;
};

struct seq_operations___108 {
	void * (*start)(struct seq_file___108 *, loff_t *);
	void (*stop)(struct seq_file___108 *, void *);
	void * (*next)(struct seq_file___108 *, void *, loff_t *);
	int (*show)(struct seq_file___108 *, void *);
};

struct dev_pagemap_ops___121 {
	void (*page_free)(struct page___128 *);
	void (*kill)(struct dev_pagemap___121 *);
	void (*cleanup)(struct dev_pagemap___121 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___121 *);
};

struct kernfs_root___115;

struct kernfs_elem_dir___115 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___115 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___115;

struct kernfs_root___115 {
	struct kernfs_node___115 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___115 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___115 {
	struct kernfs_node___115 *target_kn;
};

struct kernfs_ops___115;

struct kernfs_elem_attr___115 {
	const struct kernfs_ops___115 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___115 *notify_next;
};

struct kernfs_node___115 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___115 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___115 dir;
		struct kernfs_elem_symlink___115 symlink;
		struct kernfs_elem_attr___115 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___115;

struct kernfs_ops___115 {
	int (*open)(struct kernfs_open_file___115 *);
	void (*release)(struct kernfs_open_file___115 *);
	int (*seq_show)(struct seq_file___108 *, void *);
	void * (*seq_start)(struct seq_file___108 *, loff_t *);
	void * (*seq_next)(struct seq_file___108 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___108 *, void *);
	ssize_t (*read)(struct kernfs_open_file___115 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___115 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___115 *, struct poll_table_struct___84 *);
	int (*mmap)(struct kernfs_open_file___115 *, struct vm_area_struct___128 *);
};

struct kernfs_syscall_ops___115 {
	int (*show_options)(struct seq_file___108 *, struct kernfs_root___115 *);
	int (*mkdir)(struct kernfs_node___115 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___115 *);
	int (*rename)(struct kernfs_node___115 *, struct kernfs_node___115 *, const char *);
	int (*show_path)(struct seq_file___108 *, struct kernfs_node___115 *, struct kernfs_root___115 *);
};

struct kernfs_open_file___115 {
	struct kernfs_node___115 *kn;
	struct file___123 *file;
	struct seq_file___108 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___121 *vm_ops;
};

struct nsset___18;

struct proc_ns_operations___19 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___19 * (*get)(struct task_struct___130 *);
	void (*put)(struct ns_common___19 *);
	int (*install)(struct nsset___18 *, struct ns_common___19 *);
	struct user_namespace___17 * (*owner)(struct ns_common___19 *);
	struct ns_common___19 * (*get_parent)(struct ns_common___19 *);
};

struct time_namespace___6 {
	struct user_namespace___17 *user_ns;
	struct ucounts___17 *ucounts;
	struct ns_common___19 ns;
	struct timens_offsets offsets;
	struct page___128 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___91 {
	struct ns_common___19 ns;
	struct user_namespace___17 *user_ns;
	struct ucounts___17 *ucounts;
	struct css_set___91 *root_cset;
};

struct nsset___18 {
	unsigned int flags;
	struct nsproxy___114 *nsproxy;
	struct fs_struct___19 *fs;
	const struct cred___17 *cred;
};

struct fwnode_operations___93;

struct fwnode_handle___93 {
	struct fwnode_handle___93 *secondary;
	const struct fwnode_operations___93 *ops;
	struct device___93 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___93;

struct fwnode_endpoint___93;

struct fwnode_operations___93 {
	struct fwnode_handle___93 * (*get)(struct fwnode_handle___93 *);
	void (*put)(struct fwnode_handle___93 *);
	bool (*device_is_available)(const struct fwnode_handle___93 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___93 *, const struct device___93 *);
	bool (*property_present)(const struct fwnode_handle___93 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___93 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___93 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___93 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*get_parent)(const struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*get_next_child_node)(const struct fwnode_handle___93 *, struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*get_named_child_node)(const struct fwnode_handle___93 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___93 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___93 *);
	struct fwnode_handle___93 * (*graph_get_next_endpoint)(const struct fwnode_handle___93 *, struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*graph_get_remote_endpoint)(const struct fwnode_handle___93 *);
	struct fwnode_handle___93 * (*graph_get_port_parent)(struct fwnode_handle___93 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___93 *, struct fwnode_endpoint___93 *);
	int (*add_links)(struct fwnode_handle___93 *);
};

struct fwnode_endpoint___93 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___93 *local_fwnode;
};

struct fwnode_reference_args___93 {
	struct fwnode_handle___93 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___115;

struct attribute_group___115 {
	const char *name;
	umode_t (*is_visible)(struct kobject___115 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___115 *, struct bin_attribute___115 *, int);
	struct attribute **attrs;
	struct bin_attribute___115 **bin_attrs;
};

struct bin_attribute___115 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___123 * (*f_mapping)();
	ssize_t (*read)(struct file___123 *, struct kobject___115 *, struct bin_attribute___115 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___123 *, struct kobject___115 *, struct bin_attribute___115 *, char *, loff_t, size_t);
	int (*mmap)(struct file___123 *, struct kobject___115 *, struct bin_attribute___115 *, struct vm_area_struct___128 *);
};

struct sysfs_ops___115 {
	ssize_t (*show)(struct kobject___115 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___115 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___115;

struct kset___115 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___115 kobj;
	const struct kset_uevent_ops___115 *uevent_ops;
};

struct kobj_type___115 {
	void (*release)(struct kobject___115 *);
	const struct sysfs_ops___115 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___115 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___115 *);
	const void * (*namespace)(struct kobject___115 *);
	void (*get_ownership)(struct kobject___115 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___115 {
	int (* const filter)(struct kset___115 *, struct kobject___115 *);
	const char * (* const name)(struct kset___115 *, struct kobject___115 *);
	int (* const uevent)(struct kset___115 *, struct kobject___115 *, struct kobj_uevent_env *);
};

struct proc_dir_entry___6 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___123 *proc_iops;
	union {
		const struct proc_ops___12 *proc_ops;
		const struct file_operations___123 *proc_dir_ops;
	};
	const struct dentry_operations___123 *proc_dops;
	union {
		const struct seq_operations___108 *seq_ops;
		int (*single_show)(struct seq_file___108 *, void *);
	};
	proc_write_t___5 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___6 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct kernel_param_ops___112 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___112 *);
	int (*get)(char *, const struct kernel_param___112 *);
	void (*free)(void *);
};

struct kparam_array___112;

struct kernel_param___112 {
	const char *name;
	struct module___113 *mod;
	const struct kernel_param_ops___112 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___112 *arr;
	};
};

struct kparam_array___112 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___112 *ops;
	void *elem;
};

struct module_attribute___112 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___112 *, struct module_kobject___112 *, char *);
	ssize_t (*store)(struct module_attribute___112 *, struct module_kobject___112 *, const char *, size_t);
	void (*setup)(struct module___113 *, const char *);
	int (*test)(struct module___113 *);
	void (*free)(struct module___113 *);
};

struct cftype___91;

struct cgroup_subsys___91 {
	struct cgroup_subsys_state___91 * (*css_alloc)(struct cgroup_subsys_state___91 *);
	int (*css_online)(struct cgroup_subsys_state___91 *);
	void (*css_offline)(struct cgroup_subsys_state___91 *);
	void (*css_released)(struct cgroup_subsys_state___91 *);
	void (*css_free)(struct cgroup_subsys_state___91 *);
	void (*css_reset)(struct cgroup_subsys_state___91 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___91 *, int);
	int (*css_extra_stat_show)(struct seq_file___108 *, struct cgroup_subsys_state___91 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___130 *, struct css_set___91 *);
	void (*cancel_fork)(struct task_struct___130 *, struct css_set___91 *);
	void (*fork)(struct task_struct___130 *);
	void (*exit)(struct task_struct___130 *);
	void (*release)(struct task_struct___130 *);
	void (*bind)(struct cgroup_subsys_state___91 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___91 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___91 *dfl_cftypes;
	struct cftype___91 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___91 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___91 *updated_children;
	struct cgroup___91 *updated_next;
};

struct cgroup_root___91 {
	struct kernfs_root___115 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___91 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___91 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___91 *ss;
	struct list_head node;
	struct kernfs_ops___115 *kf_ops;
	int (*open)(struct kernfs_open_file___115 *);
	void (*release)(struct kernfs_open_file___115 *);
	u64 (*read_u64)(struct cgroup_subsys_state___91 *, struct cftype___91 *);
	s64 (*read_s64)(struct cgroup_subsys_state___91 *, struct cftype___91 *);
	int (*seq_show)(struct seq_file___108 *, void *);
	void * (*seq_start)(struct seq_file___108 *, loff_t *);
	void * (*seq_next)(struct seq_file___108 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___108 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___91 *, struct cftype___91 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___91 *, struct cftype___91 *, s64);
	ssize_t (*write)(struct kernfs_open_file___115 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___115 *, struct poll_table_struct___84 *);
};

struct syscall_info {
	__u64 sp;
	struct seccomp_data data;
};

struct dev_pm_ops___93 {
	int (*prepare)(struct device___93 *);
	void (*complete)(struct device___93 *);
	int (*suspend)(struct device___93 *);
	int (*resume)(struct device___93 *);
	int (*freeze)(struct device___93 *);
	int (*thaw)(struct device___93 *);
	int (*poweroff)(struct device___93 *);
	int (*restore)(struct device___93 *);
	int (*suspend_late)(struct device___93 *);
	int (*resume_early)(struct device___93 *);
	int (*freeze_late)(struct device___93 *);
	int (*thaw_early)(struct device___93 *);
	int (*poweroff_late)(struct device___93 *);
	int (*restore_early)(struct device___93 *);
	int (*suspend_noirq)(struct device___93 *);
	int (*resume_noirq)(struct device___93 *);
	int (*freeze_noirq)(struct device___93 *);
	int (*thaw_noirq)(struct device___93 *);
	int (*poweroff_noirq)(struct device___93 *);
	int (*restore_noirq)(struct device___93 *);
	int (*runtime_suspend)(struct device___93 *);
	int (*runtime_resume)(struct device___93 *);
	int (*runtime_idle)(struct device___93 *);
};

struct wakeup_source___93 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___93 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___93 {
	struct dev_pm_ops___93 ops;
	int (*start)(struct device___93 *);
	void (*detach)(struct device___93 *, bool);
	int (*activate)(struct device___93 *);
	void (*sync)(struct device___93 *);
	void (*dismiss)(struct device___93 *);
};

struct bus_type___93 {
	const char *name;
	const char *dev_name;
	struct device___93 *dev_root;
	const struct attribute_group___115 **bus_groups;
	const struct attribute_group___115 **dev_groups;
	const struct attribute_group___115 **drv_groups;
	int (*match)(struct device___93 *, struct device_driver___93 *);
	int (*uevent)(struct device___93 *, struct kobj_uevent_env *);
	int (*probe)(struct device___93 *);
	void (*sync_state)(struct device___93 *);
	void (*remove)(struct device___93 *);
	void (*shutdown)(struct device___93 *);
	int (*online)(struct device___93 *);
	int (*offline)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	int (*num_vf)(struct device___93 *);
	int (*dma_configure)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___93 {
	const char *name;
	struct bus_type___93 *bus;
	struct module___113 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___93 *);
	void (*sync_state)(struct device___93 *);
	int (*remove)(struct device___93 *);
	void (*shutdown)(struct device___93 *);
	int (*suspend)(struct device___93 *, pm_message_t);
	int (*resume)(struct device___93 *);
	const struct attribute_group___115 **groups;
	const struct attribute_group___115 **dev_groups;
	const struct dev_pm_ops___93 *pm;
	void (*coredump)(struct device___93 *);
	struct driver_private *p;
};

struct device_type___93 {
	const char *name;
	const struct attribute_group___115 **groups;
	int (*uevent)(struct device___93 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___93 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___93 *);
	const struct dev_pm_ops___93 *pm;
};

struct class___93 {
	const char *name;
	struct module___113 *owner;
	const struct attribute_group___115 **class_groups;
	const struct attribute_group___115 **dev_groups;
	struct kobject___115 *dev_kobj;
	int (*dev_uevent)(struct device___93 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___93 *, umode_t *);
	void (*class_release)(struct class___93 *);
	void (*dev_release)(struct device___93 *);
	int (*shutdown_pre)(struct device___93 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___93 *);
	void (*get_ownership)(struct device___93 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___93 *pm;
	struct subsys_private *p;
};

struct block_device_operations___56;

struct gendisk___56 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___57 *part0;
	const struct block_device_operations___56 *fops;
	struct request_queue___56 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___54 *bdi;
	struct kobject___115 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___115 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___56 {
	struct bio___56 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___67 *bip_vec;
	struct bio_vec___67 bip_inline_vecs[0];
};

struct blkcg___54;

struct blkg_policy_data___54;

struct blkcg_gq___54 {
	struct request_queue___56 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___54 *blkcg;
	struct blkcg_gq___54 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___54 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___56 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___56(struct request___56 *);

typedef void integrity_complete_fn___56(struct request___56 *, unsigned int);

struct blk_integrity_profile___56 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___56 *prepare_fn;
	integrity_complete_fn___56 *complete_fn;
	const char *name;
};

struct block_device_operations___56 {
	blk_qc_t (*submit_bio)(struct bio___56 *);
	int (*open)(struct block_device___57 *, fmode_t);
	void (*release)(struct gendisk___56 *, fmode_t);
	int (*rw_page)(struct block_device___57 *, sector_t, struct page___128 *, unsigned int);
	int (*ioctl)(struct block_device___57 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___57 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___56 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___56 *);
	int (*getgeo)(struct block_device___57 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___57 *, bool);
	void (*swap_slot_free_notify)(struct block_device___57 *, long unsigned int);
	int (*report_zones)(struct gendisk___56 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___56 *, umode_t *);
	struct module___113 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___56 *, sector_t *);
};

typedef void rq_end_io_fn___56(struct request___56 *, blk_status_t);

struct request___56 {
	struct request_queue___56 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___54 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___56 *bio;
	struct bio___56 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___67 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___56 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___56 *saved_end_io;
		} flush;
	};
	struct gendisk___56 *rq_disk;
	struct block_device___57 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___56 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___54 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___56 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___115 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___123 *debugfs_dir;
	struct dentry___123 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___56;

struct elevator_mq_ops___56 {
	int (*init_sched)(struct request_queue___56 *, struct elevator_type___56 *);
	void (*exit_sched)(struct elevator_queue___56 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___54 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___54 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___54 *);
	bool (*allow_merge)(struct request_queue___56 *, struct request___56 *, struct bio___56 *);
	bool (*bio_merge)(struct request_queue___56 *, struct bio___56 *, unsigned int);
	int (*request_merge)(struct request_queue___56 *, struct request___56 **, struct bio___56 *);
	void (*request_merged)(struct request_queue___56 *, struct request___56 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___56 *, struct request___56 *, struct request___56 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___56 *);
	void (*finish_request)(struct request___56 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___54 *, struct list_head *, bool);
	struct request___56 * (*dispatch_request)(struct blk_mq_hw_ctx___54 *);
	bool (*has_work)(struct blk_mq_hw_ctx___54 *);
	void (*completed_request)(struct request___56 *, u64);
	void (*requeue_request)(struct request___56 *);
	struct request___56 * (*former_request)(struct request_queue___56 *, struct request___56 *);
	struct request___56 * (*next_request)(struct request_queue___56 *, struct request___56 *);
	void (*init_icq)(struct io_cq___56 *);
	void (*exit_icq)(struct io_cq___56 *);
};

struct elv_fs_entry___56;

struct elevator_type___56 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___56 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___56 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___113 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___56 {
	struct elevator_type___56 *type;
	void *elevator_data;
	struct kobject___115 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___56 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___56 *, char *);
	ssize_t (*store)(struct elevator_queue___56 *, const char *, size_t);
};

struct blk_mq_queue_data___54;

struct blk_mq_ops___54 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___54 *, const struct blk_mq_queue_data___54 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___54 *);
	int (*get_budget)(struct request_queue___56 *);
	void (*put_budget)(struct request_queue___56 *, int);
	void (*set_rq_budget_token)(struct request___56 *, int);
	int (*get_rq_budget_token)(struct request___56 *);
	enum blk_eh_timer_return (*timeout)(struct request___56 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___54 *);
	void (*complete)(struct request___56 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___54 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___54 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___54 *, struct request___56 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___54 *, struct request___56 *, unsigned int);
	void (*initialize_rq_fn)(struct request___56 *);
	void (*cleanup_rq)(struct request___56 *);
	bool (*busy)(struct request_queue___56 *);
	int (*map_queues)(struct blk_mq_tag_set___54 *);
	void (*show_rq)(struct seq_file___108 *, struct request___56 *);
};

struct blk_mq_tag_set___54 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___54 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___54 {
	struct request___56 *rq;
	bool last;
};

struct blkcg_policy_data___54;

struct blkcg___54 {
	struct cgroup_subsys_state___91 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___54 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___54 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___54 {
	struct blkcg___54 *blkcg;
	int plid;
};

struct blkg_policy_data___54 {
	struct blkcg_gq___54 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___48 {
	struct mem_cgroup___48 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___48 {
	struct lruvec___54 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___48 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___48 *memcg;
};

struct obj_cgroup___48 {
	struct percpu_ref refcnt;
	struct mem_cgroup___48 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum resctrl_conf_type {
	CDP_NONE = 0,
	CDP_CODE = 1,
	CDP_DATA = 2,
};

struct linux_binprm___22 {
	struct vm_area_struct___128 *vma;
	long unsigned int vma_pages;
	struct mm_struct___129 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___123 *executable;
	struct file___123 *interpreter;
	struct file___123 *file;
	struct cred___17 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___21 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___123 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

union proc_op___4 {
	int (*proc_get_link)(struct dentry___123 *, struct path___123 *);
	int (*proc_show)(struct seq_file___108 *, struct pid_namespace___108 *, struct pid___108 *, struct task_struct___130 *);
	const char *lsm;
};

struct proc_inode___4 {
	struct pid___108 *pid;
	unsigned int fd;
	union proc_op___4 op;
	struct proc_dir_entry___6 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___19 *ns_ops;
	struct inode___123 vfs_inode;
};

typedef struct dentry___123 *instantiate_t(struct dentry___123 *, struct task_struct___130 *, const void *);

struct pid_entry {
	const char *name;
	unsigned int len;
	umode_t mode;
	const struct inode_operations___123 *iop;
	const struct file_operations___123 *fop;
	union proc_op___4 op;
};

struct limit_names {
	const char *name;
	const char *unit;
};

struct map_files_info {
	long unsigned int start;
	long unsigned int end;
	fmode_t mode;
};

struct timers_private {
	struct pid___108 *pid;
	struct task_struct___130 *task;
	struct sighand_struct *sighand;
	struct pid_namespace___108 *ns;
	long unsigned int flags;
};

struct tgid_iter {
	unsigned int tgid;
	struct task_struct___130 *task;
};

struct dentry___124;

struct super_block___124;

struct module___114;

struct file_system_type___124 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___124 * (*mount)(struct file_system_type___124 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___124 *);
	struct module___114 *owner;
	struct file_system_type___124 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___124;

struct kiocb___124;

struct iov_iter___70;

struct vm_area_struct___129;

struct inode___124;

struct file_lock___124;

struct page___129;

struct seq_file___109;

struct file_operations___124 {
	struct module___114 *owner;
	loff_t (*llseek)(struct file___124 *, loff_t, int);
	ssize_t (*read)(struct file___124 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___124 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___124 *, struct iov_iter___70 *);
	ssize_t (*write_iter)(struct kiocb___124 *, struct iov_iter___70 *);
	int (*iopoll)(struct kiocb___124 *, bool);
	int (*iterate)(struct file___124 *, struct dir_context *);
	int (*iterate_shared)(struct file___124 *, struct dir_context *);
	__poll_t (*poll)(struct file___124 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___124 *, struct vm_area_struct___129 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___124 *, struct file___124 *);
	int (*flush)(struct file___124 *, fl_owner_t);
	int (*release)(struct inode___124 *, struct file___124 *);
	int (*fsync)(struct file___124 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___124 *, int);
	int (*lock)(struct file___124 *, int, struct file_lock___124 *);
	ssize_t (*sendpage)(struct file___124 *, struct page___129 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___124 *, long unsigned int);
	int (*flock)(struct file___124 *, int, struct file_lock___124 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___124 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___124 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___124 *, long int, struct file_lock___124 **, void **);
	long int (*fallocate)(struct file___124 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___109 *, struct file___124 *);
	ssize_t (*copy_file_range)(struct file___124 *, loff_t, struct file___124 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___124 *, loff_t, struct file___124 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___124 *, loff_t, loff_t, int);
};

struct vmacache___129 {
	u64 seqnum;
	struct vm_area_struct___129 *vmas[4];
};

struct page_frag___129 {
	struct page___129 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___130;

struct pid___109;

struct cred___18;

struct fs_struct___20;

struct files_struct___17;

struct nsproxy___115;

struct signal_struct___125;

struct bio_list___57;

struct backing_dev_info___55;

struct io_context___57;

struct css_set___92;

struct mem_cgroup___49;

struct request_queue___57;

struct vm_struct___112;

struct task_struct___131 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___131 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___130 *mm;
	struct mm_struct___130 *active_mm;
	struct vmacache___129 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___131 *real_parent;
	struct task_struct___131 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___131 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___109 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___18 *ptracer_cred;
	const struct cred___18 *real_cred;
	const struct cred___18 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___20 *fs;
	struct files_struct___17 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___115 *nsproxy;
	struct signal_struct___125 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___131 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___57 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___55 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___92 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___129 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___49 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___49 *active_memcg;
	struct request_queue___57 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___131 *oom_reaper_list;
	struct vm_struct___112 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___116;

struct kobj_type___116;

struct kernfs_node___116;

struct kobject___116 {
	const char *name;
	struct list_head entry;
	struct kobject___116 *parent;
	struct kset___116 *kset;
	struct kobj_type___116 *ktype;
	struct kernfs_node___116 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___113 {
	struct kobject___116 kobj;
	struct module___114 *mod;
	struct kobject___116 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___113 {
	struct module___114 *mod;
	struct latch_tree_node node;
};

struct module_layout___113 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___113 mtn;
};

struct module_attribute___113;

struct kernel_param___113;

struct module___114 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___113 mkobj;
	struct module_attribute___113 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___116 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___113 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___113 core_layout;
	struct module_layout___113 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___109;

struct upid___109 {
	int nr;
	struct pid_namespace___109 *ns;
};

struct proc_ns_operations___20;

struct ns_common___20 {
	atomic_long_t stashed;
	const struct proc_ns_operations___20 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___18;

struct ucounts___18;

struct pid_namespace___109 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___131 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___109 *parent;
	struct fs_pin *bacct;
	struct user_namespace___18 *user_ns;
	struct ucounts___18 *ucounts;
	int reboot;
	struct ns_common___20 ns;
};

struct pid___109 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___109 numbers[1];
};

struct user_namespace___18 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___18 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___20 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___3 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___3 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___18 *ucounts;
	long int ucount_max[16];
};

typedef struct page___129 *pgtable_t___129;

struct address_space___124;

struct dev_pagemap___122;

struct page___129 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___124 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___129 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___129 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___130 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___122 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___18 {
	struct hlist_node node;
	struct user_namespace___18 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___122;

struct vm_area_struct___129 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___129 *vm_next;
	struct vm_area_struct___129 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___130 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___122 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___124 *vm_file;
	struct file___124 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___11;

struct signal_struct___125 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___131 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___131 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___109 *pids[4];
	struct pid___109 *tty_old_pgrp;
	int leader;
	struct tty_struct___11 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___130 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___22;

struct core_state___129;

struct mm_struct___130 {
	struct {
		struct vm_area_struct___129 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___22 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___129 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___131 *owner;
		struct user_namespace___18 *user_ns;
		struct file___124 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___18 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___18 *user_ns;
	struct ucounts___18 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct vfsmount___124;

struct path___124 {
	struct vfsmount___124 *mnt;
	struct dentry___124 *dentry;
};

struct fs_struct___20 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___124 root;
	struct path___124 pwd;
};

struct fdtable___17 {
	unsigned int max_fds;
	struct file___124 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___17 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___17 *fdt;
	struct fdtable___17 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___124 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct time_namespace___7;

struct cgroup_namespace___92;

struct nsproxy___115 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___109 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace___7 *time_ns;
	struct time_namespace___7 *time_ns_for_children;
	struct cgroup_namespace___92 *cgroup_ns;
};

struct bio___57;

struct bio_list___57 {
	struct bio___57 *head;
	struct bio___57 *tail;
};

struct cgroup_subsys_state___92;

struct bdi_writeback___55 {
	struct backing_dev_info___55 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___92 *memcg_css;
	struct cgroup_subsys_state___92 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___94;

struct backing_dev_info___55 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___55 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___94 *dev;
	char dev_name[64];
	struct device___94 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___124 *debug_dir;
};

struct io_cq___57;

struct io_context___57 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___57 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___92;

struct css_set___92 {
	struct cgroup_subsys_state___92 *subsys[14];
	refcount_t refcount;
	struct css_set___92 *dom_cset;
	struct cgroup___92 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___92 *mg_src_cgrp;
	struct cgroup___92 *mg_dst_cgrp;
	struct css_set___92 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___92;

struct cgroup_subsys_state___92 {
	struct cgroup___92 *cgroup;
	struct cgroup_subsys___92 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___92 *parent;
};

struct cgroup_file___92 {
	struct kernfs_node___116 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___49;

struct mem_cgroup_per_node___49;

struct mem_cgroup___49 {
	struct cgroup_subsys_state___92 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___92 events_file;
	struct cgroup_file___92 events_local_file;
	struct cgroup_file___92 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___49 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___131 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___49 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___57;

struct blk_integrity___57 {
	const struct blk_integrity_profile___57 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___57 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___57 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___57;

struct elevator_queue___57;

struct blk_mq_ops___55;

struct blk_mq_hw_ctx___55;

struct gendisk___57;

struct blkcg_gq___55;

struct blk_mq_tag_set___55;

struct request_queue___57 {
	struct request___57 *last_merge;
	struct elevator_queue___57 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___55 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___55 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___57 *disk;
	struct kobject___116 kobj;
	struct kobject___116 *mq_kobj;
	struct blk_integrity___57 integrity;
	struct device___94 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___55 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___55 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___57 bio_split;
	struct dentry___124 *debugfs_dir;
	struct dentry___124 *sched_debugfs_dir;
	struct dentry___124 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___112 {
	struct vm_struct___112 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___129 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct time_namespace___7 {
	struct user_namespace___18 *user_ns;
	struct ucounts___18 *ucounts;
	struct ns_common___20 ns;
	struct timens_offsets offsets;
	struct page___129 *vvar_page;
	bool frozen_offsets;
};

struct cgroup_namespace___92 {
	struct ns_common___20 ns;
	struct user_namespace___18 *user_ns;
	struct ucounts___18 *ucounts;
	struct css_set___92 *root_cset;
};

struct nsset___19 {
	unsigned int flags;
	struct nsproxy___115 *nsproxy;
	struct fs_struct___20 *fs;
	const struct cred___18 *cred;
};

struct proc_ns_operations___20 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___20 * (*get)(struct task_struct___131 *);
	void (*put)(struct ns_common___20 *);
	int (*install)(struct nsset___19 *, struct ns_common___20 *);
	struct user_namespace___18 * (*owner)(struct ns_common___20 *);
	struct ns_common___20 * (*get_parent)(struct ns_common___20 *);
};

struct address_space_operations___124;

struct address_space___124 {
	struct inode___124 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___124 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___122;

struct dev_pagemap___122 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___122 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___109 {
	rwlock_t lock;
	struct pid___109 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___124 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___124 f_path;
	struct inode___124 *f_inode;
	const struct file_operations___124 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___109 f_owner;
	const struct cred___18 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___124 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___122;

struct vm_operations_struct___122 {
	void (*open)(struct vm_area_struct___129 *);
	void (*close)(struct vm_area_struct___129 *);
	int (*may_split)(struct vm_area_struct___129 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___129 *);
	int (*mprotect)(struct vm_area_struct___129 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___122 *);
	vm_fault_t (*huge_fault)(struct vm_fault___122 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___122 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___129 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___122 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___122 *);
	int (*access)(struct vm_area_struct___129 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___129 *);
	int (*set_policy)(struct vm_area_struct___129 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___129 *, long unsigned int);
	struct page___129 * (*find_special_page)(struct vm_area_struct___129 *, long unsigned int);
};

struct core_thread___129 {
	struct task_struct___131 *task;
	struct core_thread___129 *next;
};

struct core_state___129 {
	atomic_t nr_threads;
	struct core_thread___129 dumper;
	struct completion startup;
};

struct linux_binprm___23;

struct coredump_params___22;

struct linux_binfmt___22 {
	struct list_head lh;
	struct module___114 *module;
	int (*load_binary)(struct linux_binprm___23 *);
	int (*load_shlib)(struct file___124 *);
	int (*core_dump)(struct coredump_params___22 *);
	long unsigned int min_coredump;
};

struct vm_fault___122 {
	const struct {
		struct vm_area_struct___129 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___129 *cow_page;
	struct page___129 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___129 prealloc_pte;
};

struct pglist_data___55;

struct lruvec___55 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___55 *pgdat;
};

struct zone___55 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___55 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___55 {
	struct zone___55 *zone;
	int zone_idx;
};

struct zonelist___55 {
	struct zoneref___55 _zonerefs[321];
};

struct pglist_data___55 {
	struct zone___55 node_zones[5];
	struct zonelist___55 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___131 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___131 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___55 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct fwnode_operations___94;

struct fwnode_handle___94 {
	struct fwnode_handle___94 *secondary;
	const struct fwnode_operations___94 *ops;
	struct device___94 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___94;

struct fwnode_endpoint___94;

struct fwnode_operations___94 {
	struct fwnode_handle___94 * (*get)(struct fwnode_handle___94 *);
	void (*put)(struct fwnode_handle___94 *);
	bool (*device_is_available)(const struct fwnode_handle___94 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___94 *, const struct device___94 *);
	bool (*property_present)(const struct fwnode_handle___94 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___94 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___94 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___94 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*get_parent)(const struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*get_next_child_node)(const struct fwnode_handle___94 *, struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*get_named_child_node)(const struct fwnode_handle___94 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___94 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___94 *);
	struct fwnode_handle___94 * (*graph_get_next_endpoint)(const struct fwnode_handle___94 *, struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*graph_get_remote_endpoint)(const struct fwnode_handle___94 *);
	struct fwnode_handle___94 * (*graph_get_port_parent)(struct fwnode_handle___94 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___94 *, struct fwnode_endpoint___94 *);
	int (*add_links)(struct fwnode_handle___94 *);
};

struct wakeup_source___94;

struct dev_pm_info___94 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___94 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___94 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___94;

struct bus_type___94;

struct device_driver___94;

struct dev_pm_domain___94;

struct class___94;

struct attribute_group___116;

struct device___94 {
	struct kobject___116 kobj;
	struct device___94 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___94 *type;
	struct bus_type___94 *bus;
	struct device_driver___94 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___94 power;
	struct dev_pm_domain___94 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___94 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___94 *class;
	const struct attribute_group___116 **groups;
	void (*release)(struct device___94 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___94 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___94 *local_fwnode;
};

struct fwnode_reference_args___94 {
	struct fwnode_handle___94 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___109;

struct seq_file___109 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___109 *op;
	int poll_event;
	const struct file___124 *file;
	void *private;
};

struct kernfs_root___116;

struct kernfs_elem_dir___116 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___116 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___116;

struct kernfs_root___116 {
	struct kernfs_node___116 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___116 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___116 {
	struct kernfs_node___116 *target_kn;
};

struct kernfs_ops___116;

struct kernfs_elem_attr___116 {
	const struct kernfs_ops___116 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___116 *notify_next;
};

struct kernfs_node___116 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___116 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___116 dir;
		struct kernfs_elem_symlink___116 symlink;
		struct kernfs_elem_attr___116 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___116;

struct kernfs_ops___116 {
	int (*open)(struct kernfs_open_file___116 *);
	void (*release)(struct kernfs_open_file___116 *);
	int (*seq_show)(struct seq_file___109 *, void *);
	void * (*seq_start)(struct seq_file___109 *, loff_t *);
	void * (*seq_next)(struct seq_file___109 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___109 *, void *);
	ssize_t (*read)(struct kernfs_open_file___116 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___116 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___116 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___116 *, struct vm_area_struct___129 *);
};

struct kernfs_syscall_ops___116 {
	int (*show_options)(struct seq_file___109 *, struct kernfs_root___116 *);
	int (*mkdir)(struct kernfs_node___116 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___116 *);
	int (*rename)(struct kernfs_node___116 *, struct kernfs_node___116 *, const char *);
	int (*show_path)(struct seq_file___109 *, struct kernfs_node___116 *, struct kernfs_root___116 *);
};

struct kernfs_open_file___116 {
	struct kernfs_node___116 *kn;
	struct file___124 *file;
	struct seq_file___109 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___122 *vm_ops;
};

struct bin_attribute___116;

struct attribute_group___116 {
	const char *name;
	umode_t (*is_visible)(struct kobject___116 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___116 *, struct bin_attribute___116 *, int);
	struct attribute **attrs;
	struct bin_attribute___116 **bin_attrs;
};

struct bin_attribute___116 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___124 * (*f_mapping)();
	ssize_t (*read)(struct file___124 *, struct kobject___116 *, struct bin_attribute___116 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___124 *, struct kobject___116 *, struct bin_attribute___116 *, char *, loff_t, size_t);
	int (*mmap)(struct file___124 *, struct kobject___116 *, struct bin_attribute___116 *, struct vm_area_struct___129 *);
};

struct sysfs_ops___116 {
	ssize_t (*show)(struct kobject___116 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___116 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___116;

struct kset___116 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___116 kobj;
	const struct kset_uevent_ops___116 *uevent_ops;
};

struct kobj_type___116 {
	void (*release)(struct kobject___116 *);
	const struct sysfs_ops___116 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___116 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___116 *);
	const void * (*namespace)(struct kobject___116 *);
	void (*get_ownership)(struct kobject___116 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___116 {
	int (* const filter)(struct kset___116 *, struct kobject___116 *);
	const char * (* const name)(struct kset___116 *, struct kobject___116 *);
	int (* const uevent)(struct kset___116 *, struct kobject___116 *, struct kobj_uevent_env *);
};

typedef int (*proc_write_t___6)(struct file___124 *, char *, size_t);

struct inode_operations___124;

struct proc_ops___13;

struct dentry_operations___124;

struct proc_dir_entry___7 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___124 *proc_iops;
	union {
		const struct proc_ops___13 *proc_ops;
		const struct file_operations___124 *proc_dir_ops;
	};
	const struct dentry_operations___124 *proc_dops;
	union {
		const struct seq_operations___109 *seq_ops;
		int (*single_show)(struct seq_file___109 *, void *);
	};
	proc_write_t___6 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___7 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct dentry___124 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___124 *d_parent;
	struct qstr d_name;
	struct inode___124 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___124 *d_op;
	struct super_block___124 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct cdev___22;

struct inode___124 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___124 *i_op;
	struct super_block___124 *i_sb;
	struct address_space___124 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___55 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___124 *i_fop;
		void (*free_inode)(struct inode___124 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___124 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___22 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___124 {
	int (*d_revalidate)(struct dentry___124 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___124 *, unsigned int);
	int (*d_hash)(const struct dentry___124 *, struct qstr *);
	int (*d_compare)(const struct dentry___124 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___124 *);
	int (*d_init)(struct dentry___124 *);
	void (*d_release)(struct dentry___124 *);
	void (*d_prune)(struct dentry___124 *);
	void (*d_iput)(struct dentry___124 *, struct inode___124 *);
	char * (*d_dname)(struct dentry___124 *, char *, int);
	struct vfsmount___124 * (*d_automount)(struct path___124 *);
	int (*d_manage)(const struct path___124 *, bool);
	struct dentry___124 * (*d_real)(struct dentry___124 *, const struct inode___124 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___124;

struct mem_dqinfo___124 {
	struct quota_format_type___124 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___124;

struct quota_info___124 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___124 *files[3];
	struct mem_dqinfo___124 info[3];
	const struct quota_format_ops___124 *ops[3];
};

struct rcuwait___125 {
	struct task_struct___131 *task;
};

struct percpu_rw_semaphore___125 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___125 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___124 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___125 rw_sem[3];
};

struct shrink_control___49;

struct shrinker___49 {
	long unsigned int (*count_objects)(struct shrinker___49 *, struct shrink_control___49 *);
	long unsigned int (*scan_objects)(struct shrinker___49 *, struct shrink_control___49 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___124;

struct dquot_operations___124;

struct quotactl_ops___124;

struct block_device___58;

struct super_block___124 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___124 *s_type;
	const struct super_operations___124 *s_op;
	const struct dquot_operations___124 *dq_op;
	const struct quotactl_ops___124 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___124 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___58 *s_bdev;
	struct backing_dev_info___55 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___124 s_dquot;
	struct sb_writers___124 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___124 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___18 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___124 {
	struct dentry___124 *mnt_root;
	struct super_block___124 *mnt_sb;
	int mnt_flags;
	struct user_namespace___18 *mnt_userns;
};

struct shrink_control___49 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___49 *memcg;
};

struct psi_group___92 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___131 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___92;

struct cgroup_rstat_cpu___92;

struct cgroup___92 {
	struct cgroup_subsys_state___92 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___116 *kn;
	struct cgroup_file___92 procs_file;
	struct cgroup_file___92 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___92 *subsys[14];
	struct cgroup_root___92 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___92 *dom_cgrp;
	struct cgroup___92 *old_dom_cgrp;
	struct cgroup_rstat_cpu___92 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___92 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___11;

struct tty_operations___11;

struct tty_ldisc___11;

struct fasync_struct___124;

struct tty_port___11;

struct tty_struct___11 {
	int magic;
	struct kref kref;
	struct device___94 *dev;
	struct tty_driver___11 *driver;
	const struct tty_operations___11 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___11 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___109 *pgrp;
		struct pid___109 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___11 *link;
	struct fasync_struct___124 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___11 *port;
};

struct io_cq___57 {
	struct request_queue___57 *q;
	struct io_context___57 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___56;

struct kiocb___124 {
	struct file___124 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___124 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___56 *ki_waitq;
	};
};

struct iattr___124 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___124 *ia_file;
};

struct dquot___124 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___124 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___124 {
	int qf_fmt_id;
	const struct quota_format_ops___124 *qf_ops;
	struct module___114 *qf_owner;
	struct quota_format_type___124 *qf_next;
};

struct quota_format_ops___124 {
	int (*check_quota_file)(struct super_block___124 *, int);
	int (*read_file_info)(struct super_block___124 *, int);
	int (*write_file_info)(struct super_block___124 *, int);
	int (*free_file_info)(struct super_block___124 *, int);
	int (*read_dqblk)(struct dquot___124 *);
	int (*commit_dqblk)(struct dquot___124 *);
	int (*release_dqblk)(struct dquot___124 *);
	int (*get_next_id)(struct super_block___124 *, struct kqid *);
};

struct dquot_operations___124 {
	int (*write_dquot)(struct dquot___124 *);
	struct dquot___124 * (*alloc_dquot)(struct super_block___124 *, int);
	void (*destroy_dquot)(struct dquot___124 *);
	int (*acquire_dquot)(struct dquot___124 *);
	int (*release_dquot)(struct dquot___124 *);
	int (*mark_dirty)(struct dquot___124 *);
	int (*write_info)(struct super_block___124 *, int);
	qsize_t * (*get_reserved_space)(struct inode___124 *);
	int (*get_projid)(struct inode___124 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___124 *, qsize_t *);
	int (*get_next_id)(struct super_block___124 *, struct kqid *);
};

struct quotactl_ops___124 {
	int (*quota_on)(struct super_block___124 *, int, int, const struct path___124 *);
	int (*quota_off)(struct super_block___124 *, int);
	int (*quota_enable)(struct super_block___124 *, unsigned int);
	int (*quota_disable)(struct super_block___124 *, unsigned int);
	int (*quota_sync)(struct super_block___124 *, int);
	int (*set_info)(struct super_block___124 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___124 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___124 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___124 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___124 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___124 *, unsigned int);
};

struct wait_page_queue___56 {
	struct page___129 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___55;

struct readahead_control___56;

struct swap_info_struct___31;

struct address_space_operations___124 {
	int (*writepage)(struct page___129 *, struct writeback_control___55 *);
	int (*readpage)(struct file___124 *, struct page___129 *);
	int (*writepages)(struct address_space___124 *, struct writeback_control___55 *);
	int (*set_page_dirty)(struct page___129 *);
	int (*readpages)(struct file___124 *, struct address_space___124 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___56 *);
	int (*write_begin)(struct file___124 *, struct address_space___124 *, loff_t, unsigned int, unsigned int, struct page___129 **, void **);
	int (*write_end)(struct file___124 *, struct address_space___124 *, loff_t, unsigned int, unsigned int, struct page___129 *, void *);
	sector_t (*bmap)(struct address_space___124 *, sector_t);
	void (*invalidatepage)(struct page___129 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___129 *, gfp_t);
	void (*freepage)(struct page___129 *);
	ssize_t (*direct_IO)(struct kiocb___124 *, struct iov_iter___70 *);
	int (*migratepage)(struct address_space___124 *, struct page___129 *, struct page___129 *, enum migrate_mode);
	bool (*isolate_page)(struct page___129 *, isolate_mode_t);
	void (*putback_page)(struct page___129 *);
	int (*launder_page)(struct page___129 *);
	int (*is_partially_uptodate)(struct page___129 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___129 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___124 *, struct page___129 *);
	int (*swap_activate)(struct swap_info_struct___31 *, struct file___124 *, sector_t *);
	void (*swap_deactivate)(struct file___124 *);
};

struct writeback_control___55 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___55 *wb;
	struct inode___124 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___56 {
	struct file___124 *file;
	struct address_space___124 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___68;

struct iov_iter___70 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___68 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___31 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___58 *bdev;
	struct file___124 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___22 {
	struct kobject___116 kobj;
	struct module___114 *owner;
	const struct file_operations___124 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___124 {
	struct dentry___124 * (*lookup)(struct inode___124 *, struct dentry___124 *, unsigned int);
	const char * (*get_link)(struct dentry___124 *, struct inode___124 *, struct delayed_call *);
	int (*permission)(struct user_namespace___18 *, struct inode___124 *, int);
	struct posix_acl * (*get_acl)(struct inode___124 *, int, bool);
	int (*readlink)(struct dentry___124 *, char *, int);
	int (*create)(struct user_namespace___18 *, struct inode___124 *, struct dentry___124 *, umode_t, bool);
	int (*link)(struct dentry___124 *, struct inode___124 *, struct dentry___124 *);
	int (*unlink)(struct inode___124 *, struct dentry___124 *);
	int (*symlink)(struct user_namespace___18 *, struct inode___124 *, struct dentry___124 *, const char *);
	int (*mkdir)(struct user_namespace___18 *, struct inode___124 *, struct dentry___124 *, umode_t);
	int (*rmdir)(struct inode___124 *, struct dentry___124 *);
	int (*mknod)(struct user_namespace___18 *, struct inode___124 *, struct dentry___124 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___18 *, struct inode___124 *, struct dentry___124 *, struct inode___124 *, struct dentry___124 *, unsigned int);
	int (*setattr)(struct user_namespace___18 *, struct dentry___124 *, struct iattr___124 *);
	int (*getattr)(struct user_namespace___18 *, const struct path___124 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___124 *, char *, size_t);
	int (*fiemap)(struct inode___124 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___124 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___124 *, struct dentry___124 *, struct file___124 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___18 *, struct inode___124 *, struct dentry___124 *, umode_t);
	int (*set_acl)(struct user_namespace___18 *, struct inode___124 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___18 *, struct dentry___124 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___124 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___124 {
	void (*fl_copy_lock)(struct file_lock___124 *, struct file_lock___124 *);
	void (*fl_release_private)(struct file_lock___124 *);
};

struct lock_manager_operations___124;

struct file_lock___124 {
	struct file_lock___124 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___124 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___124 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___124 *fl_ops;
	const struct lock_manager_operations___124 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___124 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___124 *);
	int (*lm_grant)(struct file_lock___124 *, int);
	bool (*lm_break)(struct file_lock___124 *);
	int (*lm_change)(struct file_lock___124 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___124 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___124 *);
};

struct fasync_struct___124 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___124 *fa_next;
	struct file___124 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___124 {
	struct inode___124 * (*alloc_inode)(struct super_block___124 *);
	void (*destroy_inode)(struct inode___124 *);
	void (*free_inode)(struct inode___124 *);
	void (*dirty_inode)(struct inode___124 *, int);
	int (*write_inode)(struct inode___124 *, struct writeback_control___55 *);
	int (*drop_inode)(struct inode___124 *);
	void (*evict_inode)(struct inode___124 *);
	void (*put_super)(struct super_block___124 *);
	int (*sync_fs)(struct super_block___124 *, int);
	int (*freeze_super)(struct super_block___124 *);
	int (*freeze_fs)(struct super_block___124 *);
	int (*thaw_super)(struct super_block___124 *);
	int (*unfreeze_fs)(struct super_block___124 *);
	int (*statfs)(struct dentry___124 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___124 *, int *, char *);
	void (*umount_begin)(struct super_block___124 *);
	int (*show_options)(struct seq_file___109 *, struct dentry___124 *);
	int (*show_devname)(struct seq_file___109 *, struct dentry___124 *);
	int (*show_path)(struct seq_file___109 *, struct dentry___124 *);
	int (*show_stats)(struct seq_file___109 *, struct dentry___124 *);
	ssize_t (*quota_read)(struct super_block___124 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___124 *, int, const char *, size_t, loff_t);
	struct dquot___124 ** (*get_dquots)(struct inode___124 *);
	long int (*nr_cached_objects)(struct super_block___124 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___124 *, struct shrink_control___49 *);
	struct file___124 * (*real_loop)(struct file___124 *);
};

struct block_device___58 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___124 *bd_inode;
	struct super_block___124 *bd_super;
	void *bd_claiming;
	struct device___94 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___116 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___57 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___124 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___57(struct bio___57 *);

struct bio_vec___68 {
	struct page___129 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___57;

struct bio___57 {
	struct bio___57 *bi_next;
	struct block_device___58 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___57 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___55 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___57 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___68 *bi_io_vec;
	struct bio_set___57 *bi_pool;
	struct bio_vec___68 bi_inline_vecs[0];
};

struct dev_pm_ops___94 {
	int (*prepare)(struct device___94 *);
	void (*complete)(struct device___94 *);
	int (*suspend)(struct device___94 *);
	int (*resume)(struct device___94 *);
	int (*freeze)(struct device___94 *);
	int (*thaw)(struct device___94 *);
	int (*poweroff)(struct device___94 *);
	int (*restore)(struct device___94 *);
	int (*suspend_late)(struct device___94 *);
	int (*resume_early)(struct device___94 *);
	int (*freeze_late)(struct device___94 *);
	int (*thaw_early)(struct device___94 *);
	int (*poweroff_late)(struct device___94 *);
	int (*restore_early)(struct device___94 *);
	int (*suspend_noirq)(struct device___94 *);
	int (*resume_noirq)(struct device___94 *);
	int (*freeze_noirq)(struct device___94 *);
	int (*thaw_noirq)(struct device___94 *);
	int (*poweroff_noirq)(struct device___94 *);
	int (*restore_noirq)(struct device___94 *);
	int (*runtime_suspend)(struct device___94 *);
	int (*runtime_resume)(struct device___94 *);
	int (*runtime_idle)(struct device___94 *);
};

struct wakeup_source___94 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___94 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___94 {
	struct dev_pm_ops___94 ops;
	int (*start)(struct device___94 *);
	void (*detach)(struct device___94 *, bool);
	int (*activate)(struct device___94 *);
	void (*sync)(struct device___94 *);
	void (*dismiss)(struct device___94 *);
};

struct bus_type___94 {
	const char *name;
	const char *dev_name;
	struct device___94 *dev_root;
	const struct attribute_group___116 **bus_groups;
	const struct attribute_group___116 **dev_groups;
	const struct attribute_group___116 **drv_groups;
	int (*match)(struct device___94 *, struct device_driver___94 *);
	int (*uevent)(struct device___94 *, struct kobj_uevent_env *);
	int (*probe)(struct device___94 *);
	void (*sync_state)(struct device___94 *);
	void (*remove)(struct device___94 *);
	void (*shutdown)(struct device___94 *);
	int (*online)(struct device___94 *);
	int (*offline)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	int (*num_vf)(struct device___94 *);
	int (*dma_configure)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___94 {
	const char *name;
	struct bus_type___94 *bus;
	struct module___114 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___94 *);
	void (*sync_state)(struct device___94 *);
	int (*remove)(struct device___94 *);
	void (*shutdown)(struct device___94 *);
	int (*suspend)(struct device___94 *, pm_message_t);
	int (*resume)(struct device___94 *);
	const struct attribute_group___116 **groups;
	const struct attribute_group___116 **dev_groups;
	const struct dev_pm_ops___94 *pm;
	void (*coredump)(struct device___94 *);
	struct driver_private *p;
};

struct device_type___94 {
	const char *name;
	const struct attribute_group___116 **groups;
	int (*uevent)(struct device___94 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___94 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___94 *);
	const struct dev_pm_ops___94 *pm;
};

struct class___94 {
	const char *name;
	struct module___114 *owner;
	const struct attribute_group___116 **class_groups;
	const struct attribute_group___116 **dev_groups;
	struct kobject___116 *dev_kobj;
	int (*dev_uevent)(struct device___94 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___94 *, umode_t *);
	void (*class_release)(struct class___94 *);
	void (*dev_release)(struct device___94 *);
	int (*shutdown_pre)(struct device___94 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___94 *);
	void (*get_ownership)(struct device___94 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___94 *pm;
	struct subsys_private *p;
};

struct seq_operations___109 {
	void * (*start)(struct seq_file___109 *, loff_t *);
	void (*stop)(struct seq_file___109 *, void *);
	void * (*next)(struct seq_file___109 *, void *, loff_t *);
	int (*show)(struct seq_file___109 *, void *);
};

struct tty_operations___11 {
	struct tty_struct___11 * (*lookup)(struct tty_driver___11 *, struct file___124 *, int);
	int (*install)(struct tty_driver___11 *, struct tty_struct___11 *);
	void (*remove)(struct tty_driver___11 *, struct tty_struct___11 *);
	int (*open)(struct tty_struct___11 *, struct file___124 *);
	void (*close)(struct tty_struct___11 *, struct file___124 *);
	void (*shutdown)(struct tty_struct___11 *);
	void (*cleanup)(struct tty_struct___11 *);
	int (*write)(struct tty_struct___11 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___11 *, unsigned char);
	void (*flush_chars)(struct tty_struct___11 *);
	unsigned int (*write_room)(struct tty_struct___11 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___11 *);
	int (*ioctl)(struct tty_struct___11 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___11 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___11 *, struct ktermios *);
	void (*throttle)(struct tty_struct___11 *);
	void (*unthrottle)(struct tty_struct___11 *);
	void (*stop)(struct tty_struct___11 *);
	void (*start)(struct tty_struct___11 *);
	void (*hangup)(struct tty_struct___11 *);
	int (*break_ctl)(struct tty_struct___11 *, int);
	void (*flush_buffer)(struct tty_struct___11 *);
	void (*set_ldisc)(struct tty_struct___11 *);
	void (*wait_until_sent)(struct tty_struct___11 *, int);
	void (*send_xchar)(struct tty_struct___11 *, char);
	int (*tiocmget)(struct tty_struct___11 *);
	int (*tiocmset)(struct tty_struct___11 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___11 *, struct winsize *);
	int (*get_icount)(struct tty_struct___11 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___11 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___11 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___11 *, struct seq_file___109 *);
	int (*poll_init)(struct tty_driver___11 *, int, char *);
	int (*poll_get_char)(struct tty_driver___11 *, int);
	void (*poll_put_char)(struct tty_driver___11 *, int, char);
	int (*proc_show)(struct seq_file___109 *, void *);
};

struct tty_driver___11 {
	int magic;
	struct kref kref;
	struct cdev___22 **cdevs;
	struct module___114 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry___7 *proc_entry;
	struct tty_driver___11 *other;
	struct tty_struct___11 **ttys;
	struct tty_port___11 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___11 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___11;

struct tty_port_client_operations___11;

struct tty_port___11 {
	struct tty_bufhead buf;
	struct tty_struct___11 *tty;
	struct tty_struct___11 *itty;
	const struct tty_port_operations___11 *ops;
	const struct tty_port_client_operations___11 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___11 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___11 *);
	void (*close)(struct tty_struct___11 *);
	void (*flush_buffer)(struct tty_struct___11 *);
	ssize_t (*read)(struct tty_struct___11 *, struct file___124 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___11 *, struct file___124 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___11 *, struct file___124 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___11 *, struct file___124 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___11 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___11 *, struct file___124 *, struct poll_table_struct___5 *);
	int (*hangup)(struct tty_struct___11 *);
	void (*receive_buf)(struct tty_struct___11 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___11 *);
	void (*dcd_change)(struct tty_struct___11 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___11 *, const unsigned char *, const char *, int);
	struct module___114 *owner;
};

struct tty_ldisc___11 {
	struct tty_ldisc_ops___11 *ops;
	struct tty_struct___11 *tty;
};

struct tty_port_operations___11 {
	int (*carrier_raised)(struct tty_port___11 *);
	void (*dtr_rts)(struct tty_port___11 *, int);
	void (*shutdown)(struct tty_port___11 *);
	int (*activate)(struct tty_port___11 *, struct tty_struct___11 *);
	void (*destruct)(struct tty_port___11 *);
};

struct tty_port_client_operations___11 {
	int (*receive_buf)(struct tty_port___11 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___11 *);
};

struct dev_pagemap_ops___122 {
	void (*page_free)(struct page___129 *);
	void (*kill)(struct dev_pagemap___122 *);
	void (*cleanup)(struct dev_pagemap___122 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___122 *);
};

struct proc_ops___13 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___124 *, struct file___124 *);
	ssize_t (*proc_read)(struct file___124 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___124 *, struct iov_iter___70 *);
	ssize_t (*proc_write)(struct file___124 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___124 *, loff_t, int);
	int (*proc_release)(struct inode___124 *, struct file___124 *);
	__poll_t (*proc_poll)(struct file___124 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___124 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___124 *, struct vm_area_struct___129 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___124 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct proc_fs_info___6 {
	struct pid_namespace___109 *pid_ns;
	struct dentry___124 *proc_self;
	struct dentry___124 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

struct kernel_param_ops___113 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___113 *);
	int (*get)(char *, const struct kernel_param___113 *);
	void (*free)(void *);
};

struct kparam_array___113;

struct kernel_param___113 {
	const char *name;
	struct module___114 *mod;
	const struct kernel_param_ops___113 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___113 *arr;
	};
};

struct kparam_array___113 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___113 *ops;
	void *elem;
};

struct module_attribute___113 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___113 *, struct module_kobject___113 *, char *);
	ssize_t (*store)(struct module_attribute___113 *, struct module_kobject___113 *, const char *, size_t);
	void (*setup)(struct module___114 *, const char *);
	int (*test)(struct module___114 *);
	void (*free)(struct module___114 *);
};

struct cftype___92;

struct cgroup_subsys___92 {
	struct cgroup_subsys_state___92 * (*css_alloc)(struct cgroup_subsys_state___92 *);
	int (*css_online)(struct cgroup_subsys_state___92 *);
	void (*css_offline)(struct cgroup_subsys_state___92 *);
	void (*css_released)(struct cgroup_subsys_state___92 *);
	void (*css_free)(struct cgroup_subsys_state___92 *);
	void (*css_reset)(struct cgroup_subsys_state___92 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___92 *, int);
	int (*css_extra_stat_show)(struct seq_file___109 *, struct cgroup_subsys_state___92 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___131 *, struct css_set___92 *);
	void (*cancel_fork)(struct task_struct___131 *, struct css_set___92 *);
	void (*fork)(struct task_struct___131 *);
	void (*exit)(struct task_struct___131 *);
	void (*release)(struct task_struct___131 *);
	void (*bind)(struct cgroup_subsys_state___92 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___92 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___92 *dfl_cftypes;
	struct cftype___92 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___92 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___92 *updated_children;
	struct cgroup___92 *updated_next;
};

struct cgroup_root___92 {
	struct kernfs_root___116 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___92 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___92 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___92 *ss;
	struct list_head node;
	struct kernfs_ops___116 *kf_ops;
	int (*open)(struct kernfs_open_file___116 *);
	void (*release)(struct kernfs_open_file___116 *);
	u64 (*read_u64)(struct cgroup_subsys_state___92 *, struct cftype___92 *);
	s64 (*read_s64)(struct cgroup_subsys_state___92 *, struct cftype___92 *);
	int (*seq_show)(struct seq_file___109 *, void *);
	void * (*seq_start)(struct seq_file___109 *, loff_t *);
	void * (*seq_next)(struct seq_file___109 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___109 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___92 *, struct cftype___92 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___92 *, struct cftype___92 *, s64);
	ssize_t (*write)(struct kernfs_open_file___116 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___116 *, struct poll_table_struct___5 *);
};

struct block_device_operations___57;

struct gendisk___57 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___58 *part0;
	const struct block_device_operations___57 *fops;
	struct request_queue___57 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___55 *bdi;
	struct kobject___116 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___116 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___57 {
	struct bio___57 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___68 *bip_vec;
	struct bio_vec___68 bip_inline_vecs[0];
};

struct blkcg___55;

struct blkg_policy_data___55;

struct blkcg_gq___55 {
	struct request_queue___57 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___55 *blkcg;
	struct blkcg_gq___55 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___55 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___57 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___57(struct request___57 *);

typedef void integrity_complete_fn___57(struct request___57 *, unsigned int);

struct blk_integrity_profile___57 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___57 *prepare_fn;
	integrity_complete_fn___57 *complete_fn;
	const char *name;
};

struct block_device_operations___57 {
	blk_qc_t (*submit_bio)(struct bio___57 *);
	int (*open)(struct block_device___58 *, fmode_t);
	void (*release)(struct gendisk___57 *, fmode_t);
	int (*rw_page)(struct block_device___58 *, sector_t, struct page___129 *, unsigned int);
	int (*ioctl)(struct block_device___58 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___58 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___57 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___57 *);
	int (*getgeo)(struct block_device___58 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___58 *, bool);
	void (*swap_slot_free_notify)(struct block_device___58 *, long unsigned int);
	int (*report_zones)(struct gendisk___57 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___57 *, umode_t *);
	struct module___114 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___57 *, sector_t *);
};

typedef void rq_end_io_fn___57(struct request___57 *, blk_status_t);

struct request___57 {
	struct request_queue___57 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___55 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___57 *bio;
	struct bio___57 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___68 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___57 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___57 *saved_end_io;
		} flush;
	};
	struct gendisk___57 *rq_disk;
	struct block_device___58 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___57 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___55 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___57 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___116 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___124 *debugfs_dir;
	struct dentry___124 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___57;

struct elevator_mq_ops___57 {
	int (*init_sched)(struct request_queue___57 *, struct elevator_type___57 *);
	void (*exit_sched)(struct elevator_queue___57 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___55 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___55 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___55 *);
	bool (*allow_merge)(struct request_queue___57 *, struct request___57 *, struct bio___57 *);
	bool (*bio_merge)(struct request_queue___57 *, struct bio___57 *, unsigned int);
	int (*request_merge)(struct request_queue___57 *, struct request___57 **, struct bio___57 *);
	void (*request_merged)(struct request_queue___57 *, struct request___57 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___57 *, struct request___57 *, struct request___57 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___57 *);
	void (*finish_request)(struct request___57 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___55 *, struct list_head *, bool);
	struct request___57 * (*dispatch_request)(struct blk_mq_hw_ctx___55 *);
	bool (*has_work)(struct blk_mq_hw_ctx___55 *);
	void (*completed_request)(struct request___57 *, u64);
	void (*requeue_request)(struct request___57 *);
	struct request___57 * (*former_request)(struct request_queue___57 *, struct request___57 *);
	struct request___57 * (*next_request)(struct request_queue___57 *, struct request___57 *);
	void (*init_icq)(struct io_cq___57 *);
	void (*exit_icq)(struct io_cq___57 *);
};

struct elv_fs_entry___57;

struct elevator_type___57 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___57 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___57 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___114 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___57 {
	struct elevator_type___57 *type;
	void *elevator_data;
	struct kobject___116 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___57 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___57 *, char *);
	ssize_t (*store)(struct elevator_queue___57 *, const char *, size_t);
};

struct blk_mq_queue_data___55;

struct blk_mq_ops___55 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___55 *, const struct blk_mq_queue_data___55 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___55 *);
	int (*get_budget)(struct request_queue___57 *);
	void (*put_budget)(struct request_queue___57 *, int);
	void (*set_rq_budget_token)(struct request___57 *, int);
	int (*get_rq_budget_token)(struct request___57 *);
	enum blk_eh_timer_return (*timeout)(struct request___57 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___55 *);
	void (*complete)(struct request___57 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___55 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___55 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___55 *, struct request___57 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___55 *, struct request___57 *, unsigned int);
	void (*initialize_rq_fn)(struct request___57 *);
	void (*cleanup_rq)(struct request___57 *);
	bool (*busy)(struct request_queue___57 *);
	int (*map_queues)(struct blk_mq_tag_set___55 *);
	void (*show_rq)(struct seq_file___109 *, struct request___57 *);
};

struct blk_mq_tag_set___55 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___55 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___55 {
	struct request___57 *rq;
	bool last;
};

struct blkcg_policy_data___55;

struct blkcg___55 {
	struct cgroup_subsys_state___92 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___55 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___55 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___55 {
	struct blkcg___55 *blkcg;
	int plid;
};

struct blkg_policy_data___55 {
	struct blkcg_gq___55 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___49 {
	struct mem_cgroup___49 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___49 {
	struct lruvec___55 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___49 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___49 *memcg;
};

struct obj_cgroup___49 {
	struct percpu_ref refcnt;
	struct mem_cgroup___49 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct linux_binprm___23 {
	struct vm_area_struct___129 *vma;
	long unsigned int vma_pages;
	struct mm_struct___130 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___124 *executable;
	struct file___124 *interpreter;
	struct file___124 *file;
	struct cred___18 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___22 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___124 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

union proc_op___5 {
	int (*proc_get_link)(struct dentry___124 *, struct path___124 *);
	int (*proc_show)(struct seq_file___109 *, struct pid_namespace___109 *, struct pid___109 *, struct task_struct___131 *);
	const char *lsm;
};

struct proc_inode___5 {
	struct pid___109 *pid;
	unsigned int fd;
	union proc_op___5 op;
	struct proc_dir_entry___7 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___20 *ns_ops;
	struct inode___124 vfs_inode;
};

struct dentry___125;

struct super_block___125;

struct file_system_type___125 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___125 * (*mount)(struct file_system_type___125 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___125 *);
	struct module___8 *owner;
	struct file_system_type___125 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___125;

struct kiocb___125;

struct poll_table_struct___85;

struct vm_area_struct___130;

struct inode___125;

struct file_lock___125;

struct page___130;

struct seq_file___110;

struct file_operations___125 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___125 *, loff_t, int);
	ssize_t (*read)(struct file___125 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___125 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___125 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___125 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___125 *, bool);
	int (*iterate)(struct file___125 *, struct dir_context *);
	int (*iterate_shared)(struct file___125 *, struct dir_context *);
	__poll_t (*poll)(struct file___125 *, struct poll_table_struct___85 *);
	long int (*unlocked_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___125 *, struct vm_area_struct___130 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___125 *, struct file___125 *);
	int (*flush)(struct file___125 *, fl_owner_t);
	int (*release)(struct inode___125 *, struct file___125 *);
	int (*fsync)(struct file___125 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___125 *, int);
	int (*lock)(struct file___125 *, int, struct file_lock___125 *);
	ssize_t (*sendpage)(struct file___125 *, struct page___130 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___125 *, long unsigned int);
	int (*flock)(struct file___125 *, int, struct file_lock___125 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___125 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___125 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___125 *, long int, struct file_lock___125 **, void **);
	long int (*fallocate)(struct file___125 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___110 *, struct file___125 *);
	ssize_t (*copy_file_range)(struct file___125 *, loff_t, struct file___125 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___125 *, loff_t, struct file___125 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___125 *, loff_t, loff_t, int);
};

struct vmacache___130 {
	u64 seqnum;
	struct vm_area_struct___130 *vmas[4];
};

struct page_frag___130 {
	struct page___130 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___131;

struct pid___110;

struct files_struct___18;

struct nsproxy___116;

struct signal_struct___126;

struct task_struct___132 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___132 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___131 *mm;
	struct mm_struct___131 *active_mm;
	struct vmacache___130 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___132 *real_parent;
	struct task_struct___132 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___132 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___110 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___18 *ptracer_cred;
	const struct cred___18 *real_cred;
	const struct cred___18 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___18 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___116 *nsproxy;
	struct signal_struct___126 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___132 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___130 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___132 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___110;

struct upid___110 {
	int nr;
	struct pid_namespace___110 *ns;
};

struct proc_ns_operations___21;

struct ns_common___21 {
	atomic_long_t stashed;
	const struct proc_ns_operations___21 *ops;
	unsigned int inum;
	refcount_t count;
};

struct pid_namespace___110 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___132 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___110 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___21 ns;
};

struct pid___110 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___110 numbers[1];
};

typedef struct page___130 *pgtable_t___130;

struct address_space___125;

struct dev_pagemap___123;

struct page___130 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___125 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___32 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___130 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___130 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___131 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___123 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___123;

struct vm_area_struct___130 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___130 *vm_next;
	struct vm_area_struct___130 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___131 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___123 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___125 *vm_file;
	struct file___125 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___126 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___132 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___132 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___110 *pids[4];
	struct pid___110 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___131 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___23;

struct core_state___130;

struct mm_struct___131 {
	struct {
		struct vm_area_struct___130 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___23 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___130 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___132 *owner;
		struct user_namespace *user_ns;
		struct file___125 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___18 {
	unsigned int max_fds;
	struct file___125 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___18 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___18 *fdt;
	struct fdtable___18 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___125 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mnt_namespace___14;

struct nsproxy___116 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace___14 *mnt_ns;
	struct pid_namespace___110 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct address_space_operations___125;

struct address_space___125 {
	struct inode___125 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___125 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___123;

struct dev_pagemap___123 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___123 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___125;

struct path___125 {
	struct vfsmount___125 *mnt;
	struct dentry___125 *dentry;
};

struct fown_struct___110 {
	rwlock_t lock;
	struct pid___110 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___125 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___125 f_path;
	struct inode___125 *f_inode;
	const struct file_operations___125 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___110 f_owner;
	const struct cred___18 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___125 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___123;

struct vm_operations_struct___123 {
	void (*open)(struct vm_area_struct___130 *);
	void (*close)(struct vm_area_struct___130 *);
	int (*may_split)(struct vm_area_struct___130 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___130 *);
	int (*mprotect)(struct vm_area_struct___130 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___123 *);
	vm_fault_t (*huge_fault)(struct vm_fault___123 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___123 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___130 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___123 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___123 *);
	int (*access)(struct vm_area_struct___130 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___130 *);
	int (*set_policy)(struct vm_area_struct___130 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___130 *, long unsigned int);
	struct page___130 * (*find_special_page)(struct vm_area_struct___130 *, long unsigned int);
};

struct core_thread___130 {
	struct task_struct___132 *task;
	struct core_thread___130 *next;
};

struct core_state___130 {
	atomic_t nr_threads;
	struct core_thread___130 dumper;
	struct completion startup;
};

struct linux_binprm___24;

struct coredump_params___23;

struct linux_binfmt___23 {
	struct list_head lh;
	struct module___8 *module;
	int (*load_binary)(struct linux_binprm___24 *);
	int (*load_shlib)(struct file___125 *);
	int (*core_dump)(struct coredump_params___23 *);
	long unsigned int min_coredump;
};

struct vm_fault___123 {
	const struct {
		struct vm_area_struct___130 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___130 *cow_page;
	struct page___130 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___130 prealloc_pte;
};

struct dentry_operations___125;

struct dentry___125 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___125 *d_parent;
	struct qstr d_name;
	struct inode___125 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___125 *d_op;
	struct super_block___125 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___125;

struct inode___125 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___125 *i_op;
	struct super_block___125 *i_sb;
	struct address_space___125 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___125 *i_fop;
		void (*free_inode)(struct inode___125 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___125 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___22 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___125 {
	int (*d_revalidate)(struct dentry___125 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___125 *, unsigned int);
	int (*d_hash)(const struct dentry___125 *, struct qstr *);
	int (*d_compare)(const struct dentry___125 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___125 *);
	int (*d_init)(struct dentry___125 *);
	void (*d_release)(struct dentry___125 *);
	void (*d_prune)(struct dentry___125 *);
	void (*d_iput)(struct dentry___125 *, struct inode___125 *);
	char * (*d_dname)(struct dentry___125 *, char *, int);
	struct vfsmount___125 * (*d_automount)(struct path___125 *);
	int (*d_manage)(const struct path___125 *, bool);
	struct dentry___125 * (*d_real)(struct dentry___125 *, const struct inode___125 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___125;

struct mem_dqinfo___125 {
	struct quota_format_type___125 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___125;

struct quota_info___125 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___125 *files[3];
	struct mem_dqinfo___125 info[3];
	const struct quota_format_ops___125 *ops[3];
};

struct rcuwait___126 {
	struct task_struct___132 *task;
};

struct percpu_rw_semaphore___126 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___126 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___125 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___126 rw_sem[3];
};

struct super_operations___125;

struct dquot_operations___125;

struct quotactl_ops___125;

struct super_block___125 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___125 *s_type;
	const struct super_operations___125 *s_op;
	const struct dquot_operations___125 *dq_op;
	const struct quotactl_ops___125 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___125 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___125 s_dquot;
	struct sb_writers___125 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___125 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___125 {
	struct dentry___125 *mnt_root;
	struct super_block___125 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___125 {
	struct file___125 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___125 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___56 *ki_waitq;
	};
};

struct iattr___125 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___125 *ia_file;
};

struct dquot___125 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___125 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___125 {
	int qf_fmt_id;
	const struct quota_format_ops___125 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___125 *qf_next;
};

struct quota_format_ops___125 {
	int (*check_quota_file)(struct super_block___125 *, int);
	int (*read_file_info)(struct super_block___125 *, int);
	int (*write_file_info)(struct super_block___125 *, int);
	int (*free_file_info)(struct super_block___125 *, int);
	int (*read_dqblk)(struct dquot___125 *);
	int (*commit_dqblk)(struct dquot___125 *);
	int (*release_dqblk)(struct dquot___125 *);
	int (*get_next_id)(struct super_block___125 *, struct kqid *);
};

struct dquot_operations___125 {
	int (*write_dquot)(struct dquot___125 *);
	struct dquot___125 * (*alloc_dquot)(struct super_block___125 *, int);
	void (*destroy_dquot)(struct dquot___125 *);
	int (*acquire_dquot)(struct dquot___125 *);
	int (*release_dquot)(struct dquot___125 *);
	int (*mark_dirty)(struct dquot___125 *);
	int (*write_info)(struct super_block___125 *, int);
	qsize_t * (*get_reserved_space)(struct inode___125 *);
	int (*get_projid)(struct inode___125 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___125 *, qsize_t *);
	int (*get_next_id)(struct super_block___125 *, struct kqid *);
};

struct quotactl_ops___125 {
	int (*quota_on)(struct super_block___125 *, int, int, const struct path___125 *);
	int (*quota_off)(struct super_block___125 *, int);
	int (*quota_enable)(struct super_block___125 *, unsigned int);
	int (*quota_disable)(struct super_block___125 *, unsigned int);
	int (*quota_sync)(struct super_block___125 *, int);
	int (*set_info)(struct super_block___125 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___125 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___125 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___125 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___125 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___125 *, unsigned int);
};

struct address_space_operations___125 {
	int (*writepage)(struct page___130 *, struct writeback_control___3 *);
	int (*readpage)(struct file___125 *, struct page___130 *);
	int (*writepages)(struct address_space___125 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___130 *);
	int (*readpages)(struct file___125 *, struct address_space___125 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___125 *, struct address_space___125 *, loff_t, unsigned int, unsigned int, struct page___130 **, void **);
	int (*write_end)(struct file___125 *, struct address_space___125 *, loff_t, unsigned int, unsigned int, struct page___130 *, void *);
	sector_t (*bmap)(struct address_space___125 *, sector_t);
	void (*invalidatepage)(struct page___130 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___130 *, gfp_t);
	void (*freepage)(struct page___130 *);
	ssize_t (*direct_IO)(struct kiocb___125 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___125 *, struct page___130 *, struct page___130 *, enum migrate_mode);
	bool (*isolate_page)(struct page___130 *, isolate_mode_t);
	void (*putback_page)(struct page___130 *);
	int (*launder_page)(struct page___130 *);
	int (*is_partially_uptodate)(struct page___130 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___130 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___125 *, struct page___130 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___125 *, sector_t *);
	void (*swap_deactivate)(struct file___125 *);
};

struct inode_operations___125 {
	struct dentry___125 * (*lookup)(struct inode___125 *, struct dentry___125 *, unsigned int);
	const char * (*get_link)(struct dentry___125 *, struct inode___125 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___125 *, int);
	struct posix_acl * (*get_acl)(struct inode___125 *, int, bool);
	int (*readlink)(struct dentry___125 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___125 *, struct dentry___125 *, umode_t, bool);
	int (*link)(struct dentry___125 *, struct inode___125 *, struct dentry___125 *);
	int (*unlink)(struct inode___125 *, struct dentry___125 *);
	int (*symlink)(struct user_namespace *, struct inode___125 *, struct dentry___125 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___125 *, struct dentry___125 *, umode_t);
	int (*rmdir)(struct inode___125 *, struct dentry___125 *);
	int (*mknod)(struct user_namespace *, struct inode___125 *, struct dentry___125 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___125 *, struct dentry___125 *, struct inode___125 *, struct dentry___125 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___125 *, struct iattr___125 *);
	int (*getattr)(struct user_namespace *, const struct path___125 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___125 *, char *, size_t);
	int (*fiemap)(struct inode___125 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___125 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___125 *, struct dentry___125 *, struct file___125 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___125 *, struct dentry___125 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___125 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___125 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___125 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___125 {
	void (*fl_copy_lock)(struct file_lock___125 *, struct file_lock___125 *);
	void (*fl_release_private)(struct file_lock___125 *);
};

struct fasync_struct___125;

struct lock_manager_operations___125;

struct file_lock___125 {
	struct file_lock___125 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___125 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___125 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___125 *fl_ops;
	const struct lock_manager_operations___125 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___125 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___125 *);
	int (*lm_grant)(struct file_lock___125 *, int);
	bool (*lm_break)(struct file_lock___125 *);
	int (*lm_change)(struct file_lock___125 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___125 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___125 *);
};

struct fasync_struct___125 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___125 *fa_next;
	struct file___125 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___125 {
	struct inode___125 * (*alloc_inode)(struct super_block___125 *);
	void (*destroy_inode)(struct inode___125 *);
	void (*free_inode)(struct inode___125 *);
	void (*dirty_inode)(struct inode___125 *, int);
	int (*write_inode)(struct inode___125 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___125 *);
	void (*evict_inode)(struct inode___125 *);
	void (*put_super)(struct super_block___125 *);
	int (*sync_fs)(struct super_block___125 *, int);
	int (*freeze_super)(struct super_block___125 *);
	int (*freeze_fs)(struct super_block___125 *);
	int (*thaw_super)(struct super_block___125 *);
	int (*unfreeze_fs)(struct super_block___125 *);
	int (*statfs)(struct dentry___125 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___125 *, int *, char *);
	void (*umount_begin)(struct super_block___125 *);
	int (*show_options)(struct seq_file___110 *, struct dentry___125 *);
	int (*show_devname)(struct seq_file___110 *, struct dentry___125 *);
	int (*show_path)(struct seq_file___110 *, struct dentry___125 *);
	int (*show_stats)(struct seq_file___110 *, struct dentry___125 *);
	ssize_t (*quota_read)(struct super_block___125 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___125 *, int, const char *, size_t, loff_t);
	struct dquot___125 ** (*get_dquots)(struct inode___125 *);
	long int (*nr_cached_objects)(struct super_block___125 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___125 *, struct shrink_control___49 *);
	struct file___125 * (*real_loop)(struct file___125 *);
};

typedef void (*poll_queue_proc___86)(struct file___125 *, wait_queue_head_t *, struct poll_table_struct___85 *);

struct poll_table_struct___85 {
	poll_queue_proc___86 _qproc;
	__poll_t _key;
};

struct seq_operations___110;

struct seq_file___110 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___110 *op;
	int poll_event;
	const struct file___125 *file;
	void *private;
};

struct dev_pagemap_ops___123 {
	void (*page_free)(struct page___130 *);
	void (*kill)(struct dev_pagemap___123 *);
	void (*cleanup)(struct dev_pagemap___123 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___123 *);
};

struct mount___14;

struct mnt_namespace___14 {
	struct ns_common___21 ns;
	struct mount___14 *root;
	struct list_head list;
	spinlock_t ns_lock;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	u64 seq;
	wait_queue_head_t poll;
	u64 event;
	unsigned int mounts;
	unsigned int pending_mounts;
};

struct nsset___20 {
	unsigned int flags;
	struct nsproxy___116 *nsproxy;
	struct fs_struct *fs;
	const struct cred___18 *cred;
};

struct proc_ns_operations___21 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___21 * (*get)(struct task_struct___132 *);
	void (*put)(struct ns_common___21 *);
	int (*install)(struct nsset___20 *, struct ns_common___21 *);
	struct user_namespace * (*owner)(struct ns_common___21 *);
	struct ns_common___21 * (*get_parent)(struct ns_common___21 *);
};

struct seq_operations___110 {
	void * (*start)(struct seq_file___110 *, loff_t *);
	void (*stop)(struct seq_file___110 *, void *);
	void * (*next)(struct seq_file___110 *, void *, loff_t *);
	int (*show)(struct seq_file___110 *, void *);
};

struct proc_ops___14 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___125 *, struct file___125 *);
	ssize_t (*proc_read)(struct file___125 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___125 *, struct iov_iter___4 *);
	ssize_t (*proc_write)(struct file___125 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___125 *, loff_t, int);
	int (*proc_release)(struct inode___125 *, struct file___125 *);
	__poll_t (*proc_poll)(struct file___125 *, struct poll_table_struct___85 *);
	long int (*proc_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___125 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___125 *, struct vm_area_struct___130 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___125 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

typedef int (*proc_write_t___7)(struct file___125 *, char *, size_t);

struct mountpoint___14;

struct mount___14 {
	struct hlist_node mnt_hash;
	struct mount___14 *mnt_parent;
	struct dentry___125 *mnt_mountpoint;
	struct vfsmount___125 mnt;
	union {
		struct callback_head mnt_rcu;
		struct llist_node mnt_llist;
	};
	struct mnt_pcp *mnt_pcp;
	struct list_head mnt_mounts;
	struct list_head mnt_child;
	struct list_head mnt_instance;
	const char *mnt_devname;
	struct list_head mnt_list;
	struct list_head mnt_expire;
	struct list_head mnt_share;
	struct list_head mnt_slave_list;
	struct list_head mnt_slave;
	struct mount___14 *mnt_master;
	struct mnt_namespace___14 *mnt_ns;
	struct mountpoint___14 *mnt_mp;
	union {
		struct hlist_node mnt_mp_list;
		struct hlist_node mnt_umount;
	};
	struct list_head mnt_umounting;
	struct fsnotify_mark_connector *mnt_fsnotify_marks;
	__u32 mnt_fsnotify_mask;
	int mnt_id;
	int mnt_group_id;
	int mnt_expiry_mark;
	struct hlist_head mnt_pins;
	struct hlist_head mnt_stuck_children;
};

struct mountpoint___14 {
	struct hlist_node m_hash;
	struct dentry___125 *m_dentry;
	struct hlist_head m_list;
	int m_count;
};

struct linux_binprm___24 {
	struct vm_area_struct___130 *vma;
	long unsigned int vma_pages;
	struct mm_struct___131 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___125 *executable;
	struct file___125 *interpreter;
	struct file___125 *file;
	struct cred___18 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___23 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___125 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct proc_dir_entry___8 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___125 *proc_iops;
	union {
		const struct proc_ops___14 *proc_ops;
		const struct file_operations___125 *proc_dir_ops;
	};
	const struct dentry_operations___125 *proc_dops;
	union {
		const struct seq_operations___110 *seq_ops;
		int (*single_show)(struct seq_file___110 *, void *);
	};
	proc_write_t___7 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___8 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

union proc_op___6 {
	int (*proc_get_link)(struct dentry___125 *, struct path___125 *);
	int (*proc_show)(struct seq_file___110 *, struct pid_namespace___110 *, struct pid___110 *, struct task_struct___132 *);
	const char *lsm;
};

struct proc_inode___6 {
	struct pid___110 *pid;
	unsigned int fd;
	union proc_op___6 op;
	struct proc_dir_entry___8 *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___21 *ns_ops;
	struct inode___125 vfs_inode;
};

typedef struct dentry___125 *instantiate_t___2(struct dentry___125 *, struct task_struct___132 *, const void *);

struct fd_data {
	fmode_t mode;
	unsigned int fd;
};

struct tty_driver___12;

struct console___3 {
	char name[16];
	void (*write)(struct console___3 *, const char *, unsigned int);
	int (*read)(struct console___3 *, char *, unsigned int);
	struct tty_driver___12 * (*device)(struct console___3 *, int *);
	void (*unblank)();
	int (*setup)(struct console___3 *, char *);
	int (*exit)(struct console___3 *);
	int (*match)(struct console___3 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___3 *next;
};

struct tty_port___12;

struct tty_operations___12;

struct tty_driver___12 {
	int magic;
	struct kref kref;
	struct cdev___5 **cdevs;
	struct module___8 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___12 *other;
	struct tty_struct **ttys;
	struct tty_port___12 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___12 *ops;
	struct list_head tty_drivers;
};

struct tty_operations___12 {
	struct tty_struct * (*lookup)(struct tty_driver___12 *, struct file___12 *, int);
	int (*install)(struct tty_driver___12 *, struct tty_struct *);
	void (*remove)(struct tty_driver___12 *, struct tty_struct *);
	int (*open)(struct tty_struct *, struct file___12 *);
	void (*close)(struct tty_struct *, struct file___12 *);
	void (*shutdown)(struct tty_struct *);
	void (*cleanup)(struct tty_struct *);
	int (*write)(struct tty_struct *, const unsigned char *, int);
	int (*put_char)(struct tty_struct *, unsigned char);
	void (*flush_chars)(struct tty_struct *);
	unsigned int (*write_room)(struct tty_struct *);
	unsigned int (*chars_in_buffer)(struct tty_struct *);
	int (*ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct *, struct ktermios *);
	void (*throttle)(struct tty_struct *);
	void (*unthrottle)(struct tty_struct *);
	void (*stop)(struct tty_struct *);
	void (*start)(struct tty_struct *);
	void (*hangup)(struct tty_struct *);
	int (*break_ctl)(struct tty_struct *, int);
	void (*flush_buffer)(struct tty_struct *);
	void (*set_ldisc)(struct tty_struct *);
	void (*wait_until_sent)(struct tty_struct *, int);
	void (*send_xchar)(struct tty_struct *, char);
	int (*tiocmget)(struct tty_struct *);
	int (*tiocmset)(struct tty_struct *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct *, struct winsize *);
	int (*get_icount)(struct tty_struct *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct *, struct serial_struct *);
	int (*set_serial)(struct tty_struct *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct *, struct seq_file___13 *);
	int (*poll_init)(struct tty_driver___12 *, int, char *);
	int (*poll_get_char)(struct tty_driver___12 *, int);
	void (*poll_put_char)(struct tty_driver___12 *, int, char);
	int (*proc_show)(struct seq_file___13 *, void *);
};

struct dentry___126;

struct super_block___126;

struct module___115;

struct file_system_type___126 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___126 * (*mount)(struct file_system_type___126 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___126 *);
	struct module___115 *owner;
	struct file_system_type___126 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___126;

struct kiocb___126;

struct iov_iter___71;

struct vm_area_struct___131;

struct inode___126;

struct file_lock___126;

struct page___131;

struct pipe_inode_info___41;

struct seq_file___111;

struct file_operations___126 {
	struct module___115 *owner;
	loff_t (*llseek)(struct file___126 *, loff_t, int);
	ssize_t (*read)(struct file___126 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___126 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___126 *, struct iov_iter___71 *);
	ssize_t (*write_iter)(struct kiocb___126 *, struct iov_iter___71 *);
	int (*iopoll)(struct kiocb___126 *, bool);
	int (*iterate)(struct file___126 *, struct dir_context *);
	int (*iterate_shared)(struct file___126 *, struct dir_context *);
	__poll_t (*poll)(struct file___126 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___126 *, struct vm_area_struct___131 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___126 *, struct file___126 *);
	int (*flush)(struct file___126 *, fl_owner_t);
	int (*release)(struct inode___126 *, struct file___126 *);
	int (*fsync)(struct file___126 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___126 *, int);
	int (*lock)(struct file___126 *, int, struct file_lock___126 *);
	ssize_t (*sendpage)(struct file___126 *, struct page___131 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___126 *, long unsigned int);
	int (*flock)(struct file___126 *, int, struct file_lock___126 *);
	ssize_t (*splice_write)(struct pipe_inode_info___41 *, struct file___126 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___126 *, loff_t *, struct pipe_inode_info___41 *, size_t, unsigned int);
	int (*setlease)(struct file___126 *, long int, struct file_lock___126 **, void **);
	long int (*fallocate)(struct file___126 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___111 *, struct file___126 *);
	ssize_t (*copy_file_range)(struct file___126 *, loff_t, struct file___126 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___126 *, loff_t, struct file___126 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___126 *, loff_t, loff_t, int);
};

struct vmacache___131 {
	u64 seqnum;
	struct vm_area_struct___131 *vmas[4];
};

struct page_frag___131 {
	struct page___131 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___132;

struct pid___111;

struct cred___19;

struct nsproxy___117;

struct signal_struct___127;

struct vm_struct___113;

struct task_struct___133 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___133 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___132 *mm;
	struct mm_struct___132 *active_mm;
	struct vmacache___131 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___133 *real_parent;
	struct task_struct___133 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___133 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___111 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___117 *nsproxy;
	struct signal_struct___127 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___133 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___41 *splice_pipe;
	struct page_frag___131 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___133 *oom_reaper_list;
	struct vm_struct___113 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___117;

struct kobj_type___117;

struct kernfs_node___117;

struct kobject___117 {
	const char *name;
	struct list_head entry;
	struct kobject___117 *parent;
	struct kset___117 *kset;
	struct kobj_type___117 *ktype;
	struct kernfs_node___117 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___114 {
	struct kobject___117 kobj;
	struct module___115 *mod;
	struct kobject___117 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___114 {
	struct module___115 *mod;
	struct latch_tree_node node;
};

struct module_layout___114 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___114 mtn;
};

struct module_attribute___114;

struct kernel_param___114;

struct module___115 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___114 mkobj;
	struct module_attribute___114 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___117 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___114 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___114 core_layout;
	struct module_layout___114 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___126;

struct dentry___126 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___126 *d_parent;
	struct qstr d_name;
	struct inode___126 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___126 *d_op;
	struct super_block___126 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___126;

struct address_space___126 {
	struct inode___126 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___126 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___126;

struct inode___126 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___126 *i_op;
	struct super_block___126 *i_sb;
	struct address_space___126 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___126 *i_fop;
		void (*free_inode)(struct inode___126 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___126 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___126;

struct path___126;

struct dentry_operations___126 {
	int (*d_revalidate)(struct dentry___126 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___126 *, unsigned int);
	int (*d_hash)(const struct dentry___126 *, struct qstr *);
	int (*d_compare)(const struct dentry___126 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___126 *);
	int (*d_init)(struct dentry___126 *);
	void (*d_release)(struct dentry___126 *);
	void (*d_prune)(struct dentry___126 *);
	void (*d_iput)(struct dentry___126 *, struct inode___126 *);
	char * (*d_dname)(struct dentry___126 *, char *, int);
	struct vfsmount___126 * (*d_automount)(struct path___126 *);
	int (*d_manage)(const struct path___126 *, bool);
	struct dentry___126 * (*d_real)(struct dentry___126 *, const struct inode___126 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___126;

struct mem_dqinfo___126 {
	struct quota_format_type___126 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___126;

struct quota_info___126 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___126 *files[3];
	struct mem_dqinfo___126 info[3];
	const struct quota_format_ops___126 *ops[3];
};

struct rcuwait___127 {
	struct task_struct___133 *task;
};

struct percpu_rw_semaphore___127 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___127 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___126 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___127 rw_sem[3];
};

struct super_operations___126;

struct dquot_operations___126;

struct quotactl_ops___126;

struct user_namespace___19;

struct super_block___126 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___126 *s_type;
	const struct super_operations___126 *s_op;
	const struct dquot_operations___126 *dq_op;
	const struct quotactl_ops___126 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___126 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___126 s_dquot;
	struct sb_writers___126 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___126 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___126 {
	struct dentry___126 *mnt_root;
	struct super_block___126 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___126 {
	struct vfsmount___126 *mnt;
	struct dentry___126 *dentry;
};

struct pid_namespace___111;

struct upid___111 {
	int nr;
	struct pid_namespace___111 *ns;
};

struct proc_ns_operations___22;

struct ns_common___22 {
	atomic_long_t stashed;
	const struct proc_ns_operations___22 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___19;

struct pid_namespace___111 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___133 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___111 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___111 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___111 numbers[1];
};

struct user_namespace___19 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___19 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___22 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___3 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___3 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___19 *ucounts;
	long int ucount_max[16];
};

typedef struct page___131 *pgtable_t___131;

struct page_pool___33;

struct dev_pagemap___124;

struct page___131 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___126 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___131 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___131 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___132 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___124 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___19 {
	struct hlist_node node;
	struct user_namespace___19 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___124;

struct vm_area_struct___131 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___131 *vm_next;
	struct vm_area_struct___131 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___132 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___124 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___126 *vm_file;
	struct file___126 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___127 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___133 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___133 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___111 *pids[4];
	struct pid___111 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___132 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___24;

struct core_state___131;

struct mm_struct___132 {
	struct {
		struct vm_area_struct___131 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___24 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___131 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___133 *owner;
		struct user_namespace___19 *user_ns;
		struct file___126 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___19 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct uts_namespace___7;

struct net___25;

struct nsproxy___117 {
	atomic_t count;
	struct uts_namespace___7 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___111 *pid_ns_for_children;
	struct net___25 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___126;

struct pipe_buffer___41;

struct pipe_inode_info___41 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___131 *tmp_page;
	struct fasync_struct___126 *fasync_readers;
	struct fasync_struct___126 *fasync_writers;
	struct pipe_buffer___41 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___113 {
	struct vm_struct___113 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___131 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct device___95;

struct page_pool_params___33 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___95 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___33 {
	u32 count;
	struct page___131 *cache[128];
};

struct page_pool___33 {
	struct page_pool_params___33 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___131 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___33 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___124;

struct dev_pagemap___124 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___124 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___111 {
	rwlock_t lock;
	struct pid___111 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___126 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___126 f_path;
	struct inode___126 *f_inode;
	const struct file_operations___126 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___111 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___126 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___124;

struct vm_operations_struct___124 {
	void (*open)(struct vm_area_struct___131 *);
	void (*close)(struct vm_area_struct___131 *);
	int (*may_split)(struct vm_area_struct___131 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___131 *);
	int (*mprotect)(struct vm_area_struct___131 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___124 *);
	vm_fault_t (*huge_fault)(struct vm_fault___124 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___124 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___131 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___124 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___124 *);
	int (*access)(struct vm_area_struct___131 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___131 *);
	int (*set_policy)(struct vm_area_struct___131 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___131 *, long unsigned int);
	struct page___131 * (*find_special_page)(struct vm_area_struct___131 *, long unsigned int);
};

struct core_thread___131 {
	struct task_struct___133 *task;
	struct core_thread___131 *next;
};

struct core_state___131 {
	atomic_t nr_threads;
	struct core_thread___131 dumper;
	struct completion startup;
};

struct linux_binprm___25;

struct coredump_params___24;

struct linux_binfmt___24 {
	struct list_head lh;
	struct module___115 *module;
	int (*load_binary)(struct linux_binprm___25 *);
	int (*load_shlib)(struct file___126 *);
	int (*core_dump)(struct coredump_params___24 *);
	long unsigned int min_coredump;
};

struct vm_fault___124 {
	const struct {
		struct vm_area_struct___131 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___131 *cow_page;
	struct page___131 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___131 prealloc_pte;
};

struct kiocb___126 {
	struct file___126 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___126 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___56 *ki_waitq;
	};
};

struct iattr___126 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___126 *ia_file;
};

struct dquot___126 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___126 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___126 {
	int qf_fmt_id;
	const struct quota_format_ops___126 *qf_ops;
	struct module___115 *qf_owner;
	struct quota_format_type___126 *qf_next;
};

struct quota_format_ops___126 {
	int (*check_quota_file)(struct super_block___126 *, int);
	int (*read_file_info)(struct super_block___126 *, int);
	int (*write_file_info)(struct super_block___126 *, int);
	int (*free_file_info)(struct super_block___126 *, int);
	int (*read_dqblk)(struct dquot___126 *);
	int (*commit_dqblk)(struct dquot___126 *);
	int (*release_dqblk)(struct dquot___126 *);
	int (*get_next_id)(struct super_block___126 *, struct kqid *);
};

struct dquot_operations___126 {
	int (*write_dquot)(struct dquot___126 *);
	struct dquot___126 * (*alloc_dquot)(struct super_block___126 *, int);
	void (*destroy_dquot)(struct dquot___126 *);
	int (*acquire_dquot)(struct dquot___126 *);
	int (*release_dquot)(struct dquot___126 *);
	int (*mark_dirty)(struct dquot___126 *);
	int (*write_info)(struct super_block___126 *, int);
	qsize_t * (*get_reserved_space)(struct inode___126 *);
	int (*get_projid)(struct inode___126 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___126 *, qsize_t *);
	int (*get_next_id)(struct super_block___126 *, struct kqid *);
};

struct quotactl_ops___126 {
	int (*quota_on)(struct super_block___126 *, int, int, const struct path___126 *);
	int (*quota_off)(struct super_block___126 *, int);
	int (*quota_enable)(struct super_block___126 *, unsigned int);
	int (*quota_disable)(struct super_block___126 *, unsigned int);
	int (*quota_sync)(struct super_block___126 *, int);
	int (*set_info)(struct super_block___126 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___126 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___126 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___126 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___126 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___126 *, unsigned int);
};

struct address_space_operations___126 {
	int (*writepage)(struct page___131 *, struct writeback_control___3 *);
	int (*readpage)(struct file___126 *, struct page___131 *);
	int (*writepages)(struct address_space___126 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___131 *);
	int (*readpages)(struct file___126 *, struct address_space___126 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___126 *, struct address_space___126 *, loff_t, unsigned int, unsigned int, struct page___131 **, void **);
	int (*write_end)(struct file___126 *, struct address_space___126 *, loff_t, unsigned int, unsigned int, struct page___131 *, void *);
	sector_t (*bmap)(struct address_space___126 *, sector_t);
	void (*invalidatepage)(struct page___131 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___131 *, gfp_t);
	void (*freepage)(struct page___131 *);
	ssize_t (*direct_IO)(struct kiocb___126 *, struct iov_iter___71 *);
	int (*migratepage)(struct address_space___126 *, struct page___131 *, struct page___131 *, enum migrate_mode);
	bool (*isolate_page)(struct page___131 *, isolate_mode_t);
	void (*putback_page)(struct page___131 *);
	int (*launder_page)(struct page___131 *);
	int (*is_partially_uptodate)(struct page___131 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___131 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___126 *, struct page___131 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___126 *, sector_t *);
	void (*swap_deactivate)(struct file___126 *);
};

struct bio_vec___69;

struct iov_iter___71 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___69 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___41 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___126 {
	struct dentry___126 * (*lookup)(struct inode___126 *, struct dentry___126 *, unsigned int);
	const char * (*get_link)(struct dentry___126 *, struct inode___126 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___126 *, int);
	struct posix_acl * (*get_acl)(struct inode___126 *, int, bool);
	int (*readlink)(struct dentry___126 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___126 *, struct dentry___126 *, umode_t, bool);
	int (*link)(struct dentry___126 *, struct inode___126 *, struct dentry___126 *);
	int (*unlink)(struct inode___126 *, struct dentry___126 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___126 *, struct dentry___126 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___126 *, struct dentry___126 *, umode_t);
	int (*rmdir)(struct inode___126 *, struct dentry___126 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___126 *, struct dentry___126 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___126 *, struct dentry___126 *, struct inode___126 *, struct dentry___126 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___126 *, struct iattr___126 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___126 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___126 *, char *, size_t);
	int (*fiemap)(struct inode___126 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___126 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___126 *, struct dentry___126 *, struct file___126 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___126 *, struct dentry___126 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___126 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___126 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___126 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___126 {
	void (*fl_copy_lock)(struct file_lock___126 *, struct file_lock___126 *);
	void (*fl_release_private)(struct file_lock___126 *);
};

struct lock_manager_operations___126;

struct file_lock___126 {
	struct file_lock___126 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___126 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___126 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___126 *fl_ops;
	const struct lock_manager_operations___126 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___126 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___126 *);
	int (*lm_grant)(struct file_lock___126 *, int);
	bool (*lm_break)(struct file_lock___126 *);
	int (*lm_change)(struct file_lock___126 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___126 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___126 *);
};

struct fasync_struct___126 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___126 *fa_next;
	struct file___126 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___126 {
	struct inode___126 * (*alloc_inode)(struct super_block___126 *);
	void (*destroy_inode)(struct inode___126 *);
	void (*free_inode)(struct inode___126 *);
	void (*dirty_inode)(struct inode___126 *, int);
	int (*write_inode)(struct inode___126 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___126 *);
	void (*evict_inode)(struct inode___126 *);
	void (*put_super)(struct super_block___126 *);
	int (*sync_fs)(struct super_block___126 *, int);
	int (*freeze_super)(struct super_block___126 *);
	int (*freeze_fs)(struct super_block___126 *);
	int (*thaw_super)(struct super_block___126 *);
	int (*unfreeze_fs)(struct super_block___126 *);
	int (*statfs)(struct dentry___126 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___126 *, int *, char *);
	void (*umount_begin)(struct super_block___126 *);
	int (*show_options)(struct seq_file___111 *, struct dentry___126 *);
	int (*show_devname)(struct seq_file___111 *, struct dentry___126 *);
	int (*show_path)(struct seq_file___111 *, struct dentry___126 *);
	int (*show_stats)(struct seq_file___111 *, struct dentry___126 *);
	ssize_t (*quota_read)(struct super_block___126 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___126 *, int, const char *, size_t, loff_t);
	struct dquot___126 ** (*get_dquots)(struct inode___126 *);
	long int (*nr_cached_objects)(struct super_block___126 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___126 *, struct shrink_control___49 *);
	struct file___126 * (*real_loop)(struct file___126 *);
};

struct seq_operations___111;

struct seq_file___111 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___111 *op;
	int poll_event;
	const struct file___126 *file;
	void *private;
};

struct proc_ops___15 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___126 *, struct file___126 *);
	ssize_t (*proc_read)(struct file___126 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___126 *, struct iov_iter___71 *);
	ssize_t (*proc_write)(struct file___126 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___126 *, loff_t, int);
	int (*proc_release)(struct inode___126 *, struct file___126 *);
	__poll_t (*proc_poll)(struct file___126 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___126 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___126 *, struct vm_area_struct___131 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___126 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

typedef int (*proc_write_t___8)(struct file___126 *, char *, size_t);

struct uts_namespace___7 {
	struct new_utsname name;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct ns_common___22 ns;
};

struct ipc_namespace {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___126 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___22 ns;
};

struct fqdir___24;

struct netns_ipv4___24 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___24 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___24 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___24 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___23 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___23 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___23 *);
	int (*local_out)(struct net___25 *, struct sock *, struct sk_buff___23 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___23 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___24 {
	struct dst_ops___24 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___24 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___24 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___24 *fqdir;
};

struct netns_xfrm___24 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___24 xfrm4_dst_ops;
	struct dst_ops___24 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___25 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct idr netns_ids;
	struct ns_common___22 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___24 ipv4;
	struct netns_ipv6___24 ipv6;
	struct netns_ieee802154_lowpan___24 ieee802154_lowpan;
	struct netns_sctp___14 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___21 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___21 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___24 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct nsset___21 {
	unsigned int flags;
	struct nsproxy___117 *nsproxy;
	struct fs_struct *fs;
	const struct cred___19 *cred;
};

struct dev_pagemap_ops___124 {
	void (*page_free)(struct page___131 *);
	void (*kill)(struct dev_pagemap___124 *);
	void (*cleanup)(struct dev_pagemap___124 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___124 *);
};

struct proc_ns_operations___22 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___22 * (*get)(struct task_struct___133 *);
	void (*put)(struct ns_common___22 *);
	int (*install)(struct nsset___21 *, struct ns_common___22 *);
	struct user_namespace___19 * (*owner)(struct ns_common___22 *);
	struct ns_common___22 * (*get_parent)(struct ns_common___22 *);
};

struct bio_vec___69 {
	struct page___131 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct proc_dir_entry {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___126 *proc_iops;
	union {
		const struct proc_ops___15 *proc_ops;
		const struct file_operations___126 *proc_dir_ops;
	};
	const struct dentry_operations___126 *proc_dops;
	union {
		const struct seq_operations___111 *seq_ops;
		int (*single_show)(struct seq_file___111 *, void *);
	};
	proc_write_t___8 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct inet_frags___24;

struct fqdir___24 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___24 *f;
	struct net___25 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___24;

struct inet_frags___24 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___24 *, const void *);
	void (*destructor)(struct inet_frag_queue___24 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___24 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___23 *fragments_tail;
	struct sk_buff___23 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___24 *fqdir;
	struct callback_head rcu;
};

enum netns_bpf_attach_type___2 {
	NETNS_BPF_INVALID___2 = 0,
	NETNS_BPF_FLOW_DISSECTOR___2 = 0,
	NETNS_BPF_SK_LOOKUP___2 = 1,
	MAX_NETNS_BPF_ATTACH_TYPE___2 = 2,
};

struct fwnode_operations___95;

struct fwnode_handle___95 {
	struct fwnode_handle___95 *secondary;
	const struct fwnode_operations___95 *ops;
	struct device___95 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___95;

struct fwnode_endpoint___95;

struct fwnode_operations___95 {
	struct fwnode_handle___95 * (*get)(struct fwnode_handle___95 *);
	void (*put)(struct fwnode_handle___95 *);
	bool (*device_is_available)(const struct fwnode_handle___95 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___95 *, const struct device___95 *);
	bool (*property_present)(const struct fwnode_handle___95 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___95 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___95 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___95 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*get_parent)(const struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*get_next_child_node)(const struct fwnode_handle___95 *, struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*get_named_child_node)(const struct fwnode_handle___95 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___95 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___95 *);
	struct fwnode_handle___95 * (*graph_get_next_endpoint)(const struct fwnode_handle___95 *, struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*graph_get_remote_endpoint)(const struct fwnode_handle___95 *);
	struct fwnode_handle___95 * (*graph_get_port_parent)(struct fwnode_handle___95 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___95 *, struct fwnode_endpoint___95 *);
	int (*add_links)(struct fwnode_handle___95 *);
};

struct wakeup_source___95;

struct dev_pm_info___95 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___95 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___95 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___95;

struct bus_type___95;

struct device_driver___95;

struct dev_pm_domain___95;

struct class___95;

struct attribute_group___117;

struct device___95 {
	struct kobject___117 kobj;
	struct device___95 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___95 *type;
	struct bus_type___95 *bus;
	struct device_driver___95 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___95 power;
	struct dev_pm_domain___95 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___95 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___95 *class;
	const struct attribute_group___117 **groups;
	void (*release)(struct device___95 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___95 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___95 *local_fwnode;
};

struct fwnode_reference_args___95 {
	struct fwnode_handle___95 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___117;

struct kernfs_elem_dir___117 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___117 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___117;

struct kernfs_root___117 {
	struct kernfs_node___117 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___117 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___117 {
	struct kernfs_node___117 *target_kn;
};

struct kernfs_ops___117;

struct kernfs_elem_attr___117 {
	const struct kernfs_ops___117 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___117 *notify_next;
};

struct kernfs_node___117 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___117 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___117 dir;
		struct kernfs_elem_symlink___117 symlink;
		struct kernfs_elem_attr___117 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___117;

struct kernfs_ops___117 {
	int (*open)(struct kernfs_open_file___117 *);
	void (*release)(struct kernfs_open_file___117 *);
	int (*seq_show)(struct seq_file___111 *, void *);
	void * (*seq_start)(struct seq_file___111 *, loff_t *);
	void * (*seq_next)(struct seq_file___111 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___111 *, void *);
	ssize_t (*read)(struct kernfs_open_file___117 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___117 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___117 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___117 *, struct vm_area_struct___131 *);
};

struct kernfs_syscall_ops___117 {
	int (*show_options)(struct seq_file___111 *, struct kernfs_root___117 *);
	int (*mkdir)(struct kernfs_node___117 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___117 *);
	int (*rename)(struct kernfs_node___117 *, struct kernfs_node___117 *, const char *);
	int (*show_path)(struct seq_file___111 *, struct kernfs_node___117 *, struct kernfs_root___117 *);
};

struct kernfs_open_file___117 {
	struct kernfs_node___117 *kn;
	struct file___126 *file;
	struct seq_file___111 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___124 *vm_ops;
};

struct bin_attribute___117;

struct attribute_group___117 {
	const char *name;
	umode_t (*is_visible)(struct kobject___117 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___117 *, struct bin_attribute___117 *, int);
	struct attribute **attrs;
	struct bin_attribute___117 **bin_attrs;
};

struct bin_attribute___117 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___126 * (*f_mapping)();
	ssize_t (*read)(struct file___126 *, struct kobject___117 *, struct bin_attribute___117 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___126 *, struct kobject___117 *, struct bin_attribute___117 *, char *, loff_t, size_t);
	int (*mmap)(struct file___126 *, struct kobject___117 *, struct bin_attribute___117 *, struct vm_area_struct___131 *);
};

struct sysfs_ops___117 {
	ssize_t (*show)(struct kobject___117 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___117 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___117;

struct kset___117 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___117 kobj;
	const struct kset_uevent_ops___117 *uevent_ops;
};

struct kobj_type___117 {
	void (*release)(struct kobject___117 *);
	const struct sysfs_ops___117 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___117 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___117 *);
	const void * (*namespace)(struct kobject___117 *);
	void (*get_ownership)(struct kobject___117 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___117 {
	int (* const filter)(struct kset___117 *, struct kobject___117 *);
	const char * (* const name)(struct kset___117 *, struct kobject___117 *);
	int (* const uevent)(struct kset___117 *, struct kobject___117 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___114 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___114 *);
	int (*get)(char *, const struct kernel_param___114 *);
	void (*free)(void *);
};

struct kparam_array___114;

struct kernel_param___114 {
	const char *name;
	struct module___115 *mod;
	const struct kernel_param_ops___114 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___114 *arr;
	};
};

struct kparam_array___114 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___114 *ops;
	void *elem;
};

struct module_attribute___114 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___114 *, struct module_kobject___114 *, char *);
	ssize_t (*store)(struct module_attribute___114 *, struct module_kobject___114 *, const char *, size_t);
	void (*setup)(struct module___115 *, const char *);
	int (*test)(struct module___115 *);
	void (*free)(struct module___115 *);
};

struct dev_pm_ops___95 {
	int (*prepare)(struct device___95 *);
	void (*complete)(struct device___95 *);
	int (*suspend)(struct device___95 *);
	int (*resume)(struct device___95 *);
	int (*freeze)(struct device___95 *);
	int (*thaw)(struct device___95 *);
	int (*poweroff)(struct device___95 *);
	int (*restore)(struct device___95 *);
	int (*suspend_late)(struct device___95 *);
	int (*resume_early)(struct device___95 *);
	int (*freeze_late)(struct device___95 *);
	int (*thaw_early)(struct device___95 *);
	int (*poweroff_late)(struct device___95 *);
	int (*restore_early)(struct device___95 *);
	int (*suspend_noirq)(struct device___95 *);
	int (*resume_noirq)(struct device___95 *);
	int (*freeze_noirq)(struct device___95 *);
	int (*thaw_noirq)(struct device___95 *);
	int (*poweroff_noirq)(struct device___95 *);
	int (*restore_noirq)(struct device___95 *);
	int (*runtime_suspend)(struct device___95 *);
	int (*runtime_resume)(struct device___95 *);
	int (*runtime_idle)(struct device___95 *);
};

struct wakeup_source___95 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___95 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___95 {
	struct dev_pm_ops___95 ops;
	int (*start)(struct device___95 *);
	void (*detach)(struct device___95 *, bool);
	int (*activate)(struct device___95 *);
	void (*sync)(struct device___95 *);
	void (*dismiss)(struct device___95 *);
};

struct bus_type___95 {
	const char *name;
	const char *dev_name;
	struct device___95 *dev_root;
	const struct attribute_group___117 **bus_groups;
	const struct attribute_group___117 **dev_groups;
	const struct attribute_group___117 **drv_groups;
	int (*match)(struct device___95 *, struct device_driver___95 *);
	int (*uevent)(struct device___95 *, struct kobj_uevent_env *);
	int (*probe)(struct device___95 *);
	void (*sync_state)(struct device___95 *);
	void (*remove)(struct device___95 *);
	void (*shutdown)(struct device___95 *);
	int (*online)(struct device___95 *);
	int (*offline)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	int (*num_vf)(struct device___95 *);
	int (*dma_configure)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___95 {
	const char *name;
	struct bus_type___95 *bus;
	struct module___115 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___95 *);
	void (*sync_state)(struct device___95 *);
	int (*remove)(struct device___95 *);
	void (*shutdown)(struct device___95 *);
	int (*suspend)(struct device___95 *, pm_message_t);
	int (*resume)(struct device___95 *);
	const struct attribute_group___117 **groups;
	const struct attribute_group___117 **dev_groups;
	const struct dev_pm_ops___95 *pm;
	void (*coredump)(struct device___95 *);
	struct driver_private *p;
};

struct device_type___95 {
	const char *name;
	const struct attribute_group___117 **groups;
	int (*uevent)(struct device___95 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___95 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___95 *);
	const struct dev_pm_ops___95 *pm;
};

struct class___95 {
	const char *name;
	struct module___115 *owner;
	const struct attribute_group___117 **class_groups;
	const struct attribute_group___117 **dev_groups;
	struct kobject___117 *dev_kobj;
	int (*dev_uevent)(struct device___95 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___95 *, umode_t *);
	void (*class_release)(struct class___95 *);
	void (*dev_release)(struct device___95 *);
	int (*shutdown_pre)(struct device___95 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___95 *);
	void (*get_ownership)(struct device___95 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___95 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___41;

struct pipe_buffer___41 {
	struct page___131 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___41 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___41 {
	int (*confirm)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
	void (*release)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
	bool (*try_steal)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
	bool (*get)(struct pipe_inode_info___41 *, struct pipe_buffer___41 *);
};

struct seq_operations___111 {
	void * (*start)(struct seq_file___111 *, loff_t *);
	void (*stop)(struct seq_file___111 *, void *);
	void * (*next)(struct seq_file___111 *, void *, loff_t *);
	int (*show)(struct seq_file___111 *, void *);
};

struct linux_binprm___25 {
	struct vm_area_struct___131 *vma;
	long unsigned int vma_pages;
	struct mm_struct___132 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___126 *executable;
	struct file___126 *interpreter;
	struct file___126 *file;
	struct cred___19 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___24 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___126 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

union proc_op___7 {
	int (*proc_get_link)(struct dentry___126 *, struct path___126 *);
	int (*proc_show)(struct seq_file___111 *, struct pid_namespace___111 *, struct pid___111 *, struct task_struct___133 *);
	const char *lsm;
};

struct proc_inode___7 {
	struct pid___111 *pid;
	unsigned int fd;
	union proc_op___7 op;
	struct proc_dir_entry *pde;
	struct ctl_table_header *sysctl;
	struct ctl_table *sysctl_entry;
	struct hlist_node sibling_inodes;
	const struct proc_ns_operations___22 *ns_ops;
	struct inode___126 vfs_inode;
};

typedef struct dentry___126 *instantiate_t___3(struct dentry___126 *, struct task_struct___133 *, const void *);

typedef struct poll_table_struct___83 poll_table___23;

struct sysctl_alias {
	const char *kernel_param;
	const char *sysctl_param;
};

struct seq_net_private {
	struct net___25 *net;
};

struct pernet_operations___2 {
	struct list_head list;
	int (*init)(struct net___25 *);
	void (*pre_exit)(struct net___25 *);
	void (*exit)(struct net___25 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct bpf_iter_aux_info___23;

struct dentry___127;

struct super_block___127;

struct module___116;

struct file_system_type___127 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___127 * (*mount)(struct file_system_type___127 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___127 *);
	struct module___116 *owner;
	struct file_system_type___127 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___127;

struct kiocb___127;

struct vm_area_struct___132;

struct inode___127;

struct file_lock___127;

struct page___132;

struct file_operations___127 {
	struct module___116 *owner;
	loff_t (*llseek)(struct file___127 *, loff_t, int);
	ssize_t (*read)(struct file___127 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___127 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___127 *, struct iov_iter___71 *);
	ssize_t (*write_iter)(struct kiocb___127 *, struct iov_iter___71 *);
	int (*iopoll)(struct kiocb___127 *, bool);
	int (*iterate)(struct file___127 *, struct dir_context *);
	int (*iterate_shared)(struct file___127 *, struct dir_context *);
	__poll_t (*poll)(struct file___127 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___127 *, struct vm_area_struct___132 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___127 *, struct file___127 *);
	int (*flush)(struct file___127 *, fl_owner_t);
	int (*release)(struct inode___127 *, struct file___127 *);
	int (*fsync)(struct file___127 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___127 *, int);
	int (*lock)(struct file___127 *, int, struct file_lock___127 *);
	ssize_t (*sendpage)(struct file___127 *, struct page___132 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___127 *, long unsigned int);
	int (*flock)(struct file___127 *, int, struct file_lock___127 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___127 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___127 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___127 *, long int, struct file_lock___127 **, void **);
	long int (*fallocate)(struct file___127 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___127 *);
	ssize_t (*copy_file_range)(struct file___127 *, loff_t, struct file___127 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___127 *, loff_t, struct file___127 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___127 *, loff_t, loff_t, int);
};

struct vmacache___132 {
	u64 seqnum;
	struct vm_area_struct___132 *vmas[4];
};

struct page_frag___132 {
	struct page___132 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___133;

struct pid___112;

struct nsproxy___118;

struct signal_struct___128;

struct vm_struct___114;

struct task_struct___134 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___134 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___133 *mm;
	struct mm_struct___133 *active_mm;
	struct vmacache___132 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___134 *real_parent;
	struct task_struct___134 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___134 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___112 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___118 *nsproxy;
	struct signal_struct___128 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___134 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___132 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___134 *oom_reaper_list;
	struct vm_struct___114 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___118;

struct kobj_type___118;

struct kernfs_node___118;

struct kobject___118 {
	const char *name;
	struct list_head entry;
	struct kobject___118 *parent;
	struct kset___118 *kset;
	struct kobj_type___118 *ktype;
	struct kernfs_node___118 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___115 {
	struct kobject___118 kobj;
	struct module___116 *mod;
	struct kobject___118 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___115 {
	struct module___116 *mod;
	struct latch_tree_node node;
};

struct module_layout___115 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___115 mtn;
};

struct module_attribute___115;

struct kernel_param___115;

struct module___116 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___115 mkobj;
	struct module_attribute___115 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___118 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___115 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___115 core_layout;
	struct module_layout___115 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___112;

struct upid___112 {
	int nr;
	struct pid_namespace___112 *ns;
};

struct proc_ns_operations___23;

struct ns_common___23 {
	atomic_long_t stashed;
	const struct proc_ns_operations___23 *ops;
	unsigned int inum;
	refcount_t count;
};

struct pid_namespace___112 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___134 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___112 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___23 ns;
};

struct pid___112 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___112 numbers[1];
};

typedef struct page___132 *pgtable_t___132;

struct address_space___127;

struct dev_pagemap___125;

struct page___132 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___127 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___132 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___132 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___133 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___125 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___125;

struct vm_area_struct___132 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___132 *vm_next;
	struct vm_area_struct___132 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___133 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___125 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___127 *vm_file;
	struct file___127 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___128 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___134 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___134 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___112 *pids[4];
	struct pid___112 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___133 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___25;

struct core_state___132;

struct mm_struct___133 {
	struct {
		struct vm_area_struct___132 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___25 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___132 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___134 *owner;
		struct user_namespace *user_ns;
		struct file___127 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___118 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___112 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___114 {
	struct vm_struct___114 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___132 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___127;

struct address_space___127 {
	struct inode___127 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___127 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___125;

struct dev_pagemap___125 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___125 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___127;

struct path___127 {
	struct vfsmount___127 *mnt;
	struct dentry___127 *dentry;
};

struct fown_struct___112 {
	rwlock_t lock;
	struct pid___112 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___127 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___127 f_path;
	struct inode___127 *f_inode;
	const struct file_operations___127 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___112 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___127 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___125;

struct vm_operations_struct___125 {
	void (*open)(struct vm_area_struct___132 *);
	void (*close)(struct vm_area_struct___132 *);
	int (*may_split)(struct vm_area_struct___132 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___132 *);
	int (*mprotect)(struct vm_area_struct___132 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___125 *);
	vm_fault_t (*huge_fault)(struct vm_fault___125 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___125 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___132 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___125 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___125 *);
	int (*access)(struct vm_area_struct___132 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___132 *);
	int (*set_policy)(struct vm_area_struct___132 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___132 *, long unsigned int);
	struct page___132 * (*find_special_page)(struct vm_area_struct___132 *, long unsigned int);
};

struct core_thread___132 {
	struct task_struct___134 *task;
	struct core_thread___132 *next;
};

struct core_state___132 {
	atomic_t nr_threads;
	struct core_thread___132 dumper;
	struct completion startup;
};

struct linux_binprm___26;

struct coredump_params___25;

struct linux_binfmt___25 {
	struct list_head lh;
	struct module___116 *module;
	int (*load_binary)(struct linux_binprm___26 *);
	int (*load_shlib)(struct file___127 *);
	int (*core_dump)(struct coredump_params___25 *);
	long unsigned int min_coredump;
};

struct vm_fault___125 {
	const struct {
		struct vm_area_struct___132 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___132 *cow_page;
	struct page___132 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___132 prealloc_pte;
};

struct pglist_data___56;

struct lruvec___56 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___56 *pgdat;
};

struct zone___56 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___56 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___56 {
	struct zone___56 *zone;
	int zone_idx;
};

struct zonelist___56 {
	struct zoneref___56 _zonerefs[321];
};

struct pglist_data___56 {
	struct zone___56 node_zones[5];
	struct zonelist___56 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___134 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___134 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___56 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___56 pg_data_t___12;

struct dev_pagemap_ops___125 {
	void (*page_free)(struct page___132 *);
	void (*kill)(struct dev_pagemap___125 *);
	void (*cleanup)(struct dev_pagemap___125 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___125 *);
};

struct dentry_operations___127;

struct dentry___127 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___127 *d_parent;
	struct qstr d_name;
	struct inode___127 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___127 *d_op;
	struct super_block___127 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___127;

struct inode___127 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___127 *i_op;
	struct super_block___127 *i_sb;
	struct address_space___127 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___127 *i_fop;
		void (*free_inode)(struct inode___127 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___127 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___127 {
	int (*d_revalidate)(struct dentry___127 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___127 *, unsigned int);
	int (*d_hash)(const struct dentry___127 *, struct qstr *);
	int (*d_compare)(const struct dentry___127 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___127 *);
	int (*d_init)(struct dentry___127 *);
	void (*d_release)(struct dentry___127 *);
	void (*d_prune)(struct dentry___127 *);
	void (*d_iput)(struct dentry___127 *, struct inode___127 *);
	char * (*d_dname)(struct dentry___127 *, char *, int);
	struct vfsmount___127 * (*d_automount)(struct path___127 *);
	int (*d_manage)(const struct path___127 *, bool);
	struct dentry___127 * (*d_real)(struct dentry___127 *, const struct inode___127 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___127;

struct mem_dqinfo___127 {
	struct quota_format_type___127 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___127;

struct quota_info___127 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___127 *files[3];
	struct mem_dqinfo___127 info[3];
	const struct quota_format_ops___127 *ops[3];
};

struct rcuwait___128 {
	struct task_struct___134 *task;
};

struct percpu_rw_semaphore___128 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___128 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___127 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___128 rw_sem[3];
};

struct super_operations___127;

struct dquot_operations___127;

struct quotactl_ops___127;

struct super_block___127 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___127 *s_type;
	const struct super_operations___127 *s_op;
	const struct dquot_operations___127 *dq_op;
	const struct quotactl_ops___127 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___127 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___127 s_dquot;
	struct sb_writers___127 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___127 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___127 {
	struct dentry___127 *mnt_root;
	struct super_block___127 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___127 {
	struct file___127 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___127 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___56 *ki_waitq;
	};
};

struct iattr___127 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___127 *ia_file;
};

struct dquot___127 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___127 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___127 {
	int qf_fmt_id;
	const struct quota_format_ops___127 *qf_ops;
	struct module___116 *qf_owner;
	struct quota_format_type___127 *qf_next;
};

struct quota_format_ops___127 {
	int (*check_quota_file)(struct super_block___127 *, int);
	int (*read_file_info)(struct super_block___127 *, int);
	int (*write_file_info)(struct super_block___127 *, int);
	int (*free_file_info)(struct super_block___127 *, int);
	int (*read_dqblk)(struct dquot___127 *);
	int (*commit_dqblk)(struct dquot___127 *);
	int (*release_dqblk)(struct dquot___127 *);
	int (*get_next_id)(struct super_block___127 *, struct kqid *);
};

struct dquot_operations___127 {
	int (*write_dquot)(struct dquot___127 *);
	struct dquot___127 * (*alloc_dquot)(struct super_block___127 *, int);
	void (*destroy_dquot)(struct dquot___127 *);
	int (*acquire_dquot)(struct dquot___127 *);
	int (*release_dquot)(struct dquot___127 *);
	int (*mark_dirty)(struct dquot___127 *);
	int (*write_info)(struct super_block___127 *, int);
	qsize_t * (*get_reserved_space)(struct inode___127 *);
	int (*get_projid)(struct inode___127 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___127 *, qsize_t *);
	int (*get_next_id)(struct super_block___127 *, struct kqid *);
};

struct quotactl_ops___127 {
	int (*quota_on)(struct super_block___127 *, int, int, const struct path___127 *);
	int (*quota_off)(struct super_block___127 *, int);
	int (*quota_enable)(struct super_block___127 *, unsigned int);
	int (*quota_disable)(struct super_block___127 *, unsigned int);
	int (*quota_sync)(struct super_block___127 *, int);
	int (*set_info)(struct super_block___127 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___127 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___127 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___127 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___127 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___127 *, unsigned int);
};

struct address_space_operations___127 {
	int (*writepage)(struct page___132 *, struct writeback_control___3 *);
	int (*readpage)(struct file___127 *, struct page___132 *);
	int (*writepages)(struct address_space___127 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___132 *);
	int (*readpages)(struct file___127 *, struct address_space___127 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___127 *, struct address_space___127 *, loff_t, unsigned int, unsigned int, struct page___132 **, void **);
	int (*write_end)(struct file___127 *, struct address_space___127 *, loff_t, unsigned int, unsigned int, struct page___132 *, void *);
	sector_t (*bmap)(struct address_space___127 *, sector_t);
	void (*invalidatepage)(struct page___132 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___132 *, gfp_t);
	void (*freepage)(struct page___132 *);
	ssize_t (*direct_IO)(struct kiocb___127 *, struct iov_iter___71 *);
	int (*migratepage)(struct address_space___127 *, struct page___132 *, struct page___132 *, enum migrate_mode);
	bool (*isolate_page)(struct page___132 *, isolate_mode_t);
	void (*putback_page)(struct page___132 *);
	int (*launder_page)(struct page___132 *);
	int (*is_partially_uptodate)(struct page___132 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___132 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___127 *, struct page___132 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___127 *, sector_t *);
	void (*swap_deactivate)(struct file___127 *);
};

struct inode_operations___127 {
	struct dentry___127 * (*lookup)(struct inode___127 *, struct dentry___127 *, unsigned int);
	const char * (*get_link)(struct dentry___127 *, struct inode___127 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___127 *, int);
	struct posix_acl * (*get_acl)(struct inode___127 *, int, bool);
	int (*readlink)(struct dentry___127 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___127 *, struct dentry___127 *, umode_t, bool);
	int (*link)(struct dentry___127 *, struct inode___127 *, struct dentry___127 *);
	int (*unlink)(struct inode___127 *, struct dentry___127 *);
	int (*symlink)(struct user_namespace *, struct inode___127 *, struct dentry___127 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___127 *, struct dentry___127 *, umode_t);
	int (*rmdir)(struct inode___127 *, struct dentry___127 *);
	int (*mknod)(struct user_namespace *, struct inode___127 *, struct dentry___127 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___127 *, struct dentry___127 *, struct inode___127 *, struct dentry___127 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___127 *, struct iattr___127 *);
	int (*getattr)(struct user_namespace *, const struct path___127 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___127 *, char *, size_t);
	int (*fiemap)(struct inode___127 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___127 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___127 *, struct dentry___127 *, struct file___127 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___127 *, struct dentry___127 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___127 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___127 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___127 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___127 {
	void (*fl_copy_lock)(struct file_lock___127 *, struct file_lock___127 *);
	void (*fl_release_private)(struct file_lock___127 *);
};

struct fasync_struct___127;

struct lock_manager_operations___127;

struct file_lock___127 {
	struct file_lock___127 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___127 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___127 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___127 *fl_ops;
	const struct lock_manager_operations___127 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___127 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___127 *);
	int (*lm_grant)(struct file_lock___127 *, int);
	bool (*lm_break)(struct file_lock___127 *);
	int (*lm_change)(struct file_lock___127 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___127 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___127 *);
};

struct fasync_struct___127 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___127 *fa_next;
	struct file___127 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___127 {
	struct inode___127 * (*alloc_inode)(struct super_block___127 *);
	void (*destroy_inode)(struct inode___127 *);
	void (*free_inode)(struct inode___127 *);
	void (*dirty_inode)(struct inode___127 *, int);
	int (*write_inode)(struct inode___127 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___127 *);
	void (*evict_inode)(struct inode___127 *);
	void (*put_super)(struct super_block___127 *);
	int (*sync_fs)(struct super_block___127 *, int);
	int (*freeze_super)(struct super_block___127 *);
	int (*freeze_fs)(struct super_block___127 *);
	int (*thaw_super)(struct super_block___127 *);
	int (*unfreeze_fs)(struct super_block___127 *);
	int (*statfs)(struct dentry___127 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___127 *, int *, char *);
	void (*umount_begin)(struct super_block___127 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___127 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___127 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___127 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___127 *);
	ssize_t (*quota_read)(struct super_block___127 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___127 *, int, const char *, size_t, loff_t);
	struct dquot___127 ** (*get_dquots)(struct inode___127 *);
	long int (*nr_cached_objects)(struct super_block___127 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___127 *, struct shrink_control___49 *);
	struct file___127 * (*real_loop)(struct file___127 *);
};

struct nsset___22 {
	unsigned int flags;
	struct nsproxy___118 *nsproxy;
	struct fs_struct *fs;
	const struct cred___19 *cred;
};

struct proc_ns_operations___23 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___23 * (*get)(struct task_struct___134 *);
	void (*put)(struct ns_common___23 *);
	int (*install)(struct nsset___22 *, struct ns_common___23 *);
	struct user_namespace * (*owner)(struct ns_common___23 *);
	struct ns_common___23 * (*get_parent)(struct ns_common___23 *);
};

struct proc_ops___16 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___127 *, struct file___127 *);
	ssize_t (*proc_read)(struct file___127 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___127 *, struct iov_iter___71 *);
	ssize_t (*proc_write)(struct file___127 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___127 *, loff_t, int);
	int (*proc_release)(struct inode___127 *, struct file___127 *);
	__poll_t (*proc_poll)(struct file___127 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___127 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___127 *, struct vm_area_struct___132 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___127 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

typedef int (*proc_write_t___9)(struct file___127 *, char *, size_t);

enum kcore_type {
	KCORE_TEXT = 0,
	KCORE_VMALLOC = 1,
	KCORE_RAM = 2,
	KCORE_VMEMMAP = 3,
	KCORE_USER = 4,
};

struct kcore_list {
	struct list_head list;
	long unsigned int addr;
	size_t size;
	int type;
};

struct kernfs_root___118;

struct kernfs_elem_dir___118 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___118 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___118;

struct kernfs_root___118 {
	struct kernfs_node___118 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___118 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___118 {
	struct kernfs_node___118 *target_kn;
};

struct kernfs_ops___118;

struct kernfs_elem_attr___118 {
	const struct kernfs_ops___118 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___118 *notify_next;
};

struct kernfs_node___118 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___118 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___118 dir;
		struct kernfs_elem_symlink___118 symlink;
		struct kernfs_elem_attr___118 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___118;

struct kernfs_ops___118 {
	int (*open)(struct kernfs_open_file___118 *);
	void (*release)(struct kernfs_open_file___118 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___118 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___118 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___118 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___118 *, struct vm_area_struct___132 *);
};

struct kernfs_syscall_ops___118 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___118 *);
	int (*mkdir)(struct kernfs_node___118 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___118 *);
	int (*rename)(struct kernfs_node___118 *, struct kernfs_node___118 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___118 *, struct kernfs_root___118 *);
};

struct kernfs_open_file___118 {
	struct kernfs_node___118 *kn;
	struct file___127 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___125 *vm_ops;
};

struct bin_attribute___118;

struct attribute_group___118 {
	const char *name;
	umode_t (*is_visible)(struct kobject___118 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___118 *, struct bin_attribute___118 *, int);
	struct attribute **attrs;
	struct bin_attribute___118 **bin_attrs;
};

struct bin_attribute___118 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___127 * (*f_mapping)();
	ssize_t (*read)(struct file___127 *, struct kobject___118 *, struct bin_attribute___118 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___127 *, struct kobject___118 *, struct bin_attribute___118 *, char *, loff_t, size_t);
	int (*mmap)(struct file___127 *, struct kobject___118 *, struct bin_attribute___118 *, struct vm_area_struct___132 *);
};

struct sysfs_ops___118 {
	ssize_t (*show)(struct kobject___118 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___118 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___118;

struct kset___118 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___118 kobj;
	const struct kset_uevent_ops___118 *uevent_ops;
};

struct kobj_type___118 {
	void (*release)(struct kobject___118 *);
	const struct sysfs_ops___118 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___118 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___118 *);
	const void * (*namespace)(struct kobject___118 *);
	void (*get_ownership)(struct kobject___118 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___118 {
	int (* const filter)(struct kset___118 *, struct kobject___118 *);
	const char * (* const name)(struct kset___118 *, struct kobject___118 *);
	int (* const uevent)(struct kset___118 *, struct kobject___118 *, struct kobj_uevent_env *);
};

struct proc_dir_entry___9 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___127 *proc_iops;
	union {
		const struct proc_ops___16 *proc_ops;
		const struct file_operations___127 *proc_dir_ops;
	};
	const struct dentry_operations___127 *proc_dops;
	union {
		const struct seq_operations___111 *seq_ops;
		int (*single_show)(struct seq_file___111 *, void *);
	};
	proc_write_t___9 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___9 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct kernel_param_ops___115 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___115 *);
	int (*get)(char *, const struct kernel_param___115 *);
	void (*free)(void *);
};

struct kparam_array___115;

struct kernel_param___115 {
	const char *name;
	struct module___116 *mod;
	const struct kernel_param_ops___115 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___115 *arr;
	};
};

struct kparam_array___115 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___115 *ops;
	void *elem;
};

struct module_attribute___115 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___115 *, struct module_kobject___115 *, char *);
	ssize_t (*store)(struct module_attribute___115 *, struct module_kobject___115 *, const char *, size_t);
	void (*setup)(struct module___116 *, const char *);
	int (*test)(struct module___116 *);
	void (*free)(struct module___116 *);
};

struct linux_binprm___26 {
	struct vm_area_struct___132 *vma;
	long unsigned int vma_pages;
	struct mm_struct___133 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___127 *executable;
	struct file___127 *interpreter;
	struct file___127 *file;
	struct cred___19 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___25 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___127 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dentry___128;

struct super_block___128;

struct module___117;

struct file_system_type___128 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___128 * (*mount)(struct file_system_type___128 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___128 *);
	struct module___117 *owner;
	struct file_system_type___128 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___128;

struct kiocb___128;

struct vm_area_struct___133;

struct inode___128;

struct file_lock___128;

struct page___133;

struct file_operations___128 {
	struct module___117 *owner;
	loff_t (*llseek)(struct file___128 *, loff_t, int);
	ssize_t (*read)(struct file___128 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___128 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___128 *, struct iov_iter___71 *);
	ssize_t (*write_iter)(struct kiocb___128 *, struct iov_iter___71 *);
	int (*iopoll)(struct kiocb___128 *, bool);
	int (*iterate)(struct file___128 *, struct dir_context *);
	int (*iterate_shared)(struct file___128 *, struct dir_context *);
	__poll_t (*poll)(struct file___128 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___128 *, struct vm_area_struct___133 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___128 *, struct file___128 *);
	int (*flush)(struct file___128 *, fl_owner_t);
	int (*release)(struct inode___128 *, struct file___128 *);
	int (*fsync)(struct file___128 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___128 *, int);
	int (*lock)(struct file___128 *, int, struct file_lock___128 *);
	ssize_t (*sendpage)(struct file___128 *, struct page___133 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___128 *, long unsigned int);
	int (*flock)(struct file___128 *, int, struct file_lock___128 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___128 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___128 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___128 *, long int, struct file_lock___128 **, void **);
	long int (*fallocate)(struct file___128 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___128 *);
	ssize_t (*copy_file_range)(struct file___128 *, loff_t, struct file___128 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___128 *, loff_t, struct file___128 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___128 *, loff_t, loff_t, int);
};

struct vmacache___133 {
	u64 seqnum;
	struct vm_area_struct___133 *vmas[4];
};

struct page_frag___133 {
	struct page___133 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___134;

struct pid___113;

struct nsproxy___119;

struct signal_struct___129;

struct vm_struct___115;

struct task_struct___135 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___135 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___134 *mm;
	struct mm_struct___134 *active_mm;
	struct vmacache___133 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___135 *real_parent;
	struct task_struct___135 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___135 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___113 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___119 *nsproxy;
	struct signal_struct___129 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___135 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___133 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___135 *oom_reaper_list;
	struct vm_struct___115 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___119;

struct kobj_type___119;

struct kernfs_node___119;

struct kobject___119 {
	const char *name;
	struct list_head entry;
	struct kobject___119 *parent;
	struct kset___119 *kset;
	struct kobj_type___119 *ktype;
	struct kernfs_node___119 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___116 {
	struct kobject___119 kobj;
	struct module___117 *mod;
	struct kobject___119 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___116 {
	struct module___117 *mod;
	struct latch_tree_node node;
};

struct module_layout___116 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___116 mtn;
};

struct module_attribute___116;

struct kernel_param___116;

struct module___117 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___116 mkobj;
	struct module_attribute___116 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___119 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___116 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___116 core_layout;
	struct module_layout___116 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___133 *pgtable_t___133;

struct address_space___128;

struct dev_pagemap___126;

struct page___133 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___128 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___133 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___133 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___134 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___126 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___126;

struct vm_area_struct___133 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___133 *vm_next;
	struct vm_area_struct___133 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___134 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___126 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___128 *vm_file;
	struct file___128 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___26;

struct core_state___133;

struct mm_struct___134 {
	struct {
		struct vm_area_struct___133 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___26 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___133 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___135 *owner;
		struct user_namespace *user_ns;
		struct file___128 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___128;

struct address_space___128 {
	struct inode___128 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___128 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___126;

struct dev_pagemap___126 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___126 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___128;

struct path___128 {
	struct vfsmount___128 *mnt;
	struct dentry___128 *dentry;
};

struct fown_struct___113 {
	rwlock_t lock;
	struct pid___113 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___128 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___128 f_path;
	struct inode___128 *f_inode;
	const struct file_operations___128 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___113 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___128 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___126;

struct vm_operations_struct___126 {
	void (*open)(struct vm_area_struct___133 *);
	void (*close)(struct vm_area_struct___133 *);
	int (*may_split)(struct vm_area_struct___133 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___133 *);
	int (*mprotect)(struct vm_area_struct___133 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___126 *);
	vm_fault_t (*huge_fault)(struct vm_fault___126 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___126 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___133 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___126 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___126 *);
	int (*access)(struct vm_area_struct___133 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___133 *);
	int (*set_policy)(struct vm_area_struct___133 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___133 *, long unsigned int);
	struct page___133 * (*find_special_page)(struct vm_area_struct___133 *, long unsigned int);
};

struct core_thread___133 {
	struct task_struct___135 *task;
	struct core_thread___133 *next;
};

struct core_state___133 {
	atomic_t nr_threads;
	struct core_thread___133 dumper;
	struct completion startup;
};

struct linux_binprm___27;

struct coredump_params___26;

struct linux_binfmt___26 {
	struct list_head lh;
	struct module___117 *module;
	int (*load_binary)(struct linux_binprm___27 *);
	int (*load_shlib)(struct file___128 *);
	int (*core_dump)(struct coredump_params___26 *);
	long unsigned int min_coredump;
};

struct vm_fault___126 {
	const struct {
		struct vm_area_struct___133 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___133 *cow_page;
	struct page___133 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___133 prealloc_pte;
};

struct dev_pagemap_ops___126 {
	void (*page_free)(struct page___133 *);
	void (*kill)(struct dev_pagemap___126 *);
	void (*cleanup)(struct dev_pagemap___126 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___126 *);
};

struct pid_namespace___113;

struct upid___113 {
	int nr;
	struct pid_namespace___113 *ns;
};

struct proc_ns_operations___24;

struct ns_common___24 {
	atomic_long_t stashed;
	const struct proc_ns_operations___24 *ops;
	unsigned int inum;
	refcount_t count;
};

struct pid_namespace___113 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___135 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___113 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___24 ns;
};

struct pid___113 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___113 numbers[1];
};

struct signal_struct___129 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___135 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___135 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___113 *pids[4];
	struct pid___113 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___134 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___119 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___113 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___115 {
	struct vm_struct___115 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___133 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___128;

struct dentry___128 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___128 *d_parent;
	struct qstr d_name;
	struct inode___128 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___128 *d_op;
	struct super_block___128 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___128;

struct inode___128 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___128 *i_op;
	struct super_block___128 *i_sb;
	struct address_space___128 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___128 *i_fop;
		void (*free_inode)(struct inode___128 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___128 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___128 {
	int (*d_revalidate)(struct dentry___128 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___128 *, unsigned int);
	int (*d_hash)(const struct dentry___128 *, struct qstr *);
	int (*d_compare)(const struct dentry___128 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___128 *);
	int (*d_init)(struct dentry___128 *);
	void (*d_release)(struct dentry___128 *);
	void (*d_prune)(struct dentry___128 *);
	void (*d_iput)(struct dentry___128 *, struct inode___128 *);
	char * (*d_dname)(struct dentry___128 *, char *, int);
	struct vfsmount___128 * (*d_automount)(struct path___128 *);
	int (*d_manage)(const struct path___128 *, bool);
	struct dentry___128 * (*d_real)(struct dentry___128 *, const struct inode___128 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___128;

struct mem_dqinfo___128 {
	struct quota_format_type___128 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___128;

struct quota_info___128 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___128 *files[3];
	struct mem_dqinfo___128 info[3];
	const struct quota_format_ops___128 *ops[3];
};

struct rcuwait___129 {
	struct task_struct___135 *task;
};

struct percpu_rw_semaphore___129 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___129 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___128 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___129 rw_sem[3];
};

struct super_operations___128;

struct dquot_operations___128;

struct quotactl_ops___128;

struct super_block___128 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___128 *s_type;
	const struct super_operations___128 *s_op;
	const struct dquot_operations___128 *dq_op;
	const struct quotactl_ops___128 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___128 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___128 s_dquot;
	struct sb_writers___128 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___128 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___128 {
	struct dentry___128 *mnt_root;
	struct super_block___128 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct wait_page_queue___57;

struct kiocb___128 {
	struct file___128 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___128 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___57 *ki_waitq;
	};
};

struct iattr___128 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___128 *ia_file;
};

struct dquot___128 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___128 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___128 {
	int qf_fmt_id;
	const struct quota_format_ops___128 *qf_ops;
	struct module___117 *qf_owner;
	struct quota_format_type___128 *qf_next;
};

struct quota_format_ops___128 {
	int (*check_quota_file)(struct super_block___128 *, int);
	int (*read_file_info)(struct super_block___128 *, int);
	int (*write_file_info)(struct super_block___128 *, int);
	int (*free_file_info)(struct super_block___128 *, int);
	int (*read_dqblk)(struct dquot___128 *);
	int (*commit_dqblk)(struct dquot___128 *);
	int (*release_dqblk)(struct dquot___128 *);
	int (*get_next_id)(struct super_block___128 *, struct kqid *);
};

struct dquot_operations___128 {
	int (*write_dquot)(struct dquot___128 *);
	struct dquot___128 * (*alloc_dquot)(struct super_block___128 *, int);
	void (*destroy_dquot)(struct dquot___128 *);
	int (*acquire_dquot)(struct dquot___128 *);
	int (*release_dquot)(struct dquot___128 *);
	int (*mark_dirty)(struct dquot___128 *);
	int (*write_info)(struct super_block___128 *, int);
	qsize_t * (*get_reserved_space)(struct inode___128 *);
	int (*get_projid)(struct inode___128 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___128 *, qsize_t *);
	int (*get_next_id)(struct super_block___128 *, struct kqid *);
};

struct quotactl_ops___128 {
	int (*quota_on)(struct super_block___128 *, int, int, const struct path___128 *);
	int (*quota_off)(struct super_block___128 *, int);
	int (*quota_enable)(struct super_block___128 *, unsigned int);
	int (*quota_disable)(struct super_block___128 *, unsigned int);
	int (*quota_sync)(struct super_block___128 *, int);
	int (*set_info)(struct super_block___128 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___128 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___128 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___128 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___128 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___128 *, unsigned int);
};

struct wait_page_queue___57 {
	struct page___133 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___57;

struct address_space_operations___128 {
	int (*writepage)(struct page___133 *, struct writeback_control___3 *);
	int (*readpage)(struct file___128 *, struct page___133 *);
	int (*writepages)(struct address_space___128 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___133 *);
	int (*readpages)(struct file___128 *, struct address_space___128 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___57 *);
	int (*write_begin)(struct file___128 *, struct address_space___128 *, loff_t, unsigned int, unsigned int, struct page___133 **, void **);
	int (*write_end)(struct file___128 *, struct address_space___128 *, loff_t, unsigned int, unsigned int, struct page___133 *, void *);
	sector_t (*bmap)(struct address_space___128 *, sector_t);
	void (*invalidatepage)(struct page___133 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___133 *, gfp_t);
	void (*freepage)(struct page___133 *);
	ssize_t (*direct_IO)(struct kiocb___128 *, struct iov_iter___71 *);
	int (*migratepage)(struct address_space___128 *, struct page___133 *, struct page___133 *, enum migrate_mode);
	bool (*isolate_page)(struct page___133 *, isolate_mode_t);
	void (*putback_page)(struct page___133 *);
	int (*launder_page)(struct page___133 *);
	int (*is_partially_uptodate)(struct page___133 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___133 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___128 *, struct page___133 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___128 *, sector_t *);
	void (*swap_deactivate)(struct file___128 *);
};

struct readahead_control___57 {
	struct file___128 *file;
	struct address_space___128 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___128 {
	struct dentry___128 * (*lookup)(struct inode___128 *, struct dentry___128 *, unsigned int);
	const char * (*get_link)(struct dentry___128 *, struct inode___128 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___128 *, int);
	struct posix_acl * (*get_acl)(struct inode___128 *, int, bool);
	int (*readlink)(struct dentry___128 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___128 *, struct dentry___128 *, umode_t, bool);
	int (*link)(struct dentry___128 *, struct inode___128 *, struct dentry___128 *);
	int (*unlink)(struct inode___128 *, struct dentry___128 *);
	int (*symlink)(struct user_namespace *, struct inode___128 *, struct dentry___128 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___128 *, struct dentry___128 *, umode_t);
	int (*rmdir)(struct inode___128 *, struct dentry___128 *);
	int (*mknod)(struct user_namespace *, struct inode___128 *, struct dentry___128 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___128 *, struct dentry___128 *, struct inode___128 *, struct dentry___128 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___128 *, struct iattr___128 *);
	int (*getattr)(struct user_namespace *, const struct path___128 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___128 *, char *, size_t);
	int (*fiemap)(struct inode___128 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___128 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___128 *, struct dentry___128 *, struct file___128 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___128 *, struct dentry___128 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___128 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___128 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___128 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___128 {
	void (*fl_copy_lock)(struct file_lock___128 *, struct file_lock___128 *);
	void (*fl_release_private)(struct file_lock___128 *);
};

struct fasync_struct___128;

struct lock_manager_operations___128;

struct file_lock___128 {
	struct file_lock___128 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___128 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___128 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___128 *fl_ops;
	const struct lock_manager_operations___128 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___128 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___128 *);
	int (*lm_grant)(struct file_lock___128 *, int);
	bool (*lm_break)(struct file_lock___128 *);
	int (*lm_change)(struct file_lock___128 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___128 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___128 *);
};

struct fasync_struct___128 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___128 *fa_next;
	struct file___128 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___128 {
	struct inode___128 * (*alloc_inode)(struct super_block___128 *);
	void (*destroy_inode)(struct inode___128 *);
	void (*free_inode)(struct inode___128 *);
	void (*dirty_inode)(struct inode___128 *, int);
	int (*write_inode)(struct inode___128 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___128 *);
	void (*evict_inode)(struct inode___128 *);
	void (*put_super)(struct super_block___128 *);
	int (*sync_fs)(struct super_block___128 *, int);
	int (*freeze_super)(struct super_block___128 *);
	int (*freeze_fs)(struct super_block___128 *);
	int (*thaw_super)(struct super_block___128 *);
	int (*unfreeze_fs)(struct super_block___128 *);
	int (*statfs)(struct dentry___128 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___128 *, int *, char *);
	void (*umount_begin)(struct super_block___128 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___128 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___128 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___128 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___128 *);
	ssize_t (*quota_read)(struct super_block___128 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___128 *, int, const char *, size_t, loff_t);
	struct dquot___128 ** (*get_dquots)(struct inode___128 *);
	long int (*nr_cached_objects)(struct super_block___128 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___128 *, struct shrink_control___49 *);
	struct file___128 * (*real_loop)(struct file___128 *);
};

struct vmcore {
	struct list_head list;
	long long unsigned int paddr;
	long long unsigned int size;
	loff_t offset;
};

struct vmcoredd_node {
	struct list_head list;
	void *buf;
	unsigned int size;
};

typedef struct elf32_hdr Elf32_Ehdr;

typedef struct elf32_phdr Elf32_Phdr;

typedef struct elf32_note Elf32_Nhdr;

typedef struct elf64_note Elf64_Nhdr;

struct nsset___23 {
	unsigned int flags;
	struct nsproxy___119 *nsproxy;
	struct fs_struct *fs;
	const struct cred___19 *cred;
};

struct proc_ns_operations___24 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___24 * (*get)(struct task_struct___135 *);
	void (*put)(struct ns_common___24 *);
	int (*install)(struct nsset___23 *, struct ns_common___24 *);
	struct user_namespace * (*owner)(struct ns_common___24 *);
	struct ns_common___24 * (*get_parent)(struct ns_common___24 *);
};

struct kernfs_root___119;

struct kernfs_elem_dir___119 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___119 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___119;

struct kernfs_root___119 {
	struct kernfs_node___119 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___119 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___119 {
	struct kernfs_node___119 *target_kn;
};

struct kernfs_ops___119;

struct kernfs_elem_attr___119 {
	const struct kernfs_ops___119 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___119 *notify_next;
};

struct kernfs_node___119 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___119 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___119 dir;
		struct kernfs_elem_symlink___119 symlink;
		struct kernfs_elem_attr___119 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___119;

struct kernfs_ops___119 {
	int (*open)(struct kernfs_open_file___119 *);
	void (*release)(struct kernfs_open_file___119 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___119 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___119 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___119 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___119 *, struct vm_area_struct___133 *);
};

struct kernfs_syscall_ops___119 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___119 *);
	int (*mkdir)(struct kernfs_node___119 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___119 *);
	int (*rename)(struct kernfs_node___119 *, struct kernfs_node___119 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___119 *, struct kernfs_root___119 *);
};

struct kernfs_open_file___119 {
	struct kernfs_node___119 *kn;
	struct file___128 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___126 *vm_ops;
};

struct bin_attribute___119;

struct attribute_group___119 {
	const char *name;
	umode_t (*is_visible)(struct kobject___119 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___119 *, struct bin_attribute___119 *, int);
	struct attribute **attrs;
	struct bin_attribute___119 **bin_attrs;
};

struct bin_attribute___119 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___128 * (*f_mapping)();
	ssize_t (*read)(struct file___128 *, struct kobject___119 *, struct bin_attribute___119 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___128 *, struct kobject___119 *, struct bin_attribute___119 *, char *, loff_t, size_t);
	int (*mmap)(struct file___128 *, struct kobject___119 *, struct bin_attribute___119 *, struct vm_area_struct___133 *);
};

struct sysfs_ops___119 {
	ssize_t (*show)(struct kobject___119 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___119 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___119;

struct kset___119 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___119 kobj;
	const struct kset_uevent_ops___119 *uevent_ops;
};

struct kobj_type___119 {
	void (*release)(struct kobject___119 *);
	const struct sysfs_ops___119 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___119 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___119 *);
	const void * (*namespace)(struct kobject___119 *);
	void (*get_ownership)(struct kobject___119 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___119 {
	int (* const filter)(struct kset___119 *, struct kobject___119 *);
	const char * (* const name)(struct kset___119 *, struct kobject___119 *);
	int (* const uevent)(struct kset___119 *, struct kobject___119 *, struct kobj_uevent_env *);
};

typedef int (*proc_write_t___10)(struct file___128 *, char *, size_t);

struct proc_ops___17;

struct proc_dir_entry___10 {
	atomic_t in_use;
	refcount_t refcnt;
	struct list_head pde_openers;
	spinlock_t pde_unload_lock;
	struct completion *pde_unload_completion;
	const struct inode_operations___128 *proc_iops;
	union {
		const struct proc_ops___17 *proc_ops;
		const struct file_operations___128 *proc_dir_ops;
	};
	const struct dentry_operations___128 *proc_dops;
	union {
		const struct seq_operations___111 *seq_ops;
		int (*single_show)(struct seq_file___111 *, void *);
	};
	proc_write_t___10 write;
	void *data;
	unsigned int state_size;
	unsigned int low_ino;
	nlink_t nlink;
	kuid_t uid;
	kgid_t gid;
	loff_t size;
	struct proc_dir_entry___10 *parent;
	struct rb_root subdir;
	struct rb_node subdir_node;
	char *name;
	umode_t mode;
	u8 flags;
	u8 namelen;
	char inline_name[0];
};

struct kernel_param_ops___116 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___116 *);
	int (*get)(char *, const struct kernel_param___116 *);
	void (*free)(void *);
};

struct kparam_array___116;

struct kernel_param___116 {
	const char *name;
	struct module___117 *mod;
	const struct kernel_param_ops___116 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___116 *arr;
	};
};

struct kparam_array___116 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___116 *ops;
	void *elem;
};

struct module_attribute___116 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___116 *, struct module_kobject___116 *, char *);
	ssize_t (*store)(struct module_attribute___116 *, struct module_kobject___116 *, const char *, size_t);
	void (*setup)(struct module___117 *, const char *);
	int (*test)(struct module___117 *);
	void (*free)(struct module___117 *);
};

struct proc_ops___17 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___128 *, struct file___128 *);
	ssize_t (*proc_read)(struct file___128 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___128 *, struct iov_iter___71 *);
	ssize_t (*proc_write)(struct file___128 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___128 *, loff_t, int);
	int (*proc_release)(struct inode___128 *, struct file___128 *);
	__poll_t (*proc_poll)(struct file___128 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___128 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___128 *, struct vm_area_struct___133 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___128 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct vmcoredd_header {
	__u32 n_namesz;
	__u32 n_descsz;
	__u32 n_type;
	__u8 name[8];
	__u8 dump_name[44];
};

struct vmcoredd_data {
	char dump_name[44];
	unsigned int size;
	int (*vmcoredd_callback)(struct vmcoredd_data *, void *);
};

struct linux_binprm___27 {
	struct vm_area_struct___133 *vma;
	long unsigned int vma_pages;
	struct mm_struct___134 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___128 *executable;
	struct file___128 *interpreter;
	struct file___128 *file;
	struct cred___19 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___26 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___128 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

typedef struct poll_table_struct___8 poll_table___24;

struct proc_ops___18 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___13 *, struct file___12 *);
	ssize_t (*proc_read)(struct file___12 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___11 *, struct iov_iter___4 *);
	ssize_t (*proc_write)(struct file___12 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___12 *, loff_t, int);
	int (*proc_release)(struct inode___13 *, struct file___12 *);
	__poll_t (*proc_poll)(struct file___12 *, struct poll_table_struct___8 *);
	long int (*proc_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___12 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___12 *, struct vm_area_struct___11 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___12 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct fs_context___22;

struct dentry___129;

struct super_block___129;

struct module___118;

struct file_system_type___129 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___22 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___129 * (*mount)(struct file_system_type___129 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___129 *);
	struct module___118 *owner;
	struct file_system_type___129 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___129;

struct kiocb___129;

struct vm_area_struct___134;

struct inode___129;

struct file_lock___129;

struct page___134;

struct seq_file___112;

struct file_operations___129 {
	struct module___118 *owner;
	loff_t (*llseek)(struct file___129 *, loff_t, int);
	ssize_t (*read)(struct file___129 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___129 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___129 *, struct iov_iter___71 *);
	ssize_t (*write_iter)(struct kiocb___129 *, struct iov_iter___71 *);
	int (*iopoll)(struct kiocb___129 *, bool);
	int (*iterate)(struct file___129 *, struct dir_context *);
	int (*iterate_shared)(struct file___129 *, struct dir_context *);
	__poll_t (*poll)(struct file___129 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___129 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___129 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___129 *, struct vm_area_struct___134 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___129 *, struct file___129 *);
	int (*flush)(struct file___129 *, fl_owner_t);
	int (*release)(struct inode___129 *, struct file___129 *);
	int (*fsync)(struct file___129 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___129 *, int);
	int (*lock)(struct file___129 *, int, struct file_lock___129 *);
	ssize_t (*sendpage)(struct file___129 *, struct page___134 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___129 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___129 *, long unsigned int);
	int (*flock)(struct file___129 *, int, struct file_lock___129 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___129 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___129 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___129 *, long int, struct file_lock___129 **, void **);
	long int (*fallocate)(struct file___129 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___112 *, struct file___129 *);
	ssize_t (*copy_file_range)(struct file___129 *, loff_t, struct file___129 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___129 *, loff_t, struct file___129 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___129 *, loff_t, loff_t, int);
};

struct vmacache___134 {
	u64 seqnum;
	struct vm_area_struct___134 *vmas[4];
};

struct page_frag___134 {
	struct page___134 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___135;

struct pid___114;

struct nsproxy___120;

struct signal_struct___130;

struct vm_struct___116;

struct task_struct___136 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___136 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___135 *mm;
	struct mm_struct___135 *active_mm;
	struct vmacache___134 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___136 *real_parent;
	struct task_struct___136 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___136 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___114 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___120 *nsproxy;
	struct signal_struct___130 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___136 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___134 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___136 *oom_reaper_list;
	struct vm_struct___116 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___120;

struct kobj_type___120;

struct kernfs_node___120;

struct kobject___120 {
	const char *name;
	struct list_head entry;
	struct kobject___120 *parent;
	struct kset___120 *kset;
	struct kobj_type___120 *ktype;
	struct kernfs_node___120 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___117 {
	struct kobject___120 kobj;
	struct module___118 *mod;
	struct kobject___120 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___117 {
	struct module___118 *mod;
	struct latch_tree_node node;
};

struct module_layout___117 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___117 mtn;
};

struct module_attribute___117;

struct kernel_param___117;

struct module___118 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___117 mkobj;
	struct module_attribute___117 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___120 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___117 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___117 core_layout;
	struct module_layout___117 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___129;

struct dentry___129 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___129 *d_parent;
	struct qstr d_name;
	struct inode___129 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___129 *d_op;
	struct super_block___129 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___129;

struct address_space___129 {
	struct inode___129 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___129 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___129;

struct inode___129 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___129 *i_op;
	struct super_block___129 *i_sb;
	struct address_space___129 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___129 *i_fop;
		void (*free_inode)(struct inode___129 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___129 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___129;

struct path___129;

struct dentry_operations___129 {
	int (*d_revalidate)(struct dentry___129 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___129 *, unsigned int);
	int (*d_hash)(const struct dentry___129 *, struct qstr *);
	int (*d_compare)(const struct dentry___129 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___129 *);
	int (*d_init)(struct dentry___129 *);
	void (*d_release)(struct dentry___129 *);
	void (*d_prune)(struct dentry___129 *);
	void (*d_iput)(struct dentry___129 *, struct inode___129 *);
	char * (*d_dname)(struct dentry___129 *, char *, int);
	struct vfsmount___129 * (*d_automount)(struct path___129 *);
	int (*d_manage)(const struct path___129 *, bool);
	struct dentry___129 * (*d_real)(struct dentry___129 *, const struct inode___129 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___129;

struct mem_dqinfo___129 {
	struct quota_format_type___129 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___129;

struct quota_info___129 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___129 *files[3];
	struct mem_dqinfo___129 info[3];
	const struct quota_format_ops___129 *ops[3];
};

struct rcuwait___130 {
	struct task_struct___136 *task;
};

struct percpu_rw_semaphore___130 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___130 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___129 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___130 rw_sem[3];
};

struct super_operations___129;

struct dquot_operations___129;

struct quotactl_ops___129;

struct export_operations___10;

struct xattr_handler___12;

struct super_block___129 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___129 *s_type;
	const struct super_operations___129 *s_op;
	const struct dquot_operations___129 *dq_op;
	const struct quotactl_ops___129 *s_qcop;
	const struct export_operations___10 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___129 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___12 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___129 s_dquot;
	struct sb_writers___129 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___129 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___129 {
	struct dentry___129 *mnt_root;
	struct super_block___129 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___129 {
	struct vfsmount___129 *mnt;
	struct dentry___129 *dentry;
};

struct pid_namespace___114;

struct upid___114 {
	int nr;
	struct pid_namespace___114 *ns;
};

struct pid_namespace___114 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___136 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___114 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___114 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___114 numbers[1];
};

typedef struct page___134 *pgtable_t___134;

struct dev_pagemap___127;

struct page___134 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___129 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___134 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___134 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___135 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___127 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___127;

struct vm_area_struct___134 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___134 *vm_next;
	struct vm_area_struct___134 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___135 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___127 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___129 *vm_file;
	struct file___129 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___130 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___136 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___136 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___114 *pids[4];
	struct pid___114 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___135 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___134;

struct mm_struct___135 {
	struct {
		struct vm_area_struct___134 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___129 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___134 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___136 *owner;
		struct user_namespace___19 *user_ns;
		struct file___129 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___120 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___114 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___116 {
	struct vm_struct___116 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___134 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___127;

struct dev_pagemap___127 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___127 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___114 {
	rwlock_t lock;
	struct pid___114 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___129 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___129 f_path;
	struct inode___129 *f_inode;
	const struct file_operations___129 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___114 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___129 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___127;

struct vm_operations_struct___127 {
	void (*open)(struct vm_area_struct___134 *);
	void (*close)(struct vm_area_struct___134 *);
	int (*may_split)(struct vm_area_struct___134 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___134 *);
	int (*mprotect)(struct vm_area_struct___134 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___127 *);
	vm_fault_t (*huge_fault)(struct vm_fault___127 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___127 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___134 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___127 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___127 *);
	int (*access)(struct vm_area_struct___134 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___134 *);
	int (*set_policy)(struct vm_area_struct___134 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___134 *, long unsigned int);
	struct page___134 * (*find_special_page)(struct vm_area_struct___134 *, long unsigned int);
};

struct core_thread___134 {
	struct task_struct___136 *task;
	struct core_thread___134 *next;
};

struct core_state___134 {
	atomic_t nr_threads;
	struct core_thread___134 dumper;
	struct completion startup;
};

struct vm_fault___127 {
	const struct {
		struct vm_area_struct___134 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___134 *cow_page;
	struct page___134 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___134 prealloc_pte;
};

struct wait_page_queue___58;

struct kiocb___129 {
	struct file___129 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___129 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___58 *ki_waitq;
	};
};

struct iattr___129 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___129 *ia_file;
};

struct dquot___129 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___129 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___129 {
	int qf_fmt_id;
	const struct quota_format_ops___129 *qf_ops;
	struct module___118 *qf_owner;
	struct quota_format_type___129 *qf_next;
};

struct quota_format_ops___129 {
	int (*check_quota_file)(struct super_block___129 *, int);
	int (*read_file_info)(struct super_block___129 *, int);
	int (*write_file_info)(struct super_block___129 *, int);
	int (*free_file_info)(struct super_block___129 *, int);
	int (*read_dqblk)(struct dquot___129 *);
	int (*commit_dqblk)(struct dquot___129 *);
	int (*release_dqblk)(struct dquot___129 *);
	int (*get_next_id)(struct super_block___129 *, struct kqid *);
};

struct dquot_operations___129 {
	int (*write_dquot)(struct dquot___129 *);
	struct dquot___129 * (*alloc_dquot)(struct super_block___129 *, int);
	void (*destroy_dquot)(struct dquot___129 *);
	int (*acquire_dquot)(struct dquot___129 *);
	int (*release_dquot)(struct dquot___129 *);
	int (*mark_dirty)(struct dquot___129 *);
	int (*write_info)(struct super_block___129 *, int);
	qsize_t * (*get_reserved_space)(struct inode___129 *);
	int (*get_projid)(struct inode___129 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___129 *, qsize_t *);
	int (*get_next_id)(struct super_block___129 *, struct kqid *);
};

struct quotactl_ops___129 {
	int (*quota_on)(struct super_block___129 *, int, int, const struct path___129 *);
	int (*quota_off)(struct super_block___129 *, int);
	int (*quota_enable)(struct super_block___129 *, unsigned int);
	int (*quota_disable)(struct super_block___129 *, unsigned int);
	int (*quota_sync)(struct super_block___129 *, int);
	int (*set_info)(struct super_block___129 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___129 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___129 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___129 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___129 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___129 *, unsigned int);
};

struct wait_page_queue___58 {
	struct page___134 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___58;

struct address_space_operations___129 {
	int (*writepage)(struct page___134 *, struct writeback_control___3 *);
	int (*readpage)(struct file___129 *, struct page___134 *);
	int (*writepages)(struct address_space___129 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___134 *);
	int (*readpages)(struct file___129 *, struct address_space___129 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___58 *);
	int (*write_begin)(struct file___129 *, struct address_space___129 *, loff_t, unsigned int, unsigned int, struct page___134 **, void **);
	int (*write_end)(struct file___129 *, struct address_space___129 *, loff_t, unsigned int, unsigned int, struct page___134 *, void *);
	sector_t (*bmap)(struct address_space___129 *, sector_t);
	void (*invalidatepage)(struct page___134 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___134 *, gfp_t);
	void (*freepage)(struct page___134 *);
	ssize_t (*direct_IO)(struct kiocb___129 *, struct iov_iter___71 *);
	int (*migratepage)(struct address_space___129 *, struct page___134 *, struct page___134 *, enum migrate_mode);
	bool (*isolate_page)(struct page___134 *, isolate_mode_t);
	void (*putback_page)(struct page___134 *);
	int (*launder_page)(struct page___134 *);
	int (*is_partially_uptodate)(struct page___134 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___134 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___129 *, struct page___134 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___129 *, sector_t *);
	void (*swap_deactivate)(struct file___129 *);
};

struct readahead_control___58 {
	struct file___129 *file;
	struct address_space___129 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___129 {
	struct dentry___129 * (*lookup)(struct inode___129 *, struct dentry___129 *, unsigned int);
	const char * (*get_link)(struct dentry___129 *, struct inode___129 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___129 *, int);
	struct posix_acl * (*get_acl)(struct inode___129 *, int, bool);
	int (*readlink)(struct dentry___129 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___129 *, struct dentry___129 *, umode_t, bool);
	int (*link)(struct dentry___129 *, struct inode___129 *, struct dentry___129 *);
	int (*unlink)(struct inode___129 *, struct dentry___129 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___129 *, struct dentry___129 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___129 *, struct dentry___129 *, umode_t);
	int (*rmdir)(struct inode___129 *, struct dentry___129 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___129 *, struct dentry___129 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___129 *, struct dentry___129 *, struct inode___129 *, struct dentry___129 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___129 *, struct iattr___129 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___129 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___129 *, char *, size_t);
	int (*fiemap)(struct inode___129 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___129 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___129 *, struct dentry___129 *, struct file___129 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___129 *, struct dentry___129 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___129 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___129 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___129 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___129 {
	void (*fl_copy_lock)(struct file_lock___129 *, struct file_lock___129 *);
	void (*fl_release_private)(struct file_lock___129 *);
};

struct fasync_struct___129;

struct lock_manager_operations___129;

struct file_lock___129 {
	struct file_lock___129 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___129 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___129 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___129 *fl_ops;
	const struct lock_manager_operations___129 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___129 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___129 *);
	int (*lm_grant)(struct file_lock___129 *, int);
	bool (*lm_break)(struct file_lock___129 *);
	int (*lm_change)(struct file_lock___129 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___129 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___129 *);
};

struct fasync_struct___129 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___129 *fa_next;
	struct file___129 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___129 {
	struct inode___129 * (*alloc_inode)(struct super_block___129 *);
	void (*destroy_inode)(struct inode___129 *);
	void (*free_inode)(struct inode___129 *);
	void (*dirty_inode)(struct inode___129 *, int);
	int (*write_inode)(struct inode___129 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___129 *);
	void (*evict_inode)(struct inode___129 *);
	void (*put_super)(struct super_block___129 *);
	int (*sync_fs)(struct super_block___129 *, int);
	int (*freeze_super)(struct super_block___129 *);
	int (*freeze_fs)(struct super_block___129 *);
	int (*thaw_super)(struct super_block___129 *);
	int (*unfreeze_fs)(struct super_block___129 *);
	int (*statfs)(struct dentry___129 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___129 *, int *, char *);
	void (*umount_begin)(struct super_block___129 *);
	int (*show_options)(struct seq_file___112 *, struct dentry___129 *);
	int (*show_devname)(struct seq_file___112 *, struct dentry___129 *);
	int (*show_path)(struct seq_file___112 *, struct dentry___129 *);
	int (*show_stats)(struct seq_file___112 *, struct dentry___129 *);
	ssize_t (*quota_read)(struct super_block___129 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___129 *, int, const char *, size_t, loff_t);
	struct dquot___129 ** (*get_dquots)(struct inode___129 *);
	long int (*nr_cached_objects)(struct super_block___129 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___129 *, struct shrink_control___49 *);
	struct file___129 * (*real_loop)(struct file___129 *);
};

struct export_operations___10 {
	int (*encode_fh)(struct inode___129 *, __u32 *, int *, struct inode___129 *);
	struct dentry___129 * (*fh_to_dentry)(struct super_block___129 *, struct fid *, int, int);
	struct dentry___129 * (*fh_to_parent)(struct super_block___129 *, struct fid *, int, int);
	int (*get_name)(struct dentry___129 *, char *, struct dentry___129 *);
	struct dentry___129 * (*get_parent)(struct dentry___129 *);
	int (*commit_metadata)(struct inode___129 *);
	int (*get_uuid)(struct super_block___129 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___129 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___129 *, struct iomap *, int, struct iattr___129 *);
	u64 (*fetch_iversion)(struct inode___129 *);
	long unsigned int flags;
};

struct xattr_handler___12 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___129 *);
	int (*get)(const struct xattr_handler___12 *, struct dentry___129 *, struct inode___129 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___12 *, struct user_namespace___19 *, struct dentry___129 *, struct inode___129 *, const char *, const void *, size_t, int);
};

struct seq_operations___112;

struct seq_file___112 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___112 *op;
	int poll_event;
	const struct file___129 *file;
	void *private;
};

struct fc_log___22;

struct p_log___22 {
	const char *prefix;
	struct fc_log___22 *log;
};

struct fs_context_operations___22;

struct fs_context___22 {
	const struct fs_context_operations___22 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___129 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___129 *root;
	struct user_namespace___19 *user_ns;
	struct net *net_ns;
	const struct cred___19 *cred;
	struct p_log___22 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___127 {
	void (*page_free)(struct page___134 *);
	void (*kill)(struct dev_pagemap___127 *);
	void (*cleanup)(struct dev_pagemap___127 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___127 *);
};

struct kernfs_root___120;

struct kernfs_elem_dir___120 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___120 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___120;

struct kernfs_root___120 {
	struct kernfs_node___120 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___120 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___120 {
	struct kernfs_node___120 *target_kn;
};

struct kernfs_ops___120;

struct kernfs_elem_attr___120 {
	const struct kernfs_ops___120 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___120 *notify_next;
};

struct kernfs_node___120 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___120 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___120 dir;
		struct kernfs_elem_symlink___120 symlink;
		struct kernfs_elem_attr___120 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___120;

struct kernfs_ops___120 {
	int (*open)(struct kernfs_open_file___120 *);
	void (*release)(struct kernfs_open_file___120 *);
	int (*seq_show)(struct seq_file___112 *, void *);
	void * (*seq_start)(struct seq_file___112 *, loff_t *);
	void * (*seq_next)(struct seq_file___112 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___112 *, void *);
	ssize_t (*read)(struct kernfs_open_file___120 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___120 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___120 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___120 *, struct vm_area_struct___134 *);
};

struct kernfs_iattrs {
	kuid_t ia_uid;
	kgid_t ia_gid;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct simple_xattrs xattrs;
	atomic_t nr_user_xattrs;
	atomic_t user_xattr_size;
};

struct kernfs_syscall_ops___120 {
	int (*show_options)(struct seq_file___112 *, struct kernfs_root___120 *);
	int (*mkdir)(struct kernfs_node___120 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___120 *);
	int (*rename)(struct kernfs_node___120 *, struct kernfs_node___120 *, const char *);
	int (*show_path)(struct seq_file___112 *, struct kernfs_node___120 *, struct kernfs_root___120 *);
};

struct kernfs_open_file___120 {
	struct kernfs_node___120 *kn;
	struct file___129 *file;
	struct seq_file___112 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___127 *vm_ops;
};

struct kernfs_fs_context___3 {
	struct kernfs_root___120 *root;
	void *ns_tag;
	long unsigned int magic;
	bool new_sb_created;
};

struct bin_attribute___120;

struct attribute_group___120 {
	const char *name;
	umode_t (*is_visible)(struct kobject___120 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___120 *, struct bin_attribute___120 *, int);
	struct attribute **attrs;
	struct bin_attribute___120 **bin_attrs;
};

struct bin_attribute___120 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___129 * (*f_mapping)();
	ssize_t (*read)(struct file___129 *, struct kobject___120 *, struct bin_attribute___120 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___129 *, struct kobject___120 *, struct bin_attribute___120 *, char *, loff_t, size_t);
	int (*mmap)(struct file___129 *, struct kobject___120 *, struct bin_attribute___120 *, struct vm_area_struct___134 *);
};

struct sysfs_ops___120 {
	ssize_t (*show)(struct kobject___120 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___120 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___120;

struct kset___120 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___120 kobj;
	const struct kset_uevent_ops___120 *uevent_ops;
};

struct kobj_type___120 {
	void (*release)(struct kobject___120 *);
	const struct sysfs_ops___120 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___120 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___120 *);
	const void * (*namespace)(struct kobject___120 *);
	void (*get_ownership)(struct kobject___120 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___120 {
	int (* const filter)(struct kset___120 *, struct kobject___120 *);
	const char * (* const name)(struct kset___120 *, struct kobject___120 *);
	int (* const uevent)(struct kset___120 *, struct kobject___120 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___117 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___117 *);
	int (*get)(char *, const struct kernel_param___117 *);
	void (*free)(void *);
};

struct kparam_array___117;

struct kernel_param___117 {
	const char *name;
	struct module___118 *mod;
	const struct kernel_param_ops___117 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___117 *arr;
	};
};

struct kparam_array___117 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___117 *ops;
	void *elem;
};

struct module_attribute___117 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___117 *, struct module_kobject___117 *, char *);
	ssize_t (*store)(struct module_attribute___117 *, struct module_kobject___117 *, const char *, size_t);
	void (*setup)(struct module___118 *, const char *);
	int (*test)(struct module___118 *);
	void (*free)(struct module___118 *);
};

struct seq_operations___112 {
	void * (*start)(struct seq_file___112 *, loff_t *);
	void (*stop)(struct seq_file___112 *, void *);
	void * (*next)(struct seq_file___112 *, void *, loff_t *);
	int (*show)(struct seq_file___112 *, void *);
};

struct fs_parameter___22 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___129 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___22 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___118 *owner;
	char *buffer[8];
};

struct fs_context_operations___22 {
	void (*free)(struct fs_context___22 *);
	int (*dup)(struct fs_context___22 *, struct fs_context___22 *);
	int (*parse_param)(struct fs_context___22 *, struct fs_parameter___22 *);
	int (*parse_monolithic)(struct fs_context___22 *, void *);
	int (*get_tree)(struct fs_context___22 *);
	int (*reconfigure)(struct fs_context___22 *);
};

struct kernfs_super_info {
	struct super_block___129 *sb;
	struct kernfs_root___120 *root;
	const void *ns;
	struct list_head node;
};

enum kernfs_node_flag {
	KERNFS_ACTIVATED = 16,
	KERNFS_NS = 32,
	KERNFS_HAS_SEQ_SHOW = 64,
	KERNFS_HAS_MMAP = 128,
	KERNFS_LOCKDEP = 256,
	KERNFS_SUICIDAL = 1024,
	KERNFS_SUICIDED = 2048,
	KERNFS_EMPTY_DIR = 4096,
	KERNFS_HAS_RELEASE = 8192,
};

struct fs_context___23;

struct dentry___130;

struct super_block___130;

struct module___119;

struct file_system_type___130 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___23 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___130 * (*mount)(struct file_system_type___130 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___130 *);
	struct module___119 *owner;
	struct file_system_type___130 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___130;

struct kiocb___130;

struct poll_table_struct___86;

struct vm_area_struct___135;

struct inode___130;

struct file_lock___130;

struct page___135;

struct seq_file___113;

struct file_operations___130 {
	struct module___119 *owner;
	loff_t (*llseek)(struct file___130 *, loff_t, int);
	ssize_t (*read)(struct file___130 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___130 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___130 *, struct iov_iter___71 *);
	ssize_t (*write_iter)(struct kiocb___130 *, struct iov_iter___71 *);
	int (*iopoll)(struct kiocb___130 *, bool);
	int (*iterate)(struct file___130 *, struct dir_context *);
	int (*iterate_shared)(struct file___130 *, struct dir_context *);
	__poll_t (*poll)(struct file___130 *, struct poll_table_struct___86 *);
	long int (*unlocked_ioctl)(struct file___130 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___130 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___130 *, struct vm_area_struct___135 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___130 *, struct file___130 *);
	int (*flush)(struct file___130 *, fl_owner_t);
	int (*release)(struct inode___130 *, struct file___130 *);
	int (*fsync)(struct file___130 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___130 *, int);
	int (*lock)(struct file___130 *, int, struct file_lock___130 *);
	ssize_t (*sendpage)(struct file___130 *, struct page___135 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___130 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___130 *, long unsigned int);
	int (*flock)(struct file___130 *, int, struct file_lock___130 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___130 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___130 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___130 *, long int, struct file_lock___130 **, void **);
	long int (*fallocate)(struct file___130 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___113 *, struct file___130 *);
	ssize_t (*copy_file_range)(struct file___130 *, loff_t, struct file___130 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___130 *, loff_t, struct file___130 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___130 *, loff_t, loff_t, int);
};

struct vmacache___135 {
	u64 seqnum;
	struct vm_area_struct___135 *vmas[4];
};

struct page_frag___135 {
	struct page___135 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___136;

struct pid___115;

struct nsproxy___121;

struct signal_struct___131;

struct vm_struct___117;

struct task_struct___137 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___137 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___136 *mm;
	struct mm_struct___136 *active_mm;
	struct vmacache___135 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___137 *real_parent;
	struct task_struct___137 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___137 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___115 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___121 *nsproxy;
	struct signal_struct___131 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___137 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___57 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___135 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___137 *oom_reaper_list;
	struct vm_struct___117 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___121;

struct kobj_type___121;

struct kernfs_node___121;

struct kobject___121 {
	const char *name;
	struct list_head entry;
	struct kobject___121 *parent;
	struct kset___121 *kset;
	struct kobj_type___121 *ktype;
	struct kernfs_node___121 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___118 {
	struct kobject___121 kobj;
	struct module___119 *mod;
	struct kobject___121 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___118 {
	struct module___119 *mod;
	struct latch_tree_node node;
};

struct module_layout___118 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___118 mtn;
};

struct module_attribute___118;

struct kernel_param___118;

struct module___119 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___118 mkobj;
	struct module_attribute___118 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___121 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___118 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___118 core_layout;
	struct module_layout___118 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___130;

struct dentry___130 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___130 *d_parent;
	struct qstr d_name;
	struct inode___130 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___130 *d_op;
	struct super_block___130 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___130;

struct address_space___130 {
	struct inode___130 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___130 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___130;

struct inode___130 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___130 *i_op;
	struct super_block___130 *i_sb;
	struct address_space___130 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___130 *i_fop;
		void (*free_inode)(struct inode___130 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___130 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___130;

struct path___130;

struct dentry_operations___130 {
	int (*d_revalidate)(struct dentry___130 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___130 *, unsigned int);
	int (*d_hash)(const struct dentry___130 *, struct qstr *);
	int (*d_compare)(const struct dentry___130 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___130 *);
	int (*d_init)(struct dentry___130 *);
	void (*d_release)(struct dentry___130 *);
	void (*d_prune)(struct dentry___130 *);
	void (*d_iput)(struct dentry___130 *, struct inode___130 *);
	char * (*d_dname)(struct dentry___130 *, char *, int);
	struct vfsmount___130 * (*d_automount)(struct path___130 *);
	int (*d_manage)(const struct path___130 *, bool);
	struct dentry___130 * (*d_real)(struct dentry___130 *, const struct inode___130 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___130;

struct mem_dqinfo___130 {
	struct quota_format_type___130 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___130;

struct quota_info___130 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___130 *files[3];
	struct mem_dqinfo___130 info[3];
	const struct quota_format_ops___130 *ops[3];
};

struct rcuwait___131 {
	struct task_struct___137 *task;
};

struct percpu_rw_semaphore___131 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___131 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___130 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___131 rw_sem[3];
};

struct super_operations___130;

struct dquot_operations___130;

struct quotactl_ops___130;

struct xattr_handler___13;

struct super_block___130 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___130 *s_type;
	const struct super_operations___130 *s_op;
	const struct dquot_operations___130 *dq_op;
	const struct quotactl_ops___130 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___130 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___13 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___130 s_dquot;
	struct sb_writers___130 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___130 *s_d_op;
	int cleancache_poolid;
	struct shrinker___49 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___130 {
	struct dentry___130 *mnt_root;
	struct super_block___130 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___130 {
	struct vfsmount___130 *mnt;
	struct dentry___130 *dentry;
};

struct pid_namespace___115;

struct upid___115 {
	int nr;
	struct pid_namespace___115 *ns;
};

struct pid_namespace___115 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___137 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___115 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___115 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___115 numbers[1];
};

typedef struct page___135 *pgtable_t___135;

struct dev_pagemap___128;

struct page___135 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___130 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___135 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___135 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___136 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___128 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___128;

struct vm_area_struct___135 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___135 *vm_next;
	struct vm_area_struct___135 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___136 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___128 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___130 *vm_file;
	struct file___130 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___131 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___137 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___137 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___115 *pids[4];
	struct pid___115 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___136 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___135;

struct mm_struct___136 {
	struct {
		struct vm_area_struct___135 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___130 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___135 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___137 *owner;
		struct user_namespace___19 *user_ns;
		struct file___130 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___121 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___115 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___117 {
	struct vm_struct___117 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___135 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___128;

struct dev_pagemap___128 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___128 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___115 {
	rwlock_t lock;
	struct pid___115 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___130 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___130 f_path;
	struct inode___130 *f_inode;
	const struct file_operations___130 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___115 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___130 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___128;

struct vm_operations_struct___128 {
	void (*open)(struct vm_area_struct___135 *);
	void (*close)(struct vm_area_struct___135 *);
	int (*may_split)(struct vm_area_struct___135 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___135 *);
	int (*mprotect)(struct vm_area_struct___135 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___128 *);
	vm_fault_t (*huge_fault)(struct vm_fault___128 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___128 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___135 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___128 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___128 *);
	int (*access)(struct vm_area_struct___135 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___135 *);
	int (*set_policy)(struct vm_area_struct___135 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___135 *, long unsigned int);
	struct page___135 * (*find_special_page)(struct vm_area_struct___135 *, long unsigned int);
};

struct core_thread___135 {
	struct task_struct___137 *task;
	struct core_thread___135 *next;
};

struct core_state___135 {
	atomic_t nr_threads;
	struct core_thread___135 dumper;
	struct completion startup;
};

struct vm_fault___128 {
	const struct {
		struct vm_area_struct___135 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___135 *cow_page;
	struct page___135 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___135 prealloc_pte;
};

struct wait_page_queue___59;

struct kiocb___130 {
	struct file___130 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___130 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___59 *ki_waitq;
	};
};

struct iattr___130 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___130 *ia_file;
};

struct dquot___130 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___130 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___130 {
	int qf_fmt_id;
	const struct quota_format_ops___130 *qf_ops;
	struct module___119 *qf_owner;
	struct quota_format_type___130 *qf_next;
};

struct quota_format_ops___130 {
	int (*check_quota_file)(struct super_block___130 *, int);
	int (*read_file_info)(struct super_block___130 *, int);
	int (*write_file_info)(struct super_block___130 *, int);
	int (*free_file_info)(struct super_block___130 *, int);
	int (*read_dqblk)(struct dquot___130 *);
	int (*commit_dqblk)(struct dquot___130 *);
	int (*release_dqblk)(struct dquot___130 *);
	int (*get_next_id)(struct super_block___130 *, struct kqid *);
};

struct dquot_operations___130 {
	int (*write_dquot)(struct dquot___130 *);
	struct dquot___130 * (*alloc_dquot)(struct super_block___130 *, int);
	void (*destroy_dquot)(struct dquot___130 *);
	int (*acquire_dquot)(struct dquot___130 *);
	int (*release_dquot)(struct dquot___130 *);
	int (*mark_dirty)(struct dquot___130 *);
	int (*write_info)(struct super_block___130 *, int);
	qsize_t * (*get_reserved_space)(struct inode___130 *);
	int (*get_projid)(struct inode___130 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___130 *, qsize_t *);
	int (*get_next_id)(struct super_block___130 *, struct kqid *);
};

struct quotactl_ops___130 {
	int (*quota_on)(struct super_block___130 *, int, int, const struct path___130 *);
	int (*quota_off)(struct super_block___130 *, int);
	int (*quota_enable)(struct super_block___130 *, unsigned int);
	int (*quota_disable)(struct super_block___130 *, unsigned int);
	int (*quota_sync)(struct super_block___130 *, int);
	int (*set_info)(struct super_block___130 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___130 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___130 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___130 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___130 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___130 *, unsigned int);
};

struct wait_page_queue___59 {
	struct page___135 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___59;

struct address_space_operations___130 {
	int (*writepage)(struct page___135 *, struct writeback_control___3 *);
	int (*readpage)(struct file___130 *, struct page___135 *);
	int (*writepages)(struct address_space___130 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___135 *);
	int (*readpages)(struct file___130 *, struct address_space___130 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___59 *);
	int (*write_begin)(struct file___130 *, struct address_space___130 *, loff_t, unsigned int, unsigned int, struct page___135 **, void **);
	int (*write_end)(struct file___130 *, struct address_space___130 *, loff_t, unsigned int, unsigned int, struct page___135 *, void *);
	sector_t (*bmap)(struct address_space___130 *, sector_t);
	void (*invalidatepage)(struct page___135 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___135 *, gfp_t);
	void (*freepage)(struct page___135 *);
	ssize_t (*direct_IO)(struct kiocb___130 *, struct iov_iter___71 *);
	int (*migratepage)(struct address_space___130 *, struct page___135 *, struct page___135 *, enum migrate_mode);
	bool (*isolate_page)(struct page___135 *, isolate_mode_t);
	void (*putback_page)(struct page___135 *);
	int (*launder_page)(struct page___135 *);
	int (*is_partially_uptodate)(struct page___135 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___135 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___130 *, struct page___135 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___130 *, sector_t *);
	void (*swap_deactivate)(struct file___130 *);
};

struct readahead_control___59 {
	struct file___130 *file;
	struct address_space___130 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___130 {
	struct dentry___130 * (*lookup)(struct inode___130 *, struct dentry___130 *, unsigned int);
	const char * (*get_link)(struct dentry___130 *, struct inode___130 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___130 *, int);
	struct posix_acl * (*get_acl)(struct inode___130 *, int, bool);
	int (*readlink)(struct dentry___130 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___130 *, struct dentry___130 *, umode_t, bool);
	int (*link)(struct dentry___130 *, struct inode___130 *, struct dentry___130 *);
	int (*unlink)(struct inode___130 *, struct dentry___130 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___130 *, struct dentry___130 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___130 *, struct dentry___130 *, umode_t);
	int (*rmdir)(struct inode___130 *, struct dentry___130 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___130 *, struct dentry___130 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___130 *, struct dentry___130 *, struct inode___130 *, struct dentry___130 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___130 *, struct iattr___130 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___130 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___130 *, char *, size_t);
	int (*fiemap)(struct inode___130 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___130 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___130 *, struct dentry___130 *, struct file___130 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___130 *, struct dentry___130 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___130 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___130 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___130 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___130 {
	void (*fl_copy_lock)(struct file_lock___130 *, struct file_lock___130 *);
	void (*fl_release_private)(struct file_lock___130 *);
};

struct fasync_struct___130;

struct lock_manager_operations___130;

struct file_lock___130 {
	struct file_lock___130 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___130 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___130 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___130 *fl_ops;
	const struct lock_manager_operations___130 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___130 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___130 *);
	int (*lm_grant)(struct file_lock___130 *, int);
	bool (*lm_break)(struct file_lock___130 *);
	int (*lm_change)(struct file_lock___130 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___130 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___130 *);
};

struct fasync_struct___130 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___130 *fa_next;
	struct file___130 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___130 {
	struct inode___130 * (*alloc_inode)(struct super_block___130 *);
	void (*destroy_inode)(struct inode___130 *);
	void (*free_inode)(struct inode___130 *);
	void (*dirty_inode)(struct inode___130 *, int);
	int (*write_inode)(struct inode___130 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___130 *);
	void (*evict_inode)(struct inode___130 *);
	void (*put_super)(struct super_block___130 *);
	int (*sync_fs)(struct super_block___130 *, int);
	int (*freeze_super)(struct super_block___130 *);
	int (*freeze_fs)(struct super_block___130 *);
	int (*thaw_super)(struct super_block___130 *);
	int (*unfreeze_fs)(struct super_block___130 *);
	int (*statfs)(struct dentry___130 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___130 *, int *, char *);
	void (*umount_begin)(struct super_block___130 *);
	int (*show_options)(struct seq_file___113 *, struct dentry___130 *);
	int (*show_devname)(struct seq_file___113 *, struct dentry___130 *);
	int (*show_path)(struct seq_file___113 *, struct dentry___130 *);
	int (*show_stats)(struct seq_file___113 *, struct dentry___130 *);
	ssize_t (*quota_read)(struct super_block___130 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___130 *, int, const char *, size_t, loff_t);
	struct dquot___130 ** (*get_dquots)(struct inode___130 *);
	long int (*nr_cached_objects)(struct super_block___130 *, struct shrink_control___49 *);
	long int (*free_cached_objects)(struct super_block___130 *, struct shrink_control___49 *);
	struct file___130 * (*real_loop)(struct file___130 *);
};

struct xattr_handler___13 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___130 *);
	int (*get)(const struct xattr_handler___13 *, struct dentry___130 *, struct inode___130 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___13 *, struct user_namespace___19 *, struct dentry___130 *, struct inode___130 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___87)(struct file___130 *, wait_queue_head_t *, struct poll_table_struct___86 *);

struct poll_table_struct___86 {
	poll_queue_proc___87 _qproc;
	__poll_t _key;
};

struct seq_operations___113;

struct seq_file___113 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___113 *op;
	int poll_event;
	const struct file___130 *file;
	void *private;
};

struct fc_log___23;

struct p_log___23 {
	const char *prefix;
	struct fc_log___23 *log;
};

struct fs_context_operations___23;

struct fs_context___23 {
	const struct fs_context_operations___23 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___130 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___130 *root;
	struct user_namespace___19 *user_ns;
	struct net *net_ns;
	const struct cred___19 *cred;
	struct p_log___23 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct seq_operations___113 {
	void * (*start)(struct seq_file___113 *, loff_t *);
	void (*stop)(struct seq_file___113 *, void *);
	void * (*next)(struct seq_file___113 *, void *, loff_t *);
	int (*show)(struct seq_file___113 *, void *);
};

typedef struct poll_table_struct___86 poll_table___25;

struct dev_pagemap_ops___128 {
	void (*page_free)(struct page___135 *);
	void (*kill)(struct dev_pagemap___128 *);
	void (*cleanup)(struct dev_pagemap___128 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___128 *);
};

struct kernfs_root___121;

struct kernfs_elem_dir___121 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___121 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___121;

struct kernfs_root___121 {
	struct kernfs_node___121 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___121 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___121 {
	struct kernfs_node___121 *target_kn;
};

struct kernfs_ops___121;

struct kernfs_elem_attr___121 {
	const struct kernfs_ops___121 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___121 *notify_next;
};

struct kernfs_node___121 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___121 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___121 dir;
		struct kernfs_elem_symlink___121 symlink;
		struct kernfs_elem_attr___121 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___121;

struct kernfs_ops___121 {
	int (*open)(struct kernfs_open_file___121 *);
	void (*release)(struct kernfs_open_file___121 *);
	int (*seq_show)(struct seq_file___113 *, void *);
	void * (*seq_start)(struct seq_file___113 *, loff_t *);
	void * (*seq_next)(struct seq_file___113 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___113 *, void *);
	ssize_t (*read)(struct kernfs_open_file___121 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___121 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___121 *, struct poll_table_struct___86 *);
	int (*mmap)(struct kernfs_open_file___121 *, struct vm_area_struct___135 *);
};

struct kernfs_open_node {
	atomic_t refcnt;
	atomic_t event;
	wait_queue_head_t poll;
	struct list_head files;
};

struct kernfs_syscall_ops___121 {
	int (*show_options)(struct seq_file___113 *, struct kernfs_root___121 *);
	int (*mkdir)(struct kernfs_node___121 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___121 *);
	int (*rename)(struct kernfs_node___121 *, struct kernfs_node___121 *, const char *);
	int (*show_path)(struct seq_file___113 *, struct kernfs_node___121 *, struct kernfs_root___121 *);
};

struct kernfs_open_file___121 {
	struct kernfs_node___121 *kn;
	struct file___130 *file;
	struct seq_file___113 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___128 *vm_ops;
};

struct bin_attribute___121;

struct attribute_group___121 {
	const char *name;
	umode_t (*is_visible)(struct kobject___121 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___121 *, struct bin_attribute___121 *, int);
	struct attribute **attrs;
	struct bin_attribute___121 **bin_attrs;
};

struct bin_attribute___121 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___130 * (*f_mapping)();
	ssize_t (*read)(struct file___130 *, struct kobject___121 *, struct bin_attribute___121 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___130 *, struct kobject___121 *, struct bin_attribute___121 *, char *, loff_t, size_t);
	int (*mmap)(struct file___130 *, struct kobject___121 *, struct bin_attribute___121 *, struct vm_area_struct___135 *);
};

struct sysfs_ops___121 {
	ssize_t (*show)(struct kobject___121 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___121 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___121;

struct kset___121 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___121 kobj;
	const struct kset_uevent_ops___121 *uevent_ops;
};

struct kobj_type___121 {
	void (*release)(struct kobject___121 *);
	const struct sysfs_ops___121 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___121 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___121 *);
	const void * (*namespace)(struct kobject___121 *);
	void (*get_ownership)(struct kobject___121 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___121 {
	int (* const filter)(struct kset___121 *, struct kobject___121 *);
	const char * (* const name)(struct kset___121 *, struct kobject___121 *);
	int (* const uevent)(struct kset___121 *, struct kobject___121 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___118 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___118 *);
	int (*get)(char *, const struct kernel_param___118 *);
	void (*free)(void *);
};

struct kparam_array___118;

struct kernel_param___118 {
	const char *name;
	struct module___119 *mod;
	const struct kernel_param_ops___118 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___118 *arr;
	};
};

struct kparam_array___118 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___118 *ops;
	void *elem;
};

struct module_attribute___118 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___118 *, struct module_kobject___118 *, char *);
	ssize_t (*store)(struct module_attribute___118 *, struct module_kobject___118 *, const char *, size_t);
	void (*setup)(struct module___119 *, const char *);
	int (*test)(struct module___119 *);
	void (*free)(struct module___119 *);
};

struct fs_parameter___23 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___130 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___23 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___119 *owner;
	char *buffer[8];
};

struct fs_context_operations___23 {
	void (*free)(struct fs_context___23 *);
	int (*dup)(struct fs_context___23 *, struct fs_context___23 *);
	int (*parse_param)(struct fs_context___23 *, struct fs_parameter___23 *);
	int (*parse_monolithic)(struct fs_context___23 *, void *);
	int (*get_tree)(struct fs_context___23 *);
	int (*reconfigure)(struct fs_context___23 *);
};

struct kernfs_super_info___2 {
	struct super_block___130 *sb;
	struct kernfs_root___121 *root;
	const void *ns;
	struct list_head node;
};

struct kernfs_fs_context___4 {
	struct kernfs_root___2 *root;
	void *ns_tag;
	long unsigned int magic;
	bool new_sb_created;
};

struct config_group;

struct config_item_type;

struct config_item {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item *ci_parent;
	struct config_group *ci_group;
	const struct config_item_type *ci_type;
	struct dentry___124 *ci_dentry;
};

struct configfs_subsystem;

struct config_group {
	struct config_item cg_item;
	struct list_head cg_children;
	struct configfs_subsystem *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations;

struct configfs_group_operations;

struct configfs_attribute;

struct configfs_bin_attribute;

struct config_item_type {
	struct module___114 *ct_owner;
	struct configfs_item_operations *ct_item_ops;
	struct configfs_group_operations *ct_group_ops;
	struct configfs_attribute **ct_attrs;
	struct configfs_bin_attribute **ct_bin_attrs;
};

struct configfs_item_operations {
	void (*release)(struct config_item *);
	int (*allow_link)(struct config_item *, struct config_item *);
	void (*drop_link)(struct config_item *, struct config_item *);
};

struct configfs_group_operations {
	struct config_item * (*make_item)(struct config_group *, const char *);
	struct config_group * (*make_group)(struct config_group *, const char *);
	int (*commit_item)(struct config_item *);
	void (*disconnect_notify)(struct config_group *, struct config_item *);
	void (*drop_item)(struct config_group *, struct config_item *);
};

struct configfs_attribute {
	const char *ca_name;
	struct module___114 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item *, char *);
	ssize_t (*store)(struct config_item *, const char *, size_t);
};

struct configfs_bin_attribute {
	struct configfs_attribute cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item *, void *, size_t);
	ssize_t (*write)(struct config_item *, const void *, size_t);
};

struct configfs_subsystem {
	struct config_group su_group;
	struct mutex su_mutex;
};

struct configfs_fragment {
	atomic_t frag_count;
	struct rw_semaphore frag_sem;
	bool frag_dead;
};

struct configfs_dirent {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	int s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___124 *s_dentry;
	struct iattr___124 *s_iattr;
	struct configfs_fragment *s_frag;
};

struct config_group___2;

struct config_item_type___2;

struct config_item___2 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___2 *ci_parent;
	struct config_group___2 *ci_group;
	const struct config_item_type___2 *ci_type;
	struct dentry___130 *ci_dentry;
};

struct configfs_subsystem___2;

struct config_group___2 {
	struct config_item___2 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___2 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___2;

struct configfs_group_operations___2;

struct configfs_attribute___2;

struct configfs_bin_attribute___2;

struct config_item_type___2 {
	struct module___119 *ct_owner;
	struct configfs_item_operations___2 *ct_item_ops;
	struct configfs_group_operations___2 *ct_group_ops;
	struct configfs_attribute___2 **ct_attrs;
	struct configfs_bin_attribute___2 **ct_bin_attrs;
};

struct configfs_item_operations___2 {
	void (*release)(struct config_item___2 *);
	int (*allow_link)(struct config_item___2 *, struct config_item___2 *);
	void (*drop_link)(struct config_item___2 *, struct config_item___2 *);
};

struct configfs_group_operations___2 {
	struct config_item___2 * (*make_item)(struct config_group___2 *, const char *);
	struct config_group___2 * (*make_group)(struct config_group___2 *, const char *);
	int (*commit_item)(struct config_item___2 *);
	void (*disconnect_notify)(struct config_group___2 *, struct config_item___2 *);
	void (*drop_item)(struct config_group___2 *, struct config_item___2 *);
};

struct configfs_attribute___2 {
	const char *ca_name;
	struct module___119 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___2 *, char *);
	ssize_t (*store)(struct config_item___2 *, const char *, size_t);
};

struct configfs_bin_attribute___2 {
	struct configfs_attribute___2 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___2 *, void *, size_t);
	ssize_t (*write)(struct config_item___2 *, const void *, size_t);
};

struct configfs_subsystem___2 {
	struct config_group___2 su_group;
	struct mutex su_mutex;
};

struct configfs_dirent___2 {
	atomic_t s_count;
	int s_dependent_count;
	struct list_head s_sibling;
	struct list_head s_children;
	int s_links;
	void *s_element;
	int s_type;
	umode_t s_mode;
	struct dentry___130 *s_dentry;
	struct iattr___130 *s_iattr;
	struct configfs_fragment *s_frag;
};

struct configfs_buffer {
	size_t count;
	loff_t pos;
	char *page;
	struct configfs_item_operations___2 *ops;
	struct mutex mutex;
	int needs_read_fill;
	bool read_in_progress;
	bool write_in_progress;
	char *bin_buffer;
	int bin_buffer_size;
	int cb_max_size;
	struct config_item___2 *item;
	struct module___119 *owner;
	union {
		struct configfs_attribute___2 *attr;
		struct configfs_bin_attribute___2 *bin_attr;
	};
};

struct module_version_attribute___2 {
	struct module_attribute___118 mattr;
	const char *module_name;
	const char *version;
};

struct pts_mount_opts {
	int setuid;
	int setgid;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
	umode_t ptmxmode;
	int reserve;
	int max;
};

enum {
	Opt_uid___2 = 0,
	Opt_gid___3 = 1,
	Opt_mode___2 = 2,
	Opt_ptmxmode = 3,
	Opt_newinstance = 4,
	Opt_max = 5,
	Opt_err = 6,
};

struct pts_fs_info {
	struct ida allocated_ptys;
	struct pts_mount_opts mount_opts;
	struct super_block___124 *sb;
	struct dentry___124 *ptmx_dentry;
};

struct dentry___131;

struct super_block___131;

struct module___120;

struct file_system_type___131 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___131 * (*mount)(struct file_system_type___131 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___131 *);
	struct module___120 *owner;
	struct file_system_type___131 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___131;

struct kiocb___131;

struct iov_iter___72;

struct vm_area_struct___136;

struct inode___131;

struct file_lock___131;

struct page___136;

struct seq_file___114;

struct file_operations___131 {
	struct module___120 *owner;
	loff_t (*llseek)(struct file___131 *, loff_t, int);
	ssize_t (*read)(struct file___131 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___131 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___131 *, struct iov_iter___72 *);
	ssize_t (*write_iter)(struct kiocb___131 *, struct iov_iter___72 *);
	int (*iopoll)(struct kiocb___131 *, bool);
	int (*iterate)(struct file___131 *, struct dir_context *);
	int (*iterate_shared)(struct file___131 *, struct dir_context *);
	__poll_t (*poll)(struct file___131 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___131 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___131 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___131 *, struct vm_area_struct___136 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___131 *, struct file___131 *);
	int (*flush)(struct file___131 *, fl_owner_t);
	int (*release)(struct inode___131 *, struct file___131 *);
	int (*fsync)(struct file___131 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___131 *, int);
	int (*lock)(struct file___131 *, int, struct file_lock___131 *);
	ssize_t (*sendpage)(struct file___131 *, struct page___136 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___131 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___131 *, long unsigned int);
	int (*flock)(struct file___131 *, int, struct file_lock___131 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___131 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___131 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___131 *, long int, struct file_lock___131 **, void **);
	long int (*fallocate)(struct file___131 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___114 *, struct file___131 *);
	ssize_t (*copy_file_range)(struct file___131 *, loff_t, struct file___131 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___131 *, loff_t, struct file___131 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___131 *, loff_t, loff_t, int);
};

struct vmacache___136 {
	u64 seqnum;
	struct vm_area_struct___136 *vmas[4];
};

struct page_frag___136 {
	struct page___136 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___137;

struct pid___116;

struct nsproxy___122;

struct signal_struct___132;

struct bio_list___58;

struct backing_dev_info___56;

struct io_context___58;

struct css_set___93;

struct mem_cgroup___50;

struct request_queue___58;

struct vm_struct___118;

struct task_struct___138 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___138 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___137 *mm;
	struct mm_struct___137 *active_mm;
	struct vmacache___136 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___138 *real_parent;
	struct task_struct___138 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___138 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___116 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___122 *nsproxy;
	struct signal_struct___132 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___138 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___58 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___56 *backing_dev_info;
	struct io_context___58 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___93 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___136 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___50 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___50 *active_memcg;
	struct request_queue___58 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___138 *oom_reaper_list;
	struct vm_struct___118 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___122;

struct kobj_type___122;

struct kernfs_node___122;

struct kobject___122 {
	const char *name;
	struct list_head entry;
	struct kobject___122 *parent;
	struct kset___122 *kset;
	struct kobj_type___122 *ktype;
	struct kernfs_node___122 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___119 {
	struct kobject___122 kobj;
	struct module___120 *mod;
	struct kobject___122 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___119 {
	struct module___120 *mod;
	struct latch_tree_node node;
};

struct module_layout___119 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___119 mtn;
};

struct module_attribute___119;

struct kernel_param___119;

struct module___120 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___119 mkobj;
	struct module_attribute___119 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___122 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___119 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___119 core_layout;
	struct module_layout___119 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___131;

struct dentry___131 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___131 *d_parent;
	struct qstr d_name;
	struct inode___131 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___131 *d_op;
	struct super_block___131 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___131;

struct address_space___131 {
	struct inode___131 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___131 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___131;

struct bdi_writeback___56;

struct inode___131 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___131 *i_op;
	struct super_block___131 *i_sb;
	struct address_space___131 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___56 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___131 *i_fop;
		void (*free_inode)(struct inode___131 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___131 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___131;

struct path___131;

struct dentry_operations___131 {
	int (*d_revalidate)(struct dentry___131 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___131 *, unsigned int);
	int (*d_hash)(const struct dentry___131 *, struct qstr *);
	int (*d_compare)(const struct dentry___131 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___131 *);
	int (*d_init)(struct dentry___131 *);
	void (*d_release)(struct dentry___131 *);
	void (*d_prune)(struct dentry___131 *);
	void (*d_iput)(struct dentry___131 *, struct inode___131 *);
	char * (*d_dname)(struct dentry___131 *, char *, int);
	struct vfsmount___131 * (*d_automount)(struct path___131 *);
	int (*d_manage)(const struct path___131 *, bool);
	struct dentry___131 * (*d_real)(struct dentry___131 *, const struct inode___131 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___131;

struct mem_dqinfo___131 {
	struct quota_format_type___131 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___131;

struct quota_info___131 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___131 *files[3];
	struct mem_dqinfo___131 info[3];
	const struct quota_format_ops___131 *ops[3];
};

struct rcuwait___132 {
	struct task_struct___138 *task;
};

struct percpu_rw_semaphore___132 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___132 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___131 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___132 rw_sem[3];
};

struct shrink_control___50;

struct shrinker___50 {
	long unsigned int (*count_objects)(struct shrinker___50 *, struct shrink_control___50 *);
	long unsigned int (*scan_objects)(struct shrinker___50 *, struct shrink_control___50 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___131;

struct dquot_operations___131;

struct quotactl_ops___131;

struct fscrypt_operations___7;

struct fsverity_operations___5;

struct block_device___59;

struct super_block___131 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___131 *s_type;
	const struct super_operations___131 *s_op;
	const struct dquot_operations___131 *dq_op;
	const struct quotactl_ops___131 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___131 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___7 *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___5 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___59 *s_bdev;
	struct backing_dev_info___56 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___131 s_dquot;
	struct sb_writers___131 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___131 *s_d_op;
	int cleancache_poolid;
	struct shrinker___50 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___131 {
	struct dentry___131 *mnt_root;
	struct super_block___131 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___131 {
	struct vfsmount___131 *mnt;
	struct dentry___131 *dentry;
};

struct pid_namespace___116;

struct upid___116 {
	int nr;
	struct pid_namespace___116 *ns;
};

struct pid_namespace___116 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___138 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___116 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___116 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___116 numbers[1];
};

typedef struct page___136 *pgtable_t___136;

struct dev_pagemap___129;

struct page___136 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___131 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___136 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___136 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___137 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___129 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___129;

struct vm_area_struct___136 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___136 *vm_next;
	struct vm_area_struct___136 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___137 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___129 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___131 *vm_file;
	struct file___131 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___132 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___138 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___138 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___116 *pids[4];
	struct pid___116 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___137 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___136;

struct mm_struct___137 {
	struct {
		struct vm_area_struct___136 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___131 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___136 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___138 *owner;
		struct user_namespace___19 *user_ns;
		struct file___131 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___93;

struct nsproxy___122 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___116 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___93 *cgroup_ns;
};

struct bio___58;

struct bio_list___58 {
	struct bio___58 *head;
	struct bio___58 *tail;
};

struct cgroup_subsys_state___93;

struct bdi_writeback___56 {
	struct backing_dev_info___56 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___93 *memcg_css;
	struct cgroup_subsys_state___93 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___96;

struct backing_dev_info___56 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___56 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___96 *dev;
	char dev_name[64];
	struct device___96 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___131 *debug_dir;
};

struct io_cq___58;

struct io_context___58 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___58 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___93;

struct css_set___93 {
	struct cgroup_subsys_state___93 *subsys[14];
	refcount_t refcount;
	struct css_set___93 *dom_cset;
	struct cgroup___93 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___93 *mg_src_cgrp;
	struct cgroup___93 *mg_dst_cgrp;
	struct css_set___93 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___93;

struct cgroup_subsys_state___93 {
	struct cgroup___93 *cgroup;
	struct cgroup_subsys___93 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___93 *parent;
};

struct cgroup_file___93 {
	struct kernfs_node___122 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___50;

struct mem_cgroup_per_node___50;

struct mem_cgroup___50 {
	struct cgroup_subsys_state___93 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___93 events_file;
	struct cgroup_file___93 events_local_file;
	struct cgroup_file___93 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___50 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___138 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___50 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___58;

struct blk_integrity___58 {
	const struct blk_integrity_profile___58 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___58 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___58 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___58;

struct elevator_queue___58;

struct blk_mq_ops___56;

struct blk_mq_hw_ctx___56;

struct gendisk___58;

struct blkcg_gq___56;

struct blk_mq_tag_set___56;

struct request_queue___58 {
	struct request___58 *last_merge;
	struct elevator_queue___58 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___56 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___56 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___58 *disk;
	struct kobject___122 kobj;
	struct kobject___122 *mq_kobj;
	struct blk_integrity___58 integrity;
	struct device___96 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___56 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___56 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___58 bio_split;
	struct dentry___131 *debugfs_dir;
	struct dentry___131 *sched_debugfs_dir;
	struct dentry___131 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___118 {
	struct vm_struct___118 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___136 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___50 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___50 *memcg;
};

struct dev_pagemap_ops___129;

struct dev_pagemap___129 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___129 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___116 {
	rwlock_t lock;
	struct pid___116 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___131 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___131 f_path;
	struct inode___131 *f_inode;
	const struct file_operations___131 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___116 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___131 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___129;

struct vm_operations_struct___129 {
	void (*open)(struct vm_area_struct___136 *);
	void (*close)(struct vm_area_struct___136 *);
	int (*may_split)(struct vm_area_struct___136 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___136 *);
	int (*mprotect)(struct vm_area_struct___136 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___129 *);
	vm_fault_t (*huge_fault)(struct vm_fault___129 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___129 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___136 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___129 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___129 *);
	int (*access)(struct vm_area_struct___136 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___136 *);
	int (*set_policy)(struct vm_area_struct___136 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___136 *, long unsigned int);
	struct page___136 * (*find_special_page)(struct vm_area_struct___136 *, long unsigned int);
};

struct core_thread___136 {
	struct task_struct___138 *task;
	struct core_thread___136 *next;
};

struct core_state___136 {
	atomic_t nr_threads;
	struct core_thread___136 dumper;
	struct completion startup;
};

struct vm_fault___129 {
	const struct {
		struct vm_area_struct___136 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___136 *cow_page;
	struct page___136 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___136 prealloc_pte;
};

struct pglist_data___57;

struct lruvec___57 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___57 *pgdat;
};

struct zone___57 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___57 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___57 {
	struct zone___57 *zone;
	int zone_idx;
};

struct zonelist___57 {
	struct zoneref___57 _zonerefs[321];
};

struct pglist_data___57 {
	struct zone___57 node_zones[5];
	struct zonelist___57 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___138 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___138 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___57 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___93 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___138 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___93;

struct cgroup_rstat_cpu___93;

struct cgroup___93 {
	struct cgroup_subsys_state___93 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___122 *kn;
	struct cgroup_file___93 procs_file;
	struct cgroup_file___93 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___93 *subsys[14];
	struct cgroup_root___93 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___93 *dom_cgrp;
	struct cgroup___93 *old_dom_cgrp;
	struct cgroup_rstat_cpu___93 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___93 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___58 {
	struct request_queue___58 *q;
	struct io_context___58 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___4;

typedef void bh_end_io_t___4(struct buffer_head___4 *, int);

struct buffer_head___4 {
	long unsigned int b_state;
	struct buffer_head___4 *b_this_page;
	struct page___136 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___59 *b_bdev;
	bh_end_io_t___4 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___131 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___60;

struct kiocb___131 {
	struct file___131 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___131 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___60 *ki_waitq;
	};
};

struct iattr___131 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___131 *ia_file;
};

struct dquot___131 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___131 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___131 {
	int qf_fmt_id;
	const struct quota_format_ops___131 *qf_ops;
	struct module___120 *qf_owner;
	struct quota_format_type___131 *qf_next;
};

struct quota_format_ops___131 {
	int (*check_quota_file)(struct super_block___131 *, int);
	int (*read_file_info)(struct super_block___131 *, int);
	int (*write_file_info)(struct super_block___131 *, int);
	int (*free_file_info)(struct super_block___131 *, int);
	int (*read_dqblk)(struct dquot___131 *);
	int (*commit_dqblk)(struct dquot___131 *);
	int (*release_dqblk)(struct dquot___131 *);
	int (*get_next_id)(struct super_block___131 *, struct kqid *);
};

struct dquot_operations___131 {
	int (*write_dquot)(struct dquot___131 *);
	struct dquot___131 * (*alloc_dquot)(struct super_block___131 *, int);
	void (*destroy_dquot)(struct dquot___131 *);
	int (*acquire_dquot)(struct dquot___131 *);
	int (*release_dquot)(struct dquot___131 *);
	int (*mark_dirty)(struct dquot___131 *);
	int (*write_info)(struct super_block___131 *, int);
	qsize_t * (*get_reserved_space)(struct inode___131 *);
	int (*get_projid)(struct inode___131 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___131 *, qsize_t *);
	int (*get_next_id)(struct super_block___131 *, struct kqid *);
};

struct quotactl_ops___131 {
	int (*quota_on)(struct super_block___131 *, int, int, const struct path___131 *);
	int (*quota_off)(struct super_block___131 *, int);
	int (*quota_enable)(struct super_block___131 *, unsigned int);
	int (*quota_disable)(struct super_block___131 *, unsigned int);
	int (*quota_sync)(struct super_block___131 *, int);
	int (*set_info)(struct super_block___131 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___131 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___131 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___131 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___131 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___131 *, unsigned int);
};

struct wait_page_queue___60 {
	struct page___136 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___56;

struct readahead_control___60;

struct swap_info_struct___32;

struct address_space_operations___131 {
	int (*writepage)(struct page___136 *, struct writeback_control___56 *);
	int (*readpage)(struct file___131 *, struct page___136 *);
	int (*writepages)(struct address_space___131 *, struct writeback_control___56 *);
	int (*set_page_dirty)(struct page___136 *);
	int (*readpages)(struct file___131 *, struct address_space___131 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___60 *);
	int (*write_begin)(struct file___131 *, struct address_space___131 *, loff_t, unsigned int, unsigned int, struct page___136 **, void **);
	int (*write_end)(struct file___131 *, struct address_space___131 *, loff_t, unsigned int, unsigned int, struct page___136 *, void *);
	sector_t (*bmap)(struct address_space___131 *, sector_t);
	void (*invalidatepage)(struct page___136 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___136 *, gfp_t);
	void (*freepage)(struct page___136 *);
	ssize_t (*direct_IO)(struct kiocb___131 *, struct iov_iter___72 *);
	int (*migratepage)(struct address_space___131 *, struct page___136 *, struct page___136 *, enum migrate_mode);
	bool (*isolate_page)(struct page___136 *, isolate_mode_t);
	void (*putback_page)(struct page___136 *);
	int (*launder_page)(struct page___136 *);
	int (*is_partially_uptodate)(struct page___136 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___136 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___131 *, struct page___136 *);
	int (*swap_activate)(struct swap_info_struct___32 *, struct file___131 *, sector_t *);
	void (*swap_deactivate)(struct file___131 *);
};

struct writeback_control___56 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___56 *wb;
	struct inode___131 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___60 {
	struct file___131 *file;
	struct address_space___131 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___70;

struct iov_iter___72 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___70 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___32 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___59 *bdev;
	struct file___131 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___131 {
	struct dentry___131 * (*lookup)(struct inode___131 *, struct dentry___131 *, unsigned int);
	const char * (*get_link)(struct dentry___131 *, struct inode___131 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___131 *, int);
	struct posix_acl * (*get_acl)(struct inode___131 *, int, bool);
	int (*readlink)(struct dentry___131 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___131 *, struct dentry___131 *, umode_t, bool);
	int (*link)(struct dentry___131 *, struct inode___131 *, struct dentry___131 *);
	int (*unlink)(struct inode___131 *, struct dentry___131 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___131 *, struct dentry___131 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___131 *, struct dentry___131 *, umode_t);
	int (*rmdir)(struct inode___131 *, struct dentry___131 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___131 *, struct dentry___131 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___131 *, struct dentry___131 *, struct inode___131 *, struct dentry___131 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___131 *, struct iattr___131 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___131 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___131 *, char *, size_t);
	int (*fiemap)(struct inode___131 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___131 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___131 *, struct dentry___131 *, struct file___131 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___131 *, struct dentry___131 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___131 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___131 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___131 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___131 {
	void (*fl_copy_lock)(struct file_lock___131 *, struct file_lock___131 *);
	void (*fl_release_private)(struct file_lock___131 *);
};

struct fasync_struct___131;

struct lock_manager_operations___131;

struct file_lock___131 {
	struct file_lock___131 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___131 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___131 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___131 *fl_ops;
	const struct lock_manager_operations___131 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___131 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___131 *);
	int (*lm_grant)(struct file_lock___131 *, int);
	bool (*lm_break)(struct file_lock___131 *);
	int (*lm_change)(struct file_lock___131 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___131 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___131 *);
};

struct fasync_struct___131 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___131 *fa_next;
	struct file___131 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___131 {
	struct inode___131 * (*alloc_inode)(struct super_block___131 *);
	void (*destroy_inode)(struct inode___131 *);
	void (*free_inode)(struct inode___131 *);
	void (*dirty_inode)(struct inode___131 *, int);
	int (*write_inode)(struct inode___131 *, struct writeback_control___56 *);
	int (*drop_inode)(struct inode___131 *);
	void (*evict_inode)(struct inode___131 *);
	void (*put_super)(struct super_block___131 *);
	int (*sync_fs)(struct super_block___131 *, int);
	int (*freeze_super)(struct super_block___131 *);
	int (*freeze_fs)(struct super_block___131 *);
	int (*thaw_super)(struct super_block___131 *);
	int (*unfreeze_fs)(struct super_block___131 *);
	int (*statfs)(struct dentry___131 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___131 *, int *, char *);
	void (*umount_begin)(struct super_block___131 *);
	int (*show_options)(struct seq_file___114 *, struct dentry___131 *);
	int (*show_devname)(struct seq_file___114 *, struct dentry___131 *);
	int (*show_path)(struct seq_file___114 *, struct dentry___131 *);
	int (*show_stats)(struct seq_file___114 *, struct dentry___131 *);
	ssize_t (*quota_read)(struct super_block___131 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___131 *, int, const char *, size_t, loff_t);
	struct dquot___131 ** (*get_dquots)(struct inode___131 *);
	long int (*nr_cached_objects)(struct super_block___131 *, struct shrink_control___50 *);
	long int (*free_cached_objects)(struct super_block___131 *, struct shrink_control___50 *);
	struct file___131 * (*real_loop)(struct file___131 *);
};

struct fscrypt_operations___7 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___131 *, void *, size_t);
	int (*set_context)(struct inode___131 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___131 *);
	bool (*empty_dir)(struct inode___131 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___131 *);
	void (*get_ino_and_lblk_bits)(struct super_block___131 *, int *, int *);
	int (*get_num_devices)(struct super_block___131 *);
	void (*get_devices)(struct super_block___131 *, struct request_queue___58 **);
};

struct fsverity_operations___5 {
	int (*begin_enable_verity)(struct file___131 *);
	int (*end_enable_verity)(struct file___131 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___131 *, void *, size_t);
	struct page___136 * (*read_merkle_tree_page)(struct inode___131 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___131 *, const void *, u64, int);
};

struct wakeup_source___96;

struct dev_pm_info___96 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___96 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___96 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___96;

struct bus_type___96;

struct device_driver___96;

struct dev_pm_domain___96;

struct fwnode_handle___96;

struct class___96;

struct attribute_group___122;

struct device___96 {
	struct kobject___122 kobj;
	struct device___96 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___96 *type;
	struct bus_type___96 *bus;
	struct device_driver___96 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___96 power;
	struct dev_pm_domain___96 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___96 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___96 *class;
	const struct attribute_group___122 **groups;
	void (*release)(struct device___96 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___59 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___131 *bd_inode;
	struct super_block___131 *bd_super;
	void *bd_claiming;
	struct device___96 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___122 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___58 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___131 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___114;

struct seq_file___114 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___114 *op;
	int poll_event;
	const struct file___131 *file;
	void *private;
};

typedef void bio_end_io_t___58(struct bio___58 *);

struct bio_vec___70 {
	struct page___136 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___58;

struct bio___58 {
	struct bio___58 *bi_next;
	struct block_device___59 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___58 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___56 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___58 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___70 *bi_io_vec;
	struct bio_set___58 *bi_pool;
	struct bio_vec___70 bi_inline_vecs[0];
};

struct dev_pagemap_ops___129 {
	void (*page_free)(struct page___136 *);
	void (*kill)(struct dev_pagemap___129 *);
	void (*cleanup)(struct dev_pagemap___129 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___129 *);
};

struct fwnode_operations___96;

struct fwnode_handle___96 {
	struct fwnode_handle___96 *secondary;
	const struct fwnode_operations___96 *ops;
	struct device___96 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___96;

struct fwnode_endpoint___96;

struct fwnode_operations___96 {
	struct fwnode_handle___96 * (*get)(struct fwnode_handle___96 *);
	void (*put)(struct fwnode_handle___96 *);
	bool (*device_is_available)(const struct fwnode_handle___96 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___96 *, const struct device___96 *);
	bool (*property_present)(const struct fwnode_handle___96 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___96 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___96 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___96 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*get_parent)(const struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*get_next_child_node)(const struct fwnode_handle___96 *, struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*get_named_child_node)(const struct fwnode_handle___96 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___96 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___96 *);
	struct fwnode_handle___96 * (*graph_get_next_endpoint)(const struct fwnode_handle___96 *, struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*graph_get_remote_endpoint)(const struct fwnode_handle___96 *);
	struct fwnode_handle___96 * (*graph_get_port_parent)(struct fwnode_handle___96 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___96 *, struct fwnode_endpoint___96 *);
	int (*add_links)(struct fwnode_handle___96 *);
};

struct fwnode_endpoint___96 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___96 *local_fwnode;
};

struct fwnode_reference_args___96 {
	struct fwnode_handle___96 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___122;

struct kernfs_elem_dir___122 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___122 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___122;

struct kernfs_root___122 {
	struct kernfs_node___122 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___122 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___122 {
	struct kernfs_node___122 *target_kn;
};

struct kernfs_ops___122;

struct kernfs_elem_attr___122 {
	const struct kernfs_ops___122 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___122 *notify_next;
};

struct kernfs_node___122 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___122 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___122 dir;
		struct kernfs_elem_symlink___122 symlink;
		struct kernfs_elem_attr___122 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___122;

struct kernfs_ops___122 {
	int (*open)(struct kernfs_open_file___122 *);
	void (*release)(struct kernfs_open_file___122 *);
	int (*seq_show)(struct seq_file___114 *, void *);
	void * (*seq_start)(struct seq_file___114 *, loff_t *);
	void * (*seq_next)(struct seq_file___114 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___114 *, void *);
	ssize_t (*read)(struct kernfs_open_file___122 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___122 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___122 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___122 *, struct vm_area_struct___136 *);
};

struct kernfs_syscall_ops___122 {
	int (*show_options)(struct seq_file___114 *, struct kernfs_root___122 *);
	int (*mkdir)(struct kernfs_node___122 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___122 *);
	int (*rename)(struct kernfs_node___122 *, struct kernfs_node___122 *, const char *);
	int (*show_path)(struct seq_file___114 *, struct kernfs_node___122 *, struct kernfs_root___122 *);
};

struct kernfs_open_file___122 {
	struct kernfs_node___122 *kn;
	struct file___131 *file;
	struct seq_file___114 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___129 *vm_ops;
};

struct bin_attribute___122;

struct attribute_group___122 {
	const char *name;
	umode_t (*is_visible)(struct kobject___122 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___122 *, struct bin_attribute___122 *, int);
	struct attribute **attrs;
	struct bin_attribute___122 **bin_attrs;
};

struct bin_attribute___122 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___131 * (*f_mapping)();
	ssize_t (*read)(struct file___131 *, struct kobject___122 *, struct bin_attribute___122 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___131 *, struct kobject___122 *, struct bin_attribute___122 *, char *, loff_t, size_t);
	int (*mmap)(struct file___131 *, struct kobject___122 *, struct bin_attribute___122 *, struct vm_area_struct___136 *);
};

struct sysfs_ops___122 {
	ssize_t (*show)(struct kobject___122 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___122 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___122;

struct kset___122 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___122 kobj;
	const struct kset_uevent_ops___122 *uevent_ops;
};

struct kobj_type___122 {
	void (*release)(struct kobject___122 *);
	const struct sysfs_ops___122 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___122 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___122 *);
	const void * (*namespace)(struct kobject___122 *);
	void (*get_ownership)(struct kobject___122 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___122 {
	int (* const filter)(struct kset___122 *, struct kobject___122 *);
	const char * (* const name)(struct kset___122 *, struct kobject___122 *);
	int (* const uevent)(struct kset___122 *, struct kobject___122 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___119 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___119 *);
	int (*get)(char *, const struct kernel_param___119 *);
	void (*free)(void *);
};

struct kparam_array___119;

struct kernel_param___119 {
	const char *name;
	struct module___120 *mod;
	const struct kernel_param_ops___119 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___119 *arr;
	};
};

struct kparam_array___119 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___119 *ops;
	void *elem;
};

struct module_attribute___119 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___119 *, struct module_kobject___119 *, char *);
	ssize_t (*store)(struct module_attribute___119 *, struct module_kobject___119 *, const char *, size_t);
	void (*setup)(struct module___120 *, const char *);
	int (*test)(struct module___120 *);
	void (*free)(struct module___120 *);
};

struct cgroup_namespace___93 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___93 *root_cset;
};

struct dev_pm_ops___96 {
	int (*prepare)(struct device___96 *);
	void (*complete)(struct device___96 *);
	int (*suspend)(struct device___96 *);
	int (*resume)(struct device___96 *);
	int (*freeze)(struct device___96 *);
	int (*thaw)(struct device___96 *);
	int (*poweroff)(struct device___96 *);
	int (*restore)(struct device___96 *);
	int (*suspend_late)(struct device___96 *);
	int (*resume_early)(struct device___96 *);
	int (*freeze_late)(struct device___96 *);
	int (*thaw_early)(struct device___96 *);
	int (*poweroff_late)(struct device___96 *);
	int (*restore_early)(struct device___96 *);
	int (*suspend_noirq)(struct device___96 *);
	int (*resume_noirq)(struct device___96 *);
	int (*freeze_noirq)(struct device___96 *);
	int (*thaw_noirq)(struct device___96 *);
	int (*poweroff_noirq)(struct device___96 *);
	int (*restore_noirq)(struct device___96 *);
	int (*runtime_suspend)(struct device___96 *);
	int (*runtime_resume)(struct device___96 *);
	int (*runtime_idle)(struct device___96 *);
};

struct wakeup_source___96 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___96 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___96 {
	struct dev_pm_ops___96 ops;
	int (*start)(struct device___96 *);
	void (*detach)(struct device___96 *, bool);
	int (*activate)(struct device___96 *);
	void (*sync)(struct device___96 *);
	void (*dismiss)(struct device___96 *);
};

struct bus_type___96 {
	const char *name;
	const char *dev_name;
	struct device___96 *dev_root;
	const struct attribute_group___122 **bus_groups;
	const struct attribute_group___122 **dev_groups;
	const struct attribute_group___122 **drv_groups;
	int (*match)(struct device___96 *, struct device_driver___96 *);
	int (*uevent)(struct device___96 *, struct kobj_uevent_env *);
	int (*probe)(struct device___96 *);
	void (*sync_state)(struct device___96 *);
	void (*remove)(struct device___96 *);
	void (*shutdown)(struct device___96 *);
	int (*online)(struct device___96 *);
	int (*offline)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	int (*num_vf)(struct device___96 *);
	int (*dma_configure)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___96 {
	const char *name;
	struct bus_type___96 *bus;
	struct module___120 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___96 *);
	void (*sync_state)(struct device___96 *);
	int (*remove)(struct device___96 *);
	void (*shutdown)(struct device___96 *);
	int (*suspend)(struct device___96 *, pm_message_t);
	int (*resume)(struct device___96 *);
	const struct attribute_group___122 **groups;
	const struct attribute_group___122 **dev_groups;
	const struct dev_pm_ops___96 *pm;
	void (*coredump)(struct device___96 *);
	struct driver_private *p;
};

struct device_type___96 {
	const char *name;
	const struct attribute_group___122 **groups;
	int (*uevent)(struct device___96 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___96 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___96 *);
	const struct dev_pm_ops___96 *pm;
};

struct class___96 {
	const char *name;
	struct module___120 *owner;
	const struct attribute_group___122 **class_groups;
	const struct attribute_group___122 **dev_groups;
	struct kobject___122 *dev_kobj;
	int (*dev_uevent)(struct device___96 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___96 *, umode_t *);
	void (*class_release)(struct class___96 *);
	void (*dev_release)(struct device___96 *);
	int (*shutdown_pre)(struct device___96 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___96 *);
	void (*get_ownership)(struct device___96 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___96 *pm;
	struct subsys_private *p;
};

struct block_device_operations___58;

struct gendisk___58 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___59 *part0;
	const struct block_device_operations___58 *fops;
	struct request_queue___58 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___56 *bdi;
	struct kobject___122 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___122 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___58 {
	struct bio___58 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___70 *bip_vec;
	struct bio_vec___70 bip_inline_vecs[0];
};

struct blkcg___56;

struct blkg_policy_data___56;

struct blkcg_gq___56 {
	struct request_queue___58 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___56 *blkcg;
	struct blkcg_gq___56 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___56 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___58 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___58(struct request___58 *);

typedef void integrity_complete_fn___58(struct request___58 *, unsigned int);

struct blk_integrity_profile___58 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___58 *prepare_fn;
	integrity_complete_fn___58 *complete_fn;
	const char *name;
};

struct block_device_operations___58 {
	blk_qc_t (*submit_bio)(struct bio___58 *);
	int (*open)(struct block_device___59 *, fmode_t);
	void (*release)(struct gendisk___58 *, fmode_t);
	int (*rw_page)(struct block_device___59 *, sector_t, struct page___136 *, unsigned int);
	int (*ioctl)(struct block_device___59 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___59 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___58 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___58 *);
	int (*getgeo)(struct block_device___59 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___59 *, bool);
	void (*swap_slot_free_notify)(struct block_device___59 *, long unsigned int);
	int (*report_zones)(struct gendisk___58 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___58 *, umode_t *);
	struct module___120 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___58 *, sector_t *);
};

typedef void rq_end_io_fn___58(struct request___58 *, blk_status_t);

struct request___58 {
	struct request_queue___58 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___56 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___58 *bio;
	struct bio___58 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___70 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___58 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___58 *saved_end_io;
		} flush;
	};
	struct gendisk___58 *rq_disk;
	struct block_device___59 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___58 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___56 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___58 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___122 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___131 *debugfs_dir;
	struct dentry___131 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___58;

struct elevator_mq_ops___58 {
	int (*init_sched)(struct request_queue___58 *, struct elevator_type___58 *);
	void (*exit_sched)(struct elevator_queue___58 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___56 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___56 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___56 *);
	bool (*allow_merge)(struct request_queue___58 *, struct request___58 *, struct bio___58 *);
	bool (*bio_merge)(struct request_queue___58 *, struct bio___58 *, unsigned int);
	int (*request_merge)(struct request_queue___58 *, struct request___58 **, struct bio___58 *);
	void (*request_merged)(struct request_queue___58 *, struct request___58 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___58 *, struct request___58 *, struct request___58 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___58 *);
	void (*finish_request)(struct request___58 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___56 *, struct list_head *, bool);
	struct request___58 * (*dispatch_request)(struct blk_mq_hw_ctx___56 *);
	bool (*has_work)(struct blk_mq_hw_ctx___56 *);
	void (*completed_request)(struct request___58 *, u64);
	void (*requeue_request)(struct request___58 *);
	struct request___58 * (*former_request)(struct request_queue___58 *, struct request___58 *);
	struct request___58 * (*next_request)(struct request_queue___58 *, struct request___58 *);
	void (*init_icq)(struct io_cq___58 *);
	void (*exit_icq)(struct io_cq___58 *);
};

struct elv_fs_entry___58;

struct elevator_type___58 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___58 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___58 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___120 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___58 {
	struct elevator_type___58 *type;
	void *elevator_data;
	struct kobject___122 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___58 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___58 *, char *);
	ssize_t (*store)(struct elevator_queue___58 *, const char *, size_t);
};

struct blk_mq_queue_data___56;

struct blk_mq_ops___56 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___56 *, const struct blk_mq_queue_data___56 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___56 *);
	int (*get_budget)(struct request_queue___58 *);
	void (*put_budget)(struct request_queue___58 *, int);
	void (*set_rq_budget_token)(struct request___58 *, int);
	int (*get_rq_budget_token)(struct request___58 *);
	enum blk_eh_timer_return (*timeout)(struct request___58 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___56 *);
	void (*complete)(struct request___58 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___56 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___56 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___56 *, struct request___58 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___56 *, struct request___58 *, unsigned int);
	void (*initialize_rq_fn)(struct request___58 *);
	void (*cleanup_rq)(struct request___58 *);
	bool (*busy)(struct request_queue___58 *);
	int (*map_queues)(struct blk_mq_tag_set___56 *);
	void (*show_rq)(struct seq_file___114 *, struct request___58 *);
};

struct blk_mq_tag_set___56 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___56 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

typedef unsigned int tid_t;

struct transaction_chp_stats_s {
	long unsigned int cs_chp_time;
	__u32 cs_forced_to_close;
	__u32 cs_written;
	__u32 cs_dropped;
};

struct journal_s;

typedef struct journal_s journal_t;

struct journal_head;

struct transaction_s;

typedef struct transaction_s transaction_t;

struct transaction_s {
	journal_t *t_journal;
	tid_t t_tid;
	enum {
		T_RUNNING = 0,
		T_LOCKED = 1,
		T_SWITCH = 2,
		T_FLUSH = 3,
		T_COMMIT = 4,
		T_COMMIT_DFLUSH = 5,
		T_COMMIT_JFLUSH = 6,
		T_COMMIT_CALLBACK = 7,
		T_FINISHED = 8,
	} t_state;
	long unsigned int t_log_start;
	int t_nr_buffers;
	struct journal_head *t_reserved_list;
	struct journal_head *t_buffers;
	struct journal_head *t_forget;
	struct journal_head *t_checkpoint_list;
	struct journal_head *t_checkpoint_io_list;
	struct journal_head *t_shadow_list;
	struct list_head t_inode_list;
	spinlock_t t_handle_lock;
	long unsigned int t_max_wait;
	long unsigned int t_start;
	long unsigned int t_requested;
	struct transaction_chp_stats_s t_chp_stats;
	atomic_t t_updates;
	atomic_t t_outstanding_credits;
	atomic_t t_outstanding_revokes;
	atomic_t t_handle_count;
	transaction_t *t_cpnext;
	transaction_t *t_cpprev;
	long unsigned int t_expires;
	ktime_t t_start_time;
	unsigned int t_synchronous_commit: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int t_need_data_flush;
	struct list_head t_private_list;
};

struct jbd2_buffer_trigger_type;

struct journal_head {
	struct buffer_head___4 *b_bh;
	spinlock_t b_state_lock;
	int b_jcount;
	unsigned int b_jlist;
	unsigned int b_modified;
	char *b_frozen_data;
	char *b_committed_data;
	transaction_t *b_transaction;
	transaction_t *b_next_transaction;
	struct journal_head *b_tnext;
	struct journal_head *b_tprev;
	transaction_t *b_cp_transaction;
	struct journal_head *b_cpnext;
	struct journal_head *b_cpprev;
	struct jbd2_buffer_trigger_type *b_triggers;
	struct jbd2_buffer_trigger_type *b_frozen_triggers;
};

struct jbd2_buffer_trigger_type {
	void (*t_frozen)(struct jbd2_buffer_trigger_type *, struct buffer_head___4 *, void *, size_t);
	void (*t_abort)(struct jbd2_buffer_trigger_type *, struct buffer_head___4 *);
};

struct crypto_alg___5;

struct crypto_tfm___5 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___5 *);
	struct crypto_alg___5 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___5 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___5 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___5 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___5 *, u8 *, const u8 *);
};

struct compress_alg___5 {
	int (*coa_compress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___5 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___5 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___5 cipher;
		struct compress_alg___5 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___5 *);
	void (*cra_exit)(struct crypto_tfm___5 *);
	void (*cra_destroy)(struct crypto_alg___5 *);
	struct module___120 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___4 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___5 base;
};

struct jbd2_journal_handle;

typedef struct jbd2_journal_handle handle_t;

struct jbd2_journal_handle {
	union {
		transaction_t *h_transaction;
		journal_t *h_journal;
	};
	handle_t *h_rsv_handle;
	int h_total_credits;
	int h_revoke_credits;
	int h_revoke_credits_requested;
	int h_ref;
	int h_err;
	unsigned int h_sync: 1;
	unsigned int h_jdata: 1;
	unsigned int h_reserved: 1;
	unsigned int h_aborted: 1;
	unsigned int h_type: 8;
	unsigned int h_line_no: 16;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int h_start_jiffies;
	unsigned int h_requested_credits;
	unsigned int saved_alloc_context;
};

struct transaction_run_stats_s {
	long unsigned int rs_wait;
	long unsigned int rs_request_delay;
	long unsigned int rs_running;
	long unsigned int rs_locked;
	long unsigned int rs_flushing;
	long unsigned int rs_logging;
	__u32 rs_handle_count;
	__u32 rs_blocks;
	__u32 rs_blocks_logged;
};

struct transaction_stats_s {
	long unsigned int ts_tid;
	long unsigned int ts_requested;
	struct transaction_run_stats_s run;
};

enum passtype {
	PASS_SCAN = 0,
	PASS_REVOKE = 1,
	PASS_REPLAY = 2,
};

struct journal_superblock_s;

typedef struct journal_superblock_s journal_superblock_t;

struct jbd2_revoke_table_s;

struct jbd2_inode;

struct journal_s {
	long unsigned int j_flags;
	long unsigned int j_atomic_flags;
	int j_errno;
	struct mutex j_abort_mutex;
	struct buffer_head___4 *j_sb_buffer;
	journal_superblock_t *j_superblock;
	int j_format_version;
	rwlock_t j_state_lock;
	int j_barrier_count;
	struct mutex j_barrier;
	transaction_t *j_running_transaction;
	transaction_t *j_committing_transaction;
	transaction_t *j_checkpoint_transactions;
	wait_queue_head_t j_wait_transaction_locked;
	wait_queue_head_t j_wait_done_commit;
	wait_queue_head_t j_wait_commit;
	wait_queue_head_t j_wait_updates;
	wait_queue_head_t j_wait_reserved;
	wait_queue_head_t j_fc_wait;
	struct mutex j_checkpoint_mutex;
	struct buffer_head___4 *j_chkpt_bhs[64];
	struct shrinker___50 j_shrinker;
	struct percpu_counter j_checkpoint_jh_count;
	transaction_t *j_shrink_transaction;
	long unsigned int j_head;
	long unsigned int j_tail;
	long unsigned int j_free;
	long unsigned int j_first;
	long unsigned int j_last;
	long unsigned int j_fc_first;
	long unsigned int j_fc_off;
	long unsigned int j_fc_last;
	struct block_device___59 *j_dev;
	int j_blocksize;
	long long unsigned int j_blk_offset;
	char j_devname[56];
	struct block_device___59 *j_fs_dev;
	unsigned int j_total_len;
	atomic_t j_reserved_credits;
	spinlock_t j_list_lock;
	struct inode___131 *j_inode;
	tid_t j_tail_sequence;
	tid_t j_transaction_sequence;
	tid_t j_commit_sequence;
	tid_t j_commit_request;
	__u8 j_uuid[16];
	struct task_struct___138 *j_task;
	int j_max_transaction_buffers;
	int j_revoke_records_per_block;
	long unsigned int j_commit_interval;
	struct timer_list j_commit_timer;
	spinlock_t j_revoke_lock;
	struct jbd2_revoke_table_s *j_revoke;
	struct jbd2_revoke_table_s *j_revoke_table[2];
	struct buffer_head___4 **j_wbuf;
	struct buffer_head___4 **j_fc_wbuf;
	int j_wbufsize;
	int j_fc_wbufsize;
	pid_t j_last_sync_writer;
	u64 j_average_commit_time;
	u32 j_min_batch_time;
	u32 j_max_batch_time;
	void (*j_commit_callback)(journal_t *, transaction_t *);
	int (*j_submit_inode_data_buffers)(struct jbd2_inode *);
	int (*j_finish_inode_data_buffers)(struct jbd2_inode *);
	spinlock_t j_history_lock;
	struct proc_dir_entry *j_proc_entry;
	struct transaction_stats_s j_stats;
	unsigned int j_failed_commit;
	void *j_private;
	struct crypto_shash___4 *j_chksum_driver;
	__u32 j_csum_seed;
	void (*j_fc_cleanup_callback)(struct journal_s *, int, tid_t);
	int (*j_fc_replay_callback)(struct journal_s *, struct buffer_head___4 *, enum passtype, int, tid_t);
};

struct journal_header_s {
	__be32 h_magic;
	__be32 h_blocktype;
	__be32 h_sequence;
};

typedef struct journal_header_s journal_header_t;

struct journal_superblock_s {
	journal_header_t s_header;
	__be32 s_blocksize;
	__be32 s_maxlen;
	__be32 s_first;
	__be32 s_sequence;
	__be32 s_start;
	__be32 s_errno;
	__be32 s_feature_compat;
	__be32 s_feature_incompat;
	__be32 s_feature_ro_compat;
	__u8 s_uuid[16];
	__be32 s_nr_users;
	__be32 s_dynsuper;
	__be32 s_max_transaction;
	__be32 s_max_trans_data;
	__u8 s_checksum_type;
	__u8 s_padding2[3];
	__be32 s_num_fc_blks;
	__u32 s_padding[41];
	__be32 s_checksum;
	__u8 s_users[768];
};

enum jbd_state_bits {
	BH_JBD = 16,
	BH_JWrite = 17,
	BH_Freed = 18,
	BH_Revoked = 19,
	BH_RevokeValid = 20,
	BH_JBDDirty = 21,
	BH_JournalHead = 22,
	BH_Shadow = 23,
	BH_Verified = 24,
	BH_JBDPrivateStart = 25,
};

struct jbd2_inode {
	transaction_t *i_transaction;
	transaction_t *i_next_transaction;
	struct list_head i_list;
	struct inode___131 *i_vfs_inode;
	long unsigned int i_flags;
	loff_t i_dirty_start;
	loff_t i_dirty_end;
};

struct bgl_lock {
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blockgroup_lock {
	struct bgl_lock locks[128];
};

typedef int ext4_grpblk_t;

typedef long long unsigned int ext4_fsblk_t;

typedef __u32 ext4_lblk_t;

typedef unsigned int ext4_group_t;

struct ext4_allocation_request {
	struct inode___131 *inode;
	unsigned int len;
	ext4_lblk_t logical;
	ext4_lblk_t lleft;
	ext4_lblk_t lright;
	ext4_fsblk_t goal;
	ext4_fsblk_t pleft;
	ext4_fsblk_t pright;
	unsigned int flags;
};

struct ext4_system_blocks {
	struct rb_root root;
	struct callback_head rcu;
};

struct ext4_group_desc {
	__le32 bg_block_bitmap_lo;
	__le32 bg_inode_bitmap_lo;
	__le32 bg_inode_table_lo;
	__le16 bg_free_blocks_count_lo;
	__le16 bg_free_inodes_count_lo;
	__le16 bg_used_dirs_count_lo;
	__le16 bg_flags;
	__le32 bg_exclude_bitmap_lo;
	__le16 bg_block_bitmap_csum_lo;
	__le16 bg_inode_bitmap_csum_lo;
	__le16 bg_itable_unused_lo;
	__le16 bg_checksum;
	__le32 bg_block_bitmap_hi;
	__le32 bg_inode_bitmap_hi;
	__le32 bg_inode_table_hi;
	__le16 bg_free_blocks_count_hi;
	__le16 bg_free_inodes_count_hi;
	__le16 bg_used_dirs_count_hi;
	__le16 bg_itable_unused_hi;
	__le32 bg_exclude_bitmap_hi;
	__le16 bg_block_bitmap_csum_hi;
	__le16 bg_inode_bitmap_csum_hi;
	__u32 bg_reserved;
};

struct flex_groups {
	atomic64_t free_clusters;
	atomic_t free_inodes;
	atomic_t used_dirs;
};

struct extent_status {
	struct rb_node rb_node;
	ext4_lblk_t es_lblk;
	ext4_lblk_t es_len;
	ext4_fsblk_t es_pblk;
};

struct ext4_es_tree {
	struct rb_root root;
	struct extent_status *cache_es;
};

struct ext4_es_stats {
	long unsigned int es_stats_shrunk;
	struct percpu_counter es_stats_cache_hits;
	struct percpu_counter es_stats_cache_misses;
	u64 es_stats_scan_time;
	u64 es_stats_max_scan_time;
	struct percpu_counter es_stats_all_cnt;
	struct percpu_counter es_stats_shk_cnt;
};

struct ext4_pending_tree {
	struct rb_root root;
};

struct ext4_fc_stats {
	unsigned int fc_ineligible_reason_count[10];
	long unsigned int fc_num_commits;
	long unsigned int fc_ineligible_commits;
	long unsigned int fc_failed_commits;
	long unsigned int fc_skipped_commits;
	long unsigned int fc_numblks;
	u64 s_fc_avg_commit_time;
};

struct ext4_fc_alloc_region {
	ext4_lblk_t lblk;
	ext4_fsblk_t pblk;
	int ino;
	int len;
};

struct ext4_fc_replay_state {
	int fc_replay_num_tags;
	int fc_replay_expected_off;
	int fc_current_pass;
	int fc_cur_tag;
	int fc_crc;
	struct ext4_fc_alloc_region *fc_regions;
	int fc_regions_size;
	int fc_regions_used;
	int fc_regions_valid;
	int *fc_modified_inodes;
	int fc_modified_inodes_used;
	int fc_modified_inodes_size;
};

struct ext4_inode_info {
	__le32 i_data[15];
	__u32 i_dtime;
	ext4_fsblk_t i_file_acl;
	ext4_group_t i_block_group;
	ext4_lblk_t i_dir_start_lookup;
	long unsigned int i_flags;
	struct rw_semaphore xattr_sem;
	union {
		struct list_head i_orphan;
		unsigned int i_orphan_idx;
	};
	struct list_head i_fc_list;
	ext4_lblk_t i_fc_lblk_start;
	ext4_lblk_t i_fc_lblk_len;
	atomic_t i_fc_updates;
	wait_queue_head_t i_fc_wait;
	struct mutex i_fc_lock;
	loff_t i_disksize;
	struct rw_semaphore i_data_sem;
	struct inode___131 vfs_inode;
	struct jbd2_inode *jinode;
	spinlock_t i_raw_lock;
	struct timespec64 i_crtime;
	atomic_t i_prealloc_active;
	struct list_head i_prealloc_list;
	spinlock_t i_prealloc_lock;
	struct ext4_es_tree i_es_tree;
	rwlock_t i_es_lock;
	struct list_head i_es_list;
	unsigned int i_es_all_nr;
	unsigned int i_es_shk_nr;
	ext4_lblk_t i_es_shrink_lblk;
	ext4_group_t i_last_alloc_group;
	unsigned int i_reserved_data_blocks;
	struct ext4_pending_tree i_pending_tree;
	__u16 i_extra_isize;
	u16 i_inline_off;
	u16 i_inline_size;
	qsize_t i_reserved_quota;
	spinlock_t i_completed_io_lock;
	struct list_head i_rsv_conversion_list;
	struct work_struct i_rsv_conversion_work;
	atomic_t i_unwritten;
	spinlock_t i_block_reservation_lock;
	tid_t i_sync_tid;
	tid_t i_datasync_tid;
	struct dquot___131 *i_dquot[3];
	__u32 i_csum_seed;
	kprojid_t i_projid;
};

struct ext4_super_block {
	__le32 s_inodes_count;
	__le32 s_blocks_count_lo;
	__le32 s_r_blocks_count_lo;
	__le32 s_free_blocks_count_lo;
	__le32 s_free_inodes_count;
	__le32 s_first_data_block;
	__le32 s_log_block_size;
	__le32 s_log_cluster_size;
	__le32 s_blocks_per_group;
	__le32 s_clusters_per_group;
	__le32 s_inodes_per_group;
	__le32 s_mtime;
	__le32 s_wtime;
	__le16 s_mnt_count;
	__le16 s_max_mnt_count;
	__le16 s_magic;
	__le16 s_state;
	__le16 s_errors;
	__le16 s_minor_rev_level;
	__le32 s_lastcheck;
	__le32 s_checkinterval;
	__le32 s_creator_os;
	__le32 s_rev_level;
	__le16 s_def_resuid;
	__le16 s_def_resgid;
	__le32 s_first_ino;
	__le16 s_inode_size;
	__le16 s_block_group_nr;
	__le32 s_feature_compat;
	__le32 s_feature_incompat;
	__le32 s_feature_ro_compat;
	__u8 s_uuid[16];
	char s_volume_name[16];
	char s_last_mounted[64];
	__le32 s_algorithm_usage_bitmap;
	__u8 s_prealloc_blocks;
	__u8 s_prealloc_dir_blocks;
	__le16 s_reserved_gdt_blocks;
	__u8 s_journal_uuid[16];
	__le32 s_journal_inum;
	__le32 s_journal_dev;
	__le32 s_last_orphan;
	__le32 s_hash_seed[4];
	__u8 s_def_hash_version;
	__u8 s_jnl_backup_type;
	__le16 s_desc_size;
	__le32 s_default_mount_opts;
	__le32 s_first_meta_bg;
	__le32 s_mkfs_time;
	__le32 s_jnl_blocks[17];
	__le32 s_blocks_count_hi;
	__le32 s_r_blocks_count_hi;
	__le32 s_free_blocks_count_hi;
	__le16 s_min_extra_isize;
	__le16 s_want_extra_isize;
	__le32 s_flags;
	__le16 s_raid_stride;
	__le16 s_mmp_update_interval;
	__le64 s_mmp_block;
	__le32 s_raid_stripe_width;
	__u8 s_log_groups_per_flex;
	__u8 s_checksum_type;
	__u8 s_encryption_level;
	__u8 s_reserved_pad;
	__le64 s_kbytes_written;
	__le32 s_snapshot_inum;
	__le32 s_snapshot_id;
	__le64 s_snapshot_r_blocks_count;
	__le32 s_snapshot_list;
	__le32 s_error_count;
	__le32 s_first_error_time;
	__le32 s_first_error_ino;
	__le64 s_first_error_block;
	__u8 s_first_error_func[32];
	__le32 s_first_error_line;
	__le32 s_last_error_time;
	__le32 s_last_error_ino;
	__le32 s_last_error_line;
	__le64 s_last_error_block;
	__u8 s_last_error_func[32];
	__u8 s_mount_opts[64];
	__le32 s_usr_quota_inum;
	__le32 s_grp_quota_inum;
	__le32 s_overhead_clusters;
	__le32 s_backup_bgs[2];
	__u8 s_encrypt_algos[4];
	__u8 s_encrypt_pw_salt[16];
	__le32 s_lpf_ino;
	__le32 s_prj_quota_inum;
	__le32 s_checksum_seed;
	__u8 s_wtime_hi;
	__u8 s_mtime_hi;
	__u8 s_mkfs_time_hi;
	__u8 s_lastcheck_hi;
	__u8 s_first_error_time_hi;
	__u8 s_last_error_time_hi;
	__u8 s_first_error_errcode;
	__u8 s_last_error_errcode;
	__le16 s_encoding;
	__le16 s_encoding_flags;
	__le32 s_orphan_file_inum;
	__le32 s_reserved[94];
	__le32 s_checksum;
};

struct ext4_journal_trigger {
	struct jbd2_buffer_trigger_type tr_triggers;
	struct super_block___131 *sb;
};

struct ext4_orphan_block {
	atomic_t ob_free_entries;
	struct buffer_head___4 *ob_bh;
};

struct ext4_orphan_info {
	int of_blocks;
	__u32 of_csum_seed;
	struct ext4_orphan_block *of_binfo;
};

struct mb_cache___2;

struct ext4_group_info;

struct ext4_locality_group;

struct ext4_li_request;

struct ext4_sb_info {
	long unsigned int s_desc_size;
	long unsigned int s_inodes_per_block;
	long unsigned int s_blocks_per_group;
	long unsigned int s_clusters_per_group;
	long unsigned int s_inodes_per_group;
	long unsigned int s_itb_per_group;
	long unsigned int s_gdb_count;
	long unsigned int s_desc_per_block;
	ext4_group_t s_groups_count;
	ext4_group_t s_blockfile_groups;
	long unsigned int s_overhead;
	unsigned int s_cluster_ratio;
	unsigned int s_cluster_bits;
	loff_t s_bitmap_maxbytes;
	struct buffer_head___4 *s_sbh;
	struct ext4_super_block *s_es;
	struct buffer_head___4 **s_group_desc;
	unsigned int s_mount_opt;
	unsigned int s_mount_opt2;
	long unsigned int s_mount_flags;
	unsigned int s_def_mount_opt;
	ext4_fsblk_t s_sb_block;
	atomic64_t s_resv_clusters;
	kuid_t s_resuid;
	kgid_t s_resgid;
	short unsigned int s_mount_state;
	short unsigned int s_pad;
	int s_addr_per_block_bits;
	int s_desc_per_block_bits;
	int s_inode_size;
	int s_first_ino;
	unsigned int s_inode_readahead_blks;
	unsigned int s_inode_goal;
	u32 s_hash_seed[4];
	int s_def_hash_version;
	int s_hash_unsigned;
	struct percpu_counter s_freeclusters_counter;
	struct percpu_counter s_freeinodes_counter;
	struct percpu_counter s_dirs_counter;
	struct percpu_counter s_dirtyclusters_counter;
	struct percpu_counter s_sra_exceeded_retry_limit;
	struct blockgroup_lock *s_blockgroup_lock;
	struct proc_dir_entry *s_proc;
	struct kobject___122 s_kobj;
	struct completion s_kobj_unregister;
	struct super_block___131 *s_sb;
	struct buffer_head___4 *s_mmp_bh;
	struct journal_s *s_journal;
	long unsigned int s_ext4_flags;
	struct mutex s_orphan_lock;
	struct list_head s_orphan;
	struct ext4_orphan_info s_orphan_info;
	long unsigned int s_commit_interval;
	u32 s_max_batch_time;
	u32 s_min_batch_time;
	struct block_device___59 *s_journal_bdev;
	char *s_qf_names[3];
	int s_jquota_fmt;
	unsigned int s_want_extra_isize;
	struct ext4_system_blocks *s_system_blks;
	struct ext4_group_info ***s_group_info;
	struct inode___131 *s_buddy_cache;
	spinlock_t s_md_lock;
	short unsigned int *s_mb_offsets;
	unsigned int *s_mb_maxs;
	unsigned int s_group_info_size;
	unsigned int s_mb_free_pending;
	struct list_head s_freed_data_list;
	struct list_head s_discard_list;
	struct work_struct s_discard_work;
	atomic_t s_retry_alloc_pending;
	struct rb_root s_mb_avg_fragment_size_root;
	rwlock_t s_mb_rb_lock;
	struct list_head *s_mb_largest_free_orders;
	rwlock_t *s_mb_largest_free_orders_locks;
	long unsigned int s_stripe;
	unsigned int s_mb_max_linear_groups;
	unsigned int s_mb_stream_request;
	unsigned int s_mb_max_to_scan;
	unsigned int s_mb_min_to_scan;
	unsigned int s_mb_stats;
	unsigned int s_mb_order2_reqs;
	unsigned int s_mb_group_prealloc;
	unsigned int s_mb_max_inode_prealloc;
	unsigned int s_max_dir_size_kb;
	long unsigned int s_mb_last_group;
	long unsigned int s_mb_last_start;
	unsigned int s_mb_prefetch;
	unsigned int s_mb_prefetch_limit;
	atomic_t s_bal_reqs;
	atomic_t s_bal_success;
	atomic_t s_bal_allocated;
	atomic_t s_bal_ex_scanned;
	atomic_t s_bal_groups_scanned;
	atomic_t s_bal_goals;
	atomic_t s_bal_breaks;
	atomic_t s_bal_2orders;
	atomic_t s_bal_cr0_bad_suggestions;
	atomic_t s_bal_cr1_bad_suggestions;
	atomic64_t s_bal_cX_groups_considered[4];
	atomic64_t s_bal_cX_hits[4];
	atomic64_t s_bal_cX_failed[4];
	atomic_t s_mb_buddies_generated;
	atomic64_t s_mb_generation_time;
	atomic_t s_mb_lost_chunks;
	atomic_t s_mb_preallocated;
	atomic_t s_mb_discarded;
	atomic_t s_lock_busy;
	struct ext4_locality_group *s_locality_groups;
	long unsigned int s_sectors_written_start;
	u64 s_kbytes_written;
	unsigned int s_extent_max_zeroout_kb;
	unsigned int s_log_groups_per_flex;
	struct flex_groups **s_flex_groups;
	ext4_group_t s_flex_groups_allocated;
	struct workqueue_struct *rsv_conversion_wq;
	struct timer_list s_err_report;
	struct ext4_li_request *s_li_request;
	unsigned int s_li_wait_mult;
	struct task_struct___138 *s_mmp_tsk;
	atomic_t s_last_trim_minblks;
	struct crypto_shash___4 *s_chksum_driver;
	__u32 s_csum_seed;
	struct shrinker___50 s_es_shrinker;
	struct list_head s_es_list;
	long int s_es_nr_inode;
	struct ext4_es_stats s_es_stats;
	struct mb_cache___2 *s_ea_block_cache;
	struct mb_cache___2 *s_ea_inode_cache;
	long: 64;
	long: 64;
	spinlock_t s_es_lock;
	struct ext4_journal_trigger s_journal_triggers[1];
	struct ratelimit_state s_err_ratelimit_state;
	struct ratelimit_state s_warning_ratelimit_state;
	struct ratelimit_state s_msg_ratelimit_state;
	atomic_t s_warning_count;
	atomic_t s_msg_count;
	struct fscrypt_dummy_policy s_dummy_enc_policy;
	struct percpu_rw_semaphore___132 s_writepages_rwsem;
	struct dax_device *s_daxdev;
	errseq_t s_bdev_wb_err;
	spinlock_t s_bdev_wb_lock;
	spinlock_t s_error_lock;
	int s_add_error_count;
	int s_first_error_code;
	__u32 s_first_error_line;
	__u32 s_first_error_ino;
	__u64 s_first_error_block;
	const char *s_first_error_func;
	time64_t s_first_error_time;
	int s_last_error_code;
	__u32 s_last_error_line;
	__u32 s_last_error_ino;
	__u64 s_last_error_block;
	const char *s_last_error_func;
	time64_t s_last_error_time;
	struct work_struct s_error_work;
	atomic_t s_fc_subtid;
	struct list_head s_fc_q[2];
	struct list_head s_fc_dentry_q[2];
	unsigned int s_fc_bytes;
	spinlock_t s_fc_lock;
	struct buffer_head___4 *s_fc_bh;
	struct ext4_fc_stats s_fc_stats;
	tid_t s_fc_ineligible_tid;
	struct ext4_fc_replay_state s_fc_replay_state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ext4_group_info {
	long unsigned int bb_state;
	struct rb_root bb_free_root;
	ext4_grpblk_t bb_first_free;
	ext4_grpblk_t bb_free;
	ext4_grpblk_t bb_fragments;
	ext4_grpblk_t bb_largest_free_order;
	ext4_group_t bb_group;
	struct list_head bb_prealloc_list;
	struct rw_semaphore alloc_sem;
	struct rb_node bb_avg_fragment_size_rb;
	struct list_head bb_largest_free_order_node;
	ext4_grpblk_t bb_counters[0];
};

struct ext4_locality_group {
	struct mutex lg_mutex;
	struct list_head lg_prealloc_list[10];
	spinlock_t lg_prealloc_lock;
};

enum ext4_li_mode {
	EXT4_LI_MODE_PREFETCH_BBITMAP = 0,
	EXT4_LI_MODE_ITABLE = 1,
};

struct ext4_li_request {
	struct super_block___131 *lr_super;
	enum ext4_li_mode lr_mode;
	ext4_group_t lr_first_not_zeroed;
	ext4_group_t lr_next_group;
	struct list_head lr_request;
	long unsigned int lr_next_sched;
	long unsigned int lr_timeout;
};

struct seq_operations___114 {
	void * (*start)(struct seq_file___114 *, loff_t *);
	void (*stop)(struct seq_file___114 *, void *);
	void * (*next)(struct seq_file___114 *, void *, loff_t *);
	int (*show)(struct seq_file___114 *, void *);
};

struct cftype___93;

struct cgroup_subsys___93 {
	struct cgroup_subsys_state___93 * (*css_alloc)(struct cgroup_subsys_state___93 *);
	int (*css_online)(struct cgroup_subsys_state___93 *);
	void (*css_offline)(struct cgroup_subsys_state___93 *);
	void (*css_released)(struct cgroup_subsys_state___93 *);
	void (*css_free)(struct cgroup_subsys_state___93 *);
	void (*css_reset)(struct cgroup_subsys_state___93 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___93 *, int);
	int (*css_extra_stat_show)(struct seq_file___114 *, struct cgroup_subsys_state___93 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___138 *, struct css_set___93 *);
	void (*cancel_fork)(struct task_struct___138 *, struct css_set___93 *);
	void (*fork)(struct task_struct___138 *);
	void (*exit)(struct task_struct___138 *);
	void (*release)(struct task_struct___138 *);
	void (*bind)(struct cgroup_subsys_state___93 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___93 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___93 *dfl_cftypes;
	struct cftype___93 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___93 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___93 *updated_children;
	struct cgroup___93 *updated_next;
};

struct cgroup_root___93 {
	struct kernfs_root___122 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___93 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___93 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___93 *ss;
	struct list_head node;
	struct kernfs_ops___122 *kf_ops;
	int (*open)(struct kernfs_open_file___122 *);
	void (*release)(struct kernfs_open_file___122 *);
	u64 (*read_u64)(struct cgroup_subsys_state___93 *, struct cftype___93 *);
	s64 (*read_s64)(struct cgroup_subsys_state___93 *, struct cftype___93 *);
	int (*seq_show)(struct seq_file___114 *, void *);
	void * (*seq_start)(struct seq_file___114 *, loff_t *);
	void * (*seq_next)(struct seq_file___114 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___114 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___93 *, struct cftype___93 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___93 *, struct cftype___93 *, s64);
	ssize_t (*write)(struct kernfs_open_file___122 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___122 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___56 {
	struct request___58 *rq;
	bool last;
};

struct blkcg_policy_data___56;

struct blkcg___56 {
	struct cgroup_subsys_state___93 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___56 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___56 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___56 {
	struct blkcg___56 *blkcg;
	int plid;
};

struct blkg_policy_data___56 {
	struct blkcg_gq___56 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___50 {
	struct mem_cgroup___50 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___50 {
	struct lruvec___57 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___50 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___50 *memcg;
};

struct obj_cgroup___50 {
	struct percpu_ref refcnt;
	struct mem_cgroup___50 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct shash_desc___3 {
	struct crypto_shash___4 *tfm;
	void *__ctx[0];
};

struct ext4_map_blocks {
	ext4_fsblk_t m_pblk;
	ext4_lblk_t m_lblk;
	unsigned int m_len;
	unsigned int m_flags;
};

typedef enum {
	EXT4_IGET_NORMAL = 0,
	EXT4_IGET_SPECIAL = 1,
	EXT4_IGET_HANDLE = 2,
} ext4_iget_flags;

struct ext4_system_zone {
	struct rb_node node;
	ext4_fsblk_t start_blk;
	unsigned int count;
	u32 ino;
};

struct dentry___132;

struct super_block___132;

struct module___121;

struct file_system_type___132 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___132 * (*mount)(struct file_system_type___132 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___132 *);
	struct module___121 *owner;
	struct file_system_type___132 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___132;

struct kiocb___132;

struct iov_iter___73;

struct vm_area_struct___137;

struct inode___132;

struct file_lock___132;

struct page___137;

struct file_operations___132 {
	struct module___121 *owner;
	loff_t (*llseek)(struct file___132 *, loff_t, int);
	ssize_t (*read)(struct file___132 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___132 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___132 *, struct iov_iter___73 *);
	ssize_t (*write_iter)(struct kiocb___132 *, struct iov_iter___73 *);
	int (*iopoll)(struct kiocb___132 *, bool);
	int (*iterate)(struct file___132 *, struct dir_context *);
	int (*iterate_shared)(struct file___132 *, struct dir_context *);
	__poll_t (*poll)(struct file___132 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___132 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___132 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___132 *, struct vm_area_struct___137 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___132 *, struct file___132 *);
	int (*flush)(struct file___132 *, fl_owner_t);
	int (*release)(struct inode___132 *, struct file___132 *);
	int (*fsync)(struct file___132 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___132 *, int);
	int (*lock)(struct file___132 *, int, struct file_lock___132 *);
	ssize_t (*sendpage)(struct file___132 *, struct page___137 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___132 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___132 *, long unsigned int);
	int (*flock)(struct file___132 *, int, struct file_lock___132 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___132 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___132 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___132 *, long int, struct file_lock___132 **, void **);
	long int (*fallocate)(struct file___132 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___132 *);
	ssize_t (*copy_file_range)(struct file___132 *, loff_t, struct file___132 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___132 *, loff_t, struct file___132 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___132 *, loff_t, loff_t, int);
};

struct vmacache___137 {
	u64 seqnum;
	struct vm_area_struct___137 *vmas[4];
};

struct page_frag___137 {
	struct page___137 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___138;

struct pid___117;

struct nsproxy___123;

struct signal_struct___133;

struct bio_list___59;

struct io_context___59;

struct request_queue___59;

struct vm_struct___119;

struct task_struct___139 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___139 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___138 *mm;
	struct mm_struct___138 *active_mm;
	struct vmacache___137 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___139 *real_parent;
	struct task_struct___139 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___139 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___117 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___123 *nsproxy;
	struct signal_struct___133 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___139 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___59 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___59 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___137 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___59 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___139 *oom_reaper_list;
	struct vm_struct___119 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___123;

struct kobj_type___123;

struct kernfs_node___123;

struct kobject___123 {
	const char *name;
	struct list_head entry;
	struct kobject___123 *parent;
	struct kset___123 *kset;
	struct kobj_type___123 *ktype;
	struct kernfs_node___123 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___120 {
	struct kobject___123 kobj;
	struct module___121 *mod;
	struct kobject___123 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___120 {
	struct module___121 *mod;
	struct latch_tree_node node;
};

struct module_layout___120 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___120 mtn;
};

struct module_attribute___120;

struct kernel_param___120;

struct module___121 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___120 mkobj;
	struct module_attribute___120 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___123 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___120 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___120 core_layout;
	struct module_layout___120 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___132;

struct dentry___132 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___132 *d_parent;
	struct qstr d_name;
	struct inode___132 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___132 *d_op;
	struct super_block___132 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___132;

struct address_space___132 {
	struct inode___132 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___132 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___132;

struct inode___132 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___132 *i_op;
	struct super_block___132 *i_sb;
	struct address_space___132 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___132 *i_fop;
		void (*free_inode)(struct inode___132 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___132 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___132;

struct path___132;

struct dentry_operations___132 {
	int (*d_revalidate)(struct dentry___132 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___132 *, unsigned int);
	int (*d_hash)(const struct dentry___132 *, struct qstr *);
	int (*d_compare)(const struct dentry___132 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___132 *);
	int (*d_init)(struct dentry___132 *);
	void (*d_release)(struct dentry___132 *);
	void (*d_prune)(struct dentry___132 *);
	void (*d_iput)(struct dentry___132 *, struct inode___132 *);
	char * (*d_dname)(struct dentry___132 *, char *, int);
	struct vfsmount___132 * (*d_automount)(struct path___132 *);
	int (*d_manage)(const struct path___132 *, bool);
	struct dentry___132 * (*d_real)(struct dentry___132 *, const struct inode___132 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___132;

struct mem_dqinfo___132 {
	struct quota_format_type___132 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___132;

struct quota_info___132 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___132 *files[3];
	struct mem_dqinfo___132 info[3];
	const struct quota_format_ops___132 *ops[3];
};

struct rcuwait___133 {
	struct task_struct___139 *task;
};

struct percpu_rw_semaphore___133 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___133 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___132 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___133 rw_sem[3];
};

struct super_operations___132;

struct dquot_operations___132;

struct quotactl_ops___132;

struct xattr_handler___14;

struct fscrypt_operations___8;

struct fsverity_operations___6;

struct block_device___60;

struct super_block___132 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___132 *s_type;
	const struct super_operations___132 *s_op;
	const struct dquot_operations___132 *dq_op;
	const struct quotactl_ops___132 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___132 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___14 **s_xattr;
	const struct fscrypt_operations___8 *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___6 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___60 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___132 s_dquot;
	struct sb_writers___132 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___132 *s_d_op;
	int cleancache_poolid;
	struct shrinker___50 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___132 {
	struct dentry___132 *mnt_root;
	struct super_block___132 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___132 {
	struct vfsmount___132 *mnt;
	struct dentry___132 *dentry;
};

struct pid_namespace___117;

struct upid___117 {
	int nr;
	struct pid_namespace___117 *ns;
};

struct pid_namespace___117 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___139 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___117 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___117 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___117 numbers[1];
};

typedef struct page___137 *pgtable_t___137;

struct dev_pagemap___130;

struct page___137 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___132 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___137 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___137 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___138 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___130 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___130;

struct vm_area_struct___137 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___137 *vm_next;
	struct vm_area_struct___137 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___138 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___130 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___132 *vm_file;
	struct file___132 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___133 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___139 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___139 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___117 *pids[4];
	struct pid___117 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___138 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___137;

struct mm_struct___138 {
	struct {
		struct vm_area_struct___137 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___132 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___137 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___139 *owner;
		struct user_namespace___19 *user_ns;
		struct file___132 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___123 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___117 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___59;

struct bio_list___59 {
	struct bio___59 *head;
	struct bio___59 *tail;
};

struct io_cq___59;

struct io_context___59 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___59 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___59;

struct blk_integrity___59 {
	const struct blk_integrity_profile___59 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___59 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___59 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___59;

struct elevator_queue___59;

struct gendisk___59;

struct device___97;

struct request_queue___59 {
	struct request___59 *last_merge;
	struct elevator_queue___59 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___59 *disk;
	struct kobject___123 kobj;
	struct kobject___123 *mq_kobj;
	struct blk_integrity___59 integrity;
	struct device___97 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___59 bio_split;
	struct dentry___132 *debugfs_dir;
	struct dentry___132 *sched_debugfs_dir;
	struct dentry___132 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___119 {
	struct vm_struct___119 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___137 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___130;

struct dev_pagemap___130 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___130 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___117 {
	rwlock_t lock;
	struct pid___117 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___132 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___132 f_path;
	struct inode___132 *f_inode;
	const struct file_operations___132 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___117 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___132 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___130;

struct vm_operations_struct___130 {
	void (*open)(struct vm_area_struct___137 *);
	void (*close)(struct vm_area_struct___137 *);
	int (*may_split)(struct vm_area_struct___137 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___137 *);
	int (*mprotect)(struct vm_area_struct___137 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___130 *);
	vm_fault_t (*huge_fault)(struct vm_fault___130 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___130 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___137 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___130 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___130 *);
	int (*access)(struct vm_area_struct___137 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___137 *);
	int (*set_policy)(struct vm_area_struct___137 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___137 *, long unsigned int);
	struct page___137 * (*find_special_page)(struct vm_area_struct___137 *, long unsigned int);
};

struct core_thread___137 {
	struct task_struct___139 *task;
	struct core_thread___137 *next;
};

struct core_state___137 {
	atomic_t nr_threads;
	struct core_thread___137 dumper;
	struct completion startup;
};

struct vm_fault___130 {
	const struct {
		struct vm_area_struct___137 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___137 *cow_page;
	struct page___137 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___137 prealloc_pte;
};

struct io_cq___59 {
	struct request_queue___59 *q;
	struct io_context___59 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___5;

typedef void bh_end_io_t___5(struct buffer_head___5 *, int);

struct buffer_head___5 {
	long unsigned int b_state;
	struct buffer_head___5 *b_this_page;
	struct page___137 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___60 *b_bdev;
	bh_end_io_t___5 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___132 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___61;

struct kiocb___132 {
	struct file___132 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___132 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___61 *ki_waitq;
	};
};

struct iattr___132 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___132 *ia_file;
};

struct dquot___132 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___132 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___132 {
	int qf_fmt_id;
	const struct quota_format_ops___132 *qf_ops;
	struct module___121 *qf_owner;
	struct quota_format_type___132 *qf_next;
};

struct quota_format_ops___132 {
	int (*check_quota_file)(struct super_block___132 *, int);
	int (*read_file_info)(struct super_block___132 *, int);
	int (*write_file_info)(struct super_block___132 *, int);
	int (*free_file_info)(struct super_block___132 *, int);
	int (*read_dqblk)(struct dquot___132 *);
	int (*commit_dqblk)(struct dquot___132 *);
	int (*release_dqblk)(struct dquot___132 *);
	int (*get_next_id)(struct super_block___132 *, struct kqid *);
};

struct dquot_operations___132 {
	int (*write_dquot)(struct dquot___132 *);
	struct dquot___132 * (*alloc_dquot)(struct super_block___132 *, int);
	void (*destroy_dquot)(struct dquot___132 *);
	int (*acquire_dquot)(struct dquot___132 *);
	int (*release_dquot)(struct dquot___132 *);
	int (*mark_dirty)(struct dquot___132 *);
	int (*write_info)(struct super_block___132 *, int);
	qsize_t * (*get_reserved_space)(struct inode___132 *);
	int (*get_projid)(struct inode___132 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___132 *, qsize_t *);
	int (*get_next_id)(struct super_block___132 *, struct kqid *);
};

struct quotactl_ops___132 {
	int (*quota_on)(struct super_block___132 *, int, int, const struct path___132 *);
	int (*quota_off)(struct super_block___132 *, int);
	int (*quota_enable)(struct super_block___132 *, unsigned int);
	int (*quota_disable)(struct super_block___132 *, unsigned int);
	int (*quota_sync)(struct super_block___132 *, int);
	int (*set_info)(struct super_block___132 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___132 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___132 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___132 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___132 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___132 *, unsigned int);
};

struct wait_page_queue___61 {
	struct page___137 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___61;

struct address_space_operations___132 {
	int (*writepage)(struct page___137 *, struct writeback_control___3 *);
	int (*readpage)(struct file___132 *, struct page___137 *);
	int (*writepages)(struct address_space___132 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___137 *);
	int (*readpages)(struct file___132 *, struct address_space___132 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___61 *);
	int (*write_begin)(struct file___132 *, struct address_space___132 *, loff_t, unsigned int, unsigned int, struct page___137 **, void **);
	int (*write_end)(struct file___132 *, struct address_space___132 *, loff_t, unsigned int, unsigned int, struct page___137 *, void *);
	sector_t (*bmap)(struct address_space___132 *, sector_t);
	void (*invalidatepage)(struct page___137 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___137 *, gfp_t);
	void (*freepage)(struct page___137 *);
	ssize_t (*direct_IO)(struct kiocb___132 *, struct iov_iter___73 *);
	int (*migratepage)(struct address_space___132 *, struct page___137 *, struct page___137 *, enum migrate_mode);
	bool (*isolate_page)(struct page___137 *, isolate_mode_t);
	void (*putback_page)(struct page___137 *);
	int (*launder_page)(struct page___137 *);
	int (*is_partially_uptodate)(struct page___137 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___137 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___132 *, struct page___137 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___132 *, sector_t *);
	void (*swap_deactivate)(struct file___132 *);
};

struct readahead_control___61 {
	struct file___132 *file;
	struct address_space___132 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___71;

struct iov_iter___73 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___71 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___132 {
	struct dentry___132 * (*lookup)(struct inode___132 *, struct dentry___132 *, unsigned int);
	const char * (*get_link)(struct dentry___132 *, struct inode___132 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___132 *, int);
	struct posix_acl * (*get_acl)(struct inode___132 *, int, bool);
	int (*readlink)(struct dentry___132 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___132 *, struct dentry___132 *, umode_t, bool);
	int (*link)(struct dentry___132 *, struct inode___132 *, struct dentry___132 *);
	int (*unlink)(struct inode___132 *, struct dentry___132 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___132 *, struct dentry___132 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___132 *, struct dentry___132 *, umode_t);
	int (*rmdir)(struct inode___132 *, struct dentry___132 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___132 *, struct dentry___132 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___132 *, struct dentry___132 *, struct inode___132 *, struct dentry___132 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___132 *, struct iattr___132 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___132 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___132 *, char *, size_t);
	int (*fiemap)(struct inode___132 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___132 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___132 *, struct dentry___132 *, struct file___132 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___132 *, struct dentry___132 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___132 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___132 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___132 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___132 {
	void (*fl_copy_lock)(struct file_lock___132 *, struct file_lock___132 *);
	void (*fl_release_private)(struct file_lock___132 *);
};

struct fasync_struct___132;

struct lock_manager_operations___132;

struct file_lock___132 {
	struct file_lock___132 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___132 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___132 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___132 *fl_ops;
	const struct lock_manager_operations___132 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___132 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___132 *);
	int (*lm_grant)(struct file_lock___132 *, int);
	bool (*lm_break)(struct file_lock___132 *);
	int (*lm_change)(struct file_lock___132 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___132 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___132 *);
};

struct fasync_struct___132 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___132 *fa_next;
	struct file___132 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___132 {
	struct inode___132 * (*alloc_inode)(struct super_block___132 *);
	void (*destroy_inode)(struct inode___132 *);
	void (*free_inode)(struct inode___132 *);
	void (*dirty_inode)(struct inode___132 *, int);
	int (*write_inode)(struct inode___132 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___132 *);
	void (*evict_inode)(struct inode___132 *);
	void (*put_super)(struct super_block___132 *);
	int (*sync_fs)(struct super_block___132 *, int);
	int (*freeze_super)(struct super_block___132 *);
	int (*freeze_fs)(struct super_block___132 *);
	int (*thaw_super)(struct super_block___132 *);
	int (*unfreeze_fs)(struct super_block___132 *);
	int (*statfs)(struct dentry___132 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___132 *, int *, char *);
	void (*umount_begin)(struct super_block___132 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___132 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___132 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___132 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___132 *);
	ssize_t (*quota_read)(struct super_block___132 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___132 *, int, const char *, size_t, loff_t);
	struct dquot___132 ** (*get_dquots)(struct inode___132 *);
	long int (*nr_cached_objects)(struct super_block___132 *, struct shrink_control___50 *);
	long int (*free_cached_objects)(struct super_block___132 *, struct shrink_control___50 *);
	struct file___132 * (*real_loop)(struct file___132 *);
};

struct xattr_handler___14 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___132 *);
	int (*get)(const struct xattr_handler___14 *, struct dentry___132 *, struct inode___132 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___14 *, struct user_namespace___19 *, struct dentry___132 *, struct inode___132 *, const char *, const void *, size_t, int);
};

struct fscrypt_operations___8 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___132 *, void *, size_t);
	int (*set_context)(struct inode___132 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___132 *);
	bool (*empty_dir)(struct inode___132 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___132 *);
	void (*get_ino_and_lblk_bits)(struct super_block___132 *, int *, int *);
	int (*get_num_devices)(struct super_block___132 *);
	void (*get_devices)(struct super_block___132 *, struct request_queue___59 **);
};

struct fsverity_operations___6 {
	int (*begin_enable_verity)(struct file___132 *);
	int (*end_enable_verity)(struct file___132 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___132 *, void *, size_t);
	struct page___137 * (*read_merkle_tree_page)(struct inode___132 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___132 *, const void *, u64, int);
};

struct wakeup_source___97;

struct dev_pm_info___97 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___97 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___97 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___97;

struct bus_type___97;

struct device_driver___97;

struct dev_pm_domain___97;

struct fwnode_handle___97;

struct class___97;

struct attribute_group___123;

struct device___97 {
	struct kobject___123 kobj;
	struct device___97 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___97 *type;
	struct bus_type___97 *bus;
	struct device_driver___97 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___97 power;
	struct dev_pm_domain___97 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___97 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___97 *class;
	const struct attribute_group___123 **groups;
	void (*release)(struct device___97 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___60 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___132 *bd_inode;
	struct super_block___132 *bd_super;
	void *bd_claiming;
	struct device___97 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___123 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___59 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___132 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___59(struct bio___59 *);

struct bio_vec___71 {
	struct page___137 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___59;

struct bio___59 {
	struct bio___59 *bi_next;
	struct block_device___60 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___59 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___59 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___71 *bi_io_vec;
	struct bio_set___59 *bi_pool;
	struct bio_vec___71 bi_inline_vecs[0];
};

struct dev_pagemap_ops___130 {
	void (*page_free)(struct page___137 *);
	void (*kill)(struct dev_pagemap___130 *);
	void (*cleanup)(struct dev_pagemap___130 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___130 *);
};

struct fwnode_operations___97;

struct fwnode_handle___97 {
	struct fwnode_handle___97 *secondary;
	const struct fwnode_operations___97 *ops;
	struct device___97 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___97;

struct fwnode_endpoint___97;

struct fwnode_operations___97 {
	struct fwnode_handle___97 * (*get)(struct fwnode_handle___97 *);
	void (*put)(struct fwnode_handle___97 *);
	bool (*device_is_available)(const struct fwnode_handle___97 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___97 *, const struct device___97 *);
	bool (*property_present)(const struct fwnode_handle___97 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___97 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___97 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___97 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*get_parent)(const struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*get_next_child_node)(const struct fwnode_handle___97 *, struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*get_named_child_node)(const struct fwnode_handle___97 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___97 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___97 *);
	struct fwnode_handle___97 * (*graph_get_next_endpoint)(const struct fwnode_handle___97 *, struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*graph_get_remote_endpoint)(const struct fwnode_handle___97 *);
	struct fwnode_handle___97 * (*graph_get_port_parent)(struct fwnode_handle___97 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___97 *, struct fwnode_endpoint___97 *);
	int (*add_links)(struct fwnode_handle___97 *);
};

struct fwnode_endpoint___97 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___97 *local_fwnode;
};

struct fwnode_reference_args___97 {
	struct fwnode_handle___97 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___123;

struct kernfs_elem_dir___123 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___123 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___123;

struct kernfs_root___123 {
	struct kernfs_node___123 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___123 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___123 {
	struct kernfs_node___123 *target_kn;
};

struct kernfs_ops___123;

struct kernfs_elem_attr___123 {
	const struct kernfs_ops___123 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___123 *notify_next;
};

struct kernfs_node___123 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___123 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___123 dir;
		struct kernfs_elem_symlink___123 symlink;
		struct kernfs_elem_attr___123 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___123;

struct kernfs_ops___123 {
	int (*open)(struct kernfs_open_file___123 *);
	void (*release)(struct kernfs_open_file___123 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___123 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___123 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___123 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___123 *, struct vm_area_struct___137 *);
};

struct kernfs_syscall_ops___123 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___123 *);
	int (*mkdir)(struct kernfs_node___123 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___123 *);
	int (*rename)(struct kernfs_node___123 *, struct kernfs_node___123 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___123 *, struct kernfs_root___123 *);
};

struct kernfs_open_file___123 {
	struct kernfs_node___123 *kn;
	struct file___132 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___130 *vm_ops;
};

struct bin_attribute___123;

struct attribute_group___123 {
	const char *name;
	umode_t (*is_visible)(struct kobject___123 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___123 *, struct bin_attribute___123 *, int);
	struct attribute **attrs;
	struct bin_attribute___123 **bin_attrs;
};

struct bin_attribute___123 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___132 * (*f_mapping)();
	ssize_t (*read)(struct file___132 *, struct kobject___123 *, struct bin_attribute___123 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___132 *, struct kobject___123 *, struct bin_attribute___123 *, char *, loff_t, size_t);
	int (*mmap)(struct file___132 *, struct kobject___123 *, struct bin_attribute___123 *, struct vm_area_struct___137 *);
};

struct sysfs_ops___123 {
	ssize_t (*show)(struct kobject___123 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___123 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___123;

struct kset___123 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___123 kobj;
	const struct kset_uevent_ops___123 *uevent_ops;
};

struct kobj_type___123 {
	void (*release)(struct kobject___123 *);
	const struct sysfs_ops___123 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___123 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___123 *);
	const void * (*namespace)(struct kobject___123 *);
	void (*get_ownership)(struct kobject___123 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___123 {
	int (* const filter)(struct kset___123 *, struct kobject___123 *);
	const char * (* const name)(struct kset___123 *, struct kobject___123 *);
	int (* const uevent)(struct kset___123 *, struct kobject___123 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___120 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___120 *);
	int (*get)(char *, const struct kernel_param___120 *);
	void (*free)(void *);
};

struct kparam_array___120;

struct kernel_param___120 {
	const char *name;
	struct module___121 *mod;
	const struct kernel_param_ops___120 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___120 *arr;
	};
};

struct kparam_array___120 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___120 *ops;
	void *elem;
};

struct module_attribute___120 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___120 *, struct module_kobject___120 *, char *);
	ssize_t (*store)(struct module_attribute___120 *, struct module_kobject___120 *, const char *, size_t);
	void (*setup)(struct module___121 *, const char *);
	int (*test)(struct module___121 *);
	void (*free)(struct module___121 *);
};

struct dev_pm_ops___97 {
	int (*prepare)(struct device___97 *);
	void (*complete)(struct device___97 *);
	int (*suspend)(struct device___97 *);
	int (*resume)(struct device___97 *);
	int (*freeze)(struct device___97 *);
	int (*thaw)(struct device___97 *);
	int (*poweroff)(struct device___97 *);
	int (*restore)(struct device___97 *);
	int (*suspend_late)(struct device___97 *);
	int (*resume_early)(struct device___97 *);
	int (*freeze_late)(struct device___97 *);
	int (*thaw_early)(struct device___97 *);
	int (*poweroff_late)(struct device___97 *);
	int (*restore_early)(struct device___97 *);
	int (*suspend_noirq)(struct device___97 *);
	int (*resume_noirq)(struct device___97 *);
	int (*freeze_noirq)(struct device___97 *);
	int (*thaw_noirq)(struct device___97 *);
	int (*poweroff_noirq)(struct device___97 *);
	int (*restore_noirq)(struct device___97 *);
	int (*runtime_suspend)(struct device___97 *);
	int (*runtime_resume)(struct device___97 *);
	int (*runtime_idle)(struct device___97 *);
};

struct wakeup_source___97 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___97 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___97 {
	struct dev_pm_ops___97 ops;
	int (*start)(struct device___97 *);
	void (*detach)(struct device___97 *, bool);
	int (*activate)(struct device___97 *);
	void (*sync)(struct device___97 *);
	void (*dismiss)(struct device___97 *);
};

struct bus_type___97 {
	const char *name;
	const char *dev_name;
	struct device___97 *dev_root;
	const struct attribute_group___123 **bus_groups;
	const struct attribute_group___123 **dev_groups;
	const struct attribute_group___123 **drv_groups;
	int (*match)(struct device___97 *, struct device_driver___97 *);
	int (*uevent)(struct device___97 *, struct kobj_uevent_env *);
	int (*probe)(struct device___97 *);
	void (*sync_state)(struct device___97 *);
	void (*remove)(struct device___97 *);
	void (*shutdown)(struct device___97 *);
	int (*online)(struct device___97 *);
	int (*offline)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	int (*num_vf)(struct device___97 *);
	int (*dma_configure)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___97 {
	const char *name;
	struct bus_type___97 *bus;
	struct module___121 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___97 *);
	void (*sync_state)(struct device___97 *);
	int (*remove)(struct device___97 *);
	void (*shutdown)(struct device___97 *);
	int (*suspend)(struct device___97 *, pm_message_t);
	int (*resume)(struct device___97 *);
	const struct attribute_group___123 **groups;
	const struct attribute_group___123 **dev_groups;
	const struct dev_pm_ops___97 *pm;
	void (*coredump)(struct device___97 *);
	struct driver_private *p;
};

struct device_type___97 {
	const char *name;
	const struct attribute_group___123 **groups;
	int (*uevent)(struct device___97 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___97 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___97 *);
	const struct dev_pm_ops___97 *pm;
};

struct class___97 {
	const char *name;
	struct module___121 *owner;
	const struct attribute_group___123 **class_groups;
	const struct attribute_group___123 **dev_groups;
	struct kobject___123 *dev_kobj;
	int (*dev_uevent)(struct device___97 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___97 *, umode_t *);
	void (*class_release)(struct class___97 *);
	void (*dev_release)(struct device___97 *);
	int (*shutdown_pre)(struct device___97 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___97 *);
	void (*get_ownership)(struct device___97 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___97 *pm;
	struct subsys_private *p;
};

struct block_device_operations___59;

struct gendisk___59 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___60 *part0;
	const struct block_device_operations___59 *fops;
	struct request_queue___59 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___123 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___123 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___59 {
	struct bio___59 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___71 *bip_vec;
	struct bio_vec___71 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___59(struct request___59 *);

typedef void integrity_complete_fn___59(struct request___59 *, unsigned int);

struct blk_integrity_profile___59 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___59 *prepare_fn;
	integrity_complete_fn___59 *complete_fn;
	const char *name;
};

struct block_device_operations___59 {
	blk_qc_t (*submit_bio)(struct bio___59 *);
	int (*open)(struct block_device___60 *, fmode_t);
	void (*release)(struct gendisk___59 *, fmode_t);
	int (*rw_page)(struct block_device___60 *, sector_t, struct page___137 *, unsigned int);
	int (*ioctl)(struct block_device___60 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___60 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___59 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___59 *);
	int (*getgeo)(struct block_device___60 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___60 *, bool);
	void (*swap_slot_free_notify)(struct block_device___60 *, long unsigned int);
	int (*report_zones)(struct gendisk___59 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___59 *, umode_t *);
	struct module___121 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___59 *, sector_t *);
};

typedef void rq_end_io_fn___59(struct request___59 *, blk_status_t);

struct request___59 {
	struct request_queue___59 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___59 *bio;
	struct bio___59 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___71 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___59 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___59 *saved_end_io;
		} flush;
	};
	struct gendisk___59 *rq_disk;
	struct block_device___60 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___59 *end_io;
	void *end_io_data;
};

struct elevator_type___59;

struct elevator_mq_ops___59 {
	int (*init_sched)(struct request_queue___59 *, struct elevator_type___59 *);
	void (*exit_sched)(struct elevator_queue___59 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
	bool (*allow_merge)(struct request_queue___59 *, struct request___59 *, struct bio___59 *);
	bool (*bio_merge)(struct request_queue___59 *, struct bio___59 *, unsigned int);
	int (*request_merge)(struct request_queue___59 *, struct request___59 **, struct bio___59 *);
	void (*request_merged)(struct request_queue___59 *, struct request___59 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___59 *, struct request___59 *, struct request___59 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___59 *);
	void (*finish_request)(struct request___59 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___59 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___59 *, u64);
	void (*requeue_request)(struct request___59 *);
	struct request___59 * (*former_request)(struct request_queue___59 *, struct request___59 *);
	struct request___59 * (*next_request)(struct request_queue___59 *, struct request___59 *);
	void (*init_icq)(struct io_cq___59 *);
	void (*exit_icq)(struct io_cq___59 *);
};

struct elv_fs_entry___59;

struct elevator_type___59 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___59 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___59 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___121 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___59 {
	struct elevator_type___59 *type;
	void *elevator_data;
	struct kobject___123 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___59 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___59 *, char *);
	ssize_t (*store)(struct elevator_queue___59 *, const char *, size_t);
};

struct journal_s___2;

typedef struct journal_s___2 journal_t___2;

struct journal_head___2;

struct transaction_s___2;

typedef struct transaction_s___2 transaction_t___2;

struct transaction_s___2 {
	journal_t___2 *t_journal;
	tid_t t_tid;
	enum {
		T_RUNNING___2 = 0,
		T_LOCKED___2 = 1,
		T_SWITCH___2 = 2,
		T_FLUSH___2 = 3,
		T_COMMIT___2 = 4,
		T_COMMIT_DFLUSH___2 = 5,
		T_COMMIT_JFLUSH___2 = 6,
		T_COMMIT_CALLBACK___2 = 7,
		T_FINISHED___2 = 8,
	} t_state;
	long unsigned int t_log_start;
	int t_nr_buffers;
	struct journal_head___2 *t_reserved_list;
	struct journal_head___2 *t_buffers;
	struct journal_head___2 *t_forget;
	struct journal_head___2 *t_checkpoint_list;
	struct journal_head___2 *t_checkpoint_io_list;
	struct journal_head___2 *t_shadow_list;
	struct list_head t_inode_list;
	spinlock_t t_handle_lock;
	long unsigned int t_max_wait;
	long unsigned int t_start;
	long unsigned int t_requested;
	struct transaction_chp_stats_s t_chp_stats;
	atomic_t t_updates;
	atomic_t t_outstanding_credits;
	atomic_t t_outstanding_revokes;
	atomic_t t_handle_count;
	transaction_t___2 *t_cpnext;
	transaction_t___2 *t_cpprev;
	long unsigned int t_expires;
	ktime_t t_start_time;
	unsigned int t_synchronous_commit: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int t_need_data_flush;
	struct list_head t_private_list;
};

struct jbd2_buffer_trigger_type___2;

struct journal_head___2 {
	struct buffer_head___5 *b_bh;
	spinlock_t b_state_lock;
	int b_jcount;
	unsigned int b_jlist;
	unsigned int b_modified;
	char *b_frozen_data;
	char *b_committed_data;
	transaction_t___2 *b_transaction;
	transaction_t___2 *b_next_transaction;
	struct journal_head___2 *b_tnext;
	struct journal_head___2 *b_tprev;
	transaction_t___2 *b_cp_transaction;
	struct journal_head___2 *b_cpnext;
	struct journal_head___2 *b_cpprev;
	struct jbd2_buffer_trigger_type___2 *b_triggers;
	struct jbd2_buffer_trigger_type___2 *b_frozen_triggers;
};

struct jbd2_buffer_trigger_type___2 {
	void (*t_frozen)(struct jbd2_buffer_trigger_type___2 *, struct buffer_head___5 *, void *, size_t);
	void (*t_abort)(struct jbd2_buffer_trigger_type___2 *, struct buffer_head___5 *);
};

struct crypto_alg___6;

struct crypto_tfm___6 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___6 *);
	struct crypto_alg___6 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___6 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___6 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___6 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___6 *, u8 *, const u8 *);
};

struct compress_alg___6 {
	int (*coa_compress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___6 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___6 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___6 cipher;
		struct compress_alg___6 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___6 *);
	void (*cra_exit)(struct crypto_tfm___6 *);
	void (*cra_destroy)(struct crypto_alg___6 *);
	struct module___121 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___5 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___6 base;
};

struct jbd2_journal_handle___2;

typedef struct jbd2_journal_handle___2 handle_t___2;

struct jbd2_journal_handle___2 {
	union {
		transaction_t___2 *h_transaction;
		journal_t___2 *h_journal;
	};
	handle_t___2 *h_rsv_handle;
	int h_total_credits;
	int h_revoke_credits;
	int h_revoke_credits_requested;
	int h_ref;
	int h_err;
	unsigned int h_sync: 1;
	unsigned int h_jdata: 1;
	unsigned int h_reserved: 1;
	unsigned int h_aborted: 1;
	unsigned int h_type: 8;
	unsigned int h_line_no: 16;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int h_start_jiffies;
	unsigned int h_requested_credits;
	unsigned int saved_alloc_context;
};

struct jbd2_inode___2;

struct journal_s___2 {
	long unsigned int j_flags;
	long unsigned int j_atomic_flags;
	int j_errno;
	struct mutex j_abort_mutex;
	struct buffer_head___5 *j_sb_buffer;
	journal_superblock_t *j_superblock;
	int j_format_version;
	rwlock_t j_state_lock;
	int j_barrier_count;
	struct mutex j_barrier;
	transaction_t___2 *j_running_transaction;
	transaction_t___2 *j_committing_transaction;
	transaction_t___2 *j_checkpoint_transactions;
	wait_queue_head_t j_wait_transaction_locked;
	wait_queue_head_t j_wait_done_commit;
	wait_queue_head_t j_wait_commit;
	wait_queue_head_t j_wait_updates;
	wait_queue_head_t j_wait_reserved;
	wait_queue_head_t j_fc_wait;
	struct mutex j_checkpoint_mutex;
	struct buffer_head___5 *j_chkpt_bhs[64];
	struct shrinker___50 j_shrinker;
	struct percpu_counter j_checkpoint_jh_count;
	transaction_t___2 *j_shrink_transaction;
	long unsigned int j_head;
	long unsigned int j_tail;
	long unsigned int j_free;
	long unsigned int j_first;
	long unsigned int j_last;
	long unsigned int j_fc_first;
	long unsigned int j_fc_off;
	long unsigned int j_fc_last;
	struct block_device___60 *j_dev;
	int j_blocksize;
	long long unsigned int j_blk_offset;
	char j_devname[56];
	struct block_device___60 *j_fs_dev;
	unsigned int j_total_len;
	atomic_t j_reserved_credits;
	spinlock_t j_list_lock;
	struct inode___132 *j_inode;
	tid_t j_tail_sequence;
	tid_t j_transaction_sequence;
	tid_t j_commit_sequence;
	tid_t j_commit_request;
	__u8 j_uuid[16];
	struct task_struct___139 *j_task;
	int j_max_transaction_buffers;
	int j_revoke_records_per_block;
	long unsigned int j_commit_interval;
	struct timer_list j_commit_timer;
	spinlock_t j_revoke_lock;
	struct jbd2_revoke_table_s *j_revoke;
	struct jbd2_revoke_table_s *j_revoke_table[2];
	struct buffer_head___5 **j_wbuf;
	struct buffer_head___5 **j_fc_wbuf;
	int j_wbufsize;
	int j_fc_wbufsize;
	pid_t j_last_sync_writer;
	u64 j_average_commit_time;
	u32 j_min_batch_time;
	u32 j_max_batch_time;
	void (*j_commit_callback)(journal_t___2 *, transaction_t___2 *);
	int (*j_submit_inode_data_buffers)(struct jbd2_inode___2 *);
	int (*j_finish_inode_data_buffers)(struct jbd2_inode___2 *);
	spinlock_t j_history_lock;
	struct proc_dir_entry *j_proc_entry;
	struct transaction_stats_s j_stats;
	unsigned int j_failed_commit;
	void *j_private;
	struct crypto_shash___5 *j_chksum_driver;
	__u32 j_csum_seed;
	void (*j_fc_cleanup_callback)(struct journal_s___2 *, int, tid_t);
	int (*j_fc_replay_callback)(struct journal_s___2 *, struct buffer_head___5 *, enum passtype, int, tid_t);
};

struct jbd2_inode___2 {
	transaction_t___2 *i_transaction;
	transaction_t___2 *i_next_transaction;
	struct list_head i_list;
	struct inode___132 *i_vfs_inode;
	long unsigned int i_flags;
	loff_t i_dirty_start;
	loff_t i_dirty_end;
};

enum {
	EXT4_INODE_SECRM = 0,
	EXT4_INODE_UNRM = 1,
	EXT4_INODE_COMPR = 2,
	EXT4_INODE_SYNC = 3,
	EXT4_INODE_IMMUTABLE = 4,
	EXT4_INODE_APPEND = 5,
	EXT4_INODE_NODUMP = 6,
	EXT4_INODE_NOATIME = 7,
	EXT4_INODE_DIRTY = 8,
	EXT4_INODE_COMPRBLK = 9,
	EXT4_INODE_NOCOMPR = 10,
	EXT4_INODE_ENCRYPT = 11,
	EXT4_INODE_INDEX = 12,
	EXT4_INODE_IMAGIC = 13,
	EXT4_INODE_JOURNAL_DATA = 14,
	EXT4_INODE_NOTAIL = 15,
	EXT4_INODE_DIRSYNC = 16,
	EXT4_INODE_TOPDIR = 17,
	EXT4_INODE_HUGE_FILE = 18,
	EXT4_INODE_EXTENTS = 19,
	EXT4_INODE_VERITY = 20,
	EXT4_INODE_EA_INODE = 21,
	EXT4_INODE_DAX = 25,
	EXT4_INODE_INLINE_DATA = 28,
	EXT4_INODE_PROJINHERIT = 29,
	EXT4_INODE_CASEFOLD = 30,
	EXT4_INODE_RESERVED = 31,
};

enum {
	EXT4_FC_REASON_XATTR = 0,
	EXT4_FC_REASON_CROSS_RENAME = 1,
	EXT4_FC_REASON_JOURNAL_FLAG_CHANGE = 2,
	EXT4_FC_REASON_NOMEM = 3,
	EXT4_FC_REASON_SWAP_BOOT = 4,
	EXT4_FC_REASON_RESIZE = 5,
	EXT4_FC_REASON_RENAME_DIR = 6,
	EXT4_FC_REASON_FALLOC_RANGE = 7,
	EXT4_FC_REASON_INODE_JOURNAL_DATA = 8,
	EXT4_FC_COMMIT_FAILED = 9,
	EXT4_FC_REASON_MAX = 10,
};

struct ext4_inode_info___2 {
	__le32 i_data[15];
	__u32 i_dtime;
	ext4_fsblk_t i_file_acl;
	ext4_group_t i_block_group;
	ext4_lblk_t i_dir_start_lookup;
	long unsigned int i_flags;
	struct rw_semaphore xattr_sem;
	union {
		struct list_head i_orphan;
		unsigned int i_orphan_idx;
	};
	struct list_head i_fc_list;
	ext4_lblk_t i_fc_lblk_start;
	ext4_lblk_t i_fc_lblk_len;
	atomic_t i_fc_updates;
	wait_queue_head_t i_fc_wait;
	struct mutex i_fc_lock;
	loff_t i_disksize;
	struct rw_semaphore i_data_sem;
	struct inode___132 vfs_inode;
	struct jbd2_inode___2 *jinode;
	spinlock_t i_raw_lock;
	struct timespec64 i_crtime;
	atomic_t i_prealloc_active;
	struct list_head i_prealloc_list;
	spinlock_t i_prealloc_lock;
	struct ext4_es_tree i_es_tree;
	rwlock_t i_es_lock;
	struct list_head i_es_list;
	unsigned int i_es_all_nr;
	unsigned int i_es_shk_nr;
	ext4_lblk_t i_es_shrink_lblk;
	ext4_group_t i_last_alloc_group;
	unsigned int i_reserved_data_blocks;
	struct ext4_pending_tree i_pending_tree;
	__u16 i_extra_isize;
	u16 i_inline_off;
	u16 i_inline_size;
	qsize_t i_reserved_quota;
	spinlock_t i_completed_io_lock;
	struct list_head i_rsv_conversion_list;
	struct work_struct i_rsv_conversion_work;
	atomic_t i_unwritten;
	spinlock_t i_block_reservation_lock;
	tid_t i_sync_tid;
	tid_t i_datasync_tid;
	struct dquot___132 *i_dquot[3];
	__u32 i_csum_seed;
	kprojid_t i_projid;
};

enum ext4_journal_trigger_type {
	EXT4_JTR_ORPHAN_FILE = 0,
	EXT4_JTR_NONE = 1,
};

struct ext4_journal_trigger___2 {
	struct jbd2_buffer_trigger_type___2 tr_triggers;
	struct super_block___132 *sb;
};

struct ext4_orphan_block___2 {
	atomic_t ob_free_entries;
	struct buffer_head___5 *ob_bh;
};

struct ext4_orphan_info___2 {
	int of_blocks;
	__u32 of_csum_seed;
	struct ext4_orphan_block___2 *of_binfo;
};

struct ext4_li_request___2;

struct ext4_sb_info___2 {
	long unsigned int s_desc_size;
	long unsigned int s_inodes_per_block;
	long unsigned int s_blocks_per_group;
	long unsigned int s_clusters_per_group;
	long unsigned int s_inodes_per_group;
	long unsigned int s_itb_per_group;
	long unsigned int s_gdb_count;
	long unsigned int s_desc_per_block;
	ext4_group_t s_groups_count;
	ext4_group_t s_blockfile_groups;
	long unsigned int s_overhead;
	unsigned int s_cluster_ratio;
	unsigned int s_cluster_bits;
	loff_t s_bitmap_maxbytes;
	struct buffer_head___5 *s_sbh;
	struct ext4_super_block *s_es;
	struct buffer_head___5 **s_group_desc;
	unsigned int s_mount_opt;
	unsigned int s_mount_opt2;
	long unsigned int s_mount_flags;
	unsigned int s_def_mount_opt;
	ext4_fsblk_t s_sb_block;
	atomic64_t s_resv_clusters;
	kuid_t s_resuid;
	kgid_t s_resgid;
	short unsigned int s_mount_state;
	short unsigned int s_pad;
	int s_addr_per_block_bits;
	int s_desc_per_block_bits;
	int s_inode_size;
	int s_first_ino;
	unsigned int s_inode_readahead_blks;
	unsigned int s_inode_goal;
	u32 s_hash_seed[4];
	int s_def_hash_version;
	int s_hash_unsigned;
	struct percpu_counter s_freeclusters_counter;
	struct percpu_counter s_freeinodes_counter;
	struct percpu_counter s_dirs_counter;
	struct percpu_counter s_dirtyclusters_counter;
	struct percpu_counter s_sra_exceeded_retry_limit;
	struct blockgroup_lock *s_blockgroup_lock;
	struct proc_dir_entry *s_proc;
	struct kobject___123 s_kobj;
	struct completion s_kobj_unregister;
	struct super_block___132 *s_sb;
	struct buffer_head___5 *s_mmp_bh;
	struct journal_s___2 *s_journal;
	long unsigned int s_ext4_flags;
	struct mutex s_orphan_lock;
	struct list_head s_orphan;
	struct ext4_orphan_info___2 s_orphan_info;
	long unsigned int s_commit_interval;
	u32 s_max_batch_time;
	u32 s_min_batch_time;
	struct block_device___60 *s_journal_bdev;
	char *s_qf_names[3];
	int s_jquota_fmt;
	unsigned int s_want_extra_isize;
	struct ext4_system_blocks *s_system_blks;
	struct ext4_group_info ***s_group_info;
	struct inode___132 *s_buddy_cache;
	spinlock_t s_md_lock;
	short unsigned int *s_mb_offsets;
	unsigned int *s_mb_maxs;
	unsigned int s_group_info_size;
	unsigned int s_mb_free_pending;
	struct list_head s_freed_data_list;
	struct list_head s_discard_list;
	struct work_struct s_discard_work;
	atomic_t s_retry_alloc_pending;
	struct rb_root s_mb_avg_fragment_size_root;
	rwlock_t s_mb_rb_lock;
	struct list_head *s_mb_largest_free_orders;
	rwlock_t *s_mb_largest_free_orders_locks;
	long unsigned int s_stripe;
	unsigned int s_mb_max_linear_groups;
	unsigned int s_mb_stream_request;
	unsigned int s_mb_max_to_scan;
	unsigned int s_mb_min_to_scan;
	unsigned int s_mb_stats;
	unsigned int s_mb_order2_reqs;
	unsigned int s_mb_group_prealloc;
	unsigned int s_mb_max_inode_prealloc;
	unsigned int s_max_dir_size_kb;
	long unsigned int s_mb_last_group;
	long unsigned int s_mb_last_start;
	unsigned int s_mb_prefetch;
	unsigned int s_mb_prefetch_limit;
	atomic_t s_bal_reqs;
	atomic_t s_bal_success;
	atomic_t s_bal_allocated;
	atomic_t s_bal_ex_scanned;
	atomic_t s_bal_groups_scanned;
	atomic_t s_bal_goals;
	atomic_t s_bal_breaks;
	atomic_t s_bal_2orders;
	atomic_t s_bal_cr0_bad_suggestions;
	atomic_t s_bal_cr1_bad_suggestions;
	atomic64_t s_bal_cX_groups_considered[4];
	atomic64_t s_bal_cX_hits[4];
	atomic64_t s_bal_cX_failed[4];
	atomic_t s_mb_buddies_generated;
	atomic64_t s_mb_generation_time;
	atomic_t s_mb_lost_chunks;
	atomic_t s_mb_preallocated;
	atomic_t s_mb_discarded;
	atomic_t s_lock_busy;
	struct ext4_locality_group *s_locality_groups;
	long unsigned int s_sectors_written_start;
	u64 s_kbytes_written;
	unsigned int s_extent_max_zeroout_kb;
	unsigned int s_log_groups_per_flex;
	struct flex_groups **s_flex_groups;
	ext4_group_t s_flex_groups_allocated;
	struct workqueue_struct *rsv_conversion_wq;
	struct timer_list s_err_report;
	struct ext4_li_request___2 *s_li_request;
	unsigned int s_li_wait_mult;
	struct task_struct___139 *s_mmp_tsk;
	atomic_t s_last_trim_minblks;
	struct crypto_shash___5 *s_chksum_driver;
	__u32 s_csum_seed;
	struct shrinker___50 s_es_shrinker;
	struct list_head s_es_list;
	long int s_es_nr_inode;
	struct ext4_es_stats s_es_stats;
	struct mb_cache___2 *s_ea_block_cache;
	struct mb_cache___2 *s_ea_inode_cache;
	long: 64;
	long: 64;
	spinlock_t s_es_lock;
	struct ext4_journal_trigger___2 s_journal_triggers[1];
	struct ratelimit_state s_err_ratelimit_state;
	struct ratelimit_state s_warning_ratelimit_state;
	struct ratelimit_state s_msg_ratelimit_state;
	atomic_t s_warning_count;
	atomic_t s_msg_count;
	struct fscrypt_dummy_policy s_dummy_enc_policy;
	struct percpu_rw_semaphore___133 s_writepages_rwsem;
	struct dax_device *s_daxdev;
	errseq_t s_bdev_wb_err;
	spinlock_t s_bdev_wb_lock;
	spinlock_t s_error_lock;
	int s_add_error_count;
	int s_first_error_code;
	__u32 s_first_error_line;
	__u32 s_first_error_ino;
	__u64 s_first_error_block;
	const char *s_first_error_func;
	time64_t s_first_error_time;
	int s_last_error_code;
	__u32 s_last_error_line;
	__u32 s_last_error_ino;
	__u64 s_last_error_block;
	const char *s_last_error_func;
	time64_t s_last_error_time;
	struct work_struct s_error_work;
	atomic_t s_fc_subtid;
	struct list_head s_fc_q[2];
	struct list_head s_fc_dentry_q[2];
	unsigned int s_fc_bytes;
	spinlock_t s_fc_lock;
	struct buffer_head___5 *s_fc_bh;
	struct ext4_fc_stats s_fc_stats;
	tid_t s_fc_ineligible_tid;
	struct ext4_fc_replay_state s_fc_replay_state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ext4_li_request___2 {
	struct super_block___132 *lr_super;
	enum ext4_li_mode lr_mode;
	ext4_group_t lr_first_not_zeroed;
	ext4_group_t lr_next_group;
	struct list_head lr_request;
	long unsigned int lr_next_sched;
	long unsigned int lr_timeout;
};

struct ext4_dir_entry_hash {
	__le32 hash;
	__le32 minor_hash;
};

struct ext4_dir_entry_2 {
	__le32 inode;
	__le16 rec_len;
	__u8 name_len;
	__u8 file_type;
	char name[255];
};

struct fname;

struct dir_private_info {
	struct rb_root root;
	struct rb_node *curr_node;
	struct fname *extra_fname;
	loff_t last_pos;
	__u32 curr_hash;
	__u32 curr_minor_hash;
	__u32 next_hash;
};

struct fname {
	__u32 hash;
	__u32 minor_hash;
	struct rb_node rb_hash;
	struct fname *next;
	__u32 inode;
	__u8 name_len;
	__u8 file_type;
	char name[0];
};

struct dentry___133;

struct super_block___133;

struct module___122;

struct file_system_type___133 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___133 * (*mount)(struct file_system_type___133 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___133 *);
	struct module___122 *owner;
	struct file_system_type___133 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___133;

struct kiocb___133;

struct iov_iter___74;

struct vm_area_struct___138;

struct inode___133;

struct file_lock___133;

struct page___138;

struct seq_file___115;

struct file_operations___133 {
	struct module___122 *owner;
	loff_t (*llseek)(struct file___133 *, loff_t, int);
	ssize_t (*read)(struct file___133 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___133 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___133 *, struct iov_iter___74 *);
	ssize_t (*write_iter)(struct kiocb___133 *, struct iov_iter___74 *);
	int (*iopoll)(struct kiocb___133 *, bool);
	int (*iterate)(struct file___133 *, struct dir_context *);
	int (*iterate_shared)(struct file___133 *, struct dir_context *);
	__poll_t (*poll)(struct file___133 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___133 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___133 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___133 *, struct vm_area_struct___138 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___133 *, struct file___133 *);
	int (*flush)(struct file___133 *, fl_owner_t);
	int (*release)(struct inode___133 *, struct file___133 *);
	int (*fsync)(struct file___133 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___133 *, int);
	int (*lock)(struct file___133 *, int, struct file_lock___133 *);
	ssize_t (*sendpage)(struct file___133 *, struct page___138 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___133 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___133 *, long unsigned int);
	int (*flock)(struct file___133 *, int, struct file_lock___133 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___133 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___133 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___133 *, long int, struct file_lock___133 **, void **);
	long int (*fallocate)(struct file___133 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___115 *, struct file___133 *);
	ssize_t (*copy_file_range)(struct file___133 *, loff_t, struct file___133 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___133 *, loff_t, struct file___133 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___133 *, loff_t, loff_t, int);
};

struct vmacache___138 {
	u64 seqnum;
	struct vm_area_struct___138 *vmas[4];
};

struct page_frag___138 {
	struct page___138 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___139;

struct pid___118;

struct nsproxy___124;

struct signal_struct___134;

struct bio_list___60;

struct backing_dev_info___57;

struct io_context___60;

struct css_set___94;

struct request_queue___60;

struct vm_struct___120;

struct task_struct___140 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___140 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___139 *mm;
	struct mm_struct___139 *active_mm;
	struct vmacache___138 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___140 *real_parent;
	struct task_struct___140 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___140 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___118 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___124 *nsproxy;
	struct signal_struct___134 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___140 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___60 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___57 *backing_dev_info;
	struct io_context___60 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___94 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___138 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___60 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___140 *oom_reaper_list;
	struct vm_struct___120 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___124;

struct kobj_type___124;

struct kernfs_node___124;

struct kobject___124 {
	const char *name;
	struct list_head entry;
	struct kobject___124 *parent;
	struct kset___124 *kset;
	struct kobj_type___124 *ktype;
	struct kernfs_node___124 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___121 {
	struct kobject___124 kobj;
	struct module___122 *mod;
	struct kobject___124 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___121 {
	struct module___122 *mod;
	struct latch_tree_node node;
};

struct module_layout___121 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___121 mtn;
};

struct module_attribute___121;

struct kernel_param___121;

struct module___122 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___121 mkobj;
	struct module_attribute___121 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___124 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___121 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___121 core_layout;
	struct module_layout___121 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___133;

struct dentry___133 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___133 *d_parent;
	struct qstr d_name;
	struct inode___133 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___133 *d_op;
	struct super_block___133 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___133;

struct address_space___133 {
	struct inode___133 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___133 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___133;

struct bdi_writeback___57;

struct inode___133 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___133 *i_op;
	struct super_block___133 *i_sb;
	struct address_space___133 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___57 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___133 *i_fop;
		void (*free_inode)(struct inode___133 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___133 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___133;

struct path___133;

struct dentry_operations___133 {
	int (*d_revalidate)(struct dentry___133 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___133 *, unsigned int);
	int (*d_hash)(const struct dentry___133 *, struct qstr *);
	int (*d_compare)(const struct dentry___133 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___133 *);
	int (*d_init)(struct dentry___133 *);
	void (*d_release)(struct dentry___133 *);
	void (*d_prune)(struct dentry___133 *);
	void (*d_iput)(struct dentry___133 *, struct inode___133 *);
	char * (*d_dname)(struct dentry___133 *, char *, int);
	struct vfsmount___133 * (*d_automount)(struct path___133 *);
	int (*d_manage)(const struct path___133 *, bool);
	struct dentry___133 * (*d_real)(struct dentry___133 *, const struct inode___133 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___133;

struct mem_dqinfo___133 {
	struct quota_format_type___133 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___133;

struct quota_info___133 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___133 *files[3];
	struct mem_dqinfo___133 info[3];
	const struct quota_format_ops___133 *ops[3];
};

struct rcuwait___134 {
	struct task_struct___140 *task;
};

struct percpu_rw_semaphore___134 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___134 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___133 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___134 rw_sem[3];
};

struct super_operations___133;

struct dquot_operations___133;

struct quotactl_ops___133;

struct xattr_handler___15;

struct fscrypt_operations___9;

struct fsverity_operations___7;

struct block_device___61;

struct super_block___133 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___133 *s_type;
	const struct super_operations___133 *s_op;
	const struct dquot_operations___133 *dq_op;
	const struct quotactl_ops___133 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___133 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___15 **s_xattr;
	const struct fscrypt_operations___9 *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___7 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___61 *s_bdev;
	struct backing_dev_info___57 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___133 s_dquot;
	struct sb_writers___133 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___133 *s_d_op;
	int cleancache_poolid;
	struct shrinker___50 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___133 {
	struct dentry___133 *mnt_root;
	struct super_block___133 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___133 {
	struct vfsmount___133 *mnt;
	struct dentry___133 *dentry;
};

struct pid_namespace___118;

struct upid___118 {
	int nr;
	struct pid_namespace___118 *ns;
};

struct pid_namespace___118 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___140 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___118 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___118 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___118 numbers[1];
};

typedef struct page___138 *pgtable_t___138;

struct dev_pagemap___131;

struct page___138 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___133 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___138 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___138 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___139 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___131 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___131;

struct vm_area_struct___138 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___138 *vm_next;
	struct vm_area_struct___138 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___139 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___131 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___133 *vm_file;
	struct file___133 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___134 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___140 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___140 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___118 *pids[4];
	struct pid___118 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___139 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___138;

struct mm_struct___139 {
	struct {
		struct vm_area_struct___138 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___133 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___138 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___140 *owner;
		struct user_namespace___19 *user_ns;
		struct file___133 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___94;

struct nsproxy___124 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___118 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___94 *cgroup_ns;
};

struct bio___60;

struct bio_list___60 {
	struct bio___60 *head;
	struct bio___60 *tail;
};

struct cgroup_subsys_state___94;

struct bdi_writeback___57 {
	struct backing_dev_info___57 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___94 *memcg_css;
	struct cgroup_subsys_state___94 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___98;

struct backing_dev_info___57 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___57 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___98 *dev;
	char dev_name[64];
	struct device___98 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___133 *debug_dir;
};

struct io_cq___60;

struct io_context___60 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___60 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___94;

struct css_set___94 {
	struct cgroup_subsys_state___94 *subsys[14];
	refcount_t refcount;
	struct css_set___94 *dom_cset;
	struct cgroup___94 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___94 *mg_src_cgrp;
	struct cgroup___94 *mg_dst_cgrp;
	struct css_set___94 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___60;

struct blk_integrity___60 {
	const struct blk_integrity_profile___60 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___60 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___60 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___60;

struct elevator_queue___60;

struct blk_mq_ops___57;

struct blk_mq_hw_ctx___57;

struct gendisk___60;

struct blkcg_gq___57;

struct blk_mq_tag_set___57;

struct request_queue___60 {
	struct request___60 *last_merge;
	struct elevator_queue___60 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___57 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___57 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___60 *disk;
	struct kobject___124 kobj;
	struct kobject___124 *mq_kobj;
	struct blk_integrity___60 integrity;
	struct device___98 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___57 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___57 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___60 bio_split;
	struct dentry___133 *debugfs_dir;
	struct dentry___133 *sched_debugfs_dir;
	struct dentry___133 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___120 {
	struct vm_struct___120 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___138 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___131;

struct dev_pagemap___131 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___131 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___118 {
	rwlock_t lock;
	struct pid___118 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___133 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___133 f_path;
	struct inode___133 *f_inode;
	const struct file_operations___133 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___118 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___133 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___131;

struct vm_operations_struct___131 {
	void (*open)(struct vm_area_struct___138 *);
	void (*close)(struct vm_area_struct___138 *);
	int (*may_split)(struct vm_area_struct___138 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___138 *);
	int (*mprotect)(struct vm_area_struct___138 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___131 *);
	vm_fault_t (*huge_fault)(struct vm_fault___131 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___131 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___138 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___131 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___131 *);
	int (*access)(struct vm_area_struct___138 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___138 *);
	int (*set_policy)(struct vm_area_struct___138 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___138 *, long unsigned int);
	struct page___138 * (*find_special_page)(struct vm_area_struct___138 *, long unsigned int);
};

struct core_thread___138 {
	struct task_struct___140 *task;
	struct core_thread___138 *next;
};

struct core_state___138 {
	atomic_t nr_threads;
	struct core_thread___138 dumper;
	struct completion startup;
};

struct vm_fault___131 {
	const struct {
		struct vm_area_struct___138 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___138 *cow_page;
	struct page___138 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___138 prealloc_pte;
};

struct cgroup_subsys___94;

struct cgroup_subsys_state___94 {
	struct cgroup___94 *cgroup;
	struct cgroup_subsys___94 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___94 *parent;
};

struct cgroup_file___94 {
	struct kernfs_node___124 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___94 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___140 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___94;

struct cgroup_rstat_cpu___94;

struct cgroup___94 {
	struct cgroup_subsys_state___94 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___124 *kn;
	struct cgroup_file___94 procs_file;
	struct cgroup_file___94 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___94 *subsys[14];
	struct cgroup_root___94 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___94 *dom_cgrp;
	struct cgroup___94 *old_dom_cgrp;
	struct cgroup_rstat_cpu___94 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___94 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___60 {
	struct request_queue___60 *q;
	struct io_context___60 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___6;

typedef void bh_end_io_t___6(struct buffer_head___6 *, int);

struct buffer_head___6 {
	long unsigned int b_state;
	struct buffer_head___6 *b_this_page;
	struct page___138 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___61 *b_bdev;
	bh_end_io_t___6 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___133 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___62;

struct kiocb___133 {
	struct file___133 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___133 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___62 *ki_waitq;
	};
};

struct iattr___133 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___133 *ia_file;
};

struct dquot___133 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___133 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___133 {
	int qf_fmt_id;
	const struct quota_format_ops___133 *qf_ops;
	struct module___122 *qf_owner;
	struct quota_format_type___133 *qf_next;
};

struct quota_format_ops___133 {
	int (*check_quota_file)(struct super_block___133 *, int);
	int (*read_file_info)(struct super_block___133 *, int);
	int (*write_file_info)(struct super_block___133 *, int);
	int (*free_file_info)(struct super_block___133 *, int);
	int (*read_dqblk)(struct dquot___133 *);
	int (*commit_dqblk)(struct dquot___133 *);
	int (*release_dqblk)(struct dquot___133 *);
	int (*get_next_id)(struct super_block___133 *, struct kqid *);
};

struct dquot_operations___133 {
	int (*write_dquot)(struct dquot___133 *);
	struct dquot___133 * (*alloc_dquot)(struct super_block___133 *, int);
	void (*destroy_dquot)(struct dquot___133 *);
	int (*acquire_dquot)(struct dquot___133 *);
	int (*release_dquot)(struct dquot___133 *);
	int (*mark_dirty)(struct dquot___133 *);
	int (*write_info)(struct super_block___133 *, int);
	qsize_t * (*get_reserved_space)(struct inode___133 *);
	int (*get_projid)(struct inode___133 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___133 *, qsize_t *);
	int (*get_next_id)(struct super_block___133 *, struct kqid *);
};

struct quotactl_ops___133 {
	int (*quota_on)(struct super_block___133 *, int, int, const struct path___133 *);
	int (*quota_off)(struct super_block___133 *, int);
	int (*quota_enable)(struct super_block___133 *, unsigned int);
	int (*quota_disable)(struct super_block___133 *, unsigned int);
	int (*quota_sync)(struct super_block___133 *, int);
	int (*set_info)(struct super_block___133 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___133 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___133 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___133 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___133 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___133 *, unsigned int);
};

struct wait_page_queue___62 {
	struct page___138 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___57;

struct readahead_control___62;

struct address_space_operations___133 {
	int (*writepage)(struct page___138 *, struct writeback_control___57 *);
	int (*readpage)(struct file___133 *, struct page___138 *);
	int (*writepages)(struct address_space___133 *, struct writeback_control___57 *);
	int (*set_page_dirty)(struct page___138 *);
	int (*readpages)(struct file___133 *, struct address_space___133 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___62 *);
	int (*write_begin)(struct file___133 *, struct address_space___133 *, loff_t, unsigned int, unsigned int, struct page___138 **, void **);
	int (*write_end)(struct file___133 *, struct address_space___133 *, loff_t, unsigned int, unsigned int, struct page___138 *, void *);
	sector_t (*bmap)(struct address_space___133 *, sector_t);
	void (*invalidatepage)(struct page___138 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___138 *, gfp_t);
	void (*freepage)(struct page___138 *);
	ssize_t (*direct_IO)(struct kiocb___133 *, struct iov_iter___74 *);
	int (*migratepage)(struct address_space___133 *, struct page___138 *, struct page___138 *, enum migrate_mode);
	bool (*isolate_page)(struct page___138 *, isolate_mode_t);
	void (*putback_page)(struct page___138 *);
	int (*launder_page)(struct page___138 *);
	int (*is_partially_uptodate)(struct page___138 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___138 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___133 *, struct page___138 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___133 *, sector_t *);
	void (*swap_deactivate)(struct file___133 *);
};

struct writeback_control___57 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___57 *wb;
	struct inode___133 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___62 {
	struct file___133 *file;
	struct address_space___133 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___72;

struct iov_iter___74 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___72 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___133 {
	struct dentry___133 * (*lookup)(struct inode___133 *, struct dentry___133 *, unsigned int);
	const char * (*get_link)(struct dentry___133 *, struct inode___133 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___133 *, int);
	struct posix_acl * (*get_acl)(struct inode___133 *, int, bool);
	int (*readlink)(struct dentry___133 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___133 *, struct dentry___133 *, umode_t, bool);
	int (*link)(struct dentry___133 *, struct inode___133 *, struct dentry___133 *);
	int (*unlink)(struct inode___133 *, struct dentry___133 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___133 *, struct dentry___133 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___133 *, struct dentry___133 *, umode_t);
	int (*rmdir)(struct inode___133 *, struct dentry___133 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___133 *, struct dentry___133 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___133 *, struct dentry___133 *, struct inode___133 *, struct dentry___133 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___133 *, struct iattr___133 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___133 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___133 *, char *, size_t);
	int (*fiemap)(struct inode___133 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___133 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___133 *, struct dentry___133 *, struct file___133 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___133 *, struct dentry___133 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___133 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___133 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___133 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___133 {
	void (*fl_copy_lock)(struct file_lock___133 *, struct file_lock___133 *);
	void (*fl_release_private)(struct file_lock___133 *);
};

struct fasync_struct___133;

struct lock_manager_operations___133;

struct file_lock___133 {
	struct file_lock___133 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___133 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___133 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___133 *fl_ops;
	const struct lock_manager_operations___133 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___133 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___133 *);
	int (*lm_grant)(struct file_lock___133 *, int);
	bool (*lm_break)(struct file_lock___133 *);
	int (*lm_change)(struct file_lock___133 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___133 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___133 *);
};

struct fasync_struct___133 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___133 *fa_next;
	struct file___133 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___133 {
	struct inode___133 * (*alloc_inode)(struct super_block___133 *);
	void (*destroy_inode)(struct inode___133 *);
	void (*free_inode)(struct inode___133 *);
	void (*dirty_inode)(struct inode___133 *, int);
	int (*write_inode)(struct inode___133 *, struct writeback_control___57 *);
	int (*drop_inode)(struct inode___133 *);
	void (*evict_inode)(struct inode___133 *);
	void (*put_super)(struct super_block___133 *);
	int (*sync_fs)(struct super_block___133 *, int);
	int (*freeze_super)(struct super_block___133 *);
	int (*freeze_fs)(struct super_block___133 *);
	int (*thaw_super)(struct super_block___133 *);
	int (*unfreeze_fs)(struct super_block___133 *);
	int (*statfs)(struct dentry___133 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___133 *, int *, char *);
	void (*umount_begin)(struct super_block___133 *);
	int (*show_options)(struct seq_file___115 *, struct dentry___133 *);
	int (*show_devname)(struct seq_file___115 *, struct dentry___133 *);
	int (*show_path)(struct seq_file___115 *, struct dentry___133 *);
	int (*show_stats)(struct seq_file___115 *, struct dentry___133 *);
	ssize_t (*quota_read)(struct super_block___133 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___133 *, int, const char *, size_t, loff_t);
	struct dquot___133 ** (*get_dquots)(struct inode___133 *);
	long int (*nr_cached_objects)(struct super_block___133 *, struct shrink_control___50 *);
	long int (*free_cached_objects)(struct super_block___133 *, struct shrink_control___50 *);
	struct file___133 * (*real_loop)(struct file___133 *);
};

struct xattr_handler___15 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___133 *);
	int (*get)(const struct xattr_handler___15 *, struct dentry___133 *, struct inode___133 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___15 *, struct user_namespace___19 *, struct dentry___133 *, struct inode___133 *, const char *, const void *, size_t, int);
};

struct fscrypt_operations___9 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___133 *, void *, size_t);
	int (*set_context)(struct inode___133 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___133 *);
	bool (*empty_dir)(struct inode___133 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___133 *);
	void (*get_ino_and_lblk_bits)(struct super_block___133 *, int *, int *);
	int (*get_num_devices)(struct super_block___133 *);
	void (*get_devices)(struct super_block___133 *, struct request_queue___60 **);
};

struct fsverity_operations___7 {
	int (*begin_enable_verity)(struct file___133 *);
	int (*end_enable_verity)(struct file___133 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___133 *, void *, size_t);
	struct page___138 * (*read_merkle_tree_page)(struct inode___133 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___133 *, const void *, u64, int);
};

struct wakeup_source___98;

struct dev_pm_info___98 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___98 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___98 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___98;

struct bus_type___98;

struct device_driver___98;

struct dev_pm_domain___98;

struct fwnode_handle___98;

struct class___98;

struct attribute_group___124;

struct device___98 {
	struct kobject___124 kobj;
	struct device___98 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___98 *type;
	struct bus_type___98 *bus;
	struct device_driver___98 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___98 power;
	struct dev_pm_domain___98 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___98 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___98 *class;
	const struct attribute_group___124 **groups;
	void (*release)(struct device___98 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___61 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___133 *bd_inode;
	struct super_block___133 *bd_super;
	void *bd_claiming;
	struct device___98 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___124 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___60 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___133 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___115;

struct seq_file___115 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___115 *op;
	int poll_event;
	const struct file___133 *file;
	void *private;
};

typedef void bio_end_io_t___60(struct bio___60 *);

struct bio_vec___72 {
	struct page___138 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___60;

struct bio___60 {
	struct bio___60 *bi_next;
	struct block_device___61 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___60 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___57 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___60 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___72 *bi_io_vec;
	struct bio_set___60 *bi_pool;
	struct bio_vec___72 bi_inline_vecs[0];
};

struct dev_pagemap_ops___131 {
	void (*page_free)(struct page___138 *);
	void (*kill)(struct dev_pagemap___131 *);
	void (*cleanup)(struct dev_pagemap___131 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___131 *);
};

struct fwnode_operations___98;

struct fwnode_handle___98 {
	struct fwnode_handle___98 *secondary;
	const struct fwnode_operations___98 *ops;
	struct device___98 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___98;

struct fwnode_endpoint___98;

struct fwnode_operations___98 {
	struct fwnode_handle___98 * (*get)(struct fwnode_handle___98 *);
	void (*put)(struct fwnode_handle___98 *);
	bool (*device_is_available)(const struct fwnode_handle___98 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___98 *, const struct device___98 *);
	bool (*property_present)(const struct fwnode_handle___98 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___98 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___98 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___98 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*get_parent)(const struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*get_next_child_node)(const struct fwnode_handle___98 *, struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*get_named_child_node)(const struct fwnode_handle___98 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___98 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___98 *);
	struct fwnode_handle___98 * (*graph_get_next_endpoint)(const struct fwnode_handle___98 *, struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*graph_get_remote_endpoint)(const struct fwnode_handle___98 *);
	struct fwnode_handle___98 * (*graph_get_port_parent)(struct fwnode_handle___98 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___98 *, struct fwnode_endpoint___98 *);
	int (*add_links)(struct fwnode_handle___98 *);
};

struct fwnode_endpoint___98 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___98 *local_fwnode;
};

struct fwnode_reference_args___98 {
	struct fwnode_handle___98 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___124;

struct kernfs_elem_dir___124 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___124 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___124;

struct kernfs_root___124 {
	struct kernfs_node___124 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___124 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___124 {
	struct kernfs_node___124 *target_kn;
};

struct kernfs_ops___124;

struct kernfs_elem_attr___124 {
	const struct kernfs_ops___124 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___124 *notify_next;
};

struct kernfs_node___124 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___124 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___124 dir;
		struct kernfs_elem_symlink___124 symlink;
		struct kernfs_elem_attr___124 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___124;

struct kernfs_ops___124 {
	int (*open)(struct kernfs_open_file___124 *);
	void (*release)(struct kernfs_open_file___124 *);
	int (*seq_show)(struct seq_file___115 *, void *);
	void * (*seq_start)(struct seq_file___115 *, loff_t *);
	void * (*seq_next)(struct seq_file___115 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___115 *, void *);
	ssize_t (*read)(struct kernfs_open_file___124 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___124 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___124 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___124 *, struct vm_area_struct___138 *);
};

struct kernfs_syscall_ops___124 {
	int (*show_options)(struct seq_file___115 *, struct kernfs_root___124 *);
	int (*mkdir)(struct kernfs_node___124 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___124 *);
	int (*rename)(struct kernfs_node___124 *, struct kernfs_node___124 *, const char *);
	int (*show_path)(struct seq_file___115 *, struct kernfs_node___124 *, struct kernfs_root___124 *);
};

struct kernfs_open_file___124 {
	struct kernfs_node___124 *kn;
	struct file___133 *file;
	struct seq_file___115 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___131 *vm_ops;
};

struct bin_attribute___124;

struct attribute_group___124 {
	const char *name;
	umode_t (*is_visible)(struct kobject___124 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___124 *, struct bin_attribute___124 *, int);
	struct attribute **attrs;
	struct bin_attribute___124 **bin_attrs;
};

struct bin_attribute___124 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___133 * (*f_mapping)();
	ssize_t (*read)(struct file___133 *, struct kobject___124 *, struct bin_attribute___124 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___133 *, struct kobject___124 *, struct bin_attribute___124 *, char *, loff_t, size_t);
	int (*mmap)(struct file___133 *, struct kobject___124 *, struct bin_attribute___124 *, struct vm_area_struct___138 *);
};

struct sysfs_ops___124 {
	ssize_t (*show)(struct kobject___124 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___124 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___124;

struct kset___124 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___124 kobj;
	const struct kset_uevent_ops___124 *uevent_ops;
};

struct kobj_type___124 {
	void (*release)(struct kobject___124 *);
	const struct sysfs_ops___124 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___124 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___124 *);
	const void * (*namespace)(struct kobject___124 *);
	void (*get_ownership)(struct kobject___124 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___124 {
	int (* const filter)(struct kset___124 *, struct kobject___124 *);
	const char * (* const name)(struct kset___124 *, struct kobject___124 *);
	int (* const uevent)(struct kset___124 *, struct kobject___124 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___121 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___121 *);
	int (*get)(char *, const struct kernel_param___121 *);
	void (*free)(void *);
};

struct kparam_array___121;

struct kernel_param___121 {
	const char *name;
	struct module___122 *mod;
	const struct kernel_param_ops___121 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___121 *arr;
	};
};

struct kparam_array___121 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___121 *ops;
	void *elem;
};

struct module_attribute___121 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___121 *, struct module_kobject___121 *, char *);
	ssize_t (*store)(struct module_attribute___121 *, struct module_kobject___121 *, const char *, size_t);
	void (*setup)(struct module___122 *, const char *);
	int (*test)(struct module___122 *);
	void (*free)(struct module___122 *);
};

struct cgroup_namespace___94 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___94 *root_cset;
};

struct journal_s___3;

typedef struct journal_s___3 journal_t___3;

struct journal_head___3;

struct transaction_s___3;

typedef struct transaction_s___3 transaction_t___3;

struct transaction_s___3 {
	journal_t___3 *t_journal;
	tid_t t_tid;
	enum {
		T_RUNNING___3 = 0,
		T_LOCKED___3 = 1,
		T_SWITCH___3 = 2,
		T_FLUSH___3 = 3,
		T_COMMIT___3 = 4,
		T_COMMIT_DFLUSH___3 = 5,
		T_COMMIT_JFLUSH___3 = 6,
		T_COMMIT_CALLBACK___3 = 7,
		T_FINISHED___3 = 8,
	} t_state;
	long unsigned int t_log_start;
	int t_nr_buffers;
	struct journal_head___3 *t_reserved_list;
	struct journal_head___3 *t_buffers;
	struct journal_head___3 *t_forget;
	struct journal_head___3 *t_checkpoint_list;
	struct journal_head___3 *t_checkpoint_io_list;
	struct journal_head___3 *t_shadow_list;
	struct list_head t_inode_list;
	spinlock_t t_handle_lock;
	long unsigned int t_max_wait;
	long unsigned int t_start;
	long unsigned int t_requested;
	struct transaction_chp_stats_s t_chp_stats;
	atomic_t t_updates;
	atomic_t t_outstanding_credits;
	atomic_t t_outstanding_revokes;
	atomic_t t_handle_count;
	transaction_t___3 *t_cpnext;
	transaction_t___3 *t_cpprev;
	long unsigned int t_expires;
	ktime_t t_start_time;
	unsigned int t_synchronous_commit: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int t_need_data_flush;
	struct list_head t_private_list;
};

struct jbd2_buffer_trigger_type___3;

struct journal_head___3 {
	struct buffer_head___6 *b_bh;
	spinlock_t b_state_lock;
	int b_jcount;
	unsigned int b_jlist;
	unsigned int b_modified;
	char *b_frozen_data;
	char *b_committed_data;
	transaction_t___3 *b_transaction;
	transaction_t___3 *b_next_transaction;
	struct journal_head___3 *b_tnext;
	struct journal_head___3 *b_tprev;
	transaction_t___3 *b_cp_transaction;
	struct journal_head___3 *b_cpnext;
	struct journal_head___3 *b_cpprev;
	struct jbd2_buffer_trigger_type___3 *b_triggers;
	struct jbd2_buffer_trigger_type___3 *b_frozen_triggers;
};

struct jbd2_buffer_trigger_type___3 {
	void (*t_frozen)(struct jbd2_buffer_trigger_type___3 *, struct buffer_head___6 *, void *, size_t);
	void (*t_abort)(struct jbd2_buffer_trigger_type___3 *, struct buffer_head___6 *);
};

struct dev_pm_ops___98 {
	int (*prepare)(struct device___98 *);
	void (*complete)(struct device___98 *);
	int (*suspend)(struct device___98 *);
	int (*resume)(struct device___98 *);
	int (*freeze)(struct device___98 *);
	int (*thaw)(struct device___98 *);
	int (*poweroff)(struct device___98 *);
	int (*restore)(struct device___98 *);
	int (*suspend_late)(struct device___98 *);
	int (*resume_early)(struct device___98 *);
	int (*freeze_late)(struct device___98 *);
	int (*thaw_early)(struct device___98 *);
	int (*poweroff_late)(struct device___98 *);
	int (*restore_early)(struct device___98 *);
	int (*suspend_noirq)(struct device___98 *);
	int (*resume_noirq)(struct device___98 *);
	int (*freeze_noirq)(struct device___98 *);
	int (*thaw_noirq)(struct device___98 *);
	int (*poweroff_noirq)(struct device___98 *);
	int (*restore_noirq)(struct device___98 *);
	int (*runtime_suspend)(struct device___98 *);
	int (*runtime_resume)(struct device___98 *);
	int (*runtime_idle)(struct device___98 *);
};

struct wakeup_source___98 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___98 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___98 {
	struct dev_pm_ops___98 ops;
	int (*start)(struct device___98 *);
	void (*detach)(struct device___98 *, bool);
	int (*activate)(struct device___98 *);
	void (*sync)(struct device___98 *);
	void (*dismiss)(struct device___98 *);
};

struct bus_type___98 {
	const char *name;
	const char *dev_name;
	struct device___98 *dev_root;
	const struct attribute_group___124 **bus_groups;
	const struct attribute_group___124 **dev_groups;
	const struct attribute_group___124 **drv_groups;
	int (*match)(struct device___98 *, struct device_driver___98 *);
	int (*uevent)(struct device___98 *, struct kobj_uevent_env *);
	int (*probe)(struct device___98 *);
	void (*sync_state)(struct device___98 *);
	void (*remove)(struct device___98 *);
	void (*shutdown)(struct device___98 *);
	int (*online)(struct device___98 *);
	int (*offline)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	int (*num_vf)(struct device___98 *);
	int (*dma_configure)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___98 {
	const char *name;
	struct bus_type___98 *bus;
	struct module___122 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___98 *);
	void (*sync_state)(struct device___98 *);
	int (*remove)(struct device___98 *);
	void (*shutdown)(struct device___98 *);
	int (*suspend)(struct device___98 *, pm_message_t);
	int (*resume)(struct device___98 *);
	const struct attribute_group___124 **groups;
	const struct attribute_group___124 **dev_groups;
	const struct dev_pm_ops___98 *pm;
	void (*coredump)(struct device___98 *);
	struct driver_private *p;
};

struct device_type___98 {
	const char *name;
	const struct attribute_group___124 **groups;
	int (*uevent)(struct device___98 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___98 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___98 *);
	const struct dev_pm_ops___98 *pm;
};

struct class___98 {
	const char *name;
	struct module___122 *owner;
	const struct attribute_group___124 **class_groups;
	const struct attribute_group___124 **dev_groups;
	struct kobject___124 *dev_kobj;
	int (*dev_uevent)(struct device___98 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___98 *, umode_t *);
	void (*class_release)(struct class___98 *);
	void (*dev_release)(struct device___98 *);
	int (*shutdown_pre)(struct device___98 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___98 *);
	void (*get_ownership)(struct device___98 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___98 *pm;
	struct subsys_private *p;
};

struct block_device_operations___60;

struct gendisk___60 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___61 *part0;
	const struct block_device_operations___60 *fops;
	struct request_queue___60 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___57 *bdi;
	struct kobject___124 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___124 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___60 {
	struct bio___60 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___72 *bip_vec;
	struct bio_vec___72 bip_inline_vecs[0];
};

struct blkcg___57;

struct blkg_policy_data___57;

struct blkcg_gq___57 {
	struct request_queue___60 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___57 *blkcg;
	struct blkcg_gq___57 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___57 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___60 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___60(struct request___60 *);

typedef void integrity_complete_fn___60(struct request___60 *, unsigned int);

struct blk_integrity_profile___60 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___60 *prepare_fn;
	integrity_complete_fn___60 *complete_fn;
	const char *name;
};

struct block_device_operations___60 {
	blk_qc_t (*submit_bio)(struct bio___60 *);
	int (*open)(struct block_device___61 *, fmode_t);
	void (*release)(struct gendisk___60 *, fmode_t);
	int (*rw_page)(struct block_device___61 *, sector_t, struct page___138 *, unsigned int);
	int (*ioctl)(struct block_device___61 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___61 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___60 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___60 *);
	int (*getgeo)(struct block_device___61 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___61 *, bool);
	void (*swap_slot_free_notify)(struct block_device___61 *, long unsigned int);
	int (*report_zones)(struct gendisk___60 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___60 *, umode_t *);
	struct module___122 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___60 *, sector_t *);
};

typedef void rq_end_io_fn___60(struct request___60 *, blk_status_t);

struct request___60 {
	struct request_queue___60 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___57 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___60 *bio;
	struct bio___60 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___72 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___60 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___60 *saved_end_io;
		} flush;
	};
	struct gendisk___60 *rq_disk;
	struct block_device___61 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___60 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___57 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___60 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___124 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___133 *debugfs_dir;
	struct dentry___133 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___60;

struct elevator_mq_ops___60 {
	int (*init_sched)(struct request_queue___60 *, struct elevator_type___60 *);
	void (*exit_sched)(struct elevator_queue___60 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___57 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___57 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___57 *);
	bool (*allow_merge)(struct request_queue___60 *, struct request___60 *, struct bio___60 *);
	bool (*bio_merge)(struct request_queue___60 *, struct bio___60 *, unsigned int);
	int (*request_merge)(struct request_queue___60 *, struct request___60 **, struct bio___60 *);
	void (*request_merged)(struct request_queue___60 *, struct request___60 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___60 *, struct request___60 *, struct request___60 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___60 *);
	void (*finish_request)(struct request___60 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___57 *, struct list_head *, bool);
	struct request___60 * (*dispatch_request)(struct blk_mq_hw_ctx___57 *);
	bool (*has_work)(struct blk_mq_hw_ctx___57 *);
	void (*completed_request)(struct request___60 *, u64);
	void (*requeue_request)(struct request___60 *);
	struct request___60 * (*former_request)(struct request_queue___60 *, struct request___60 *);
	struct request___60 * (*next_request)(struct request_queue___60 *, struct request___60 *);
	void (*init_icq)(struct io_cq___60 *);
	void (*exit_icq)(struct io_cq___60 *);
};

struct elv_fs_entry___60;

struct elevator_type___60 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___60 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___60 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___122 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___60 {
	struct elevator_type___60 *type;
	void *elevator_data;
	struct kobject___124 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___60 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___60 *, char *);
	ssize_t (*store)(struct elevator_queue___60 *, const char *, size_t);
};

struct blk_mq_queue_data___57;

struct blk_mq_ops___57 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___57 *, const struct blk_mq_queue_data___57 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___57 *);
	int (*get_budget)(struct request_queue___60 *);
	void (*put_budget)(struct request_queue___60 *, int);
	void (*set_rq_budget_token)(struct request___60 *, int);
	int (*get_rq_budget_token)(struct request___60 *);
	enum blk_eh_timer_return (*timeout)(struct request___60 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___57 *);
	void (*complete)(struct request___60 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___57 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___57 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___57 *, struct request___60 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___57 *, struct request___60 *, unsigned int);
	void (*initialize_rq_fn)(struct request___60 *);
	void (*cleanup_rq)(struct request___60 *);
	bool (*busy)(struct request_queue___60 *);
	int (*map_queues)(struct blk_mq_tag_set___57 *);
	void (*show_rq)(struct seq_file___115 *, struct request___60 *);
};

struct blk_mq_tag_set___57 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___57 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct crypto_alg___7;

struct crypto_tfm___7 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___7 *);
	struct crypto_alg___7 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___7 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___7 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___7 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___7 *, u8 *, const u8 *);
};

struct compress_alg___7 {
	int (*coa_compress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___7 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___7 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___7 cipher;
		struct compress_alg___7 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___7 *);
	void (*cra_exit)(struct crypto_tfm___7 *);
	void (*cra_destroy)(struct crypto_alg___7 *);
	struct module___122 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___6;

struct shash_desc___4 {
	struct crypto_shash___6 *tfm;
	void *__ctx[0];
};

struct crypto_shash___6 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___7 base;
};

struct jbd2_journal_handle___3;

typedef struct jbd2_journal_handle___3 handle_t___3;

struct jbd2_journal_handle___3 {
	union {
		transaction_t___3 *h_transaction;
		journal_t___3 *h_journal;
	};
	handle_t___3 *h_rsv_handle;
	int h_total_credits;
	int h_revoke_credits;
	int h_revoke_credits_requested;
	int h_ref;
	int h_err;
	unsigned int h_sync: 1;
	unsigned int h_jdata: 1;
	unsigned int h_reserved: 1;
	unsigned int h_aborted: 1;
	unsigned int h_type: 8;
	unsigned int h_line_no: 16;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int h_start_jiffies;
	unsigned int h_requested_credits;
	unsigned int saved_alloc_context;
};

struct jbd2_inode___3;

struct journal_s___3 {
	long unsigned int j_flags;
	long unsigned int j_atomic_flags;
	int j_errno;
	struct mutex j_abort_mutex;
	struct buffer_head___6 *j_sb_buffer;
	journal_superblock_t *j_superblock;
	int j_format_version;
	rwlock_t j_state_lock;
	int j_barrier_count;
	struct mutex j_barrier;
	transaction_t___3 *j_running_transaction;
	transaction_t___3 *j_committing_transaction;
	transaction_t___3 *j_checkpoint_transactions;
	wait_queue_head_t j_wait_transaction_locked;
	wait_queue_head_t j_wait_done_commit;
	wait_queue_head_t j_wait_commit;
	wait_queue_head_t j_wait_updates;
	wait_queue_head_t j_wait_reserved;
	wait_queue_head_t j_fc_wait;
	struct mutex j_checkpoint_mutex;
	struct buffer_head___6 *j_chkpt_bhs[64];
	struct shrinker___50 j_shrinker;
	struct percpu_counter j_checkpoint_jh_count;
	transaction_t___3 *j_shrink_transaction;
	long unsigned int j_head;
	long unsigned int j_tail;
	long unsigned int j_free;
	long unsigned int j_first;
	long unsigned int j_last;
	long unsigned int j_fc_first;
	long unsigned int j_fc_off;
	long unsigned int j_fc_last;
	struct block_device___61 *j_dev;
	int j_blocksize;
	long long unsigned int j_blk_offset;
	char j_devname[56];
	struct block_device___61 *j_fs_dev;
	unsigned int j_total_len;
	atomic_t j_reserved_credits;
	spinlock_t j_list_lock;
	struct inode___133 *j_inode;
	tid_t j_tail_sequence;
	tid_t j_transaction_sequence;
	tid_t j_commit_sequence;
	tid_t j_commit_request;
	__u8 j_uuid[16];
	struct task_struct___140 *j_task;
	int j_max_transaction_buffers;
	int j_revoke_records_per_block;
	long unsigned int j_commit_interval;
	struct timer_list j_commit_timer;
	spinlock_t j_revoke_lock;
	struct jbd2_revoke_table_s *j_revoke;
	struct jbd2_revoke_table_s *j_revoke_table[2];
	struct buffer_head___6 **j_wbuf;
	struct buffer_head___6 **j_fc_wbuf;
	int j_wbufsize;
	int j_fc_wbufsize;
	pid_t j_last_sync_writer;
	u64 j_average_commit_time;
	u32 j_min_batch_time;
	u32 j_max_batch_time;
	void (*j_commit_callback)(journal_t___3 *, transaction_t___3 *);
	int (*j_submit_inode_data_buffers)(struct jbd2_inode___3 *);
	int (*j_finish_inode_data_buffers)(struct jbd2_inode___3 *);
	spinlock_t j_history_lock;
	struct proc_dir_entry *j_proc_entry;
	struct transaction_stats_s j_stats;
	unsigned int j_failed_commit;
	void *j_private;
	struct crypto_shash___6 *j_chksum_driver;
	__u32 j_csum_seed;
	void (*j_fc_cleanup_callback)(struct journal_s___3 *, int, tid_t);
	int (*j_fc_replay_callback)(struct journal_s___3 *, struct buffer_head___6 *, enum passtype, int, tid_t);
};

struct jbd2_inode___3 {
	transaction_t___3 *i_transaction;
	transaction_t___3 *i_next_transaction;
	struct list_head i_list;
	struct inode___133 *i_vfs_inode;
	long unsigned int i_flags;
	loff_t i_dirty_start;
	loff_t i_dirty_end;
};

struct seq_operations___115 {
	void * (*start)(struct seq_file___115 *, loff_t *);
	void (*stop)(struct seq_file___115 *, void *);
	void * (*next)(struct seq_file___115 *, void *, loff_t *);
	int (*show)(struct seq_file___115 *, void *);
};

struct cftype___94;

struct cgroup_subsys___94 {
	struct cgroup_subsys_state___94 * (*css_alloc)(struct cgroup_subsys_state___94 *);
	int (*css_online)(struct cgroup_subsys_state___94 *);
	void (*css_offline)(struct cgroup_subsys_state___94 *);
	void (*css_released)(struct cgroup_subsys_state___94 *);
	void (*css_free)(struct cgroup_subsys_state___94 *);
	void (*css_reset)(struct cgroup_subsys_state___94 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___94 *, int);
	int (*css_extra_stat_show)(struct seq_file___115 *, struct cgroup_subsys_state___94 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___140 *, struct css_set___94 *);
	void (*cancel_fork)(struct task_struct___140 *, struct css_set___94 *);
	void (*fork)(struct task_struct___140 *);
	void (*exit)(struct task_struct___140 *);
	void (*release)(struct task_struct___140 *);
	void (*bind)(struct cgroup_subsys_state___94 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___94 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___94 *dfl_cftypes;
	struct cftype___94 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___94 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___94 *updated_children;
	struct cgroup___94 *updated_next;
};

struct cgroup_root___94 {
	struct kernfs_root___124 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___94 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___94 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___94 *ss;
	struct list_head node;
	struct kernfs_ops___124 *kf_ops;
	int (*open)(struct kernfs_open_file___124 *);
	void (*release)(struct kernfs_open_file___124 *);
	u64 (*read_u64)(struct cgroup_subsys_state___94 *, struct cftype___94 *);
	s64 (*read_s64)(struct cgroup_subsys_state___94 *, struct cftype___94 *);
	int (*seq_show)(struct seq_file___115 *, void *);
	void * (*seq_start)(struct seq_file___115 *, loff_t *);
	void * (*seq_next)(struct seq_file___115 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___115 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___94 *, struct cftype___94 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___94 *, struct cftype___94 *, s64);
	ssize_t (*write)(struct kernfs_open_file___124 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___124 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___57 {
	struct request___60 *rq;
	bool last;
};

struct blkcg_policy_data___57;

struct blkcg___57 {
	struct cgroup_subsys_state___94 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___57 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___57 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___57 {
	struct blkcg___57 *blkcg;
	int plid;
};

struct blkg_policy_data___57 {
	struct blkcg_gq___57 *blkg;
	int plid;
};

struct iomap_page_ops___3;

struct iomap___4 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___61 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops___3 *page_ops;
};

struct iomap_page_ops___3 {
	int (*page_prepare)(struct inode___133 *, loff_t, unsigned int);
	void (*page_done)(struct inode___133 *, loff_t, unsigned int, struct page___138 *);
};

struct iomap_ops___3 {
	int (*iomap_begin)(struct inode___133 *, loff_t, loff_t, unsigned int, struct iomap___4 *, struct iomap___4 *);
	int (*iomap_end)(struct inode___133 *, loff_t, loff_t, ssize_t, unsigned int, struct iomap___4 *);
};

enum SHIFT_DIRECTION {
	SHIFT_LEFT = 0,
	SHIFT_RIGHT = 1,
};

struct ext4_allocation_request___2 {
	struct inode___133 *inode;
	unsigned int len;
	ext4_lblk_t logical;
	ext4_lblk_t lleft;
	ext4_lblk_t lright;
	ext4_fsblk_t goal;
	ext4_fsblk_t pleft;
	ext4_fsblk_t pright;
	unsigned int flags;
};

struct ext4_io_end_vec {
	struct list_head list;
	loff_t offset;
	ssize_t size;
};

struct ext4_io_end {
	struct list_head list;
	handle_t___3 *handle;
	struct inode___133 *inode;
	struct bio___60 *bio;
	unsigned int flag;
	atomic_t count;
	struct list_head list_vec;
};

typedef struct ext4_io_end ext4_io_end_t;

enum {
	ES_WRITTEN_B = 0,
	ES_UNWRITTEN_B = 1,
	ES_DELAYED_B = 2,
	ES_HOLE_B = 3,
	ES_REFERENCED_B = 4,
	ES_FLAGS = 5,
};

struct ext4_inode_info___3 {
	__le32 i_data[15];
	__u32 i_dtime;
	ext4_fsblk_t i_file_acl;
	ext4_group_t i_block_group;
	ext4_lblk_t i_dir_start_lookup;
	long unsigned int i_flags;
	struct rw_semaphore xattr_sem;
	union {
		struct list_head i_orphan;
		unsigned int i_orphan_idx;
	};
	struct list_head i_fc_list;
	ext4_lblk_t i_fc_lblk_start;
	ext4_lblk_t i_fc_lblk_len;
	atomic_t i_fc_updates;
	wait_queue_head_t i_fc_wait;
	struct mutex i_fc_lock;
	loff_t i_disksize;
	struct rw_semaphore i_data_sem;
	struct inode___133 vfs_inode;
	struct jbd2_inode___3 *jinode;
	spinlock_t i_raw_lock;
	struct timespec64 i_crtime;
	atomic_t i_prealloc_active;
	struct list_head i_prealloc_list;
	spinlock_t i_prealloc_lock;
	struct ext4_es_tree i_es_tree;
	rwlock_t i_es_lock;
	struct list_head i_es_list;
	unsigned int i_es_all_nr;
	unsigned int i_es_shk_nr;
	ext4_lblk_t i_es_shrink_lblk;
	ext4_group_t i_last_alloc_group;
	unsigned int i_reserved_data_blocks;
	struct ext4_pending_tree i_pending_tree;
	__u16 i_extra_isize;
	u16 i_inline_off;
	u16 i_inline_size;
	qsize_t i_reserved_quota;
	spinlock_t i_completed_io_lock;
	struct list_head i_rsv_conversion_list;
	struct work_struct i_rsv_conversion_work;
	atomic_t i_unwritten;
	spinlock_t i_block_reservation_lock;
	tid_t i_sync_tid;
	tid_t i_datasync_tid;
	struct dquot___133 *i_dquot[3];
	__u32 i_csum_seed;
	kprojid_t i_projid;
};

struct ext4_journal_trigger___3 {
	struct jbd2_buffer_trigger_type___3 tr_triggers;
	struct super_block___133 *sb;
};

struct ext4_orphan_block___3 {
	atomic_t ob_free_entries;
	struct buffer_head___6 *ob_bh;
};

struct ext4_orphan_info___3 {
	int of_blocks;
	__u32 of_csum_seed;
	struct ext4_orphan_block___3 *of_binfo;
};

struct ext4_li_request___3;

struct ext4_sb_info___3 {
	long unsigned int s_desc_size;
	long unsigned int s_inodes_per_block;
	long unsigned int s_blocks_per_group;
	long unsigned int s_clusters_per_group;
	long unsigned int s_inodes_per_group;
	long unsigned int s_itb_per_group;
	long unsigned int s_gdb_count;
	long unsigned int s_desc_per_block;
	ext4_group_t s_groups_count;
	ext4_group_t s_blockfile_groups;
	long unsigned int s_overhead;
	unsigned int s_cluster_ratio;
	unsigned int s_cluster_bits;
	loff_t s_bitmap_maxbytes;
	struct buffer_head___6 *s_sbh;
	struct ext4_super_block *s_es;
	struct buffer_head___6 **s_group_desc;
	unsigned int s_mount_opt;
	unsigned int s_mount_opt2;
	long unsigned int s_mount_flags;
	unsigned int s_def_mount_opt;
	ext4_fsblk_t s_sb_block;
	atomic64_t s_resv_clusters;
	kuid_t s_resuid;
	kgid_t s_resgid;
	short unsigned int s_mount_state;
	short unsigned int s_pad;
	int s_addr_per_block_bits;
	int s_desc_per_block_bits;
	int s_inode_size;
	int s_first_ino;
	unsigned int s_inode_readahead_blks;
	unsigned int s_inode_goal;
	u32 s_hash_seed[4];
	int s_def_hash_version;
	int s_hash_unsigned;
	struct percpu_counter s_freeclusters_counter;
	struct percpu_counter s_freeinodes_counter;
	struct percpu_counter s_dirs_counter;
	struct percpu_counter s_dirtyclusters_counter;
	struct percpu_counter s_sra_exceeded_retry_limit;
	struct blockgroup_lock *s_blockgroup_lock;
	struct proc_dir_entry *s_proc;
	struct kobject___124 s_kobj;
	struct completion s_kobj_unregister;
	struct super_block___133 *s_sb;
	struct buffer_head___6 *s_mmp_bh;
	struct journal_s___3 *s_journal;
	long unsigned int s_ext4_flags;
	struct mutex s_orphan_lock;
	struct list_head s_orphan;
	struct ext4_orphan_info___3 s_orphan_info;
	long unsigned int s_commit_interval;
	u32 s_max_batch_time;
	u32 s_min_batch_time;
	struct block_device___61 *s_journal_bdev;
	char *s_qf_names[3];
	int s_jquota_fmt;
	unsigned int s_want_extra_isize;
	struct ext4_system_blocks *s_system_blks;
	struct ext4_group_info ***s_group_info;
	struct inode___133 *s_buddy_cache;
	spinlock_t s_md_lock;
	short unsigned int *s_mb_offsets;
	unsigned int *s_mb_maxs;
	unsigned int s_group_info_size;
	unsigned int s_mb_free_pending;
	struct list_head s_freed_data_list;
	struct list_head s_discard_list;
	struct work_struct s_discard_work;
	atomic_t s_retry_alloc_pending;
	struct rb_root s_mb_avg_fragment_size_root;
	rwlock_t s_mb_rb_lock;
	struct list_head *s_mb_largest_free_orders;
	rwlock_t *s_mb_largest_free_orders_locks;
	long unsigned int s_stripe;
	unsigned int s_mb_max_linear_groups;
	unsigned int s_mb_stream_request;
	unsigned int s_mb_max_to_scan;
	unsigned int s_mb_min_to_scan;
	unsigned int s_mb_stats;
	unsigned int s_mb_order2_reqs;
	unsigned int s_mb_group_prealloc;
	unsigned int s_mb_max_inode_prealloc;
	unsigned int s_max_dir_size_kb;
	long unsigned int s_mb_last_group;
	long unsigned int s_mb_last_start;
	unsigned int s_mb_prefetch;
	unsigned int s_mb_prefetch_limit;
	atomic_t s_bal_reqs;
	atomic_t s_bal_success;
	atomic_t s_bal_allocated;
	atomic_t s_bal_ex_scanned;
	atomic_t s_bal_groups_scanned;
	atomic_t s_bal_goals;
	atomic_t s_bal_breaks;
	atomic_t s_bal_2orders;
	atomic_t s_bal_cr0_bad_suggestions;
	atomic_t s_bal_cr1_bad_suggestions;
	atomic64_t s_bal_cX_groups_considered[4];
	atomic64_t s_bal_cX_hits[4];
	atomic64_t s_bal_cX_failed[4];
	atomic_t s_mb_buddies_generated;
	atomic64_t s_mb_generation_time;
	atomic_t s_mb_lost_chunks;
	atomic_t s_mb_preallocated;
	atomic_t s_mb_discarded;
	atomic_t s_lock_busy;
	struct ext4_locality_group *s_locality_groups;
	long unsigned int s_sectors_written_start;
	u64 s_kbytes_written;
	unsigned int s_extent_max_zeroout_kb;
	unsigned int s_log_groups_per_flex;
	struct flex_groups **s_flex_groups;
	ext4_group_t s_flex_groups_allocated;
	struct workqueue_struct *rsv_conversion_wq;
	struct timer_list s_err_report;
	struct ext4_li_request___3 *s_li_request;
	unsigned int s_li_wait_mult;
	struct task_struct___140 *s_mmp_tsk;
	atomic_t s_last_trim_minblks;
	struct crypto_shash___6 *s_chksum_driver;
	__u32 s_csum_seed;
	struct shrinker___50 s_es_shrinker;
	struct list_head s_es_list;
	long int s_es_nr_inode;
	struct ext4_es_stats s_es_stats;
	struct mb_cache___2 *s_ea_block_cache;
	struct mb_cache___2 *s_ea_inode_cache;
	long: 64;
	long: 64;
	spinlock_t s_es_lock;
	struct ext4_journal_trigger___3 s_journal_triggers[1];
	struct ratelimit_state s_err_ratelimit_state;
	struct ratelimit_state s_warning_ratelimit_state;
	struct ratelimit_state s_msg_ratelimit_state;
	atomic_t s_warning_count;
	atomic_t s_msg_count;
	struct fscrypt_dummy_policy s_dummy_enc_policy;
	struct percpu_rw_semaphore___134 s_writepages_rwsem;
	struct dax_device *s_daxdev;
	errseq_t s_bdev_wb_err;
	spinlock_t s_bdev_wb_lock;
	spinlock_t s_error_lock;
	int s_add_error_count;
	int s_first_error_code;
	__u32 s_first_error_line;
	__u32 s_first_error_ino;
	__u64 s_first_error_block;
	const char *s_first_error_func;
	time64_t s_first_error_time;
	int s_last_error_code;
	__u32 s_last_error_line;
	__u32 s_last_error_ino;
	__u64 s_last_error_block;
	const char *s_last_error_func;
	time64_t s_last_error_time;
	struct work_struct s_error_work;
	atomic_t s_fc_subtid;
	struct list_head s_fc_q[2];
	struct list_head s_fc_dentry_q[2];
	unsigned int s_fc_bytes;
	spinlock_t s_fc_lock;
	struct buffer_head___6 *s_fc_bh;
	struct ext4_fc_stats s_fc_stats;
	tid_t s_fc_ineligible_tid;
	struct ext4_fc_replay_state s_fc_replay_state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ext4_li_request___3 {
	struct super_block___133 *lr_super;
	enum ext4_li_mode lr_mode;
	ext4_group_t lr_first_not_zeroed;
	ext4_group_t lr_next_group;
	struct list_head lr_request;
	long unsigned int lr_next_sched;
	long unsigned int lr_timeout;
};

enum {
	EXT4_STATE_JDATA = 0,
	EXT4_STATE_NEW = 1,
	EXT4_STATE_XATTR = 2,
	EXT4_STATE_NO_EXPAND = 3,
	EXT4_STATE_DA_ALLOC_CLOSE = 4,
	EXT4_STATE_EXT_MIGRATE = 5,
	EXT4_STATE_NEWENTRY = 6,
	EXT4_STATE_MAY_INLINE_DATA = 7,
	EXT4_STATE_EXT_PRECACHED = 8,
	EXT4_STATE_LUSTRE_EA_INODE = 9,
	EXT4_STATE_VERITY_IN_PROGRESS = 10,
	EXT4_STATE_FC_COMMITTING = 11,
	EXT4_STATE_ORPHAN_FILE = 12,
};

struct ext4_iloc {
	struct buffer_head___6 *bh;
	long unsigned int offset;
	ext4_group_t block_group;
};

struct ext4_extent_tail {
	__le32 et_checksum;
};

struct ext4_extent {
	__le32 ee_block;
	__le16 ee_len;
	__le16 ee_start_hi;
	__le32 ee_start_lo;
};

struct ext4_extent_idx {
	__le32 ei_block;
	__le32 ei_leaf_lo;
	__le16 ei_leaf_hi;
	__u16 ei_unused;
};

struct ext4_extent_header {
	__le16 eh_magic;
	__le16 eh_entries;
	__le16 eh_max;
	__le16 eh_depth;
	__le32 eh_generation;
};

struct ext4_ext_path {
	ext4_fsblk_t p_block;
	__u16 p_depth;
	__u16 p_maxdepth;
	struct ext4_extent *p_ext;
	struct ext4_extent_idx *p_idx;
	struct ext4_extent_header *p_hdr;
	struct buffer_head___6 *p_bh;
};

struct partial_cluster {
	ext4_fsblk_t pclu;
	ext4_lblk_t lblk;
	enum {
		initial = 0,
		tofree = 1,
		nofree = 2,
	} state;
};

struct pending_reservation {
	struct rb_node rb_node;
	ext4_lblk_t lclu;
};

struct rsvd_count {
	int ndelonly;
	bool first_do_lblk_found;
	ext4_lblk_t first_do_lblk;
	ext4_lblk_t last_do_lblk;
	struct extent_status *left_es;
	bool partial;
	ext4_lblk_t lclu;
};

struct iomap_iter___4 {
	struct inode___133 *inode;
	loff_t pos;
	u64 len;
	s64 processed;
	unsigned int flags;
	struct iomap___4 iomap;
	struct iomap___4 srcmap;
};

struct iomap_dio_ops___2 {
	int (*end_io)(struct kiocb___133 *, ssize_t, int, unsigned int);
	blk_qc_t (*submit_io)(const struct iomap_iter___4 *, struct bio___60 *, loff_t);
};

enum {
	EXT4_MF_MNTDIR_SAMPLED = 0,
	EXT4_MF_FS_ABORTED = 1,
	EXT4_MF_FC_INELIGIBLE = 2,
};

struct fsmap {
	__u32 fmr_device;
	__u32 fmr_flags;
	__u64 fmr_physical;
	__u64 fmr_owner;
	__u64 fmr_offset;
	__u64 fmr_length;
	__u64 fmr_reserved[3];
};

struct ext4_fsmap {
	struct list_head fmr_list;
	dev_t fmr_device;
	uint32_t fmr_flags;
	uint64_t fmr_physical;
	uint64_t fmr_owner;
	uint64_t fmr_length;
};

struct ext4_fsmap_head {
	uint32_t fmh_iflags;
	uint32_t fmh_oflags;
	unsigned int fmh_count;
	unsigned int fmh_entries;
	struct ext4_fsmap fmh_keys[2];
};

typedef int (*ext4_fsmap_format_t)(struct ext4_fsmap *, void *);

typedef int (*ext4_mballoc_query_range_fn)(struct super_block___131 *, ext4_group_t, ext4_grpblk_t, ext4_grpblk_t, void *);

struct ext4_getfsmap_info {
	struct ext4_fsmap_head *gfi_head;
	ext4_fsmap_format_t gfi_formatter;
	void *gfi_format_arg;
	ext4_fsblk_t gfi_next_fsblk;
	u32 gfi_dev;
	ext4_group_t gfi_agno;
	struct ext4_fsmap gfi_low;
	struct ext4_fsmap gfi_high;
	struct ext4_fsmap gfi_lastfree;
	struct list_head gfi_meta_list;
	bool gfi_last;
};

struct ext4_getfsmap_dev {
	int (*gfd_fn)(struct super_block___131 *, struct ext4_fsmap *, struct ext4_getfsmap_info *);
	u32 gfd_dev;
};

struct dx_hash_info {
	u32 hash;
	u32 minor_hash;
	int hash_version;
	u32 *seed;
};

typedef unsigned int __kernel_mode_t;

typedef __kernel_mode_t mode_t;

struct ext4_inode {
	__le16 i_mode;
	__le16 i_uid;
	__le32 i_size_lo;
	__le32 i_atime;
	__le32 i_ctime;
	__le32 i_mtime;
	__le32 i_dtime;
	__le16 i_gid;
	__le16 i_links_count;
	__le32 i_blocks_lo;
	__le32 i_flags;
	union {
		struct {
			__le32 l_i_version;
		} linux1;
		struct {
			__u32 h_i_translator;
		} hurd1;
		struct {
			__u32 m_i_reserved1;
		} masix1;
	} osd1;
	__le32 i_block[15];
	__le32 i_generation;
	__le32 i_file_acl_lo;
	__le32 i_size_high;
	__le32 i_obso_faddr;
	union {
		struct {
			__le16 l_i_blocks_high;
			__le16 l_i_file_acl_high;
			__le16 l_i_uid_high;
			__le16 l_i_gid_high;
			__le16 l_i_checksum_lo;
			__le16 l_i_reserved;
		} linux2;
		struct {
			__le16 h_i_reserved1;
			__u16 h_i_mode_high;
			__u16 h_i_uid_high;
			__u16 h_i_gid_high;
			__u32 h_i_author;
		} hurd2;
		struct {
			__le16 h_i_reserved1;
			__le16 m_i_file_acl_high;
			__u32 m_i_reserved2[2];
		} masix2;
	} osd2;
	__le16 i_extra_isize;
	__le16 i_checksum_hi;
	__le32 i_ctime_extra;
	__le32 i_mtime_extra;
	__le32 i_atime_extra;
	__le32 i_crtime;
	__le32 i_crtime_extra;
	__le32 i_version_hi;
	__le32 i_projid;
};

struct orlov_stats {
	__u64 free_clusters;
	__u32 free_inodes;
	__u32 used_dirs;
};

typedef struct {
	__le32 *p;
	__le32 key;
	struct buffer_head___6 *bh;
} Indirect;

typedef int get_block_t___4(struct inode___133 *, sector_t, struct buffer_head___6 *, int);

struct ext4_filename {
	const struct qstr *usr_fname;
	struct fscrypt_str disk_name;
	struct dx_hash_info hinfo;
	struct fscrypt_str crypto_buf;
	struct fscrypt_str cf_name;
};

struct ext4_xattr_ibody_header {
	__le32 h_magic;
};

struct ext4_xattr_entry {
	__u8 e_name_len;
	__u8 e_name_index;
	__le16 e_value_offs;
	__le32 e_value_inum;
	__le32 e_value_size;
	__le32 e_hash;
	char e_name[0];
};

struct ext4_xattr_info {
	const char *name;
	const void *value;
	size_t value_len;
	int name_index;
	int in_inode;
};

struct ext4_xattr_search {
	struct ext4_xattr_entry *first;
	void *base;
	void *end;
	struct ext4_xattr_entry *here;
	int not_found;
};

struct ext4_xattr_ibody_find {
	struct ext4_xattr_search s;
	struct ext4_iloc iloc;
};

typedef short unsigned int __kernel_uid16_t;

typedef short unsigned int __kernel_gid16_t;

typedef __kernel_uid16_t uid16_t;

typedef __kernel_gid16_t gid16_t;

struct pagevec___7 {
	unsigned char nr;
	bool percpu_pvec_drained;
	struct page___138 *pages[15];
};

struct ext4_io_submit {
	struct writeback_control___57 *io_wbc;
	struct bio___60 *io_bio;
	ext4_io_end_t *io_end;
	sector_t io_next_block;
};

struct ext4_xattr_inode_array {
	unsigned int count;
	struct inode___133 *inodes[0];
};

struct mpage_da_data {
	struct inode___133 *inode;
	struct writeback_control___57 *wbc;
	long unsigned int first_page;
	long unsigned int next_page;
	long unsigned int last_page;
	struct ext4_map_blocks map;
	struct ext4_io_submit io_submit;
	unsigned int do_map: 1;
	unsigned int scanned_until_end: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fstrim_range {
	__u64 start;
	__u64 len;
	__u64 minlen;
};

struct fd___26 {
	struct file___133 *file;
	unsigned int flags;
};

struct ext4_new_group_input {
	__u32 group;
	__u64 block_bitmap;
	__u64 inode_bitmap;
	__u64 inode_table;
	__u32 blocks_count;
	__u16 reserved_blocks;
	__u16 unused;
};

struct compat_ext4_new_group_input {
	u32 group;
	compat_u64 block_bitmap;
	compat_u64 inode_bitmap;
	compat_u64 inode_table;
	u32 blocks_count;
	u16 reserved_blocks;
	u16 unused;
};

struct ext4_new_group_data {
	__u32 group;
	__u64 block_bitmap;
	__u64 inode_bitmap;
	__u64 inode_table;
	__u32 blocks_count;
	__u16 reserved_blocks;
	__u16 mdata_blocks;
	__u32 free_clusters_count;
};

struct move_extent {
	__u32 reserved;
	__u32 donor_fd;
	__u64 orig_start;
	__u64 donor_start;
	__u64 len;
	__u64 moved_len;
};

struct fsmap_head {
	__u32 fmh_iflags;
	__u32 fmh_oflags;
	__u32 fmh_count;
	__u32 fmh_entries;
	__u64 fmh_reserved[6];
	struct fsmap fmh_keys[2];
	struct fsmap fmh_recs[0];
};

struct getfsmap_info {
	struct super_block___133 *gi_sb;
	struct fsmap_head *gi_data;
	unsigned int gi_idx;
	__u32 gi_last_flags;
};

enum blk_default_limits {
	BLK_MAX_SEGMENTS = 128,
	BLK_SAFE_MAX_SECTORS = 255,
	BLK_DEF_MAX_SECTORS = 2560,
	BLK_MAX_SEGMENT_SIZE = 65536,
	BLK_SEG_BOUNDARY_MASK = 4294967295,
};

struct ext4_free_data {
	struct list_head efd_list;
	struct rb_node efd_node;
	ext4_group_t efd_group;
	ext4_grpblk_t efd_start_cluster;
	ext4_grpblk_t efd_count;
	tid_t efd_tid;
};

struct ext4_prealloc_space {
	struct list_head pa_inode_list;
	struct list_head pa_group_list;
	union {
		struct list_head pa_tmp_list;
		struct callback_head pa_rcu;
	} u;
	spinlock_t pa_lock;
	atomic_t pa_count;
	unsigned int pa_deleted;
	ext4_fsblk_t pa_pstart;
	ext4_lblk_t pa_lstart;
	ext4_grpblk_t pa_len;
	ext4_grpblk_t pa_free;
	short unsigned int pa_type;
	spinlock_t *pa_obj_lock;
	struct inode___131 *pa_inode;
};

enum {
	MB_INODE_PA = 0,
	MB_GROUP_PA = 1,
};

struct ext4_free_extent {
	ext4_lblk_t fe_logical;
	ext4_grpblk_t fe_start;
	ext4_group_t fe_group;
	ext4_grpblk_t fe_len;
};

struct ext4_allocation_context {
	struct inode___131 *ac_inode;
	struct super_block___131 *ac_sb;
	struct ext4_free_extent ac_o_ex;
	struct ext4_free_extent ac_g_ex;
	struct ext4_free_extent ac_b_ex;
	struct ext4_free_extent ac_f_ex;
	ext4_group_t ac_last_optimal_group;
	__u32 ac_groups_considered;
	__u32 ac_flags;
	__u16 ac_groups_scanned;
	__u16 ac_groups_linear_remaining;
	__u16 ac_found;
	__u16 ac_tail;
	__u16 ac_buddy;
	__u8 ac_status;
	__u8 ac_criteria;
	__u8 ac_2order;
	__u8 ac_op;
	struct page___136 *ac_bitmap_page;
	struct page___136 *ac_buddy_page;
	struct ext4_prealloc_space *ac_pa;
	struct ext4_locality_group *ac_lg;
};

struct ext4_buddy {
	struct page___136 *bd_buddy_page;
	void *bd_buddy;
	struct page___136 *bd_bitmap_page;
	void *bd_bitmap;
	struct ext4_group_info *bd_info;
	struct super_block___131 *bd_sb;
	__u16 bd_blkbits;
	ext4_group_t bd_group;
};

struct sg {
	struct ext4_group_info info;
	ext4_grpblk_t counters[18];
};

struct migrate_struct {
	ext4_lblk_t first_block;
	ext4_lblk_t last_block;
	ext4_lblk_t curr_block;
	ext4_fsblk_t first_pblock;
	ext4_fsblk_t last_pblock;
};

struct mmp_struct {
	__le32 mmp_magic;
	__le32 mmp_seq;
	__le64 mmp_time;
	char mmp_nodename[64];
	char mmp_bdevname[32];
	__le16 mmp_check_interval;
	__le16 mmp_pad1;
	__le32 mmp_pad2[226];
	__le32 mmp_checksum;
};

struct ext4_dir_entry {
	__le32 inode;
	__le16 rec_len;
	__le16 name_len;
	char name[255];
};

struct ext4_dir_entry_tail {
	__le32 det_reserved_zero1;
	__le16 det_rec_len;
	__u8 det_reserved_zero2;
	__u8 det_reserved_ft;
	__le32 det_checksum;
};

typedef enum {
	EITHER = 0,
	INDEX = 1,
	DIRENT = 2,
	DIRENT_HTREE = 3,
} dirblock_type_t;

struct fake_dirent {
	__le32 inode;
	__le16 rec_len;
	u8 name_len;
	u8 file_type;
};

struct dx_countlimit {
	__le16 limit;
	__le16 count;
};

struct dx_entry {
	__le32 hash;
	__le32 block;
};

struct dx_root_info {
	__le32 reserved_zero;
	u8 hash_version;
	u8 info_length;
	u8 indirect_levels;
	u8 unused_flags;
};

struct dx_root {
	struct fake_dirent dot;
	char dot_name[4];
	struct fake_dirent dotdot;
	char dotdot_name[4];
	struct dx_root_info info;
	struct dx_entry entries[0];
};

struct dx_node {
	struct fake_dirent fake;
	struct dx_entry entries[0];
};

struct dx_frame {
	struct buffer_head___6 *bh;
	struct dx_entry *entries;
	struct dx_entry *at;
};

struct dx_map_entry {
	u32 hash;
	u16 offs;
	u16 size;
};

struct dx_tail {
	u32 dt_reserved;
	__le32 dt_checksum;
};

struct ext4_renament {
	struct inode___133 *dir;
	struct dentry___133 *dentry;
	struct inode___133 *inode;
	bool is_dir;
	int dir_nlink_delta;
	struct buffer_head___6 *bh;
	struct ext4_dir_entry_2 *de;
	int inlined;
	struct buffer_head___6 *dir_bh;
	struct ext4_dir_entry_2 *parent_de;
	int dir_inlined;
};

struct bvec_iter_all___4 {
	struct bio_vec___72 bv;
	int idx;
	unsigned int done;
};

struct dentry___134;

struct super_block___134;

struct module___123;

struct file_system_type___134 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___134 * (*mount)(struct file_system_type___134 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___134 *);
	struct module___123 *owner;
	struct file_system_type___134 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___134;

struct kiocb___134;

struct iov_iter___75;

struct vm_area_struct___139;

struct inode___134;

struct file_lock___134;

struct page___139;

struct seq_file___116;

struct file_operations___134 {
	struct module___123 *owner;
	loff_t (*llseek)(struct file___134 *, loff_t, int);
	ssize_t (*read)(struct file___134 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___134 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___134 *, struct iov_iter___75 *);
	ssize_t (*write_iter)(struct kiocb___134 *, struct iov_iter___75 *);
	int (*iopoll)(struct kiocb___134 *, bool);
	int (*iterate)(struct file___134 *, struct dir_context *);
	int (*iterate_shared)(struct file___134 *, struct dir_context *);
	__poll_t (*poll)(struct file___134 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___134 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___134 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___134 *, struct vm_area_struct___139 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___134 *, struct file___134 *);
	int (*flush)(struct file___134 *, fl_owner_t);
	int (*release)(struct inode___134 *, struct file___134 *);
	int (*fsync)(struct file___134 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___134 *, int);
	int (*lock)(struct file___134 *, int, struct file_lock___134 *);
	ssize_t (*sendpage)(struct file___134 *, struct page___139 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___134 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___134 *, long unsigned int);
	int (*flock)(struct file___134 *, int, struct file_lock___134 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___134 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___134 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___134 *, long int, struct file_lock___134 **, void **);
	long int (*fallocate)(struct file___134 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___116 *, struct file___134 *);
	ssize_t (*copy_file_range)(struct file___134 *, loff_t, struct file___134 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___134 *, loff_t, struct file___134 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___134 *, loff_t, loff_t, int);
};

struct vmacache___139 {
	u64 seqnum;
	struct vm_area_struct___139 *vmas[4];
};

struct page_frag___139 {
	struct page___139 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___140;

struct pid___119;

struct nsproxy___125;

struct signal_struct___135;

struct bio_list___61;

struct backing_dev_info___58;

struct io_context___61;

struct css_set___95;

struct request_queue___61;

struct vm_struct___121;

struct task_struct___141 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___141 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___140 *mm;
	struct mm_struct___140 *active_mm;
	struct vmacache___139 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___141 *real_parent;
	struct task_struct___141 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___141 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___119 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___125 *nsproxy;
	struct signal_struct___135 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___141 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___61 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___58 *backing_dev_info;
	struct io_context___61 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___95 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___139 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___61 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___141 *oom_reaper_list;
	struct vm_struct___121 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___64 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___125;

struct kobj_type___125;

struct kernfs_node___125;

struct kobject___125 {
	const char *name;
	struct list_head entry;
	struct kobject___125 *parent;
	struct kset___125 *kset;
	struct kobj_type___125 *ktype;
	struct kernfs_node___125 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___122 {
	struct kobject___125 kobj;
	struct module___123 *mod;
	struct kobject___125 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___122 {
	struct module___123 *mod;
	struct latch_tree_node node;
};

struct module_layout___122 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___122 mtn;
};

struct module_attribute___122;

struct kernel_param___122;

struct module___123 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___122 mkobj;
	struct module_attribute___122 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___125 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___122 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___122 core_layout;
	struct module_layout___122 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___139 *pgtable_t___139;

struct address_space___134;

struct dev_pagemap___132;

struct page___139 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___134 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___139 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___139 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___140 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___132 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___132;

struct vm_area_struct___139 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___139 *vm_next;
	struct vm_area_struct___139 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___140 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___132 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___134 *vm_file;
	struct file___134 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___139;

struct mm_struct___140 {
	struct {
		struct vm_area_struct___139 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___134 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___139 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___141 *owner;
		struct user_namespace___19 *user_ns;
		struct file___134 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___134;

struct address_space___134 {
	struct inode___134 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___134 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___132;

struct dev_pagemap___132 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___132 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___134;

struct path___134 {
	struct vfsmount___134 *mnt;
	struct dentry___134 *dentry;
};

struct fown_struct___119 {
	rwlock_t lock;
	struct pid___119 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___134 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___134 f_path;
	struct inode___134 *f_inode;
	const struct file_operations___134 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___119 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___134 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___132;

struct vm_operations_struct___132 {
	void (*open)(struct vm_area_struct___139 *);
	void (*close)(struct vm_area_struct___139 *);
	int (*may_split)(struct vm_area_struct___139 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___139 *);
	int (*mprotect)(struct vm_area_struct___139 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___132 *);
	vm_fault_t (*huge_fault)(struct vm_fault___132 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___132 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___139 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___132 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___132 *);
	int (*access)(struct vm_area_struct___139 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___139 *);
	int (*set_policy)(struct vm_area_struct___139 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___139 *, long unsigned int);
	struct page___139 * (*find_special_page)(struct vm_area_struct___139 *, long unsigned int);
};

struct core_thread___139 {
	struct task_struct___141 *task;
	struct core_thread___139 *next;
};

struct core_state___139 {
	atomic_t nr_threads;
	struct core_thread___139 dumper;
	struct completion startup;
};

struct vm_fault___132 {
	const struct {
		struct vm_area_struct___139 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___139 *cow_page;
	struct page___139 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___139 prealloc_pte;
};

struct dev_pagemap_ops___132 {
	void (*page_free)(struct page___139 *);
	void (*kill)(struct dev_pagemap___132 *);
	void (*cleanup)(struct dev_pagemap___132 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___132 *);
};

struct pid_namespace___119;

struct upid___119 {
	int nr;
	struct pid_namespace___119 *ns;
};

struct pid_namespace___119 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___141 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___119 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___119 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___119 numbers[1];
};

struct signal_struct___135 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___141 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___141 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___119 *pids[4];
	struct pid___119 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___140 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___95;

struct nsproxy___125 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___119 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___95 *cgroup_ns;
};

struct bio___61;

struct bio_list___61 {
	struct bio___61 *head;
	struct bio___61 *tail;
};

struct cgroup_subsys_state___95;

struct bdi_writeback___58 {
	struct backing_dev_info___58 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___95 *memcg_css;
	struct cgroup_subsys_state___95 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___99;

struct backing_dev_info___58 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___58 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___99 *dev;
	char dev_name[64];
	struct device___99 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___134 *debug_dir;
};

struct io_cq___61;

struct io_context___61 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___61 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___95;

struct css_set___95 {
	struct cgroup_subsys_state___95 *subsys[14];
	refcount_t refcount;
	struct css_set___95 *dom_cset;
	struct cgroup___95 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___95 *mg_src_cgrp;
	struct cgroup___95 *mg_dst_cgrp;
	struct css_set___95 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___61;

struct blk_integrity___61 {
	const struct blk_integrity_profile___61 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___61 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___61 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___61;

struct elevator_queue___61;

struct blk_mq_ops___58;

struct blk_mq_hw_ctx___58;

struct gendisk___61;

struct blkcg_gq___58;

struct blk_mq_tag_set___58;

struct request_queue___61 {
	struct request___61 *last_merge;
	struct elevator_queue___61 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___58 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___58 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___61 *disk;
	struct kobject___125 kobj;
	struct kobject___125 *mq_kobj;
	struct blk_integrity___61 integrity;
	struct device___99 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___58 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___58 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___61 bio_split;
	struct dentry___134 *debugfs_dir;
	struct dentry___134 *sched_debugfs_dir;
	struct dentry___134 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___121 {
	struct vm_struct___121 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___139 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___134;

struct dentry___134 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___134 *d_parent;
	struct qstr d_name;
	struct inode___134 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___134 *d_op;
	struct super_block___134 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___134;

struct inode___134 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___134 *i_op;
	struct super_block___134 *i_sb;
	struct address_space___134 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___58 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___134 *i_fop;
		void (*free_inode)(struct inode___134 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___134 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___134 {
	int (*d_revalidate)(struct dentry___134 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___134 *, unsigned int);
	int (*d_hash)(const struct dentry___134 *, struct qstr *);
	int (*d_compare)(const struct dentry___134 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___134 *);
	int (*d_init)(struct dentry___134 *);
	void (*d_release)(struct dentry___134 *);
	void (*d_prune)(struct dentry___134 *);
	void (*d_iput)(struct dentry___134 *, struct inode___134 *);
	char * (*d_dname)(struct dentry___134 *, char *, int);
	struct vfsmount___134 * (*d_automount)(struct path___134 *);
	int (*d_manage)(const struct path___134 *, bool);
	struct dentry___134 * (*d_real)(struct dentry___134 *, const struct inode___134 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___134;

struct mem_dqinfo___134 {
	struct quota_format_type___134 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___134;

struct quota_info___134 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___134 *files[3];
	struct mem_dqinfo___134 info[3];
	const struct quota_format_ops___134 *ops[3];
};

struct rcuwait___135 {
	struct task_struct___141 *task;
};

struct percpu_rw_semaphore___135 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___135 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___134 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___135 rw_sem[3];
};

struct super_operations___134;

struct dquot_operations___134;

struct quotactl_ops___134;

struct export_operations___11;

struct fscrypt_operations___10;

struct fsverity_operations___8;

struct block_device___62;

struct super_block___134 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___134 *s_type;
	const struct super_operations___134 *s_op;
	const struct dquot_operations___134 *dq_op;
	const struct quotactl_ops___134 *s_qcop;
	const struct export_operations___11 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___134 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations___10 *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___8 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___62 *s_bdev;
	struct backing_dev_info___58 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___134 s_dquot;
	struct sb_writers___134 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___134 *s_d_op;
	int cleancache_poolid;
	struct shrinker___50 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___134 {
	struct dentry___134 *mnt_root;
	struct super_block___134 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct cgroup_subsys___95;

struct cgroup_subsys_state___95 {
	struct cgroup___95 *cgroup;
	struct cgroup_subsys___95 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___95 *parent;
};

struct cgroup_file___95 {
	struct kernfs_node___125 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___95 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___141 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___95;

struct cgroup_rstat_cpu___95;

struct cgroup___95 {
	struct cgroup_subsys_state___95 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___125 *kn;
	struct cgroup_file___95 procs_file;
	struct cgroup_file___95 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___95 *subsys[14];
	struct cgroup_root___95 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___95 *dom_cgrp;
	struct cgroup___95 *old_dom_cgrp;
	struct cgroup_rstat_cpu___95 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___95 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___61 {
	struct request_queue___61 *q;
	struct io_context___61 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___7;

typedef int get_block_t___5(struct inode___134 *, sector_t, struct buffer_head___7 *, int);

typedef void bh_end_io_t___7(struct buffer_head___7 *, int);

struct buffer_head___7 {
	long unsigned int b_state;
	struct buffer_head___7 *b_this_page;
	struct page___139 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___62 *b_bdev;
	bh_end_io_t___7 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___134 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___63;

struct kiocb___134 {
	struct file___134 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___134 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___63 *ki_waitq;
	};
};

struct iattr___134 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___134 *ia_file;
};

struct dquot___134 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___134 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___134 {
	int qf_fmt_id;
	const struct quota_format_ops___134 *qf_ops;
	struct module___123 *qf_owner;
	struct quota_format_type___134 *qf_next;
};

struct quota_format_ops___134 {
	int (*check_quota_file)(struct super_block___134 *, int);
	int (*read_file_info)(struct super_block___134 *, int);
	int (*write_file_info)(struct super_block___134 *, int);
	int (*free_file_info)(struct super_block___134 *, int);
	int (*read_dqblk)(struct dquot___134 *);
	int (*commit_dqblk)(struct dquot___134 *);
	int (*release_dqblk)(struct dquot___134 *);
	int (*get_next_id)(struct super_block___134 *, struct kqid *);
};

struct dquot_operations___134 {
	int (*write_dquot)(struct dquot___134 *);
	struct dquot___134 * (*alloc_dquot)(struct super_block___134 *, int);
	void (*destroy_dquot)(struct dquot___134 *);
	int (*acquire_dquot)(struct dquot___134 *);
	int (*release_dquot)(struct dquot___134 *);
	int (*mark_dirty)(struct dquot___134 *);
	int (*write_info)(struct super_block___134 *, int);
	qsize_t * (*get_reserved_space)(struct inode___134 *);
	int (*get_projid)(struct inode___134 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___134 *, qsize_t *);
	int (*get_next_id)(struct super_block___134 *, struct kqid *);
};

struct quotactl_ops___134 {
	int (*quota_on)(struct super_block___134 *, int, int, const struct path___134 *);
	int (*quota_off)(struct super_block___134 *, int);
	int (*quota_enable)(struct super_block___134 *, unsigned int);
	int (*quota_disable)(struct super_block___134 *, unsigned int);
	int (*quota_sync)(struct super_block___134 *, int);
	int (*set_info)(struct super_block___134 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___134 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___134 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___134 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___134 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___134 *, unsigned int);
};

struct wait_page_queue___63 {
	struct page___139 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___58;

struct readahead_control___63;

struct address_space_operations___134 {
	int (*writepage)(struct page___139 *, struct writeback_control___58 *);
	int (*readpage)(struct file___134 *, struct page___139 *);
	int (*writepages)(struct address_space___134 *, struct writeback_control___58 *);
	int (*set_page_dirty)(struct page___139 *);
	int (*readpages)(struct file___134 *, struct address_space___134 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___63 *);
	int (*write_begin)(struct file___134 *, struct address_space___134 *, loff_t, unsigned int, unsigned int, struct page___139 **, void **);
	int (*write_end)(struct file___134 *, struct address_space___134 *, loff_t, unsigned int, unsigned int, struct page___139 *, void *);
	sector_t (*bmap)(struct address_space___134 *, sector_t);
	void (*invalidatepage)(struct page___139 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___139 *, gfp_t);
	void (*freepage)(struct page___139 *);
	ssize_t (*direct_IO)(struct kiocb___134 *, struct iov_iter___75 *);
	int (*migratepage)(struct address_space___134 *, struct page___139 *, struct page___139 *, enum migrate_mode);
	bool (*isolate_page)(struct page___139 *, isolate_mode_t);
	void (*putback_page)(struct page___139 *);
	int (*launder_page)(struct page___139 *);
	int (*is_partially_uptodate)(struct page___139 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___139 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___134 *, struct page___139 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___134 *, sector_t *);
	void (*swap_deactivate)(struct file___134 *);
};

struct writeback_control___58 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___58 *wb;
	struct inode___134 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___63 {
	struct file___134 *file;
	struct address_space___134 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___73;

struct iov_iter___75 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___73 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___134 {
	struct dentry___134 * (*lookup)(struct inode___134 *, struct dentry___134 *, unsigned int);
	const char * (*get_link)(struct dentry___134 *, struct inode___134 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___134 *, int);
	struct posix_acl * (*get_acl)(struct inode___134 *, int, bool);
	int (*readlink)(struct dentry___134 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___134 *, struct dentry___134 *, umode_t, bool);
	int (*link)(struct dentry___134 *, struct inode___134 *, struct dentry___134 *);
	int (*unlink)(struct inode___134 *, struct dentry___134 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___134 *, struct dentry___134 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___134 *, struct dentry___134 *, umode_t);
	int (*rmdir)(struct inode___134 *, struct dentry___134 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___134 *, struct dentry___134 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___134 *, struct dentry___134 *, struct inode___134 *, struct dentry___134 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___134 *, struct iattr___134 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___134 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___134 *, char *, size_t);
	int (*fiemap)(struct inode___134 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___134 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___134 *, struct dentry___134 *, struct file___134 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___134 *, struct dentry___134 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___134 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___134 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___134 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___134 {
	void (*fl_copy_lock)(struct file_lock___134 *, struct file_lock___134 *);
	void (*fl_release_private)(struct file_lock___134 *);
};

struct fasync_struct___134;

struct lock_manager_operations___134;

struct file_lock___134 {
	struct file_lock___134 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___134 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___134 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___134 *fl_ops;
	const struct lock_manager_operations___134 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___134 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___134 *);
	int (*lm_grant)(struct file_lock___134 *, int);
	bool (*lm_break)(struct file_lock___134 *);
	int (*lm_change)(struct file_lock___134 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___134 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___134 *);
};

struct fasync_struct___134 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___134 *fa_next;
	struct file___134 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___134 {
	struct inode___134 * (*alloc_inode)(struct super_block___134 *);
	void (*destroy_inode)(struct inode___134 *);
	void (*free_inode)(struct inode___134 *);
	void (*dirty_inode)(struct inode___134 *, int);
	int (*write_inode)(struct inode___134 *, struct writeback_control___58 *);
	int (*drop_inode)(struct inode___134 *);
	void (*evict_inode)(struct inode___134 *);
	void (*put_super)(struct super_block___134 *);
	int (*sync_fs)(struct super_block___134 *, int);
	int (*freeze_super)(struct super_block___134 *);
	int (*freeze_fs)(struct super_block___134 *);
	int (*thaw_super)(struct super_block___134 *);
	int (*unfreeze_fs)(struct super_block___134 *);
	int (*statfs)(struct dentry___134 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___134 *, int *, char *);
	void (*umount_begin)(struct super_block___134 *);
	int (*show_options)(struct seq_file___116 *, struct dentry___134 *);
	int (*show_devname)(struct seq_file___116 *, struct dentry___134 *);
	int (*show_path)(struct seq_file___116 *, struct dentry___134 *);
	int (*show_stats)(struct seq_file___116 *, struct dentry___134 *);
	ssize_t (*quota_read)(struct super_block___134 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___134 *, int, const char *, size_t, loff_t);
	struct dquot___134 ** (*get_dquots)(struct inode___134 *);
	long int (*nr_cached_objects)(struct super_block___134 *, struct shrink_control___50 *);
	long int (*free_cached_objects)(struct super_block___134 *, struct shrink_control___50 *);
	struct file___134 * (*real_loop)(struct file___134 *);
};

struct export_operations___11 {
	int (*encode_fh)(struct inode___134 *, __u32 *, int *, struct inode___134 *);
	struct dentry___134 * (*fh_to_dentry)(struct super_block___134 *, struct fid *, int, int);
	struct dentry___134 * (*fh_to_parent)(struct super_block___134 *, struct fid *, int, int);
	int (*get_name)(struct dentry___134 *, char *, struct dentry___134 *);
	struct dentry___134 * (*get_parent)(struct dentry___134 *);
	int (*commit_metadata)(struct inode___134 *);
	int (*get_uuid)(struct super_block___134 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___134 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___134 *, struct iomap *, int, struct iattr___134 *);
	u64 (*fetch_iversion)(struct inode___134 *);
	long unsigned int flags;
};

struct fscrypt_operations___10 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___134 *, void *, size_t);
	int (*set_context)(struct inode___134 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___134 *);
	bool (*empty_dir)(struct inode___134 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___134 *);
	void (*get_ino_and_lblk_bits)(struct super_block___134 *, int *, int *);
	int (*get_num_devices)(struct super_block___134 *);
	void (*get_devices)(struct super_block___134 *, struct request_queue___61 **);
};

struct fsverity_operations___8 {
	int (*begin_enable_verity)(struct file___134 *);
	int (*end_enable_verity)(struct file___134 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___134 *, void *, size_t);
	struct page___139 * (*read_merkle_tree_page)(struct inode___134 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___134 *, const void *, u64, int);
};

struct wakeup_source___99;

struct dev_pm_info___99 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___99 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___99 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___99;

struct bus_type___99;

struct device_driver___99;

struct dev_pm_domain___99;

struct fwnode_handle___99;

struct class___99;

struct attribute_group___125;

struct device___99 {
	struct kobject___125 kobj;
	struct device___99 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___99 *type;
	struct bus_type___99 *bus;
	struct device_driver___99 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___99 power;
	struct dev_pm_domain___99 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___99 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___99 *class;
	const struct attribute_group___125 **groups;
	void (*release)(struct device___99 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___62 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___134 *bd_inode;
	struct super_block___134 *bd_super;
	void *bd_claiming;
	struct device___99 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___125 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___61 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___134 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___116;

struct seq_file___116 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___116 *op;
	int poll_event;
	const struct file___134 *file;
	void *private;
};

typedef void bio_end_io_t___61(struct bio___61 *);

struct bio_vec___73 {
	struct page___139 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___61;

struct bio___61 {
	struct bio___61 *bi_next;
	struct block_device___62 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___61 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___58 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___61 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___73 *bi_io_vec;
	struct bio_set___61 *bi_pool;
	struct bio_vec___73 bi_inline_vecs[0];
};

struct fwnode_operations___99;

struct fwnode_handle___99 {
	struct fwnode_handle___99 *secondary;
	const struct fwnode_operations___99 *ops;
	struct device___99 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___99;

struct fwnode_endpoint___99;

struct fwnode_operations___99 {
	struct fwnode_handle___99 * (*get)(struct fwnode_handle___99 *);
	void (*put)(struct fwnode_handle___99 *);
	bool (*device_is_available)(const struct fwnode_handle___99 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___99 *, const struct device___99 *);
	bool (*property_present)(const struct fwnode_handle___99 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___99 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___99 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___99 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*get_parent)(const struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*get_next_child_node)(const struct fwnode_handle___99 *, struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*get_named_child_node)(const struct fwnode_handle___99 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___99 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___99 *);
	struct fwnode_handle___99 * (*graph_get_next_endpoint)(const struct fwnode_handle___99 *, struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*graph_get_remote_endpoint)(const struct fwnode_handle___99 *);
	struct fwnode_handle___99 * (*graph_get_port_parent)(struct fwnode_handle___99 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___99 *, struct fwnode_endpoint___99 *);
	int (*add_links)(struct fwnode_handle___99 *);
};

struct fwnode_endpoint___99 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___99 *local_fwnode;
};

struct fwnode_reference_args___99 {
	struct fwnode_handle___99 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___125;

struct kernfs_elem_dir___125 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___125 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___125;

struct kernfs_root___125 {
	struct kernfs_node___125 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___125 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___125 {
	struct kernfs_node___125 *target_kn;
};

struct kernfs_ops___125;

struct kernfs_elem_attr___125 {
	const struct kernfs_ops___125 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___125 *notify_next;
};

struct kernfs_node___125 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___125 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___125 dir;
		struct kernfs_elem_symlink___125 symlink;
		struct kernfs_elem_attr___125 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___125;

struct kernfs_ops___125 {
	int (*open)(struct kernfs_open_file___125 *);
	void (*release)(struct kernfs_open_file___125 *);
	int (*seq_show)(struct seq_file___116 *, void *);
	void * (*seq_start)(struct seq_file___116 *, loff_t *);
	void * (*seq_next)(struct seq_file___116 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___116 *, void *);
	ssize_t (*read)(struct kernfs_open_file___125 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___125 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___125 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___125 *, struct vm_area_struct___139 *);
};

struct kernfs_syscall_ops___125 {
	int (*show_options)(struct seq_file___116 *, struct kernfs_root___125 *);
	int (*mkdir)(struct kernfs_node___125 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___125 *);
	int (*rename)(struct kernfs_node___125 *, struct kernfs_node___125 *, const char *);
	int (*show_path)(struct seq_file___116 *, struct kernfs_node___125 *, struct kernfs_root___125 *);
};

struct kernfs_open_file___125 {
	struct kernfs_node___125 *kn;
	struct file___134 *file;
	struct seq_file___116 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___132 *vm_ops;
};

struct bin_attribute___125;

struct attribute_group___125 {
	const char *name;
	umode_t (*is_visible)(struct kobject___125 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___125 *, struct bin_attribute___125 *, int);
	struct attribute **attrs;
	struct bin_attribute___125 **bin_attrs;
};

struct bin_attribute___125 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___134 * (*f_mapping)();
	ssize_t (*read)(struct file___134 *, struct kobject___125 *, struct bin_attribute___125 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___134 *, struct kobject___125 *, struct bin_attribute___125 *, char *, loff_t, size_t);
	int (*mmap)(struct file___134 *, struct kobject___125 *, struct bin_attribute___125 *, struct vm_area_struct___139 *);
};

struct sysfs_ops___125 {
	ssize_t (*show)(struct kobject___125 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___125 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___125;

struct kset___125 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___125 kobj;
	const struct kset_uevent_ops___125 *uevent_ops;
};

struct kobj_type___125 {
	void (*release)(struct kobject___125 *);
	const struct sysfs_ops___125 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___125 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___125 *);
	const void * (*namespace)(struct kobject___125 *);
	void (*get_ownership)(struct kobject___125 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___125 {
	int (* const filter)(struct kset___125 *, struct kobject___125 *);
	const char * (* const name)(struct kset___125 *, struct kobject___125 *);
	int (* const uevent)(struct kset___125 *, struct kobject___125 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___122 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___122 *);
	int (*get)(char *, const struct kernel_param___122 *);
	void (*free)(void *);
};

struct kparam_array___122;

struct kernel_param___122 {
	const char *name;
	struct module___123 *mod;
	const struct kernel_param_ops___122 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___122 *arr;
	};
};

struct kparam_array___122 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___122 *ops;
	void *elem;
};

struct module_attribute___122 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___122 *, struct module_kobject___122 *, char *);
	ssize_t (*store)(struct module_attribute___122 *, struct module_kobject___122 *, const char *, size_t);
	void (*setup)(struct module___123 *, const char *);
	int (*test)(struct module___123 *);
	void (*free)(struct module___123 *);
};

struct cgroup_namespace___95 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___95 *root_cset;
};

struct bvec_iter_all___5 {
	struct bio_vec___73 bv;
	int idx;
	unsigned int done;
};

struct dev_pm_ops___99 {
	int (*prepare)(struct device___99 *);
	void (*complete)(struct device___99 *);
	int (*suspend)(struct device___99 *);
	int (*resume)(struct device___99 *);
	int (*freeze)(struct device___99 *);
	int (*thaw)(struct device___99 *);
	int (*poweroff)(struct device___99 *);
	int (*restore)(struct device___99 *);
	int (*suspend_late)(struct device___99 *);
	int (*resume_early)(struct device___99 *);
	int (*freeze_late)(struct device___99 *);
	int (*thaw_early)(struct device___99 *);
	int (*poweroff_late)(struct device___99 *);
	int (*restore_early)(struct device___99 *);
	int (*suspend_noirq)(struct device___99 *);
	int (*resume_noirq)(struct device___99 *);
	int (*freeze_noirq)(struct device___99 *);
	int (*thaw_noirq)(struct device___99 *);
	int (*poweroff_noirq)(struct device___99 *);
	int (*restore_noirq)(struct device___99 *);
	int (*runtime_suspend)(struct device___99 *);
	int (*runtime_resume)(struct device___99 *);
	int (*runtime_idle)(struct device___99 *);
};

struct wakeup_source___99 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___99 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___99 {
	struct dev_pm_ops___99 ops;
	int (*start)(struct device___99 *);
	void (*detach)(struct device___99 *, bool);
	int (*activate)(struct device___99 *);
	void (*sync)(struct device___99 *);
	void (*dismiss)(struct device___99 *);
};

struct bus_type___99 {
	const char *name;
	const char *dev_name;
	struct device___99 *dev_root;
	const struct attribute_group___125 **bus_groups;
	const struct attribute_group___125 **dev_groups;
	const struct attribute_group___125 **drv_groups;
	int (*match)(struct device___99 *, struct device_driver___99 *);
	int (*uevent)(struct device___99 *, struct kobj_uevent_env *);
	int (*probe)(struct device___99 *);
	void (*sync_state)(struct device___99 *);
	void (*remove)(struct device___99 *);
	void (*shutdown)(struct device___99 *);
	int (*online)(struct device___99 *);
	int (*offline)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	int (*num_vf)(struct device___99 *);
	int (*dma_configure)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___99 {
	const char *name;
	struct bus_type___99 *bus;
	struct module___123 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___99 *);
	void (*sync_state)(struct device___99 *);
	int (*remove)(struct device___99 *);
	void (*shutdown)(struct device___99 *);
	int (*suspend)(struct device___99 *, pm_message_t);
	int (*resume)(struct device___99 *);
	const struct attribute_group___125 **groups;
	const struct attribute_group___125 **dev_groups;
	const struct dev_pm_ops___99 *pm;
	void (*coredump)(struct device___99 *);
	struct driver_private *p;
};

struct device_type___99 {
	const char *name;
	const struct attribute_group___125 **groups;
	int (*uevent)(struct device___99 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___99 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___99 *);
	const struct dev_pm_ops___99 *pm;
};

struct class___99 {
	const char *name;
	struct module___123 *owner;
	const struct attribute_group___125 **class_groups;
	const struct attribute_group___125 **dev_groups;
	struct kobject___125 *dev_kobj;
	int (*dev_uevent)(struct device___99 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___99 *, umode_t *);
	void (*class_release)(struct class___99 *);
	void (*dev_release)(struct device___99 *);
	int (*shutdown_pre)(struct device___99 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___99 *);
	void (*get_ownership)(struct device___99 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___99 *pm;
	struct subsys_private *p;
};

struct block_device_operations___61;

struct gendisk___61 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___62 *part0;
	const struct block_device_operations___61 *fops;
	struct request_queue___61 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___58 *bdi;
	struct kobject___125 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___125 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___61 {
	struct bio___61 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___73 *bip_vec;
	struct bio_vec___73 bip_inline_vecs[0];
};

struct blkcg___58;

struct blkg_policy_data___58;

struct blkcg_gq___58 {
	struct request_queue___61 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___58 *blkcg;
	struct blkcg_gq___58 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___58 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___61 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___61(struct request___61 *);

typedef void integrity_complete_fn___61(struct request___61 *, unsigned int);

struct blk_integrity_profile___61 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___61 *prepare_fn;
	integrity_complete_fn___61 *complete_fn;
	const char *name;
};

struct block_device_operations___61 {
	blk_qc_t (*submit_bio)(struct bio___61 *);
	int (*open)(struct block_device___62 *, fmode_t);
	void (*release)(struct gendisk___61 *, fmode_t);
	int (*rw_page)(struct block_device___62 *, sector_t, struct page___139 *, unsigned int);
	int (*ioctl)(struct block_device___62 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___62 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___61 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___61 *);
	int (*getgeo)(struct block_device___62 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___62 *, bool);
	void (*swap_slot_free_notify)(struct block_device___62 *, long unsigned int);
	int (*report_zones)(struct gendisk___61 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___61 *, umode_t *);
	struct module___123 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___61 *, sector_t *);
};

typedef void rq_end_io_fn___61(struct request___61 *, blk_status_t);

struct request___61 {
	struct request_queue___61 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___58 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___61 *bio;
	struct bio___61 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___73 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___61 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___61 *saved_end_io;
		} flush;
	};
	struct gendisk___61 *rq_disk;
	struct block_device___62 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___61 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___58 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___61 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___125 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___134 *debugfs_dir;
	struct dentry___134 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___61;

struct elevator_mq_ops___61 {
	int (*init_sched)(struct request_queue___61 *, struct elevator_type___61 *);
	void (*exit_sched)(struct elevator_queue___61 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___58 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___58 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___58 *);
	bool (*allow_merge)(struct request_queue___61 *, struct request___61 *, struct bio___61 *);
	bool (*bio_merge)(struct request_queue___61 *, struct bio___61 *, unsigned int);
	int (*request_merge)(struct request_queue___61 *, struct request___61 **, struct bio___61 *);
	void (*request_merged)(struct request_queue___61 *, struct request___61 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___61 *, struct request___61 *, struct request___61 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___61 *);
	void (*finish_request)(struct request___61 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___58 *, struct list_head *, bool);
	struct request___61 * (*dispatch_request)(struct blk_mq_hw_ctx___58 *);
	bool (*has_work)(struct blk_mq_hw_ctx___58 *);
	void (*completed_request)(struct request___61 *, u64);
	void (*requeue_request)(struct request___61 *);
	struct request___61 * (*former_request)(struct request_queue___61 *, struct request___61 *);
	struct request___61 * (*next_request)(struct request_queue___61 *, struct request___61 *);
	void (*init_icq)(struct io_cq___61 *);
	void (*exit_icq)(struct io_cq___61 *);
};

struct elv_fs_entry___61;

struct elevator_type___61 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___61 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___61 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___123 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___61 {
	struct elevator_type___61 *type;
	void *elevator_data;
	struct kobject___125 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___61 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___61 *, char *);
	ssize_t (*store)(struct elevator_queue___61 *, const char *, size_t);
};

struct blk_mq_queue_data___58;

struct blk_mq_ops___58 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___58 *, const struct blk_mq_queue_data___58 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___58 *);
	int (*get_budget)(struct request_queue___61 *);
	void (*put_budget)(struct request_queue___61 *, int);
	void (*set_rq_budget_token)(struct request___61 *, int);
	int (*get_rq_budget_token)(struct request___61 *);
	enum blk_eh_timer_return (*timeout)(struct request___61 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___58 *);
	void (*complete)(struct request___61 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___58 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___58 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___58 *, struct request___61 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___58 *, struct request___61 *, unsigned int);
	void (*initialize_rq_fn)(struct request___61 *);
	void (*cleanup_rq)(struct request___61 *);
	bool (*busy)(struct request_queue___61 *);
	int (*map_queues)(struct blk_mq_tag_set___58 *);
	void (*show_rq)(struct seq_file___116 *, struct request___61 *);
};

struct blk_mq_tag_set___58 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___58 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___116 {
	void * (*start)(struct seq_file___116 *, loff_t *);
	void (*stop)(struct seq_file___116 *, void *);
	void * (*next)(struct seq_file___116 *, void *, loff_t *);
	int (*show)(struct seq_file___116 *, void *);
};

struct cftype___95;

struct cgroup_subsys___95 {
	struct cgroup_subsys_state___95 * (*css_alloc)(struct cgroup_subsys_state___95 *);
	int (*css_online)(struct cgroup_subsys_state___95 *);
	void (*css_offline)(struct cgroup_subsys_state___95 *);
	void (*css_released)(struct cgroup_subsys_state___95 *);
	void (*css_free)(struct cgroup_subsys_state___95 *);
	void (*css_reset)(struct cgroup_subsys_state___95 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___95 *, int);
	int (*css_extra_stat_show)(struct seq_file___116 *, struct cgroup_subsys_state___95 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___141 *, struct css_set___95 *);
	void (*cancel_fork)(struct task_struct___141 *, struct css_set___95 *);
	void (*fork)(struct task_struct___141 *);
	void (*exit)(struct task_struct___141 *);
	void (*release)(struct task_struct___141 *);
	void (*bind)(struct cgroup_subsys_state___95 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___95 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___95 *dfl_cftypes;
	struct cftype___95 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___95 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___95 *updated_children;
	struct cgroup___95 *updated_next;
};

struct cgroup_root___95 {
	struct kernfs_root___125 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___95 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___95 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___95 *ss;
	struct list_head node;
	struct kernfs_ops___125 *kf_ops;
	int (*open)(struct kernfs_open_file___125 *);
	void (*release)(struct kernfs_open_file___125 *);
	u64 (*read_u64)(struct cgroup_subsys_state___95 *, struct cftype___95 *);
	s64 (*read_s64)(struct cgroup_subsys_state___95 *, struct cftype___95 *);
	int (*seq_show)(struct seq_file___116 *, void *);
	void * (*seq_start)(struct seq_file___116 *, loff_t *);
	void * (*seq_next)(struct seq_file___116 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___116 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___95 *, struct cftype___95 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___95 *, struct cftype___95 *, s64);
	ssize_t (*write)(struct kernfs_open_file___125 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___125 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___58 {
	struct request___61 *rq;
	bool last;
};

struct blkcg_policy_data___58;

struct blkcg___58 {
	struct cgroup_subsys_state___95 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___58 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___58 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___58 {
	struct blkcg___58 *blkcg;
	int plid;
};

struct blkg_policy_data___58 {
	struct blkcg_gq___58 *blkg;
	int plid;
};

struct journal_s___4;

typedef struct journal_s___4 journal_t___4;

struct journal_head___4;

struct transaction_s___4;

typedef struct transaction_s___4 transaction_t___4;

struct transaction_s___4 {
	journal_t___4 *t_journal;
	tid_t t_tid;
	enum {
		T_RUNNING___4 = 0,
		T_LOCKED___4 = 1,
		T_SWITCH___4 = 2,
		T_FLUSH___4 = 3,
		T_COMMIT___4 = 4,
		T_COMMIT_DFLUSH___4 = 5,
		T_COMMIT_JFLUSH___4 = 6,
		T_COMMIT_CALLBACK___4 = 7,
		T_FINISHED___4 = 8,
	} t_state;
	long unsigned int t_log_start;
	int t_nr_buffers;
	struct journal_head___4 *t_reserved_list;
	struct journal_head___4 *t_buffers;
	struct journal_head___4 *t_forget;
	struct journal_head___4 *t_checkpoint_list;
	struct journal_head___4 *t_checkpoint_io_list;
	struct journal_head___4 *t_shadow_list;
	struct list_head t_inode_list;
	spinlock_t t_handle_lock;
	long unsigned int t_max_wait;
	long unsigned int t_start;
	long unsigned int t_requested;
	struct transaction_chp_stats_s t_chp_stats;
	atomic_t t_updates;
	atomic_t t_outstanding_credits;
	atomic_t t_outstanding_revokes;
	atomic_t t_handle_count;
	transaction_t___4 *t_cpnext;
	transaction_t___4 *t_cpprev;
	long unsigned int t_expires;
	ktime_t t_start_time;
	unsigned int t_synchronous_commit: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int t_need_data_flush;
	struct list_head t_private_list;
};

struct jbd2_buffer_trigger_type___4;

struct journal_head___4 {
	struct buffer_head___7 *b_bh;
	spinlock_t b_state_lock;
	int b_jcount;
	unsigned int b_jlist;
	unsigned int b_modified;
	char *b_frozen_data;
	char *b_committed_data;
	transaction_t___4 *b_transaction;
	transaction_t___4 *b_next_transaction;
	struct journal_head___4 *b_tnext;
	struct journal_head___4 *b_tprev;
	transaction_t___4 *b_cp_transaction;
	struct journal_head___4 *b_cpnext;
	struct journal_head___4 *b_cpprev;
	struct jbd2_buffer_trigger_type___4 *b_triggers;
	struct jbd2_buffer_trigger_type___4 *b_frozen_triggers;
};

struct jbd2_buffer_trigger_type___4 {
	void (*t_frozen)(struct jbd2_buffer_trigger_type___4 *, struct buffer_head___7 *, void *, size_t);
	void (*t_abort)(struct jbd2_buffer_trigger_type___4 *, struct buffer_head___7 *);
};

struct crypto_alg___8;

struct crypto_tfm___8 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___8 *);
	struct crypto_alg___8 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___8 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___8 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___8 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___8 *, u8 *, const u8 *);
};

struct compress_alg___8 {
	int (*coa_compress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___8 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___8 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___8 cipher;
		struct compress_alg___8 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___8 *);
	void (*cra_exit)(struct crypto_tfm___8 *);
	void (*cra_destroy)(struct crypto_alg___8 *);
	struct module___123 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___7 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___8 base;
};

struct jbd2_journal_handle___4;

typedef struct jbd2_journal_handle___4 handle_t___4;

struct jbd2_journal_handle___4 {
	union {
		transaction_t___4 *h_transaction;
		journal_t___4 *h_journal;
	};
	handle_t___4 *h_rsv_handle;
	int h_total_credits;
	int h_revoke_credits;
	int h_revoke_credits_requested;
	int h_ref;
	int h_err;
	unsigned int h_sync: 1;
	unsigned int h_jdata: 1;
	unsigned int h_reserved: 1;
	unsigned int h_aborted: 1;
	unsigned int h_type: 8;
	unsigned int h_line_no: 16;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int h_start_jiffies;
	unsigned int h_requested_credits;
	unsigned int saved_alloc_context;
};

struct jbd2_inode___4;

struct journal_s___4 {
	long unsigned int j_flags;
	long unsigned int j_atomic_flags;
	int j_errno;
	struct mutex j_abort_mutex;
	struct buffer_head___7 *j_sb_buffer;
	journal_superblock_t *j_superblock;
	int j_format_version;
	rwlock_t j_state_lock;
	int j_barrier_count;
	struct mutex j_barrier;
	transaction_t___4 *j_running_transaction;
	transaction_t___4 *j_committing_transaction;
	transaction_t___4 *j_checkpoint_transactions;
	wait_queue_head_t j_wait_transaction_locked;
	wait_queue_head_t j_wait_done_commit;
	wait_queue_head_t j_wait_commit;
	wait_queue_head_t j_wait_updates;
	wait_queue_head_t j_wait_reserved;
	wait_queue_head_t j_fc_wait;
	struct mutex j_checkpoint_mutex;
	struct buffer_head___7 *j_chkpt_bhs[64];
	struct shrinker___50 j_shrinker;
	struct percpu_counter j_checkpoint_jh_count;
	transaction_t___4 *j_shrink_transaction;
	long unsigned int j_head;
	long unsigned int j_tail;
	long unsigned int j_free;
	long unsigned int j_first;
	long unsigned int j_last;
	long unsigned int j_fc_first;
	long unsigned int j_fc_off;
	long unsigned int j_fc_last;
	struct block_device___62 *j_dev;
	int j_blocksize;
	long long unsigned int j_blk_offset;
	char j_devname[56];
	struct block_device___62 *j_fs_dev;
	unsigned int j_total_len;
	atomic_t j_reserved_credits;
	spinlock_t j_list_lock;
	struct inode___134 *j_inode;
	tid_t j_tail_sequence;
	tid_t j_transaction_sequence;
	tid_t j_commit_sequence;
	tid_t j_commit_request;
	__u8 j_uuid[16];
	struct task_struct___141 *j_task;
	int j_max_transaction_buffers;
	int j_revoke_records_per_block;
	long unsigned int j_commit_interval;
	struct timer_list j_commit_timer;
	spinlock_t j_revoke_lock;
	struct jbd2_revoke_table_s *j_revoke;
	struct jbd2_revoke_table_s *j_revoke_table[2];
	struct buffer_head___7 **j_wbuf;
	struct buffer_head___7 **j_fc_wbuf;
	int j_wbufsize;
	int j_fc_wbufsize;
	pid_t j_last_sync_writer;
	u64 j_average_commit_time;
	u32 j_min_batch_time;
	u32 j_max_batch_time;
	void (*j_commit_callback)(journal_t___4 *, transaction_t___4 *);
	int (*j_submit_inode_data_buffers)(struct jbd2_inode___4 *);
	int (*j_finish_inode_data_buffers)(struct jbd2_inode___4 *);
	spinlock_t j_history_lock;
	struct proc_dir_entry *j_proc_entry;
	struct transaction_stats_s j_stats;
	unsigned int j_failed_commit;
	void *j_private;
	struct crypto_shash___7 *j_chksum_driver;
	__u32 j_csum_seed;
	void (*j_fc_cleanup_callback)(struct journal_s___4 *, int, tid_t);
	int (*j_fc_replay_callback)(struct journal_s___4 *, struct buffer_head___7 *, enum passtype, int, tid_t);
};

struct jbd2_inode___4 {
	transaction_t___4 *i_transaction;
	transaction_t___4 *i_next_transaction;
	struct list_head i_list;
	struct inode___134 *i_vfs_inode;
	long unsigned int i_flags;
	loff_t i_dirty_start;
	loff_t i_dirty_end;
};

struct ext4_inode_info___4 {
	__le32 i_data[15];
	__u32 i_dtime;
	ext4_fsblk_t i_file_acl;
	ext4_group_t i_block_group;
	ext4_lblk_t i_dir_start_lookup;
	long unsigned int i_flags;
	struct rw_semaphore xattr_sem;
	union {
		struct list_head i_orphan;
		unsigned int i_orphan_idx;
	};
	struct list_head i_fc_list;
	ext4_lblk_t i_fc_lblk_start;
	ext4_lblk_t i_fc_lblk_len;
	atomic_t i_fc_updates;
	wait_queue_head_t i_fc_wait;
	struct mutex i_fc_lock;
	loff_t i_disksize;
	struct rw_semaphore i_data_sem;
	struct inode___134 vfs_inode;
	struct jbd2_inode___4 *jinode;
	spinlock_t i_raw_lock;
	struct timespec64 i_crtime;
	atomic_t i_prealloc_active;
	struct list_head i_prealloc_list;
	spinlock_t i_prealloc_lock;
	struct ext4_es_tree i_es_tree;
	rwlock_t i_es_lock;
	struct list_head i_es_list;
	unsigned int i_es_all_nr;
	unsigned int i_es_shk_nr;
	ext4_lblk_t i_es_shrink_lblk;
	ext4_group_t i_last_alloc_group;
	unsigned int i_reserved_data_blocks;
	struct ext4_pending_tree i_pending_tree;
	__u16 i_extra_isize;
	u16 i_inline_off;
	u16 i_inline_size;
	qsize_t i_reserved_quota;
	spinlock_t i_completed_io_lock;
	struct list_head i_rsv_conversion_list;
	struct work_struct i_rsv_conversion_work;
	atomic_t i_unwritten;
	spinlock_t i_block_reservation_lock;
	tid_t i_sync_tid;
	tid_t i_datasync_tid;
	struct dquot___134 *i_dquot[3];
	__u32 i_csum_seed;
	kprojid_t i_projid;
};

enum bio_post_read_step {
	STEP_INITIAL = 0,
	STEP_DECRYPT = 1,
	STEP_VERITY = 2,
	STEP_MAX = 3,
};

struct bio_post_read_ctx {
	struct bio___61 *bio;
	struct work_struct work;
	unsigned int cur_step;
	unsigned int enabled_steps;
};

enum {
	BLOCK_BITMAP = 0,
	INODE_BITMAP = 1,
	INODE_TABLE = 2,
	GROUP_TABLE_COUNT = 3,
};

struct ext4_rcu_ptr {
	struct callback_head rcu;
	void *ptr;
};

struct ext4_new_flex_group_data {
	struct ext4_new_group_data *groups;
	__u16 *bg_flags;
	ext4_group_t count;
};

struct dentry___135;

struct super_block___135;

struct module___124;

struct file_system_type___135 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___135 * (*mount)(struct file_system_type___135 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___135 *);
	struct module___124 *owner;
	struct file_system_type___135 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___135;

struct kiocb___135;

struct iov_iter___76;

struct poll_table_struct___87;

struct vm_area_struct___140;

struct inode___135;

struct file_lock___135;

struct page___140;

struct seq_file___117;

struct file_operations___135 {
	struct module___124 *owner;
	loff_t (*llseek)(struct file___135 *, loff_t, int);
	ssize_t (*read)(struct file___135 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___135 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___135 *, struct iov_iter___76 *);
	ssize_t (*write_iter)(struct kiocb___135 *, struct iov_iter___76 *);
	int (*iopoll)(struct kiocb___135 *, bool);
	int (*iterate)(struct file___135 *, struct dir_context *);
	int (*iterate_shared)(struct file___135 *, struct dir_context *);
	__poll_t (*poll)(struct file___135 *, struct poll_table_struct___87 *);
	long int (*unlocked_ioctl)(struct file___135 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___135 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___135 *, struct vm_area_struct___140 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___135 *, struct file___135 *);
	int (*flush)(struct file___135 *, fl_owner_t);
	int (*release)(struct inode___135 *, struct file___135 *);
	int (*fsync)(struct file___135 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___135 *, int);
	int (*lock)(struct file___135 *, int, struct file_lock___135 *);
	ssize_t (*sendpage)(struct file___135 *, struct page___140 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___135 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___135 *, long unsigned int);
	int (*flock)(struct file___135 *, int, struct file_lock___135 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___135 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___135 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___135 *, long int, struct file_lock___135 **, void **);
	long int (*fallocate)(struct file___135 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___117 *, struct file___135 *);
	ssize_t (*copy_file_range)(struct file___135 *, loff_t, struct file___135 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___135 *, loff_t, struct file___135 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___135 *, loff_t, loff_t, int);
};

struct vmacache___140 {
	u64 seqnum;
	struct vm_area_struct___140 *vmas[4];
};

struct page_frag___140 {
	struct page___140 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___65;

struct debug_info___65 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___65 *hbp_break[16];
	struct perf_event___65 *hbp_watch[16];
};

struct thread_struct___65 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___65 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___141;

struct pid___120;

struct nsproxy___126;

struct signal_struct___136;

struct bio_list___62;

struct backing_dev_info___59;

struct io_context___62;

struct css_set___96;

struct perf_event_context___65;

struct mem_cgroup___51;

struct request_queue___62;

struct vm_struct___122;

struct task_struct___142 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___142 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___141 *mm;
	struct mm_struct___141 *active_mm;
	struct vmacache___140 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___142 *real_parent;
	struct task_struct___142 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___142 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___120 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___126 *nsproxy;
	struct signal_struct___136 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___142 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___62 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___59 *backing_dev_info;
	struct io_context___62 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___96 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___65 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___140 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___51 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___51 *active_memcg;
	struct request_queue___62 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___142 *oom_reaper_list;
	struct vm_struct___122 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___126;

struct kobj_type___126;

struct kernfs_node___126;

struct kobject___126 {
	const char *name;
	struct list_head entry;
	struct kobject___126 *parent;
	struct kset___126 *kset;
	struct kobj_type___126 *ktype;
	struct kernfs_node___126 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___123 {
	struct kobject___126 kobj;
	struct module___124 *mod;
	struct kobject___126 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___123 {
	struct module___124 *mod;
	struct latch_tree_node node;
};

struct module_layout___123 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___123 mtn;
};

struct module_attribute___123;

struct kernel_param___123;

struct trace_event_call___59;

struct module___124 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___123 mkobj;
	struct module_attribute___123 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___126 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___123 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___123 core_layout;
	struct module_layout___123 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___59 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___65 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___142 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___65)(struct perf_event___65 *, struct perf_sample_data___3 *, struct pt_regs *);

struct pmu___65;

struct fasync_struct___135;

struct pid_namespace___120;

struct perf_cgroup___65;

struct perf_event___65 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___65 *group_leader;
	struct pmu___65 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___65 hw;
	struct perf_event_context___65 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___65 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___142 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___135 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___65 *aux_event;
	void (*destroy)(struct perf_event___65 *);
	struct callback_head callback_head;
	struct pid_namespace___120 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___65 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___65 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___59 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___65 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___120 {
	int nr;
	struct pid_namespace___120 *ns;
};

struct pid_namespace___120 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___142 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___120 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___120 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___120 numbers[1];
};

typedef struct page___140 *pgtable_t___140;

struct address_space___135;

struct dev_pagemap___133;

struct page___140 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___135 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___140 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___140 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___141 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___133 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___133;

struct vm_area_struct___140 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___140 *vm_next;
	struct vm_area_struct___140 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___141 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___133 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___135 *vm_file;
	struct file___135 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___136 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___142 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___142 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___120 *pids[4];
	struct pid___120 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___141 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___140;

struct mm_struct___141 {
	struct {
		struct vm_area_struct___140 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___135 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___140 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___142 *owner;
		struct user_namespace___19 *user_ns;
		struct file___135 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___96;

struct nsproxy___126 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___120 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___96 *cgroup_ns;
};

struct bio___62;

struct bio_list___62 {
	struct bio___62 *head;
	struct bio___62 *tail;
};

struct cgroup_subsys_state___96;

struct bdi_writeback___59 {
	struct backing_dev_info___59 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___96 *memcg_css;
	struct cgroup_subsys_state___96 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___100;

struct backing_dev_info___59 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___59 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___100 *dev;
	char dev_name[64];
	struct device___100 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___135 *debug_dir;
};

struct io_cq___62;

struct io_context___62 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___62 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___96;

struct css_set___96 {
	struct cgroup_subsys_state___96 *subsys[14];
	refcount_t refcount;
	struct css_set___96 *dom_cset;
	struct cgroup___96 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___96 *mg_src_cgrp;
	struct cgroup___96 *mg_dst_cgrp;
	struct css_set___96 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___65 {
	struct pmu___65 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___142 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___65 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___96;

struct cgroup_subsys_state___96 {
	struct cgroup___96 *cgroup;
	struct cgroup_subsys___96 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___96 *parent;
};

struct cgroup_file___96 {
	struct kernfs_node___126 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___51;

struct mem_cgroup_per_node___51;

struct mem_cgroup___51 {
	struct cgroup_subsys_state___96 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___96 events_file;
	struct cgroup_file___96 events_local_file;
	struct cgroup_file___96 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___51 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___142 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___51 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___62;

struct blk_integrity___62 {
	const struct blk_integrity_profile___62 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___62 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___62 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___62;

struct elevator_queue___62;

struct blk_mq_ops___59;

struct blk_mq_hw_ctx___59;

struct gendisk___62;

struct blkcg_gq___59;

struct blk_mq_tag_set___59;

struct request_queue___62 {
	struct request___62 *last_merge;
	struct elevator_queue___62 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___59 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___59 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___62 *disk;
	struct kobject___126 kobj;
	struct kobject___126 *mq_kobj;
	struct blk_integrity___62 integrity;
	struct device___100 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___59 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___59 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___62 bio_split;
	struct dentry___135 *debugfs_dir;
	struct dentry___135 *sched_debugfs_dir;
	struct dentry___135 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___122 {
	struct vm_struct___122 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___140 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___135;

struct address_space___135 {
	struct inode___135 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___135 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___133;

struct dev_pagemap___133 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___133 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___135;

struct path___135 {
	struct vfsmount___135 *mnt;
	struct dentry___135 *dentry;
};

struct fown_struct___120 {
	rwlock_t lock;
	struct pid___120 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___135 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___135 f_path;
	struct inode___135 *f_inode;
	const struct file_operations___135 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___120 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___135 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___133;

struct vm_operations_struct___133 {
	void (*open)(struct vm_area_struct___140 *);
	void (*close)(struct vm_area_struct___140 *);
	int (*may_split)(struct vm_area_struct___140 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___140 *);
	int (*mprotect)(struct vm_area_struct___140 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___133 *);
	vm_fault_t (*huge_fault)(struct vm_fault___133 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___133 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___140 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___133 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___133 *);
	int (*access)(struct vm_area_struct___140 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___140 *);
	int (*set_policy)(struct vm_area_struct___140 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___140 *, long unsigned int);
	struct page___140 * (*find_special_page)(struct vm_area_struct___140 *, long unsigned int);
};

struct core_thread___140 {
	struct task_struct___142 *task;
	struct core_thread___140 *next;
};

struct core_state___140 {
	atomic_t nr_threads;
	struct core_thread___140 dumper;
	struct completion startup;
};

struct vm_fault___133 {
	const struct {
		struct vm_area_struct___140 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___140 *cow_page;
	struct page___140 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___140 prealloc_pte;
};

struct pglist_data___58;

struct lruvec___58 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___58 *pgdat;
};

struct zone___58 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___58 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___58 {
	struct zone___58 *zone;
	int zone_idx;
};

struct zonelist___58 {
	struct zoneref___58 _zonerefs[321];
};

struct pglist_data___58 {
	struct zone___58 node_zones[5];
	struct zonelist___58 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___142 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___142 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___58 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___135;

struct dentry___135 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___135 *d_parent;
	struct qstr d_name;
	struct inode___135 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___135 *d_op;
	struct super_block___135 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___135;

struct inode___135 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___135 *i_op;
	struct super_block___135 *i_sb;
	struct address_space___135 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___59 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___135 *i_fop;
		void (*free_inode)(struct inode___135 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___135 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___135 {
	int (*d_revalidate)(struct dentry___135 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___135 *, unsigned int);
	int (*d_hash)(const struct dentry___135 *, struct qstr *);
	int (*d_compare)(const struct dentry___135 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___135 *);
	int (*d_init)(struct dentry___135 *);
	void (*d_release)(struct dentry___135 *);
	void (*d_prune)(struct dentry___135 *);
	void (*d_iput)(struct dentry___135 *, struct inode___135 *);
	char * (*d_dname)(struct dentry___135 *, char *, int);
	struct vfsmount___135 * (*d_automount)(struct path___135 *);
	int (*d_manage)(const struct path___135 *, bool);
	struct dentry___135 * (*d_real)(struct dentry___135 *, const struct inode___135 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___135;

struct mem_dqinfo___135 {
	struct quota_format_type___135 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___135;

struct quota_info___135 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___135 *files[3];
	struct mem_dqinfo___135 info[3];
	const struct quota_format_ops___135 *ops[3];
};

struct rcuwait___136 {
	struct task_struct___142 *task;
};

struct percpu_rw_semaphore___136 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___136 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___135 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___136 rw_sem[3];
};

struct shrink_control___51;

struct shrinker___51 {
	long unsigned int (*count_objects)(struct shrinker___51 *, struct shrink_control___51 *);
	long unsigned int (*scan_objects)(struct shrinker___51 *, struct shrink_control___51 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___135;

struct dquot_operations___135;

struct quotactl_ops___135;

struct export_operations___12;

struct xattr_handler___16;

struct fscrypt_operations___11;

struct fsverity_operations___9;

struct block_device___63;

struct super_block___135 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___135 *s_type;
	const struct super_operations___135 *s_op;
	const struct dquot_operations___135 *dq_op;
	const struct quotactl_ops___135 *s_qcop;
	const struct export_operations___12 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___135 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___16 **s_xattr;
	const struct fscrypt_operations___11 *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations___9 *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___63 *s_bdev;
	struct backing_dev_info___59 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___135 s_dquot;
	struct sb_writers___135 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___135 *s_d_op;
	int cleancache_poolid;
	struct shrinker___51 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___135 {
	struct dentry___135 *mnt_root;
	struct super_block___135 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct shrink_control___51 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___51 *memcg;
};

struct psi_group___96 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___142 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___96;

struct cgroup_rstat_cpu___96;

struct cgroup___96 {
	struct cgroup_subsys_state___96 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___126 *kn;
	struct cgroup_file___96 procs_file;
	struct cgroup_file___96 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___96 *subsys[14];
	struct cgroup_root___96 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___96 *dom_cgrp;
	struct cgroup___96 *old_dom_cgrp;
	struct cgroup_rstat_cpu___96 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___96 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___62 {
	struct request_queue___62 *q;
	struct io_context___62 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___8;

typedef void bh_end_io_t___8(struct buffer_head___8 *, int);

struct buffer_head___8 {
	long unsigned int b_state;
	struct buffer_head___8 *b_this_page;
	struct page___140 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___63 *b_bdev;
	bh_end_io_t___8 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___135 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___64;

struct kiocb___135 {
	struct file___135 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___135 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___64 *ki_waitq;
	};
};

struct iattr___135 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___135 *ia_file;
};

struct dquot___135 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___135 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___135 {
	int qf_fmt_id;
	const struct quota_format_ops___135 *qf_ops;
	struct module___124 *qf_owner;
	struct quota_format_type___135 *qf_next;
};

struct quota_format_ops___135 {
	int (*check_quota_file)(struct super_block___135 *, int);
	int (*read_file_info)(struct super_block___135 *, int);
	int (*write_file_info)(struct super_block___135 *, int);
	int (*free_file_info)(struct super_block___135 *, int);
	int (*read_dqblk)(struct dquot___135 *);
	int (*commit_dqblk)(struct dquot___135 *);
	int (*release_dqblk)(struct dquot___135 *);
	int (*get_next_id)(struct super_block___135 *, struct kqid *);
};

struct dquot_operations___135 {
	int (*write_dquot)(struct dquot___135 *);
	struct dquot___135 * (*alloc_dquot)(struct super_block___135 *, int);
	void (*destroy_dquot)(struct dquot___135 *);
	int (*acquire_dquot)(struct dquot___135 *);
	int (*release_dquot)(struct dquot___135 *);
	int (*mark_dirty)(struct dquot___135 *);
	int (*write_info)(struct super_block___135 *, int);
	qsize_t * (*get_reserved_space)(struct inode___135 *);
	int (*get_projid)(struct inode___135 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___135 *, qsize_t *);
	int (*get_next_id)(struct super_block___135 *, struct kqid *);
};

struct quotactl_ops___135 {
	int (*quota_on)(struct super_block___135 *, int, int, const struct path___135 *);
	int (*quota_off)(struct super_block___135 *, int);
	int (*quota_enable)(struct super_block___135 *, unsigned int);
	int (*quota_disable)(struct super_block___135 *, unsigned int);
	int (*quota_sync)(struct super_block___135 *, int);
	int (*set_info)(struct super_block___135 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___135 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___135 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___135 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___135 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___135 *, unsigned int);
};

struct wait_page_queue___64 {
	struct page___140 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___59;

struct readahead_control___64;

struct swap_info_struct___33;

struct address_space_operations___135 {
	int (*writepage)(struct page___140 *, struct writeback_control___59 *);
	int (*readpage)(struct file___135 *, struct page___140 *);
	int (*writepages)(struct address_space___135 *, struct writeback_control___59 *);
	int (*set_page_dirty)(struct page___140 *);
	int (*readpages)(struct file___135 *, struct address_space___135 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___64 *);
	int (*write_begin)(struct file___135 *, struct address_space___135 *, loff_t, unsigned int, unsigned int, struct page___140 **, void **);
	int (*write_end)(struct file___135 *, struct address_space___135 *, loff_t, unsigned int, unsigned int, struct page___140 *, void *);
	sector_t (*bmap)(struct address_space___135 *, sector_t);
	void (*invalidatepage)(struct page___140 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___140 *, gfp_t);
	void (*freepage)(struct page___140 *);
	ssize_t (*direct_IO)(struct kiocb___135 *, struct iov_iter___76 *);
	int (*migratepage)(struct address_space___135 *, struct page___140 *, struct page___140 *, enum migrate_mode);
	bool (*isolate_page)(struct page___140 *, isolate_mode_t);
	void (*putback_page)(struct page___140 *);
	int (*launder_page)(struct page___140 *);
	int (*is_partially_uptodate)(struct page___140 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___140 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___135 *, struct page___140 *);
	int (*swap_activate)(struct swap_info_struct___33 *, struct file___135 *, sector_t *);
	void (*swap_deactivate)(struct file___135 *);
};

struct writeback_control___59 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___59 *wb;
	struct inode___135 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___64 {
	struct file___135 *file;
	struct address_space___135 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___74;

struct iov_iter___76 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___74 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___33 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___63 *bdev;
	struct file___135 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___135 {
	struct dentry___135 * (*lookup)(struct inode___135 *, struct dentry___135 *, unsigned int);
	const char * (*get_link)(struct dentry___135 *, struct inode___135 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___135 *, int);
	struct posix_acl * (*get_acl)(struct inode___135 *, int, bool);
	int (*readlink)(struct dentry___135 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___135 *, struct dentry___135 *, umode_t, bool);
	int (*link)(struct dentry___135 *, struct inode___135 *, struct dentry___135 *);
	int (*unlink)(struct inode___135 *, struct dentry___135 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___135 *, struct dentry___135 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___135 *, struct dentry___135 *, umode_t);
	int (*rmdir)(struct inode___135 *, struct dentry___135 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___135 *, struct dentry___135 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___135 *, struct dentry___135 *, struct inode___135 *, struct dentry___135 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___135 *, struct iattr___135 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___135 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___135 *, char *, size_t);
	int (*fiemap)(struct inode___135 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___135 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___135 *, struct dentry___135 *, struct file___135 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___135 *, struct dentry___135 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___135 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___135 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___135 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___135 {
	void (*fl_copy_lock)(struct file_lock___135 *, struct file_lock___135 *);
	void (*fl_release_private)(struct file_lock___135 *);
};

struct lock_manager_operations___135;

struct file_lock___135 {
	struct file_lock___135 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___135 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___135 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___135 *fl_ops;
	const struct lock_manager_operations___135 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___135 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___135 *);
	int (*lm_grant)(struct file_lock___135 *, int);
	bool (*lm_break)(struct file_lock___135 *);
	int (*lm_change)(struct file_lock___135 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___135 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___135 *);
};

struct fasync_struct___135 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___135 *fa_next;
	struct file___135 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___135 {
	struct inode___135 * (*alloc_inode)(struct super_block___135 *);
	void (*destroy_inode)(struct inode___135 *);
	void (*free_inode)(struct inode___135 *);
	void (*dirty_inode)(struct inode___135 *, int);
	int (*write_inode)(struct inode___135 *, struct writeback_control___59 *);
	int (*drop_inode)(struct inode___135 *);
	void (*evict_inode)(struct inode___135 *);
	void (*put_super)(struct super_block___135 *);
	int (*sync_fs)(struct super_block___135 *, int);
	int (*freeze_super)(struct super_block___135 *);
	int (*freeze_fs)(struct super_block___135 *);
	int (*thaw_super)(struct super_block___135 *);
	int (*unfreeze_fs)(struct super_block___135 *);
	int (*statfs)(struct dentry___135 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___135 *, int *, char *);
	void (*umount_begin)(struct super_block___135 *);
	int (*show_options)(struct seq_file___117 *, struct dentry___135 *);
	int (*show_devname)(struct seq_file___117 *, struct dentry___135 *);
	int (*show_path)(struct seq_file___117 *, struct dentry___135 *);
	int (*show_stats)(struct seq_file___117 *, struct dentry___135 *);
	ssize_t (*quota_read)(struct super_block___135 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___135 *, int, const char *, size_t, loff_t);
	struct dquot___135 ** (*get_dquots)(struct inode___135 *);
	long int (*nr_cached_objects)(struct super_block___135 *, struct shrink_control___51 *);
	long int (*free_cached_objects)(struct super_block___135 *, struct shrink_control___51 *);
	struct file___135 * (*real_loop)(struct file___135 *);
};

struct export_operations___12 {
	int (*encode_fh)(struct inode___135 *, __u32 *, int *, struct inode___135 *);
	struct dentry___135 * (*fh_to_dentry)(struct super_block___135 *, struct fid *, int, int);
	struct dentry___135 * (*fh_to_parent)(struct super_block___135 *, struct fid *, int, int);
	int (*get_name)(struct dentry___135 *, char *, struct dentry___135 *);
	struct dentry___135 * (*get_parent)(struct dentry___135 *);
	int (*commit_metadata)(struct inode___135 *);
	int (*get_uuid)(struct super_block___135 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___135 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___135 *, struct iomap *, int, struct iattr___135 *);
	u64 (*fetch_iversion)(struct inode___135 *);
	long unsigned int flags;
};

struct xattr_handler___16 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___135 *);
	int (*get)(const struct xattr_handler___16 *, struct dentry___135 *, struct inode___135 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___16 *, struct user_namespace___19 *, struct dentry___135 *, struct inode___135 *, const char *, const void *, size_t, int);
};

struct fscrypt_operations___11 {
	unsigned int flags;
	const char *key_prefix;
	int (*get_context)(struct inode___135 *, void *, size_t);
	int (*set_context)(struct inode___135 *, const void *, size_t, void *);
	const union fscrypt_policy * (*get_dummy_policy)(struct super_block___135 *);
	bool (*empty_dir)(struct inode___135 *);
	unsigned int max_namelen;
	bool (*has_stable_inodes)(struct super_block___135 *);
	void (*get_ino_and_lblk_bits)(struct super_block___135 *, int *, int *);
	int (*get_num_devices)(struct super_block___135 *);
	void (*get_devices)(struct super_block___135 *, struct request_queue___62 **);
};

struct fsverity_operations___9 {
	int (*begin_enable_verity)(struct file___135 *);
	int (*end_enable_verity)(struct file___135 *, const void *, size_t, u64);
	int (*get_verity_descriptor)(struct inode___135 *, void *, size_t);
	struct page___140 * (*read_merkle_tree_page)(struct inode___135 *, long unsigned int, long unsigned int);
	int (*write_merkle_tree_block)(struct inode___135 *, const void *, u64, int);
};

struct wakeup_source___100;

struct dev_pm_info___100 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___100 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___100 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___100;

struct bus_type___100;

struct device_driver___100;

struct dev_pm_domain___100;

struct fwnode_handle___100;

struct class___100;

struct attribute_group___126;

struct device___100 {
	struct kobject___126 kobj;
	struct device___100 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___100 *type;
	struct bus_type___100 *bus;
	struct device_driver___100 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___100 power;
	struct dev_pm_domain___100 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___100 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___100 *class;
	const struct attribute_group___126 **groups;
	void (*release)(struct device___100 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___63 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___135 *bd_inode;
	struct super_block___135 *bd_super;
	void *bd_claiming;
	struct device___100 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___126 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___62 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___135 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___88)(struct file___135 *, wait_queue_head_t *, struct poll_table_struct___87 *);

struct poll_table_struct___87 {
	poll_queue_proc___88 _qproc;
	__poll_t _key;
};

struct seq_operations___117;

struct seq_file___117 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___117 *op;
	int poll_event;
	const struct file___135 *file;
	void *private;
};

typedef void bio_end_io_t___62(struct bio___62 *);

struct bio_vec___74 {
	struct page___140 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___62;

struct bio___62 {
	struct bio___62 *bi_next;
	struct block_device___63 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___62 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___59 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___62 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___74 *bi_io_vec;
	struct bio_set___62 *bi_pool;
	struct bio_vec___74 bi_inline_vecs[0];
};

struct kernfs_root___126;

struct kernfs_elem_dir___126 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___126 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___126;

struct kernfs_root___126 {
	struct kernfs_node___126 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___126 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___126 {
	struct kernfs_node___126 *target_kn;
};

struct kernfs_ops___126;

struct kernfs_elem_attr___126 {
	const struct kernfs_ops___126 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___126 *notify_next;
};

struct kernfs_node___126 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___126 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___126 dir;
		struct kernfs_elem_symlink___126 symlink;
		struct kernfs_elem_attr___126 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___126;

struct kernfs_ops___126 {
	int (*open)(struct kernfs_open_file___126 *);
	void (*release)(struct kernfs_open_file___126 *);
	int (*seq_show)(struct seq_file___117 *, void *);
	void * (*seq_start)(struct seq_file___117 *, loff_t *);
	void * (*seq_next)(struct seq_file___117 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___117 *, void *);
	ssize_t (*read)(struct kernfs_open_file___126 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___126 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___126 *, struct poll_table_struct___87 *);
	int (*mmap)(struct kernfs_open_file___126 *, struct vm_area_struct___140 *);
};

struct kernfs_syscall_ops___126 {
	int (*show_options)(struct seq_file___117 *, struct kernfs_root___126 *);
	int (*mkdir)(struct kernfs_node___126 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___126 *);
	int (*rename)(struct kernfs_node___126 *, struct kernfs_node___126 *, const char *);
	int (*show_path)(struct seq_file___117 *, struct kernfs_node___126 *, struct kernfs_root___126 *);
};

struct kernfs_open_file___126 {
	struct kernfs_node___126 *kn;
	struct file___135 *file;
	struct seq_file___117 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___133 *vm_ops;
};

struct bin_attribute___126;

struct attribute_group___126 {
	const char *name;
	umode_t (*is_visible)(struct kobject___126 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___126 *, struct bin_attribute___126 *, int);
	struct attribute **attrs;
	struct bin_attribute___126 **bin_attrs;
};

struct bin_attribute___126 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___135 * (*f_mapping)();
	ssize_t (*read)(struct file___135 *, struct kobject___126 *, struct bin_attribute___126 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___135 *, struct kobject___126 *, struct bin_attribute___126 *, char *, loff_t, size_t);
	int (*mmap)(struct file___135 *, struct kobject___126 *, struct bin_attribute___126 *, struct vm_area_struct___140 *);
};

struct sysfs_ops___126 {
	ssize_t (*show)(struct kobject___126 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___126 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___126;

struct kset___126 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___126 kobj;
	const struct kset_uevent_ops___126 *uevent_ops;
};

struct kobj_type___126 {
	void (*release)(struct kobject___126 *);
	const struct sysfs_ops___126 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___126 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___126 *);
	const void * (*namespace)(struct kobject___126 *);
	void (*get_ownership)(struct kobject___126 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___126 {
	int (* const filter)(struct kset___126 *, struct kobject___126 *);
	const char * (* const name)(struct kset___126 *, struct kobject___126 *);
	int (* const uevent)(struct kset___126 *, struct kobject___126 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___123 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___123 *);
	int (*get)(char *, const struct kernel_param___123 *);
	void (*free)(void *);
};

struct kparam_array___123;

struct kernel_param___123 {
	const char *name;
	struct module___124 *mod;
	const struct kernel_param_ops___123 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___123 *arr;
	};
};

struct kparam_array___123 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___123 *ops;
	void *elem;
};

struct module_attribute___123 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___123 *, struct module_kobject___123 *, char *);
	ssize_t (*store)(struct module_attribute___123 *, struct module_kobject___123 *, const char *, size_t);
	void (*setup)(struct module___124 *, const char *);
	int (*test)(struct module___124 *);
	void (*free)(struct module___124 *);
};

struct trace_event_class___59;

struct trace_event_call___59 {
	struct list_head list;
	struct trace_event_class___59 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___59 *, struct perf_event___65 *);
};

struct dev_pagemap_ops___133 {
	void (*page_free)(struct page___140 *);
	void (*kill)(struct dev_pagemap___133 *);
	void (*cleanup)(struct dev_pagemap___133 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___133 *);
};

struct fwnode_operations___100;

struct fwnode_handle___100 {
	struct fwnode_handle___100 *secondary;
	const struct fwnode_operations___100 *ops;
	struct device___100 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___100;

struct fwnode_endpoint___100;

struct fwnode_operations___100 {
	struct fwnode_handle___100 * (*get)(struct fwnode_handle___100 *);
	void (*put)(struct fwnode_handle___100 *);
	bool (*device_is_available)(const struct fwnode_handle___100 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___100 *, const struct device___100 *);
	bool (*property_present)(const struct fwnode_handle___100 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___100 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___100 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___100 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*get_parent)(const struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*get_next_child_node)(const struct fwnode_handle___100 *, struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*get_named_child_node)(const struct fwnode_handle___100 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___100 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___100 *);
	struct fwnode_handle___100 * (*graph_get_next_endpoint)(const struct fwnode_handle___100 *, struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*graph_get_remote_endpoint)(const struct fwnode_handle___100 *);
	struct fwnode_handle___100 * (*graph_get_port_parent)(struct fwnode_handle___100 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___100 *, struct fwnode_endpoint___100 *);
	int (*add_links)(struct fwnode_handle___100 *);
};

struct fwnode_endpoint___100 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___100 *local_fwnode;
};

struct fwnode_reference_args___100 {
	struct fwnode_handle___100 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___96 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___96 *root_cset;
};

struct dev_pm_ops___100 {
	int (*prepare)(struct device___100 *);
	void (*complete)(struct device___100 *);
	int (*suspend)(struct device___100 *);
	int (*resume)(struct device___100 *);
	int (*freeze)(struct device___100 *);
	int (*thaw)(struct device___100 *);
	int (*poweroff)(struct device___100 *);
	int (*restore)(struct device___100 *);
	int (*suspend_late)(struct device___100 *);
	int (*resume_early)(struct device___100 *);
	int (*freeze_late)(struct device___100 *);
	int (*thaw_early)(struct device___100 *);
	int (*poweroff_late)(struct device___100 *);
	int (*restore_early)(struct device___100 *);
	int (*suspend_noirq)(struct device___100 *);
	int (*resume_noirq)(struct device___100 *);
	int (*freeze_noirq)(struct device___100 *);
	int (*thaw_noirq)(struct device___100 *);
	int (*poweroff_noirq)(struct device___100 *);
	int (*restore_noirq)(struct device___100 *);
	int (*runtime_suspend)(struct device___100 *);
	int (*runtime_resume)(struct device___100 *);
	int (*runtime_idle)(struct device___100 *);
};

struct wakeup_source___100 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___100 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___100 {
	struct dev_pm_ops___100 ops;
	int (*start)(struct device___100 *);
	void (*detach)(struct device___100 *, bool);
	int (*activate)(struct device___100 *);
	void (*sync)(struct device___100 *);
	void (*dismiss)(struct device___100 *);
};

struct bus_type___100 {
	const char *name;
	const char *dev_name;
	struct device___100 *dev_root;
	const struct attribute_group___126 **bus_groups;
	const struct attribute_group___126 **dev_groups;
	const struct attribute_group___126 **drv_groups;
	int (*match)(struct device___100 *, struct device_driver___100 *);
	int (*uevent)(struct device___100 *, struct kobj_uevent_env *);
	int (*probe)(struct device___100 *);
	void (*sync_state)(struct device___100 *);
	void (*remove)(struct device___100 *);
	void (*shutdown)(struct device___100 *);
	int (*online)(struct device___100 *);
	int (*offline)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	int (*num_vf)(struct device___100 *);
	int (*dma_configure)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___100 {
	const char *name;
	struct bus_type___100 *bus;
	struct module___124 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___100 *);
	void (*sync_state)(struct device___100 *);
	int (*remove)(struct device___100 *);
	void (*shutdown)(struct device___100 *);
	int (*suspend)(struct device___100 *, pm_message_t);
	int (*resume)(struct device___100 *);
	const struct attribute_group___126 **groups;
	const struct attribute_group___126 **dev_groups;
	const struct dev_pm_ops___100 *pm;
	void (*coredump)(struct device___100 *);
	struct driver_private *p;
};

struct device_type___100 {
	const char *name;
	const struct attribute_group___126 **groups;
	int (*uevent)(struct device___100 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___100 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___100 *);
	const struct dev_pm_ops___100 *pm;
};

struct class___100 {
	const char *name;
	struct module___124 *owner;
	const struct attribute_group___126 **class_groups;
	const struct attribute_group___126 **dev_groups;
	struct kobject___126 *dev_kobj;
	int (*dev_uevent)(struct device___100 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___100 *, umode_t *);
	void (*class_release)(struct class___100 *);
	void (*dev_release)(struct device___100 *);
	int (*shutdown_pre)(struct device___100 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___100 *);
	void (*get_ownership)(struct device___100 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___100 *pm;
	struct subsys_private *p;
};

struct block_device_operations___62;

struct gendisk___62 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___63 *part0;
	const struct block_device_operations___62 *fops;
	struct request_queue___62 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___59 *bdi;
	struct kobject___126 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___126 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___62 {
	struct bio___62 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___74 *bip_vec;
	struct bio_vec___74 bip_inline_vecs[0];
};

struct blkcg___59;

struct blkg_policy_data___59;

struct blkcg_gq___59 {
	struct request_queue___62 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___59 *blkcg;
	struct blkcg_gq___59 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___59 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___62 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

enum stat_group {
	STAT_READ = 0,
	STAT_WRITE = 1,
	STAT_DISCARD = 2,
	STAT_FLUSH = 3,
	NR_STAT_GROUPS = 4,
};

typedef void integrity_prepare_fn___62(struct request___62 *);

typedef void integrity_complete_fn___62(struct request___62 *, unsigned int);

struct blk_integrity_profile___62 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___62 *prepare_fn;
	integrity_complete_fn___62 *complete_fn;
	const char *name;
};

struct block_device_operations___62 {
	blk_qc_t (*submit_bio)(struct bio___62 *);
	int (*open)(struct block_device___63 *, fmode_t);
	void (*release)(struct gendisk___62 *, fmode_t);
	int (*rw_page)(struct block_device___63 *, sector_t, struct page___140 *, unsigned int);
	int (*ioctl)(struct block_device___63 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___63 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___62 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___62 *);
	int (*getgeo)(struct block_device___63 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___63 *, bool);
	void (*swap_slot_free_notify)(struct block_device___63 *, long unsigned int);
	int (*report_zones)(struct gendisk___62 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___62 *, umode_t *);
	struct module___124 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___62 *, sector_t *);
};

typedef void rq_end_io_fn___62(struct request___62 *, blk_status_t);

struct request___62 {
	struct request_queue___62 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___59 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___62 *bio;
	struct bio___62 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___74 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___62 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___62 *saved_end_io;
		} flush;
	};
	struct gendisk___62 *rq_disk;
	struct block_device___63 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___62 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___59 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___62 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___126 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___135 *debugfs_dir;
	struct dentry___135 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___62;

struct elevator_mq_ops___62 {
	int (*init_sched)(struct request_queue___62 *, struct elevator_type___62 *);
	void (*exit_sched)(struct elevator_queue___62 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___59 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___59 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___59 *);
	bool (*allow_merge)(struct request_queue___62 *, struct request___62 *, struct bio___62 *);
	bool (*bio_merge)(struct request_queue___62 *, struct bio___62 *, unsigned int);
	int (*request_merge)(struct request_queue___62 *, struct request___62 **, struct bio___62 *);
	void (*request_merged)(struct request_queue___62 *, struct request___62 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___62 *, struct request___62 *, struct request___62 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___62 *);
	void (*finish_request)(struct request___62 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___59 *, struct list_head *, bool);
	struct request___62 * (*dispatch_request)(struct blk_mq_hw_ctx___59 *);
	bool (*has_work)(struct blk_mq_hw_ctx___59 *);
	void (*completed_request)(struct request___62 *, u64);
	void (*requeue_request)(struct request___62 *);
	struct request___62 * (*former_request)(struct request_queue___62 *, struct request___62 *);
	struct request___62 * (*next_request)(struct request_queue___62 *, struct request___62 *);
	void (*init_icq)(struct io_cq___62 *);
	void (*exit_icq)(struct io_cq___62 *);
};

struct elv_fs_entry___62;

struct elevator_type___62 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___62 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___62 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___124 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___62 {
	struct elevator_type___62 *type;
	void *elevator_data;
	struct kobject___126 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___62 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___62 *, char *);
	ssize_t (*store)(struct elevator_queue___62 *, const char *, size_t);
};

struct blk_mq_queue_data___59;

struct blk_mq_ops___59 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___59 *, const struct blk_mq_queue_data___59 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___59 *);
	int (*get_budget)(struct request_queue___62 *);
	void (*put_budget)(struct request_queue___62 *, int);
	void (*set_rq_budget_token)(struct request___62 *, int);
	int (*get_rq_budget_token)(struct request___62 *);
	enum blk_eh_timer_return (*timeout)(struct request___62 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___59 *);
	void (*complete)(struct request___62 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___59 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___59 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___59 *, struct request___62 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___59 *, struct request___62 *, unsigned int);
	void (*initialize_rq_fn)(struct request___62 *);
	void (*cleanup_rq)(struct request___62 *);
	bool (*busy)(struct request_queue___62 *);
	int (*map_queues)(struct blk_mq_tag_set___59 *);
	void (*show_rq)(struct seq_file___117 *, struct request___62 *);
};

struct blk_mq_tag_set___59 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___59 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___117 {
	void * (*start)(struct seq_file___117 *, loff_t *);
	void (*stop)(struct seq_file___117 *, void *);
	void * (*next)(struct seq_file___117 *, void *, loff_t *);
	int (*show)(struct seq_file___117 *, void *);
};

struct cftype___96;

struct cgroup_subsys___96 {
	struct cgroup_subsys_state___96 * (*css_alloc)(struct cgroup_subsys_state___96 *);
	int (*css_online)(struct cgroup_subsys_state___96 *);
	void (*css_offline)(struct cgroup_subsys_state___96 *);
	void (*css_released)(struct cgroup_subsys_state___96 *);
	void (*css_free)(struct cgroup_subsys_state___96 *);
	void (*css_reset)(struct cgroup_subsys_state___96 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___96 *, int);
	int (*css_extra_stat_show)(struct seq_file___117 *, struct cgroup_subsys_state___96 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___142 *, struct css_set___96 *);
	void (*cancel_fork)(struct task_struct___142 *, struct css_set___96 *);
	void (*fork)(struct task_struct___142 *);
	void (*exit)(struct task_struct___142 *);
	void (*release)(struct task_struct___142 *);
	void (*bind)(struct cgroup_subsys_state___96 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___96 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___96 *dfl_cftypes;
	struct cftype___96 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___96 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___96 *updated_children;
	struct cgroup___96 *updated_next;
};

struct cgroup_root___96 {
	struct kernfs_root___126 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___96 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___96 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___96 *ss;
	struct list_head node;
	struct kernfs_ops___126 *kf_ops;
	int (*open)(struct kernfs_open_file___126 *);
	void (*release)(struct kernfs_open_file___126 *);
	u64 (*read_u64)(struct cgroup_subsys_state___96 *, struct cftype___96 *);
	s64 (*read_s64)(struct cgroup_subsys_state___96 *, struct cftype___96 *);
	int (*seq_show)(struct seq_file___117 *, void *);
	void * (*seq_start)(struct seq_file___117 *, loff_t *);
	void * (*seq_next)(struct seq_file___117 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___117 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___96 *, struct cftype___96 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___96 *, struct cftype___96 *, s64);
	ssize_t (*write)(struct kernfs_open_file___126 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___126 *, struct poll_table_struct___87 *);
};

struct blk_mq_queue_data___59 {
	struct request___62 *rq;
	bool last;
};

struct blkcg_policy_data___59;

struct blkcg___59 {
	struct cgroup_subsys_state___96 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___59 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___59 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___59 {
	struct blkcg___59 *blkcg;
	int plid;
};

struct blkg_policy_data___59 {
	struct blkcg_gq___59 *blkg;
	int plid;
};

typedef int (*writepage_t___4)(struct page___140 *, struct writeback_control___59 *, void *);

struct journal_s___5;

typedef struct journal_s___5 journal_t___5;

struct journal_head___5;

struct transaction_s___5;

typedef struct transaction_s___5 transaction_t___5;

struct transaction_s___5 {
	journal_t___5 *t_journal;
	tid_t t_tid;
	enum {
		T_RUNNING___5 = 0,
		T_LOCKED___5 = 1,
		T_SWITCH___5 = 2,
		T_FLUSH___5 = 3,
		T_COMMIT___5 = 4,
		T_COMMIT_DFLUSH___5 = 5,
		T_COMMIT_JFLUSH___5 = 6,
		T_COMMIT_CALLBACK___5 = 7,
		T_FINISHED___5 = 8,
	} t_state;
	long unsigned int t_log_start;
	int t_nr_buffers;
	struct journal_head___5 *t_reserved_list;
	struct journal_head___5 *t_buffers;
	struct journal_head___5 *t_forget;
	struct journal_head___5 *t_checkpoint_list;
	struct journal_head___5 *t_checkpoint_io_list;
	struct journal_head___5 *t_shadow_list;
	struct list_head t_inode_list;
	spinlock_t t_handle_lock;
	long unsigned int t_max_wait;
	long unsigned int t_start;
	long unsigned int t_requested;
	struct transaction_chp_stats_s t_chp_stats;
	atomic_t t_updates;
	atomic_t t_outstanding_credits;
	atomic_t t_outstanding_revokes;
	atomic_t t_handle_count;
	transaction_t___5 *t_cpnext;
	transaction_t___5 *t_cpprev;
	long unsigned int t_expires;
	ktime_t t_start_time;
	unsigned int t_synchronous_commit: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int t_need_data_flush;
	struct list_head t_private_list;
};

struct jbd2_buffer_trigger_type___5;

struct journal_head___5 {
	struct buffer_head___8 *b_bh;
	spinlock_t b_state_lock;
	int b_jcount;
	unsigned int b_jlist;
	unsigned int b_modified;
	char *b_frozen_data;
	char *b_committed_data;
	transaction_t___5 *b_transaction;
	transaction_t___5 *b_next_transaction;
	struct journal_head___5 *b_tnext;
	struct journal_head___5 *b_tprev;
	transaction_t___5 *b_cp_transaction;
	struct journal_head___5 *b_cpnext;
	struct journal_head___5 *b_cpprev;
	struct jbd2_buffer_trigger_type___5 *b_triggers;
	struct jbd2_buffer_trigger_type___5 *b_frozen_triggers;
};

struct jbd2_buffer_trigger_type___5 {
	void (*t_frozen)(struct jbd2_buffer_trigger_type___5 *, struct buffer_head___8 *, void *, size_t);
	void (*t_abort)(struct jbd2_buffer_trigger_type___5 *, struct buffer_head___8 *);
};

struct crypto_alg___9;

struct crypto_tfm___9 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___9 *);
	struct crypto_alg___9 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___9 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___9 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___9 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___9 *, u8 *, const u8 *);
};

struct compress_alg___9 {
	int (*coa_compress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___9 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___9 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___9 cipher;
		struct compress_alg___9 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___9 *);
	void (*cra_exit)(struct crypto_tfm___9 *);
	void (*cra_destroy)(struct crypto_alg___9 *);
	struct module___124 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___8;

struct shash_desc___5 {
	struct crypto_shash___8 *tfm;
	void *__ctx[0];
};

struct crypto_shash___8 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___9 base;
};

struct jbd2_journal_handle___5;

typedef struct jbd2_journal_handle___5 handle_t___5;

struct jbd2_journal_handle___5 {
	union {
		transaction_t___5 *h_transaction;
		journal_t___5 *h_journal;
	};
	handle_t___5 *h_rsv_handle;
	int h_total_credits;
	int h_revoke_credits;
	int h_revoke_credits_requested;
	int h_ref;
	int h_err;
	unsigned int h_sync: 1;
	unsigned int h_jdata: 1;
	unsigned int h_reserved: 1;
	unsigned int h_aborted: 1;
	unsigned int h_type: 8;
	unsigned int h_line_no: 16;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int h_start_jiffies;
	unsigned int h_requested_credits;
	unsigned int saved_alloc_context;
};

struct jbd2_inode___5;

struct journal_s___5 {
	long unsigned int j_flags;
	long unsigned int j_atomic_flags;
	int j_errno;
	struct mutex j_abort_mutex;
	struct buffer_head___8 *j_sb_buffer;
	journal_superblock_t *j_superblock;
	int j_format_version;
	rwlock_t j_state_lock;
	int j_barrier_count;
	struct mutex j_barrier;
	transaction_t___5 *j_running_transaction;
	transaction_t___5 *j_committing_transaction;
	transaction_t___5 *j_checkpoint_transactions;
	wait_queue_head_t j_wait_transaction_locked;
	wait_queue_head_t j_wait_done_commit;
	wait_queue_head_t j_wait_commit;
	wait_queue_head_t j_wait_updates;
	wait_queue_head_t j_wait_reserved;
	wait_queue_head_t j_fc_wait;
	struct mutex j_checkpoint_mutex;
	struct buffer_head___8 *j_chkpt_bhs[64];
	struct shrinker___51 j_shrinker;
	struct percpu_counter j_checkpoint_jh_count;
	transaction_t___5 *j_shrink_transaction;
	long unsigned int j_head;
	long unsigned int j_tail;
	long unsigned int j_free;
	long unsigned int j_first;
	long unsigned int j_last;
	long unsigned int j_fc_first;
	long unsigned int j_fc_off;
	long unsigned int j_fc_last;
	struct block_device___63 *j_dev;
	int j_blocksize;
	long long unsigned int j_blk_offset;
	char j_devname[56];
	struct block_device___63 *j_fs_dev;
	unsigned int j_total_len;
	atomic_t j_reserved_credits;
	spinlock_t j_list_lock;
	struct inode___135 *j_inode;
	tid_t j_tail_sequence;
	tid_t j_transaction_sequence;
	tid_t j_commit_sequence;
	tid_t j_commit_request;
	__u8 j_uuid[16];
	struct task_struct___142 *j_task;
	int j_max_transaction_buffers;
	int j_revoke_records_per_block;
	long unsigned int j_commit_interval;
	struct timer_list j_commit_timer;
	spinlock_t j_revoke_lock;
	struct jbd2_revoke_table_s *j_revoke;
	struct jbd2_revoke_table_s *j_revoke_table[2];
	struct buffer_head___8 **j_wbuf;
	struct buffer_head___8 **j_fc_wbuf;
	int j_wbufsize;
	int j_fc_wbufsize;
	pid_t j_last_sync_writer;
	u64 j_average_commit_time;
	u32 j_min_batch_time;
	u32 j_max_batch_time;
	void (*j_commit_callback)(journal_t___5 *, transaction_t___5 *);
	int (*j_submit_inode_data_buffers)(struct jbd2_inode___5 *);
	int (*j_finish_inode_data_buffers)(struct jbd2_inode___5 *);
	spinlock_t j_history_lock;
	struct proc_dir_entry *j_proc_entry;
	struct transaction_stats_s j_stats;
	unsigned int j_failed_commit;
	void *j_private;
	struct crypto_shash___8 *j_chksum_driver;
	__u32 j_csum_seed;
	void (*j_fc_cleanup_callback)(struct journal_s___5 *, int, tid_t);
	int (*j_fc_replay_callback)(struct journal_s___5 *, struct buffer_head___8 *, enum passtype, int, tid_t);
};

struct jbd2_inode___5 {
	transaction_t___5 *i_transaction;
	transaction_t___5 *i_next_transaction;
	struct list_head i_list;
	struct inode___135 *i_vfs_inode;
	long unsigned int i_flags;
	loff_t i_dirty_start;
	loff_t i_dirty_end;
};

struct ext4_allocation_request___3 {
	struct inode___135 *inode;
	unsigned int len;
	ext4_lblk_t logical;
	ext4_lblk_t lleft;
	ext4_lblk_t lright;
	ext4_fsblk_t goal;
	ext4_fsblk_t pleft;
	ext4_fsblk_t pright;
	unsigned int flags;
};

enum {
	I_DATA_SEM_NORMAL = 0,
	I_DATA_SEM_OTHER = 1,
	I_DATA_SEM_QUOTA = 2,
};

struct ext4_inode_info___5 {
	__le32 i_data[15];
	__u32 i_dtime;
	ext4_fsblk_t i_file_acl;
	ext4_group_t i_block_group;
	ext4_lblk_t i_dir_start_lookup;
	long unsigned int i_flags;
	struct rw_semaphore xattr_sem;
	union {
		struct list_head i_orphan;
		unsigned int i_orphan_idx;
	};
	struct list_head i_fc_list;
	ext4_lblk_t i_fc_lblk_start;
	ext4_lblk_t i_fc_lblk_len;
	atomic_t i_fc_updates;
	wait_queue_head_t i_fc_wait;
	struct mutex i_fc_lock;
	loff_t i_disksize;
	struct rw_semaphore i_data_sem;
	struct inode___135 vfs_inode;
	struct jbd2_inode___5 *jinode;
	spinlock_t i_raw_lock;
	struct timespec64 i_crtime;
	atomic_t i_prealloc_active;
	struct list_head i_prealloc_list;
	spinlock_t i_prealloc_lock;
	struct ext4_es_tree i_es_tree;
	rwlock_t i_es_lock;
	struct list_head i_es_list;
	unsigned int i_es_all_nr;
	unsigned int i_es_shk_nr;
	ext4_lblk_t i_es_shrink_lblk;
	ext4_group_t i_last_alloc_group;
	unsigned int i_reserved_data_blocks;
	struct ext4_pending_tree i_pending_tree;
	__u16 i_extra_isize;
	u16 i_inline_off;
	u16 i_inline_size;
	qsize_t i_reserved_quota;
	spinlock_t i_completed_io_lock;
	struct list_head i_rsv_conversion_list;
	struct work_struct i_rsv_conversion_work;
	atomic_t i_unwritten;
	spinlock_t i_block_reservation_lock;
	tid_t i_sync_tid;
	tid_t i_datasync_tid;
	struct dquot___135 *i_dquot[3];
	__u32 i_csum_seed;
	kprojid_t i_projid;
};

struct ext4_journal_trigger___4 {
	struct jbd2_buffer_trigger_type___5 tr_triggers;
	struct super_block___135 *sb;
};

struct ext4_orphan_block___4 {
	atomic_t ob_free_entries;
	struct buffer_head___8 *ob_bh;
};

struct ext4_orphan_info___4 {
	int of_blocks;
	__u32 of_csum_seed;
	struct ext4_orphan_block___4 *of_binfo;
};

struct ext4_li_request___4;

struct ext4_sb_info___4 {
	long unsigned int s_desc_size;
	long unsigned int s_inodes_per_block;
	long unsigned int s_blocks_per_group;
	long unsigned int s_clusters_per_group;
	long unsigned int s_inodes_per_group;
	long unsigned int s_itb_per_group;
	long unsigned int s_gdb_count;
	long unsigned int s_desc_per_block;
	ext4_group_t s_groups_count;
	ext4_group_t s_blockfile_groups;
	long unsigned int s_overhead;
	unsigned int s_cluster_ratio;
	unsigned int s_cluster_bits;
	loff_t s_bitmap_maxbytes;
	struct buffer_head___8 *s_sbh;
	struct ext4_super_block *s_es;
	struct buffer_head___8 **s_group_desc;
	unsigned int s_mount_opt;
	unsigned int s_mount_opt2;
	long unsigned int s_mount_flags;
	unsigned int s_def_mount_opt;
	ext4_fsblk_t s_sb_block;
	atomic64_t s_resv_clusters;
	kuid_t s_resuid;
	kgid_t s_resgid;
	short unsigned int s_mount_state;
	short unsigned int s_pad;
	int s_addr_per_block_bits;
	int s_desc_per_block_bits;
	int s_inode_size;
	int s_first_ino;
	unsigned int s_inode_readahead_blks;
	unsigned int s_inode_goal;
	u32 s_hash_seed[4];
	int s_def_hash_version;
	int s_hash_unsigned;
	struct percpu_counter s_freeclusters_counter;
	struct percpu_counter s_freeinodes_counter;
	struct percpu_counter s_dirs_counter;
	struct percpu_counter s_dirtyclusters_counter;
	struct percpu_counter s_sra_exceeded_retry_limit;
	struct blockgroup_lock *s_blockgroup_lock;
	struct proc_dir_entry *s_proc;
	struct kobject___126 s_kobj;
	struct completion s_kobj_unregister;
	struct super_block___135 *s_sb;
	struct buffer_head___8 *s_mmp_bh;
	struct journal_s___5 *s_journal;
	long unsigned int s_ext4_flags;
	struct mutex s_orphan_lock;
	struct list_head s_orphan;
	struct ext4_orphan_info___4 s_orphan_info;
	long unsigned int s_commit_interval;
	u32 s_max_batch_time;
	u32 s_min_batch_time;
	struct block_device___63 *s_journal_bdev;
	char *s_qf_names[3];
	int s_jquota_fmt;
	unsigned int s_want_extra_isize;
	struct ext4_system_blocks *s_system_blks;
	struct ext4_group_info ***s_group_info;
	struct inode___135 *s_buddy_cache;
	spinlock_t s_md_lock;
	short unsigned int *s_mb_offsets;
	unsigned int *s_mb_maxs;
	unsigned int s_group_info_size;
	unsigned int s_mb_free_pending;
	struct list_head s_freed_data_list;
	struct list_head s_discard_list;
	struct work_struct s_discard_work;
	atomic_t s_retry_alloc_pending;
	struct rb_root s_mb_avg_fragment_size_root;
	rwlock_t s_mb_rb_lock;
	struct list_head *s_mb_largest_free_orders;
	rwlock_t *s_mb_largest_free_orders_locks;
	long unsigned int s_stripe;
	unsigned int s_mb_max_linear_groups;
	unsigned int s_mb_stream_request;
	unsigned int s_mb_max_to_scan;
	unsigned int s_mb_min_to_scan;
	unsigned int s_mb_stats;
	unsigned int s_mb_order2_reqs;
	unsigned int s_mb_group_prealloc;
	unsigned int s_mb_max_inode_prealloc;
	unsigned int s_max_dir_size_kb;
	long unsigned int s_mb_last_group;
	long unsigned int s_mb_last_start;
	unsigned int s_mb_prefetch;
	unsigned int s_mb_prefetch_limit;
	atomic_t s_bal_reqs;
	atomic_t s_bal_success;
	atomic_t s_bal_allocated;
	atomic_t s_bal_ex_scanned;
	atomic_t s_bal_groups_scanned;
	atomic_t s_bal_goals;
	atomic_t s_bal_breaks;
	atomic_t s_bal_2orders;
	atomic_t s_bal_cr0_bad_suggestions;
	atomic_t s_bal_cr1_bad_suggestions;
	atomic64_t s_bal_cX_groups_considered[4];
	atomic64_t s_bal_cX_hits[4];
	atomic64_t s_bal_cX_failed[4];
	atomic_t s_mb_buddies_generated;
	atomic64_t s_mb_generation_time;
	atomic_t s_mb_lost_chunks;
	atomic_t s_mb_preallocated;
	atomic_t s_mb_discarded;
	atomic_t s_lock_busy;
	struct ext4_locality_group *s_locality_groups;
	long unsigned int s_sectors_written_start;
	u64 s_kbytes_written;
	unsigned int s_extent_max_zeroout_kb;
	unsigned int s_log_groups_per_flex;
	struct flex_groups **s_flex_groups;
	ext4_group_t s_flex_groups_allocated;
	struct workqueue_struct *rsv_conversion_wq;
	struct timer_list s_err_report;
	struct ext4_li_request___4 *s_li_request;
	unsigned int s_li_wait_mult;
	struct task_struct___142 *s_mmp_tsk;
	atomic_t s_last_trim_minblks;
	struct crypto_shash___8 *s_chksum_driver;
	__u32 s_csum_seed;
	struct shrinker___51 s_es_shrinker;
	struct list_head s_es_list;
	long int s_es_nr_inode;
	struct ext4_es_stats s_es_stats;
	struct mb_cache___2 *s_ea_block_cache;
	struct mb_cache___2 *s_ea_inode_cache;
	long: 64;
	long: 64;
	spinlock_t s_es_lock;
	struct ext4_journal_trigger___4 s_journal_triggers[1];
	struct ratelimit_state s_err_ratelimit_state;
	struct ratelimit_state s_warning_ratelimit_state;
	struct ratelimit_state s_msg_ratelimit_state;
	atomic_t s_warning_count;
	atomic_t s_msg_count;
	struct fscrypt_dummy_policy s_dummy_enc_policy;
	struct percpu_rw_semaphore___136 s_writepages_rwsem;
	struct dax_device *s_daxdev;
	errseq_t s_bdev_wb_err;
	spinlock_t s_bdev_wb_lock;
	spinlock_t s_error_lock;
	int s_add_error_count;
	int s_first_error_code;
	__u32 s_first_error_line;
	__u32 s_first_error_ino;
	__u64 s_first_error_block;
	const char *s_first_error_func;
	time64_t s_first_error_time;
	int s_last_error_code;
	__u32 s_last_error_line;
	__u32 s_last_error_ino;
	__u64 s_last_error_block;
	const char *s_last_error_func;
	time64_t s_last_error_time;
	struct work_struct s_error_work;
	atomic_t s_fc_subtid;
	struct list_head s_fc_q[2];
	struct list_head s_fc_dentry_q[2];
	unsigned int s_fc_bytes;
	spinlock_t s_fc_lock;
	struct buffer_head___8 *s_fc_bh;
	struct ext4_fc_stats s_fc_stats;
	tid_t s_fc_ineligible_tid;
	struct ext4_fc_replay_state s_fc_replay_state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ext4_li_request___4 {
	struct super_block___135 *lr_super;
	enum ext4_li_mode lr_mode;
	ext4_group_t lr_first_not_zeroed;
	ext4_group_t lr_next_group;
	struct list_head lr_request;
	long unsigned int lr_next_sched;
	long unsigned int lr_timeout;
};

struct ext4_lazy_init {
	long unsigned int li_state;
	struct list_head li_request_list;
	struct mutex li_list_mtx;
};

struct ext4_journal_cb_entry {
	struct list_head jce_list;
	void (*jce_func)(struct super_block___135 *, struct ext4_journal_cb_entry *, int);
};

struct mem_cgroup_reclaim_iter___51 {
	struct mem_cgroup___51 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___51 {
	struct lruvec___58 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___51 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___51 *memcg;
};

struct obj_cgroup___51 {
	struct percpu_ref refcnt;
	struct mem_cgroup___51 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct ext4_prealloc_space___2 {
	struct list_head pa_inode_list;
	struct list_head pa_group_list;
	union {
		struct list_head pa_tmp_list;
		struct callback_head pa_rcu;
	} u;
	spinlock_t pa_lock;
	atomic_t pa_count;
	unsigned int pa_deleted;
	ext4_fsblk_t pa_pstart;
	ext4_lblk_t pa_lstart;
	ext4_grpblk_t pa_len;
	ext4_grpblk_t pa_free;
	short unsigned int pa_type;
	spinlock_t *pa_obj_lock;
	struct inode___135 *pa_inode;
};

struct ext4_allocation_context___2 {
	struct inode___135 *ac_inode;
	struct super_block___135 *ac_sb;
	struct ext4_free_extent ac_o_ex;
	struct ext4_free_extent ac_g_ex;
	struct ext4_free_extent ac_b_ex;
	struct ext4_free_extent ac_f_ex;
	ext4_group_t ac_last_optimal_group;
	__u32 ac_groups_considered;
	__u32 ac_flags;
	__u16 ac_groups_scanned;
	__u16 ac_groups_linear_remaining;
	__u16 ac_found;
	__u16 ac_tail;
	__u16 ac_buddy;
	__u8 ac_status;
	__u8 ac_criteria;
	__u8 ac_2order;
	__u8 ac_op;
	struct page___140 *ac_bitmap_page;
	struct page___140 *ac_buddy_page;
	struct ext4_prealloc_space___2 *ac_pa;
	struct ext4_locality_group *ac_lg;
};

struct perf_cpu_context___65;

struct perf_output_handle___65;

struct pmu___65 {
	struct list_head entry;
	struct module___124 *module;
	struct device___100 *dev;
	const struct attribute_group___126 **attr_groups;
	const struct attribute_group___126 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___65 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___65 *);
	void (*pmu_disable)(struct pmu___65 *);
	int (*event_init)(struct perf_event___65 *);
	void (*event_mapped)(struct perf_event___65 *, struct mm_struct___141 *);
	void (*event_unmapped)(struct perf_event___65 *, struct mm_struct___141 *);
	int (*add)(struct perf_event___65 *, int);
	void (*del)(struct perf_event___65 *, int);
	void (*start)(struct perf_event___65 *, int);
	void (*stop)(struct perf_event___65 *, int);
	void (*read)(struct perf_event___65 *);
	void (*start_txn)(struct pmu___65 *, unsigned int);
	int (*commit_txn)(struct pmu___65 *);
	void (*cancel_txn)(struct pmu___65 *);
	int (*event_idx)(struct perf_event___65 *);
	void (*sched_task)(struct perf_event_context___65 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___65 *, struct perf_event_context___65 *);
	void * (*setup_aux)(struct perf_event___65 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___65 *, struct perf_output_handle___65 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___65 *);
	int (*aux_output_match)(struct perf_event___65 *);
	int (*filter_match)(struct perf_event___65 *);
	int (*check_period)(struct perf_event___65 *, u64);
};

struct perf_cpu_context___65 {
	struct perf_event_context___65 ctx;
	struct perf_event_context___65 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___65 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___65 **heap;
	struct perf_event___65 *heap_default[2];
};

struct perf_output_handle___65 {
	struct perf_event___65 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___65 {
	struct cgroup_subsys_state___96 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___59 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___59 *);
	};
};

struct trace_event_class___59 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___59 *, enum trace_reg, void *);
	struct trace_event_fields___59 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___59 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___59 *);
};

struct trace_event_file___26;

struct trace_event_buffer___25 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___26 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___26 {
	struct list_head list;
	struct trace_event_call___59 *event_call;
	struct event_filter *filter;
	struct dentry___135 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_ext4_other_inode_update_time {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ino_t orig_ino;
	uid_t uid;
	gid_t gid;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_free_inode {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	uid_t uid;
	gid_t gid;
	__u64 blocks;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_request_inode {
	struct trace_entry ent;
	dev_t dev;
	ino_t dir;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_allocate_inode {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ino_t dir;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_evict_inode {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int nlink;
	char __data[0];
};

struct trace_event_raw_ext4_drop_inode {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int drop;
	char __data[0];
};

struct trace_event_raw_ext4_nfs_commit_metadata {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	char __data[0];
};

struct trace_event_raw_ext4_mark_inode_dirty {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	long unsigned int ip;
	char __data[0];
};

struct trace_event_raw_ext4_begin_ordered_truncate {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t new_size;
	char __data[0];
};

struct trace_event_raw_ext4__write_begin {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t pos;
	unsigned int len;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ext4__write_end {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t pos;
	unsigned int len;
	unsigned int copied;
	char __data[0];
};

struct trace_event_raw_ext4_writepages {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	long unsigned int writeback_index;
	int sync_mode;
	char for_kupdate;
	char range_cyclic;
	char __data[0];
};

struct trace_event_raw_ext4_da_write_pages {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	long unsigned int first_page;
	long int nr_to_write;
	int sync_mode;
	char __data[0];
};

struct trace_event_raw_ext4_da_write_pages_extent {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 lblk;
	__u32 len;
	__u32 flags;
	char __data[0];
};

struct trace_event_raw_ext4_writepages_result {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int ret;
	int pages_written;
	long int pages_skipped;
	long unsigned int writeback_index;
	int sync_mode;
	char __data[0];
};

struct trace_event_raw_ext4__page_op {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	long unsigned int index;
	char __data[0];
};

struct trace_event_raw_ext4_invalidatepage_op {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	long unsigned int index;
	unsigned int offset;
	unsigned int length;
	char __data[0];
};

struct trace_event_raw_ext4_discard_blocks {
	struct trace_entry ent;
	dev_t dev;
	__u64 blk;
	__u64 count;
	char __data[0];
};

struct trace_event_raw_ext4__mb_new_pa {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 pa_pstart;
	__u64 pa_lstart;
	__u32 pa_len;
	char __data[0];
};

struct trace_event_raw_ext4_mb_release_inode_pa {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 block;
	__u32 count;
	char __data[0];
};

struct trace_event_raw_ext4_mb_release_group_pa {
	struct trace_entry ent;
	dev_t dev;
	__u64 pa_pstart;
	__u32 pa_len;
	char __data[0];
};

struct trace_event_raw_ext4_discard_preallocations {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	unsigned int len;
	unsigned int needed;
	char __data[0];
};

struct trace_event_raw_ext4_mb_discard_preallocations {
	struct trace_entry ent;
	dev_t dev;
	int needed;
	char __data[0];
};

struct trace_event_raw_ext4_request_blocks {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	unsigned int len;
	__u32 logical;
	__u32 lleft;
	__u32 lright;
	__u64 goal;
	__u64 pleft;
	__u64 pright;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ext4_allocate_blocks {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 block;
	unsigned int len;
	__u32 logical;
	__u32 lleft;
	__u32 lright;
	__u64 goal;
	__u64 pleft;
	__u64 pright;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ext4_free_blocks {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 block;
	long unsigned int count;
	int flags;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_sync_file_enter {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ino_t parent;
	int datasync;
	char __data[0];
};

struct trace_event_raw_ext4_sync_file_exit {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int ret;
	char __data[0];
};

struct trace_event_raw_ext4_sync_fs {
	struct trace_entry ent;
	dev_t dev;
	int wait;
	char __data[0];
};

struct trace_event_raw_ext4_alloc_da_blocks {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	unsigned int data_blocks;
	char __data[0];
};

struct trace_event_raw_ext4_mballoc_alloc {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u32 orig_logical;
	int orig_start;
	__u32 orig_group;
	int orig_len;
	__u32 goal_logical;
	int goal_start;
	__u32 goal_group;
	int goal_len;
	__u32 result_logical;
	int result_start;
	__u32 result_group;
	int result_len;
	__u16 found;
	__u16 groups;
	__u16 buddy;
	__u16 flags;
	__u16 tail;
	__u8 cr;
	char __data[0];
};

struct trace_event_raw_ext4_mballoc_prealloc {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u32 orig_logical;
	int orig_start;
	__u32 orig_group;
	int orig_len;
	__u32 result_logical;
	int result_start;
	__u32 result_group;
	int result_len;
	char __data[0];
};

struct trace_event_raw_ext4__mballoc {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int result_start;
	__u32 result_group;
	int result_len;
	char __data[0];
};

struct trace_event_raw_ext4_forget {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 block;
	int is_metadata;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_da_update_reserve_space {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 i_blocks;
	int used_blocks;
	int reserved_data_blocks;
	int quota_claim;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_da_reserve_space {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 i_blocks;
	int reserved_data_blocks;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4_da_release_space {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 i_blocks;
	int freed_blocks;
	int reserved_data_blocks;
	__u16 mode;
	char __data[0];
};

struct trace_event_raw_ext4__bitmap_load {
	struct trace_entry ent;
	dev_t dev;
	__u32 group;
	char __data[0];
};

struct trace_event_raw_ext4_read_block_bitmap_load {
	struct trace_entry ent;
	dev_t dev;
	__u32 group;
	bool prefetch;
	char __data[0];
};

struct trace_event_raw_ext4__fallocate_mode {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t offset;
	loff_t len;
	int mode;
	char __data[0];
};

struct trace_event_raw_ext4_fallocate_exit {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t pos;
	unsigned int blocks;
	int ret;
	char __data[0];
};

struct trace_event_raw_ext4_unlink_enter {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ino_t parent;
	loff_t size;
	char __data[0];
};

struct trace_event_raw_ext4_unlink_exit {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int ret;
	char __data[0];
};

struct trace_event_raw_ext4__truncate {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	__u64 blocks;
	char __data[0];
};

struct trace_event_raw_ext4_ext_convert_to_initialized_enter {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t m_lblk;
	unsigned int m_len;
	ext4_lblk_t u_lblk;
	unsigned int u_len;
	ext4_fsblk_t u_pblk;
	char __data[0];
};

struct trace_event_raw_ext4_ext_convert_to_initialized_fastpath {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t m_lblk;
	unsigned int m_len;
	ext4_lblk_t u_lblk;
	unsigned int u_len;
	ext4_fsblk_t u_pblk;
	ext4_lblk_t i_lblk;
	unsigned int i_len;
	ext4_fsblk_t i_pblk;
	char __data[0];
};

struct trace_event_raw_ext4__map_blocks_enter {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	unsigned int len;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ext4__map_blocks_exit {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	unsigned int flags;
	ext4_fsblk_t pblk;
	ext4_lblk_t lblk;
	unsigned int len;
	unsigned int mflags;
	int ret;
	char __data[0];
};

struct trace_event_raw_ext4_ext_load_extent {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_fsblk_t pblk;
	ext4_lblk_t lblk;
	char __data[0];
};

struct trace_event_raw_ext4_load_inode {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	char __data[0];
};

struct trace_event_raw_ext4_journal_start {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int ip;
	int blocks;
	int rsv_blocks;
	int revoke_creds;
	char __data[0];
};

struct trace_event_raw_ext4_journal_start_reserved {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int ip;
	int blocks;
	char __data[0];
};

struct trace_event_raw_ext4__trim {
	struct trace_entry ent;
	int dev_major;
	int dev_minor;
	__u32 group;
	int start;
	int len;
	char __data[0];
};

struct trace_event_raw_ext4_ext_handle_unwritten_extents {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	int flags;
	ext4_lblk_t lblk;
	ext4_fsblk_t pblk;
	unsigned int len;
	unsigned int allocated;
	ext4_fsblk_t newblk;
	char __data[0];
};

struct trace_event_raw_ext4_get_implied_cluster_alloc_exit {
	struct trace_entry ent;
	dev_t dev;
	unsigned int flags;
	ext4_lblk_t lblk;
	ext4_fsblk_t pblk;
	unsigned int len;
	int ret;
	char __data[0];
};

struct trace_event_raw_ext4_ext_show_extent {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_fsblk_t pblk;
	ext4_lblk_t lblk;
	short unsigned int len;
	char __data[0];
};

struct trace_event_raw_ext4_remove_blocks {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t from;
	ext4_lblk_t to;
	ext4_fsblk_t ee_pblk;
	ext4_lblk_t ee_lblk;
	short unsigned int ee_len;
	ext4_fsblk_t pc_pclu;
	ext4_lblk_t pc_lblk;
	int pc_state;
	char __data[0];
};

struct trace_event_raw_ext4_ext_rm_leaf {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t start;
	ext4_lblk_t ee_lblk;
	ext4_fsblk_t ee_pblk;
	short int ee_len;
	ext4_fsblk_t pc_pclu;
	ext4_lblk_t pc_lblk;
	int pc_state;
	char __data[0];
};

struct trace_event_raw_ext4_ext_rm_idx {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_fsblk_t pblk;
	char __data[0];
};

struct trace_event_raw_ext4_ext_remove_space {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t start;
	ext4_lblk_t end;
	int depth;
	char __data[0];
};

struct trace_event_raw_ext4_ext_remove_space_done {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t start;
	ext4_lblk_t end;
	int depth;
	ext4_fsblk_t pc_pclu;
	ext4_lblk_t pc_lblk;
	int pc_state;
	short unsigned int eh_entries;
	char __data[0];
};

struct trace_event_raw_ext4__es_extent {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	ext4_lblk_t len;
	ext4_fsblk_t pblk;
	char status;
	char __data[0];
};

struct trace_event_raw_ext4_es_remove_extent {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t lblk;
	loff_t len;
	char __data[0];
};

struct trace_event_raw_ext4_es_find_extent_range_enter {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	char __data[0];
};

struct trace_event_raw_ext4_es_find_extent_range_exit {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	ext4_lblk_t len;
	ext4_fsblk_t pblk;
	char status;
	char __data[0];
};

struct trace_event_raw_ext4_es_lookup_extent_enter {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	char __data[0];
};

struct trace_event_raw_ext4_es_lookup_extent_exit {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	ext4_lblk_t len;
	ext4_fsblk_t pblk;
	char status;
	int found;
	char __data[0];
};

struct trace_event_raw_ext4__es_shrink_enter {
	struct trace_entry ent;
	dev_t dev;
	int nr_to_scan;
	int cache_cnt;
	char __data[0];
};

struct trace_event_raw_ext4_es_shrink_scan_exit {
	struct trace_entry ent;
	dev_t dev;
	int nr_shrunk;
	int cache_cnt;
	char __data[0];
};

struct trace_event_raw_ext4_collapse_range {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t offset;
	loff_t len;
	char __data[0];
};

struct trace_event_raw_ext4_insert_range {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	loff_t offset;
	loff_t len;
	char __data[0];
};

struct trace_event_raw_ext4_es_shrink {
	struct trace_entry ent;
	dev_t dev;
	int nr_shrunk;
	long long unsigned int scan_time;
	int nr_skipped;
	int retried;
	char __data[0];
};

struct trace_event_raw_ext4_es_insert_delayed_block {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	ext4_lblk_t lblk;
	ext4_lblk_t len;
	ext4_fsblk_t pblk;
	char status;
	bool allocated;
	char __data[0];
};

struct trace_event_raw_ext4_fsmap_class {
	struct trace_entry ent;
	dev_t dev;
	dev_t keydev;
	u32 agno;
	u64 bno;
	u64 len;
	u64 owner;
	char __data[0];
};

struct trace_event_raw_ext4_getfsmap_class {
	struct trace_entry ent;
	dev_t dev;
	dev_t keydev;
	u64 block;
	u64 len;
	u64 owner;
	u64 flags;
	char __data[0];
};

struct trace_event_raw_ext4_shutdown {
	struct trace_entry ent;
	dev_t dev;
	unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ext4_error {
	struct trace_entry ent;
	dev_t dev;
	const char *function;
	unsigned int line;
	char __data[0];
};

struct trace_event_raw_ext4_prefetch_bitmaps {
	struct trace_entry ent;
	dev_t dev;
	__u32 group;
	__u32 next;
	__u32 ios;
	char __data[0];
};

struct trace_event_raw_ext4_lazy_itable_init {
	struct trace_entry ent;
	dev_t dev;
	__u32 group;
	char __data[0];
};

struct trace_event_raw_ext4_fc_replay_scan {
	struct trace_entry ent;
	dev_t dev;
	int error;
	int off;
	char __data[0];
};

struct trace_event_raw_ext4_fc_replay {
	struct trace_entry ent;
	dev_t dev;
	int tag;
	int ino;
	int priv1;
	int priv2;
	char __data[0];
};

struct trace_event_raw_ext4_fc_commit_start {
	struct trace_entry ent;
	dev_t dev;
	char __data[0];
};

struct trace_event_raw_ext4_fc_commit_stop {
	struct trace_entry ent;
	dev_t dev;
	int nblks;
	int reason;
	int num_fc;
	int num_fc_ineligible;
	int nblks_agg;
	char __data[0];
};

struct trace_event_raw_ext4_fc_stats {
	struct trace_entry ent;
	dev_t dev;
	unsigned int fc_ineligible_rc[10];
	long unsigned int fc_commits;
	long unsigned int fc_ineligible_commits;
	long unsigned int fc_numblks;
	char __data[0];
};

struct trace_event_raw_ext4_fc_track_create {
	struct trace_entry ent;
	dev_t dev;
	int ino;
	int error;
	char __data[0];
};

struct trace_event_raw_ext4_fc_track_link {
	struct trace_entry ent;
	dev_t dev;
	int ino;
	int error;
	char __data[0];
};

struct trace_event_raw_ext4_fc_track_unlink {
	struct trace_entry ent;
	dev_t dev;
	int ino;
	int error;
	char __data[0];
};

struct trace_event_raw_ext4_fc_track_inode {
	struct trace_entry ent;
	dev_t dev;
	int ino;
	int error;
	char __data[0];
};

struct trace_event_raw_ext4_fc_track_range {
	struct trace_entry ent;
	dev_t dev;
	int ino;
	long int start;
	long int end;
	int error;
	char __data[0];
};

struct trace_event_data_offsets_ext4_other_inode_update_time {};

struct trace_event_data_offsets_ext4_free_inode {};

struct trace_event_data_offsets_ext4_request_inode {};

struct trace_event_data_offsets_ext4_allocate_inode {};

struct trace_event_data_offsets_ext4_evict_inode {};

struct trace_event_data_offsets_ext4_drop_inode {};

struct trace_event_data_offsets_ext4_nfs_commit_metadata {};

struct trace_event_data_offsets_ext4_mark_inode_dirty {};

struct trace_event_data_offsets_ext4_begin_ordered_truncate {};

struct trace_event_data_offsets_ext4__write_begin {};

struct trace_event_data_offsets_ext4__write_end {};

struct trace_event_data_offsets_ext4_writepages {};

struct trace_event_data_offsets_ext4_da_write_pages {};

struct trace_event_data_offsets_ext4_da_write_pages_extent {};

struct trace_event_data_offsets_ext4_writepages_result {};

struct trace_event_data_offsets_ext4__page_op {};

struct trace_event_data_offsets_ext4_invalidatepage_op {};

struct trace_event_data_offsets_ext4_discard_blocks {};

struct trace_event_data_offsets_ext4__mb_new_pa {};

struct trace_event_data_offsets_ext4_mb_release_inode_pa {};

struct trace_event_data_offsets_ext4_mb_release_group_pa {};

struct trace_event_data_offsets_ext4_discard_preallocations {};

struct trace_event_data_offsets_ext4_mb_discard_preallocations {};

struct trace_event_data_offsets_ext4_request_blocks {};

struct trace_event_data_offsets_ext4_allocate_blocks {};

struct trace_event_data_offsets_ext4_free_blocks {};

struct trace_event_data_offsets_ext4_sync_file_enter {};

struct trace_event_data_offsets_ext4_sync_file_exit {};

struct trace_event_data_offsets_ext4_sync_fs {};

struct trace_event_data_offsets_ext4_alloc_da_blocks {};

struct trace_event_data_offsets_ext4_mballoc_alloc {};

struct trace_event_data_offsets_ext4_mballoc_prealloc {};

struct trace_event_data_offsets_ext4__mballoc {};

struct trace_event_data_offsets_ext4_forget {};

struct trace_event_data_offsets_ext4_da_update_reserve_space {};

struct trace_event_data_offsets_ext4_da_reserve_space {};

struct trace_event_data_offsets_ext4_da_release_space {};

struct trace_event_data_offsets_ext4__bitmap_load {};

struct trace_event_data_offsets_ext4_read_block_bitmap_load {};

struct trace_event_data_offsets_ext4__fallocate_mode {};

struct trace_event_data_offsets_ext4_fallocate_exit {};

struct trace_event_data_offsets_ext4_unlink_enter {};

struct trace_event_data_offsets_ext4_unlink_exit {};

struct trace_event_data_offsets_ext4__truncate {};

struct trace_event_data_offsets_ext4_ext_convert_to_initialized_enter {};

struct trace_event_data_offsets_ext4_ext_convert_to_initialized_fastpath {};

struct trace_event_data_offsets_ext4__map_blocks_enter {};

struct trace_event_data_offsets_ext4__map_blocks_exit {};

struct trace_event_data_offsets_ext4_ext_load_extent {};

struct trace_event_data_offsets_ext4_load_inode {};

struct trace_event_data_offsets_ext4_journal_start {};

struct trace_event_data_offsets_ext4_journal_start_reserved {};

struct trace_event_data_offsets_ext4__trim {};

struct trace_event_data_offsets_ext4_ext_handle_unwritten_extents {};

struct trace_event_data_offsets_ext4_get_implied_cluster_alloc_exit {};

struct trace_event_data_offsets_ext4_ext_show_extent {};

struct trace_event_data_offsets_ext4_remove_blocks {};

struct trace_event_data_offsets_ext4_ext_rm_leaf {};

struct trace_event_data_offsets_ext4_ext_rm_idx {};

struct trace_event_data_offsets_ext4_ext_remove_space {};

struct trace_event_data_offsets_ext4_ext_remove_space_done {};

struct trace_event_data_offsets_ext4__es_extent {};

struct trace_event_data_offsets_ext4_es_remove_extent {};

struct trace_event_data_offsets_ext4_es_find_extent_range_enter {};

struct trace_event_data_offsets_ext4_es_find_extent_range_exit {};

struct trace_event_data_offsets_ext4_es_lookup_extent_enter {};

struct trace_event_data_offsets_ext4_es_lookup_extent_exit {};

struct trace_event_data_offsets_ext4__es_shrink_enter {};

struct trace_event_data_offsets_ext4_es_shrink_scan_exit {};

struct trace_event_data_offsets_ext4_collapse_range {};

struct trace_event_data_offsets_ext4_insert_range {};

struct trace_event_data_offsets_ext4_es_shrink {};

struct trace_event_data_offsets_ext4_es_insert_delayed_block {};

struct trace_event_data_offsets_ext4_fsmap_class {};

struct trace_event_data_offsets_ext4_getfsmap_class {};

struct trace_event_data_offsets_ext4_shutdown {};

struct trace_event_data_offsets_ext4_error {};

struct trace_event_data_offsets_ext4_prefetch_bitmaps {};

struct trace_event_data_offsets_ext4_lazy_itable_init {};

struct trace_event_data_offsets_ext4_fc_replay_scan {};

struct trace_event_data_offsets_ext4_fc_replay {};

struct trace_event_data_offsets_ext4_fc_commit_start {};

struct trace_event_data_offsets_ext4_fc_commit_stop {};

struct trace_event_data_offsets_ext4_fc_stats {};

struct trace_event_data_offsets_ext4_fc_track_create {};

struct trace_event_data_offsets_ext4_fc_track_link {};

struct trace_event_data_offsets_ext4_fc_track_unlink {};

struct trace_event_data_offsets_ext4_fc_track_inode {};

struct trace_event_data_offsets_ext4_fc_track_range {};

typedef void (*btf_trace_ext4_other_inode_update_time)(void *, struct inode___135 *, ino_t);

typedef void (*btf_trace_ext4_free_inode)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_request_inode)(void *, struct inode___135 *, int);

typedef void (*btf_trace_ext4_allocate_inode)(void *, struct inode___135 *, struct inode___135 *, int);

typedef void (*btf_trace_ext4_evict_inode)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_drop_inode)(void *, struct inode___135 *, int);

typedef void (*btf_trace_ext4_nfs_commit_metadata)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_mark_inode_dirty)(void *, struct inode___135 *, long unsigned int);

typedef void (*btf_trace_ext4_begin_ordered_truncate)(void *, struct inode___135 *, loff_t);

typedef void (*btf_trace_ext4_write_begin)(void *, struct inode___135 *, loff_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_da_write_begin)(void *, struct inode___135 *, loff_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_write_end)(void *, struct inode___135 *, loff_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_journalled_write_end)(void *, struct inode___135 *, loff_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_da_write_end)(void *, struct inode___135 *, loff_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_writepages)(void *, struct inode___135 *, struct writeback_control___59 *);

typedef void (*btf_trace_ext4_da_write_pages)(void *, struct inode___135 *, long unsigned int, struct writeback_control___59 *);

typedef void (*btf_trace_ext4_da_write_pages_extent)(void *, struct inode___135 *, struct ext4_map_blocks *);

typedef void (*btf_trace_ext4_writepages_result)(void *, struct inode___135 *, struct writeback_control___59 *, int, int);

typedef void (*btf_trace_ext4_writepage)(void *, struct page___140 *);

typedef void (*btf_trace_ext4_readpage)(void *, struct page___140 *);

typedef void (*btf_trace_ext4_releasepage)(void *, struct page___140 *);

typedef void (*btf_trace_ext4_invalidatepage)(void *, struct page___140 *, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_journalled_invalidatepage)(void *, struct page___140 *, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_discard_blocks)(void *, struct super_block___135 *, long long unsigned int, long long unsigned int);

typedef void (*btf_trace_ext4_mb_new_inode_pa)(void *, struct ext4_allocation_context___2 *, struct ext4_prealloc_space___2 *);

typedef void (*btf_trace_ext4_mb_new_group_pa)(void *, struct ext4_allocation_context___2 *, struct ext4_prealloc_space___2 *);

typedef void (*btf_trace_ext4_mb_release_inode_pa)(void *, struct ext4_prealloc_space___2 *, long long unsigned int, unsigned int);

typedef void (*btf_trace_ext4_mb_release_group_pa)(void *, struct super_block___135 *, struct ext4_prealloc_space___2 *);

typedef void (*btf_trace_ext4_discard_preallocations)(void *, struct inode___135 *, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_mb_discard_preallocations)(void *, struct super_block___135 *, int);

typedef void (*btf_trace_ext4_request_blocks)(void *, struct ext4_allocation_request___3 *);

typedef void (*btf_trace_ext4_allocate_blocks)(void *, struct ext4_allocation_request___3 *, long long unsigned int);

typedef void (*btf_trace_ext4_free_blocks)(void *, struct inode___135 *, __u64, long unsigned int, int);

typedef void (*btf_trace_ext4_sync_file_enter)(void *, struct file___135 *, int);

typedef void (*btf_trace_ext4_sync_file_exit)(void *, struct inode___135 *, int);

typedef void (*btf_trace_ext4_sync_fs)(void *, struct super_block___135 *, int);

typedef void (*btf_trace_ext4_alloc_da_blocks)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_mballoc_alloc)(void *, struct ext4_allocation_context___2 *);

typedef void (*btf_trace_ext4_mballoc_prealloc)(void *, struct ext4_allocation_context___2 *);

typedef void (*btf_trace_ext4_mballoc_discard)(void *, struct super_block___135 *, struct inode___135 *, ext4_group_t, ext4_grpblk_t, ext4_grpblk_t);

typedef void (*btf_trace_ext4_mballoc_free)(void *, struct super_block___135 *, struct inode___135 *, ext4_group_t, ext4_grpblk_t, ext4_grpblk_t);

typedef void (*btf_trace_ext4_forget)(void *, struct inode___135 *, int, __u64);

typedef void (*btf_trace_ext4_da_update_reserve_space)(void *, struct inode___135 *, int, int);

typedef void (*btf_trace_ext4_da_reserve_space)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_da_release_space)(void *, struct inode___135 *, int);

typedef void (*btf_trace_ext4_mb_bitmap_load)(void *, struct super_block___135 *, long unsigned int);

typedef void (*btf_trace_ext4_mb_buddy_bitmap_load)(void *, struct super_block___135 *, long unsigned int);

typedef void (*btf_trace_ext4_load_inode_bitmap)(void *, struct super_block___135 *, long unsigned int);

typedef void (*btf_trace_ext4_read_block_bitmap_load)(void *, struct super_block___135 *, long unsigned int, bool);

typedef void (*btf_trace_ext4_fallocate_enter)(void *, struct inode___135 *, loff_t, loff_t, int);

typedef void (*btf_trace_ext4_punch_hole)(void *, struct inode___135 *, loff_t, loff_t, int);

typedef void (*btf_trace_ext4_zero_range)(void *, struct inode___135 *, loff_t, loff_t, int);

typedef void (*btf_trace_ext4_fallocate_exit)(void *, struct inode___135 *, loff_t, unsigned int, int);

typedef void (*btf_trace_ext4_unlink_enter)(void *, struct inode___135 *, struct dentry___135 *);

typedef void (*btf_trace_ext4_unlink_exit)(void *, struct dentry___135 *, int);

typedef void (*btf_trace_ext4_truncate_enter)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_truncate_exit)(void *, struct inode___135 *);

typedef void (*btf_trace_ext4_ext_convert_to_initialized_enter)(void *, struct inode___135 *, struct ext4_map_blocks *, struct ext4_extent *);

typedef void (*btf_trace_ext4_ext_convert_to_initialized_fastpath)(void *, struct inode___135 *, struct ext4_map_blocks *, struct ext4_extent *, struct ext4_extent *);

typedef void (*btf_trace_ext4_ext_map_blocks_enter)(void *, struct inode___135 *, ext4_lblk_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_ind_map_blocks_enter)(void *, struct inode___135 *, ext4_lblk_t, unsigned int, unsigned int);

typedef void (*btf_trace_ext4_ext_map_blocks_exit)(void *, struct inode___135 *, unsigned int, struct ext4_map_blocks *, int);

typedef void (*btf_trace_ext4_ind_map_blocks_exit)(void *, struct inode___135 *, unsigned int, struct ext4_map_blocks *, int);

typedef void (*btf_trace_ext4_ext_load_extent)(void *, struct inode___135 *, ext4_lblk_t, ext4_fsblk_t);

typedef void (*btf_trace_ext4_load_inode)(void *, struct super_block___135 *, long unsigned int);

typedef void (*btf_trace_ext4_journal_start)(void *, struct super_block___135 *, int, int, int, long unsigned int);

typedef void (*btf_trace_ext4_journal_start_reserved)(void *, struct super_block___135 *, int, long unsigned int);

typedef void (*btf_trace_ext4_trim_extent)(void *, struct super_block___135 *, ext4_group_t, ext4_grpblk_t, ext4_grpblk_t);

typedef void (*btf_trace_ext4_trim_all_free)(void *, struct super_block___135 *, ext4_group_t, ext4_grpblk_t, ext4_grpblk_t);

typedef void (*btf_trace_ext4_ext_handle_unwritten_extents)(void *, struct inode___135 *, struct ext4_map_blocks *, int, unsigned int, ext4_fsblk_t);

typedef void (*btf_trace_ext4_get_implied_cluster_alloc_exit)(void *, struct super_block___135 *, struct ext4_map_blocks *, int);

typedef void (*btf_trace_ext4_ext_show_extent)(void *, struct inode___135 *, ext4_lblk_t, ext4_fsblk_t, short unsigned int);

typedef void (*btf_trace_ext4_remove_blocks)(void *, struct inode___135 *, struct ext4_extent *, ext4_lblk_t, ext4_fsblk_t, struct partial_cluster *);

typedef void (*btf_trace_ext4_ext_rm_leaf)(void *, struct inode___135 *, ext4_lblk_t, struct ext4_extent *, struct partial_cluster *);

typedef void (*btf_trace_ext4_ext_rm_idx)(void *, struct inode___135 *, ext4_fsblk_t);

typedef void (*btf_trace_ext4_ext_remove_space)(void *, struct inode___135 *, ext4_lblk_t, ext4_lblk_t, int);

typedef void (*btf_trace_ext4_ext_remove_space_done)(void *, struct inode___135 *, ext4_lblk_t, ext4_lblk_t, int, struct partial_cluster *, __le16);

typedef void (*btf_trace_ext4_es_insert_extent)(void *, struct inode___135 *, struct extent_status *);

typedef void (*btf_trace_ext4_es_cache_extent)(void *, struct inode___135 *, struct extent_status *);

typedef void (*btf_trace_ext4_es_remove_extent)(void *, struct inode___135 *, ext4_lblk_t, ext4_lblk_t);

typedef void (*btf_trace_ext4_es_find_extent_range_enter)(void *, struct inode___135 *, ext4_lblk_t);

typedef void (*btf_trace_ext4_es_find_extent_range_exit)(void *, struct inode___135 *, struct extent_status *);

typedef void (*btf_trace_ext4_es_lookup_extent_enter)(void *, struct inode___135 *, ext4_lblk_t);

typedef void (*btf_trace_ext4_es_lookup_extent_exit)(void *, struct inode___135 *, struct extent_status *, int);

typedef void (*btf_trace_ext4_es_shrink_count)(void *, struct super_block___135 *, int, int);

typedef void (*btf_trace_ext4_es_shrink_scan_enter)(void *, struct super_block___135 *, int, int);

typedef void (*btf_trace_ext4_es_shrink_scan_exit)(void *, struct super_block___135 *, int, int);

typedef void (*btf_trace_ext4_collapse_range)(void *, struct inode___135 *, loff_t, loff_t);

typedef void (*btf_trace_ext4_insert_range)(void *, struct inode___135 *, loff_t, loff_t);

typedef void (*btf_trace_ext4_es_shrink)(void *, struct super_block___135 *, int, u64, int, int);

typedef void (*btf_trace_ext4_es_insert_delayed_block)(void *, struct inode___135 *, struct extent_status *, bool);

typedef void (*btf_trace_ext4_fsmap_low_key)(void *, struct super_block___135 *, u32, u32, u64, u64, u64);

typedef void (*btf_trace_ext4_fsmap_high_key)(void *, struct super_block___135 *, u32, u32, u64, u64, u64);

typedef void (*btf_trace_ext4_fsmap_mapping)(void *, struct super_block___135 *, u32, u32, u64, u64, u64);

typedef void (*btf_trace_ext4_getfsmap_low_key)(void *, struct super_block___135 *, struct ext4_fsmap *);

typedef void (*btf_trace_ext4_getfsmap_high_key)(void *, struct super_block___135 *, struct ext4_fsmap *);

typedef void (*btf_trace_ext4_getfsmap_mapping)(void *, struct super_block___135 *, struct ext4_fsmap *);

typedef void (*btf_trace_ext4_shutdown)(void *, struct super_block___135 *, long unsigned int);

typedef void (*btf_trace_ext4_error)(void *, struct super_block___135 *, const char *, unsigned int);

typedef void (*btf_trace_ext4_prefetch_bitmaps)(void *, struct super_block___135 *, ext4_group_t, ext4_group_t, unsigned int);

typedef void (*btf_trace_ext4_lazy_itable_init)(void *, struct super_block___135 *, ext4_group_t);

typedef void (*btf_trace_ext4_fc_replay_scan)(void *, struct super_block___135 *, int, int);

typedef void (*btf_trace_ext4_fc_replay)(void *, struct super_block___135 *, int, int, int, int);

typedef void (*btf_trace_ext4_fc_commit_start)(void *, struct super_block___135 *);

typedef void (*btf_trace_ext4_fc_commit_stop)(void *, struct super_block___135 *, int, int);

typedef void (*btf_trace_ext4_fc_stats)(void *, struct super_block___135 *);

typedef void (*btf_trace_ext4_fc_track_create)(void *, struct inode___135 *, struct dentry___135 *, int);

typedef void (*btf_trace_ext4_fc_track_link)(void *, struct inode___135 *, struct dentry___135 *, int);

typedef void (*btf_trace_ext4_fc_track_unlink)(void *, struct inode___135 *, struct dentry___135 *, int);

typedef void (*btf_trace_ext4_fc_track_inode)(void *, struct inode___135 *, int);

typedef void (*btf_trace_ext4_fc_track_range)(void *, struct inode___135 *, long int, long int, int);

struct ext4_err_translation {
	int code;
	int errno;
};

enum {
	Opt_bsd_df = 0,
	Opt_minix_df = 1,
	Opt_grpid = 2,
	Opt_nogrpid = 3,
	Opt_resgid = 4,
	Opt_resuid = 5,
	Opt_sb = 6,
	Opt_err_cont = 7,
	Opt_err_panic = 8,
	Opt_err_ro = 9,
	Opt_nouid32 = 10,
	Opt_debug = 11,
	Opt_removed = 12,
	Opt_user_xattr = 13,
	Opt_nouser_xattr = 14,
	Opt_acl = 15,
	Opt_noacl = 16,
	Opt_auto_da_alloc = 17,
	Opt_noauto_da_alloc = 18,
	Opt_noload = 19,
	Opt_commit = 20,
	Opt_min_batch_time = 21,
	Opt_max_batch_time = 22,
	Opt_journal_dev = 23,
	Opt_journal_path = 24,
	Opt_journal_checksum = 25,
	Opt_journal_async_commit = 26,
	Opt_abort = 27,
	Opt_data_journal = 28,
	Opt_data_ordered = 29,
	Opt_data_writeback = 30,
	Opt_data_err_abort = 31,
	Opt_data_err_ignore = 32,
	Opt_test_dummy_encryption = 33,
	Opt_inlinecrypt = 34,
	Opt_usrjquota = 35,
	Opt_grpjquota = 36,
	Opt_offusrjquota = 37,
	Opt_offgrpjquota = 38,
	Opt_jqfmt_vfsold = 39,
	Opt_jqfmt_vfsv0 = 40,
	Opt_jqfmt_vfsv1 = 41,
	Opt_quota = 42,
	Opt_noquota = 43,
	Opt_barrier = 44,
	Opt_nobarrier = 45,
	Opt_err___2 = 46,
	Opt_usrquota = 47,
	Opt_grpquota = 48,
	Opt_prjquota = 49,
	Opt_i_version = 50,
	Opt_dax = 51,
	Opt_dax_always = 52,
	Opt_dax_inode = 53,
	Opt_dax_never = 54,
	Opt_stripe = 55,
	Opt_delalloc = 56,
	Opt_nodelalloc = 57,
	Opt_warn_on_error = 58,
	Opt_nowarn_on_error = 59,
	Opt_mblk_io_submit = 60,
	Opt_lazytime = 61,
	Opt_nolazytime = 62,
	Opt_debug_want_extra_isize = 63,
	Opt_nomblk_io_submit = 64,
	Opt_block_validity = 65,
	Opt_noblock_validity = 66,
	Opt_inode_readahead_blks = 67,
	Opt_journal_ioprio = 68,
	Opt_dioread_nolock = 69,
	Opt_dioread_lock = 70,
	Opt_discard = 71,
	Opt_nodiscard = 72,
	Opt_init_itable = 73,
	Opt_noinit_itable = 74,
	Opt_max_dir_size_kb = 75,
	Opt_nojournal_checksum = 76,
	Opt_nombcache = 77,
	Opt_no_prefetch_block_bitmaps = 78,
	Opt_mb_optimize_scan = 79,
};

struct mount_opts {
	int token;
	int mount_opt;
	int flags;
};

struct ext4_sb_encodings {
	__u16 magic;
	char *name;
	char *version;
};

struct ext4_parsed_options {
	long unsigned int journal_devnum;
	unsigned int journal_ioprio;
	int mb_optimize_scan;
};

struct ext4_mount_options {
	long unsigned int s_mount_opt;
	long unsigned int s_mount_opt2;
	kuid_t s_resuid;
	kgid_t s_resgid;
	long unsigned int s_commit_interval;
	u32 s_min_batch_time;
	u32 s_max_batch_time;
	int s_jquota_fmt;
	char *s_qf_names[3];
};

typedef int filler_t___5(void *, struct page___138 *);

enum {
	attr_noop = 0,
	attr_delayed_allocation_blocks = 1,
	attr_session_write_kbytes = 2,
	attr_lifetime_write_kbytes = 3,
	attr_reserved_clusters = 4,
	attr_sra_exceeded_retry_limit = 5,
	attr_inode_readahead = 6,
	attr_trigger_test_error = 7,
	attr_first_error_time = 8,
	attr_last_error_time = 9,
	attr_feature = 10,
	attr_pointer_ui = 11,
	attr_pointer_ul = 12,
	attr_pointer_u64 = 13,
	attr_pointer_u8 = 14,
	attr_pointer_string = 15,
	attr_pointer_atomic = 16,
	attr_journal_task = 17,
};

enum {
	ptr_explicit = 0,
	ptr_ext4_sb_info_offset = 1,
	ptr_ext4_super_block_offset = 2,
};

struct ext4_attr {
	struct attribute attr;
	short int attr_id;
	short int attr_ptr;
	short unsigned int attr_size;
	union {
		int offset;
		void *explicit_ptr;
	} u;
};

struct ext4_xattr_header {
	__le32 h_magic;
	__le32 h_refcount;
	__le32 h_blocks;
	__le32 h_hash;
	__le32 h_checksum;
	__u32 h_reserved[3];
};

struct ext4_xattr_block_find {
	struct ext4_xattr_search s;
	struct buffer_head___6 *bh;
};

struct ext4_fc_tl {
	__le16 fc_tag;
	__le16 fc_len;
};

struct ext4_fc_head {
	__le32 fc_features;
	__le32 fc_tid;
};

struct ext4_fc_add_range {
	__le32 fc_ino;
	__u8 fc_ex[12];
};

struct ext4_fc_del_range {
	__le32 fc_ino;
	__le32 fc_lblk;
	__le32 fc_len;
};

struct ext4_fc_dentry_info {
	__le32 fc_parent_ino;
	__le32 fc_ino;
	__u8 fc_dname[0];
};

struct ext4_fc_inode {
	__le32 fc_ino;
	__u8 fc_raw_inode[0];
};

struct ext4_fc_tail {
	__le32 fc_tid;
	__le32 fc_crc;
};

enum {
	EXT4_FC_STATUS_OK = 0,
	EXT4_FC_STATUS_INELIGIBLE = 1,
	EXT4_FC_STATUS_SKIPPED = 2,
	EXT4_FC_STATUS_FAILED = 3,
};

struct ext4_fc_dentry_update {
	int fcd_op;
	int fcd_parent;
	int fcd_ino;
	struct qstr fcd_name;
	unsigned char fcd_iname[32];
	struct list_head fcd_list;
};

struct ext4_iloc___2 {
	struct buffer_head___4 *bh;
	long unsigned int offset;
	ext4_group_t block_group;
};

struct ext4_ext_path___2 {
	ext4_fsblk_t p_block;
	__u16 p_depth;
	__u16 p_maxdepth;
	struct ext4_extent *p_ext;
	struct ext4_extent_idx *p_idx;
	struct ext4_extent_header *p_hdr;
	struct buffer_head___4 *p_bh;
};

struct __track_dentry_update_args {
	struct dentry___131 *dentry;
	int op;
};

struct __track_range_args {
	ext4_lblk_t start;
	ext4_lblk_t end;
};

struct dentry_info_args {
	int parent_ino;
	int dname_len;
	int ino;
	int inode_len;
	char *dname;
};

struct ext4_orphan_block_tail {
	__le32 ob_magic;
	__le32 ob_checksum;
};

typedef struct {
	__le16 e_tag;
	__le16 e_perm;
	__le32 e_id;
} ext4_acl_entry;

typedef struct {
	__le32 a_version;
} ext4_acl_header;

typedef int (*initxattrs___2)(struct inode___133 *, const struct xattr *, void *);

typedef int filler_t___6(void *, struct page___139 *);

struct commit_header {
	__be32 h_magic;
	__be32 h_blocktype;
	__be32 h_sequence;
	unsigned char h_chksum_type;
	unsigned char h_chksum_size;
	unsigned char h_padding[2];
	__be32 h_chksum[8];
	__be64 h_commit_sec;
	__be32 h_commit_nsec;
};

struct journal_block_tag3_s {
	__be32 t_blocknr;
	__be32 t_flags;
	__be32 t_blocknr_high;
	__be32 t_checksum;
};

typedef struct journal_block_tag3_s journal_block_tag3_t;

struct journal_block_tag_s {
	__be32 t_blocknr;
	__be16 t_checksum;
	__be16 t_flags;
	__be32 t_blocknr_high;
};

typedef struct journal_block_tag_s journal_block_tag_t;

struct jbd2_journal_block_tail {
	__be32 t_checksum;
};

struct jbd2_journal_revoke_header_s {
	journal_header_t r_header;
	__be32 r_count;
};

typedef struct jbd2_journal_revoke_header_s jbd2_journal_revoke_header_t;

struct recovery_info {
	tid_t start_transaction;
	tid_t end_transaction;
	int nr_replays;
	int nr_revokes;
	int nr_revoke_hits;
};

struct jbd2_revoke_table_s {
	int hash_size;
	int hash_shift;
	struct list_head *hash_table;
};

struct jbd2_revoke_record_s {
	struct list_head hash;
	tid_t sequence;
	long long unsigned int blocknr;
};

struct buffer_head___9;

typedef void bh_end_io_t___9(struct buffer_head___9 *, int);

struct buffer_head___9 {
	long unsigned int b_state;
	struct buffer_head___9 *b_this_page;
	struct page___39 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___19 *b_bdev;
	bh_end_io_t___9 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___37 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct journal_s___6;

typedef struct journal_s___6 journal_t___6;

struct journal_head___6;

struct transaction_s___6;

typedef struct transaction_s___6 transaction_t___6;

struct transaction_s___6 {
	journal_t___6 *t_journal;
	tid_t t_tid;
	enum {
		T_RUNNING___6 = 0,
		T_LOCKED___6 = 1,
		T_SWITCH___6 = 2,
		T_FLUSH___6 = 3,
		T_COMMIT___6 = 4,
		T_COMMIT_DFLUSH___6 = 5,
		T_COMMIT_JFLUSH___6 = 6,
		T_COMMIT_CALLBACK___6 = 7,
		T_FINISHED___6 = 8,
	} t_state;
	long unsigned int t_log_start;
	int t_nr_buffers;
	struct journal_head___6 *t_reserved_list;
	struct journal_head___6 *t_buffers;
	struct journal_head___6 *t_forget;
	struct journal_head___6 *t_checkpoint_list;
	struct journal_head___6 *t_checkpoint_io_list;
	struct journal_head___6 *t_shadow_list;
	struct list_head t_inode_list;
	spinlock_t t_handle_lock;
	long unsigned int t_max_wait;
	long unsigned int t_start;
	long unsigned int t_requested;
	struct transaction_chp_stats_s t_chp_stats;
	atomic_t t_updates;
	atomic_t t_outstanding_credits;
	atomic_t t_outstanding_revokes;
	atomic_t t_handle_count;
	transaction_t___6 *t_cpnext;
	transaction_t___6 *t_cpprev;
	long unsigned int t_expires;
	ktime_t t_start_time;
	unsigned int t_synchronous_commit: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int t_need_data_flush;
	struct list_head t_private_list;
};

struct jbd2_buffer_trigger_type___6;

struct journal_head___6 {
	struct buffer_head___9 *b_bh;
	spinlock_t b_state_lock;
	int b_jcount;
	unsigned int b_jlist;
	unsigned int b_modified;
	char *b_frozen_data;
	char *b_committed_data;
	transaction_t___6 *b_transaction;
	transaction_t___6 *b_next_transaction;
	struct journal_head___6 *b_tnext;
	struct journal_head___6 *b_tprev;
	transaction_t___6 *b_cp_transaction;
	struct journal_head___6 *b_cpnext;
	struct journal_head___6 *b_cpprev;
	struct jbd2_buffer_trigger_type___6 *b_triggers;
	struct jbd2_buffer_trigger_type___6 *b_frozen_triggers;
};

struct jbd2_buffer_trigger_type___6 {
	void (*t_frozen)(struct jbd2_buffer_trigger_type___6 *, struct buffer_head___9 *, void *, size_t);
	void (*t_abort)(struct jbd2_buffer_trigger_type___6 *, struct buffer_head___9 *);
};

struct crypto_alg___10;

struct crypto_tfm___10 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___10 *);
	struct crypto_alg___10 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___10 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___10 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___10 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___10 *, u8 *, const u8 *);
};

struct compress_alg___10 {
	int (*coa_compress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___10 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___10 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___10 cipher;
		struct compress_alg___10 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___10 *);
	void (*cra_exit)(struct crypto_tfm___10 *);
	void (*cra_destroy)(struct crypto_alg___10 *);
	struct module___39 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___9;

struct shash_desc___6 {
	struct crypto_shash___9 *tfm;
	void *__ctx[0];
};

struct crypto_shash___9 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___10 base;
};

struct jbd2_journal_handle___6;

typedef struct jbd2_journal_handle___6 handle_t___6;

struct jbd2_journal_handle___6 {
	union {
		transaction_t___6 *h_transaction;
		journal_t___6 *h_journal;
	};
	handle_t___6 *h_rsv_handle;
	int h_total_credits;
	int h_revoke_credits;
	int h_revoke_credits_requested;
	int h_ref;
	int h_err;
	unsigned int h_sync: 1;
	unsigned int h_jdata: 1;
	unsigned int h_reserved: 1;
	unsigned int h_aborted: 1;
	unsigned int h_type: 8;
	unsigned int h_line_no: 16;
	long: 48;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int h_start_jiffies;
	unsigned int h_requested_credits;
	unsigned int saved_alloc_context;
};

struct jbd2_inode___6;

struct journal_s___6 {
	long unsigned int j_flags;
	long unsigned int j_atomic_flags;
	int j_errno;
	struct mutex j_abort_mutex;
	struct buffer_head___9 *j_sb_buffer;
	journal_superblock_t *j_superblock;
	int j_format_version;
	rwlock_t j_state_lock;
	int j_barrier_count;
	struct mutex j_barrier;
	transaction_t___6 *j_running_transaction;
	transaction_t___6 *j_committing_transaction;
	transaction_t___6 *j_checkpoint_transactions;
	wait_queue_head_t j_wait_transaction_locked;
	wait_queue_head_t j_wait_done_commit;
	wait_queue_head_t j_wait_commit;
	wait_queue_head_t j_wait_updates;
	wait_queue_head_t j_wait_reserved;
	wait_queue_head_t j_fc_wait;
	struct mutex j_checkpoint_mutex;
	struct buffer_head___9 *j_chkpt_bhs[64];
	struct shrinker___17 j_shrinker;
	struct percpu_counter j_checkpoint_jh_count;
	transaction_t___6 *j_shrink_transaction;
	long unsigned int j_head;
	long unsigned int j_tail;
	long unsigned int j_free;
	long unsigned int j_first;
	long unsigned int j_last;
	long unsigned int j_fc_first;
	long unsigned int j_fc_off;
	long unsigned int j_fc_last;
	struct block_device___19 *j_dev;
	int j_blocksize;
	long long unsigned int j_blk_offset;
	char j_devname[56];
	struct block_device___19 *j_fs_dev;
	unsigned int j_total_len;
	atomic_t j_reserved_credits;
	spinlock_t j_list_lock;
	struct inode___38 *j_inode;
	tid_t j_tail_sequence;
	tid_t j_transaction_sequence;
	tid_t j_commit_sequence;
	tid_t j_commit_request;
	__u8 j_uuid[16];
	struct task_struct___2 *j_task;
	int j_max_transaction_buffers;
	int j_revoke_records_per_block;
	long unsigned int j_commit_interval;
	struct timer_list j_commit_timer;
	spinlock_t j_revoke_lock;
	struct jbd2_revoke_table_s *j_revoke;
	struct jbd2_revoke_table_s *j_revoke_table[2];
	struct buffer_head___9 **j_wbuf;
	struct buffer_head___9 **j_fc_wbuf;
	int j_wbufsize;
	int j_fc_wbufsize;
	pid_t j_last_sync_writer;
	u64 j_average_commit_time;
	u32 j_min_batch_time;
	u32 j_max_batch_time;
	void (*j_commit_callback)(journal_t___6 *, transaction_t___6 *);
	int (*j_submit_inode_data_buffers)(struct jbd2_inode___6 *);
	int (*j_finish_inode_data_buffers)(struct jbd2_inode___6 *);
	spinlock_t j_history_lock;
	struct proc_dir_entry *j_proc_entry;
	struct transaction_stats_s j_stats;
	unsigned int j_failed_commit;
	void *j_private;
	struct crypto_shash___9 *j_chksum_driver;
	__u32 j_csum_seed;
	void (*j_fc_cleanup_callback)(struct journal_s___6 *, int, tid_t);
	int (*j_fc_replay_callback)(struct journal_s___6 *, struct buffer_head___9 *, enum passtype, int, tid_t);
};

struct jbd2_inode___6 {
	transaction_t___6 *i_transaction;
	transaction_t___6 *i_next_transaction;
	struct list_head i_list;
	struct inode___38 *i_vfs_inode;
	long unsigned int i_flags;
	loff_t i_dirty_start;
	loff_t i_dirty_end;
};

struct trace_event_raw_jbd2_checkpoint {
	struct trace_entry ent;
	dev_t dev;
	int result;
	char __data[0];
};

struct trace_event_raw_jbd2_commit {
	struct trace_entry ent;
	dev_t dev;
	char sync_commit;
	int transaction;
	char __data[0];
};

struct trace_event_raw_jbd2_end_commit {
	struct trace_entry ent;
	dev_t dev;
	char sync_commit;
	int transaction;
	int head;
	char __data[0];
};

struct trace_event_raw_jbd2_submit_inode_data {
	struct trace_entry ent;
	dev_t dev;
	ino_t ino;
	char __data[0];
};

struct trace_event_raw_jbd2_handle_start_class {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int tid;
	unsigned int type;
	unsigned int line_no;
	int requested_blocks;
	char __data[0];
};

struct trace_event_raw_jbd2_handle_extend {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int tid;
	unsigned int type;
	unsigned int line_no;
	int buffer_credits;
	int requested_blocks;
	char __data[0];
};

struct trace_event_raw_jbd2_handle_stats {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int tid;
	unsigned int type;
	unsigned int line_no;
	int interval;
	int sync;
	int requested_blocks;
	int dirtied_blocks;
	char __data[0];
};

struct trace_event_raw_jbd2_run_stats {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int tid;
	long unsigned int wait;
	long unsigned int request_delay;
	long unsigned int running;
	long unsigned int locked;
	long unsigned int flushing;
	long unsigned int logging;
	__u32 handle_count;
	__u32 blocks;
	__u32 blocks_logged;
	char __data[0];
};

struct trace_event_raw_jbd2_checkpoint_stats {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int tid;
	long unsigned int chp_time;
	__u32 forced_to_close;
	__u32 written;
	__u32 dropped;
	char __data[0];
};

struct trace_event_raw_jbd2_update_log_tail {
	struct trace_entry ent;
	dev_t dev;
	tid_t tail_sequence;
	tid_t first_tid;
	long unsigned int block_nr;
	long unsigned int freed;
	char __data[0];
};

struct trace_event_raw_jbd2_write_superblock {
	struct trace_entry ent;
	dev_t dev;
	int write_op;
	char __data[0];
};

struct trace_event_raw_jbd2_lock_buffer_stall {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int stall_ms;
	char __data[0];
};

struct trace_event_raw_jbd2_journal_shrink {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int nr_to_scan;
	long unsigned int count;
	char __data[0];
};

struct trace_event_raw_jbd2_shrink_scan_exit {
	struct trace_entry ent;
	dev_t dev;
	long unsigned int nr_to_scan;
	long unsigned int nr_shrunk;
	long unsigned int count;
	char __data[0];
};

struct trace_event_raw_jbd2_shrink_checkpoint_list {
	struct trace_entry ent;
	dev_t dev;
	tid_t first_tid;
	tid_t tid;
	tid_t last_tid;
	long unsigned int nr_freed;
	long unsigned int nr_scanned;
	tid_t next_tid;
	char __data[0];
};

struct trace_event_data_offsets_jbd2_checkpoint {};

struct trace_event_data_offsets_jbd2_commit {};

struct trace_event_data_offsets_jbd2_end_commit {};

struct trace_event_data_offsets_jbd2_submit_inode_data {};

struct trace_event_data_offsets_jbd2_handle_start_class {};

struct trace_event_data_offsets_jbd2_handle_extend {};

struct trace_event_data_offsets_jbd2_handle_stats {};

struct trace_event_data_offsets_jbd2_run_stats {};

struct trace_event_data_offsets_jbd2_checkpoint_stats {};

struct trace_event_data_offsets_jbd2_update_log_tail {};

struct trace_event_data_offsets_jbd2_write_superblock {};

struct trace_event_data_offsets_jbd2_lock_buffer_stall {};

struct trace_event_data_offsets_jbd2_journal_shrink {};

struct trace_event_data_offsets_jbd2_shrink_scan_exit {};

struct trace_event_data_offsets_jbd2_shrink_checkpoint_list {};

typedef void (*btf_trace_jbd2_checkpoint)(void *, journal_t___6 *, int);

typedef void (*btf_trace_jbd2_start_commit)(void *, journal_t___6 *, transaction_t___6 *);

typedef void (*btf_trace_jbd2_commit_locking)(void *, journal_t___6 *, transaction_t___6 *);

typedef void (*btf_trace_jbd2_commit_flushing)(void *, journal_t___6 *, transaction_t___6 *);

typedef void (*btf_trace_jbd2_commit_logging)(void *, journal_t___6 *, transaction_t___6 *);

typedef void (*btf_trace_jbd2_drop_transaction)(void *, journal_t___6 *, transaction_t___6 *);

typedef void (*btf_trace_jbd2_end_commit)(void *, journal_t___6 *, transaction_t___6 *);

typedef void (*btf_trace_jbd2_submit_inode_data)(void *, struct inode___38 *);

typedef void (*btf_trace_jbd2_handle_start)(void *, dev_t, long unsigned int, unsigned int, unsigned int, int);

typedef void (*btf_trace_jbd2_handle_restart)(void *, dev_t, long unsigned int, unsigned int, unsigned int, int);

typedef void (*btf_trace_jbd2_handle_extend)(void *, dev_t, long unsigned int, unsigned int, unsigned int, int, int);

typedef void (*btf_trace_jbd2_handle_stats)(void *, dev_t, long unsigned int, unsigned int, unsigned int, int, int, int, int);

typedef void (*btf_trace_jbd2_run_stats)(void *, dev_t, long unsigned int, struct transaction_run_stats_s *);

typedef void (*btf_trace_jbd2_checkpoint_stats)(void *, dev_t, long unsigned int, struct transaction_chp_stats_s *);

typedef void (*btf_trace_jbd2_update_log_tail)(void *, journal_t___6 *, tid_t, long unsigned int, long unsigned int);

typedef void (*btf_trace_jbd2_write_superblock)(void *, journal_t___6 *, int);

typedef void (*btf_trace_jbd2_lock_buffer_stall)(void *, dev_t, long unsigned int);

typedef void (*btf_trace_jbd2_shrink_count)(void *, journal_t___6 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_jbd2_shrink_scan_enter)(void *, journal_t___6 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_jbd2_shrink_scan_exit)(void *, journal_t___6 *, long unsigned int, long unsigned int, long unsigned int);

typedef void (*btf_trace_jbd2_shrink_checkpoint_list)(void *, journal_t___6 *, tid_t, tid_t, tid_t, long unsigned int, long unsigned int, tid_t);

struct jbd2_stats_proc_session {
	journal_t___6 *journal;
	struct transaction_stats_s *stats;
	int start;
	int max;
};

struct bvec_iter_all___6 {
	struct bio_vec___66 bv;
	int idx;
	unsigned int done;
};

struct meta_entry {
	u64 data_block;
	unsigned int index_block;
	short unsigned int offset;
	short unsigned int pad;
};

struct meta_index {
	unsigned int inode_number;
	unsigned int offset;
	short unsigned int entries;
	short unsigned int skip;
	short unsigned int locked;
	short unsigned int pad;
	struct meta_entry meta_entry[127];
};

struct squashfs_cache_entry;

struct squashfs_cache {
	char *name;
	int entries;
	int curr_blk;
	int next_blk;
	int num_waiters;
	int unused;
	int block_size;
	int pages;
	spinlock_t lock;
	wait_queue_head_t wait_queue;
	struct squashfs_cache_entry *entry;
};

struct squashfs_page_actor;

struct squashfs_cache_entry {
	u64 block;
	int length;
	int refcount;
	u64 next_index;
	int pending;
	int error;
	int num_waiters;
	wait_queue_head_t wait_queue;
	struct squashfs_cache *cache;
	void **data;
	struct squashfs_page_actor *actor;
};

struct squashfs_page_actor {
	union {
		void **buffer;
		struct page___125 **page;
	};
	void *pageaddr;
	void * (*squashfs_first_page)(struct squashfs_page_actor *);
	void * (*squashfs_next_page)(struct squashfs_page_actor *);
	void (*squashfs_finish_page)(struct squashfs_page_actor *);
	int pages;
	int length;
	int next_page;
};

struct squashfs_decompressor;

struct squashfs_stream;

struct squashfs_sb_info {
	const struct squashfs_decompressor *decompressor;
	int devblksize;
	int devblksize_log2;
	struct squashfs_cache *block_cache;
	struct squashfs_cache *fragment_cache;
	struct squashfs_cache *read_page;
	int next_meta_index;
	__le64 *id_table;
	__le64 *fragment_index;
	__le64 *xattr_id_table;
	struct mutex meta_index_mutex;
	struct meta_index *meta_index;
	struct squashfs_stream *stream;
	__le64 *inode_lookup_table;
	u64 inode_table;
	u64 directory_table;
	u64 xattr_table;
	unsigned int block_size;
	short unsigned int block_log;
	long long int bytes_used;
	unsigned int inodes;
	unsigned int fragments;
	int xattr_ids;
	unsigned int ids;
	bool panic_on_errors;
};

struct squashfs_decompressor {
	void * (*init)(struct squashfs_sb_info *, void *);
	void * (*comp_opts)(struct squashfs_sb_info *, void *, int);
	void (*free)(void *);
	int (*decompress)(struct squashfs_sb_info *, void *, struct bio___55 *, int, int, struct squashfs_page_actor *);
	int id;
	char *name;
	int supported;
};

struct squashfs_cache_entry___2;

struct squashfs_cache___2 {
	char *name;
	int entries;
	int curr_blk;
	int next_blk;
	int num_waiters;
	int unused;
	int block_size;
	int pages;
	spinlock_t lock;
	wait_queue_head_t wait_queue;
	struct squashfs_cache_entry___2 *entry;
};

struct squashfs_page_actor___2;

struct squashfs_cache_entry___2 {
	u64 block;
	int length;
	int refcount;
	u64 next_index;
	int pending;
	int error;
	int num_waiters;
	wait_queue_head_t wait_queue;
	struct squashfs_cache___2 *cache;
	void **data;
	struct squashfs_page_actor___2 *actor;
};

struct squashfs_page_actor___2 {
	union {
		void **buffer;
		struct page___135 **page;
	};
	void *pageaddr;
	void * (*squashfs_first_page)(struct squashfs_page_actor___2 *);
	void * (*squashfs_next_page)(struct squashfs_page_actor___2 *);
	void (*squashfs_finish_page)(struct squashfs_page_actor___2 *);
	int pages;
	int length;
	int next_page;
};

struct squashfs_sb_info___2 {
	const struct squashfs_decompressor *decompressor;
	int devblksize;
	int devblksize_log2;
	struct squashfs_cache___2 *block_cache;
	struct squashfs_cache___2 *fragment_cache;
	struct squashfs_cache___2 *read_page;
	int next_meta_index;
	__le64 *id_table;
	__le64 *fragment_index;
	__le64 *xattr_id_table;
	struct mutex meta_index_mutex;
	struct meta_index *meta_index;
	struct squashfs_stream *stream;
	__le64 *inode_lookup_table;
	u64 inode_table;
	u64 directory_table;
	u64 xattr_table;
	unsigned int block_size;
	short unsigned int block_log;
	long long int bytes_used;
	unsigned int inodes;
	unsigned int fragments;
	int xattr_ids;
	unsigned int ids;
	bool panic_on_errors;
};

struct squashfs_dir_index {
	__le32 index;
	__le32 start_block;
	__le32 size;
	unsigned char name[0];
};

struct squashfs_dir_entry {
	__le16 offset;
	__le16 inode_number;
	__le16 type;
	__le16 size;
	char name[0];
};

struct squashfs_dir_header {
	__le32 count;
	__le32 start_block;
	__le32 inode_number;
};

struct squashfs_inode_info {
	u64 start;
	int offset;
	u64 xattr;
	unsigned int xattr_size;
	int xattr_count;
	union {
		struct {
			u64 fragment_block;
			int fragment_size;
			int fragment_offset;
			u64 block_list_start;
		};
		struct {
			u64 dir_idx_start;
			int dir_idx_offset;
			int dir_idx_cnt;
			int parent;
		};
	};
	struct inode___130 vfs_inode;
};

struct squashfs_inode_info___2 {
	u64 start;
	int offset;
	u64 xattr;
	unsigned int xattr_size;
	int xattr_count;
	union {
		struct {
			u64 fragment_block;
			int fragment_size;
			int fragment_offset;
			u64 block_list_start;
		};
		struct {
			u64 dir_idx_start;
			int dir_idx_offset;
			int dir_idx_cnt;
			int parent;
		};
	};
	struct inode___129 vfs_inode;
};

struct squashfs_fragment_entry {
	__le64 start_block;
	__le32 size;
	unsigned int unused;
};

struct squashfs_base_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
};

struct squashfs_ipc_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 nlink;
};

struct squashfs_lipc_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 nlink;
	__le32 xattr;
};

struct squashfs_dev_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 nlink;
	__le32 rdev;
};

struct squashfs_ldev_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 nlink;
	__le32 rdev;
	__le32 xattr;
};

struct squashfs_symlink_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 nlink;
	__le32 symlink_size;
	char symlink[0];
};

struct squashfs_reg_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 start_block;
	__le32 fragment;
	__le32 offset;
	__le32 file_size;
	__le16 block_list[0];
};

struct squashfs_lreg_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le64 start_block;
	__le64 file_size;
	__le64 sparse;
	__le32 nlink;
	__le32 fragment;
	__le32 offset;
	__le32 xattr;
	__le16 block_list[0];
};

struct squashfs_dir_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 start_block;
	__le32 nlink;
	__le16 file_size;
	__le16 offset;
	__le32 parent_inode;
};

struct squashfs_ldir_inode {
	__le16 inode_type;
	__le16 mode;
	__le16 uid;
	__le16 guid;
	__le32 mtime;
	__le32 inode_number;
	__le32 nlink;
	__le32 file_size;
	__le32 start_block;
	__le32 parent_inode;
	__le16 i_count;
	__le16 offset;
	__le32 xattr;
	struct squashfs_dir_index index[0];
};

union squashfs_inode {
	struct squashfs_base_inode base;
	struct squashfs_dev_inode dev;
	struct squashfs_ldev_inode ldev;
	struct squashfs_symlink_inode symlink;
	struct squashfs_reg_inode reg;
	struct squashfs_lreg_inode lreg;
	struct squashfs_dir_inode dir;
	struct squashfs_ldir_inode ldir;
	struct squashfs_ipc_inode ipc;
	struct squashfs_lipc_inode lipc;
};

struct squashfs_super_block {
	__le32 s_magic;
	__le32 inodes;
	__le32 mkfs_time;
	__le32 block_size;
	__le32 fragments;
	__le16 compression;
	__le16 block_log;
	__le16 flags;
	__le16 no_ids;
	__le16 s_major;
	__le16 s_minor;
	__le64 root_inode;
	__le64 bytes_used;
	__le64 id_table_start;
	__le64 xattr_id_table_start;
	__le64 inode_table_start;
	__le64 directory_table_start;
	__le64 fragment_table_start;
	__le64 lookup_table_start;
};

struct squashfs_inode_info___3 {
	u64 start;
	int offset;
	u64 xattr;
	unsigned int xattr_size;
	int xattr_count;
	union {
		struct {
			u64 fragment_block;
			int fragment_size;
			int fragment_offset;
			u64 block_list_start;
		};
		struct {
			u64 dir_idx_start;
			int dir_idx_offset;
			int dir_idx_cnt;
			int parent;
		};
	};
	struct inode___120 vfs_inode;
};

enum Opt_errors {
	Opt_errors_continue = 0,
	Opt_errors_panic = 1,
};

enum squashfs_param {
	Opt_errors = 0,
};

struct squashfs_mount_opts {
	enum Opt_errors errors;
};

struct squashfs_cache_entry___3;

struct squashfs_cache___3 {
	char *name;
	int entries;
	int curr_blk;
	int next_blk;
	int num_waiters;
	int unused;
	int block_size;
	int pages;
	spinlock_t lock;
	wait_queue_head_t wait_queue;
	struct squashfs_cache_entry___3 *entry;
};

struct squashfs_page_actor___3;

struct squashfs_cache_entry___3 {
	u64 block;
	int length;
	int refcount;
	u64 next_index;
	int pending;
	int error;
	int num_waiters;
	wait_queue_head_t wait_queue;
	struct squashfs_cache___3 *cache;
	void **data;
	struct squashfs_page_actor___3 *actor;
};

struct squashfs_page_actor___3 {
	union {
		void **buffer;
		struct page___139 **page;
	};
	void *pageaddr;
	void * (*squashfs_first_page)(struct squashfs_page_actor___3 *);
	void * (*squashfs_next_page)(struct squashfs_page_actor___3 *);
	void (*squashfs_finish_page)(struct squashfs_page_actor___3 *);
	int pages;
	int length;
	int next_page;
};

struct squashfs_decompressor___2;

struct squashfs_sb_info___3 {
	const struct squashfs_decompressor___2 *decompressor;
	int devblksize;
	int devblksize_log2;
	struct squashfs_cache___3 *block_cache;
	struct squashfs_cache___3 *fragment_cache;
	struct squashfs_cache___3 *read_page;
	int next_meta_index;
	__le64 *id_table;
	__le64 *fragment_index;
	__le64 *xattr_id_table;
	struct mutex meta_index_mutex;
	struct meta_index *meta_index;
	struct squashfs_stream *stream;
	__le64 *inode_lookup_table;
	u64 inode_table;
	u64 directory_table;
	u64 xattr_table;
	unsigned int block_size;
	short unsigned int block_log;
	long long int bytes_used;
	unsigned int inodes;
	unsigned int fragments;
	int xattr_ids;
	unsigned int ids;
	bool panic_on_errors;
};

struct squashfs_decompressor___2 {
	void * (*init)(struct squashfs_sb_info___3 *, void *);
	void * (*comp_opts)(struct squashfs_sb_info___3 *, void *, int);
	void (*free)(void *);
	int (*decompress)(struct squashfs_sb_info___3 *, void *, struct bio___61 *, int, int, struct squashfs_page_actor___3 *);
	int id;
	char *name;
	int supported;
};

struct squashfs_cache_entry___4;

struct squashfs_cache___4 {
	char *name;
	int entries;
	int curr_blk;
	int next_blk;
	int num_waiters;
	int unused;
	int block_size;
	int pages;
	spinlock_t lock;
	wait_queue_head_t wait_queue;
	struct squashfs_cache_entry___4 *entry;
};

struct squashfs_page_actor___4;

struct squashfs_cache_entry___4 {
	u64 block;
	int length;
	int refcount;
	u64 next_index;
	int pending;
	int error;
	int num_waiters;
	wait_queue_head_t wait_queue;
	struct squashfs_cache___4 *cache;
	void **data;
	struct squashfs_page_actor___4 *actor;
};

struct squashfs_page_actor___4 {
	union {
		void **buffer;
		struct page___133 **page;
	};
	void *pageaddr;
	void * (*squashfs_first_page)(struct squashfs_page_actor___4 *);
	void * (*squashfs_next_page)(struct squashfs_page_actor___4 *);
	void (*squashfs_finish_page)(struct squashfs_page_actor___4 *);
	int pages;
	int length;
	int next_page;
};

struct squashfs_sb_info___4 {
	const struct squashfs_decompressor *decompressor;
	int devblksize;
	int devblksize_log2;
	struct squashfs_cache___4 *block_cache;
	struct squashfs_cache___4 *fragment_cache;
	struct squashfs_cache___4 *read_page;
	int next_meta_index;
	__le64 *id_table;
	__le64 *fragment_index;
	__le64 *xattr_id_table;
	struct mutex meta_index_mutex;
	struct meta_index *meta_index;
	struct squashfs_stream *stream;
	__le64 *inode_lookup_table;
	u64 inode_table;
	u64 directory_table;
	u64 xattr_table;
	unsigned int block_size;
	short unsigned int block_log;
	long long int bytes_used;
	unsigned int inodes;
	unsigned int fragments;
	int xattr_ids;
	unsigned int ids;
	bool panic_on_errors;
};

struct squashfs_stream {
	void *stream;
	struct mutex mutex;
};

struct squashfs_xattr_entry {
	__le16 type;
	__le16 size;
	char data[0];
};

struct squashfs_xattr_val {
	__le32 vsize;
	char value[0];
};

struct squashfs_inode_info___4 {
	u64 start;
	int offset;
	u64 xattr;
	unsigned int xattr_size;
	int xattr_count;
	union {
		struct {
			u64 fragment_block;
			int fragment_size;
			int fragment_offset;
			u64 block_list_start;
		};
		struct {
			u64 dir_idx_start;
			int dir_idx_offset;
			int dir_idx_cnt;
			int parent;
		};
	};
	struct inode___93 vfs_inode;
};

struct squashfs_xattr_id {
	__le64 xattr;
	__le32 count;
	__le32 size;
};

struct squashfs_xattr_id_table {
	__le64 xattr_table_start;
	__le32 xattr_ids;
	__le32 unused;
};

struct lz4_comp_opts {
	__le32 version;
	__le32 flags;
};

struct squashfs_lz4 {
	void *input;
	void *output;
};

struct squashfs_lzo {
	void *input;
	void *output;
};

enum xz_mode {
	XZ_SINGLE = 0,
	XZ_PREALLOC = 1,
	XZ_DYNALLOC = 2,
};

enum xz_ret {
	XZ_OK = 0,
	XZ_STREAM_END = 1,
	XZ_UNSUPPORTED_CHECK = 2,
	XZ_MEM_ERROR = 3,
	XZ_MEMLIMIT_ERROR = 4,
	XZ_FORMAT_ERROR = 5,
	XZ_OPTIONS_ERROR = 6,
	XZ_DATA_ERROR = 7,
	XZ_BUF_ERROR = 8,
};

struct xz_buf {
	const uint8_t *in;
	size_t in_pos;
	size_t in_size;
	uint8_t *out;
	size_t out_pos;
	size_t out_size;
};

struct xz_dec;

struct squashfs_xz {
	struct xz_dec *state;
	struct xz_buf buf;
};

struct disk_comp_opts {
	__le32 dictionary_size;
	__le32 flags;
};

struct comp_opts {
	int dict_size;
};

typedef unsigned char Byte;

typedef long unsigned int uLong;

struct internal_state;

struct z_stream_s {
	const Byte *next_in;
	uLong avail_in;
	uLong total_in;
	Byte *next_out;
	uLong avail_out;
	uLong total_out;
	char *msg;
	struct internal_state *state;
	void *workspace;
	int data_type;
	uLong adler;
	uLong reserved;
};

struct internal_state {
	int dummy;
};

typedef struct z_stream_s z_stream;

typedef z_stream *z_streamp;

typedef enum {
	ZSTD_error_no_error = 0,
	ZSTD_error_GENERIC = 1,
	ZSTD_error_prefix_unknown = 2,
	ZSTD_error_version_unsupported = 3,
	ZSTD_error_parameter_unknown = 4,
	ZSTD_error_frameParameter_unsupported = 5,
	ZSTD_error_frameParameter_unsupportedBy32bits = 6,
	ZSTD_error_frameParameter_windowTooLarge = 7,
	ZSTD_error_compressionParameter_unsupported = 8,
	ZSTD_error_init_missing = 9,
	ZSTD_error_memory_allocation = 10,
	ZSTD_error_stage_wrong = 11,
	ZSTD_error_dstSize_tooSmall = 12,
	ZSTD_error_srcSize_wrong = 13,
	ZSTD_error_corruption_detected = 14,
	ZSTD_error_checksum_wrong = 15,
	ZSTD_error_tableLog_tooLarge = 16,
	ZSTD_error_maxSymbolValue_tooLarge = 17,
	ZSTD_error_maxSymbolValue_tooSmall = 18,
	ZSTD_error_dictionary_corrupted = 19,
	ZSTD_error_dictionary_wrong = 20,
	ZSTD_error_dictionaryCreation_failed = 21,
	ZSTD_error_maxCode = 22,
} ZSTD_ErrorCode;

struct ZSTD_inBuffer_s {
	const void *src;
	size_t size;
	size_t pos;
};

typedef struct ZSTD_inBuffer_s ZSTD_inBuffer;

struct ZSTD_outBuffer_s {
	void *dst;
	size_t size;
	size_t pos;
};

typedef struct ZSTD_outBuffer_s ZSTD_outBuffer;

struct ZSTD_DStream_s;

typedef struct ZSTD_DStream_s ZSTD_DStream;

struct workspace {
	void *mem;
	size_t mem_size;
	size_t window_size;
};

struct ramfs_mount_opts {
	umode_t mode;
};

struct ramfs_fs_info {
	struct ramfs_mount_opts mount_opts;
};

enum ramfs_param {
	Opt_mode___3 = 0,
};

struct page_counter___2;

struct resv_map___3 {
	struct kref refs;
	spinlock_t lock;
	struct list_head regions;
	long int adds_in_progress;
	struct list_head region_cache;
	long int region_cache_count;
	struct page_counter___2 *reservation_counter;
	long unsigned int pages_per_hpage;
	struct cgroup_subsys_state___90 *css;
};

enum hugetlbfs_size_type {
	NO_SIZE = 0,
	SIZE_STD = 1,
	SIZE_PERCENT = 2,
};

struct hugetlbfs_fs_context {
	struct hstate___7 *hstate;
	long long unsigned int max_size_opt;
	long long unsigned int min_size_opt;
	long int max_hpages;
	long int nr_inodes;
	long int min_hpages;
	enum hugetlbfs_size_type max_val_type;
	enum hugetlbfs_size_type min_val_type;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

enum hugetlb_param {
	Opt_gid___4 = 0,
	Opt_min_size = 1,
	Opt_mode___4 = 2,
	Opt_nr_inodes___2 = 3,
	Opt_pagesize = 4,
	Opt_size___2 = 5,
	Opt_uid___3 = 6,
};

struct buffer_head___10;

typedef void bh_end_io_t___10(struct buffer_head___10 *, int);

struct buffer_head___10 {
	long unsigned int b_state;
	struct buffer_head___10 *b_this_page;
	struct page___133 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___5 *b_bdev;
	bh_end_io_t___10 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___128 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

typedef u16 wchar_t;

struct nls_table {
	const char *charset;
	const char *alias;
	int (*uni2char)(wchar_t, unsigned char *, int);
	int (*char2uni)(const unsigned char *, int, wchar_t *);
	const unsigned char *charset2lower;
	const unsigned char *charset2upper;
	struct module___117 *owner;
	struct nls_table *next;
};

struct fat_mount_options {
	kuid_t fs_uid;
	kgid_t fs_gid;
	short unsigned int fs_fmask;
	short unsigned int fs_dmask;
	short unsigned int codepage;
	int time_offset;
	char *iocharset;
	short unsigned int shortname;
	unsigned char name_check;
	unsigned char errors;
	unsigned char nfs;
	short unsigned int allow_utime;
	unsigned int quiet;
	unsigned int showexec;
	unsigned int sys_immutable;
	unsigned int dotsOK;
	unsigned int isvfat;
	unsigned int utf8;
	unsigned int unicode_xlate;
	unsigned int numtail;
	unsigned int flush;
	unsigned int nocase;
	unsigned int usefree;
	unsigned int tz_set;
	unsigned int rodir;
	unsigned int discard;
	unsigned int dos1xfloppy;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fatent_operations;

struct msdos_sb_info {
	short unsigned int sec_per_clus;
	short unsigned int cluster_bits;
	unsigned int cluster_size;
	unsigned char fats;
	unsigned char fat_bits;
	short unsigned int fat_start;
	long unsigned int fat_length;
	long unsigned int dir_start;
	short unsigned int dir_entries;
	long unsigned int data_start;
	long unsigned int max_cluster;
	long unsigned int root_cluster;
	long unsigned int fsinfo_sector;
	struct mutex fat_lock;
	struct mutex nfs_build_inode_lock;
	struct mutex s_lock;
	unsigned int prev_free;
	unsigned int free_clusters;
	unsigned int free_clus_valid;
	struct fat_mount_options options;
	struct nls_table *nls_disk;
	struct nls_table *nls_io;
	const void *dir_ops;
	int dir_per_block;
	int dir_per_block_bits;
	unsigned int vol_id;
	int fatent_shift;
	const struct fatent_operations *fatent_ops;
	struct inode___128 *fat_inode;
	struct inode___128 *fsinfo_inode;
	struct ratelimit_state ratelimit;
	spinlock_t inode_hash_lock;
	struct hlist_head inode_hashtable[256];
	spinlock_t dir_hash_lock;
	struct hlist_head dir_hashtable[256];
	unsigned int dirty;
	struct callback_head rcu;
};

struct fat_entry;

struct fatent_operations {
	void (*ent_blocknr)(struct super_block___134 *, int, int *, sector_t *);
	void (*ent_set_ptr)(struct fat_entry *, int);
	int (*ent_bread)(struct super_block___134 *, struct fat_entry *, int, sector_t);
	int (*ent_get)(struct fat_entry *);
	void (*ent_put)(struct fat_entry *, int);
	int (*ent_next)(struct fat_entry *);
};

struct msdos_inode_info {
	spinlock_t cache_lru_lock;
	struct list_head cache_lru;
	int nr_caches;
	unsigned int cache_valid_id;
	loff_t mmu_private;
	int i_start;
	int i_logstart;
	int i_attrs;
	loff_t i_pos;
	struct hlist_node i_fat_hash;
	struct hlist_node i_dir_hash;
	struct rw_semaphore truncate_lock;
	struct inode___128 vfs_inode;
};

struct fat_entry___2 {
	int entry;
	union {
		u8 *ent12_p[2];
		__le16 *ent16_p;
		__le32 *ent32_p;
	} u;
	int nr_bhs;
	struct buffer_head___10 *bhs[2];
	struct inode___128 *fat_inode;
};

struct fat_cache {
	struct list_head cache_list;
	int nr_contig;
	int fcluster;
	int dcluster;
};

struct fat_cache_id {
	unsigned int id;
	int nr_contig;
	int fcluster;
	int dcluster;
};

struct compat_dirent {
	u32 d_ino;
	compat_off_t d_off;
	u16 d_reclen;
	char d_name[256];
};

enum utf16_endian {
	UTF16_HOST_ENDIAN = 0,
	UTF16_LITTLE_ENDIAN = 1,
	UTF16_BIG_ENDIAN = 2,
};

struct __fat_dirent {
	long int d_ino;
	__kernel_off_t d_off;
	short unsigned int d_reclen;
	char d_name[256];
};

struct msdos_dir_entry {
	__u8 name[11];
	__u8 attr;
	__u8 lcase;
	__u8 ctime_cs;
	__le16 ctime;
	__le16 cdate;
	__le16 adate;
	__le16 starthi;
	__le16 time;
	__le16 date;
	__le16 start;
	__le32 size;
};

struct msdos_dir_slot {
	__u8 id;
	__u8 name0_4[10];
	__u8 attr;
	__u8 reserved;
	__u8 alias_checksum;
	__u8 name5_10[12];
	__le16 start;
	__u8 name11_12[4];
};

struct fat_slot_info {
	loff_t i_pos;
	loff_t slot_off;
	int nr_slots;
	struct msdos_dir_entry *de;
	struct buffer_head___10 *bh;
};

typedef long long unsigned int llu;

enum {
	PARSE_INVALID = 1,
	PARSE_NOT_LONGNAME = 2,
	PARSE_EOF = 3,
};

struct fat_ioctl_filldir_callback {
	struct dir_context ctx;
	void *dirent;
	int result;
	const char *longname;
	int long_len;
	const char *shortname;
	int short_len;
};

struct nls_table___2 {
	const char *charset;
	const char *alias;
	int (*uni2char)(wchar_t, unsigned char *, int);
	int (*char2uni)(const unsigned char *, int, wchar_t *);
	const unsigned char *charset2lower;
	const unsigned char *charset2upper;
	struct module___123 *owner;
	struct nls_table___2 *next;
};

struct msdos_sb_info___2 {
	short unsigned int sec_per_clus;
	short unsigned int cluster_bits;
	unsigned int cluster_size;
	unsigned char fats;
	unsigned char fat_bits;
	short unsigned int fat_start;
	long unsigned int fat_length;
	long unsigned int dir_start;
	short unsigned int dir_entries;
	long unsigned int data_start;
	long unsigned int max_cluster;
	long unsigned int root_cluster;
	long unsigned int fsinfo_sector;
	struct mutex fat_lock;
	struct mutex nfs_build_inode_lock;
	struct mutex s_lock;
	unsigned int prev_free;
	unsigned int free_clusters;
	unsigned int free_clus_valid;
	struct fat_mount_options options;
	struct nls_table___2 *nls_disk;
	struct nls_table___2 *nls_io;
	const void *dir_ops;
	int dir_per_block;
	int dir_per_block_bits;
	unsigned int vol_id;
	int fatent_shift;
	const struct fatent_operations *fatent_ops;
	struct inode___134 *fat_inode;
	struct inode___134 *fsinfo_inode;
	struct ratelimit_state ratelimit;
	spinlock_t inode_hash_lock;
	struct hlist_head inode_hashtable[256];
	spinlock_t dir_hash_lock;
	struct hlist_head dir_hashtable[256];
	unsigned int dirty;
	struct callback_head rcu;
};

struct fat_entry {
	int entry;
	union {
		u8 *ent12_p[2];
		__le16 *ent16_p;
		__le32 *ent32_p;
	} u;
	int nr_bhs;
	struct buffer_head___7 *bhs[2];
	struct inode___134 *fat_inode;
};

struct fatent_ra {
	sector_t cur;
	sector_t limit;
	unsigned int ra_blocks;
	sector_t ra_advance;
	sector_t ra_next;
	sector_t ra_limit;
};

struct msdos_inode_info___2 {
	spinlock_t cache_lru_lock;
	struct list_head cache_lru;
	int nr_caches;
	unsigned int cache_valid_id;
	loff_t mmu_private;
	int i_start;
	int i_logstart;
	int i_attrs;
	loff_t i_pos;
	struct hlist_node i_fat_hash;
	struct hlist_node i_dir_hash;
	struct rw_semaphore truncate_lock;
	struct inode___134 vfs_inode;
};

typedef int dio_iodone_t___2(struct kiocb___134 *, loff_t, ssize_t, void *);

typedef void dio_submit_t___2(struct bio___61 *, struct inode___134 *, loff_t);

struct fat_boot_sector {
	__u8 ignored[3];
	__u8 system_id[8];
	__u8 sector_size[2];
	__u8 sec_per_clus;
	__le16 reserved;
	__u8 fats;
	__u8 dir_entries[2];
	__u8 sectors[2];
	__u8 media;
	__le16 fat_length;
	__le16 secs_track;
	__le16 heads;
	__le32 hidden;
	__le32 total_sect;
	union {
		struct {
			__u8 drive_number;
			__u8 state;
			__u8 signature;
			__u8 vol_id[4];
			__u8 vol_label[11];
			__u8 fs_type[8];
		} fat16;
		struct {
			__le32 length;
			__le16 flags;
			__u8 version[2];
			__le32 root_cluster;
			__le16 info_sector;
			__le16 backup_boot;
			__le16 reserved2[6];
			__u8 drive_number;
			__u8 state;
			__u8 signature;
			__u8 vol_id[4];
			__u8 vol_label[11];
			__u8 fs_type[8];
		} fat32;
	};
};

struct fat_boot_fsinfo {
	__le32 signature1;
	__le32 reserved1[120];
	__le32 signature2;
	__le32 free_clusters;
	__le32 next_cluster;
	__le32 reserved2[4];
};

struct fat_bios_param_block {
	u16 fat_sector_size;
	u8 fat_sec_per_clus;
	u16 fat_reserved;
	u8 fat_fats;
	u16 fat_dir_entries;
	u16 fat_sectors;
	u16 fat_fat_length;
	u32 fat_total_sect;
	u8 fat16_state;
	u32 fat16_vol_id;
	u32 fat32_length;
	u32 fat32_root_cluster;
	u16 fat32_info_sector;
	u8 fat32_state;
	u32 fat32_vol_id;
};

struct fat_floppy_defaults {
	unsigned int nr_sectors;
	unsigned int sec_per_clus;
	unsigned int dir_entries;
	unsigned int media;
	unsigned int fat_length;
};

enum {
	Opt_check_n = 0,
	Opt_check_r = 1,
	Opt_check_s = 2,
	Opt_uid___4 = 3,
	Opt_gid___5 = 4,
	Opt_umask = 5,
	Opt_dmask = 6,
	Opt_fmask = 7,
	Opt_allow_utime = 8,
	Opt_codepage = 9,
	Opt_usefree = 10,
	Opt_nocase = 11,
	Opt_quiet = 12,
	Opt_showexec = 13,
	Opt_debug___2 = 14,
	Opt_immutable = 15,
	Opt_dots = 16,
	Opt_nodots = 17,
	Opt_charset = 18,
	Opt_shortname_lower = 19,
	Opt_shortname_win95 = 20,
	Opt_shortname_winnt = 21,
	Opt_shortname_mixed = 22,
	Opt_utf8_no = 23,
	Opt_utf8_yes = 24,
	Opt_uni_xl_no = 25,
	Opt_uni_xl_yes = 26,
	Opt_nonumtail_no = 27,
	Opt_nonumtail_yes = 28,
	Opt_obsolete = 29,
	Opt_flush = 30,
	Opt_tz_utc = 31,
	Opt_rodir = 32,
	Opt_err_cont___2 = 33,
	Opt_err_panic___2 = 34,
	Opt_err_ro___2 = 35,
	Opt_discard___2 = 36,
	Opt_nfs = 37,
	Opt_time_offset = 38,
	Opt_nfs_stale_rw = 39,
	Opt_nfs_nostale_ro = 40,
	Opt_err___3 = 41,
	Opt_dos1xfloppy = 42,
};

struct inode___136;

struct dentry___136;

struct super_block___136;

struct iattr___136;

struct export_operations___13 {
	int (*encode_fh)(struct inode___136 *, __u32 *, int *, struct inode___136 *);
	struct dentry___136 * (*fh_to_dentry)(struct super_block___136 *, struct fid *, int, int);
	struct dentry___136 * (*fh_to_parent)(struct super_block___136 *, struct fid *, int, int);
	int (*get_name)(struct dentry___136 *, char *, struct dentry___136 *);
	struct dentry___136 * (*get_parent)(struct dentry___136 *);
	int (*commit_metadata)(struct inode___136 *);
	int (*get_uuid)(struct super_block___136 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___136 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___136 *, struct iomap *, int, struct iattr___136 *);
	u64 (*fetch_iversion)(struct inode___136 *);
	long unsigned int flags;
};

struct address_space_operations___136;

struct address_space___136 {
	struct inode___136 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___136 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___136;

struct file_operations___136;

struct inode___136 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___136 *i_op;
	struct super_block___136 *i_sb;
	struct address_space___136 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___136 *i_fop;
		void (*free_inode)(struct inode___136 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___136 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___41 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___136;

struct dentry___136 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___136 *d_parent;
	struct qstr d_name;
	struct inode___136 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___136 *d_op;
	struct super_block___136 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct quota_format_type___136;

struct mem_dqinfo___136 {
	struct quota_format_type___136 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___136;

struct quota_info___136 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___136 *files[3];
	struct mem_dqinfo___136 info[3];
	const struct quota_format_ops___136 *ops[3];
};

struct task_struct___143;

struct rcuwait___137 {
	struct task_struct___143 *task;
};

struct percpu_rw_semaphore___137 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___137 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___136 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___137 rw_sem[3];
};

struct file_system_type___136;

struct super_operations___136;

struct dquot_operations___136;

struct quotactl_ops___136;

struct super_block___136 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___136 *s_type;
	const struct super_operations___136 *s_op;
	const struct dquot_operations___136 *dq_op;
	const struct quotactl_ops___136 *s_qcop;
	const struct export_operations___13 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___136 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___136 s_dquot;
	struct sb_writers___136 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___136 *s_d_op;
	int cleancache_poolid;
	struct shrinker___51 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct file___136;

struct iattr___136 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___136 *ia_file;
};

struct module___125;

struct file_system_type___136 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___136 * (*mount)(struct file_system_type___136 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___136 *);
	struct module___125 *owner;
	struct file_system_type___136 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___136;

struct vm_area_struct___141;

struct file_lock___136;

struct page___141;

struct file_operations___136 {
	struct module___125 *owner;
	loff_t (*llseek)(struct file___136 *, loff_t, int);
	ssize_t (*read)(struct file___136 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___136 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___136 *, struct iov_iter___76 *);
	ssize_t (*write_iter)(struct kiocb___136 *, struct iov_iter___76 *);
	int (*iopoll)(struct kiocb___136 *, bool);
	int (*iterate)(struct file___136 *, struct dir_context *);
	int (*iterate_shared)(struct file___136 *, struct dir_context *);
	__poll_t (*poll)(struct file___136 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___136 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___136 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___136 *, struct vm_area_struct___141 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___136 *, struct file___136 *);
	int (*flush)(struct file___136 *, fl_owner_t);
	int (*release)(struct inode___136 *, struct file___136 *);
	int (*fsync)(struct file___136 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___136 *, int);
	int (*lock)(struct file___136 *, int, struct file_lock___136 *);
	ssize_t (*sendpage)(struct file___136 *, struct page___141 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___136 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___136 *, long unsigned int);
	int (*flock)(struct file___136 *, int, struct file_lock___136 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___136 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___136 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___136 *, long int, struct file_lock___136 **, void **);
	long int (*fallocate)(struct file___136 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___136 *);
	ssize_t (*copy_file_range)(struct file___136 *, loff_t, struct file___136 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___136 *, loff_t, struct file___136 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___136 *, loff_t, loff_t, int);
};

struct vmacache___141 {
	u64 seqnum;
	struct vm_area_struct___141 *vmas[4];
};

struct page_frag___141 {
	struct page___141 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___142;

struct pid___121;

struct nsproxy___127;

struct signal_struct___137;

struct vm_struct___123;

struct task_struct___143 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___143 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___142 *mm;
	struct mm_struct___142 *active_mm;
	struct vmacache___141 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___143 *real_parent;
	struct task_struct___143 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___143 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___121 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___127 *nsproxy;
	struct signal_struct___137 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___143 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___62 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___141 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___143 *oom_reaper_list;
	struct vm_struct___123 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___127;

struct kobj_type___127;

struct kernfs_node___127;

struct kobject___127 {
	const char *name;
	struct list_head entry;
	struct kobject___127 *parent;
	struct kset___127 *kset;
	struct kobj_type___127 *ktype;
	struct kernfs_node___127 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___124 {
	struct kobject___127 kobj;
	struct module___125 *mod;
	struct kobject___127 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___124 {
	struct module___125 *mod;
	struct latch_tree_node node;
};

struct module_layout___124 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___124 mtn;
};

struct module_attribute___124;

struct kernel_param___124;

struct module___125 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___124 mkobj;
	struct module_attribute___124 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___127 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___124 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___124 core_layout;
	struct module_layout___124 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___136;

struct path___136;

struct dentry_operations___136 {
	int (*d_revalidate)(struct dentry___136 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___136 *, unsigned int);
	int (*d_hash)(const struct dentry___136 *, struct qstr *);
	int (*d_compare)(const struct dentry___136 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___136 *);
	int (*d_init)(struct dentry___136 *);
	void (*d_release)(struct dentry___136 *);
	void (*d_prune)(struct dentry___136 *);
	void (*d_iput)(struct dentry___136 *, struct inode___136 *);
	char * (*d_dname)(struct dentry___136 *, char *, int);
	struct vfsmount___136 * (*d_automount)(struct path___136 *);
	int (*d_manage)(const struct path___136 *, bool);
	struct dentry___136 * (*d_real)(struct dentry___136 *, const struct inode___136 *);
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___136 {
	struct dentry___136 *mnt_root;
	struct super_block___136 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___136 {
	struct vfsmount___136 *mnt;
	struct dentry___136 *dentry;
};

struct pid_namespace___121;

struct upid___121 {
	int nr;
	struct pid_namespace___121 *ns;
};

struct pid_namespace___121 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___143 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___121 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___24 ns;
};

struct pid___121 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___121 numbers[1];
};

typedef struct page___141 *pgtable_t___141;

struct dev_pagemap___134;

struct page___141 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___136 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___33 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___141 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___141 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___142 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___134 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___134;

struct vm_area_struct___141 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___141 *vm_next;
	struct vm_area_struct___141 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___142 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___134 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___136 *vm_file;
	struct file___136 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___137 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___143 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___143 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___121 *pids[4];
	struct pid___121 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___142 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___141;

struct mm_struct___142 {
	struct {
		struct vm_area_struct___141 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___136 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___141 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___143 *owner;
		struct user_namespace *user_ns;
		struct file___136 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___127 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___121 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___123 {
	struct vm_struct___123 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___141 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___134;

struct dev_pagemap___134 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___134 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___121 {
	rwlock_t lock;
	struct pid___121 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___136 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___136 f_path;
	struct inode___136 *f_inode;
	const struct file_operations___136 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___121 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___136 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___134;

struct vm_operations_struct___134 {
	void (*open)(struct vm_area_struct___141 *);
	void (*close)(struct vm_area_struct___141 *);
	int (*may_split)(struct vm_area_struct___141 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___141 *);
	int (*mprotect)(struct vm_area_struct___141 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___134 *);
	vm_fault_t (*huge_fault)(struct vm_fault___134 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___134 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___141 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___134 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___134 *);
	int (*access)(struct vm_area_struct___141 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___141 *);
	int (*set_policy)(struct vm_area_struct___141 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___141 *, long unsigned int);
	struct page___141 * (*find_special_page)(struct vm_area_struct___141 *, long unsigned int);
};

struct core_thread___141 {
	struct task_struct___143 *task;
	struct core_thread___141 *next;
};

struct core_state___141 {
	atomic_t nr_threads;
	struct core_thread___141 dumper;
	struct completion startup;
};

struct vm_fault___134 {
	const struct {
		struct vm_area_struct___141 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___141 *cow_page;
	struct page___141 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___141 prealloc_pte;
};

struct buffer_head___11;

typedef void bh_end_io_t___11(struct buffer_head___11 *, int);

struct buffer_head___11 {
	long unsigned int b_state;
	struct buffer_head___11 *b_this_page;
	struct page___141 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___5 *b_bdev;
	bh_end_io_t___11 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___136 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___65;

struct kiocb___136 {
	struct file___136 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___136 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___65 *ki_waitq;
	};
};

struct dquot___136 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___136 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___136 {
	int qf_fmt_id;
	const struct quota_format_ops___136 *qf_ops;
	struct module___125 *qf_owner;
	struct quota_format_type___136 *qf_next;
};

struct quota_format_ops___136 {
	int (*check_quota_file)(struct super_block___136 *, int);
	int (*read_file_info)(struct super_block___136 *, int);
	int (*write_file_info)(struct super_block___136 *, int);
	int (*free_file_info)(struct super_block___136 *, int);
	int (*read_dqblk)(struct dquot___136 *);
	int (*commit_dqblk)(struct dquot___136 *);
	int (*release_dqblk)(struct dquot___136 *);
	int (*get_next_id)(struct super_block___136 *, struct kqid *);
};

struct dquot_operations___136 {
	int (*write_dquot)(struct dquot___136 *);
	struct dquot___136 * (*alloc_dquot)(struct super_block___136 *, int);
	void (*destroy_dquot)(struct dquot___136 *);
	int (*acquire_dquot)(struct dquot___136 *);
	int (*release_dquot)(struct dquot___136 *);
	int (*mark_dirty)(struct dquot___136 *);
	int (*write_info)(struct super_block___136 *, int);
	qsize_t * (*get_reserved_space)(struct inode___136 *);
	int (*get_projid)(struct inode___136 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___136 *, qsize_t *);
	int (*get_next_id)(struct super_block___136 *, struct kqid *);
};

struct quotactl_ops___136 {
	int (*quota_on)(struct super_block___136 *, int, int, const struct path___136 *);
	int (*quota_off)(struct super_block___136 *, int);
	int (*quota_enable)(struct super_block___136 *, unsigned int);
	int (*quota_disable)(struct super_block___136 *, unsigned int);
	int (*quota_sync)(struct super_block___136 *, int);
	int (*set_info)(struct super_block___136 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___136 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___136 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___136 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___136 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___136 *, unsigned int);
};

struct wait_page_queue___65 {
	struct page___141 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___65;

struct address_space_operations___136 {
	int (*writepage)(struct page___141 *, struct writeback_control___3 *);
	int (*readpage)(struct file___136 *, struct page___141 *);
	int (*writepages)(struct address_space___136 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___141 *);
	int (*readpages)(struct file___136 *, struct address_space___136 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___65 *);
	int (*write_begin)(struct file___136 *, struct address_space___136 *, loff_t, unsigned int, unsigned int, struct page___141 **, void **);
	int (*write_end)(struct file___136 *, struct address_space___136 *, loff_t, unsigned int, unsigned int, struct page___141 *, void *);
	sector_t (*bmap)(struct address_space___136 *, sector_t);
	void (*invalidatepage)(struct page___141 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___141 *, gfp_t);
	void (*freepage)(struct page___141 *);
	ssize_t (*direct_IO)(struct kiocb___136 *, struct iov_iter___76 *);
	int (*migratepage)(struct address_space___136 *, struct page___141 *, struct page___141 *, enum migrate_mode);
	bool (*isolate_page)(struct page___141 *, isolate_mode_t);
	void (*putback_page)(struct page___141 *);
	int (*launder_page)(struct page___141 *);
	int (*is_partially_uptodate)(struct page___141 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___141 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___136 *, struct page___141 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___136 *, sector_t *);
	void (*swap_deactivate)(struct file___136 *);
};

struct readahead_control___65 {
	struct file___136 *file;
	struct address_space___136 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___136 {
	struct dentry___136 * (*lookup)(struct inode___136 *, struct dentry___136 *, unsigned int);
	const char * (*get_link)(struct dentry___136 *, struct inode___136 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___136 *, int);
	struct posix_acl * (*get_acl)(struct inode___136 *, int, bool);
	int (*readlink)(struct dentry___136 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___136 *, struct dentry___136 *, umode_t, bool);
	int (*link)(struct dentry___136 *, struct inode___136 *, struct dentry___136 *);
	int (*unlink)(struct inode___136 *, struct dentry___136 *);
	int (*symlink)(struct user_namespace *, struct inode___136 *, struct dentry___136 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___136 *, struct dentry___136 *, umode_t);
	int (*rmdir)(struct inode___136 *, struct dentry___136 *);
	int (*mknod)(struct user_namespace *, struct inode___136 *, struct dentry___136 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___136 *, struct dentry___136 *, struct inode___136 *, struct dentry___136 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___136 *, struct iattr___136 *);
	int (*getattr)(struct user_namespace *, const struct path___136 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___136 *, char *, size_t);
	int (*fiemap)(struct inode___136 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___136 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___136 *, struct dentry___136 *, struct file___136 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___136 *, struct dentry___136 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___136 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___136 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___136 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___136 {
	void (*fl_copy_lock)(struct file_lock___136 *, struct file_lock___136 *);
	void (*fl_release_private)(struct file_lock___136 *);
};

struct fasync_struct___136;

struct lock_manager_operations___136;

struct file_lock___136 {
	struct file_lock___136 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___136 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___136 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___136 *fl_ops;
	const struct lock_manager_operations___136 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___136 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___136 *);
	int (*lm_grant)(struct file_lock___136 *, int);
	bool (*lm_break)(struct file_lock___136 *);
	int (*lm_change)(struct file_lock___136 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___136 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___136 *);
};

struct fasync_struct___136 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___136 *fa_next;
	struct file___136 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___136 {
	struct inode___136 * (*alloc_inode)(struct super_block___136 *);
	void (*destroy_inode)(struct inode___136 *);
	void (*free_inode)(struct inode___136 *);
	void (*dirty_inode)(struct inode___136 *, int);
	int (*write_inode)(struct inode___136 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___136 *);
	void (*evict_inode)(struct inode___136 *);
	void (*put_super)(struct super_block___136 *);
	int (*sync_fs)(struct super_block___136 *, int);
	int (*freeze_super)(struct super_block___136 *);
	int (*freeze_fs)(struct super_block___136 *);
	int (*thaw_super)(struct super_block___136 *);
	int (*unfreeze_fs)(struct super_block___136 *);
	int (*statfs)(struct dentry___136 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___136 *, int *, char *);
	void (*umount_begin)(struct super_block___136 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___136 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___136 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___136 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___136 *);
	ssize_t (*quota_read)(struct super_block___136 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___136 *, int, const char *, size_t, loff_t);
	struct dquot___136 ** (*get_dquots)(struct inode___136 *);
	long int (*nr_cached_objects)(struct super_block___136 *, struct shrink_control___51 *);
	long int (*free_cached_objects)(struct super_block___136 *, struct shrink_control___51 *);
	struct file___136 * (*real_loop)(struct file___136 *);
};

struct dev_pagemap_ops___134 {
	void (*page_free)(struct page___141 *);
	void (*kill)(struct dev_pagemap___134 *);
	void (*cleanup)(struct dev_pagemap___134 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___134 *);
};

struct kernfs_root___127;

struct kernfs_elem_dir___127 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___127 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___127;

struct kernfs_root___127 {
	struct kernfs_node___127 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___127 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___127 {
	struct kernfs_node___127 *target_kn;
};

struct kernfs_ops___127;

struct kernfs_elem_attr___127 {
	const struct kernfs_ops___127 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___127 *notify_next;
};

struct kernfs_node___127 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___127 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___127 dir;
		struct kernfs_elem_symlink___127 symlink;
		struct kernfs_elem_attr___127 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___127;

struct kernfs_ops___127 {
	int (*open)(struct kernfs_open_file___127 *);
	void (*release)(struct kernfs_open_file___127 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___127 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___127 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___127 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___127 *, struct vm_area_struct___141 *);
};

struct kernfs_syscall_ops___127 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___127 *);
	int (*mkdir)(struct kernfs_node___127 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___127 *);
	int (*rename)(struct kernfs_node___127 *, struct kernfs_node___127 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___127 *, struct kernfs_root___127 *);
};

struct kernfs_open_file___127 {
	struct kernfs_node___127 *kn;
	struct file___136 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___134 *vm_ops;
};

struct bin_attribute___127;

struct attribute_group___127 {
	const char *name;
	umode_t (*is_visible)(struct kobject___127 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___127 *, struct bin_attribute___127 *, int);
	struct attribute **attrs;
	struct bin_attribute___127 **bin_attrs;
};

struct bin_attribute___127 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___136 * (*f_mapping)();
	ssize_t (*read)(struct file___136 *, struct kobject___127 *, struct bin_attribute___127 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___136 *, struct kobject___127 *, struct bin_attribute___127 *, char *, loff_t, size_t);
	int (*mmap)(struct file___136 *, struct kobject___127 *, struct bin_attribute___127 *, struct vm_area_struct___141 *);
};

struct sysfs_ops___127 {
	ssize_t (*show)(struct kobject___127 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___127 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___127;

struct kset___127 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___127 kobj;
	const struct kset_uevent_ops___127 *uevent_ops;
};

struct kobj_type___127 {
	void (*release)(struct kobject___127 *);
	const struct sysfs_ops___127 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___127 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___127 *);
	const void * (*namespace)(struct kobject___127 *);
	void (*get_ownership)(struct kobject___127 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___127 {
	int (* const filter)(struct kset___127 *, struct kobject___127 *);
	const char * (* const name)(struct kset___127 *, struct kobject___127 *);
	int (* const uevent)(struct kset___127 *, struct kobject___127 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___124 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___124 *);
	int (*get)(char *, const struct kernel_param___124 *);
	void (*free)(void *);
};

struct kparam_array___124;

struct kernel_param___124 {
	const char *name;
	struct module___125 *mod;
	const struct kernel_param_ops___124 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___124 *arr;
	};
};

struct kparam_array___124 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___124 *ops;
	void *elem;
};

struct module_attribute___124 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___124 *, struct module_kobject___124 *, char *);
	ssize_t (*store)(struct module_attribute___124 *, struct module_kobject___124 *, const char *, size_t);
	void (*setup)(struct module___125 *, const char *);
	int (*test)(struct module___125 *);
	void (*free)(struct module___125 *);
};

struct nls_table___3 {
	const char *charset;
	const char *alias;
	int (*uni2char)(wchar_t, unsigned char *, int);
	int (*char2uni)(const unsigned char *, int, wchar_t *);
	const unsigned char *charset2lower;
	const unsigned char *charset2upper;
	struct module___125 *owner;
	struct nls_table___3 *next;
};

struct msdos_sb_info___3 {
	short unsigned int sec_per_clus;
	short unsigned int cluster_bits;
	unsigned int cluster_size;
	unsigned char fats;
	unsigned char fat_bits;
	short unsigned int fat_start;
	long unsigned int fat_length;
	long unsigned int dir_start;
	short unsigned int dir_entries;
	long unsigned int data_start;
	long unsigned int max_cluster;
	long unsigned int root_cluster;
	long unsigned int fsinfo_sector;
	struct mutex fat_lock;
	struct mutex nfs_build_inode_lock;
	struct mutex s_lock;
	unsigned int prev_free;
	unsigned int free_clusters;
	unsigned int free_clus_valid;
	struct fat_mount_options options;
	struct nls_table___3 *nls_disk;
	struct nls_table___3 *nls_io;
	const void *dir_ops;
	int dir_per_block;
	int dir_per_block_bits;
	unsigned int vol_id;
	int fatent_shift;
	const struct fatent_operations *fatent_ops;
	struct inode___136 *fat_inode;
	struct inode___136 *fsinfo_inode;
	struct ratelimit_state ratelimit;
	spinlock_t inode_hash_lock;
	struct hlist_head inode_hashtable[256];
	spinlock_t dir_hash_lock;
	struct hlist_head dir_hashtable[256];
	unsigned int dirty;
	struct callback_head rcu;
};

struct msdos_inode_info___3 {
	spinlock_t cache_lru_lock;
	struct list_head cache_lru;
	int nr_caches;
	unsigned int cache_valid_id;
	loff_t mmu_private;
	int i_start;
	int i_logstart;
	int i_attrs;
	loff_t i_pos;
	struct hlist_node i_fat_hash;
	struct hlist_node i_dir_hash;
	struct rw_semaphore truncate_lock;
	struct inode___136 vfs_inode;
};

struct fat_slot_info___2 {
	loff_t i_pos;
	loff_t slot_off;
	int nr_slots;
	struct msdos_dir_entry *de;
	struct buffer_head___11 *bh;
};

struct fat_fid {
	u32 i_gen;
	u32 i_pos_low;
	u16 i_pos_hi;
	u16 parent_i_pos_hi;
	u32 parent_i_pos_low;
	u32 parent_i_gen;
};

struct shortname_info {
	unsigned char lower: 1;
	unsigned char upper: 1;
	unsigned char valid: 1;
};

struct ecryptfs_mount_crypt_stat;

struct ecryptfs_crypt_stat {
	u32 flags;
	unsigned int file_version;
	size_t iv_bytes;
	size_t metadata_size;
	size_t extent_size;
	size_t key_size;
	size_t extent_shift;
	unsigned int extent_mask;
	struct ecryptfs_mount_crypt_stat *mount_crypt_stat;
	struct crypto_skcipher___2 *tfm;
	struct crypto_shash___6 *hash_tfm;
	unsigned char cipher[32];
	unsigned char key[64];
	unsigned char root_iv[16];
	struct list_head keysig_list;
	struct mutex keysig_list_mutex;
	struct mutex cs_tfm_mutex;
	struct mutex cs_mutex;
};

struct ecryptfs_mount_crypt_stat {
	u32 flags;
	struct list_head global_auth_tok_list;
	struct mutex global_auth_tok_list_mutex;
	size_t global_default_cipher_key_size;
	size_t global_default_fn_cipher_key_bytes;
	unsigned char global_default_cipher_name[32];
	unsigned char global_default_fn_cipher_name[32];
	char global_default_fnek_sig[17];
};

struct ecryptfs_inode_info {
	struct inode___134 vfs_inode;
	struct inode___134 *wii_inode;
	struct mutex lower_file_mutex;
	atomic_t lower_file_count;
	struct file___134 *lower_file;
	struct ecryptfs_crypt_stat crypt_stat;
};

struct ecryptfs_dentry_info {
	struct path___134 lower_path;
	struct callback_head rcu;
};

struct crypto_alg___11;

struct crypto_tfm___11 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___11 *);
	struct crypto_alg___11 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___11 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___11 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___11 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___11 *, u8 *, const u8 *);
};

struct compress_alg___11 {
	int (*coa_compress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___11 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___11 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___11 cipher;
		struct compress_alg___11 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___11 *);
	void (*cra_exit)(struct crypto_tfm___11 *);
	void (*cra_destroy)(struct crypto_alg___11 *);
	struct module___113 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_skcipher___3 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___11 base;
};

struct ecryptfs_crypt_stat___2 {
	u32 flags;
	unsigned int file_version;
	size_t iv_bytes;
	size_t metadata_size;
	size_t extent_size;
	size_t key_size;
	size_t extent_shift;
	unsigned int extent_mask;
	struct ecryptfs_mount_crypt_stat *mount_crypt_stat;
	struct crypto_skcipher___3 *tfm;
	struct crypto_shash___6 *hash_tfm;
	unsigned char cipher[32];
	unsigned char key[64];
	unsigned char root_iv[16];
	struct list_head keysig_list;
	struct mutex keysig_list_mutex;
	struct mutex cs_tfm_mutex;
	struct mutex cs_mutex;
};

struct ecryptfs_inode_info___2 {
	struct inode___123 vfs_inode;
	struct inode___123 *wii_inode;
	struct mutex lower_file_mutex;
	atomic_t lower_file_count;
	struct file___123 *lower_file;
	struct ecryptfs_crypt_stat___2 crypt_stat;
};

struct ecryptfs_dentry_info___2 {
	struct path___123 lower_path;
	struct callback_head rcu;
};

struct ecryptfs_sb_info {
	struct super_block___123 *wsi_sb;
	struct ecryptfs_mount_crypt_stat mount_crypt_stat;
};

struct ecryptfs_file_info {
	struct file___123 *wfi_file;
	struct ecryptfs_crypt_stat___2 *crypt_stat;
};

struct ecryptfs_getdents_callback {
	struct dir_context ctx;
	struct dir_context *caller;
	struct super_block___123 *sb;
	int filldir_called;
	int entries_written;
};

struct renamedata___2 {
	struct user_namespace___19 *old_mnt_userns;
	struct inode___133 *old_dir;
	struct dentry___133 *old_dentry;
	struct user_namespace___19 *new_mnt_userns;
	struct inode___133 *new_dir;
	struct dentry___133 *new_dentry;
	struct inode___133 **delegated_inode;
	unsigned int flags;
};

struct crypto_skcipher___4 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___7 base;
};

struct ecryptfs_crypt_stat___3 {
	u32 flags;
	unsigned int file_version;
	size_t iv_bytes;
	size_t metadata_size;
	size_t extent_size;
	size_t key_size;
	size_t extent_shift;
	unsigned int extent_mask;
	struct ecryptfs_mount_crypt_stat *mount_crypt_stat;
	struct crypto_skcipher___4 *tfm;
	struct crypto_shash___6 *hash_tfm;
	unsigned char cipher[32];
	unsigned char key[64];
	unsigned char root_iv[16];
	struct list_head keysig_list;
	struct mutex keysig_list_mutex;
	struct mutex cs_tfm_mutex;
	struct mutex cs_mutex;
};

struct ecryptfs_inode_info___3 {
	struct inode___133 vfs_inode;
	struct inode___133 *wii_inode;
	struct mutex lower_file_mutex;
	atomic_t lower_file_count;
	struct file___133 *lower_file;
	struct ecryptfs_crypt_stat___3 crypt_stat;
};

struct ecryptfs_dentry_info___3 {
	struct path___133 lower_path;
	struct callback_head rcu;
};

struct ecryptfs_sb_info___2 {
	struct super_block___133 *wsi_sb;
	struct ecryptfs_mount_crypt_stat mount_crypt_stat;
};

struct ecryptfs_file_info___2 {
	struct file___133 *wfi_file;
	struct ecryptfs_crypt_stat___3 *crypt_stat;
};

struct dentry___137;

struct super_block___137;

struct module___126;

struct file_system_type___137 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___137 * (*mount)(struct file_system_type___137 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___137 *);
	struct module___126 *owner;
	struct file_system_type___137 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___137;

struct kiocb___137;

struct iov_iter___77;

struct vm_area_struct___142;

struct inode___137;

struct file_lock___137;

struct page___142;

struct pipe_inode_info___42;

struct seq_file___118;

struct file_operations___137 {
	struct module___126 *owner;
	loff_t (*llseek)(struct file___137 *, loff_t, int);
	ssize_t (*read)(struct file___137 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___137 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___137 *, struct iov_iter___77 *);
	ssize_t (*write_iter)(struct kiocb___137 *, struct iov_iter___77 *);
	int (*iopoll)(struct kiocb___137 *, bool);
	int (*iterate)(struct file___137 *, struct dir_context *);
	int (*iterate_shared)(struct file___137 *, struct dir_context *);
	__poll_t (*poll)(struct file___137 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___137 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___137 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___137 *, struct vm_area_struct___142 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___137 *, struct file___137 *);
	int (*flush)(struct file___137 *, fl_owner_t);
	int (*release)(struct inode___137 *, struct file___137 *);
	int (*fsync)(struct file___137 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___137 *, int);
	int (*lock)(struct file___137 *, int, struct file_lock___137 *);
	ssize_t (*sendpage)(struct file___137 *, struct page___142 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___137 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___137 *, long unsigned int);
	int (*flock)(struct file___137 *, int, struct file_lock___137 *);
	ssize_t (*splice_write)(struct pipe_inode_info___42 *, struct file___137 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___137 *, loff_t *, struct pipe_inode_info___42 *, size_t, unsigned int);
	int (*setlease)(struct file___137 *, long int, struct file_lock___137 **, void **);
	long int (*fallocate)(struct file___137 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___118 *, struct file___137 *);
	ssize_t (*copy_file_range)(struct file___137 *, loff_t, struct file___137 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___137 *, loff_t, struct file___137 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___137 *, loff_t, loff_t, int);
};

struct vmacache___142 {
	u64 seqnum;
	struct vm_area_struct___142 *vmas[4];
};

struct page_frag___142 {
	struct page___142 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___143;

struct pid___122;

struct nsproxy___128;

struct signal_struct___138;

struct bio_list___63;

struct backing_dev_info___60;

struct io_context___63;

struct css_set___97;

struct request_queue___63;

struct vm_struct___124;

struct task_struct___144 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___144 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___143 *mm;
	struct mm_struct___143 *active_mm;
	struct vmacache___142 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___144 *real_parent;
	struct task_struct___144 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___144 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___122 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___128 *nsproxy;
	struct signal_struct___138 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___144 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___63 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___60 *backing_dev_info;
	struct io_context___63 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___97 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___42 *splice_pipe;
	struct page_frag___142 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___63 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___144 *oom_reaper_list;
	struct vm_struct___124 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___128;

struct kobj_type___128;

struct kernfs_node___128;

struct kobject___128 {
	const char *name;
	struct list_head entry;
	struct kobject___128 *parent;
	struct kset___128 *kset;
	struct kobj_type___128 *ktype;
	struct kernfs_node___128 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___125 {
	struct kobject___128 kobj;
	struct module___126 *mod;
	struct kobject___128 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___125 {
	struct module___126 *mod;
	struct latch_tree_node node;
};

struct module_layout___125 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___125 mtn;
};

struct module_attribute___125;

struct kernel_param___125;

struct module___126 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___125 mkobj;
	struct module_attribute___125 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___128 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___125 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___125 core_layout;
	struct module_layout___125 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___137;

struct dentry___137 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___137 *d_parent;
	struct qstr d_name;
	struct inode___137 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___137 *d_op;
	struct super_block___137 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___137;

struct address_space___137 {
	struct inode___137 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___137 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___137;

struct bdi_writeback___60;

struct inode___137 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___137 *i_op;
	struct super_block___137 *i_sb;
	struct address_space___137 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___60 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___137 *i_fop;
		void (*free_inode)(struct inode___137 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___137 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___42 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___137;

struct path___137;

struct dentry_operations___137 {
	int (*d_revalidate)(struct dentry___137 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___137 *, unsigned int);
	int (*d_hash)(const struct dentry___137 *, struct qstr *);
	int (*d_compare)(const struct dentry___137 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___137 *);
	int (*d_init)(struct dentry___137 *);
	void (*d_release)(struct dentry___137 *);
	void (*d_prune)(struct dentry___137 *);
	void (*d_iput)(struct dentry___137 *, struct inode___137 *);
	char * (*d_dname)(struct dentry___137 *, char *, int);
	struct vfsmount___137 * (*d_automount)(struct path___137 *);
	int (*d_manage)(const struct path___137 *, bool);
	struct dentry___137 * (*d_real)(struct dentry___137 *, const struct inode___137 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___137;

struct mem_dqinfo___137 {
	struct quota_format_type___137 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___137;

struct quota_info___137 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___137 *files[3];
	struct mem_dqinfo___137 info[3];
	const struct quota_format_ops___137 *ops[3];
};

struct rcuwait___138 {
	struct task_struct___144 *task;
};

struct percpu_rw_semaphore___138 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___138 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___137 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___138 rw_sem[3];
};

struct super_operations___137;

struct dquot_operations___137;

struct quotactl_ops___137;

struct block_device___64;

struct super_block___137 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___137 *s_type;
	const struct super_operations___137 *s_op;
	const struct dquot_operations___137 *dq_op;
	const struct quotactl_ops___137 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___137 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___64 *s_bdev;
	struct backing_dev_info___60 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___137 s_dquot;
	struct sb_writers___137 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___137 *s_d_op;
	int cleancache_poolid;
	struct shrinker___51 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___137 {
	struct dentry___137 *mnt_root;
	struct super_block___137 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___137 {
	struct vfsmount___137 *mnt;
	struct dentry___137 *dentry;
};

struct fown_struct___122 {
	rwlock_t lock;
	struct pid___122 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___137 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___137 f_path;
	struct inode___137 *f_inode;
	const struct file_operations___137 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___122 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___137 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct pid_namespace___122;

struct upid___122 {
	int nr;
	struct pid_namespace___122 *ns;
};

struct pid_namespace___122 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___144 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___122 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___122 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___122 numbers[1];
};

typedef struct page___142 *pgtable_t___142;

struct page_pool___34;

struct dev_pagemap___135;

struct page___142 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___137 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___142 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___142 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___143 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___135 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___135;

struct vm_area_struct___142 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___142 *vm_next;
	struct vm_area_struct___142 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___143 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___135 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___137 *vm_file;
	struct file___137 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___138 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___144 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___144 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___122 *pids[4];
	struct pid___122 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___143 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___142;

struct mm_struct___143 {
	struct {
		struct vm_area_struct___142 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___137 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___142 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___144 *owner;
		struct user_namespace___19 *user_ns;
		struct file___137 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___97;

struct nsproxy___128 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___122 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___97 *cgroup_ns;
};

struct bio___63;

struct bio_list___63 {
	struct bio___63 *head;
	struct bio___63 *tail;
};

struct cgroup_subsys_state___97;

struct bdi_writeback___60 {
	struct backing_dev_info___60 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___97 *memcg_css;
	struct cgroup_subsys_state___97 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___101;

struct backing_dev_info___60 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___60 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___101 *dev;
	char dev_name[64];
	struct device___101 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___137 *debug_dir;
};

struct io_cq___63;

struct io_context___63 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___63 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___97;

struct css_set___97 {
	struct cgroup_subsys_state___97 *subsys[14];
	refcount_t refcount;
	struct css_set___97 *dom_cset;
	struct cgroup___97 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___97 *mg_src_cgrp;
	struct cgroup___97 *mg_dst_cgrp;
	struct css_set___97 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___137;

struct pipe_buffer___42;

struct pipe_inode_info___42 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___142 *tmp_page;
	struct fasync_struct___137 *fasync_readers;
	struct fasync_struct___137 *fasync_writers;
	struct pipe_buffer___42 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___63;

struct blk_integrity___63 {
	const struct blk_integrity_profile___63 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___63 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___63 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___63;

struct elevator_queue___63;

struct blk_mq_ops___60;

struct blk_mq_hw_ctx___60;

struct gendisk___63;

struct blkcg_gq___60;

struct blk_mq_tag_set___60;

struct request_queue___63 {
	struct request___63 *last_merge;
	struct elevator_queue___63 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___60 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___60 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___63 *disk;
	struct kobject___128 kobj;
	struct kobject___128 *mq_kobj;
	struct blk_integrity___63 integrity;
	struct device___101 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___60 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___60 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___63 bio_split;
	struct dentry___137 *debugfs_dir;
	struct dentry___137 *sched_debugfs_dir;
	struct dentry___137 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___124 {
	struct vm_struct___124 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___142 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct page_pool_params___34 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___101 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___34 {
	u32 count;
	struct page___142 *cache[128];
};

struct page_pool___34 {
	struct page_pool_params___34 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___142 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___34 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___135;

struct dev_pagemap___135 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___135 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___135;

struct vm_operations_struct___135 {
	void (*open)(struct vm_area_struct___142 *);
	void (*close)(struct vm_area_struct___142 *);
	int (*may_split)(struct vm_area_struct___142 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___142 *);
	int (*mprotect)(struct vm_area_struct___142 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___135 *);
	vm_fault_t (*huge_fault)(struct vm_fault___135 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___135 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___142 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___135 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___135 *);
	int (*access)(struct vm_area_struct___142 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___142 *);
	int (*set_policy)(struct vm_area_struct___142 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___142 *, long unsigned int);
	struct page___142 * (*find_special_page)(struct vm_area_struct___142 *, long unsigned int);
};

struct core_thread___142 {
	struct task_struct___144 *task;
	struct core_thread___142 *next;
};

struct core_state___142 {
	atomic_t nr_threads;
	struct core_thread___142 dumper;
	struct completion startup;
};

struct vm_fault___135 {
	const struct {
		struct vm_area_struct___142 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___142 *cow_page;
	struct page___142 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___142 prealloc_pte;
};

struct cgroup_subsys___97;

struct cgroup_subsys_state___97 {
	struct cgroup___97 *cgroup;
	struct cgroup_subsys___97 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___97 *parent;
};

struct cgroup_file___97 {
	struct kernfs_node___128 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___97 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___144 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___97;

struct cgroup_rstat_cpu___97;

struct cgroup___97 {
	struct cgroup_subsys_state___97 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___128 *kn;
	struct cgroup_file___97 procs_file;
	struct cgroup_file___97 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___97 *subsys[14];
	struct cgroup_root___97 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___97 *dom_cgrp;
	struct cgroup___97 *old_dom_cgrp;
	struct cgroup_rstat_cpu___97 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___97 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___63 {
	struct request_queue___63 *q;
	struct io_context___63 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___66;

struct kiocb___137 {
	struct file___137 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___137 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___66 *ki_waitq;
	};
};

struct iattr___137 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___137 *ia_file;
};

struct dquot___137 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___137 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___137 {
	int qf_fmt_id;
	const struct quota_format_ops___137 *qf_ops;
	struct module___126 *qf_owner;
	struct quota_format_type___137 *qf_next;
};

struct quota_format_ops___137 {
	int (*check_quota_file)(struct super_block___137 *, int);
	int (*read_file_info)(struct super_block___137 *, int);
	int (*write_file_info)(struct super_block___137 *, int);
	int (*free_file_info)(struct super_block___137 *, int);
	int (*read_dqblk)(struct dquot___137 *);
	int (*commit_dqblk)(struct dquot___137 *);
	int (*release_dqblk)(struct dquot___137 *);
	int (*get_next_id)(struct super_block___137 *, struct kqid *);
};

struct dquot_operations___137 {
	int (*write_dquot)(struct dquot___137 *);
	struct dquot___137 * (*alloc_dquot)(struct super_block___137 *, int);
	void (*destroy_dquot)(struct dquot___137 *);
	int (*acquire_dquot)(struct dquot___137 *);
	int (*release_dquot)(struct dquot___137 *);
	int (*mark_dirty)(struct dquot___137 *);
	int (*write_info)(struct super_block___137 *, int);
	qsize_t * (*get_reserved_space)(struct inode___137 *);
	int (*get_projid)(struct inode___137 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___137 *, qsize_t *);
	int (*get_next_id)(struct super_block___137 *, struct kqid *);
};

struct quotactl_ops___137 {
	int (*quota_on)(struct super_block___137 *, int, int, const struct path___137 *);
	int (*quota_off)(struct super_block___137 *, int);
	int (*quota_enable)(struct super_block___137 *, unsigned int);
	int (*quota_disable)(struct super_block___137 *, unsigned int);
	int (*quota_sync)(struct super_block___137 *, int);
	int (*set_info)(struct super_block___137 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___137 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___137 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___137 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___137 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___137 *, unsigned int);
};

struct wait_page_queue___66 {
	struct page___142 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___60;

struct readahead_control___66;

struct address_space_operations___137 {
	int (*writepage)(struct page___142 *, struct writeback_control___60 *);
	int (*readpage)(struct file___137 *, struct page___142 *);
	int (*writepages)(struct address_space___137 *, struct writeback_control___60 *);
	int (*set_page_dirty)(struct page___142 *);
	int (*readpages)(struct file___137 *, struct address_space___137 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___66 *);
	int (*write_begin)(struct file___137 *, struct address_space___137 *, loff_t, unsigned int, unsigned int, struct page___142 **, void **);
	int (*write_end)(struct file___137 *, struct address_space___137 *, loff_t, unsigned int, unsigned int, struct page___142 *, void *);
	sector_t (*bmap)(struct address_space___137 *, sector_t);
	void (*invalidatepage)(struct page___142 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___142 *, gfp_t);
	void (*freepage)(struct page___142 *);
	ssize_t (*direct_IO)(struct kiocb___137 *, struct iov_iter___77 *);
	int (*migratepage)(struct address_space___137 *, struct page___142 *, struct page___142 *, enum migrate_mode);
	bool (*isolate_page)(struct page___142 *, isolate_mode_t);
	void (*putback_page)(struct page___142 *);
	int (*launder_page)(struct page___142 *);
	int (*is_partially_uptodate)(struct page___142 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___142 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___137 *, struct page___142 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___137 *, sector_t *);
	void (*swap_deactivate)(struct file___137 *);
};

struct writeback_control___60 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___60 *wb;
	struct inode___137 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___66 {
	struct file___137 *file;
	struct address_space___137 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___75;

struct iov_iter___77 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___75 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___42 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___137 {
	struct dentry___137 * (*lookup)(struct inode___137 *, struct dentry___137 *, unsigned int);
	const char * (*get_link)(struct dentry___137 *, struct inode___137 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___137 *, int);
	struct posix_acl * (*get_acl)(struct inode___137 *, int, bool);
	int (*readlink)(struct dentry___137 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___137 *, struct dentry___137 *, umode_t, bool);
	int (*link)(struct dentry___137 *, struct inode___137 *, struct dentry___137 *);
	int (*unlink)(struct inode___137 *, struct dentry___137 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___137 *, struct dentry___137 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___137 *, struct dentry___137 *, umode_t);
	int (*rmdir)(struct inode___137 *, struct dentry___137 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___137 *, struct dentry___137 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___137 *, struct dentry___137 *, struct inode___137 *, struct dentry___137 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___137 *, struct iattr___137 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___137 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___137 *, char *, size_t);
	int (*fiemap)(struct inode___137 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___137 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___137 *, struct dentry___137 *, struct file___137 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___137 *, struct dentry___137 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___137 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___137 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___137 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___137 {
	void (*fl_copy_lock)(struct file_lock___137 *, struct file_lock___137 *);
	void (*fl_release_private)(struct file_lock___137 *);
};

struct lock_manager_operations___137;

struct file_lock___137 {
	struct file_lock___137 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___137 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___137 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___137 *fl_ops;
	const struct lock_manager_operations___137 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___137 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___137 *);
	int (*lm_grant)(struct file_lock___137 *, int);
	bool (*lm_break)(struct file_lock___137 *);
	int (*lm_change)(struct file_lock___137 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___137 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___137 *);
};

struct fasync_struct___137 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___137 *fa_next;
	struct file___137 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___137 {
	struct inode___137 * (*alloc_inode)(struct super_block___137 *);
	void (*destroy_inode)(struct inode___137 *);
	void (*free_inode)(struct inode___137 *);
	void (*dirty_inode)(struct inode___137 *, int);
	int (*write_inode)(struct inode___137 *, struct writeback_control___60 *);
	int (*drop_inode)(struct inode___137 *);
	void (*evict_inode)(struct inode___137 *);
	void (*put_super)(struct super_block___137 *);
	int (*sync_fs)(struct super_block___137 *, int);
	int (*freeze_super)(struct super_block___137 *);
	int (*freeze_fs)(struct super_block___137 *);
	int (*thaw_super)(struct super_block___137 *);
	int (*unfreeze_fs)(struct super_block___137 *);
	int (*statfs)(struct dentry___137 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___137 *, int *, char *);
	void (*umount_begin)(struct super_block___137 *);
	int (*show_options)(struct seq_file___118 *, struct dentry___137 *);
	int (*show_devname)(struct seq_file___118 *, struct dentry___137 *);
	int (*show_path)(struct seq_file___118 *, struct dentry___137 *);
	int (*show_stats)(struct seq_file___118 *, struct dentry___137 *);
	ssize_t (*quota_read)(struct super_block___137 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___137 *, int, const char *, size_t, loff_t);
	struct dquot___137 ** (*get_dquots)(struct inode___137 *);
	long int (*nr_cached_objects)(struct super_block___137 *, struct shrink_control___51 *);
	long int (*free_cached_objects)(struct super_block___137 *, struct shrink_control___51 *);
	struct file___137 * (*real_loop)(struct file___137 *);
};

struct wakeup_source___101;

struct dev_pm_info___101 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___101 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___101 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___101;

struct bus_type___101;

struct device_driver___101;

struct dev_pm_domain___101;

struct fwnode_handle___101;

struct class___101;

struct attribute_group___128;

struct device___101 {
	struct kobject___128 kobj;
	struct device___101 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___101 *type;
	struct bus_type___101 *bus;
	struct device_driver___101 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___101 power;
	struct dev_pm_domain___101 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___101 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___101 *class;
	const struct attribute_group___128 **groups;
	void (*release)(struct device___101 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___64 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___137 *bd_inode;
	struct super_block___137 *bd_super;
	void *bd_claiming;
	struct device___101 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___128 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___63 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___137 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___118;

struct seq_file___118 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___118 *op;
	int poll_event;
	const struct file___137 *file;
	void *private;
};

typedef void bio_end_io_t___63(struct bio___63 *);

struct bio_vec___75 {
	struct page___142 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___63;

struct bio___63 {
	struct bio___63 *bi_next;
	struct block_device___64 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___63 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___60 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___63 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___75 *bi_io_vec;
	struct bio_set___63 *bi_pool;
	struct bio_vec___75 bi_inline_vecs[0];
};

struct kernfs_root___128;

struct kernfs_elem_dir___128 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___128 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___128;

struct kernfs_root___128 {
	struct kernfs_node___128 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___128 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___128 {
	struct kernfs_node___128 *target_kn;
};

struct kernfs_ops___128;

struct kernfs_elem_attr___128 {
	const struct kernfs_ops___128 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___128 *notify_next;
};

struct kernfs_node___128 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___128 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___128 dir;
		struct kernfs_elem_symlink___128 symlink;
		struct kernfs_elem_attr___128 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___128;

struct kernfs_ops___128 {
	int (*open)(struct kernfs_open_file___128 *);
	void (*release)(struct kernfs_open_file___128 *);
	int (*seq_show)(struct seq_file___118 *, void *);
	void * (*seq_start)(struct seq_file___118 *, loff_t *);
	void * (*seq_next)(struct seq_file___118 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___118 *, void *);
	ssize_t (*read)(struct kernfs_open_file___128 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___128 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___128 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___128 *, struct vm_area_struct___142 *);
};

struct kernfs_syscall_ops___128 {
	int (*show_options)(struct seq_file___118 *, struct kernfs_root___128 *);
	int (*mkdir)(struct kernfs_node___128 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___128 *);
	int (*rename)(struct kernfs_node___128 *, struct kernfs_node___128 *, const char *);
	int (*show_path)(struct seq_file___118 *, struct kernfs_node___128 *, struct kernfs_root___128 *);
};

struct kernfs_open_file___128 {
	struct kernfs_node___128 *kn;
	struct file___137 *file;
	struct seq_file___118 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___135 *vm_ops;
};

struct bin_attribute___128;

struct attribute_group___128 {
	const char *name;
	umode_t (*is_visible)(struct kobject___128 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___128 *, struct bin_attribute___128 *, int);
	struct attribute **attrs;
	struct bin_attribute___128 **bin_attrs;
};

struct bin_attribute___128 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___137 * (*f_mapping)();
	ssize_t (*read)(struct file___137 *, struct kobject___128 *, struct bin_attribute___128 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___137 *, struct kobject___128 *, struct bin_attribute___128 *, char *, loff_t, size_t);
	int (*mmap)(struct file___137 *, struct kobject___128 *, struct bin_attribute___128 *, struct vm_area_struct___142 *);
};

struct sysfs_ops___128 {
	ssize_t (*show)(struct kobject___128 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___128 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___128;

struct kset___128 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___128 kobj;
	const struct kset_uevent_ops___128 *uevent_ops;
};

struct kobj_type___128 {
	void (*release)(struct kobject___128 *);
	const struct sysfs_ops___128 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___128 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___128 *);
	const void * (*namespace)(struct kobject___128 *);
	void (*get_ownership)(struct kobject___128 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___128 {
	int (* const filter)(struct kset___128 *, struct kobject___128 *);
	const char * (* const name)(struct kset___128 *, struct kobject___128 *);
	int (* const uevent)(struct kset___128 *, struct kobject___128 *, struct kobj_uevent_env *);
};

struct kobj_attribute___8 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___128 *, struct kobj_attribute___8 *, char *);
	ssize_t (*store)(struct kobject___128 *, struct kobj_attribute___8 *, const char *, size_t);
};

struct kernel_param_ops___125 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___125 *);
	int (*get)(char *, const struct kernel_param___125 *);
	void (*free)(void *);
};

struct kparam_array___125;

struct kernel_param___125 {
	const char *name;
	struct module___126 *mod;
	const struct kernel_param_ops___125 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___125 *arr;
	};
};

struct kparam_array___125 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___125 *ops;
	void *elem;
};

struct module_attribute___125 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___125 *, struct module_kobject___125 *, char *);
	ssize_t (*store)(struct module_attribute___125 *, struct module_kobject___125 *, const char *, size_t);
	void (*setup)(struct module___126 *, const char *);
	int (*test)(struct module___126 *);
	void (*free)(struct module___126 *);
};

struct dev_pagemap_ops___135 {
	void (*page_free)(struct page___142 *);
	void (*kill)(struct dev_pagemap___135 *);
	void (*cleanup)(struct dev_pagemap___135 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___135 *);
};

struct fwnode_operations___101;

struct fwnode_handle___101 {
	struct fwnode_handle___101 *secondary;
	const struct fwnode_operations___101 *ops;
	struct device___101 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___101;

struct fwnode_endpoint___101;

struct fwnode_operations___101 {
	struct fwnode_handle___101 * (*get)(struct fwnode_handle___101 *);
	void (*put)(struct fwnode_handle___101 *);
	bool (*device_is_available)(const struct fwnode_handle___101 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___101 *, const struct device___101 *);
	bool (*property_present)(const struct fwnode_handle___101 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___101 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___101 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___101 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*get_parent)(const struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*get_next_child_node)(const struct fwnode_handle___101 *, struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*get_named_child_node)(const struct fwnode_handle___101 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___101 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___101 *);
	struct fwnode_handle___101 * (*graph_get_next_endpoint)(const struct fwnode_handle___101 *, struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*graph_get_remote_endpoint)(const struct fwnode_handle___101 *);
	struct fwnode_handle___101 * (*graph_get_port_parent)(struct fwnode_handle___101 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___101 *, struct fwnode_endpoint___101 *);
	int (*add_links)(struct fwnode_handle___101 *);
};

struct fwnode_endpoint___101 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___101 *local_fwnode;
};

struct fwnode_reference_args___101 {
	struct fwnode_handle___101 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___97 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___97 *root_cset;
};

struct dev_pm_ops___101 {
	int (*prepare)(struct device___101 *);
	void (*complete)(struct device___101 *);
	int (*suspend)(struct device___101 *);
	int (*resume)(struct device___101 *);
	int (*freeze)(struct device___101 *);
	int (*thaw)(struct device___101 *);
	int (*poweroff)(struct device___101 *);
	int (*restore)(struct device___101 *);
	int (*suspend_late)(struct device___101 *);
	int (*resume_early)(struct device___101 *);
	int (*freeze_late)(struct device___101 *);
	int (*thaw_early)(struct device___101 *);
	int (*poweroff_late)(struct device___101 *);
	int (*restore_early)(struct device___101 *);
	int (*suspend_noirq)(struct device___101 *);
	int (*resume_noirq)(struct device___101 *);
	int (*freeze_noirq)(struct device___101 *);
	int (*thaw_noirq)(struct device___101 *);
	int (*poweroff_noirq)(struct device___101 *);
	int (*restore_noirq)(struct device___101 *);
	int (*runtime_suspend)(struct device___101 *);
	int (*runtime_resume)(struct device___101 *);
	int (*runtime_idle)(struct device___101 *);
};

struct wakeup_source___101 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___101 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___101 {
	struct dev_pm_ops___101 ops;
	int (*start)(struct device___101 *);
	void (*detach)(struct device___101 *, bool);
	int (*activate)(struct device___101 *);
	void (*sync)(struct device___101 *);
	void (*dismiss)(struct device___101 *);
};

struct bus_type___101 {
	const char *name;
	const char *dev_name;
	struct device___101 *dev_root;
	const struct attribute_group___128 **bus_groups;
	const struct attribute_group___128 **dev_groups;
	const struct attribute_group___128 **drv_groups;
	int (*match)(struct device___101 *, struct device_driver___101 *);
	int (*uevent)(struct device___101 *, struct kobj_uevent_env *);
	int (*probe)(struct device___101 *);
	void (*sync_state)(struct device___101 *);
	void (*remove)(struct device___101 *);
	void (*shutdown)(struct device___101 *);
	int (*online)(struct device___101 *);
	int (*offline)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	int (*num_vf)(struct device___101 *);
	int (*dma_configure)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___101 {
	const char *name;
	struct bus_type___101 *bus;
	struct module___126 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___101 *);
	void (*sync_state)(struct device___101 *);
	int (*remove)(struct device___101 *);
	void (*shutdown)(struct device___101 *);
	int (*suspend)(struct device___101 *, pm_message_t);
	int (*resume)(struct device___101 *);
	const struct attribute_group___128 **groups;
	const struct attribute_group___128 **dev_groups;
	const struct dev_pm_ops___101 *pm;
	void (*coredump)(struct device___101 *);
	struct driver_private *p;
};

struct device_type___101 {
	const char *name;
	const struct attribute_group___128 **groups;
	int (*uevent)(struct device___101 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___101 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___101 *);
	const struct dev_pm_ops___101 *pm;
};

struct class___101 {
	const char *name;
	struct module___126 *owner;
	const struct attribute_group___128 **class_groups;
	const struct attribute_group___128 **dev_groups;
	struct kobject___128 *dev_kobj;
	int (*dev_uevent)(struct device___101 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___101 *, umode_t *);
	void (*class_release)(struct class___101 *);
	void (*dev_release)(struct device___101 *);
	int (*shutdown_pre)(struct device___101 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___101 *);
	void (*get_ownership)(struct device___101 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___101 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___42;

struct pipe_buffer___42 {
	struct page___142 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___42 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___42 {
	int (*confirm)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
	void (*release)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
	bool (*try_steal)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
	bool (*get)(struct pipe_inode_info___42 *, struct pipe_buffer___42 *);
};

struct crypto_alg___12;

struct crypto_tfm___12 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___12 *);
	struct crypto_alg___12 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___12 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___12 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___12 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___12 *, u8 *, const u8 *);
};

struct compress_alg___12 {
	int (*coa_compress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___12 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___12 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___12 cipher;
		struct compress_alg___12 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___12 *);
	void (*cra_exit)(struct crypto_tfm___12 *);
	void (*cra_destroy)(struct crypto_alg___12 *);
	struct module___126 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_skcipher___5 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___12 base;
};

struct block_device_operations___63;

struct gendisk___63 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___64 *part0;
	const struct block_device_operations___63 *fops;
	struct request_queue___63 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___60 *bdi;
	struct kobject___128 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___128 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___63 {
	struct bio___63 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___75 *bip_vec;
	struct bio_vec___75 bip_inline_vecs[0];
};

struct blkcg___60;

struct blkg_policy_data___60;

struct blkcg_gq___60 {
	struct request_queue___63 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___60 *blkcg;
	struct blkcg_gq___60 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___60 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___63 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___63(struct request___63 *);

typedef void integrity_complete_fn___63(struct request___63 *, unsigned int);

struct blk_integrity_profile___63 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___63 *prepare_fn;
	integrity_complete_fn___63 *complete_fn;
	const char *name;
};

struct block_device_operations___63 {
	blk_qc_t (*submit_bio)(struct bio___63 *);
	int (*open)(struct block_device___64 *, fmode_t);
	void (*release)(struct gendisk___63 *, fmode_t);
	int (*rw_page)(struct block_device___64 *, sector_t, struct page___142 *, unsigned int);
	int (*ioctl)(struct block_device___64 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___64 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___63 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___63 *);
	int (*getgeo)(struct block_device___64 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___64 *, bool);
	void (*swap_slot_free_notify)(struct block_device___64 *, long unsigned int);
	int (*report_zones)(struct gendisk___63 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___63 *, umode_t *);
	struct module___126 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___63 *, sector_t *);
};

typedef void rq_end_io_fn___63(struct request___63 *, blk_status_t);

struct request___63 {
	struct request_queue___63 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___60 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___63 *bio;
	struct bio___63 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___75 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___63 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___63 *saved_end_io;
		} flush;
	};
	struct gendisk___63 *rq_disk;
	struct block_device___64 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___63 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___60 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___63 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___128 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___137 *debugfs_dir;
	struct dentry___137 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___63;

struct elevator_mq_ops___63 {
	int (*init_sched)(struct request_queue___63 *, struct elevator_type___63 *);
	void (*exit_sched)(struct elevator_queue___63 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___60 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___60 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___60 *);
	bool (*allow_merge)(struct request_queue___63 *, struct request___63 *, struct bio___63 *);
	bool (*bio_merge)(struct request_queue___63 *, struct bio___63 *, unsigned int);
	int (*request_merge)(struct request_queue___63 *, struct request___63 **, struct bio___63 *);
	void (*request_merged)(struct request_queue___63 *, struct request___63 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___63 *, struct request___63 *, struct request___63 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___63 *);
	void (*finish_request)(struct request___63 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___60 *, struct list_head *, bool);
	struct request___63 * (*dispatch_request)(struct blk_mq_hw_ctx___60 *);
	bool (*has_work)(struct blk_mq_hw_ctx___60 *);
	void (*completed_request)(struct request___63 *, u64);
	void (*requeue_request)(struct request___63 *);
	struct request___63 * (*former_request)(struct request_queue___63 *, struct request___63 *);
	struct request___63 * (*next_request)(struct request_queue___63 *, struct request___63 *);
	void (*init_icq)(struct io_cq___63 *);
	void (*exit_icq)(struct io_cq___63 *);
};

struct elv_fs_entry___63;

struct elevator_type___63 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___63 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___63 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___126 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___63 {
	struct elevator_type___63 *type;
	void *elevator_data;
	struct kobject___128 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___63 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___63 *, char *);
	ssize_t (*store)(struct elevator_queue___63 *, const char *, size_t);
};

struct blk_mq_queue_data___60;

struct blk_mq_ops___60 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___60 *, const struct blk_mq_queue_data___60 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___60 *);
	int (*get_budget)(struct request_queue___63 *);
	void (*put_budget)(struct request_queue___63 *, int);
	void (*set_rq_budget_token)(struct request___63 *, int);
	int (*get_rq_budget_token)(struct request___63 *);
	enum blk_eh_timer_return (*timeout)(struct request___63 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___60 *);
	void (*complete)(struct request___63 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___60 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___60 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___60 *, struct request___63 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___60 *, struct request___63 *, unsigned int);
	void (*initialize_rq_fn)(struct request___63 *);
	void (*cleanup_rq)(struct request___63 *);
	bool (*busy)(struct request_queue___63 *);
	int (*map_queues)(struct blk_mq_tag_set___60 *);
	void (*show_rq)(struct seq_file___118 *, struct request___63 *);
};

struct blk_mq_tag_set___60 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___60 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___118 {
	void * (*start)(struct seq_file___118 *, loff_t *);
	void (*stop)(struct seq_file___118 *, void *);
	void * (*next)(struct seq_file___118 *, void *, loff_t *);
	int (*show)(struct seq_file___118 *, void *);
};

struct cftype___97;

struct cgroup_subsys___97 {
	struct cgroup_subsys_state___97 * (*css_alloc)(struct cgroup_subsys_state___97 *);
	int (*css_online)(struct cgroup_subsys_state___97 *);
	void (*css_offline)(struct cgroup_subsys_state___97 *);
	void (*css_released)(struct cgroup_subsys_state___97 *);
	void (*css_free)(struct cgroup_subsys_state___97 *);
	void (*css_reset)(struct cgroup_subsys_state___97 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___97 *, int);
	int (*css_extra_stat_show)(struct seq_file___118 *, struct cgroup_subsys_state___97 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___144 *, struct css_set___97 *);
	void (*cancel_fork)(struct task_struct___144 *, struct css_set___97 *);
	void (*fork)(struct task_struct___144 *);
	void (*exit)(struct task_struct___144 *);
	void (*release)(struct task_struct___144 *);
	void (*bind)(struct cgroup_subsys_state___97 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___97 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___97 *dfl_cftypes;
	struct cftype___97 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___97 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___97 *updated_children;
	struct cgroup___97 *updated_next;
};

struct cgroup_root___97 {
	struct kernfs_root___128 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___97 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___97 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___97 *ss;
	struct list_head node;
	struct kernfs_ops___128 *kf_ops;
	int (*open)(struct kernfs_open_file___128 *);
	void (*release)(struct kernfs_open_file___128 *);
	u64 (*read_u64)(struct cgroup_subsys_state___97 *, struct cftype___97 *);
	s64 (*read_s64)(struct cgroup_subsys_state___97 *, struct cftype___97 *);
	int (*seq_show)(struct seq_file___118 *, void *);
	void * (*seq_start)(struct seq_file___118 *, loff_t *);
	void * (*seq_next)(struct seq_file___118 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___118 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___97 *, struct cftype___97 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___97 *, struct cftype___97 *, s64);
	ssize_t (*write)(struct kernfs_open_file___128 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___128 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___60 {
	struct request___63 *rq;
	bool last;
};

struct blkcg_policy_data___60;

struct blkcg___60 {
	struct cgroup_subsys_state___97 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___60 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___60 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___60 {
	struct blkcg___60 *blkcg;
	int plid;
};

struct blkg_policy_data___60 {
	struct blkcg_gq___60 *blkg;
	int plid;
};

struct ecryptfs_session_key {
	u32 flags;
	u32 encrypted_key_size;
	u32 decrypted_key_size;
	u8 encrypted_key[512];
	u8 decrypted_key[64];
};

struct ecryptfs_password {
	u32 password_bytes;
	s32 hash_algo;
	u32 hash_iterations;
	u32 session_key_encryption_key_bytes;
	u32 flags;
	u8 session_key_encryption_key[64];
	u8 signature[17];
	u8 salt[8];
};

struct ecryptfs_private_key {
	u32 key_size;
	u32 data_len;
	u8 signature[17];
	char pki_type[17];
	u8 data[0];
};

struct ecryptfs_auth_tok {
	u16 version;
	u16 token_type;
	u32 flags;
	struct ecryptfs_session_key session_key;
	u8 reserved[32];
	union {
		struct ecryptfs_password password;
		struct ecryptfs_private_key private_key;
	} token;
};

struct ecryptfs_crypt_stat___4 {
	u32 flags;
	unsigned int file_version;
	size_t iv_bytes;
	size_t metadata_size;
	size_t extent_size;
	size_t key_size;
	size_t extent_shift;
	unsigned int extent_mask;
	struct ecryptfs_mount_crypt_stat *mount_crypt_stat;
	struct crypto_skcipher___5 *tfm;
	struct crypto_shash___6 *hash_tfm;
	unsigned char cipher[32];
	unsigned char key[64];
	unsigned char root_iv[16];
	struct list_head keysig_list;
	struct mutex keysig_list_mutex;
	struct mutex cs_tfm_mutex;
	struct mutex cs_mutex;
};

struct ecryptfs_inode_info___4 {
	struct inode___137 vfs_inode;
	struct inode___137 *wii_inode;
	struct mutex lower_file_mutex;
	atomic_t lower_file_count;
	struct file___137 *lower_file;
	struct ecryptfs_crypt_stat___4 crypt_stat;
};

struct ecryptfs_dentry_info___4 {
	struct path___137 lower_path;
	struct callback_head rcu;
};

struct ecryptfs_global_auth_tok {
	u32 flags;
	struct list_head mount_crypt_stat_list;
	struct key___3 *global_auth_tok_key;
	unsigned char sig[17];
};

struct ecryptfs_key_tfm {
	struct crypto_skcipher___5 *key_tfm;
	size_t key_size;
	struct mutex key_tfm_mutex;
	struct list_head key_tfm_list;
	unsigned char cipher_name[32];
};

struct ecryptfs_sb_info___3 {
	struct super_block___137 *wsi_sb;
	struct ecryptfs_mount_crypt_stat mount_crypt_stat;
};

enum {
	ecryptfs_opt_sig = 0,
	ecryptfs_opt_ecryptfs_sig = 1,
	ecryptfs_opt_cipher = 2,
	ecryptfs_opt_ecryptfs_cipher = 3,
	ecryptfs_opt_ecryptfs_key_bytes = 4,
	ecryptfs_opt_passthrough = 5,
	ecryptfs_opt_xattr_metadata = 6,
	ecryptfs_opt_encrypted_view = 7,
	ecryptfs_opt_fnek_sig = 8,
	ecryptfs_opt_fn_cipher = 9,
	ecryptfs_opt_fn_cipher_key_bytes = 10,
	ecryptfs_opt_unlink_sigs = 11,
	ecryptfs_opt_mount_auth_tok_only = 12,
	ecryptfs_opt_check_dev_ruid = 13,
	ecryptfs_opt_err = 14,
};

struct ecryptfs_cache_info {
	struct kmem_cache **cache;
	const char *name;
	size_t size;
	slab_flags_t flags;
	void (*ctor)(void *);
};

struct crypto_async_request___3;

typedef void (*crypto_completion_t___3)(struct crypto_async_request___3 *, int);

struct crypto_async_request___3 {
	struct list_head list;
	crypto_completion_t___3 complete;
	void *data;
	struct crypto_tfm___7 *tfm;
	u32 flags;
};

struct skcipher_request___2 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___3 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct skcipher_alg___2 {
	int (*setkey)(struct crypto_skcipher___4 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___2 *);
	int (*decrypt)(struct skcipher_request___2 *);
	int (*init)(struct crypto_skcipher___4 *);
	void (*exit)(struct crypto_skcipher___4 *);
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
	unsigned int chunksize;
	unsigned int walksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___7 base;
};

struct ecryptfs_key_sig {
	struct list_head crypt_stat_list;
	char keysig[17];
};

struct ecryptfs_filename {
	struct list_head crypt_stat_list;
	u32 flags;
	u32 seq_no;
	char *filename;
	char *encrypted_filename;
	size_t filename_size;
	size_t encrypted_filename_size;
	char fnek_sig[16];
	char dentry_name[57];
};

struct ecryptfs_key_tfm___2 {
	struct crypto_skcipher___4 *key_tfm;
	size_t key_size;
	struct mutex key_tfm_mutex;
	struct list_head key_tfm_list;
	unsigned char cipher_name[32];
};

struct extent_crypt_result {
	struct completion completion;
	int rc;
};

struct ecryptfs_flag_map_elem {
	u32 file_flag;
	u32 local_flag;
};

struct ecryptfs_cipher_code_str_map_elem {
	char cipher_str[16];
	u8 cipher_code;
};

struct encrypted_key_payload {
	struct callback_head rcu;
	char *format;
	char *master_desc;
	char *datalen;
	u8 *iv;
	u8 *encrypted_data;
	short unsigned int datablob_len;
	short unsigned int decrypted_datalen;
	short unsigned int payload_datalen;
	short unsigned int encrypted_key_format;
	u8 *decrypted_data;
	u8 payload_data[0];
};

enum ecryptfs_token_types {
	ECRYPTFS_PASSWORD = 0,
	ECRYPTFS_PRIVATE_KEY = 1,
};

struct ecryptfs_key_record {
	unsigned char type;
	size_t enc_key_size;
	unsigned char sig[8];
	unsigned char enc_key[512];
};

struct ecryptfs_auth_tok_list_item {
	unsigned char encrypted_session_key[64];
	struct list_head list;
	struct ecryptfs_auth_tok auth_tok;
};

struct ecryptfs_message {
	u32 index;
	u32 data_len;
	u8 data[0];
};

struct ecryptfs_msg_ctx {
	u8 state;
	u8 type;
	u32 index;
	u32 counter;
	size_t msg_size;
	struct ecryptfs_message *msg;
	struct task_struct___144 *task;
	struct list_head node;
	struct list_head daemon_out_list;
	struct mutex mux;
};

struct ecryptfs_write_tag_70_packet_silly_stack {
	u8 cipher_code;
	size_t max_packet_size;
	size_t packet_size_len;
	size_t block_aligned_filename_size;
	size_t block_size;
	size_t i;
	size_t j;
	size_t num_rand_bytes;
	struct mutex *tfm_mutex;
	char *block_aligned_filename;
	struct ecryptfs_auth_tok *auth_tok;
	struct scatterlist src_sg[2];
	struct scatterlist dst_sg[2];
	struct crypto_skcipher___5 *skcipher_tfm;
	struct skcipher_request___2 *skcipher_req;
	char iv[16];
	char hash[16];
	char tmp_hash[16];
	struct crypto_shash___6 *hash_tfm;
	struct shash_desc___4 *hash_desc;
};

struct ecryptfs_parse_tag_70_packet_silly_stack {
	u8 cipher_code;
	size_t max_packet_size;
	size_t packet_size_len;
	size_t parsed_tag_70_packet_size;
	size_t block_aligned_filename_size;
	size_t block_size;
	size_t i;
	struct mutex *tfm_mutex;
	char *decrypted_filename;
	struct ecryptfs_auth_tok *auth_tok;
	struct scatterlist src_sg[2];
	struct scatterlist dst_sg[2];
	struct crypto_skcipher___5 *skcipher_tfm;
	struct skcipher_request___2 *skcipher_req;
	char fnek_sig_hex[17];
	char iv[16];
	char cipher_string[32];
};

struct ecryptfs_open_req {
	struct file___137 **lower_file;
	struct path___137 path;
	struct completion done;
	struct list_head kthread_ctl_list;
};

struct ecryptfs_kthread_ctl {
	u32 flags;
	struct mutex mux;
	struct list_head req_list;
	wait_queue_head_t wait;
};

struct ecryptfs_daemon {
	u32 flags;
	u32 num_queued_msg_ctx;
	struct file___137 *file;
	struct mutex mux;
	struct list_head msg_ctx_out_queue;
	wait_queue_head_t wait;
	struct hlist_node euid_chain;
};

typedef void (*poll_queue_proc___89)(struct file___137 *, wait_queue_head_t *, struct poll_table_struct___5 *);

typedef struct poll_table_struct___5 poll_table___26;

struct getdents_callback___2 {
	struct dir_context ctx;
	char *name;
	u64 ino;
	int found;
	int sequence;
};

typedef u32 unicode_t;

struct utf8_table {
	int cmask;
	int cval;
	int shift;
	long int lmask;
	long int lval;
};

struct utf8data;

struct utf8cursor {
	const struct utf8data *data;
	const char *s;
	const char *p;
	const char *ss;
	const char *sp;
	unsigned int len;
	unsigned int slen;
	short int ccc;
	short int nccc;
	unsigned char hangul[12];
};

struct utf8data {
	unsigned int maxage;
	unsigned int offset;
};

typedef const unsigned char utf8trie_t;

typedef const unsigned char utf8leaf_t;

enum fuse_opcode {
	FUSE_LOOKUP = 1,
	FUSE_FORGET = 2,
	FUSE_GETATTR = 3,
	FUSE_SETATTR = 4,
	FUSE_READLINK = 5,
	FUSE_SYMLINK = 6,
	FUSE_MKNOD = 8,
	FUSE_MKDIR = 9,
	FUSE_UNLINK = 10,
	FUSE_RMDIR = 11,
	FUSE_RENAME = 12,
	FUSE_LINK = 13,
	FUSE_OPEN = 14,
	FUSE_READ = 15,
	FUSE_WRITE = 16,
	FUSE_STATFS = 17,
	FUSE_RELEASE = 18,
	FUSE_FSYNC = 20,
	FUSE_SETXATTR = 21,
	FUSE_GETXATTR = 22,
	FUSE_LISTXATTR = 23,
	FUSE_REMOVEXATTR = 24,
	FUSE_FLUSH = 25,
	FUSE_INIT = 26,
	FUSE_OPENDIR = 27,
	FUSE_READDIR = 28,
	FUSE_RELEASEDIR = 29,
	FUSE_FSYNCDIR = 30,
	FUSE_GETLK = 31,
	FUSE_SETLK = 32,
	FUSE_SETLKW = 33,
	FUSE_ACCESS = 34,
	FUSE_CREATE = 35,
	FUSE_INTERRUPT = 36,
	FUSE_BMAP = 37,
	FUSE_DESTROY = 38,
	FUSE_IOCTL = 39,
	FUSE_POLL = 40,
	FUSE_NOTIFY_REPLY = 41,
	FUSE_BATCH_FORGET = 42,
	FUSE_FALLOCATE = 43,
	FUSE_READDIRPLUS = 44,
	FUSE_RENAME2 = 45,
	FUSE_LSEEK = 46,
	FUSE_COPY_FILE_RANGE = 47,
	FUSE_SETUPMAPPING = 48,
	FUSE_REMOVEMAPPING = 49,
	FUSE_SYNCFS = 50,
	CUSE_INIT = 4096,
	CUSE_INIT_BSWAP_RESERVED = 1048576,
	FUSE_INIT_BSWAP_RESERVED = 436207616,
};

enum fuse_notify_code {
	FUSE_NOTIFY_POLL = 1,
	FUSE_NOTIFY_INVAL_INODE = 2,
	FUSE_NOTIFY_INVAL_ENTRY = 3,
	FUSE_NOTIFY_STORE = 4,
	FUSE_NOTIFY_RETRIEVE = 5,
	FUSE_NOTIFY_DELETE = 6,
	FUSE_NOTIFY_CODE_MAX = 7,
};

struct fuse_forget_in {
	uint64_t nlookup;
};

struct fuse_forget_one {
	uint64_t nodeid;
	uint64_t nlookup;
};

struct fuse_batch_forget_in {
	uint32_t count;
	uint32_t dummy;
};

struct fuse_interrupt_in {
	uint64_t unique;
};

struct fuse_notify_poll_wakeup_out {
	uint64_t kh;
};

struct fuse_in_header {
	uint32_t len;
	uint32_t opcode;
	uint64_t unique;
	uint64_t nodeid;
	uint32_t uid;
	uint32_t gid;
	uint32_t pid;
	uint32_t padding;
};

struct fuse_out_header {
	uint32_t len;
	int32_t error;
	uint64_t unique;
};

struct fuse_notify_inval_inode_out {
	uint64_t ino;
	int64_t off;
	int64_t len;
};

struct fuse_notify_inval_entry_out {
	uint64_t parent;
	uint32_t namelen;
	uint32_t padding;
};

struct fuse_notify_delete_out {
	uint64_t parent;
	uint64_t child;
	uint32_t namelen;
	uint32_t padding;
};

struct fuse_notify_store_out {
	uint64_t nodeid;
	uint64_t offset;
	uint32_t size;
	uint32_t padding;
};

struct fuse_notify_retrieve_out {
	uint64_t notify_unique;
	uint64_t nodeid;
	uint64_t offset;
	uint32_t size;
	uint32_t padding;
};

struct fuse_notify_retrieve_in {
	uint64_t dummy1;
	uint64_t offset;
	uint32_t size;
	uint32_t dummy2;
	uint64_t dummy3;
	uint64_t dummy4;
};

struct dentry___138;

struct super_block___138;

struct module___127;

struct file_system_type___138 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___138 * (*mount)(struct file_system_type___138 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___138 *);
	struct module___127 *owner;
	struct file_system_type___138 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___138;

struct kiocb___138;

struct iov_iter___78;

struct poll_table_struct___88;

struct vm_area_struct___143;

struct inode___138;

struct file_lock___138;

struct page___143;

struct pipe_inode_info___43;

struct seq_file___119;

struct file_operations___138 {
	struct module___127 *owner;
	loff_t (*llseek)(struct file___138 *, loff_t, int);
	ssize_t (*read)(struct file___138 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___138 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___138 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___138 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___138 *, bool);
	int (*iterate)(struct file___138 *, struct dir_context *);
	int (*iterate_shared)(struct file___138 *, struct dir_context *);
	__poll_t (*poll)(struct file___138 *, struct poll_table_struct___88 *);
	long int (*unlocked_ioctl)(struct file___138 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___138 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___138 *, struct vm_area_struct___143 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___138 *, struct file___138 *);
	int (*flush)(struct file___138 *, fl_owner_t);
	int (*release)(struct inode___138 *, struct file___138 *);
	int (*fsync)(struct file___138 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___138 *, int);
	int (*lock)(struct file___138 *, int, struct file_lock___138 *);
	ssize_t (*sendpage)(struct file___138 *, struct page___143 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___138 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___138 *, long unsigned int);
	int (*flock)(struct file___138 *, int, struct file_lock___138 *);
	ssize_t (*splice_write)(struct pipe_inode_info___43 *, struct file___138 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___138 *, loff_t *, struct pipe_inode_info___43 *, size_t, unsigned int);
	int (*setlease)(struct file___138 *, long int, struct file_lock___138 **, void **);
	long int (*fallocate)(struct file___138 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___119 *, struct file___138 *);
	ssize_t (*copy_file_range)(struct file___138 *, loff_t, struct file___138 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___138 *, loff_t, struct file___138 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___138 *, loff_t, loff_t, int);
};

struct vmacache___143 {
	u64 seqnum;
	struct vm_area_struct___143 *vmas[4];
};

struct page_frag___143 {
	struct page___143 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___144;

struct pid___123;

struct nsproxy___129;

struct signal_struct___139;

struct bio_list___64;

struct backing_dev_info___61;

struct io_context___64;

struct css_set___98;

struct mem_cgroup___52;

struct request_queue___64;

struct vm_struct___125;

struct task_struct___145 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___145 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___144 *mm;
	struct mm_struct___144 *active_mm;
	struct vmacache___143 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___145 *real_parent;
	struct task_struct___145 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___145 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___123 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___129 *nsproxy;
	struct signal_struct___139 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___145 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___64 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___61 *backing_dev_info;
	struct io_context___64 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___98 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___43 *splice_pipe;
	struct page_frag___143 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___52 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___52 *active_memcg;
	struct request_queue___64 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___145 *oom_reaper_list;
	struct vm_struct___125 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___129;

struct kobj_type___129;

struct kernfs_node___129;

struct kobject___129 {
	const char *name;
	struct list_head entry;
	struct kobject___129 *parent;
	struct kset___129 *kset;
	struct kobj_type___129 *ktype;
	struct kernfs_node___129 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___126 {
	struct kobject___129 kobj;
	struct module___127 *mod;
	struct kobject___129 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___126 {
	struct module___127 *mod;
	struct latch_tree_node node;
};

struct module_layout___126 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___126 mtn;
};

struct module_attribute___126;

struct kernel_param___126;

struct module___127 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___126 mkobj;
	struct module_attribute___126 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___129 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___126 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___126 core_layout;
	struct module_layout___126 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___138;

struct dentry___138 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___138 *d_parent;
	struct qstr d_name;
	struct inode___138 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___138 *d_op;
	struct super_block___138 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___138;

struct address_space___138 {
	struct inode___138 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___138 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___138;

struct bdi_writeback___61;

struct inode___138 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___138 *i_op;
	struct super_block___138 *i_sb;
	struct address_space___138 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___61 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___138 *i_fop;
		void (*free_inode)(struct inode___138 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___138 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___43 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___138;

struct path___138;

struct dentry_operations___138 {
	int (*d_revalidate)(struct dentry___138 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___138 *, unsigned int);
	int (*d_hash)(const struct dentry___138 *, struct qstr *);
	int (*d_compare)(const struct dentry___138 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___138 *);
	int (*d_init)(struct dentry___138 *);
	void (*d_release)(struct dentry___138 *);
	void (*d_prune)(struct dentry___138 *);
	void (*d_iput)(struct dentry___138 *, struct inode___138 *);
	char * (*d_dname)(struct dentry___138 *, char *, int);
	struct vfsmount___138 * (*d_automount)(struct path___138 *);
	int (*d_manage)(const struct path___138 *, bool);
	struct dentry___138 * (*d_real)(struct dentry___138 *, const struct inode___138 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___138;

struct mem_dqinfo___138 {
	struct quota_format_type___138 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___138;

struct quota_info___138 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___138 *files[3];
	struct mem_dqinfo___138 info[3];
	const struct quota_format_ops___138 *ops[3];
};

struct rcuwait___139 {
	struct task_struct___145 *task;
};

struct percpu_rw_semaphore___139 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___139 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___138 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___139 rw_sem[3];
};

struct shrink_control___52;

struct shrinker___52 {
	long unsigned int (*count_objects)(struct shrinker___52 *, struct shrink_control___52 *);
	long unsigned int (*scan_objects)(struct shrinker___52 *, struct shrink_control___52 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___138;

struct dquot_operations___138;

struct quotactl_ops___138;

struct xattr_handler___17;

struct block_device___65;

struct super_block___138 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___138 *s_type;
	const struct super_operations___138 *s_op;
	const struct dquot_operations___138 *dq_op;
	const struct quotactl_ops___138 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___138 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___17 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___65 *s_bdev;
	struct backing_dev_info___61 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___138 s_dquot;
	struct sb_writers___138 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___138 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___138 {
	struct dentry___138 *mnt_root;
	struct super_block___138 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___138 {
	struct vfsmount___138 *mnt;
	struct dentry___138 *dentry;
};

struct pid_namespace___123;

struct upid___123 {
	int nr;
	struct pid_namespace___123 *ns;
};

struct pid_namespace___123 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___145 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___123 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___123 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___123 numbers[1];
};

typedef struct page___143 *pgtable_t___143;

struct dev_pagemap___136;

struct page___143 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___138 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___143 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___143 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___144 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___136 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___136;

struct vm_area_struct___143 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___143 *vm_next;
	struct vm_area_struct___143 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___144 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___136 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___138 *vm_file;
	struct file___138 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___139 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___145 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___145 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___123 *pids[4];
	struct pid___123 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___144 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___143;

struct mm_struct___144 {
	struct {
		struct vm_area_struct___143 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___138 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___143 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___145 *owner;
		struct user_namespace___19 *user_ns;
		struct file___138 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___98;

struct nsproxy___129 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___123 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___98 *cgroup_ns;
};

struct bio___64;

struct bio_list___64 {
	struct bio___64 *head;
	struct bio___64 *tail;
};

struct cgroup_subsys_state___98;

struct bdi_writeback___61 {
	struct backing_dev_info___61 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___98 *memcg_css;
	struct cgroup_subsys_state___98 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___102;

struct backing_dev_info___61 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___61 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___102 *dev;
	char dev_name[64];
	struct device___102 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___138 *debug_dir;
};

struct io_cq___64;

struct io_context___64 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___64 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___98;

struct css_set___98 {
	struct cgroup_subsys_state___98 *subsys[14];
	refcount_t refcount;
	struct css_set___98 *dom_cset;
	struct cgroup___98 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___98 *mg_src_cgrp;
	struct cgroup___98 *mg_dst_cgrp;
	struct css_set___98 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___138;

struct pipe_buffer___43;

struct pipe_inode_info___43 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___143 *tmp_page;
	struct fasync_struct___138 *fasync_readers;
	struct fasync_struct___138 *fasync_writers;
	struct pipe_buffer___43 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___98;

struct cgroup_subsys_state___98 {
	struct cgroup___98 *cgroup;
	struct cgroup_subsys___98 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___98 *parent;
};

struct cgroup_file___98 {
	struct kernfs_node___129 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___52;

struct mem_cgroup_per_node___52;

struct mem_cgroup___52 {
	struct cgroup_subsys_state___98 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___98 events_file;
	struct cgroup_file___98 events_local_file;
	struct cgroup_file___98 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___52 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___145 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___52 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___64;

struct blk_integrity___64 {
	const struct blk_integrity_profile___64 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___64 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___64 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___64;

struct elevator_queue___64;

struct blk_mq_ops___61;

struct blk_mq_hw_ctx___61;

struct gendisk___64;

struct blkcg_gq___61;

struct blk_mq_tag_set___61;

struct request_queue___64 {
	struct request___64 *last_merge;
	struct elevator_queue___64 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___61 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___61 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___64 *disk;
	struct kobject___129 kobj;
	struct kobject___129 *mq_kobj;
	struct blk_integrity___64 integrity;
	struct device___102 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___61 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___61 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___64 bio_split;
	struct dentry___138 *debugfs_dir;
	struct dentry___138 *sched_debugfs_dir;
	struct dentry___138 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___125 {
	struct vm_struct___125 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___143 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___52 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___52 *memcg;
};

struct dev_pagemap_ops___136;

struct dev_pagemap___136 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___136 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___123 {
	rwlock_t lock;
	struct pid___123 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___138 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___138 f_path;
	struct inode___138 *f_inode;
	const struct file_operations___138 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___123 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___138 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___136;

struct vm_operations_struct___136 {
	void (*open)(struct vm_area_struct___143 *);
	void (*close)(struct vm_area_struct___143 *);
	int (*may_split)(struct vm_area_struct___143 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___143 *);
	int (*mprotect)(struct vm_area_struct___143 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___136 *);
	vm_fault_t (*huge_fault)(struct vm_fault___136 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___136 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___143 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___136 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___136 *);
	int (*access)(struct vm_area_struct___143 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___143 *);
	int (*set_policy)(struct vm_area_struct___143 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___143 *, long unsigned int);
	struct page___143 * (*find_special_page)(struct vm_area_struct___143 *, long unsigned int);
};

struct core_thread___143 {
	struct task_struct___145 *task;
	struct core_thread___143 *next;
};

struct core_state___143 {
	atomic_t nr_threads;
	struct core_thread___143 dumper;
	struct completion startup;
};

struct vm_fault___136 {
	const struct {
		struct vm_area_struct___143 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___143 *cow_page;
	struct page___143 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___143 prealloc_pte;
};

struct pglist_data___59;

struct lruvec___59 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___59 *pgdat;
};

struct zone___59 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___59 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___59 {
	struct zone___59 *zone;
	int zone_idx;
};

struct zonelist___59 {
	struct zoneref___59 _zonerefs[321];
};

struct pglist_data___59 {
	struct zone___59 node_zones[5];
	struct zonelist___59 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___145 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___145 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___59 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___98 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___145 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___98;

struct cgroup_rstat_cpu___98;

struct cgroup___98 {
	struct cgroup_subsys_state___98 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___129 *kn;
	struct cgroup_file___98 procs_file;
	struct cgroup_file___98 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___98 *subsys[14];
	struct cgroup_root___98 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___98 *dom_cgrp;
	struct cgroup___98 *old_dom_cgrp;
	struct cgroup_rstat_cpu___98 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___98 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___64 {
	struct request_queue___64 *q;
	struct io_context___64 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___67;

struct kiocb___138 {
	struct file___138 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___138 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___67 *ki_waitq;
	};
};

struct iattr___138 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___138 *ia_file;
};

struct dquot___138 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___138 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___138 {
	int qf_fmt_id;
	const struct quota_format_ops___138 *qf_ops;
	struct module___127 *qf_owner;
	struct quota_format_type___138 *qf_next;
};

struct quota_format_ops___138 {
	int (*check_quota_file)(struct super_block___138 *, int);
	int (*read_file_info)(struct super_block___138 *, int);
	int (*write_file_info)(struct super_block___138 *, int);
	int (*free_file_info)(struct super_block___138 *, int);
	int (*read_dqblk)(struct dquot___138 *);
	int (*commit_dqblk)(struct dquot___138 *);
	int (*release_dqblk)(struct dquot___138 *);
	int (*get_next_id)(struct super_block___138 *, struct kqid *);
};

struct dquot_operations___138 {
	int (*write_dquot)(struct dquot___138 *);
	struct dquot___138 * (*alloc_dquot)(struct super_block___138 *, int);
	void (*destroy_dquot)(struct dquot___138 *);
	int (*acquire_dquot)(struct dquot___138 *);
	int (*release_dquot)(struct dquot___138 *);
	int (*mark_dirty)(struct dquot___138 *);
	int (*write_info)(struct super_block___138 *, int);
	qsize_t * (*get_reserved_space)(struct inode___138 *);
	int (*get_projid)(struct inode___138 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___138 *, qsize_t *);
	int (*get_next_id)(struct super_block___138 *, struct kqid *);
};

struct quotactl_ops___138 {
	int (*quota_on)(struct super_block___138 *, int, int, const struct path___138 *);
	int (*quota_off)(struct super_block___138 *, int);
	int (*quota_enable)(struct super_block___138 *, unsigned int);
	int (*quota_disable)(struct super_block___138 *, unsigned int);
	int (*quota_sync)(struct super_block___138 *, int);
	int (*set_info)(struct super_block___138 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___138 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___138 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___138 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___138 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___138 *, unsigned int);
};

struct wait_page_queue___67 {
	struct page___143 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___61;

struct readahead_control___67;

struct swap_info_struct___34;

struct address_space_operations___138 {
	int (*writepage)(struct page___143 *, struct writeback_control___61 *);
	int (*readpage)(struct file___138 *, struct page___143 *);
	int (*writepages)(struct address_space___138 *, struct writeback_control___61 *);
	int (*set_page_dirty)(struct page___143 *);
	int (*readpages)(struct file___138 *, struct address_space___138 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___67 *);
	int (*write_begin)(struct file___138 *, struct address_space___138 *, loff_t, unsigned int, unsigned int, struct page___143 **, void **);
	int (*write_end)(struct file___138 *, struct address_space___138 *, loff_t, unsigned int, unsigned int, struct page___143 *, void *);
	sector_t (*bmap)(struct address_space___138 *, sector_t);
	void (*invalidatepage)(struct page___143 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___143 *, gfp_t);
	void (*freepage)(struct page___143 *);
	ssize_t (*direct_IO)(struct kiocb___138 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___138 *, struct page___143 *, struct page___143 *, enum migrate_mode);
	bool (*isolate_page)(struct page___143 *, isolate_mode_t);
	void (*putback_page)(struct page___143 *);
	int (*launder_page)(struct page___143 *);
	int (*is_partially_uptodate)(struct page___143 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___143 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___138 *, struct page___143 *);
	int (*swap_activate)(struct swap_info_struct___34 *, struct file___138 *, sector_t *);
	void (*swap_deactivate)(struct file___138 *);
};

struct writeback_control___61 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___61 *wb;
	struct inode___138 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___67 {
	struct file___138 *file;
	struct address_space___138 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___76;

struct iov_iter___78 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___76 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___43 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___34 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___65 *bdev;
	struct file___138 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___138 {
	struct dentry___138 * (*lookup)(struct inode___138 *, struct dentry___138 *, unsigned int);
	const char * (*get_link)(struct dentry___138 *, struct inode___138 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___138 *, int);
	struct posix_acl * (*get_acl)(struct inode___138 *, int, bool);
	int (*readlink)(struct dentry___138 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___138 *, struct dentry___138 *, umode_t, bool);
	int (*link)(struct dentry___138 *, struct inode___138 *, struct dentry___138 *);
	int (*unlink)(struct inode___138 *, struct dentry___138 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___138 *, struct dentry___138 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___138 *, struct dentry___138 *, umode_t);
	int (*rmdir)(struct inode___138 *, struct dentry___138 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___138 *, struct dentry___138 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___138 *, struct dentry___138 *, struct inode___138 *, struct dentry___138 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___138 *, struct iattr___138 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___138 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___138 *, char *, size_t);
	int (*fiemap)(struct inode___138 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___138 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___138 *, struct dentry___138 *, struct file___138 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___138 *, struct dentry___138 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___138 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___138 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___138 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___138 {
	void (*fl_copy_lock)(struct file_lock___138 *, struct file_lock___138 *);
	void (*fl_release_private)(struct file_lock___138 *);
};

struct lock_manager_operations___138;

struct file_lock___138 {
	struct file_lock___138 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___138 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___138 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___138 *fl_ops;
	const struct lock_manager_operations___138 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___138 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___138 *);
	int (*lm_grant)(struct file_lock___138 *, int);
	bool (*lm_break)(struct file_lock___138 *);
	int (*lm_change)(struct file_lock___138 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___138 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___138 *);
};

struct fasync_struct___138 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___138 *fa_next;
	struct file___138 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___138 {
	struct inode___138 * (*alloc_inode)(struct super_block___138 *);
	void (*destroy_inode)(struct inode___138 *);
	void (*free_inode)(struct inode___138 *);
	void (*dirty_inode)(struct inode___138 *, int);
	int (*write_inode)(struct inode___138 *, struct writeback_control___61 *);
	int (*drop_inode)(struct inode___138 *);
	void (*evict_inode)(struct inode___138 *);
	void (*put_super)(struct super_block___138 *);
	int (*sync_fs)(struct super_block___138 *, int);
	int (*freeze_super)(struct super_block___138 *);
	int (*freeze_fs)(struct super_block___138 *);
	int (*thaw_super)(struct super_block___138 *);
	int (*unfreeze_fs)(struct super_block___138 *);
	int (*statfs)(struct dentry___138 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___138 *, int *, char *);
	void (*umount_begin)(struct super_block___138 *);
	int (*show_options)(struct seq_file___119 *, struct dentry___138 *);
	int (*show_devname)(struct seq_file___119 *, struct dentry___138 *);
	int (*show_path)(struct seq_file___119 *, struct dentry___138 *);
	int (*show_stats)(struct seq_file___119 *, struct dentry___138 *);
	ssize_t (*quota_read)(struct super_block___138 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___138 *, int, const char *, size_t, loff_t);
	struct dquot___138 ** (*get_dquots)(struct inode___138 *);
	long int (*nr_cached_objects)(struct super_block___138 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___138 *, struct shrink_control___52 *);
	struct file___138 * (*real_loop)(struct file___138 *);
};

struct xattr_handler___17 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___138 *);
	int (*get)(const struct xattr_handler___17 *, struct dentry___138 *, struct inode___138 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___17 *, struct user_namespace___19 *, struct dentry___138 *, struct inode___138 *, const char *, const void *, size_t, int);
};

struct wakeup_source___102;

struct dev_pm_info___102 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___102 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___102 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___102;

struct bus_type___102;

struct device_driver___102;

struct dev_pm_domain___102;

struct fwnode_handle___102;

struct class___102;

struct attribute_group___129;

struct device___102 {
	struct kobject___129 kobj;
	struct device___102 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___102 *type;
	struct bus_type___102 *bus;
	struct device_driver___102 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___102 power;
	struct dev_pm_domain___102 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___102 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___102 *class;
	const struct attribute_group___129 **groups;
	void (*release)(struct device___102 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___65 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___138 *bd_inode;
	struct super_block___138 *bd_super;
	void *bd_claiming;
	struct device___102 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___129 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___64 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___138 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___90)(struct file___138 *, wait_queue_head_t *, struct poll_table_struct___88 *);

struct poll_table_struct___88 {
	poll_queue_proc___90 _qproc;
	__poll_t _key;
};

struct seq_operations___119;

struct seq_file___119 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___119 *op;
	int poll_event;
	const struct file___138 *file;
	void *private;
};

typedef void bio_end_io_t___64(struct bio___64 *);

struct bio_vec___76 {
	struct page___143 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___64;

struct bio___64 {
	struct bio___64 *bi_next;
	struct block_device___65 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___64 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___61 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___64 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___76 *bi_io_vec;
	struct bio_set___64 *bi_pool;
	struct bio_vec___76 bi_inline_vecs[0];
};

struct dev_pagemap_ops___136 {
	void (*page_free)(struct page___143 *);
	void (*kill)(struct dev_pagemap___136 *);
	void (*cleanup)(struct dev_pagemap___136 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___136 *);
};

struct fwnode_operations___102;

struct fwnode_handle___102 {
	struct fwnode_handle___102 *secondary;
	const struct fwnode_operations___102 *ops;
	struct device___102 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___102;

struct fwnode_endpoint___102;

struct fwnode_operations___102 {
	struct fwnode_handle___102 * (*get)(struct fwnode_handle___102 *);
	void (*put)(struct fwnode_handle___102 *);
	bool (*device_is_available)(const struct fwnode_handle___102 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___102 *, const struct device___102 *);
	bool (*property_present)(const struct fwnode_handle___102 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___102 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___102 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___102 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*get_parent)(const struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*get_next_child_node)(const struct fwnode_handle___102 *, struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*get_named_child_node)(const struct fwnode_handle___102 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___102 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___102 *);
	struct fwnode_handle___102 * (*graph_get_next_endpoint)(const struct fwnode_handle___102 *, struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*graph_get_remote_endpoint)(const struct fwnode_handle___102 *);
	struct fwnode_handle___102 * (*graph_get_port_parent)(struct fwnode_handle___102 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___102 *, struct fwnode_endpoint___102 *);
	int (*add_links)(struct fwnode_handle___102 *);
};

struct fwnode_endpoint___102 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___102 *local_fwnode;
};

struct fwnode_reference_args___102 {
	struct fwnode_handle___102 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___129;

struct kernfs_elem_dir___129 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___129 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___129;

struct kernfs_root___129 {
	struct kernfs_node___129 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___129 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___129 {
	struct kernfs_node___129 *target_kn;
};

struct kernfs_ops___129;

struct kernfs_elem_attr___129 {
	const struct kernfs_ops___129 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___129 *notify_next;
};

struct kernfs_node___129 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___129 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___129 dir;
		struct kernfs_elem_symlink___129 symlink;
		struct kernfs_elem_attr___129 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___129;

struct kernfs_ops___129 {
	int (*open)(struct kernfs_open_file___129 *);
	void (*release)(struct kernfs_open_file___129 *);
	int (*seq_show)(struct seq_file___119 *, void *);
	void * (*seq_start)(struct seq_file___119 *, loff_t *);
	void * (*seq_next)(struct seq_file___119 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___119 *, void *);
	ssize_t (*read)(struct kernfs_open_file___129 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___129 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___129 *, struct poll_table_struct___88 *);
	int (*mmap)(struct kernfs_open_file___129 *, struct vm_area_struct___143 *);
};

struct kernfs_syscall_ops___129 {
	int (*show_options)(struct seq_file___119 *, struct kernfs_root___129 *);
	int (*mkdir)(struct kernfs_node___129 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___129 *);
	int (*rename)(struct kernfs_node___129 *, struct kernfs_node___129 *, const char *);
	int (*show_path)(struct seq_file___119 *, struct kernfs_node___129 *, struct kernfs_root___129 *);
};

struct kernfs_open_file___129 {
	struct kernfs_node___129 *kn;
	struct file___138 *file;
	struct seq_file___119 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___136 *vm_ops;
};

struct bin_attribute___129;

struct attribute_group___129 {
	const char *name;
	umode_t (*is_visible)(struct kobject___129 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___129 *, struct bin_attribute___129 *, int);
	struct attribute **attrs;
	struct bin_attribute___129 **bin_attrs;
};

struct bin_attribute___129 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___138 * (*f_mapping)();
	ssize_t (*read)(struct file___138 *, struct kobject___129 *, struct bin_attribute___129 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___138 *, struct kobject___129 *, struct bin_attribute___129 *, char *, loff_t, size_t);
	int (*mmap)(struct file___138 *, struct kobject___129 *, struct bin_attribute___129 *, struct vm_area_struct___143 *);
};

struct sysfs_ops___129 {
	ssize_t (*show)(struct kobject___129 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___129 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___129;

struct kset___129 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___129 kobj;
	const struct kset_uevent_ops___129 *uevent_ops;
};

struct kobj_type___129 {
	void (*release)(struct kobject___129 *);
	const struct sysfs_ops___129 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___129 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___129 *);
	const void * (*namespace)(struct kobject___129 *);
	void (*get_ownership)(struct kobject___129 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___129 {
	int (* const filter)(struct kset___129 *, struct kobject___129 *);
	const char * (* const name)(struct kset___129 *, struct kobject___129 *);
	int (* const uevent)(struct kset___129 *, struct kobject___129 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___126 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___126 *);
	int (*get)(char *, const struct kernel_param___126 *);
	void (*free)(void *);
};

struct kparam_array___126;

struct kernel_param___126 {
	const char *name;
	struct module___127 *mod;
	const struct kernel_param_ops___126 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___126 *arr;
	};
};

struct kparam_array___126 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___126 *ops;
	void *elem;
};

struct module_attribute___126 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___126 *, struct module_kobject___126 *, char *);
	ssize_t (*store)(struct module_attribute___126 *, struct module_kobject___126 *, const char *, size_t);
	void (*setup)(struct module___127 *, const char *);
	int (*test)(struct module___127 *);
	void (*free)(struct module___127 *);
};

struct cgroup_namespace___98 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___98 *root_cset;
};

struct dev_pm_ops___102 {
	int (*prepare)(struct device___102 *);
	void (*complete)(struct device___102 *);
	int (*suspend)(struct device___102 *);
	int (*resume)(struct device___102 *);
	int (*freeze)(struct device___102 *);
	int (*thaw)(struct device___102 *);
	int (*poweroff)(struct device___102 *);
	int (*restore)(struct device___102 *);
	int (*suspend_late)(struct device___102 *);
	int (*resume_early)(struct device___102 *);
	int (*freeze_late)(struct device___102 *);
	int (*thaw_early)(struct device___102 *);
	int (*poweroff_late)(struct device___102 *);
	int (*restore_early)(struct device___102 *);
	int (*suspend_noirq)(struct device___102 *);
	int (*resume_noirq)(struct device___102 *);
	int (*freeze_noirq)(struct device___102 *);
	int (*thaw_noirq)(struct device___102 *);
	int (*poweroff_noirq)(struct device___102 *);
	int (*restore_noirq)(struct device___102 *);
	int (*runtime_suspend)(struct device___102 *);
	int (*runtime_resume)(struct device___102 *);
	int (*runtime_idle)(struct device___102 *);
};

struct wakeup_source___102 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___102 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___102 {
	struct dev_pm_ops___102 ops;
	int (*start)(struct device___102 *);
	void (*detach)(struct device___102 *, bool);
	int (*activate)(struct device___102 *);
	void (*sync)(struct device___102 *);
	void (*dismiss)(struct device___102 *);
};

struct bus_type___102 {
	const char *name;
	const char *dev_name;
	struct device___102 *dev_root;
	const struct attribute_group___129 **bus_groups;
	const struct attribute_group___129 **dev_groups;
	const struct attribute_group___129 **drv_groups;
	int (*match)(struct device___102 *, struct device_driver___102 *);
	int (*uevent)(struct device___102 *, struct kobj_uevent_env *);
	int (*probe)(struct device___102 *);
	void (*sync_state)(struct device___102 *);
	void (*remove)(struct device___102 *);
	void (*shutdown)(struct device___102 *);
	int (*online)(struct device___102 *);
	int (*offline)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	int (*num_vf)(struct device___102 *);
	int (*dma_configure)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___102 {
	const char *name;
	struct bus_type___102 *bus;
	struct module___127 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___102 *);
	void (*sync_state)(struct device___102 *);
	int (*remove)(struct device___102 *);
	void (*shutdown)(struct device___102 *);
	int (*suspend)(struct device___102 *, pm_message_t);
	int (*resume)(struct device___102 *);
	const struct attribute_group___129 **groups;
	const struct attribute_group___129 **dev_groups;
	const struct dev_pm_ops___102 *pm;
	void (*coredump)(struct device___102 *);
	struct driver_private *p;
};

struct device_type___102 {
	const char *name;
	const struct attribute_group___129 **groups;
	int (*uevent)(struct device___102 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___102 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___102 *);
	const struct dev_pm_ops___102 *pm;
};

struct class___102 {
	const char *name;
	struct module___127 *owner;
	const struct attribute_group___129 **class_groups;
	const struct attribute_group___129 **dev_groups;
	struct kobject___129 *dev_kobj;
	int (*dev_uevent)(struct device___102 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___102 *, umode_t *);
	void (*class_release)(struct class___102 *);
	void (*dev_release)(struct device___102 *);
	int (*shutdown_pre)(struct device___102 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___102 *);
	void (*get_ownership)(struct device___102 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___102 *pm;
	struct subsys_private *p;
};

struct block_device_operations___64;

struct gendisk___64 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___65 *part0;
	const struct block_device_operations___64 *fops;
	struct request_queue___64 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___61 *bdi;
	struct kobject___129 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___129 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___64 {
	struct bio___64 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___76 *bip_vec;
	struct bio_vec___76 bip_inline_vecs[0];
};

struct blkcg___61;

struct blkg_policy_data___61;

struct blkcg_gq___61 {
	struct request_queue___64 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___61 *blkcg;
	struct blkcg_gq___61 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___61 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___64 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___64(struct request___64 *);

typedef void integrity_complete_fn___64(struct request___64 *, unsigned int);

struct blk_integrity_profile___64 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___64 *prepare_fn;
	integrity_complete_fn___64 *complete_fn;
	const char *name;
};

struct block_device_operations___64 {
	blk_qc_t (*submit_bio)(struct bio___64 *);
	int (*open)(struct block_device___65 *, fmode_t);
	void (*release)(struct gendisk___64 *, fmode_t);
	int (*rw_page)(struct block_device___65 *, sector_t, struct page___143 *, unsigned int);
	int (*ioctl)(struct block_device___65 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___65 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___64 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___64 *);
	int (*getgeo)(struct block_device___65 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___65 *, bool);
	void (*swap_slot_free_notify)(struct block_device___65 *, long unsigned int);
	int (*report_zones)(struct gendisk___64 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___64 *, umode_t *);
	struct module___127 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___64 *, sector_t *);
};

typedef void rq_end_io_fn___64(struct request___64 *, blk_status_t);

struct request___64 {
	struct request_queue___64 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___61 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___64 *bio;
	struct bio___64 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___76 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___64 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___64 *saved_end_io;
		} flush;
	};
	struct gendisk___64 *rq_disk;
	struct block_device___65 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___64 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___61 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___64 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___129 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___138 *debugfs_dir;
	struct dentry___138 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___64;

struct elevator_mq_ops___64 {
	int (*init_sched)(struct request_queue___64 *, struct elevator_type___64 *);
	void (*exit_sched)(struct elevator_queue___64 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___61 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___61 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___61 *);
	bool (*allow_merge)(struct request_queue___64 *, struct request___64 *, struct bio___64 *);
	bool (*bio_merge)(struct request_queue___64 *, struct bio___64 *, unsigned int);
	int (*request_merge)(struct request_queue___64 *, struct request___64 **, struct bio___64 *);
	void (*request_merged)(struct request_queue___64 *, struct request___64 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___64 *, struct request___64 *, struct request___64 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___64 *);
	void (*finish_request)(struct request___64 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___61 *, struct list_head *, bool);
	struct request___64 * (*dispatch_request)(struct blk_mq_hw_ctx___61 *);
	bool (*has_work)(struct blk_mq_hw_ctx___61 *);
	void (*completed_request)(struct request___64 *, u64);
	void (*requeue_request)(struct request___64 *);
	struct request___64 * (*former_request)(struct request_queue___64 *, struct request___64 *);
	struct request___64 * (*next_request)(struct request_queue___64 *, struct request___64 *);
	void (*init_icq)(struct io_cq___64 *);
	void (*exit_icq)(struct io_cq___64 *);
};

struct elv_fs_entry___64;

struct elevator_type___64 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___64 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___64 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___127 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___64 {
	struct elevator_type___64 *type;
	void *elevator_data;
	struct kobject___129 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___64 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___64 *, char *);
	ssize_t (*store)(struct elevator_queue___64 *, const char *, size_t);
};

struct blk_mq_queue_data___61;

struct blk_mq_ops___61 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___61 *, const struct blk_mq_queue_data___61 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___61 *);
	int (*get_budget)(struct request_queue___64 *);
	void (*put_budget)(struct request_queue___64 *, int);
	void (*set_rq_budget_token)(struct request___64 *, int);
	int (*get_rq_budget_token)(struct request___64 *);
	enum blk_eh_timer_return (*timeout)(struct request___64 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___61 *);
	void (*complete)(struct request___64 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___61 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___61 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___61 *, struct request___64 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___61 *, struct request___64 *, unsigned int);
	void (*initialize_rq_fn)(struct request___64 *);
	void (*cleanup_rq)(struct request___64 *);
	bool (*busy)(struct request_queue___64 *);
	int (*map_queues)(struct blk_mq_tag_set___61 *);
	void (*show_rq)(struct seq_file___119 *, struct request___64 *);
};

struct blk_mq_tag_set___61 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___61 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___119 {
	void * (*start)(struct seq_file___119 *, loff_t *);
	void (*stop)(struct seq_file___119 *, void *);
	void * (*next)(struct seq_file___119 *, void *, loff_t *);
	int (*show)(struct seq_file___119 *, void *);
};

struct cftype___98;

struct cgroup_subsys___98 {
	struct cgroup_subsys_state___98 * (*css_alloc)(struct cgroup_subsys_state___98 *);
	int (*css_online)(struct cgroup_subsys_state___98 *);
	void (*css_offline)(struct cgroup_subsys_state___98 *);
	void (*css_released)(struct cgroup_subsys_state___98 *);
	void (*css_free)(struct cgroup_subsys_state___98 *);
	void (*css_reset)(struct cgroup_subsys_state___98 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___98 *, int);
	int (*css_extra_stat_show)(struct seq_file___119 *, struct cgroup_subsys_state___98 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___145 *, struct css_set___98 *);
	void (*cancel_fork)(struct task_struct___145 *, struct css_set___98 *);
	void (*fork)(struct task_struct___145 *);
	void (*exit)(struct task_struct___145 *);
	void (*release)(struct task_struct___145 *);
	void (*bind)(struct cgroup_subsys_state___98 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___98 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___98 *dfl_cftypes;
	struct cftype___98 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___98 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___98 *updated_children;
	struct cgroup___98 *updated_next;
};

struct cgroup_root___98 {
	struct kernfs_root___129 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___98 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___98 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___98 *ss;
	struct list_head node;
	struct kernfs_ops___129 *kf_ops;
	int (*open)(struct kernfs_open_file___129 *);
	void (*release)(struct kernfs_open_file___129 *);
	u64 (*read_u64)(struct cgroup_subsys_state___98 *, struct cftype___98 *);
	s64 (*read_s64)(struct cgroup_subsys_state___98 *, struct cftype___98 *);
	int (*seq_show)(struct seq_file___119 *, void *);
	void * (*seq_start)(struct seq_file___119 *, loff_t *);
	void * (*seq_next)(struct seq_file___119 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___119 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___98 *, struct cftype___98 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___98 *, struct cftype___98 *, s64);
	ssize_t (*write)(struct kernfs_open_file___129 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___129 *, struct poll_table_struct___88 *);
};

struct blk_mq_queue_data___61 {
	struct request___64 *rq;
	bool last;
};

struct blkcg_policy_data___61;

struct blkcg___61 {
	struct cgroup_subsys_state___98 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___61 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___61 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___61 {
	struct blkcg___61 *blkcg;
	int plid;
};

struct blkg_policy_data___61 {
	struct blkcg_gq___61 *blkg;
	int plid;
};

typedef struct poll_table_struct___88 poll_table___27;

struct fuse_forget_link {
	struct fuse_forget_one forget_one;
	struct fuse_forget_link *next;
};

struct fuse_mount;

struct fuse_release_args;

struct fuse_file {
	struct fuse_mount *fm;
	struct fuse_release_args *release_args;
	u64 kh;
	u64 fh;
	u64 nodeid;
	refcount_t count;
	u32 open_flags;
	struct list_head write_entry;
	struct {
		struct mutex lock;
		loff_t pos;
		loff_t cache_off;
		u64 version;
	} readdir;
	struct rb_node polled_node;
	wait_queue_head_t poll_wait;
	bool flock;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fuse_conn;

struct fuse_mount {
	struct fuse_conn *fc;
	struct super_block___138 *sb;
	struct list_head fc_entry;
};

struct fuse_in_arg {
	unsigned int size;
	const void *value;
};

struct fuse_arg {
	unsigned int size;
	void *value;
};

struct fuse_page_desc {
	unsigned int length;
	unsigned int offset;
};

struct fuse_args {
	uint64_t nodeid;
	uint32_t opcode;
	short unsigned int in_numargs;
	short unsigned int out_numargs;
	bool force: 1;
	bool noreply: 1;
	bool nocreds: 1;
	bool in_pages: 1;
	bool out_pages: 1;
	bool user_pages: 1;
	bool out_argvar: 1;
	bool page_zeroing: 1;
	bool page_replace: 1;
	bool may_block: 1;
	long: 63;
	long: 64;
	long: 64;
	struct fuse_in_arg in_args[3];
	struct fuse_arg out_args[2];
	void (*end)(struct fuse_mount *, struct fuse_args *, int);
};

struct fuse_args_pages {
	struct fuse_args args;
	struct page___143 **pages;
	struct fuse_page_desc *descs;
	unsigned int num_pages;
};

enum fuse_req_flag {
	FR_ISREPLY = 0,
	FR_FORCE = 1,
	FR_BACKGROUND = 2,
	FR_WAITING = 3,
	FR_ABORTED = 4,
	FR_INTERRUPTED = 5,
	FR_LOCKED = 6,
	FR_PENDING = 7,
	FR_SENT = 8,
	FR_FINISHED = 9,
	FR_PRIVATE = 10,
	FR_ASYNC = 11,
};

struct fuse_req {
	struct list_head list;
	struct list_head intr_entry;
	struct fuse_args *args;
	refcount_t count;
	long unsigned int flags;
	struct {
		struct fuse_in_header h;
	} in;
	struct {
		struct fuse_out_header h;
	} out;
	wait_queue_head_t waitq;
	void *argbuf;
	struct fuse_mount *fm;
};

struct fuse_iqueue;

struct fuse_iqueue_ops {
	void (*wake_forget_and_unlock)(struct fuse_iqueue *);
	void (*wake_interrupt_and_unlock)(struct fuse_iqueue *);
	void (*wake_pending_and_unlock)(struct fuse_iqueue *);
	void (*release)(struct fuse_iqueue *);
};

struct fuse_iqueue {
	unsigned int connected;
	spinlock_t lock;
	wait_queue_head_t waitq;
	u64 reqctr;
	struct list_head pending;
	struct list_head interrupts;
	struct fuse_forget_link forget_list_head;
	struct fuse_forget_link *forget_list_tail;
	int forget_batch;
	struct fasync_struct___138 *fasync;
	const struct fuse_iqueue_ops *ops;
	void *priv;
};

struct fuse_pqueue {
	unsigned int connected;
	spinlock_t lock;
	struct list_head *processing;
	struct list_head io;
};

struct fuse_dev {
	struct fuse_conn *fc;
	struct fuse_pqueue pq;
	struct list_head entry;
};

struct fuse_conn_dax;

struct fuse_sync_bucket;

struct fuse_conn {
	spinlock_t lock;
	refcount_t count;
	atomic_t dev_count;
	struct callback_head rcu;
	kuid_t user_id;
	kgid_t group_id;
	struct pid_namespace___123 *pid_ns;
	struct user_namespace___19 *user_ns;
	unsigned int max_read;
	unsigned int max_write;
	unsigned int max_pages;
	unsigned int max_pages_limit;
	struct fuse_iqueue iq;
	atomic64_t khctr;
	struct rb_root polled_files;
	unsigned int max_background;
	unsigned int congestion_threshold;
	unsigned int num_background;
	unsigned int active_background;
	struct list_head bg_queue;
	spinlock_t bg_lock;
	int initialized;
	int blocked;
	wait_queue_head_t blocked_waitq;
	unsigned int connected;
	bool aborted;
	unsigned int conn_error: 1;
	unsigned int conn_init: 1;
	unsigned int async_read: 1;
	unsigned int abort_err: 1;
	unsigned int atomic_o_trunc: 1;
	unsigned int export_support: 1;
	unsigned int writeback_cache: 1;
	unsigned int parallel_dirops: 1;
	unsigned int handle_killpriv: 1;
	unsigned int cache_symlinks: 1;
	unsigned int legacy_opts_show: 1;
	unsigned int handle_killpriv_v2: 1;
	unsigned int no_open: 1;
	unsigned int no_opendir: 1;
	unsigned int no_fsync: 1;
	unsigned int no_fsyncdir: 1;
	unsigned int no_flush: 1;
	unsigned int no_setxattr: 1;
	unsigned int setxattr_ext: 1;
	unsigned int no_getxattr: 1;
	unsigned int no_listxattr: 1;
	unsigned int no_removexattr: 1;
	unsigned int no_lock: 1;
	unsigned int no_access: 1;
	unsigned int no_create: 1;
	unsigned int no_interrupt: 1;
	unsigned int no_bmap: 1;
	unsigned int no_poll: 1;
	unsigned int big_writes: 1;
	unsigned int dont_mask: 1;
	unsigned int no_flock: 1;
	unsigned int no_fallocate: 1;
	unsigned int no_rename2: 1;
	unsigned int auto_inval_data: 1;
	unsigned int explicit_inval_data: 1;
	unsigned int do_readdirplus: 1;
	unsigned int readdirplus_auto: 1;
	unsigned int async_dio: 1;
	unsigned int no_lseek: 1;
	unsigned int posix_acl: 1;
	unsigned int default_permissions: 1;
	unsigned int allow_other: 1;
	unsigned int no_copy_file_range: 1;
	unsigned int destroy: 1;
	unsigned int delete_stale: 1;
	unsigned int no_control: 1;
	unsigned int no_force_umount: 1;
	unsigned int auto_submounts: 1;
	unsigned int sync_fs: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t num_waiting;
	unsigned int minor;
	struct list_head entry;
	dev_t dev;
	struct dentry___138 *ctl_dentry[5];
	int ctl_ndents;
	u32 scramble_key[4];
	atomic64_t attr_version;
	void (*release)(struct fuse_conn *);
	struct rw_semaphore killsb;
	struct list_head devices;
	struct fuse_conn_dax *dax;
	struct list_head mounts;
	struct fuse_sync_bucket *curr_bucket;
};

struct fuse_sync_bucket {
	atomic_t count;
	wait_queue_head_t waitq;
	struct callback_head rcu;
};

struct miscdevice___3 {
	int minor;
	const char *name;
	const struct file_operations___138 *fops;
	struct list_head list;
	struct device___102 *parent;
	struct device___102 *this_device;
	const struct attribute_group___129 **groups;
	const char *nodename;
	umode_t mode;
};

struct pipe_buf_operations___43;

struct pipe_buffer___43 {
	struct page___143 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___43 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___43 {
	int (*confirm)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
	void (*release)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
	bool (*try_steal)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
	bool (*get)(struct pipe_inode_info___43 *, struct pipe_buffer___43 *);
};

struct mem_cgroup_reclaim_iter___52 {
	struct mem_cgroup___52 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___52 {
	struct lruvec___59 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___52 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___52 *memcg;
};

struct obj_cgroup___52 {
	struct percpu_ref refcnt;
	struct mem_cgroup___52 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fuse_copy_state {
	int write;
	struct fuse_req *req;
	struct iov_iter___78 *iter;
	struct pipe_buffer___43 *pipebufs;
	struct pipe_buffer___43 *currbuf;
	struct pipe_inode_info___43 *pipe;
	long unsigned int nr_segs;
	struct page___143 *pg;
	unsigned int len;
	unsigned int offset;
	unsigned int move_pages: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fuse_retrieve_args {
	struct fuse_args_pages ap;
	struct fuse_notify_retrieve_in inarg;
};

struct fuse_attr {
	uint64_t ino;
	uint64_t size;
	uint64_t blocks;
	uint64_t atime;
	uint64_t mtime;
	uint64_t ctime;
	uint32_t atimensec;
	uint32_t mtimensec;
	uint32_t ctimensec;
	uint32_t mode;
	uint32_t nlink;
	uint32_t uid;
	uint32_t gid;
	uint32_t rdev;
	uint32_t blksize;
	uint32_t flags;
};

struct fuse_entry_out {
	uint64_t nodeid;
	uint64_t generation;
	uint64_t entry_valid;
	uint64_t attr_valid;
	uint32_t entry_valid_nsec;
	uint32_t attr_valid_nsec;
	struct fuse_attr attr;
};

struct fuse_getattr_in {
	uint32_t getattr_flags;
	uint32_t dummy;
	uint64_t fh;
};

struct fuse_attr_out {
	uint64_t attr_valid;
	uint32_t attr_valid_nsec;
	uint32_t dummy;
	struct fuse_attr attr;
};

struct fuse_mknod_in {
	uint32_t mode;
	uint32_t rdev;
	uint32_t umask;
	uint32_t padding;
};

struct fuse_mkdir_in {
	uint32_t mode;
	uint32_t umask;
};

struct fuse_rename2_in {
	uint64_t newdir;
	uint32_t flags;
	uint32_t padding;
};

struct fuse_link_in {
	uint64_t oldnodeid;
};

struct fuse_setattr_in {
	uint32_t valid;
	uint32_t padding;
	uint64_t fh;
	uint64_t size;
	uint64_t lock_owner;
	uint64_t atime;
	uint64_t mtime;
	uint64_t ctime;
	uint32_t atimensec;
	uint32_t mtimensec;
	uint32_t ctimensec;
	uint32_t mode;
	uint32_t unused4;
	uint32_t uid;
	uint32_t gid;
	uint32_t unused5;
};

struct fuse_create_in {
	uint32_t flags;
	uint32_t mode;
	uint32_t umask;
	uint32_t open_flags;
};

struct fuse_open_out {
	uint64_t fh;
	uint32_t open_flags;
	uint32_t padding;
};

struct fuse_access_in {
	uint32_t mask;
	uint32_t padding;
};

struct fuse_inode_dax;

struct fuse_inode {
	struct inode___73 inode;
	u64 nodeid;
	u64 nlookup;
	struct fuse_forget_link *forget;
	u64 i_time;
	u32 inval_mask;
	umode_t orig_i_mode;
	u64 orig_ino;
	u64 attr_version;
	union {
		struct {
			struct list_head write_files;
			struct list_head queued_writes;
			int writectr;
			wait_queue_head_t page_waitq;
			struct rb_root writepages;
		};
		struct {
			bool cached;
			loff_t size;
			loff_t pos;
			u64 version;
			struct timespec64 mtime;
			u64 iversion;
			spinlock_t lock;
		} rdc;
	};
	long unsigned int state;
	struct mutex mutex;
	spinlock_t lock;
	struct fuse_inode_dax *dax;
};

enum {
	FUSE_I_ADVISE_RDPLUS = 0,
	FUSE_I_INIT_RDPLUS = 1,
	FUSE_I_SIZE_UNSTABLE = 2,
	FUSE_I_BAD = 3,
};

struct fuse_mount___2;

struct fuse_file___2 {
	struct fuse_mount___2 *fm;
	struct fuse_release_args *release_args;
	u64 kh;
	u64 fh;
	u64 nodeid;
	refcount_t count;
	u32 open_flags;
	struct list_head write_entry;
	struct {
		struct mutex lock;
		loff_t pos;
		loff_t cache_off;
		u64 version;
	} readdir;
	struct rb_node polled_node;
	wait_queue_head_t poll_wait;
	bool flock: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fuse_conn___2;

struct fuse_mount___2 {
	struct fuse_conn___2 *fc;
	struct super_block___73 *sb;
	struct list_head fc_entry;
};

struct fuse_args___2 {
	uint64_t nodeid;
	uint32_t opcode;
	short unsigned int in_numargs;
	short unsigned int out_numargs;
	bool force: 1;
	bool noreply: 1;
	bool nocreds: 1;
	bool in_pages: 1;
	bool out_pages: 1;
	bool user_pages: 1;
	bool out_argvar: 1;
	bool page_zeroing: 1;
	bool page_replace: 1;
	bool may_block: 1;
	long: 63;
	long: 64;
	long: 64;
	struct fuse_in_arg in_args[3];
	struct fuse_arg out_args[2];
	void (*end)(struct fuse_mount___2 *, struct fuse_args___2 *, int);
};

struct fuse_args_pages___2 {
	struct fuse_args___2 args;
	struct page___77 **pages;
	struct fuse_page_desc *descs;
	unsigned int num_pages;
};

struct fuse_iqueue___2;

struct fuse_iqueue_ops___2 {
	void (*wake_forget_and_unlock)(struct fuse_iqueue___2 *);
	void (*wake_interrupt_and_unlock)(struct fuse_iqueue___2 *);
	void (*wake_pending_and_unlock)(struct fuse_iqueue___2 *);
	void (*release)(struct fuse_iqueue___2 *);
};

struct fuse_iqueue___2 {
	unsigned int connected;
	spinlock_t lock;
	wait_queue_head_t waitq;
	u64 reqctr;
	struct list_head pending;
	struct list_head interrupts;
	struct fuse_forget_link forget_list_head;
	struct fuse_forget_link *forget_list_tail;
	int forget_batch;
	struct fasync_struct___72 *fasync;
	const struct fuse_iqueue_ops___2 *ops;
	void *priv;
};

struct fuse_conn___2 {
	spinlock_t lock;
	refcount_t count;
	atomic_t dev_count;
	struct callback_head rcu;
	kuid_t user_id;
	kgid_t group_id;
	struct pid_namespace___65 *pid_ns;
	struct user_namespace___12 *user_ns;
	unsigned int max_read;
	unsigned int max_write;
	unsigned int max_pages;
	unsigned int max_pages_limit;
	struct fuse_iqueue___2 iq;
	atomic64_t khctr;
	struct rb_root polled_files;
	unsigned int max_background;
	unsigned int congestion_threshold;
	unsigned int num_background;
	unsigned int active_background;
	struct list_head bg_queue;
	spinlock_t bg_lock;
	int initialized;
	int blocked;
	wait_queue_head_t blocked_waitq;
	unsigned int connected;
	bool aborted;
	unsigned int conn_error: 1;
	unsigned int conn_init: 1;
	unsigned int async_read: 1;
	unsigned int abort_err: 1;
	unsigned int atomic_o_trunc: 1;
	unsigned int export_support: 1;
	unsigned int writeback_cache: 1;
	unsigned int parallel_dirops: 1;
	unsigned int handle_killpriv: 1;
	unsigned int cache_symlinks: 1;
	unsigned int legacy_opts_show: 1;
	unsigned int handle_killpriv_v2: 1;
	unsigned int no_open: 1;
	unsigned int no_opendir: 1;
	unsigned int no_fsync: 1;
	unsigned int no_fsyncdir: 1;
	unsigned int no_flush: 1;
	unsigned int no_setxattr: 1;
	unsigned int setxattr_ext: 1;
	unsigned int no_getxattr: 1;
	unsigned int no_listxattr: 1;
	unsigned int no_removexattr: 1;
	unsigned int no_lock: 1;
	unsigned int no_access: 1;
	unsigned int no_create: 1;
	unsigned int no_interrupt: 1;
	unsigned int no_bmap: 1;
	unsigned int no_poll: 1;
	unsigned int big_writes: 1;
	unsigned int dont_mask: 1;
	unsigned int no_flock: 1;
	unsigned int no_fallocate: 1;
	unsigned int no_rename2: 1;
	unsigned int auto_inval_data: 1;
	unsigned int explicit_inval_data: 1;
	unsigned int do_readdirplus: 1;
	unsigned int readdirplus_auto: 1;
	unsigned int async_dio: 1;
	unsigned int no_lseek: 1;
	unsigned int posix_acl: 1;
	unsigned int default_permissions: 1;
	unsigned int allow_other: 1;
	unsigned int no_copy_file_range: 1;
	unsigned int destroy: 1;
	unsigned int delete_stale: 1;
	unsigned int no_control: 1;
	unsigned int no_force_umount: 1;
	unsigned int auto_submounts: 1;
	unsigned int sync_fs: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t num_waiting;
	unsigned int minor;
	struct list_head entry;
	dev_t dev;
	struct dentry___73 *ctl_dentry[5];
	int ctl_ndents;
	u32 scramble_key[4];
	atomic64_t attr_version;
	void (*release)(struct fuse_conn___2 *);
	struct rw_semaphore killsb;
	struct list_head devices;
	struct fuse_conn_dax *dax;
	struct list_head mounts;
	struct fuse_sync_bucket *curr_bucket;
};

struct fuse_file_lock {
	uint64_t start;
	uint64_t end;
	uint32_t type;
	uint32_t pid;
};

struct fuse_open_in {
	uint32_t flags;
	uint32_t open_flags;
};

struct fuse_release_in {
	uint64_t fh;
	uint32_t flags;
	uint32_t release_flags;
	uint64_t lock_owner;
};

struct fuse_flush_in {
	uint64_t fh;
	uint32_t unused;
	uint32_t padding;
	uint64_t lock_owner;
};

struct fuse_read_in {
	uint64_t fh;
	uint64_t offset;
	uint32_t size;
	uint32_t read_flags;
	uint64_t lock_owner;
	uint32_t flags;
	uint32_t padding;
};

struct fuse_write_in {
	uint64_t fh;
	uint64_t offset;
	uint32_t size;
	uint32_t write_flags;
	uint64_t lock_owner;
	uint32_t flags;
	uint32_t padding;
};

struct fuse_write_out {
	uint32_t size;
	uint32_t padding;
};

struct fuse_fsync_in {
	uint64_t fh;
	uint32_t fsync_flags;
	uint32_t padding;
};

struct fuse_lk_in {
	uint64_t fh;
	uint64_t owner;
	struct fuse_file_lock lk;
	uint32_t lk_flags;
	uint32_t padding;
};

struct fuse_lk_out {
	struct fuse_file_lock lk;
};

struct fuse_bmap_in {
	uint64_t block;
	uint32_t blocksize;
	uint32_t padding;
};

struct fuse_bmap_out {
	uint64_t block;
};

struct fuse_poll_in {
	uint64_t fh;
	uint64_t kh;
	uint32_t flags;
	uint32_t events;
};

struct fuse_poll_out {
	uint32_t revents;
	uint32_t padding;
};

struct fuse_fallocate_in {
	uint64_t fh;
	uint64_t offset;
	uint64_t length;
	uint32_t mode;
	uint32_t padding;
};

struct fuse_lseek_in {
	uint64_t fh;
	uint64_t offset;
	uint32_t whence;
	uint32_t padding;
};

struct fuse_lseek_out {
	uint64_t offset;
};

struct fuse_copy_file_range_in {
	uint64_t fh_in;
	uint64_t off_in;
	uint64_t nodeid_out;
	uint64_t fh_out;
	uint64_t off_out;
	uint64_t len;
	uint64_t flags;
};

typedef int (*writepage_t___5)(struct page___143 *, struct writeback_control___61 *, void *);

struct fuse_inode___2 {
	struct inode___138 inode;
	u64 nodeid;
	u64 nlookup;
	struct fuse_forget_link *forget;
	u64 i_time;
	u32 inval_mask;
	umode_t orig_i_mode;
	u64 orig_ino;
	u64 attr_version;
	union {
		struct {
			struct list_head write_files;
			struct list_head queued_writes;
			int writectr;
			wait_queue_head_t page_waitq;
			struct rb_root writepages;
		};
		struct {
			bool cached;
			loff_t size;
			loff_t pos;
			u64 version;
			struct timespec64 mtime;
			u64 iversion;
			spinlock_t lock;
		} rdc;
	};
	long unsigned int state;
	struct mutex mutex;
	spinlock_t lock;
	struct fuse_inode_dax *dax;
};

struct fuse_release_args {
	struct fuse_args args;
	struct fuse_release_in inarg;
	struct inode___138 *inode;
};

struct fuse_io_priv {
	struct kref refcnt;
	int async;
	spinlock_t lock;
	unsigned int reqs;
	ssize_t bytes;
	size_t size;
	__u64 offset;
	bool write;
	bool should_dirty;
	int err;
	struct kiocb___138 *iocb;
	struct completion *done;
	bool blocking;
};

struct fuse_io_args {
	union {
		struct {
			struct fuse_read_in in;
			u64 attr_ver;
		} read;
		struct {
			struct fuse_write_in in;
			struct fuse_write_out out;
			bool page_locked;
		} write;
	};
	struct fuse_args_pages ap;
	struct fuse_io_priv *io;
	struct fuse_file *ff;
};

struct fuse_writepage_args {
	struct fuse_io_args ia;
	struct rb_node writepages_entry;
	struct list_head queue_entry;
	struct fuse_writepage_args *next;
	struct inode___138 *inode;
	struct fuse_sync_bucket *bucket;
};

struct fuse_fill_wb_data {
	struct fuse_writepage_args *wpa;
	struct fuse_file *ff;
	struct inode___138 *inode;
	struct page___143 **orig_pages;
	unsigned int max_pages;
};

struct fuse_kstatfs {
	uint64_t blocks;
	uint64_t bfree;
	uint64_t bavail;
	uint64_t files;
	uint64_t ffree;
	uint32_t bsize;
	uint32_t namelen;
	uint32_t frsize;
	uint32_t padding;
	uint32_t spare[6];
};

struct fuse_statfs_out {
	struct fuse_kstatfs st;
};

struct fuse_init_in {
	uint32_t major;
	uint32_t minor;
	uint32_t max_readahead;
	uint32_t flags;
};

struct fuse_init_out {
	uint32_t major;
	uint32_t minor;
	uint32_t max_readahead;
	uint32_t flags;
	uint16_t max_background;
	uint16_t congestion_threshold;
	uint32_t max_write;
	uint32_t time_gran;
	uint16_t max_pages;
	uint16_t map_alignment;
	uint32_t unused[8];
};

struct fuse_syncfs_in {
	uint64_t padding;
};

struct fuse_dev___2 {
	struct fuse_conn___2 *fc;
	struct fuse_pqueue pq;
	struct list_head entry;
};

struct fuse_fs_context {
	int fd;
	struct file___72 *file;
	unsigned int rootmode;
	kuid_t user_id;
	kgid_t group_id;
	bool is_bdev: 1;
	bool fd_present: 1;
	bool rootmode_present: 1;
	bool user_id_present: 1;
	bool group_id_present: 1;
	bool default_permissions: 1;
	bool allow_other: 1;
	bool destroy: 1;
	bool no_control: 1;
	bool no_force_umount: 1;
	bool legacy_opts_show: 1;
	bool dax: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_read;
	unsigned int blksize;
	const char *subtype;
	struct dax_device *dax_dev;
	void **fudptr;
};

enum {
	OPT_SOURCE = 0,
	OPT_SUBTYPE = 1,
	OPT_FD = 2,
	OPT_ROOTMODE = 3,
	OPT_USER_ID = 4,
	OPT_GROUP_ID = 5,
	OPT_DEFAULT_PERMISSIONS = 6,
	OPT_ALLOW_OTHER = 7,
	OPT_MAX_READ = 8,
	OPT_BLKSIZE = 9,
	OPT_ERR = 10,
};

struct fuse_inode_handle {
	u64 nodeid;
	u32 generation;
};

struct fuse_init_args {
	struct fuse_args___2 args;
	struct fuse_init_in in;
	struct fuse_init_out out;
};

struct tree_descr___3 {
	const char *name;
	const struct file_operations___72 *ops;
	int mode;
};

struct fuse_setxattr_in {
	uint32_t size;
	uint32_t flags;
	uint32_t setxattr_flags;
	uint32_t padding;
};

struct fuse_getxattr_in {
	uint32_t size;
	uint32_t padding;
};

struct fuse_getxattr_out {
	uint32_t size;
	uint32_t padding;
};

struct fuse_dirent {
	uint64_t ino;
	uint64_t off;
	uint32_t namelen;
	uint32_t type;
	char name[0];
};

struct fuse_direntplus {
	struct fuse_entry_out entry_out;
	struct fuse_dirent dirent;
};

enum fuse_parse_result {
	FOUND_ERR = 4294967295,
	FOUND_NONE = 0,
	FOUND_SOME = 1,
	FOUND_ALL = 2,
};

struct fuse_ioctl_in {
	uint64_t fh;
	uint32_t flags;
	uint32_t cmd;
	uint64_t arg;
	uint32_t in_size;
	uint32_t out_size;
};

struct fuse_ioctl_iovec {
	uint64_t base;
	uint64_t len;
};

struct fuse_ioctl_out {
	int32_t result;
	uint32_t flags;
	uint32_t in_iovs;
	uint32_t out_iovs;
};

struct fuse_setupmapping_in {
	uint64_t fh;
	uint64_t foffset;
	uint64_t len;
	uint64_t flags;
	uint64_t moffset;
};

struct fuse_removemapping_in {
	uint32_t count;
};

struct fuse_removemapping_one {
	uint64_t moffset;
	uint64_t len;
};

struct fuse_inode_dax {
	struct rw_semaphore sem;
	struct rb_root_cached tree;
	long unsigned int nr;
};

struct fuse_io_priv___2 {
	struct kref refcnt;
	int async;
	spinlock_t lock;
	unsigned int reqs;
	ssize_t bytes;
	size_t size;
	__u64 offset;
	bool write;
	bool should_dirty;
	int err;
	struct kiocb___72 *iocb;
	struct completion *done;
	bool blocking;
};

struct fuse_conn_dax {
	struct dax_device *dev;
	spinlock_t lock;
	long unsigned int nr_busy_ranges;
	struct list_head busy_ranges;
	struct delayed_work free_work;
	wait_queue_head_t range_waitq;
	long int nr_free_ranges;
	struct list_head free_ranges;
	long unsigned int nr_ranges;
};

struct iomap_page_ops___4;

struct iomap___5 {
	u64 addr;
	loff_t offset;
	u64 length;
	u16 type;
	u16 flags;
	struct block_device___34 *bdev;
	struct dax_device *dax_dev;
	void *inline_data;
	void *private;
	const struct iomap_page_ops___4 *page_ops;
};

struct iomap_page_ops___4 {
	int (*page_prepare)(struct inode___73 *, loff_t, unsigned int);
	void (*page_done)(struct inode___73 *, loff_t, unsigned int, struct page___77 *);
};

struct iomap_ops___4 {
	int (*iomap_begin)(struct inode___73 *, loff_t, loff_t, unsigned int, struct iomap___5 *, struct iomap___5 *);
	int (*iomap_end)(struct inode___73 *, loff_t, loff_t, ssize_t, unsigned int, struct iomap___5 *);
};

struct fuse_dax_mapping {
	struct inode___73 *inode;
	struct list_head list;
	struct interval_tree_node itn;
	struct list_head busy_list;
	u64 window_offset;
	loff_t length;
	bool writable;
	refcount_t refcnt;
};

struct tree_descr___4 {
	const char *name;
	const struct file_operations___130 *ops;
	int mode;
};

typedef struct vfsmount___130 * (*debugfs_automount_t___2)(struct dentry___130 *, void *);

struct debugfs_fsdata {
	const struct file_operations___130 *real_fops;
	refcount_t active_users;
	struct completion active_users_drained;
};

struct debugfs_mount_opts {
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

enum {
	Opt_uid___5 = 0,
	Opt_gid___6 = 1,
	Opt_mode___5 = 2,
	Opt_err___4 = 3,
};

struct debugfs_fs_info {
	struct debugfs_mount_opts mount_opts;
};

struct debugfs_blob_wrapper {
	void *data;
	long unsigned int size;
};

struct debugfs_reg32 {
	char *name;
	long unsigned int offset;
};

struct debugfs_regset32 {
	const struct debugfs_reg32 *regs;
	int nregs;
	void *base;
	struct device___102 *dev;
};

struct debugfs_u32_array {
	u32 *array;
	u32 n_elements;
};

struct debugfs_fsdata___2 {
	const struct file_operations___138 *real_fops;
	refcount_t active_users;
	struct completion active_users_drained;
};

struct debugfs_devm_entry {
	int (*read)(struct seq_file___119 *, void *);
	struct device___102 *dev;
};

struct tracefs_dir_ops {
	int (*mkdir)(const char *);
	int (*rmdir)(const char *);
};

struct tracefs_mount_opts {
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct tracefs_fs_info {
	struct tracefs_mount_opts mount_opts;
};

struct fs_context___24;

struct fs_parameter_spec___17;

struct dentry___139;

struct super_block___139;

struct module___128;

struct file_system_type___139 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___24 *);
	const struct fs_parameter_spec___17 *parameters;
	struct dentry___139 * (*mount)(struct file_system_type___139 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___139 *);
	struct module___128 *owner;
	struct file_system_type___139 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___139;

struct kiocb___139;

struct vm_area_struct___144;

struct inode___139;

struct file_lock___139;

struct page___144;

struct seq_file___120;

struct file_operations___139 {
	struct module___128 *owner;
	loff_t (*llseek)(struct file___139 *, loff_t, int);
	ssize_t (*read)(struct file___139 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___139 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___139 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___139 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___139 *, bool);
	int (*iterate)(struct file___139 *, struct dir_context *);
	int (*iterate_shared)(struct file___139 *, struct dir_context *);
	__poll_t (*poll)(struct file___139 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___139 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___139 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___139 *, struct vm_area_struct___144 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___139 *, struct file___139 *);
	int (*flush)(struct file___139 *, fl_owner_t);
	int (*release)(struct inode___139 *, struct file___139 *);
	int (*fsync)(struct file___139 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___139 *, int);
	int (*lock)(struct file___139 *, int, struct file_lock___139 *);
	ssize_t (*sendpage)(struct file___139 *, struct page___144 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___139 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___139 *, long unsigned int);
	int (*flock)(struct file___139 *, int, struct file_lock___139 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___139 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___139 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___139 *, long int, struct file_lock___139 **, void **);
	long int (*fallocate)(struct file___139 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___120 *, struct file___139 *);
	ssize_t (*copy_file_range)(struct file___139 *, loff_t, struct file___139 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___139 *, loff_t, struct file___139 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___139 *, loff_t, loff_t, int);
};

struct vmacache___144 {
	u64 seqnum;
	struct vm_area_struct___144 *vmas[4];
};

struct page_frag___144 {
	struct page___144 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___145;

struct pid___124;

struct nsproxy___130;

struct signal_struct___140;

struct vm_struct___126;

struct task_struct___146 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___146 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___145 *mm;
	struct mm_struct___145 *active_mm;
	struct vmacache___144 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___146 *real_parent;
	struct task_struct___146 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___146 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___124 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___130 *nsproxy;
	struct signal_struct___140 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___146 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___64 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___144 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___146 *oom_reaper_list;
	struct vm_struct___126 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___130;

struct kobj_type___130;

struct kernfs_node___130;

struct kobject___130 {
	const char *name;
	struct list_head entry;
	struct kobject___130 *parent;
	struct kset___130 *kset;
	struct kobj_type___130 *ktype;
	struct kernfs_node___130 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___127 {
	struct kobject___130 kobj;
	struct module___128 *mod;
	struct kobject___130 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___127 {
	struct module___128 *mod;
	struct latch_tree_node node;
};

struct module_layout___127 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___127 mtn;
};

struct module_attribute___127;

struct kernel_param___127;

struct module___128 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___127 mkobj;
	struct module_attribute___127 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___130 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___127 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___127 core_layout;
	struct module_layout___127 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___124;

struct upid___124 {
	int nr;
	struct pid_namespace___124 *ns;
};

struct pid_namespace___124 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___146 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___124 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___124 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___124 numbers[1];
};

typedef struct page___144 *pgtable_t___144;

struct address_space___139;

struct dev_pagemap___137;

struct page___144 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___139 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___144 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___144 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___145 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___137 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___137;

struct vm_area_struct___144 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___144 *vm_next;
	struct vm_area_struct___144 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___145 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___137 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___139 *vm_file;
	struct file___139 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___140 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___146 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___146 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___124 *pids[4];
	struct pid___124 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___145 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___144;

struct mm_struct___145 {
	struct {
		struct vm_area_struct___144 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___139 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___144 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___146 *owner;
		struct user_namespace___19 *user_ns;
		struct file___139 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___130 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___124 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___126 {
	struct vm_struct___126 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___144 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___139;

struct address_space___139 {
	struct inode___139 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___139 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___137;

struct dev_pagemap___137 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___137 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___139;

struct path___139 {
	struct vfsmount___139 *mnt;
	struct dentry___139 *dentry;
};

struct fown_struct___124 {
	rwlock_t lock;
	struct pid___124 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___139 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___139 f_path;
	struct inode___139 *f_inode;
	const struct file_operations___139 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___124 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___139 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___137;

struct vm_operations_struct___137 {
	void (*open)(struct vm_area_struct___144 *);
	void (*close)(struct vm_area_struct___144 *);
	int (*may_split)(struct vm_area_struct___144 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___144 *);
	int (*mprotect)(struct vm_area_struct___144 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___137 *);
	vm_fault_t (*huge_fault)(struct vm_fault___137 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___137 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___144 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___137 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___137 *);
	int (*access)(struct vm_area_struct___144 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___144 *);
	int (*set_policy)(struct vm_area_struct___144 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___144 *, long unsigned int);
	struct page___144 * (*find_special_page)(struct vm_area_struct___144 *, long unsigned int);
};

struct core_thread___144 {
	struct task_struct___146 *task;
	struct core_thread___144 *next;
};

struct core_state___144 {
	atomic_t nr_threads;
	struct core_thread___144 dumper;
	struct completion startup;
};

struct vm_fault___137 {
	const struct {
		struct vm_area_struct___144 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___144 *cow_page;
	struct page___144 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___144 prealloc_pte;
};

struct dentry_operations___139;

struct dentry___139 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___139 *d_parent;
	struct qstr d_name;
	struct inode___139 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___139 *d_op;
	struct super_block___139 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___139;

struct inode___139 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___139 *i_op;
	struct super_block___139 *i_sb;
	struct address_space___139 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___139 *i_fop;
		void (*free_inode)(struct inode___139 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___139 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___43 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___139 {
	int (*d_revalidate)(struct dentry___139 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___139 *, unsigned int);
	int (*d_hash)(const struct dentry___139 *, struct qstr *);
	int (*d_compare)(const struct dentry___139 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___139 *);
	int (*d_init)(struct dentry___139 *);
	void (*d_release)(struct dentry___139 *);
	void (*d_prune)(struct dentry___139 *);
	void (*d_iput)(struct dentry___139 *, struct inode___139 *);
	char * (*d_dname)(struct dentry___139 *, char *, int);
	struct vfsmount___139 * (*d_automount)(struct path___139 *);
	int (*d_manage)(const struct path___139 *, bool);
	struct dentry___139 * (*d_real)(struct dentry___139 *, const struct inode___139 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___139;

struct mem_dqinfo___139 {
	struct quota_format_type___139 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___139;

struct quota_info___139 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___139 *files[3];
	struct mem_dqinfo___139 info[3];
	const struct quota_format_ops___139 *ops[3];
};

struct rcuwait___140 {
	struct task_struct___146 *task;
};

struct percpu_rw_semaphore___140 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___140 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___139 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___140 rw_sem[3];
};

struct super_operations___139;

struct dquot_operations___139;

struct quotactl_ops___139;

struct super_block___139 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___139 *s_type;
	const struct super_operations___139 *s_op;
	const struct dquot_operations___139 *dq_op;
	const struct quotactl_ops___139 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___139 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___139 s_dquot;
	struct sb_writers___139 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___139 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___139 {
	struct dentry___139 *mnt_root;
	struct super_block___139 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct wait_page_queue___68;

struct kiocb___139 {
	struct file___139 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___139 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___68 *ki_waitq;
	};
};

struct iattr___139 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___139 *ia_file;
};

struct dquot___139 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___139 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___139 {
	int qf_fmt_id;
	const struct quota_format_ops___139 *qf_ops;
	struct module___128 *qf_owner;
	struct quota_format_type___139 *qf_next;
};

struct quota_format_ops___139 {
	int (*check_quota_file)(struct super_block___139 *, int);
	int (*read_file_info)(struct super_block___139 *, int);
	int (*write_file_info)(struct super_block___139 *, int);
	int (*free_file_info)(struct super_block___139 *, int);
	int (*read_dqblk)(struct dquot___139 *);
	int (*commit_dqblk)(struct dquot___139 *);
	int (*release_dqblk)(struct dquot___139 *);
	int (*get_next_id)(struct super_block___139 *, struct kqid *);
};

struct dquot_operations___139 {
	int (*write_dquot)(struct dquot___139 *);
	struct dquot___139 * (*alloc_dquot)(struct super_block___139 *, int);
	void (*destroy_dquot)(struct dquot___139 *);
	int (*acquire_dquot)(struct dquot___139 *);
	int (*release_dquot)(struct dquot___139 *);
	int (*mark_dirty)(struct dquot___139 *);
	int (*write_info)(struct super_block___139 *, int);
	qsize_t * (*get_reserved_space)(struct inode___139 *);
	int (*get_projid)(struct inode___139 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___139 *, qsize_t *);
	int (*get_next_id)(struct super_block___139 *, struct kqid *);
};

struct quotactl_ops___139 {
	int (*quota_on)(struct super_block___139 *, int, int, const struct path___139 *);
	int (*quota_off)(struct super_block___139 *, int);
	int (*quota_enable)(struct super_block___139 *, unsigned int);
	int (*quota_disable)(struct super_block___139 *, unsigned int);
	int (*quota_sync)(struct super_block___139 *, int);
	int (*set_info)(struct super_block___139 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___139 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___139 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___139 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___139 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___139 *, unsigned int);
};

struct wait_page_queue___68 {
	struct page___144 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___68;

struct address_space_operations___139 {
	int (*writepage)(struct page___144 *, struct writeback_control___3 *);
	int (*readpage)(struct file___139 *, struct page___144 *);
	int (*writepages)(struct address_space___139 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___144 *);
	int (*readpages)(struct file___139 *, struct address_space___139 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___68 *);
	int (*write_begin)(struct file___139 *, struct address_space___139 *, loff_t, unsigned int, unsigned int, struct page___144 **, void **);
	int (*write_end)(struct file___139 *, struct address_space___139 *, loff_t, unsigned int, unsigned int, struct page___144 *, void *);
	sector_t (*bmap)(struct address_space___139 *, sector_t);
	void (*invalidatepage)(struct page___144 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___144 *, gfp_t);
	void (*freepage)(struct page___144 *);
	ssize_t (*direct_IO)(struct kiocb___139 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___139 *, struct page___144 *, struct page___144 *, enum migrate_mode);
	bool (*isolate_page)(struct page___144 *, isolate_mode_t);
	void (*putback_page)(struct page___144 *);
	int (*launder_page)(struct page___144 *);
	int (*is_partially_uptodate)(struct page___144 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___144 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___139 *, struct page___144 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___139 *, sector_t *);
	void (*swap_deactivate)(struct file___139 *);
};

struct readahead_control___68 {
	struct file___139 *file;
	struct address_space___139 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct inode_operations___139 {
	struct dentry___139 * (*lookup)(struct inode___139 *, struct dentry___139 *, unsigned int);
	const char * (*get_link)(struct dentry___139 *, struct inode___139 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___139 *, int);
	struct posix_acl * (*get_acl)(struct inode___139 *, int, bool);
	int (*readlink)(struct dentry___139 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___139 *, struct dentry___139 *, umode_t, bool);
	int (*link)(struct dentry___139 *, struct inode___139 *, struct dentry___139 *);
	int (*unlink)(struct inode___139 *, struct dentry___139 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___139 *, struct dentry___139 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___139 *, struct dentry___139 *, umode_t);
	int (*rmdir)(struct inode___139 *, struct dentry___139 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___139 *, struct dentry___139 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___139 *, struct dentry___139 *, struct inode___139 *, struct dentry___139 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___139 *, struct iattr___139 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___139 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___139 *, char *, size_t);
	int (*fiemap)(struct inode___139 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___139 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___139 *, struct dentry___139 *, struct file___139 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___139 *, struct dentry___139 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___139 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___139 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___139 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___139 {
	void (*fl_copy_lock)(struct file_lock___139 *, struct file_lock___139 *);
	void (*fl_release_private)(struct file_lock___139 *);
};

struct fasync_struct___139;

struct lock_manager_operations___139;

struct file_lock___139 {
	struct file_lock___139 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___139 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___139 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___139 *fl_ops;
	const struct lock_manager_operations___139 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___139 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___139 *);
	int (*lm_grant)(struct file_lock___139 *, int);
	bool (*lm_break)(struct file_lock___139 *);
	int (*lm_change)(struct file_lock___139 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___139 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___139 *);
};

struct fasync_struct___139 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___139 *fa_next;
	struct file___139 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___139 {
	struct inode___139 * (*alloc_inode)(struct super_block___139 *);
	void (*destroy_inode)(struct inode___139 *);
	void (*free_inode)(struct inode___139 *);
	void (*dirty_inode)(struct inode___139 *, int);
	int (*write_inode)(struct inode___139 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___139 *);
	void (*evict_inode)(struct inode___139 *);
	void (*put_super)(struct super_block___139 *);
	int (*sync_fs)(struct super_block___139 *, int);
	int (*freeze_super)(struct super_block___139 *);
	int (*freeze_fs)(struct super_block___139 *);
	int (*thaw_super)(struct super_block___139 *);
	int (*unfreeze_fs)(struct super_block___139 *);
	int (*statfs)(struct dentry___139 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___139 *, int *, char *);
	void (*umount_begin)(struct super_block___139 *);
	int (*show_options)(struct seq_file___120 *, struct dentry___139 *);
	int (*show_devname)(struct seq_file___120 *, struct dentry___139 *);
	int (*show_path)(struct seq_file___120 *, struct dentry___139 *);
	int (*show_stats)(struct seq_file___120 *, struct dentry___139 *);
	ssize_t (*quota_read)(struct super_block___139 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___139 *, int, const char *, size_t, loff_t);
	struct dquot___139 ** (*get_dquots)(struct inode___139 *);
	long int (*nr_cached_objects)(struct super_block___139 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___139 *, struct shrink_control___52 *);
	struct file___139 * (*real_loop)(struct file___139 *);
};

struct seq_operations___120;

struct seq_file___120 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___120 *op;
	int poll_event;
	const struct file___139 *file;
	void *private;
};

struct fc_log___24;

struct p_log___24 {
	const char *prefix;
	struct fc_log___24 *log;
};

struct fs_context_operations___24;

struct fs_context___24 {
	const struct fs_context_operations___24 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___139 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___139 *root;
	struct user_namespace___19 *user_ns;
	struct net *net_ns;
	const struct cred___19 *cred;
	struct p_log___24 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___24;

typedef int fs_param_type___17(struct p_log___24 *, const struct fs_parameter_spec___17 *, struct fs_parameter___24 *, struct fs_parse_result *);

struct fs_parameter_spec___17 {
	const char *name;
	fs_param_type___17 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

struct kernfs_root___130;

struct kernfs_elem_dir___130 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___130 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___130;

struct kernfs_root___130 {
	struct kernfs_node___130 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___130 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___130 {
	struct kernfs_node___130 *target_kn;
};

struct kernfs_ops___130;

struct kernfs_elem_attr___130 {
	const struct kernfs_ops___130 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___130 *notify_next;
};

struct kernfs_node___130 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___130 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___130 dir;
		struct kernfs_elem_symlink___130 symlink;
		struct kernfs_elem_attr___130 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___130;

struct kernfs_ops___130 {
	int (*open)(struct kernfs_open_file___130 *);
	void (*release)(struct kernfs_open_file___130 *);
	int (*seq_show)(struct seq_file___120 *, void *);
	void * (*seq_start)(struct seq_file___120 *, loff_t *);
	void * (*seq_next)(struct seq_file___120 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___120 *, void *);
	ssize_t (*read)(struct kernfs_open_file___130 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___130 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___130 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___130 *, struct vm_area_struct___144 *);
};

struct kernfs_syscall_ops___130 {
	int (*show_options)(struct seq_file___120 *, struct kernfs_root___130 *);
	int (*mkdir)(struct kernfs_node___130 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___130 *);
	int (*rename)(struct kernfs_node___130 *, struct kernfs_node___130 *, const char *);
	int (*show_path)(struct seq_file___120 *, struct kernfs_node___130 *, struct kernfs_root___130 *);
};

struct kernfs_open_file___130 {
	struct kernfs_node___130 *kn;
	struct file___139 *file;
	struct seq_file___120 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___137 *vm_ops;
};

struct bin_attribute___130;

struct attribute_group___130 {
	const char *name;
	umode_t (*is_visible)(struct kobject___130 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___130 *, struct bin_attribute___130 *, int);
	struct attribute **attrs;
	struct bin_attribute___130 **bin_attrs;
};

struct bin_attribute___130 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___139 * (*f_mapping)();
	ssize_t (*read)(struct file___139 *, struct kobject___130 *, struct bin_attribute___130 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___139 *, struct kobject___130 *, struct bin_attribute___130 *, char *, loff_t, size_t);
	int (*mmap)(struct file___139 *, struct kobject___130 *, struct bin_attribute___130 *, struct vm_area_struct___144 *);
};

struct sysfs_ops___130 {
	ssize_t (*show)(struct kobject___130 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___130 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___130;

struct kset___130 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___130 kobj;
	const struct kset_uevent_ops___130 *uevent_ops;
};

struct kobj_type___130 {
	void (*release)(struct kobject___130 *);
	const struct sysfs_ops___130 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___130 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___130 *);
	const void * (*namespace)(struct kobject___130 *);
	void (*get_ownership)(struct kobject___130 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___130 {
	int (* const filter)(struct kset___130 *, struct kobject___130 *);
	const char * (* const name)(struct kset___130 *, struct kobject___130 *);
	int (* const uevent)(struct kset___130 *, struct kobject___130 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___127 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___127 *);
	int (*get)(char *, const struct kernel_param___127 *);
	void (*free)(void *);
};

struct kparam_array___127;

struct kernel_param___127 {
	const char *name;
	struct module___128 *mod;
	const struct kernel_param_ops___127 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___127 *arr;
	};
};

struct kparam_array___127 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___127 *ops;
	void *elem;
};

struct module_attribute___127 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___127 *, struct module_kobject___127 *, char *);
	ssize_t (*store)(struct module_attribute___127 *, struct module_kobject___127 *, const char *, size_t);
	void (*setup)(struct module___128 *, const char *);
	int (*test)(struct module___128 *);
	void (*free)(struct module___128 *);
};

struct seq_operations___120 {
	void * (*start)(struct seq_file___120 *, loff_t *);
	void (*stop)(struct seq_file___120 *, void *);
	void * (*next)(struct seq_file___120 *, void *, loff_t *);
	int (*show)(struct seq_file___120 *, void *);
};

struct dev_pagemap_ops___137 {
	void (*page_free)(struct page___144 *);
	void (*kill)(struct dev_pagemap___137 *);
	void (*cleanup)(struct dev_pagemap___137 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___137 *);
};

struct fs_parameter___24 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___139 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___24 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___128 *owner;
	char *buffer[8];
};

struct fs_context_operations___24 {
	void (*free)(struct fs_context___24 *);
	int (*dup)(struct fs_context___24 *, struct fs_context___24 *);
	int (*parse_param)(struct fs_context___24 *, struct fs_parameter___24 *);
	int (*parse_monolithic)(struct fs_context___24 *, void *);
	int (*get_tree)(struct fs_context___24 *);
	int (*reconfigure)(struct fs_context___24 *);
};

enum pstore_type_id {
	PSTORE_TYPE_DMESG = 0,
	PSTORE_TYPE_MCE = 1,
	PSTORE_TYPE_CONSOLE = 2,
	PSTORE_TYPE_FTRACE = 3,
	PSTORE_TYPE_PPC_RTAS = 4,
	PSTORE_TYPE_PPC_OF = 5,
	PSTORE_TYPE_PPC_COMMON = 6,
	PSTORE_TYPE_PMSG = 7,
	PSTORE_TYPE_PPC_OPAL = 8,
	PSTORE_TYPE_MAX = 9,
};

struct pstore_info;

struct pstore_record {
	struct pstore_info *psi;
	enum pstore_type_id type;
	u64 id;
	struct timespec64 time;
	char *buf;
	ssize_t size;
	ssize_t ecc_notice_size;
	int count;
	enum kmsg_dump_reason reason;
	unsigned int part;
	bool compressed;
};

struct pstore_info {
	struct module___128 *owner;
	const char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex read_mutex;
	int flags;
	int max_reason;
	void *data;
	int (*open)(struct pstore_info *);
	int (*close)(struct pstore_info *);
	ssize_t (*read)(struct pstore_record *);
	int (*write)(struct pstore_record *);
	int (*write_user)(struct pstore_record *, const char *);
	int (*erase)(struct pstore_record *);
};

struct pstore_ftrace_record {
	long unsigned int ip;
	long unsigned int parent_ip;
	u64 ts;
};

struct pstore_private {
	struct list_head list;
	struct dentry___139 *dentry;
	struct pstore_record *record;
	size_t total_size;
};

struct pstore_ftrace_seq_data {
	const void *ptr;
	size_t off;
	size_t size;
};

enum {
	Opt_kmsg_bytes = 0,
	Opt_err___5 = 1,
};

struct pstore_info___2;

struct pstore_record___2 {
	struct pstore_info___2 *psi;
	enum pstore_type_id type;
	u64 id;
	struct timespec64 time;
	char *buf;
	ssize_t size;
	ssize_t ecc_notice_size;
	int count;
	enum kmsg_dump_reason reason;
	unsigned int part;
	bool compressed;
};

struct pstore_info___2 {
	struct module___125 *owner;
	const char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex read_mutex;
	int flags;
	int max_reason;
	void *data;
	int (*open)(struct pstore_info___2 *);
	int (*close)(struct pstore_info___2 *);
	ssize_t (*read)(struct pstore_record___2 *);
	int (*write)(struct pstore_record___2 *);
	int (*write_user)(struct pstore_record___2 *, const char *);
	int (*erase)(struct pstore_record___2 *);
};

struct crypto_alg___13;

struct crypto_tfm___13 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___13 *);
	struct crypto_alg___13 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___13 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___13 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___13 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___13 *, u8 *, const u8 *);
};

struct compress_alg___13 {
	int (*coa_compress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___13 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___13 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___13 cipher;
		struct compress_alg___13 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___13 *);
	void (*cra_exit)(struct crypto_tfm___13 *);
	void (*cra_destroy)(struct crypto_alg___13 *);
	struct module___125 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_comp {
	struct crypto_tfm___13 base;
};

struct pstore_zbackend {
	int (*zbufsize)(size_t);
	const char *name;
};

struct efi_variable {
	efi_char16_t VariableName[512];
	efi_guid_t VendorGuid;
	long unsigned int DataSize;
	__u8 Data[1024];
	efi_status_t Status;
	__u32 Attributes;
} __attribute__((packed));

struct efivar_entry {
	struct efi_variable var;
	struct list_head list;
	struct kobject___11 kobj;
	bool scanning;
	bool deleting;
};

struct fs_context___25;

struct dentry___140;

struct super_block___140;

struct module___129;

struct file_system_type___140 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___25 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___140 * (*mount)(struct file_system_type___140 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___140 *);
	struct module___129 *owner;
	struct file_system_type___140 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___140;

struct kiocb___140;

struct poll_table_struct___89;

struct vm_area_struct___145;

struct inode___140;

struct file_lock___140;

struct page___145;

struct seq_file___121;

struct file_operations___140 {
	struct module___129 *owner;
	loff_t (*llseek)(struct file___140 *, loff_t, int);
	ssize_t (*read)(struct file___140 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___140 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___140 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___140 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___140 *, bool);
	int (*iterate)(struct file___140 *, struct dir_context *);
	int (*iterate_shared)(struct file___140 *, struct dir_context *);
	__poll_t (*poll)(struct file___140 *, struct poll_table_struct___89 *);
	long int (*unlocked_ioctl)(struct file___140 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___140 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___140 *, struct vm_area_struct___145 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___140 *, struct file___140 *);
	int (*flush)(struct file___140 *, fl_owner_t);
	int (*release)(struct inode___140 *, struct file___140 *);
	int (*fsync)(struct file___140 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___140 *, int);
	int (*lock)(struct file___140 *, int, struct file_lock___140 *);
	ssize_t (*sendpage)(struct file___140 *, struct page___145 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___140 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___140 *, long unsigned int);
	int (*flock)(struct file___140 *, int, struct file_lock___140 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___140 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___140 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___140 *, long int, struct file_lock___140 **, void **);
	long int (*fallocate)(struct file___140 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___121 *, struct file___140 *);
	ssize_t (*copy_file_range)(struct file___140 *, loff_t, struct file___140 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___140 *, loff_t, struct file___140 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___140 *, loff_t, loff_t, int);
};

struct vmacache___145 {
	u64 seqnum;
	struct vm_area_struct___145 *vmas[4];
};

struct page_frag___145 {
	struct page___145 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___146;

struct pid___125;

struct nsproxy___131;

struct signal_struct___141;

struct vm_struct___127;

struct task_struct___147 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___147 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___146 *mm;
	struct mm_struct___146 *active_mm;
	struct vmacache___145 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___147 *real_parent;
	struct task_struct___147 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___147 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___125 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___131 *nsproxy;
	struct signal_struct___141 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___147 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___64 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___145 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___147 *oom_reaper_list;
	struct vm_struct___127 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___65 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___131;

struct kobj_type___131;

struct kernfs_node___131;

struct kobject___131 {
	const char *name;
	struct list_head entry;
	struct kobject___131 *parent;
	struct kset___131 *kset;
	struct kobj_type___131 *ktype;
	struct kernfs_node___131 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___128 {
	struct kobject___131 kobj;
	struct module___129 *mod;
	struct kobject___131 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___128 {
	struct module___129 *mod;
	struct latch_tree_node node;
};

struct module_layout___128 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___128 mtn;
};

struct module_attribute___128;

struct kernel_param___128;

struct module___129 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___128 mkobj;
	struct module_attribute___128 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___131 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___128 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___128 core_layout;
	struct module_layout___128 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___140;

struct dentry___140 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___140 *d_parent;
	struct qstr d_name;
	struct inode___140 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___140 *d_op;
	struct super_block___140 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___140;

struct address_space___140 {
	struct inode___140 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___140 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___140;

struct cdev___23;

struct inode___140 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___140 *i_op;
	struct super_block___140 *i_sb;
	struct address_space___140 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___140 *i_fop;
		void (*free_inode)(struct inode___140 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___140 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___140;

struct path___140;

struct dentry_operations___140 {
	int (*d_revalidate)(struct dentry___140 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___140 *, unsigned int);
	int (*d_hash)(const struct dentry___140 *, struct qstr *);
	int (*d_compare)(const struct dentry___140 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___140 *);
	int (*d_init)(struct dentry___140 *);
	void (*d_release)(struct dentry___140 *);
	void (*d_prune)(struct dentry___140 *);
	void (*d_iput)(struct dentry___140 *, struct inode___140 *);
	char * (*d_dname)(struct dentry___140 *, char *, int);
	struct vfsmount___140 * (*d_automount)(struct path___140 *);
	int (*d_manage)(const struct path___140 *, bool);
	struct dentry___140 * (*d_real)(struct dentry___140 *, const struct inode___140 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___140;

struct mem_dqinfo___140 {
	struct quota_format_type___140 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___140;

struct quota_info___140 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___140 *files[3];
	struct mem_dqinfo___140 info[3];
	const struct quota_format_ops___140 *ops[3];
};

struct rcuwait___141 {
	struct task_struct___147 *task;
};

struct percpu_rw_semaphore___141 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___141 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___140 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___141 rw_sem[3];
};

struct super_operations___140;

struct dquot_operations___140;

struct quotactl_ops___140;

struct super_block___140 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___140 *s_type;
	const struct super_operations___140 *s_op;
	const struct dquot_operations___140 *dq_op;
	const struct quotactl_ops___140 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___140 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___140 s_dquot;
	struct sb_writers___140 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___140 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___140 {
	struct dentry___140 *mnt_root;
	struct super_block___140 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___140 {
	struct vfsmount___140 *mnt;
	struct dentry___140 *dentry;
};

struct pid_namespace___125;

struct upid___125 {
	int nr;
	struct pid_namespace___125 *ns;
};

struct pid_namespace___125 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___147 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___125 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___24 ns;
};

struct pid___125 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___125 numbers[1];
};

typedef struct page___145 *pgtable_t___145;

struct dev_pagemap___138;

struct page___145 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___140 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___145 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___145 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___146 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___138 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___138;

struct vm_area_struct___145 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___145 *vm_next;
	struct vm_area_struct___145 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___146 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___138 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___140 *vm_file;
	struct file___140 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___141 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___147 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___147 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___125 *pids[4];
	struct pid___125 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___146 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___145;

struct mm_struct___146 {
	struct {
		struct vm_area_struct___145 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___140 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___145 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___147 *owner;
		struct user_namespace *user_ns;
		struct file___140 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___131 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___125 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___127 {
	struct vm_struct___127 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___145 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___138;

struct dev_pagemap___138 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___138 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___125 {
	rwlock_t lock;
	struct pid___125 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___140 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___140 f_path;
	struct inode___140 *f_inode;
	const struct file_operations___140 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___125 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___140 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___138;

struct vm_operations_struct___138 {
	void (*open)(struct vm_area_struct___145 *);
	void (*close)(struct vm_area_struct___145 *);
	int (*may_split)(struct vm_area_struct___145 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___145 *);
	int (*mprotect)(struct vm_area_struct___145 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___138 *);
	vm_fault_t (*huge_fault)(struct vm_fault___138 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___138 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___145 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___138 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___138 *);
	int (*access)(struct vm_area_struct___145 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___145 *);
	int (*set_policy)(struct vm_area_struct___145 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___145 *, long unsigned int);
	struct page___145 * (*find_special_page)(struct vm_area_struct___145 *, long unsigned int);
};

struct core_thread___145 {
	struct task_struct___147 *task;
	struct core_thread___145 *next;
};

struct core_state___145 {
	atomic_t nr_threads;
	struct core_thread___145 dumper;
	struct completion startup;
};

struct vm_fault___138 {
	const struct {
		struct vm_area_struct___145 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___145 *cow_page;
	struct page___145 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___145 prealloc_pte;
};

struct wait_page_queue___69;

struct kiocb___140 {
	struct file___140 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___140 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___69 *ki_waitq;
	};
};

struct iattr___140 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___140 *ia_file;
};

struct dquot___140 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___140 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___140 {
	int qf_fmt_id;
	const struct quota_format_ops___140 *qf_ops;
	struct module___129 *qf_owner;
	struct quota_format_type___140 *qf_next;
};

struct quota_format_ops___140 {
	int (*check_quota_file)(struct super_block___140 *, int);
	int (*read_file_info)(struct super_block___140 *, int);
	int (*write_file_info)(struct super_block___140 *, int);
	int (*free_file_info)(struct super_block___140 *, int);
	int (*read_dqblk)(struct dquot___140 *);
	int (*commit_dqblk)(struct dquot___140 *);
	int (*release_dqblk)(struct dquot___140 *);
	int (*get_next_id)(struct super_block___140 *, struct kqid *);
};

struct dquot_operations___140 {
	int (*write_dquot)(struct dquot___140 *);
	struct dquot___140 * (*alloc_dquot)(struct super_block___140 *, int);
	void (*destroy_dquot)(struct dquot___140 *);
	int (*acquire_dquot)(struct dquot___140 *);
	int (*release_dquot)(struct dquot___140 *);
	int (*mark_dirty)(struct dquot___140 *);
	int (*write_info)(struct super_block___140 *, int);
	qsize_t * (*get_reserved_space)(struct inode___140 *);
	int (*get_projid)(struct inode___140 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___140 *, qsize_t *);
	int (*get_next_id)(struct super_block___140 *, struct kqid *);
};

struct quotactl_ops___140 {
	int (*quota_on)(struct super_block___140 *, int, int, const struct path___140 *);
	int (*quota_off)(struct super_block___140 *, int);
	int (*quota_enable)(struct super_block___140 *, unsigned int);
	int (*quota_disable)(struct super_block___140 *, unsigned int);
	int (*quota_sync)(struct super_block___140 *, int);
	int (*set_info)(struct super_block___140 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___140 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___140 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___140 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___140 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___140 *, unsigned int);
};

struct wait_page_queue___69 {
	struct page___145 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___69;

struct address_space_operations___140 {
	int (*writepage)(struct page___145 *, struct writeback_control___3 *);
	int (*readpage)(struct file___140 *, struct page___145 *);
	int (*writepages)(struct address_space___140 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___145 *);
	int (*readpages)(struct file___140 *, struct address_space___140 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___69 *);
	int (*write_begin)(struct file___140 *, struct address_space___140 *, loff_t, unsigned int, unsigned int, struct page___145 **, void **);
	int (*write_end)(struct file___140 *, struct address_space___140 *, loff_t, unsigned int, unsigned int, struct page___145 *, void *);
	sector_t (*bmap)(struct address_space___140 *, sector_t);
	void (*invalidatepage)(struct page___145 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___145 *, gfp_t);
	void (*freepage)(struct page___145 *);
	ssize_t (*direct_IO)(struct kiocb___140 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___140 *, struct page___145 *, struct page___145 *, enum migrate_mode);
	bool (*isolate_page)(struct page___145 *, isolate_mode_t);
	void (*putback_page)(struct page___145 *);
	int (*launder_page)(struct page___145 *);
	int (*is_partially_uptodate)(struct page___145 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___145 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___140 *, struct page___145 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___140 *, sector_t *);
	void (*swap_deactivate)(struct file___140 *);
};

struct readahead_control___69 {
	struct file___140 *file;
	struct address_space___140 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct cdev___23 {
	struct kobject___131 kobj;
	struct module___129 *owner;
	const struct file_operations___140 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___140 {
	struct dentry___140 * (*lookup)(struct inode___140 *, struct dentry___140 *, unsigned int);
	const char * (*get_link)(struct dentry___140 *, struct inode___140 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___140 *, int);
	struct posix_acl * (*get_acl)(struct inode___140 *, int, bool);
	int (*readlink)(struct dentry___140 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___140 *, struct dentry___140 *, umode_t, bool);
	int (*link)(struct dentry___140 *, struct inode___140 *, struct dentry___140 *);
	int (*unlink)(struct inode___140 *, struct dentry___140 *);
	int (*symlink)(struct user_namespace *, struct inode___140 *, struct dentry___140 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___140 *, struct dentry___140 *, umode_t);
	int (*rmdir)(struct inode___140 *, struct dentry___140 *);
	int (*mknod)(struct user_namespace *, struct inode___140 *, struct dentry___140 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___140 *, struct dentry___140 *, struct inode___140 *, struct dentry___140 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___140 *, struct iattr___140 *);
	int (*getattr)(struct user_namespace *, const struct path___140 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___140 *, char *, size_t);
	int (*fiemap)(struct inode___140 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___140 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___140 *, struct dentry___140 *, struct file___140 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___140 *, struct dentry___140 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___140 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___140 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___140 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___140 {
	void (*fl_copy_lock)(struct file_lock___140 *, struct file_lock___140 *);
	void (*fl_release_private)(struct file_lock___140 *);
};

struct fasync_struct___140;

struct lock_manager_operations___140;

struct file_lock___140 {
	struct file_lock___140 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___140 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___140 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___140 *fl_ops;
	const struct lock_manager_operations___140 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___140 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___140 *);
	int (*lm_grant)(struct file_lock___140 *, int);
	bool (*lm_break)(struct file_lock___140 *);
	int (*lm_change)(struct file_lock___140 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___140 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___140 *);
};

struct fasync_struct___140 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___140 *fa_next;
	struct file___140 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___140 {
	struct inode___140 * (*alloc_inode)(struct super_block___140 *);
	void (*destroy_inode)(struct inode___140 *);
	void (*free_inode)(struct inode___140 *);
	void (*dirty_inode)(struct inode___140 *, int);
	int (*write_inode)(struct inode___140 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___140 *);
	void (*evict_inode)(struct inode___140 *);
	void (*put_super)(struct super_block___140 *);
	int (*sync_fs)(struct super_block___140 *, int);
	int (*freeze_super)(struct super_block___140 *);
	int (*freeze_fs)(struct super_block___140 *);
	int (*thaw_super)(struct super_block___140 *);
	int (*unfreeze_fs)(struct super_block___140 *);
	int (*statfs)(struct dentry___140 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___140 *, int *, char *);
	void (*umount_begin)(struct super_block___140 *);
	int (*show_options)(struct seq_file___121 *, struct dentry___140 *);
	int (*show_devname)(struct seq_file___121 *, struct dentry___140 *);
	int (*show_path)(struct seq_file___121 *, struct dentry___140 *);
	int (*show_stats)(struct seq_file___121 *, struct dentry___140 *);
	ssize_t (*quota_read)(struct super_block___140 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___140 *, int, const char *, size_t, loff_t);
	struct dquot___140 ** (*get_dquots)(struct inode___140 *);
	long int (*nr_cached_objects)(struct super_block___140 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___140 *, struct shrink_control___52 *);
	struct file___140 * (*real_loop)(struct file___140 *);
};

typedef void (*poll_queue_proc___91)(struct file___140 *, wait_queue_head_t *, struct poll_table_struct___89 *);

struct poll_table_struct___89 {
	poll_queue_proc___91 _qproc;
	__poll_t _key;
};

struct seq_operations___121;

struct seq_file___121 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___121 *op;
	int poll_event;
	const struct file___140 *file;
	void *private;
};

struct fc_log___25;

struct p_log___25 {
	const char *prefix;
	struct fc_log___25 *log;
};

struct fs_context_operations___25;

struct fs_context___25 {
	const struct fs_context_operations___25 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___140 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___140 *root;
	struct user_namespace *user_ns;
	struct net *net_ns;
	const struct cred___19 *cred;
	struct p_log___25 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___131;

struct kernfs_elem_dir___131 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___131 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___131;

struct kernfs_root___131 {
	struct kernfs_node___131 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___131 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___131 {
	struct kernfs_node___131 *target_kn;
};

struct kernfs_ops___131;

struct kernfs_elem_attr___131 {
	const struct kernfs_ops___131 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___131 *notify_next;
};

struct kernfs_node___131 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___131 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___131 dir;
		struct kernfs_elem_symlink___131 symlink;
		struct kernfs_elem_attr___131 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___131;

struct kernfs_ops___131 {
	int (*open)(struct kernfs_open_file___131 *);
	void (*release)(struct kernfs_open_file___131 *);
	int (*seq_show)(struct seq_file___121 *, void *);
	void * (*seq_start)(struct seq_file___121 *, loff_t *);
	void * (*seq_next)(struct seq_file___121 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___121 *, void *);
	ssize_t (*read)(struct kernfs_open_file___131 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___131 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___131 *, struct poll_table_struct___89 *);
	int (*mmap)(struct kernfs_open_file___131 *, struct vm_area_struct___145 *);
};

struct kernfs_syscall_ops___131 {
	int (*show_options)(struct seq_file___121 *, struct kernfs_root___131 *);
	int (*mkdir)(struct kernfs_node___131 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___131 *);
	int (*rename)(struct kernfs_node___131 *, struct kernfs_node___131 *, const char *);
	int (*show_path)(struct seq_file___121 *, struct kernfs_node___131 *, struct kernfs_root___131 *);
};

struct kernfs_open_file___131 {
	struct kernfs_node___131 *kn;
	struct file___140 *file;
	struct seq_file___121 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___138 *vm_ops;
};

struct bin_attribute___131;

struct attribute_group___131 {
	const char *name;
	umode_t (*is_visible)(struct kobject___131 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___131 *, struct bin_attribute___131 *, int);
	struct attribute **attrs;
	struct bin_attribute___131 **bin_attrs;
};

struct bin_attribute___131 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___140 * (*f_mapping)();
	ssize_t (*read)(struct file___140 *, struct kobject___131 *, struct bin_attribute___131 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___140 *, struct kobject___131 *, struct bin_attribute___131 *, char *, loff_t, size_t);
	int (*mmap)(struct file___140 *, struct kobject___131 *, struct bin_attribute___131 *, struct vm_area_struct___145 *);
};

struct sysfs_ops___131 {
	ssize_t (*show)(struct kobject___131 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___131 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___131;

struct kset___131 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___131 kobj;
	const struct kset_uevent_ops___131 *uevent_ops;
};

struct kobj_type___131 {
	void (*release)(struct kobject___131 *);
	const struct sysfs_ops___131 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___131 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___131 *);
	const void * (*namespace)(struct kobject___131 *);
	void (*get_ownership)(struct kobject___131 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___131 {
	int (* const filter)(struct kset___131 *, struct kobject___131 *);
	const char * (* const name)(struct kset___131 *, struct kobject___131 *);
	int (* const uevent)(struct kset___131 *, struct kobject___131 *, struct kobj_uevent_env *);
};

struct seq_operations___121 {
	void * (*start)(struct seq_file___121 *, loff_t *);
	void (*stop)(struct seq_file___121 *, void *);
	void * (*next)(struct seq_file___121 *, void *, loff_t *);
	int (*show)(struct seq_file___121 *, void *);
};

struct efivar_entry___2 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___131 kobj;
	bool scanning;
	bool deleting;
};

struct dev_pagemap_ops___138 {
	void (*page_free)(struct page___145 *);
	void (*kill)(struct dev_pagemap___138 *);
	void (*cleanup)(struct dev_pagemap___138 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___138 *);
};

struct fs_parameter___25 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___140 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___25 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___129 *owner;
	char *buffer[8];
};

struct fs_context_operations___25 {
	void (*free)(struct fs_context___25 *);
	int (*dup)(struct fs_context___25 *, struct fs_context___25 *);
	int (*parse_param)(struct fs_context___25 *, struct fs_parameter___25 *);
	int (*parse_monolithic)(struct fs_context___25 *, void *);
	int (*get_tree)(struct fs_context___25 *);
	int (*reconfigure)(struct fs_context___25 *);
};

struct kernel_param_ops___128 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___128 *);
	int (*get)(char *, const struct kernel_param___128 *);
	void (*free)(void *);
};

struct kparam_array___128;

struct kernel_param___128 {
	const char *name;
	struct module___129 *mod;
	const struct kernel_param_ops___128 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___128 *arr;
	};
};

struct kparam_array___128 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___128 *ops;
	void *elem;
};

struct module_attribute___128 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___128 *, struct module_kobject___128 *, char *);
	ssize_t (*store)(struct module_attribute___128 *, struct module_kobject___128 *, const char *, size_t);
	void (*setup)(struct module___129 *, const char *);
	int (*test)(struct module___129 *);
	void (*free)(struct module___129 *);
};

typedef u16 ucs2_char_t;

struct dentry___141;

struct super_block___141;

struct module___130;

struct file_system_type___141 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___141 * (*mount)(struct file_system_type___141 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___141 *);
	struct module___130 *owner;
	struct file_system_type___141 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___141;

struct kiocb___141;

struct poll_table_struct___90;

struct vm_area_struct___146;

struct inode___141;

struct file_lock___141;

struct page___146;

struct seq_file___122;

struct file_operations___141 {
	struct module___130 *owner;
	loff_t (*llseek)(struct file___141 *, loff_t, int);
	ssize_t (*read)(struct file___141 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___141 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___141 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___141 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___141 *, bool);
	int (*iterate)(struct file___141 *, struct dir_context *);
	int (*iterate_shared)(struct file___141 *, struct dir_context *);
	__poll_t (*poll)(struct file___141 *, struct poll_table_struct___90 *);
	long int (*unlocked_ioctl)(struct file___141 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___141 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___141 *, struct vm_area_struct___146 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___141 *, struct file___141 *);
	int (*flush)(struct file___141 *, fl_owner_t);
	int (*release)(struct inode___141 *, struct file___141 *);
	int (*fsync)(struct file___141 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___141 *, int);
	int (*lock)(struct file___141 *, int, struct file_lock___141 *);
	ssize_t (*sendpage)(struct file___141 *, struct page___146 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___141 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___141 *, long unsigned int);
	int (*flock)(struct file___141 *, int, struct file_lock___141 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___141 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___141 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___141 *, long int, struct file_lock___141 **, void **);
	long int (*fallocate)(struct file___141 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___122 *, struct file___141 *);
	ssize_t (*copy_file_range)(struct file___141 *, loff_t, struct file___141 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___141 *, loff_t, struct file___141 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___141 *, loff_t, loff_t, int);
};

struct vmacache___146 {
	u64 seqnum;
	struct vm_area_struct___146 *vmas[4];
};

struct page_frag___146 {
	struct page___146 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___66;

struct debug_info___66 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___66 *hbp_break[16];
	struct perf_event___66 *hbp_watch[16];
};

struct thread_struct___66 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___66 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___147;

struct pid___126;

struct nsproxy___132;

struct signal_struct___142;

struct css_set___99;

struct perf_event_context___66;

struct vm_struct___128;

struct task_struct___148 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___148 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___147 *mm;
	struct mm_struct___147 *active_mm;
	struct vmacache___146 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___148 *real_parent;
	struct task_struct___148 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___148 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___126 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___132 *nsproxy;
	struct signal_struct___142 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___148 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___64 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___99 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___66 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___146 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___148 *oom_reaper_list;
	struct vm_struct___128 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___66 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef s32 compat_key_t;

typedef u32 __compat_gid32_t;

struct kset___132;

struct kobj_type___132;

struct kernfs_node___132;

struct kobject___132 {
	const char *name;
	struct list_head entry;
	struct kobject___132 *parent;
	struct kset___132 *kset;
	struct kobj_type___132 *ktype;
	struct kernfs_node___132 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___129 {
	struct kobject___132 kobj;
	struct module___130 *mod;
	struct kobject___132 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___129 {
	struct module___130 *mod;
	struct latch_tree_node node;
};

struct module_layout___129 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___129 mtn;
};

struct module_attribute___129;

struct kernel_param___129;

struct trace_event_call___60;

struct module___130 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___129 mkobj;
	struct module_attribute___129 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___132 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___129 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___129 core_layout;
	struct module_layout___129 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___60 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___66 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___148 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___66)(struct perf_event___66 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___66;

struct fasync_struct___141;

struct pid_namespace___126;

struct perf_cgroup___66;

struct perf_event___66 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___66 *group_leader;
	struct pmu___66 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___66 hw;
	struct perf_event_context___66 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___66 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___148 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___141 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___66 *aux_event;
	void (*destroy)(struct perf_event___66 *);
	struct callback_head callback_head;
	struct pid_namespace___126 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___66 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___66 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___60 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___66 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___126 {
	int nr;
	struct pid_namespace___126 *ns;
};

struct pid_namespace___126 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___148 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___126 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___126 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___126 numbers[1];
};

struct ipc64_perm {
	__kernel_key_t key;
	__kernel_uid32_t uid;
	__kernel_gid32_t gid;
	__kernel_uid32_t cuid;
	__kernel_gid32_t cgid;
	__kernel_mode_t mode;
	unsigned char __pad1[0];
	short unsigned int seq;
	short unsigned int __pad2;
	__kernel_ulong_t __unused1;
	__kernel_ulong_t __unused2;
};

typedef struct page___146 *pgtable_t___146;

struct address_space___141;

struct dev_pagemap___139;

struct page___146 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___141 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___146 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___146 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___147 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___139 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___139;

struct vm_area_struct___146 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___146 *vm_next;
	struct vm_area_struct___146 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___147 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___139 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___141 *vm_file;
	struct file___141 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___142 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___148 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___148 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___126 *pids[4];
	struct pid___126 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___147 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___146;

struct mm_struct___147 {
	struct {
		struct vm_area_struct___146 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___141 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___146 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___148 *owner;
		struct user_namespace___19 *user_ns;
		struct file___141 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct ipc_namespace___3;

struct cgroup_namespace___99;

struct nsproxy___132 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace___3 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___126 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___99 *cgroup_ns;
};

struct cgroup_subsys_state___99;

struct cgroup___99;

struct css_set___99 {
	struct cgroup_subsys_state___99 *subsys[14];
	refcount_t refcount;
	struct css_set___99 *dom_cset;
	struct cgroup___99 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___99 *mg_src_cgrp;
	struct cgroup___99 *mg_dst_cgrp;
	struct css_set___99 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___66 {
	struct pmu___66 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___148 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___66 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___128 {
	struct vm_struct___128 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___146 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct compat_ipc64_perm {
	compat_key_t key;
	__compat_uid32_t uid;
	__compat_gid32_t gid;
	__compat_uid32_t cuid;
	__compat_gid32_t cgid;
	short unsigned int mode;
	short unsigned int __pad1;
	short unsigned int seq;
	short unsigned int __pad2;
	compat_ulong_t unused1;
	compat_ulong_t unused2;
};

struct kiocb___141 {
	struct file___141 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___141 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___69 *ki_waitq;
	};
};

struct dentry_operations___141;

struct dentry___141 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___141 *d_parent;
	struct qstr d_name;
	struct inode___141 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___141 *d_op;
	struct super_block___141 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___141;

struct address_space___141 {
	struct inode___141 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___141 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___141;

struct inode___141 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___141 *i_op;
	struct super_block___141 *i_sb;
	struct address_space___141 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___141 *i_fop;
		void (*free_inode)(struct inode___141 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___141 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___141;

struct path___141;

struct dentry_operations___141 {
	int (*d_revalidate)(struct dentry___141 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___141 *, unsigned int);
	int (*d_hash)(const struct dentry___141 *, struct qstr *);
	int (*d_compare)(const struct dentry___141 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___141 *);
	int (*d_init)(struct dentry___141 *);
	void (*d_release)(struct dentry___141 *);
	void (*d_prune)(struct dentry___141 *);
	void (*d_iput)(struct dentry___141 *, struct inode___141 *);
	char * (*d_dname)(struct dentry___141 *, char *, int);
	struct vfsmount___141 * (*d_automount)(struct path___141 *);
	int (*d_manage)(const struct path___141 *, bool);
	struct dentry___141 * (*d_real)(struct dentry___141 *, const struct inode___141 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___141;

struct mem_dqinfo___141 {
	struct quota_format_type___141 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___141;

struct quota_info___141 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___141 *files[3];
	struct mem_dqinfo___141 info[3];
	const struct quota_format_ops___141 *ops[3];
};

struct rcuwait___142 {
	struct task_struct___148 *task;
};

struct percpu_rw_semaphore___142 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___142 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___141 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___142 rw_sem[3];
};

struct super_operations___141;

struct dquot_operations___141;

struct quotactl_ops___141;

struct super_block___141 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___141 *s_type;
	const struct super_operations___141 *s_op;
	const struct dquot_operations___141 *dq_op;
	const struct quotactl_ops___141 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___141 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___141 s_dquot;
	struct sb_writers___141 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___141 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___141 {
	struct dentry___141 *mnt_root;
	struct super_block___141 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct path___141 {
	struct vfsmount___141 *mnt;
	struct dentry___141 *dentry;
};

struct dev_pagemap_ops___139;

struct dev_pagemap___139 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___139 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___126 {
	rwlock_t lock;
	struct pid___126 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___141 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___141 f_path;
	struct inode___141 *f_inode;
	const struct file_operations___141 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___126 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___141 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___139;

struct vm_operations_struct___139 {
	void (*open)(struct vm_area_struct___146 *);
	void (*close)(struct vm_area_struct___146 *);
	int (*may_split)(struct vm_area_struct___146 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___146 *);
	int (*mprotect)(struct vm_area_struct___146 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___139 *);
	vm_fault_t (*huge_fault)(struct vm_fault___139 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___139 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___146 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___139 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___139 *);
	int (*access)(struct vm_area_struct___146 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___146 *);
	int (*set_policy)(struct vm_area_struct___146 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___146 *, long unsigned int);
	struct page___146 * (*find_special_page)(struct vm_area_struct___146 *, long unsigned int);
};

struct core_thread___146 {
	struct task_struct___148 *task;
	struct core_thread___146 *next;
};

struct core_state___146 {
	atomic_t nr_threads;
	struct core_thread___146 dumper;
	struct completion startup;
};

struct vm_fault___139 {
	const struct {
		struct vm_area_struct___146 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___146 *cow_page;
	struct page___146 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___146 prealloc_pte;
};

struct cgroup_subsys___99;

struct cgroup_subsys_state___99 {
	struct cgroup___99 *cgroup;
	struct cgroup_subsys___99 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___99 *parent;
};

struct cgroup_file___99 {
	struct kernfs_node___132 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___99 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___148 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___99;

struct cgroup_rstat_cpu___99;

struct cgroup___99 {
	struct cgroup_subsys_state___99 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___132 *kn;
	struct cgroup_file___99 procs_file;
	struct cgroup_file___99 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___99 *subsys[14];
	struct cgroup_root___99 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___99 *dom_cgrp;
	struct cgroup___99 *old_dom_cgrp;
	struct cgroup_rstat_cpu___99 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___99 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___141 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___141 *ia_file;
};

struct dquot___141 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___141 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___141 {
	int qf_fmt_id;
	const struct quota_format_ops___141 *qf_ops;
	struct module___130 *qf_owner;
	struct quota_format_type___141 *qf_next;
};

struct quota_format_ops___141 {
	int (*check_quota_file)(struct super_block___141 *, int);
	int (*read_file_info)(struct super_block___141 *, int);
	int (*write_file_info)(struct super_block___141 *, int);
	int (*free_file_info)(struct super_block___141 *, int);
	int (*read_dqblk)(struct dquot___141 *);
	int (*commit_dqblk)(struct dquot___141 *);
	int (*release_dqblk)(struct dquot___141 *);
	int (*get_next_id)(struct super_block___141 *, struct kqid *);
};

struct dquot_operations___141 {
	int (*write_dquot)(struct dquot___141 *);
	struct dquot___141 * (*alloc_dquot)(struct super_block___141 *, int);
	void (*destroy_dquot)(struct dquot___141 *);
	int (*acquire_dquot)(struct dquot___141 *);
	int (*release_dquot)(struct dquot___141 *);
	int (*mark_dirty)(struct dquot___141 *);
	int (*write_info)(struct super_block___141 *, int);
	qsize_t * (*get_reserved_space)(struct inode___141 *);
	int (*get_projid)(struct inode___141 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___141 *, qsize_t *);
	int (*get_next_id)(struct super_block___141 *, struct kqid *);
};

struct quotactl_ops___141 {
	int (*quota_on)(struct super_block___141 *, int, int, const struct path___141 *);
	int (*quota_off)(struct super_block___141 *, int);
	int (*quota_enable)(struct super_block___141 *, unsigned int);
	int (*quota_disable)(struct super_block___141 *, unsigned int);
	int (*quota_sync)(struct super_block___141 *, int);
	int (*set_info)(struct super_block___141 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___141 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___141 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___141 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___141 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___141 *, unsigned int);
};

struct address_space_operations___141 {
	int (*writepage)(struct page___146 *, struct writeback_control___3 *);
	int (*readpage)(struct file___141 *, struct page___146 *);
	int (*writepages)(struct address_space___141 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___146 *);
	int (*readpages)(struct file___141 *, struct address_space___141 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___141 *, struct address_space___141 *, loff_t, unsigned int, unsigned int, struct page___146 **, void **);
	int (*write_end)(struct file___141 *, struct address_space___141 *, loff_t, unsigned int, unsigned int, struct page___146 *, void *);
	sector_t (*bmap)(struct address_space___141 *, sector_t);
	void (*invalidatepage)(struct page___146 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___146 *, gfp_t);
	void (*freepage)(struct page___146 *);
	ssize_t (*direct_IO)(struct kiocb___141 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___141 *, struct page___146 *, struct page___146 *, enum migrate_mode);
	bool (*isolate_page)(struct page___146 *, isolate_mode_t);
	void (*putback_page)(struct page___146 *);
	int (*launder_page)(struct page___146 *);
	int (*is_partially_uptodate)(struct page___146 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___146 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___141 *, struct page___146 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___141 *, sector_t *);
	void (*swap_deactivate)(struct file___141 *);
};

struct inode_operations___141 {
	struct dentry___141 * (*lookup)(struct inode___141 *, struct dentry___141 *, unsigned int);
	const char * (*get_link)(struct dentry___141 *, struct inode___141 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___141 *, int);
	struct posix_acl * (*get_acl)(struct inode___141 *, int, bool);
	int (*readlink)(struct dentry___141 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___141 *, struct dentry___141 *, umode_t, bool);
	int (*link)(struct dentry___141 *, struct inode___141 *, struct dentry___141 *);
	int (*unlink)(struct inode___141 *, struct dentry___141 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___141 *, struct dentry___141 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___141 *, struct dentry___141 *, umode_t);
	int (*rmdir)(struct inode___141 *, struct dentry___141 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___141 *, struct dentry___141 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___141 *, struct dentry___141 *, struct inode___141 *, struct dentry___141 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___141 *, struct iattr___141 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___141 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___141 *, char *, size_t);
	int (*fiemap)(struct inode___141 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___141 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___141 *, struct dentry___141 *, struct file___141 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___141 *, struct dentry___141 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___141 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___141 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___141 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___141 {
	void (*fl_copy_lock)(struct file_lock___141 *, struct file_lock___141 *);
	void (*fl_release_private)(struct file_lock___141 *);
};

struct lock_manager_operations___141;

struct file_lock___141 {
	struct file_lock___141 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___141 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___141 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___141 *fl_ops;
	const struct lock_manager_operations___141 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___141 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___141 *);
	int (*lm_grant)(struct file_lock___141 *, int);
	bool (*lm_break)(struct file_lock___141 *);
	int (*lm_change)(struct file_lock___141 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___141 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___141 *);
};

struct fasync_struct___141 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___141 *fa_next;
	struct file___141 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___141 {
	struct inode___141 * (*alloc_inode)(struct super_block___141 *);
	void (*destroy_inode)(struct inode___141 *);
	void (*free_inode)(struct inode___141 *);
	void (*dirty_inode)(struct inode___141 *, int);
	int (*write_inode)(struct inode___141 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___141 *);
	void (*evict_inode)(struct inode___141 *);
	void (*put_super)(struct super_block___141 *);
	int (*sync_fs)(struct super_block___141 *, int);
	int (*freeze_super)(struct super_block___141 *);
	int (*freeze_fs)(struct super_block___141 *);
	int (*thaw_super)(struct super_block___141 *);
	int (*unfreeze_fs)(struct super_block___141 *);
	int (*statfs)(struct dentry___141 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___141 *, int *, char *);
	void (*umount_begin)(struct super_block___141 *);
	int (*show_options)(struct seq_file___122 *, struct dentry___141 *);
	int (*show_devname)(struct seq_file___122 *, struct dentry___141 *);
	int (*show_path)(struct seq_file___122 *, struct dentry___141 *);
	int (*show_stats)(struct seq_file___122 *, struct dentry___141 *);
	ssize_t (*quota_read)(struct super_block___141 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___141 *, int, const char *, size_t, loff_t);
	struct dquot___141 ** (*get_dquots)(struct inode___141 *);
	long int (*nr_cached_objects)(struct super_block___141 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___141 *, struct shrink_control___52 *);
	struct file___141 * (*real_loop)(struct file___141 *);
};

typedef void (*poll_queue_proc___92)(struct file___141 *, wait_queue_head_t *, struct poll_table_struct___90 *);

struct poll_table_struct___90 {
	poll_queue_proc___92 _qproc;
	__poll_t _key;
};

struct seq_operations___122;

struct seq_file___122 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___122 *op;
	int poll_event;
	const struct file___141 *file;
	void *private;
};

struct kernfs_root___132;

struct kernfs_elem_dir___132 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___132 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___132;

struct kernfs_root___132 {
	struct kernfs_node___132 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___132 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___132 {
	struct kernfs_node___132 *target_kn;
};

struct kernfs_ops___132;

struct kernfs_elem_attr___132 {
	const struct kernfs_ops___132 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___132 *notify_next;
};

struct kernfs_node___132 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___132 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___132 dir;
		struct kernfs_elem_symlink___132 symlink;
		struct kernfs_elem_attr___132 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___132;

struct kernfs_ops___132 {
	int (*open)(struct kernfs_open_file___132 *);
	void (*release)(struct kernfs_open_file___132 *);
	int (*seq_show)(struct seq_file___122 *, void *);
	void * (*seq_start)(struct seq_file___122 *, loff_t *);
	void * (*seq_next)(struct seq_file___122 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___122 *, void *);
	ssize_t (*read)(struct kernfs_open_file___132 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___132 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___132 *, struct poll_table_struct___90 *);
	int (*mmap)(struct kernfs_open_file___132 *, struct vm_area_struct___146 *);
};

struct kernfs_syscall_ops___132 {
	int (*show_options)(struct seq_file___122 *, struct kernfs_root___132 *);
	int (*mkdir)(struct kernfs_node___132 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___132 *);
	int (*rename)(struct kernfs_node___132 *, struct kernfs_node___132 *, const char *);
	int (*show_path)(struct seq_file___122 *, struct kernfs_node___132 *, struct kernfs_root___132 *);
};

struct kernfs_open_file___132 {
	struct kernfs_node___132 *kn;
	struct file___141 *file;
	struct seq_file___122 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___139 *vm_ops;
};

struct bin_attribute___132;

struct attribute_group___132 {
	const char *name;
	umode_t (*is_visible)(struct kobject___132 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___132 *, struct bin_attribute___132 *, int);
	struct attribute **attrs;
	struct bin_attribute___132 **bin_attrs;
};

struct bin_attribute___132 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___141 * (*f_mapping)();
	ssize_t (*read)(struct file___141 *, struct kobject___132 *, struct bin_attribute___132 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___141 *, struct kobject___132 *, struct bin_attribute___132 *, char *, loff_t, size_t);
	int (*mmap)(struct file___141 *, struct kobject___132 *, struct bin_attribute___132 *, struct vm_area_struct___146 *);
};

struct sysfs_ops___132 {
	ssize_t (*show)(struct kobject___132 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___132 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___132;

struct kset___132 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___132 kobj;
	const struct kset_uevent_ops___132 *uevent_ops;
};

struct kobj_type___132 {
	void (*release)(struct kobject___132 *);
	const struct sysfs_ops___132 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___132 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___132 *);
	const void * (*namespace)(struct kobject___132 *);
	void (*get_ownership)(struct kobject___132 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___132 {
	int (* const filter)(struct kset___132 *, struct kobject___132 *);
	const char * (* const name)(struct kset___132 *, struct kobject___132 *);
	int (* const uevent)(struct kset___132 *, struct kobject___132 *, struct kobj_uevent_env *);
};

struct wakeup_source___103;

struct device___103;

struct dev_pm_info___103 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___103 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___103 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___103;

struct bus_type___103;

struct device_driver___103;

struct dev_pm_domain___103;

struct fwnode_handle___103;

struct class___103;

struct device___103 {
	struct kobject___132 kobj;
	struct device___103 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___103 *type;
	struct bus_type___103 *bus;
	struct device_driver___103 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___103 power;
	struct dev_pm_domain___103 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___103 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___103 *class;
	const struct attribute_group___132 **groups;
	void (*release)(struct device___103 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___103 {
	int (*prepare)(struct device___103 *);
	void (*complete)(struct device___103 *);
	int (*suspend)(struct device___103 *);
	int (*resume)(struct device___103 *);
	int (*freeze)(struct device___103 *);
	int (*thaw)(struct device___103 *);
	int (*poweroff)(struct device___103 *);
	int (*restore)(struct device___103 *);
	int (*suspend_late)(struct device___103 *);
	int (*resume_early)(struct device___103 *);
	int (*freeze_late)(struct device___103 *);
	int (*thaw_early)(struct device___103 *);
	int (*poweroff_late)(struct device___103 *);
	int (*restore_early)(struct device___103 *);
	int (*suspend_noirq)(struct device___103 *);
	int (*resume_noirq)(struct device___103 *);
	int (*freeze_noirq)(struct device___103 *);
	int (*thaw_noirq)(struct device___103 *);
	int (*poweroff_noirq)(struct device___103 *);
	int (*restore_noirq)(struct device___103 *);
	int (*runtime_suspend)(struct device___103 *);
	int (*runtime_resume)(struct device___103 *);
	int (*runtime_idle)(struct device___103 *);
};

struct wakeup_source___103 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___103 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___103 {
	struct dev_pm_ops___103 ops;
	int (*start)(struct device___103 *);
	void (*detach)(struct device___103 *, bool);
	int (*activate)(struct device___103 *);
	void (*sync)(struct device___103 *);
	void (*dismiss)(struct device___103 *);
};

struct bus_type___103 {
	const char *name;
	const char *dev_name;
	struct device___103 *dev_root;
	const struct attribute_group___132 **bus_groups;
	const struct attribute_group___132 **dev_groups;
	const struct attribute_group___132 **drv_groups;
	int (*match)(struct device___103 *, struct device_driver___103 *);
	int (*uevent)(struct device___103 *, struct kobj_uevent_env *);
	int (*probe)(struct device___103 *);
	void (*sync_state)(struct device___103 *);
	void (*remove)(struct device___103 *);
	void (*shutdown)(struct device___103 *);
	int (*online)(struct device___103 *);
	int (*offline)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	int (*num_vf)(struct device___103 *);
	int (*dma_configure)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___103 {
	const char *name;
	struct bus_type___103 *bus;
	struct module___130 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___103 *);
	void (*sync_state)(struct device___103 *);
	int (*remove)(struct device___103 *);
	void (*shutdown)(struct device___103 *);
	int (*suspend)(struct device___103 *, pm_message_t);
	int (*resume)(struct device___103 *);
	const struct attribute_group___132 **groups;
	const struct attribute_group___132 **dev_groups;
	const struct dev_pm_ops___103 *pm;
	void (*coredump)(struct device___103 *);
	struct driver_private *p;
};

struct device_type___103 {
	const char *name;
	const struct attribute_group___132 **groups;
	int (*uevent)(struct device___103 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___103 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___103 *);
	const struct dev_pm_ops___103 *pm;
};

struct class___103 {
	const char *name;
	struct module___130 *owner;
	const struct attribute_group___132 **class_groups;
	const struct attribute_group___132 **dev_groups;
	struct kobject___132 *dev_kobj;
	int (*dev_uevent)(struct device___103 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___103 *, umode_t *);
	void (*class_release)(struct class___103 *);
	void (*dev_release)(struct device___103 *);
	int (*shutdown_pre)(struct device___103 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___103 *);
	void (*get_ownership)(struct device___103 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___103 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___103;

struct fwnode_handle___103 {
	struct fwnode_handle___103 *secondary;
	const struct fwnode_operations___103 *ops;
	struct device___103 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___139 {
	void (*page_free)(struct page___146 *);
	void (*kill)(struct dev_pagemap___139 *);
	void (*cleanup)(struct dev_pagemap___139 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___139 *);
};

struct seq_operations___122 {
	void * (*start)(struct seq_file___122 *, loff_t *);
	void (*stop)(struct seq_file___122 *, void *);
	void * (*next)(struct seq_file___122 *, void *, loff_t *);
	int (*show)(struct seq_file___122 *, void *);
};

struct fwnode_reference_args___103;

struct fwnode_endpoint___103;

struct fwnode_operations___103 {
	struct fwnode_handle___103 * (*get)(struct fwnode_handle___103 *);
	void (*put)(struct fwnode_handle___103 *);
	bool (*device_is_available)(const struct fwnode_handle___103 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___103 *, const struct device___103 *);
	bool (*property_present)(const struct fwnode_handle___103 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___103 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___103 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___103 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*get_parent)(const struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*get_next_child_node)(const struct fwnode_handle___103 *, struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*get_named_child_node)(const struct fwnode_handle___103 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___103 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___103 *);
	struct fwnode_handle___103 * (*graph_get_next_endpoint)(const struct fwnode_handle___103 *, struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*graph_get_remote_endpoint)(const struct fwnode_handle___103 *);
	struct fwnode_handle___103 * (*graph_get_port_parent)(struct fwnode_handle___103 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___103 *, struct fwnode_endpoint___103 *);
	int (*add_links)(struct fwnode_handle___103 *);
};

struct fwnode_endpoint___103 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___103 *local_fwnode;
};

struct fwnode_reference_args___103 {
	struct fwnode_handle___103 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ipc_namespace___3 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___141 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___22 ns;
};

struct cgroup_namespace___99 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___99 *root_cset;
};

struct kernel_param_ops___129 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___129 *);
	int (*get)(char *, const struct kernel_param___129 *);
	void (*free)(void *);
};

struct kparam_array___129;

struct kernel_param___129 {
	const char *name;
	struct module___130 *mod;
	const struct kernel_param_ops___129 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___129 *arr;
	};
};

struct kparam_array___129 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___129 *ops;
	void *elem;
};

struct module_attribute___129 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___129 *, struct module_kobject___129 *, char *);
	ssize_t (*store)(struct module_attribute___129 *, struct module_kobject___129 *, const char *, size_t);
	void (*setup)(struct module___130 *, const char *);
	int (*test)(struct module___130 *);
	void (*free)(struct module___130 *);
};

struct trace_event_class___60;

struct trace_event_call___60 {
	struct list_head list;
	struct trace_event_class___60 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___60 *, struct perf_event___66 *);
};

struct cftype___99;

struct cgroup_subsys___99 {
	struct cgroup_subsys_state___99 * (*css_alloc)(struct cgroup_subsys_state___99 *);
	int (*css_online)(struct cgroup_subsys_state___99 *);
	void (*css_offline)(struct cgroup_subsys_state___99 *);
	void (*css_released)(struct cgroup_subsys_state___99 *);
	void (*css_free)(struct cgroup_subsys_state___99 *);
	void (*css_reset)(struct cgroup_subsys_state___99 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___99 *, int);
	int (*css_extra_stat_show)(struct seq_file___122 *, struct cgroup_subsys_state___99 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___148 *, struct css_set___99 *);
	void (*cancel_fork)(struct task_struct___148 *, struct css_set___99 *);
	void (*fork)(struct task_struct___148 *);
	void (*exit)(struct task_struct___148 *);
	void (*release)(struct task_struct___148 *);
	void (*bind)(struct cgroup_subsys_state___99 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___99 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___99 *dfl_cftypes;
	struct cftype___99 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___99 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___99 *updated_children;
	struct cgroup___99 *updated_next;
};

struct cgroup_root___99 {
	struct kernfs_root___132 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___99 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___99 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___99 *ss;
	struct list_head node;
	struct kernfs_ops___132 *kf_ops;
	int (*open)(struct kernfs_open_file___132 *);
	void (*release)(struct kernfs_open_file___132 *);
	u64 (*read_u64)(struct cgroup_subsys_state___99 *, struct cftype___99 *);
	s64 (*read_s64)(struct cgroup_subsys_state___99 *, struct cftype___99 *);
	int (*seq_show)(struct seq_file___122 *, void *);
	void * (*seq_start)(struct seq_file___122 *, loff_t *);
	void * (*seq_next)(struct seq_file___122 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___122 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___99 *, struct cftype___99 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___99 *, struct cftype___99 *, s64);
	ssize_t (*write)(struct kernfs_open_file___132 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___132 *, struct poll_table_struct___90 *);
};

struct perf_cpu_context___66;

struct perf_output_handle___66;

struct pmu___66 {
	struct list_head entry;
	struct module___130 *module;
	struct device___103 *dev;
	const struct attribute_group___132 **attr_groups;
	const struct attribute_group___132 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___66 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___66 *);
	void (*pmu_disable)(struct pmu___66 *);
	int (*event_init)(struct perf_event___66 *);
	void (*event_mapped)(struct perf_event___66 *, struct mm_struct___147 *);
	void (*event_unmapped)(struct perf_event___66 *, struct mm_struct___147 *);
	int (*add)(struct perf_event___66 *, int);
	void (*del)(struct perf_event___66 *, int);
	void (*start)(struct perf_event___66 *, int);
	void (*stop)(struct perf_event___66 *, int);
	void (*read)(struct perf_event___66 *);
	void (*start_txn)(struct pmu___66 *, unsigned int);
	int (*commit_txn)(struct pmu___66 *);
	void (*cancel_txn)(struct pmu___66 *);
	int (*event_idx)(struct perf_event___66 *);
	void (*sched_task)(struct perf_event_context___66 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___66 *, struct perf_event_context___66 *);
	void * (*setup_aux)(struct perf_event___66 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___66 *, struct perf_output_handle___66 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___66 *);
	int (*aux_output_match)(struct perf_event___66 *);
	int (*filter_match)(struct perf_event___66 *);
	int (*check_period)(struct perf_event___66 *, u64);
};

struct perf_cpu_context___66 {
	struct perf_event_context___66 ctx;
	struct perf_event_context___66 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___66 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___66 **heap;
	struct perf_event___66 *heap_default[2];
};

struct perf_output_handle___66 {
	struct perf_event___66 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___66 {
	struct cgroup_subsys_state___99 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___60 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___60 *);
	};
};

struct trace_event_class___60 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___60 *, enum trace_reg, void *);
	struct trace_event_fields___60 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___60 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___60 *);
};

struct compat_ipc_perm {
	key_t key;
	__compat_uid_t uid;
	__compat_gid_t gid;
	__compat_uid_t cuid;
	__compat_gid_t cgid;
	compat_mode_t mode;
	short unsigned int seq;
};

struct dentry___142;

struct super_block___142;

struct file_system_type___142 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___142 * (*mount)(struct file_system_type___142 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___142 *);
	struct module___8 *owner;
	struct file_system_type___142 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___142;

struct kiocb___142;

struct vm_area_struct___147;

struct inode___142;

struct file_lock___142;

struct page___147;

struct seq_file___123;

struct file_operations___142 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___142 *, loff_t, int);
	ssize_t (*read)(struct file___142 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___142 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___142 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___142 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___142 *, bool);
	int (*iterate)(struct file___142 *, struct dir_context *);
	int (*iterate_shared)(struct file___142 *, struct dir_context *);
	__poll_t (*poll)(struct file___142 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___142 *, struct vm_area_struct___147 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___142 *, struct file___142 *);
	int (*flush)(struct file___142 *, fl_owner_t);
	int (*release)(struct inode___142 *, struct file___142 *);
	int (*fsync)(struct file___142 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___142 *, int);
	int (*lock)(struct file___142 *, int, struct file_lock___142 *);
	ssize_t (*sendpage)(struct file___142 *, struct page___147 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___142 *, long unsigned int);
	int (*flock)(struct file___142 *, int, struct file_lock___142 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___142 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___142 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___142 *, long int, struct file_lock___142 **, void **);
	long int (*fallocate)(struct file___142 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___123 *, struct file___142 *);
	ssize_t (*copy_file_range)(struct file___142 *, loff_t, struct file___142 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___142 *, loff_t, struct file___142 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___142 *, loff_t, loff_t, int);
};

struct vmacache___147 {
	u64 seqnum;
	struct vm_area_struct___147 *vmas[4];
};

struct page_frag___147 {
	struct page___147 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___148;

struct pid___127;

struct nsproxy___133;

struct signal_struct___143;

struct vm_struct___129;

struct task_struct___149 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___149 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___148 *mm;
	struct mm_struct___148 *active_mm;
	struct vmacache___147 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___149 *real_parent;
	struct task_struct___149 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___149 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___127 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___133 *nsproxy;
	struct signal_struct___143 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___149 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___64 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___147 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___149 *oom_reaper_list;
	struct vm_struct___129 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___66 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___147 *pgtable_t___147;

struct address_space___142;

struct dev_pagemap___140;

struct page___147 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___142 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___147 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___147 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___148 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___140 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___140;

struct vm_area_struct___147 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___147 *vm_next;
	struct vm_area_struct___147 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___148 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___140 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___142 *vm_file;
	struct file___142 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___147;

struct mm_struct___148 {
	struct {
		struct vm_area_struct___147 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___147 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___149 *owner;
		struct user_namespace *user_ns;
		struct file___142 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___142;

struct address_space___142 {
	struct inode___142 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___142 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___140;

struct dev_pagemap___140 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___140 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___142;

struct path___142 {
	struct vfsmount___142 *mnt;
	struct dentry___142 *dentry;
};

struct fown_struct___127 {
	rwlock_t lock;
	struct pid___127 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___142 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___142 f_path;
	struct inode___142 *f_inode;
	const struct file_operations___142 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___127 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___142 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___140;

struct vm_operations_struct___140 {
	void (*open)(struct vm_area_struct___147 *);
	void (*close)(struct vm_area_struct___147 *);
	int (*may_split)(struct vm_area_struct___147 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___147 *);
	int (*mprotect)(struct vm_area_struct___147 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___140 *);
	vm_fault_t (*huge_fault)(struct vm_fault___140 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___140 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___147 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___140 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___140 *);
	int (*access)(struct vm_area_struct___147 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___147 *);
	int (*set_policy)(struct vm_area_struct___147 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___147 *, long unsigned int);
	struct page___147 * (*find_special_page)(struct vm_area_struct___147 *, long unsigned int);
};

struct core_thread___147 {
	struct task_struct___149 *task;
	struct core_thread___147 *next;
};

struct core_state___147 {
	atomic_t nr_threads;
	struct core_thread___147 dumper;
	struct completion startup;
};

struct vm_fault___140 {
	const struct {
		struct vm_area_struct___147 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___147 *cow_page;
	struct page___147 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___147 prealloc_pte;
};

struct dev_pagemap_ops___140 {
	void (*page_free)(struct page___147 *);
	void (*kill)(struct dev_pagemap___140 *);
	void (*cleanup)(struct dev_pagemap___140 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___140 *);
};

struct pid_namespace___127;

struct upid___127 {
	int nr;
	struct pid_namespace___127 *ns;
};

struct pid_namespace___127 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___149 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___127 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___24 ns;
};

struct pid___127 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___127 numbers[1];
};

struct ipc_perm {
	__kernel_key_t key;
	__kernel_uid_t uid;
	__kernel_gid_t gid;
	__kernel_uid_t cuid;
	__kernel_gid_t cgid;
	__kernel_mode_t mode;
	short unsigned int seq;
};

struct signal_struct___143 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___149 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___149 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___127 *pids[4];
	struct pid___127 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___148 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct ipc_namespace___4;

struct nsproxy___133 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace___4 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___127 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___129 {
	struct vm_struct___129 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___147 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___142;

struct dentry___142 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___142 *d_parent;
	struct qstr d_name;
	struct inode___142 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___142 *d_op;
	struct super_block___142 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___142;

struct inode___142 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___142 *i_op;
	struct super_block___142 *i_sb;
	struct address_space___142 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___142 *i_fop;
		void (*free_inode)(struct inode___142 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___142 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___142 {
	int (*d_revalidate)(struct dentry___142 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___142 *, unsigned int);
	int (*d_hash)(const struct dentry___142 *, struct qstr *);
	int (*d_compare)(const struct dentry___142 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___142 *);
	int (*d_init)(struct dentry___142 *);
	void (*d_release)(struct dentry___142 *);
	void (*d_prune)(struct dentry___142 *);
	void (*d_iput)(struct dentry___142 *, struct inode___142 *);
	char * (*d_dname)(struct dentry___142 *, char *, int);
	struct vfsmount___142 * (*d_automount)(struct path___142 *);
	int (*d_manage)(const struct path___142 *, bool);
	struct dentry___142 * (*d_real)(struct dentry___142 *, const struct inode___142 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___142;

struct mem_dqinfo___142 {
	struct quota_format_type___142 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___142;

struct quota_info___142 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___142 *files[3];
	struct mem_dqinfo___142 info[3];
	const struct quota_format_ops___142 *ops[3];
};

struct rcuwait___143 {
	struct task_struct___149 *task;
};

struct percpu_rw_semaphore___143 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___143 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___142 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___143 rw_sem[3];
};

struct super_operations___142;

struct dquot_operations___142;

struct quotactl_ops___142;

struct super_block___142 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___142 *s_type;
	const struct super_operations___142 *s_op;
	const struct dquot_operations___142 *dq_op;
	const struct quotactl_ops___142 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___142 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___142 s_dquot;
	struct sb_writers___142 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___142 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___142 {
	struct dentry___142 *mnt_root;
	struct super_block___142 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___142 {
	struct file___142 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___142 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___69 *ki_waitq;
	};
};

struct iattr___142 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___142 *ia_file;
};

struct dquot___142 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___142 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___142 {
	int qf_fmt_id;
	const struct quota_format_ops___142 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___142 *qf_next;
};

struct quota_format_ops___142 {
	int (*check_quota_file)(struct super_block___142 *, int);
	int (*read_file_info)(struct super_block___142 *, int);
	int (*write_file_info)(struct super_block___142 *, int);
	int (*free_file_info)(struct super_block___142 *, int);
	int (*read_dqblk)(struct dquot___142 *);
	int (*commit_dqblk)(struct dquot___142 *);
	int (*release_dqblk)(struct dquot___142 *);
	int (*get_next_id)(struct super_block___142 *, struct kqid *);
};

struct dquot_operations___142 {
	int (*write_dquot)(struct dquot___142 *);
	struct dquot___142 * (*alloc_dquot)(struct super_block___142 *, int);
	void (*destroy_dquot)(struct dquot___142 *);
	int (*acquire_dquot)(struct dquot___142 *);
	int (*release_dquot)(struct dquot___142 *);
	int (*mark_dirty)(struct dquot___142 *);
	int (*write_info)(struct super_block___142 *, int);
	qsize_t * (*get_reserved_space)(struct inode___142 *);
	int (*get_projid)(struct inode___142 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___142 *, qsize_t *);
	int (*get_next_id)(struct super_block___142 *, struct kqid *);
};

struct quotactl_ops___142 {
	int (*quota_on)(struct super_block___142 *, int, int, const struct path___142 *);
	int (*quota_off)(struct super_block___142 *, int);
	int (*quota_enable)(struct super_block___142 *, unsigned int);
	int (*quota_disable)(struct super_block___142 *, unsigned int);
	int (*quota_sync)(struct super_block___142 *, int);
	int (*set_info)(struct super_block___142 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___142 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___142 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___142 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___142 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___142 *, unsigned int);
};

struct address_space_operations___142 {
	int (*writepage)(struct page___147 *, struct writeback_control___3 *);
	int (*readpage)(struct file___142 *, struct page___147 *);
	int (*writepages)(struct address_space___142 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___147 *);
	int (*readpages)(struct file___142 *, struct address_space___142 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___142 *, struct address_space___142 *, loff_t, unsigned int, unsigned int, struct page___147 **, void **);
	int (*write_end)(struct file___142 *, struct address_space___142 *, loff_t, unsigned int, unsigned int, struct page___147 *, void *);
	sector_t (*bmap)(struct address_space___142 *, sector_t);
	void (*invalidatepage)(struct page___147 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___147 *, gfp_t);
	void (*freepage)(struct page___147 *);
	ssize_t (*direct_IO)(struct kiocb___142 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___142 *, struct page___147 *, struct page___147 *, enum migrate_mode);
	bool (*isolate_page)(struct page___147 *, isolate_mode_t);
	void (*putback_page)(struct page___147 *);
	int (*launder_page)(struct page___147 *);
	int (*is_partially_uptodate)(struct page___147 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___147 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___142 *, struct page___147 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___142 *, sector_t *);
	void (*swap_deactivate)(struct file___142 *);
};

struct inode_operations___142 {
	struct dentry___142 * (*lookup)(struct inode___142 *, struct dentry___142 *, unsigned int);
	const char * (*get_link)(struct dentry___142 *, struct inode___142 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___142 *, int);
	struct posix_acl * (*get_acl)(struct inode___142 *, int, bool);
	int (*readlink)(struct dentry___142 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___142 *, struct dentry___142 *, umode_t, bool);
	int (*link)(struct dentry___142 *, struct inode___142 *, struct dentry___142 *);
	int (*unlink)(struct inode___142 *, struct dentry___142 *);
	int (*symlink)(struct user_namespace *, struct inode___142 *, struct dentry___142 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___142 *, struct dentry___142 *, umode_t);
	int (*rmdir)(struct inode___142 *, struct dentry___142 *);
	int (*mknod)(struct user_namespace *, struct inode___142 *, struct dentry___142 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___142 *, struct dentry___142 *, struct inode___142 *, struct dentry___142 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___142 *, struct iattr___142 *);
	int (*getattr)(struct user_namespace *, const struct path___142 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___142 *, char *, size_t);
	int (*fiemap)(struct inode___142 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___142 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___142 *, struct dentry___142 *, struct file___142 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___142 *, struct dentry___142 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___142 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___142 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___142 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___142 {
	void (*fl_copy_lock)(struct file_lock___142 *, struct file_lock___142 *);
	void (*fl_release_private)(struct file_lock___142 *);
};

struct fasync_struct___142;

struct lock_manager_operations___142;

struct file_lock___142 {
	struct file_lock___142 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___142 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___142 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___142 *fl_ops;
	const struct lock_manager_operations___142 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___142 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___142 *);
	int (*lm_grant)(struct file_lock___142 *, int);
	bool (*lm_break)(struct file_lock___142 *);
	int (*lm_change)(struct file_lock___142 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___142 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___142 *);
};

struct fasync_struct___142 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___142 *fa_next;
	struct file___142 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___142 {
	struct inode___142 * (*alloc_inode)(struct super_block___142 *);
	void (*destroy_inode)(struct inode___142 *);
	void (*free_inode)(struct inode___142 *);
	void (*dirty_inode)(struct inode___142 *, int);
	int (*write_inode)(struct inode___142 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___142 *);
	void (*evict_inode)(struct inode___142 *);
	void (*put_super)(struct super_block___142 *);
	int (*sync_fs)(struct super_block___142 *, int);
	int (*freeze_super)(struct super_block___142 *);
	int (*freeze_fs)(struct super_block___142 *);
	int (*thaw_super)(struct super_block___142 *);
	int (*unfreeze_fs)(struct super_block___142 *);
	int (*statfs)(struct dentry___142 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___142 *, int *, char *);
	void (*umount_begin)(struct super_block___142 *);
	int (*show_options)(struct seq_file___123 *, struct dentry___142 *);
	int (*show_devname)(struct seq_file___123 *, struct dentry___142 *);
	int (*show_path)(struct seq_file___123 *, struct dentry___142 *);
	int (*show_stats)(struct seq_file___123 *, struct dentry___142 *);
	ssize_t (*quota_read)(struct super_block___142 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___142 *, int, const char *, size_t, loff_t);
	struct dquot___142 ** (*get_dquots)(struct inode___142 *);
	long int (*nr_cached_objects)(struct super_block___142 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___142 *, struct shrink_control___52 *);
	struct file___142 * (*real_loop)(struct file___142 *);
};

struct seq_operations___123;

struct seq_file___123 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___123 *op;
	int poll_event;
	const struct file___142 *file;
	void *private;
};

struct seq_operations___123 {
	void * (*start)(struct seq_file___123 *, loff_t *);
	void (*stop)(struct seq_file___123 *, void *);
	void * (*next)(struct seq_file___123 *, void *, loff_t *);
	int (*show)(struct seq_file___123 *, void *);
};

struct proc_ops___19 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___142 *, struct file___142 *);
	ssize_t (*proc_read)(struct file___142 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___142 *, struct iov_iter___78 *);
	ssize_t (*proc_write)(struct file___142 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___142 *, loff_t, int);
	int (*proc_release)(struct inode___142 *, struct file___142 *);
	__poll_t (*proc_poll)(struct file___142 *, struct poll_table_struct___5 *);
	long int (*proc_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___142 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___142 *, struct vm_area_struct___147 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___142 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct ipc_namespace___4 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___142 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___24 ns;
};

struct ipc_params {
	key_t key;
	int flg;
	union {
		size_t size;
		int nsems;
	} u;
};

struct ipc_ops {
	int (*getnew)(struct ipc_namespace___4 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct ipc_proc_iface {
	const char *path;
	const char *header;
	int ids;
	int (*show)(struct seq_file___123 *, void *);
};

struct ipc_proc_iter {
	struct ipc_namespace___4 *ns;
	struct pid_namespace___127 *pid_ns;
	struct ipc_proc_iface *iface;
};

struct dentry___143;

struct super_block___143;

struct file_system_type___143 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___143 * (*mount)(struct file_system_type___143 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___143 *);
	struct module___8 *owner;
	struct file_system_type___143 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___143;

struct kiocb___143;

struct vm_area_struct___148;

struct inode___143;

struct file_lock___143;

struct page___148;

struct file_operations___143 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___143 *, loff_t, int);
	ssize_t (*read)(struct file___143 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___143 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___143 *, struct iov_iter___78 *);
	ssize_t (*write_iter)(struct kiocb___143 *, struct iov_iter___78 *);
	int (*iopoll)(struct kiocb___143 *, bool);
	int (*iterate)(struct file___143 *, struct dir_context *);
	int (*iterate_shared)(struct file___143 *, struct dir_context *);
	__poll_t (*poll)(struct file___143 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___143 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___143 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___143 *, struct vm_area_struct___148 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___143 *, struct file___143 *);
	int (*flush)(struct file___143 *, fl_owner_t);
	int (*release)(struct inode___143 *, struct file___143 *);
	int (*fsync)(struct file___143 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___143 *, int);
	int (*lock)(struct file___143 *, int, struct file_lock___143 *);
	ssize_t (*sendpage)(struct file___143 *, struct page___148 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___143 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___143 *, long unsigned int);
	int (*flock)(struct file___143 *, int, struct file_lock___143 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___143 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___143 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___143 *, long int, struct file_lock___143 **, void **);
	long int (*fallocate)(struct file___143 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___143 *);
	ssize_t (*copy_file_range)(struct file___143 *, loff_t, struct file___143 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___143 *, loff_t, struct file___143 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___143 *, loff_t, loff_t, int);
};

struct vmacache___148 {
	u64 seqnum;
	struct vm_area_struct___148 *vmas[4];
};

struct page_frag___148 {
	struct page___148 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___149;

struct nsproxy___134;

struct signal_struct___144;

struct task_struct___150 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___150 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___149 *mm;
	struct mm_struct___149 *active_mm;
	struct vmacache___148 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___150 *real_parent;
	struct task_struct___150 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___150 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___127 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___134 *nsproxy;
	struct signal_struct___144 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___150 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___64 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___148 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___150 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___66 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___143;

struct path___143 {
	struct vfsmount___143 *mnt;
	struct dentry___143 *dentry;
};

struct address_space___143;

struct file___143 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___143 f_path;
	struct inode___143 *f_inode;
	const struct file_operations___143 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___127 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___143 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct dentry_operations___143;

struct dentry___143 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___143 *d_parent;
	struct qstr d_name;
	struct inode___143 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___143 *d_op;
	struct super_block___143 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___143;

struct address_space___143 {
	struct inode___143 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___143 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___143;

struct inode___143 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___143 *i_op;
	struct super_block___143 *i_sb;
	struct address_space___143 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___143 *i_fop;
		void (*free_inode)(struct inode___143 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___143 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___143 {
	int (*d_revalidate)(struct dentry___143 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___143 *, unsigned int);
	int (*d_hash)(const struct dentry___143 *, struct qstr *);
	int (*d_compare)(const struct dentry___143 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___143 *);
	int (*d_init)(struct dentry___143 *);
	void (*d_release)(struct dentry___143 *);
	void (*d_prune)(struct dentry___143 *);
	void (*d_iput)(struct dentry___143 *, struct inode___143 *);
	char * (*d_dname)(struct dentry___143 *, char *, int);
	struct vfsmount___143 * (*d_automount)(struct path___143 *);
	int (*d_manage)(const struct path___143 *, bool);
	struct dentry___143 * (*d_real)(struct dentry___143 *, const struct inode___143 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___143;

struct mem_dqinfo___143 {
	struct quota_format_type___143 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___143;

struct quota_info___143 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___143 *files[3];
	struct mem_dqinfo___143 info[3];
	const struct quota_format_ops___143 *ops[3];
};

struct rcuwait___144 {
	struct task_struct___150 *task;
};

struct percpu_rw_semaphore___144 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___144 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___143 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___144 rw_sem[3];
};

struct super_operations___143;

struct dquot_operations___143;

struct quotactl_ops___143;

struct super_block___143 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___143 *s_type;
	const struct super_operations___143 *s_op;
	const struct dquot_operations___143 *dq_op;
	const struct quotactl_ops___143 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___143 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___143 s_dquot;
	struct sb_writers___143 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___143 *s_d_op;
	int cleancache_poolid;
	struct shrinker___52 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___143 {
	struct dentry___143 *mnt_root;
	struct super_block___143 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

typedef struct page___148 *pgtable_t___148;

struct dev_pagemap___141;

struct page___148 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___143 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___148 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___148 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___149 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___141 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___141;

struct vm_area_struct___148 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___148 *vm_next;
	struct vm_area_struct___148 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___149 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___141 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___143 *vm_file;
	struct file___143 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___144 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___150 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___150 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___127 *pids[4];
	struct pid___127 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___149 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___148;

struct mm_struct___149 {
	struct {
		struct vm_area_struct___148 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___143 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___148 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___150 *owner;
		struct user_namespace *user_ns;
		struct file___143 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct uts_namespace___8;

struct ipc_namespace___5;

struct nsproxy___134 {
	atomic_t count;
	struct uts_namespace___8 *uts_ns;
	struct ipc_namespace___5 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct dev_pagemap_ops___141;

struct dev_pagemap___141 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___141 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___141;

struct vm_operations_struct___141 {
	void (*open)(struct vm_area_struct___148 *);
	void (*close)(struct vm_area_struct___148 *);
	int (*may_split)(struct vm_area_struct___148 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___148 *);
	int (*mprotect)(struct vm_area_struct___148 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___141 *);
	vm_fault_t (*huge_fault)(struct vm_fault___141 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___141 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___148 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___141 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___141 *);
	int (*access)(struct vm_area_struct___148 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___148 *);
	int (*set_policy)(struct vm_area_struct___148 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___148 *, long unsigned int);
	struct page___148 * (*find_special_page)(struct vm_area_struct___148 *, long unsigned int);
};

struct core_thread___148 {
	struct task_struct___150 *task;
	struct core_thread___148 *next;
};

struct core_state___148 {
	atomic_t nr_threads;
	struct core_thread___148 dumper;
	struct completion startup;
};

struct vm_fault___141 {
	const struct {
		struct vm_area_struct___148 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___148 *cow_page;
	struct page___148 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___148 prealloc_pte;
};

struct kiocb___143 {
	struct file___143 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___143 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___69 *ki_waitq;
	};
};

struct iattr___143 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___143 *ia_file;
};

struct dquot___143 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___143 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___143 {
	int qf_fmt_id;
	const struct quota_format_ops___143 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___143 *qf_next;
};

struct quota_format_ops___143 {
	int (*check_quota_file)(struct super_block___143 *, int);
	int (*read_file_info)(struct super_block___143 *, int);
	int (*write_file_info)(struct super_block___143 *, int);
	int (*free_file_info)(struct super_block___143 *, int);
	int (*read_dqblk)(struct dquot___143 *);
	int (*commit_dqblk)(struct dquot___143 *);
	int (*release_dqblk)(struct dquot___143 *);
	int (*get_next_id)(struct super_block___143 *, struct kqid *);
};

struct dquot_operations___143 {
	int (*write_dquot)(struct dquot___143 *);
	struct dquot___143 * (*alloc_dquot)(struct super_block___143 *, int);
	void (*destroy_dquot)(struct dquot___143 *);
	int (*acquire_dquot)(struct dquot___143 *);
	int (*release_dquot)(struct dquot___143 *);
	int (*mark_dirty)(struct dquot___143 *);
	int (*write_info)(struct super_block___143 *, int);
	qsize_t * (*get_reserved_space)(struct inode___143 *);
	int (*get_projid)(struct inode___143 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___143 *, qsize_t *);
	int (*get_next_id)(struct super_block___143 *, struct kqid *);
};

struct quotactl_ops___143 {
	int (*quota_on)(struct super_block___143 *, int, int, const struct path___143 *);
	int (*quota_off)(struct super_block___143 *, int);
	int (*quota_enable)(struct super_block___143 *, unsigned int);
	int (*quota_disable)(struct super_block___143 *, unsigned int);
	int (*quota_sync)(struct super_block___143 *, int);
	int (*set_info)(struct super_block___143 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___143 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___143 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___143 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___143 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___143 *, unsigned int);
};

struct address_space_operations___143 {
	int (*writepage)(struct page___148 *, struct writeback_control___3 *);
	int (*readpage)(struct file___143 *, struct page___148 *);
	int (*writepages)(struct address_space___143 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___148 *);
	int (*readpages)(struct file___143 *, struct address_space___143 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___143 *, struct address_space___143 *, loff_t, unsigned int, unsigned int, struct page___148 **, void **);
	int (*write_end)(struct file___143 *, struct address_space___143 *, loff_t, unsigned int, unsigned int, struct page___148 *, void *);
	sector_t (*bmap)(struct address_space___143 *, sector_t);
	void (*invalidatepage)(struct page___148 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___148 *, gfp_t);
	void (*freepage)(struct page___148 *);
	ssize_t (*direct_IO)(struct kiocb___143 *, struct iov_iter___78 *);
	int (*migratepage)(struct address_space___143 *, struct page___148 *, struct page___148 *, enum migrate_mode);
	bool (*isolate_page)(struct page___148 *, isolate_mode_t);
	void (*putback_page)(struct page___148 *);
	int (*launder_page)(struct page___148 *);
	int (*is_partially_uptodate)(struct page___148 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___148 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___143 *, struct page___148 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___143 *, sector_t *);
	void (*swap_deactivate)(struct file___143 *);
};

struct inode_operations___143 {
	struct dentry___143 * (*lookup)(struct inode___143 *, struct dentry___143 *, unsigned int);
	const char * (*get_link)(struct dentry___143 *, struct inode___143 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___143 *, int);
	struct posix_acl * (*get_acl)(struct inode___143 *, int, bool);
	int (*readlink)(struct dentry___143 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___143 *, struct dentry___143 *, umode_t, bool);
	int (*link)(struct dentry___143 *, struct inode___143 *, struct dentry___143 *);
	int (*unlink)(struct inode___143 *, struct dentry___143 *);
	int (*symlink)(struct user_namespace *, struct inode___143 *, struct dentry___143 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___143 *, struct dentry___143 *, umode_t);
	int (*rmdir)(struct inode___143 *, struct dentry___143 *);
	int (*mknod)(struct user_namespace *, struct inode___143 *, struct dentry___143 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___143 *, struct dentry___143 *, struct inode___143 *, struct dentry___143 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___143 *, struct iattr___143 *);
	int (*getattr)(struct user_namespace *, const struct path___143 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___143 *, char *, size_t);
	int (*fiemap)(struct inode___143 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___143 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___143 *, struct dentry___143 *, struct file___143 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___143 *, struct dentry___143 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___143 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___143 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___143 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___143 {
	void (*fl_copy_lock)(struct file_lock___143 *, struct file_lock___143 *);
	void (*fl_release_private)(struct file_lock___143 *);
};

struct fasync_struct___143;

struct lock_manager_operations___143;

struct file_lock___143 {
	struct file_lock___143 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___143 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___143 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___143 *fl_ops;
	const struct lock_manager_operations___143 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___143 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___143 *);
	int (*lm_grant)(struct file_lock___143 *, int);
	bool (*lm_break)(struct file_lock___143 *);
	int (*lm_change)(struct file_lock___143 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___143 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___143 *);
};

struct fasync_struct___143 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___143 *fa_next;
	struct file___143 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___143 {
	struct inode___143 * (*alloc_inode)(struct super_block___143 *);
	void (*destroy_inode)(struct inode___143 *);
	void (*free_inode)(struct inode___143 *);
	void (*dirty_inode)(struct inode___143 *, int);
	int (*write_inode)(struct inode___143 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___143 *);
	void (*evict_inode)(struct inode___143 *);
	void (*put_super)(struct super_block___143 *);
	int (*sync_fs)(struct super_block___143 *, int);
	int (*freeze_super)(struct super_block___143 *);
	int (*freeze_fs)(struct super_block___143 *);
	int (*thaw_super)(struct super_block___143 *);
	int (*unfreeze_fs)(struct super_block___143 *);
	int (*statfs)(struct dentry___143 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___143 *, int *, char *);
	void (*umount_begin)(struct super_block___143 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___143 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___143 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___143 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___143 *);
	ssize_t (*quota_read)(struct super_block___143 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___143 *, int, const char *, size_t, loff_t);
	struct dquot___143 ** (*get_dquots)(struct inode___143 *);
	long int (*nr_cached_objects)(struct super_block___143 *, struct shrink_control___52 *);
	long int (*free_cached_objects)(struct super_block___143 *, struct shrink_control___52 *);
	struct file___143 * (*real_loop)(struct file___143 *);
};

struct dev_pagemap_ops___141 {
	void (*page_free)(struct page___148 *);
	void (*kill)(struct dev_pagemap___141 *);
	void (*cleanup)(struct dev_pagemap___141 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___141 *);
};

struct msg_msgseg;

struct msg_msg {
	struct list_head m_list;
	long int m_type;
	size_t m_ts;
	struct msg_msgseg *next;
	void *security;
};

struct msg_msgseg {
	struct msg_msgseg *next;
};

struct proc_ns_operations___25;

struct ns_common___25 {
	atomic_long_t stashed;
	const struct proc_ns_operations___25 *ops;
	unsigned int inum;
	refcount_t count;
};

struct uts_namespace___8 {
	struct new_utsname name;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct ns_common___25 ns;
};

struct ipc_namespace___5 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___143 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___25 ns;
};

struct nsset___24 {
	unsigned int flags;
	struct nsproxy___134 *nsproxy;
	struct fs_struct *fs;
	const struct cred___19 *cred;
};

struct proc_ns_operations___25 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___25 * (*get)(struct task_struct___150 *);
	void (*put)(struct ns_common___25 *);
	int (*install)(struct nsset___24 *, struct ns_common___25 *);
	struct user_namespace * (*owner)(struct ns_common___25 *);
	struct ns_common___25 * (*get_parent)(struct ns_common___25 *);
};

typedef int __kernel_ipc_pid_t;

typedef __kernel_long_t __kernel_old_time_t;

struct msgbuf {
	__kernel_long_t mtype;
	char mtext[1];
};

struct msg;

struct msqid_ds {
	struct ipc_perm msg_perm;
	struct msg *msg_first;
	struct msg *msg_last;
	__kernel_old_time_t msg_stime;
	__kernel_old_time_t msg_rtime;
	__kernel_old_time_t msg_ctime;
	long unsigned int msg_lcbytes;
	long unsigned int msg_lqbytes;
	short unsigned int msg_cbytes;
	short unsigned int msg_qnum;
	short unsigned int msg_qbytes;
	__kernel_ipc_pid_t msg_lspid;
	__kernel_ipc_pid_t msg_lrpid;
};

struct msqid64_ds {
	struct ipc64_perm msg_perm;
	long int msg_stime;
	long int msg_rtime;
	long int msg_ctime;
	long unsigned int msg_cbytes;
	long unsigned int msg_qnum;
	long unsigned int msg_qbytes;
	__kernel_pid_t msg_lspid;
	__kernel_pid_t msg_lrpid;
	long unsigned int __unused4;
	long unsigned int __unused5;
};

struct msginfo {
	int msgpool;
	int msgmap;
	int msgmax;
	int msgmnb;
	int msgmni;
	int msgssz;
	int msgtql;
	short unsigned int msgseg;
};

typedef u16 compat_ipc_pid_t;

struct compat_msqid64_ds {
	struct compat_ipc64_perm msg_perm;
	compat_ulong_t msg_stime;
	compat_ulong_t msg_stime_high;
	compat_ulong_t msg_rtime;
	compat_ulong_t msg_rtime_high;
	compat_ulong_t msg_ctime;
	compat_ulong_t msg_ctime_high;
	compat_ulong_t msg_cbytes;
	compat_ulong_t msg_qnum;
	compat_ulong_t msg_qbytes;
	compat_pid_t msg_lspid;
	compat_pid_t msg_lrpid;
	compat_ulong_t __unused4;
	compat_ulong_t __unused5;
};

struct syscall_metadata___32 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___60 *enter_event;
	struct trace_event_call___60 *exit_event;
};

struct ipc_ops___2 {
	int (*getnew)(struct ipc_namespace___3 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct msg_queue {
	struct kern_ipc_perm q_perm;
	time64_t q_stime;
	time64_t q_rtime;
	time64_t q_ctime;
	long unsigned int q_cbytes;
	long unsigned int q_qnum;
	long unsigned int q_qbytes;
	struct pid___126 *q_lspid;
	struct pid___126 *q_lrpid;
	struct list_head q_messages;
	struct list_head q_receivers;
	struct list_head q_senders;
	long: 64;
	long: 64;
};

struct msg_receiver {
	struct list_head r_list;
	struct task_struct___148 *r_tsk;
	int r_mode;
	long int r_msgtype;
	long int r_maxsize;
	struct msg_msg *r_msg;
};

struct msg_sender {
	struct list_head list;
	struct task_struct___148 *tsk;
	size_t msgsz;
};

struct compat_msqid_ds {
	struct compat_ipc_perm msg_perm;
	compat_uptr_t msg_first;
	compat_uptr_t msg_last;
	old_time32_t msg_stime;
	old_time32_t msg_rtime;
	old_time32_t msg_ctime;
	compat_ulong_t msg_lcbytes;
	compat_ulong_t msg_lqbytes;
	short unsigned int msg_cbytes;
	short unsigned int msg_qnum;
	short unsigned int msg_qbytes;
	compat_ipc_pid_t msg_lspid;
	compat_ipc_pid_t msg_lrpid;
};

struct compat_msgbuf {
	compat_long_t mtype;
	char mtext[1];
};

struct sem;

struct sem_queue;

struct sem_undo;

struct semid_ds {
	struct ipc_perm sem_perm;
	__kernel_old_time_t sem_otime;
	__kernel_old_time_t sem_ctime;
	struct sem *sem_base;
	struct sem_queue *sem_pending;
	struct sem_queue **sem_pending_last;
	struct sem_undo *undo;
	short unsigned int sem_nsems;
};

struct sem {
	int semval;
	struct pid___126 *sempid;
	spinlock_t lock;
	struct list_head pending_alter;
	struct list_head pending_const;
	time64_t sem_otime;
};

struct sem_queue {
	struct list_head list;
	struct task_struct___148 *sleeper;
	struct sem_undo *undo;
	struct pid___126 *pid;
	int status;
	struct sembuf *sops;
	struct sembuf *blocking;
	int nsops;
	bool alter;
	bool dupsop;
};

struct sem_undo {
	struct list_head list_proc;
	struct callback_head rcu;
	struct sem_undo_list *ulp;
	struct list_head list_id;
	int semid;
	short int *semadj;
};

struct semid64_ds {
	struct ipc64_perm sem_perm;
	long int sem_otime;
	long int sem_ctime;
	long unsigned int sem_nsems;
	long unsigned int __unused3;
	long unsigned int __unused4;
};

struct seminfo {
	int semmap;
	int semmni;
	int semmns;
	int semmnu;
	int semmsl;
	int semopm;
	int semume;
	int semusz;
	int semvmx;
	int semaem;
};

struct sem_undo_list {
	refcount_t refcnt;
	spinlock_t lock;
	struct list_head list_proc;
};

struct compat_semid64_ds {
	struct compat_ipc64_perm sem_perm;
	compat_ulong_t sem_otime;
	compat_ulong_t sem_otime_high;
	compat_ulong_t sem_ctime;
	compat_ulong_t sem_ctime_high;
	compat_ulong_t sem_nsems;
	compat_ulong_t __unused3;
	compat_ulong_t __unused4;
};

struct sem_array {
	struct kern_ipc_perm sem_perm;
	time64_t sem_ctime;
	struct list_head pending_alter;
	struct list_head pending_const;
	struct list_head list_id;
	int sem_nsems;
	int complex_count;
	unsigned int use_global_lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sem sems[0];
};

struct compat_semid_ds {
	struct compat_ipc_perm sem_perm;
	old_time32_t sem_otime;
	old_time32_t sem_ctime;
	compat_uptr_t sem_base;
	compat_uptr_t sem_pending;
	compat_uptr_t sem_pending_last;
	compat_uptr_t undo;
	short unsigned int sem_nsems;
};

struct fs_context___26;

struct fs_parameter_spec___18;

struct dentry___144;

struct super_block___144;

struct module___131;

struct file_system_type___144 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___26 *);
	const struct fs_parameter_spec___18 *parameters;
	struct dentry___144 * (*mount)(struct file_system_type___144 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___144 *);
	struct module___131 *owner;
	struct file_system_type___144 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___144;

struct kiocb___144;

struct iov_iter___79;

struct poll_table_struct___91;

struct vm_area_struct___149;

struct inode___144;

struct file_lock___144;

struct page___149;

struct seq_file___124;

struct file_operations___144 {
	struct module___131 *owner;
	loff_t (*llseek)(struct file___144 *, loff_t, int);
	ssize_t (*read)(struct file___144 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___144 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___144 *, struct iov_iter___79 *);
	ssize_t (*write_iter)(struct kiocb___144 *, struct iov_iter___79 *);
	int (*iopoll)(struct kiocb___144 *, bool);
	int (*iterate)(struct file___144 *, struct dir_context *);
	int (*iterate_shared)(struct file___144 *, struct dir_context *);
	__poll_t (*poll)(struct file___144 *, struct poll_table_struct___91 *);
	long int (*unlocked_ioctl)(struct file___144 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___144 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___144 *, struct vm_area_struct___149 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___144 *, struct file___144 *);
	int (*flush)(struct file___144 *, fl_owner_t);
	int (*release)(struct inode___144 *, struct file___144 *);
	int (*fsync)(struct file___144 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___144 *, int);
	int (*lock)(struct file___144 *, int, struct file_lock___144 *);
	ssize_t (*sendpage)(struct file___144 *, struct page___149 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___144 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___144 *, long unsigned int);
	int (*flock)(struct file___144 *, int, struct file_lock___144 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___144 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___144 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___144 *, long int, struct file_lock___144 **, void **);
	long int (*fallocate)(struct file___144 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___124 *, struct file___144 *);
	ssize_t (*copy_file_range)(struct file___144 *, loff_t, struct file___144 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___144 *, loff_t, struct file___144 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___144 *, loff_t, loff_t, int);
};

struct vmacache___149 {
	u64 seqnum;
	struct vm_area_struct___149 *vmas[4];
};

struct page_frag___149 {
	struct page___149 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___67;

struct debug_info___67 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___67 *hbp_break[16];
	struct perf_event___67 *hbp_watch[16];
};

struct thread_struct___67 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___67 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___150;

struct pid___128;

struct nsproxy___135;

struct signal_struct___145;

struct bio_list___65;

struct backing_dev_info___62;

struct io_context___65;

struct css_set___100;

struct perf_event_context___67;

struct mem_cgroup___53;

struct request_queue___65;

struct vm_struct___130;

struct task_struct___151 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___151 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___150 *mm;
	struct mm_struct___150 *active_mm;
	struct vmacache___149 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___151 *real_parent;
	struct task_struct___151 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___151 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___128 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___135 *nsproxy;
	struct signal_struct___145 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___151 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___65 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___62 *backing_dev_info;
	struct io_context___65 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___100 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___67 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___149 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___53 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___53 *active_memcg;
	struct request_queue___65 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___151 *oom_reaper_list;
	struct vm_struct___130 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___67 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___133;

struct kobj_type___133;

struct kernfs_node___133;

struct kobject___133 {
	const char *name;
	struct list_head entry;
	struct kobject___133 *parent;
	struct kset___133 *kset;
	struct kobj_type___133 *ktype;
	struct kernfs_node___133 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___130 {
	struct kobject___133 kobj;
	struct module___131 *mod;
	struct kobject___133 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___130 {
	struct module___131 *mod;
	struct latch_tree_node node;
};

struct module_layout___130 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___130 mtn;
};

struct module_attribute___130;

struct kernel_param___130;

struct trace_event_call___61;

struct module___131 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___130 mkobj;
	struct module_attribute___130 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___133 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___130 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___130 core_layout;
	struct module_layout___130 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___61 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___67 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___151 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___67)(struct perf_event___67 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___67;

struct fasync_struct___144;

struct pid_namespace___128;

struct perf_cgroup___67;

struct perf_event___67 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___67 *group_leader;
	struct pmu___67 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___67 hw;
	struct perf_event_context___67 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___67 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___151 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___144 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___67 *aux_event;
	void (*destroy)(struct perf_event___67 *);
	struct callback_head callback_head;
	struct pid_namespace___128 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___67 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___67 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___61 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___67 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___149 *pgtable_t___149;

struct address_space___144;

struct dev_pagemap___142;

struct page___149 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___144 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___149 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___149 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___150 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___142 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___142;

struct vm_area_struct___149 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___149 *vm_next;
	struct vm_area_struct___149 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___150 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___142 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___144 *vm_file;
	struct file___144 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___149;

struct mm_struct___150 {
	struct {
		struct vm_area_struct___149 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___144 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___149 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___151 *owner;
		struct user_namespace___19 *user_ns;
		struct file___144 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___144;

struct address_space___144 {
	struct inode___144 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___144 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___142;

struct dev_pagemap___142 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___142 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___144;

struct path___144 {
	struct vfsmount___144 *mnt;
	struct dentry___144 *dentry;
};

struct fown_struct___128 {
	rwlock_t lock;
	struct pid___128 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___144 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___144 f_path;
	struct inode___144 *f_inode;
	const struct file_operations___144 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___128 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___144 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___142;

struct vm_operations_struct___142 {
	void (*open)(struct vm_area_struct___149 *);
	void (*close)(struct vm_area_struct___149 *);
	int (*may_split)(struct vm_area_struct___149 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___149 *);
	int (*mprotect)(struct vm_area_struct___149 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___142 *);
	vm_fault_t (*huge_fault)(struct vm_fault___142 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___142 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___149 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___142 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___142 *);
	int (*access)(struct vm_area_struct___149 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___149 *);
	int (*set_policy)(struct vm_area_struct___149 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___149 *, long unsigned int);
	struct page___149 * (*find_special_page)(struct vm_area_struct___149 *, long unsigned int);
};

struct core_thread___149 {
	struct task_struct___151 *task;
	struct core_thread___149 *next;
};

struct core_state___149 {
	atomic_t nr_threads;
	struct core_thread___149 dumper;
	struct completion startup;
};

struct vm_fault___142 {
	const struct {
		struct vm_area_struct___149 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___149 *cow_page;
	struct page___149 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___149 prealloc_pte;
};

struct pglist_data___60;

struct lruvec___60 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___60 *pgdat;
};

struct zone___60 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___60 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___60 {
	struct zone___60 *zone;
	int zone_idx;
};

struct zonelist___60 {
	struct zoneref___60 _zonerefs[321];
};

struct pglist_data___60 {
	struct zone___60 node_zones[5];
	struct zonelist___60 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___151 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___151 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___60 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___53 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___53 *memcg;
};

struct cgroup___100;

struct cgroup_subsys___100;

struct cgroup_subsys_state___100 {
	struct cgroup___100 *cgroup;
	struct cgroup_subsys___100 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___100 *parent;
};

struct cgroup_file___100 {
	struct kernfs_node___133 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___53;

struct mem_cgroup_per_node___53;

struct mem_cgroup___53 {
	struct cgroup_subsys_state___100 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___100 events_file;
	struct cgroup_file___100 events_local_file;
	struct cgroup_file___100 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___53 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___151 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___53 *nodeinfo[0];
	long: 64;
};

struct shrinker___53 {
	long unsigned int (*count_objects)(struct shrinker___53 *, struct shrink_control___53 *);
	long unsigned int (*scan_objects)(struct shrinker___53 *, struct shrink_control___53 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___142 {
	void (*page_free)(struct page___149 *);
	void (*kill)(struct dev_pagemap___142 *);
	void (*cleanup)(struct dev_pagemap___142 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___142 *);
};

struct upid___128 {
	int nr;
	struct pid_namespace___128 *ns;
};

struct pid_namespace___128 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___151 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___128 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___128 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___128 numbers[1];
};

struct shmid_ds {
	struct ipc_perm shm_perm;
	int shm_segsz;
	__kernel_old_time_t shm_atime;
	__kernel_old_time_t shm_dtime;
	__kernel_old_time_t shm_ctime;
	__kernel_ipc_pid_t shm_cpid;
	__kernel_ipc_pid_t shm_lpid;
	short unsigned int shm_nattch;
	short unsigned int shm_unused;
	void *shm_unused2;
	void *shm_unused3;
};

struct shmid64_ds {
	struct ipc64_perm shm_perm;
	size_t shm_segsz;
	long int shm_atime;
	long int shm_dtime;
	long int shm_ctime;
	__kernel_pid_t shm_cpid;
	__kernel_pid_t shm_lpid;
	long unsigned int shm_nattch;
	long unsigned int __unused4;
	long unsigned int __unused5;
};

struct shminfo64 {
	long unsigned int shmmax;
	long unsigned int shmmin;
	long unsigned int shmmni;
	long unsigned int shmseg;
	long unsigned int shmall;
	long unsigned int __unused1;
	long unsigned int __unused2;
	long unsigned int __unused3;
	long unsigned int __unused4;
};

struct shminfo {
	int shmmax;
	int shmmin;
	int shmmni;
	int shmseg;
	int shmall;
};

struct shm_info {
	int used_ids;
	__kernel_ulong_t shm_tot;
	__kernel_ulong_t shm_rss;
	__kernel_ulong_t shm_swp;
	__kernel_ulong_t swap_attempts;
	__kernel_ulong_t swap_successes;
};

struct signal_struct___145 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___151 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___151 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___128 *pids[4];
	struct pid___128 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___150 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct ipc_namespace___6;

struct cgroup_namespace___100;

struct nsproxy___135 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace___6 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___128 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___100 *cgroup_ns;
};

struct bio___65;

struct bio_list___65 {
	struct bio___65 *head;
	struct bio___65 *tail;
};

struct bdi_writeback___62 {
	struct backing_dev_info___62 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___100 *memcg_css;
	struct cgroup_subsys_state___100 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___104;

struct backing_dev_info___62 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___62 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___104 *dev;
	char dev_name[64];
	struct device___104 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___144 *debug_dir;
};

struct io_cq___65;

struct io_context___65 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___65 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___100 {
	struct cgroup_subsys_state___100 *subsys[14];
	refcount_t refcount;
	struct css_set___100 *dom_cset;
	struct cgroup___100 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___100 *mg_src_cgrp;
	struct cgroup___100 *mg_dst_cgrp;
	struct css_set___100 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___67 {
	struct pmu___67 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___151 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___67 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___65;

struct blk_integrity___65 {
	const struct blk_integrity_profile___65 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___65 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___65 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___65;

struct elevator_queue___65;

struct blk_mq_ops___62;

struct blk_mq_hw_ctx___62;

struct gendisk___65;

struct blkcg_gq___62;

struct blk_mq_tag_set___62;

struct request_queue___65 {
	struct request___65 *last_merge;
	struct elevator_queue___65 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___62 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___62 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___65 *disk;
	struct kobject___133 kobj;
	struct kobject___133 *mq_kobj;
	struct blk_integrity___65 integrity;
	struct device___104 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___62 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___62 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___65 bio_split;
	struct dentry___144 *debugfs_dir;
	struct dentry___144 *sched_debugfs_dir;
	struct dentry___144 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___130 {
	struct vm_struct___130 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___149 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___144;

struct dentry___144 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___144 *d_parent;
	struct qstr d_name;
	struct inode___144 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___144 *d_op;
	struct super_block___144 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___144;

struct inode___144 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___144 *i_op;
	struct super_block___144 *i_sb;
	struct address_space___144 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___62 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___144 *i_fop;
		void (*free_inode)(struct inode___144 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___144 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___144 {
	int (*d_revalidate)(struct dentry___144 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___144 *, unsigned int);
	int (*d_hash)(const struct dentry___144 *, struct qstr *);
	int (*d_compare)(const struct dentry___144 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___144 *);
	int (*d_init)(struct dentry___144 *);
	void (*d_release)(struct dentry___144 *);
	void (*d_prune)(struct dentry___144 *);
	void (*d_iput)(struct dentry___144 *, struct inode___144 *);
	char * (*d_dname)(struct dentry___144 *, char *, int);
	struct vfsmount___144 * (*d_automount)(struct path___144 *);
	int (*d_manage)(const struct path___144 *, bool);
	struct dentry___144 * (*d_real)(struct dentry___144 *, const struct inode___144 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___144;

struct mem_dqinfo___144 {
	struct quota_format_type___144 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___144;

struct quota_info___144 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___144 *files[3];
	struct mem_dqinfo___144 info[3];
	const struct quota_format_ops___144 *ops[3];
};

struct rcuwait___145 {
	struct task_struct___151 *task;
};

struct percpu_rw_semaphore___145 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___145 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___144 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___145 rw_sem[3];
};

struct super_operations___144;

struct dquot_operations___144;

struct quotactl_ops___144;

struct xattr_handler___18;

struct block_device___66;

struct super_block___144 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___144 *s_type;
	const struct super_operations___144 *s_op;
	const struct dquot_operations___144 *dq_op;
	const struct quotactl_ops___144 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___144 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___18 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___66 *s_bdev;
	struct backing_dev_info___62 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___144 s_dquot;
	struct sb_writers___144 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___144 *s_d_op;
	int cleancache_poolid;
	struct shrinker___53 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___144 {
	struct dentry___144 *mnt_root;
	struct super_block___144 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct compat_shmid64_ds {
	struct compat_ipc64_perm shm_perm;
	compat_size_t shm_segsz;
	compat_ulong_t shm_atime;
	compat_ulong_t shm_atime_high;
	compat_ulong_t shm_dtime;
	compat_ulong_t shm_dtime_high;
	compat_ulong_t shm_ctime;
	compat_ulong_t shm_ctime_high;
	compat_pid_t shm_cpid;
	compat_pid_t shm_lpid;
	compat_ulong_t shm_nattch;
	compat_ulong_t __unused4;
	compat_ulong_t __unused5;
};

struct psi_group___100 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___151 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___100;

struct cgroup_rstat_cpu___100;

struct cgroup___100 {
	struct cgroup_subsys_state___100 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___133 *kn;
	struct cgroup_file___100 procs_file;
	struct cgroup_file___100 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___100 *subsys[14];
	struct cgroup_root___100 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___100 *dom_cgrp;
	struct cgroup___100 *old_dom_cgrp;
	struct cgroup_rstat_cpu___100 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___100 psi;
	struct cgroup_bpf___21 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___65 {
	struct request_queue___65 *q;
	struct io_context___65 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___70;

struct kiocb___144 {
	struct file___144 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___144 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___70 *ki_waitq;
	};
};

struct iattr___144 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___144 *ia_file;
};

struct dquot___144 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___144 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___144 {
	int qf_fmt_id;
	const struct quota_format_ops___144 *qf_ops;
	struct module___131 *qf_owner;
	struct quota_format_type___144 *qf_next;
};

struct quota_format_ops___144 {
	int (*check_quota_file)(struct super_block___144 *, int);
	int (*read_file_info)(struct super_block___144 *, int);
	int (*write_file_info)(struct super_block___144 *, int);
	int (*free_file_info)(struct super_block___144 *, int);
	int (*read_dqblk)(struct dquot___144 *);
	int (*commit_dqblk)(struct dquot___144 *);
	int (*release_dqblk)(struct dquot___144 *);
	int (*get_next_id)(struct super_block___144 *, struct kqid *);
};

struct dquot_operations___144 {
	int (*write_dquot)(struct dquot___144 *);
	struct dquot___144 * (*alloc_dquot)(struct super_block___144 *, int);
	void (*destroy_dquot)(struct dquot___144 *);
	int (*acquire_dquot)(struct dquot___144 *);
	int (*release_dquot)(struct dquot___144 *);
	int (*mark_dirty)(struct dquot___144 *);
	int (*write_info)(struct super_block___144 *, int);
	qsize_t * (*get_reserved_space)(struct inode___144 *);
	int (*get_projid)(struct inode___144 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___144 *, qsize_t *);
	int (*get_next_id)(struct super_block___144 *, struct kqid *);
};

struct quotactl_ops___144 {
	int (*quota_on)(struct super_block___144 *, int, int, const struct path___144 *);
	int (*quota_off)(struct super_block___144 *, int);
	int (*quota_enable)(struct super_block___144 *, unsigned int);
	int (*quota_disable)(struct super_block___144 *, unsigned int);
	int (*quota_sync)(struct super_block___144 *, int);
	int (*set_info)(struct super_block___144 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___144 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___144 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___144 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___144 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___144 *, unsigned int);
};

struct wait_page_queue___70 {
	struct page___149 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___62;

struct readahead_control___70;

struct swap_info_struct___35;

struct address_space_operations___144 {
	int (*writepage)(struct page___149 *, struct writeback_control___62 *);
	int (*readpage)(struct file___144 *, struct page___149 *);
	int (*writepages)(struct address_space___144 *, struct writeback_control___62 *);
	int (*set_page_dirty)(struct page___149 *);
	int (*readpages)(struct file___144 *, struct address_space___144 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___70 *);
	int (*write_begin)(struct file___144 *, struct address_space___144 *, loff_t, unsigned int, unsigned int, struct page___149 **, void **);
	int (*write_end)(struct file___144 *, struct address_space___144 *, loff_t, unsigned int, unsigned int, struct page___149 *, void *);
	sector_t (*bmap)(struct address_space___144 *, sector_t);
	void (*invalidatepage)(struct page___149 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___149 *, gfp_t);
	void (*freepage)(struct page___149 *);
	ssize_t (*direct_IO)(struct kiocb___144 *, struct iov_iter___79 *);
	int (*migratepage)(struct address_space___144 *, struct page___149 *, struct page___149 *, enum migrate_mode);
	bool (*isolate_page)(struct page___149 *, isolate_mode_t);
	void (*putback_page)(struct page___149 *);
	int (*launder_page)(struct page___149 *);
	int (*is_partially_uptodate)(struct page___149 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___149 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___144 *, struct page___149 *);
	int (*swap_activate)(struct swap_info_struct___35 *, struct file___144 *, sector_t *);
	void (*swap_deactivate)(struct file___144 *);
};

struct writeback_control___62 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___62 *wb;
	struct inode___144 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___70 {
	struct file___144 *file;
	struct address_space___144 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___77;

struct iov_iter___79 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___77 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___35 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___66 *bdev;
	struct file___144 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___144 {
	struct dentry___144 * (*lookup)(struct inode___144 *, struct dentry___144 *, unsigned int);
	const char * (*get_link)(struct dentry___144 *, struct inode___144 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___144 *, int);
	struct posix_acl * (*get_acl)(struct inode___144 *, int, bool);
	int (*readlink)(struct dentry___144 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___144 *, struct dentry___144 *, umode_t, bool);
	int (*link)(struct dentry___144 *, struct inode___144 *, struct dentry___144 *);
	int (*unlink)(struct inode___144 *, struct dentry___144 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___144 *, struct dentry___144 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___144 *, struct dentry___144 *, umode_t);
	int (*rmdir)(struct inode___144 *, struct dentry___144 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___144 *, struct dentry___144 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___144 *, struct dentry___144 *, struct inode___144 *, struct dentry___144 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___144 *, struct iattr___144 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___144 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___144 *, char *, size_t);
	int (*fiemap)(struct inode___144 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___144 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___144 *, struct dentry___144 *, struct file___144 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___144 *, struct dentry___144 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___144 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___144 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___144 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___144 {
	void (*fl_copy_lock)(struct file_lock___144 *, struct file_lock___144 *);
	void (*fl_release_private)(struct file_lock___144 *);
};

struct lock_manager_operations___144;

struct file_lock___144 {
	struct file_lock___144 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___144 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___144 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___144 *fl_ops;
	const struct lock_manager_operations___144 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___144 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___144 *);
	int (*lm_grant)(struct file_lock___144 *, int);
	bool (*lm_break)(struct file_lock___144 *);
	int (*lm_change)(struct file_lock___144 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___144 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___144 *);
};

struct fasync_struct___144 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___144 *fa_next;
	struct file___144 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___144 {
	struct inode___144 * (*alloc_inode)(struct super_block___144 *);
	void (*destroy_inode)(struct inode___144 *);
	void (*free_inode)(struct inode___144 *);
	void (*dirty_inode)(struct inode___144 *, int);
	int (*write_inode)(struct inode___144 *, struct writeback_control___62 *);
	int (*drop_inode)(struct inode___144 *);
	void (*evict_inode)(struct inode___144 *);
	void (*put_super)(struct super_block___144 *);
	int (*sync_fs)(struct super_block___144 *, int);
	int (*freeze_super)(struct super_block___144 *);
	int (*freeze_fs)(struct super_block___144 *);
	int (*thaw_super)(struct super_block___144 *);
	int (*unfreeze_fs)(struct super_block___144 *);
	int (*statfs)(struct dentry___144 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___144 *, int *, char *);
	void (*umount_begin)(struct super_block___144 *);
	int (*show_options)(struct seq_file___124 *, struct dentry___144 *);
	int (*show_devname)(struct seq_file___124 *, struct dentry___144 *);
	int (*show_path)(struct seq_file___124 *, struct dentry___144 *);
	int (*show_stats)(struct seq_file___124 *, struct dentry___144 *);
	ssize_t (*quota_read)(struct super_block___144 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___144 *, int, const char *, size_t, loff_t);
	struct dquot___144 ** (*get_dquots)(struct inode___144 *);
	long int (*nr_cached_objects)(struct super_block___144 *, struct shrink_control___53 *);
	long int (*free_cached_objects)(struct super_block___144 *, struct shrink_control___53 *);
	struct file___144 * (*real_loop)(struct file___144 *);
};

struct xattr_handler___18 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___144 *);
	int (*get)(const struct xattr_handler___18 *, struct dentry___144 *, struct inode___144 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___18 *, struct user_namespace___19 *, struct dentry___144 *, struct inode___144 *, const char *, const void *, size_t, int);
};

struct wakeup_source___104;

struct dev_pm_info___104 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___104 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___104 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___104;

struct bus_type___104;

struct device_driver___104;

struct dev_pm_domain___104;

struct fwnode_handle___104;

struct class___104;

struct attribute_group___133;

struct device___104 {
	struct kobject___133 kobj;
	struct device___104 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___104 *type;
	struct bus_type___104 *bus;
	struct device_driver___104 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___104 power;
	struct dev_pm_domain___104 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___104 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___104 *class;
	const struct attribute_group___133 **groups;
	void (*release)(struct device___104 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___66 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___144 *bd_inode;
	struct super_block___144 *bd_super;
	void *bd_claiming;
	struct device___104 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___133 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___65 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___144 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___93)(struct file___144 *, wait_queue_head_t *, struct poll_table_struct___91 *);

struct poll_table_struct___91 {
	poll_queue_proc___93 _qproc;
	__poll_t _key;
};

struct seq_operations___124;

struct seq_file___124 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___124 *op;
	int poll_event;
	const struct file___144 *file;
	void *private;
};

struct fc_log___26;

struct p_log___26 {
	const char *prefix;
	struct fc_log___26 *log;
};

struct fs_context_operations___26;

struct fs_context___26 {
	const struct fs_context_operations___26 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___144 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___144 *root;
	struct user_namespace___19 *user_ns;
	struct net *net_ns;
	const struct cred___19 *cred;
	struct p_log___26 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___26;

typedef int fs_param_type___18(struct p_log___26 *, const struct fs_parameter_spec___18 *, struct fs_parameter___26 *, struct fs_parse_result *);

struct fs_parameter_spec___18 {
	const char *name;
	fs_param_type___18 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___65(struct bio___65 *);

struct bio_vec___77 {
	struct page___149 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___65;

struct bio___65 {
	struct bio___65 *bi_next;
	struct block_device___66 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___65 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___62 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___65 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___77 *bi_io_vec;
	struct bio_set___65 *bi_pool;
	struct bio_vec___77 bi_inline_vecs[0];
};

struct seq_operations___124 {
	void * (*start)(struct seq_file___124 *, loff_t *);
	void (*stop)(struct seq_file___124 *, void *);
	void * (*next)(struct seq_file___124 *, void *, loff_t *);
	int (*show)(struct seq_file___124 *, void *);
};

struct kernfs_root___133;

struct kernfs_elem_dir___133 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___133 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___133;

struct kernfs_root___133 {
	struct kernfs_node___133 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___133 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___133 {
	struct kernfs_node___133 *target_kn;
};

struct kernfs_ops___133;

struct kernfs_elem_attr___133 {
	const struct kernfs_ops___133 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___133 *notify_next;
};

struct kernfs_node___133 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___133 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___133 dir;
		struct kernfs_elem_symlink___133 symlink;
		struct kernfs_elem_attr___133 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___133;

struct kernfs_ops___133 {
	int (*open)(struct kernfs_open_file___133 *);
	void (*release)(struct kernfs_open_file___133 *);
	int (*seq_show)(struct seq_file___124 *, void *);
	void * (*seq_start)(struct seq_file___124 *, loff_t *);
	void * (*seq_next)(struct seq_file___124 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___124 *, void *);
	ssize_t (*read)(struct kernfs_open_file___133 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___133 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___133 *, struct poll_table_struct___91 *);
	int (*mmap)(struct kernfs_open_file___133 *, struct vm_area_struct___149 *);
};

struct kernfs_syscall_ops___133 {
	int (*show_options)(struct seq_file___124 *, struct kernfs_root___133 *);
	int (*mkdir)(struct kernfs_node___133 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___133 *);
	int (*rename)(struct kernfs_node___133 *, struct kernfs_node___133 *, const char *);
	int (*show_path)(struct seq_file___124 *, struct kernfs_node___133 *, struct kernfs_root___133 *);
};

struct kernfs_open_file___133 {
	struct kernfs_node___133 *kn;
	struct file___144 *file;
	struct seq_file___124 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___142 *vm_ops;
};

struct ipc_namespace___6 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___144 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___22 ns;
};

struct cgroup_namespace___100 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___100 *root_cset;
};

struct fwnode_operations___104;

struct fwnode_handle___104 {
	struct fwnode_handle___104 *secondary;
	const struct fwnode_operations___104 *ops;
	struct device___104 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___104;

struct fwnode_endpoint___104;

struct fwnode_operations___104 {
	struct fwnode_handle___104 * (*get)(struct fwnode_handle___104 *);
	void (*put)(struct fwnode_handle___104 *);
	bool (*device_is_available)(const struct fwnode_handle___104 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___104 *, const struct device___104 *);
	bool (*property_present)(const struct fwnode_handle___104 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___104 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___104 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___104 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*get_parent)(const struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*get_next_child_node)(const struct fwnode_handle___104 *, struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*get_named_child_node)(const struct fwnode_handle___104 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___104 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___104 *);
	struct fwnode_handle___104 * (*graph_get_next_endpoint)(const struct fwnode_handle___104 *, struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*graph_get_remote_endpoint)(const struct fwnode_handle___104 *);
	struct fwnode_handle___104 * (*graph_get_port_parent)(struct fwnode_handle___104 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___104 *, struct fwnode_endpoint___104 *);
	int (*add_links)(struct fwnode_handle___104 *);
};

struct fwnode_endpoint___104 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___104 *local_fwnode;
};

struct fwnode_reference_args___104 {
	struct fwnode_handle___104 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___133;

struct attribute_group___133 {
	const char *name;
	umode_t (*is_visible)(struct kobject___133 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___133 *, struct bin_attribute___133 *, int);
	struct attribute **attrs;
	struct bin_attribute___133 **bin_attrs;
};

struct bin_attribute___133 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___144 * (*f_mapping)();
	ssize_t (*read)(struct file___144 *, struct kobject___133 *, struct bin_attribute___133 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___144 *, struct kobject___133 *, struct bin_attribute___133 *, char *, loff_t, size_t);
	int (*mmap)(struct file___144 *, struct kobject___133 *, struct bin_attribute___133 *, struct vm_area_struct___149 *);
};

struct sysfs_ops___133 {
	ssize_t (*show)(struct kobject___133 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___133 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___133;

struct kset___133 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___133 kobj;
	const struct kset_uevent_ops___133 *uevent_ops;
};

struct kobj_type___133 {
	void (*release)(struct kobject___133 *);
	const struct sysfs_ops___133 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___133 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___133 *);
	const void * (*namespace)(struct kobject___133 *);
	void (*get_ownership)(struct kobject___133 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___133 {
	int (* const filter)(struct kset___133 *, struct kobject___133 *);
	const char * (* const name)(struct kset___133 *, struct kobject___133 *);
	int (* const uevent)(struct kset___133 *, struct kobject___133 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___130 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___130 *);
	int (*get)(char *, const struct kernel_param___130 *);
	void (*free)(void *);
};

struct kparam_array___130;

struct kernel_param___130 {
	const char *name;
	struct module___131 *mod;
	const struct kernel_param_ops___130 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___130 *arr;
	};
};

struct kparam_array___130 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___130 *ops;
	void *elem;
};

struct module_attribute___130 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___130 *, struct module_kobject___130 *, char *);
	ssize_t (*store)(struct module_attribute___130 *, struct module_kobject___130 *, const char *, size_t);
	void (*setup)(struct module___131 *, const char *);
	int (*test)(struct module___131 *);
	void (*free)(struct module___131 *);
};

struct trace_event_class___61;

struct trace_event_call___61 {
	struct list_head list;
	struct trace_event_class___61 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___21 *prog_array;
	int (*perf_perm)(struct trace_event_call___61 *, struct perf_event___67 *);
};

struct cftype___100;

struct cgroup_subsys___100 {
	struct cgroup_subsys_state___100 * (*css_alloc)(struct cgroup_subsys_state___100 *);
	int (*css_online)(struct cgroup_subsys_state___100 *);
	void (*css_offline)(struct cgroup_subsys_state___100 *);
	void (*css_released)(struct cgroup_subsys_state___100 *);
	void (*css_free)(struct cgroup_subsys_state___100 *);
	void (*css_reset)(struct cgroup_subsys_state___100 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___100 *, int);
	int (*css_extra_stat_show)(struct seq_file___124 *, struct cgroup_subsys_state___100 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___151 *, struct css_set___100 *);
	void (*cancel_fork)(struct task_struct___151 *, struct css_set___100 *);
	void (*fork)(struct task_struct___151 *);
	void (*exit)(struct task_struct___151 *);
	void (*release)(struct task_struct___151 *);
	void (*bind)(struct cgroup_subsys_state___100 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___100 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___100 *dfl_cftypes;
	struct cftype___100 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___100 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___100 *updated_children;
	struct cgroup___100 *updated_next;
};

struct cgroup_root___100 {
	struct kernfs_root___133 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___100 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___100 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___100 *ss;
	struct list_head node;
	struct kernfs_ops___133 *kf_ops;
	int (*open)(struct kernfs_open_file___133 *);
	void (*release)(struct kernfs_open_file___133 *);
	u64 (*read_u64)(struct cgroup_subsys_state___100 *, struct cftype___100 *);
	s64 (*read_s64)(struct cgroup_subsys_state___100 *, struct cftype___100 *);
	int (*seq_show)(struct seq_file___124 *, void *);
	void * (*seq_start)(struct seq_file___124 *, loff_t *);
	void * (*seq_next)(struct seq_file___124 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___124 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___100 *, struct cftype___100 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___100 *, struct cftype___100 *, s64);
	ssize_t (*write)(struct kernfs_open_file___133 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___133 *, struct poll_table_struct___91 *);
};

struct hstate___8;

struct hugepage_subpool___6 {
	spinlock_t lock;
	long int count;
	long int max_hpages;
	long int used_hpages;
	struct hstate___8 *hstate;
	long int min_hpages;
	long int rsv_hpages;
};

struct hstate___8 {
	struct mutex resize_lock;
	int next_nid_to_alloc;
	int next_nid_to_free;
	unsigned int order;
	long unsigned int mask;
	long unsigned int max_huge_pages;
	long unsigned int nr_huge_pages;
	long unsigned int free_huge_pages;
	long unsigned int resv_huge_pages;
	long unsigned int surplus_huge_pages;
	long unsigned int nr_overcommit_huge_pages;
	struct list_head hugepage_activelist;
	struct list_head hugepage_freelists[64];
	unsigned int nr_huge_pages_node[64];
	unsigned int free_huge_pages_node[64];
	unsigned int surplus_huge_pages_node[64];
	struct cftype___100 cgroup_files_dfl[7];
	struct cftype___100 cgroup_files_legacy[9];
	char name[32];
};

struct hugetlbfs_sb_info___6 {
	long int max_inodes;
	long int free_inodes;
	spinlock_t stat_lock;
	struct hstate___8 *hstate;
	struct hugepage_subpool___6 *spool;
	kuid_t uid;
	kgid_t gid;
	umode_t mode;
};

struct dev_pm_ops___104 {
	int (*prepare)(struct device___104 *);
	void (*complete)(struct device___104 *);
	int (*suspend)(struct device___104 *);
	int (*resume)(struct device___104 *);
	int (*freeze)(struct device___104 *);
	int (*thaw)(struct device___104 *);
	int (*poweroff)(struct device___104 *);
	int (*restore)(struct device___104 *);
	int (*suspend_late)(struct device___104 *);
	int (*resume_early)(struct device___104 *);
	int (*freeze_late)(struct device___104 *);
	int (*thaw_early)(struct device___104 *);
	int (*poweroff_late)(struct device___104 *);
	int (*restore_early)(struct device___104 *);
	int (*suspend_noirq)(struct device___104 *);
	int (*resume_noirq)(struct device___104 *);
	int (*freeze_noirq)(struct device___104 *);
	int (*thaw_noirq)(struct device___104 *);
	int (*poweroff_noirq)(struct device___104 *);
	int (*restore_noirq)(struct device___104 *);
	int (*runtime_suspend)(struct device___104 *);
	int (*runtime_resume)(struct device___104 *);
	int (*runtime_idle)(struct device___104 *);
};

struct wakeup_source___104 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___104 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___104 {
	struct dev_pm_ops___104 ops;
	int (*start)(struct device___104 *);
	void (*detach)(struct device___104 *, bool);
	int (*activate)(struct device___104 *);
	void (*sync)(struct device___104 *);
	void (*dismiss)(struct device___104 *);
};

struct bus_type___104 {
	const char *name;
	const char *dev_name;
	struct device___104 *dev_root;
	const struct attribute_group___133 **bus_groups;
	const struct attribute_group___133 **dev_groups;
	const struct attribute_group___133 **drv_groups;
	int (*match)(struct device___104 *, struct device_driver___104 *);
	int (*uevent)(struct device___104 *, struct kobj_uevent_env *);
	int (*probe)(struct device___104 *);
	void (*sync_state)(struct device___104 *);
	void (*remove)(struct device___104 *);
	void (*shutdown)(struct device___104 *);
	int (*online)(struct device___104 *);
	int (*offline)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	int (*num_vf)(struct device___104 *);
	int (*dma_configure)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___104 {
	const char *name;
	struct bus_type___104 *bus;
	struct module___131 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___104 *);
	void (*sync_state)(struct device___104 *);
	int (*remove)(struct device___104 *);
	void (*shutdown)(struct device___104 *);
	int (*suspend)(struct device___104 *, pm_message_t);
	int (*resume)(struct device___104 *);
	const struct attribute_group___133 **groups;
	const struct attribute_group___133 **dev_groups;
	const struct dev_pm_ops___104 *pm;
	void (*coredump)(struct device___104 *);
	struct driver_private *p;
};

struct device_type___104 {
	const char *name;
	const struct attribute_group___133 **groups;
	int (*uevent)(struct device___104 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___104 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___104 *);
	const struct dev_pm_ops___104 *pm;
};

struct class___104 {
	const char *name;
	struct module___131 *owner;
	const struct attribute_group___133 **class_groups;
	const struct attribute_group___133 **dev_groups;
	struct kobject___133 *dev_kobj;
	int (*dev_uevent)(struct device___104 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___104 *, umode_t *);
	void (*class_release)(struct class___104 *);
	void (*dev_release)(struct device___104 *);
	int (*shutdown_pre)(struct device___104 *);
	const struct kobj_ns_type_operations___14 *ns_type;
	const void * (*namespace)(struct device___104 *);
	void (*get_ownership)(struct device___104 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___104 *pm;
	struct subsys_private *p;
};

struct block_device_operations___65;

struct gendisk___65 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___66 *part0;
	const struct block_device_operations___65 *fops;
	struct request_queue___65 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___62 *bdi;
	struct kobject___133 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___133 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___65 {
	struct bio___65 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___77 *bip_vec;
	struct bio_vec___77 bip_inline_vecs[0];
};

struct blkcg___62;

struct blkg_policy_data___62;

struct blkcg_gq___62 {
	struct request_queue___65 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___62 *blkcg;
	struct blkcg_gq___62 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___62 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___65 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___65(struct request___65 *);

typedef void integrity_complete_fn___65(struct request___65 *, unsigned int);

struct blk_integrity_profile___65 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___65 *prepare_fn;
	integrity_complete_fn___65 *complete_fn;
	const char *name;
};

struct block_device_operations___65 {
	blk_qc_t (*submit_bio)(struct bio___65 *);
	int (*open)(struct block_device___66 *, fmode_t);
	void (*release)(struct gendisk___65 *, fmode_t);
	int (*rw_page)(struct block_device___66 *, sector_t, struct page___149 *, unsigned int);
	int (*ioctl)(struct block_device___66 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___66 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___65 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___65 *);
	int (*getgeo)(struct block_device___66 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___66 *, bool);
	void (*swap_slot_free_notify)(struct block_device___66 *, long unsigned int);
	int (*report_zones)(struct gendisk___65 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___65 *, umode_t *);
	struct module___131 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___65 *, sector_t *);
};

typedef void rq_end_io_fn___65(struct request___65 *, blk_status_t);

struct request___65 {
	struct request_queue___65 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___62 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___65 *bio;
	struct bio___65 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___77 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___65 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___65 *saved_end_io;
		} flush;
	};
	struct gendisk___65 *rq_disk;
	struct block_device___66 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___65 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___62 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___65 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___133 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___144 *debugfs_dir;
	struct dentry___144 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___65;

struct elevator_mq_ops___65 {
	int (*init_sched)(struct request_queue___65 *, struct elevator_type___65 *);
	void (*exit_sched)(struct elevator_queue___65 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___62 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___62 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___62 *);
	bool (*allow_merge)(struct request_queue___65 *, struct request___65 *, struct bio___65 *);
	bool (*bio_merge)(struct request_queue___65 *, struct bio___65 *, unsigned int);
	int (*request_merge)(struct request_queue___65 *, struct request___65 **, struct bio___65 *);
	void (*request_merged)(struct request_queue___65 *, struct request___65 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___65 *, struct request___65 *, struct request___65 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___65 *);
	void (*finish_request)(struct request___65 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___62 *, struct list_head *, bool);
	struct request___65 * (*dispatch_request)(struct blk_mq_hw_ctx___62 *);
	bool (*has_work)(struct blk_mq_hw_ctx___62 *);
	void (*completed_request)(struct request___65 *, u64);
	void (*requeue_request)(struct request___65 *);
	struct request___65 * (*former_request)(struct request_queue___65 *, struct request___65 *);
	struct request___65 * (*next_request)(struct request_queue___65 *, struct request___65 *);
	void (*init_icq)(struct io_cq___65 *);
	void (*exit_icq)(struct io_cq___65 *);
};

struct elv_fs_entry___65;

struct elevator_type___65 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___65 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___65 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___131 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___65 {
	struct elevator_type___65 *type;
	void *elevator_data;
	struct kobject___133 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___65 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___65 *, char *);
	ssize_t (*store)(struct elevator_queue___65 *, const char *, size_t);
};

struct blk_mq_queue_data___62;

struct blk_mq_ops___62 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___62 *, const struct blk_mq_queue_data___62 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___62 *);
	int (*get_budget)(struct request_queue___65 *);
	void (*put_budget)(struct request_queue___65 *, int);
	void (*set_rq_budget_token)(struct request___65 *, int);
	int (*get_rq_budget_token)(struct request___65 *);
	enum blk_eh_timer_return (*timeout)(struct request___65 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___62 *);
	void (*complete)(struct request___65 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___62 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___62 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___62 *, struct request___65 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___62 *, struct request___65 *, unsigned int);
	void (*initialize_rq_fn)(struct request___65 *);
	void (*cleanup_rq)(struct request___65 *);
	bool (*busy)(struct request_queue___65 *);
	int (*map_queues)(struct blk_mq_tag_set___62 *);
	void (*show_rq)(struct seq_file___124 *, struct request___65 *);
};

struct blk_mq_tag_set___62 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___62 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___62 {
	struct request___65 *rq;
	bool last;
};

struct blkcg_policy_data___62;

struct blkcg___62 {
	struct cgroup_subsys_state___100 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___62 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___62 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___62 {
	struct blkcg___62 *blkcg;
	int plid;
};

struct blkg_policy_data___62 {
	struct blkcg_gq___62 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___53 {
	struct mem_cgroup___53 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___53 {
	struct lruvec___60 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___53 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___53 *memcg;
};

struct obj_cgroup___53 {
	struct percpu_ref refcnt;
	struct mem_cgroup___53 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fs_parameter___26 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___144 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___26 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___131 *owner;
	char *buffer[8];
};

struct fs_context_operations___26 {
	void (*free)(struct fs_context___26 *);
	int (*dup)(struct fs_context___26 *, struct fs_context___26 *);
	int (*parse_param)(struct fs_context___26 *, struct fs_parameter___26 *);
	int (*parse_monolithic)(struct fs_context___26 *, void *);
	int (*get_tree)(struct fs_context___26 *);
	int (*reconfigure)(struct fs_context___26 *);
};

struct shmem_inode_info___2 {
	spinlock_t lock;
	unsigned int seals;
	long unsigned int flags;
	long unsigned int alloced;
	long unsigned int swapped;
	long unsigned int fallocend;
	struct list_head shrinklist;
	struct list_head swaplist;
	struct shared_policy policy;
	struct simple_xattrs xattrs;
	atomic_t stop_eviction;
	struct inode___144 vfs_inode;
};

struct perf_cpu_context___67;

struct perf_output_handle___67;

struct pmu___67 {
	struct list_head entry;
	struct module___131 *module;
	struct device___104 *dev;
	const struct attribute_group___133 **attr_groups;
	const struct attribute_group___133 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___67 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___67 *);
	void (*pmu_disable)(struct pmu___67 *);
	int (*event_init)(struct perf_event___67 *);
	void (*event_mapped)(struct perf_event___67 *, struct mm_struct___150 *);
	void (*event_unmapped)(struct perf_event___67 *, struct mm_struct___150 *);
	int (*add)(struct perf_event___67 *, int);
	void (*del)(struct perf_event___67 *, int);
	void (*start)(struct perf_event___67 *, int);
	void (*stop)(struct perf_event___67 *, int);
	void (*read)(struct perf_event___67 *);
	void (*start_txn)(struct pmu___67 *, unsigned int);
	int (*commit_txn)(struct pmu___67 *);
	void (*cancel_txn)(struct pmu___67 *);
	int (*event_idx)(struct perf_event___67 *);
	void (*sched_task)(struct perf_event_context___67 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___67 *, struct perf_event_context___67 *);
	void * (*setup_aux)(struct perf_event___67 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___67 *, struct perf_output_handle___67 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___67 *);
	int (*aux_output_match)(struct perf_event___67 *);
	int (*filter_match)(struct perf_event___67 *);
	int (*check_period)(struct perf_event___67 *, u64);
};

struct perf_cpu_context___67 {
	struct perf_event_context___67 ctx;
	struct perf_event_context___67 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___67 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___67 **heap;
	struct perf_event___67 *heap_default[2];
};

struct perf_output_handle___67 {
	struct perf_event___67 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___67 {
	struct cgroup_subsys_state___100 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___61 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___61 *);
	};
};

struct trace_event_class___61 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___61 *, enum trace_reg, void *);
	struct trace_event_fields___61 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___61 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___61 *);
};

struct syscall_metadata___33 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___61 *enter_event;
	struct trace_event_call___61 *exit_event;
};

struct ipc_ops___3 {
	int (*getnew)(struct ipc_namespace___6 *, struct ipc_params *);
	int (*associate)(struct kern_ipc_perm *, int);
	int (*more_checks)(struct kern_ipc_perm *, struct ipc_params *);
};

struct shmid_kernel {
	struct kern_ipc_perm shm_perm;
	struct file___144 *shm_file;
	long unsigned int shm_nattch;
	long unsigned int shm_segsz;
	time64_t shm_atim;
	time64_t shm_dtim;
	time64_t shm_ctim;
	struct pid___128 *shm_cprid;
	struct pid___128 *shm_lprid;
	struct ucounts___19 *mlock_ucounts;
	struct task_struct___151 *shm_creator;
	struct list_head shm_clist;
	struct ipc_namespace___6 *ns;
	long: 64;
	long: 64;
	long: 64;
};

struct shm_file_data {
	int id;
	struct ipc_namespace___6 *ns;
	struct file___144 *file;
	const struct vm_operations_struct___142 *vm_ops;
};

struct compat_shmid_ds {
	struct compat_ipc_perm shm_perm;
	int shm_segsz;
	old_time32_t shm_atime;
	old_time32_t shm_dtime;
	old_time32_t shm_ctime;
	compat_ipc_pid_t shm_cpid;
	compat_ipc_pid_t shm_lpid;
	short unsigned int shm_nattch;
	short unsigned int shm_unused;
	compat_uptr_t shm_unused2;
	compat_uptr_t shm_unused3;
};

struct compat_shminfo64 {
	compat_ulong_t shmmax;
	compat_ulong_t shmmin;
	compat_ulong_t shmmni;
	compat_ulong_t shmseg;
	compat_ulong_t shmall;
	compat_ulong_t __unused1;
	compat_ulong_t __unused2;
	compat_ulong_t __unused3;
	compat_ulong_t __unused4;
};

struct compat_shm_info {
	compat_int_t used_ids;
	compat_ulong_t shm_tot;
	compat_ulong_t shm_rss;
	compat_ulong_t shm_swp;
	compat_ulong_t swap_attempts;
	compat_ulong_t swap_successes;
};

struct dentry___145;

struct super_block___145;

struct module___132;

struct file_system_type___145 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___145 * (*mount)(struct file_system_type___145 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___145 *);
	struct module___132 *owner;
	struct file_system_type___145 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___145;

struct kiocb___145;

struct vm_area_struct___150;

struct inode___145;

struct file_lock___145;

struct page___150;

struct file_operations___145 {
	struct module___132 *owner;
	loff_t (*llseek)(struct file___145 *, loff_t, int);
	ssize_t (*read)(struct file___145 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___145 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___145 *, struct iov_iter___79 *);
	ssize_t (*write_iter)(struct kiocb___145 *, struct iov_iter___79 *);
	int (*iopoll)(struct kiocb___145 *, bool);
	int (*iterate)(struct file___145 *, struct dir_context *);
	int (*iterate_shared)(struct file___145 *, struct dir_context *);
	__poll_t (*poll)(struct file___145 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___145 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___145 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___145 *, struct vm_area_struct___150 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___145 *, struct file___145 *);
	int (*flush)(struct file___145 *, fl_owner_t);
	int (*release)(struct inode___145 *, struct file___145 *);
	int (*fsync)(struct file___145 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___145 *, int);
	int (*lock)(struct file___145 *, int, struct file_lock___145 *);
	ssize_t (*sendpage)(struct file___145 *, struct page___150 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___145 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___145 *, long unsigned int);
	int (*flock)(struct file___145 *, int, struct file_lock___145 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___145 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___145 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___145 *, long int, struct file_lock___145 **, void **);
	long int (*fallocate)(struct file___145 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___145 *);
	ssize_t (*copy_file_range)(struct file___145 *, loff_t, struct file___145 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___145 *, loff_t, struct file___145 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___145 *, loff_t, loff_t, int);
};

struct vmacache___150 {
	u64 seqnum;
	struct vm_area_struct___150 *vmas[4];
};

struct page_frag___150 {
	struct page___150 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___151;

struct nsproxy___136;

struct signal_struct___146;

struct task_struct___152 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___152 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___151 *mm;
	struct mm_struct___151 *active_mm;
	struct vmacache___150 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___152 *real_parent;
	struct task_struct___152 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___152 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___128 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___136 *nsproxy;
	struct signal_struct___146 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___152 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___65 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___150 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___152 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___67 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___134;

struct kobj_type___134;

struct kernfs_node___134;

struct kobject___134 {
	const char *name;
	struct list_head entry;
	struct kobject___134 *parent;
	struct kset___134 *kset;
	struct kobj_type___134 *ktype;
	struct kernfs_node___134 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___131 {
	struct kobject___134 kobj;
	struct module___132 *mod;
	struct kobject___134 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___131 {
	struct module___132 *mod;
	struct latch_tree_node node;
};

struct module_layout___131 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___131 mtn;
};

struct module_attribute___131;

struct kernel_param___131;

struct module___132 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___131 mkobj;
	struct module_attribute___131 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___134 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___131 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___131 core_layout;
	struct module_layout___131 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___150 *pgtable_t___150;

struct address_space___145;

struct page___150 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___145 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___34 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___150 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___150 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___151 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___142 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___150 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___150 *vm_next;
	struct vm_area_struct___150 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___151 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___145 *vm_file;
	struct file___145 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___146 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___152 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___152 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___128 *pids[4];
	struct pid___128 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___151 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___150;

struct mm_struct___151 {
	struct {
		struct vm_area_struct___150 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___145 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___150 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___152 *owner;
		struct user_namespace *user_ns;
		struct file___145 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct ipc_namespace___7;

struct nsproxy___136 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace___7 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct address_space_operations___145;

struct address_space___145 {
	struct inode___145 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___145 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___145;

struct path___145 {
	struct vfsmount___145 *mnt;
	struct dentry___145 *dentry;
};

struct file___145 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___145 f_path;
	struct inode___145 *f_inode;
	const struct file_operations___145 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___128 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___145 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct core_thread___150 {
	struct task_struct___152 *task;
	struct core_thread___150 *next;
};

struct core_state___150 {
	atomic_t nr_threads;
	struct core_thread___150 dumper;
	struct completion startup;
};

struct dentry_operations___145;

struct dentry___145 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___145 *d_parent;
	struct qstr d_name;
	struct inode___145 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___145 *d_op;
	struct super_block___145 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___145;

struct inode___145 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___145 *i_op;
	struct super_block___145 *i_sb;
	struct address_space___145 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___145 *i_fop;
		void (*free_inode)(struct inode___145 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___145 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___23 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___145 {
	int (*d_revalidate)(struct dentry___145 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___145 *, unsigned int);
	int (*d_hash)(const struct dentry___145 *, struct qstr *);
	int (*d_compare)(const struct dentry___145 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___145 *);
	int (*d_init)(struct dentry___145 *);
	void (*d_release)(struct dentry___145 *);
	void (*d_prune)(struct dentry___145 *);
	void (*d_iput)(struct dentry___145 *, struct inode___145 *);
	char * (*d_dname)(struct dentry___145 *, char *, int);
	struct vfsmount___145 * (*d_automount)(struct path___145 *);
	int (*d_manage)(const struct path___145 *, bool);
	struct dentry___145 * (*d_real)(struct dentry___145 *, const struct inode___145 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___145;

struct mem_dqinfo___145 {
	struct quota_format_type___145 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___145;

struct quota_info___145 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___145 *files[3];
	struct mem_dqinfo___145 info[3];
	const struct quota_format_ops___145 *ops[3];
};

struct rcuwait___146 {
	struct task_struct___152 *task;
};

struct percpu_rw_semaphore___146 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___146 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___145 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___146 rw_sem[3];
};

struct super_operations___145;

struct dquot_operations___145;

struct quotactl_ops___145;

struct super_block___145 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___145 *s_type;
	const struct super_operations___145 *s_op;
	const struct dquot_operations___145 *dq_op;
	const struct quotactl_ops___145 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___145 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___145 s_dquot;
	struct sb_writers___145 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___145 *s_d_op;
	int cleancache_poolid;
	struct shrinker___53 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___145 {
	struct dentry___145 *mnt_root;
	struct super_block___145 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___145 {
	struct file___145 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___145 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___70 *ki_waitq;
	};
};

struct iattr___145 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___145 *ia_file;
};

struct dquot___145 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___145 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___145 {
	int qf_fmt_id;
	const struct quota_format_ops___145 *qf_ops;
	struct module___132 *qf_owner;
	struct quota_format_type___145 *qf_next;
};

struct quota_format_ops___145 {
	int (*check_quota_file)(struct super_block___145 *, int);
	int (*read_file_info)(struct super_block___145 *, int);
	int (*write_file_info)(struct super_block___145 *, int);
	int (*free_file_info)(struct super_block___145 *, int);
	int (*read_dqblk)(struct dquot___145 *);
	int (*commit_dqblk)(struct dquot___145 *);
	int (*release_dqblk)(struct dquot___145 *);
	int (*get_next_id)(struct super_block___145 *, struct kqid *);
};

struct dquot_operations___145 {
	int (*write_dquot)(struct dquot___145 *);
	struct dquot___145 * (*alloc_dquot)(struct super_block___145 *, int);
	void (*destroy_dquot)(struct dquot___145 *);
	int (*acquire_dquot)(struct dquot___145 *);
	int (*release_dquot)(struct dquot___145 *);
	int (*mark_dirty)(struct dquot___145 *);
	int (*write_info)(struct super_block___145 *, int);
	qsize_t * (*get_reserved_space)(struct inode___145 *);
	int (*get_projid)(struct inode___145 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___145 *, qsize_t *);
	int (*get_next_id)(struct super_block___145 *, struct kqid *);
};

struct quotactl_ops___145 {
	int (*quota_on)(struct super_block___145 *, int, int, const struct path___145 *);
	int (*quota_off)(struct super_block___145 *, int);
	int (*quota_enable)(struct super_block___145 *, unsigned int);
	int (*quota_disable)(struct super_block___145 *, unsigned int);
	int (*quota_sync)(struct super_block___145 *, int);
	int (*set_info)(struct super_block___145 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___145 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___145 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___145 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___145 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___145 *, unsigned int);
};

struct address_space_operations___145 {
	int (*writepage)(struct page___150 *, struct writeback_control___3 *);
	int (*readpage)(struct file___145 *, struct page___150 *);
	int (*writepages)(struct address_space___145 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___150 *);
	int (*readpages)(struct file___145 *, struct address_space___145 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___145 *, struct address_space___145 *, loff_t, unsigned int, unsigned int, struct page___150 **, void **);
	int (*write_end)(struct file___145 *, struct address_space___145 *, loff_t, unsigned int, unsigned int, struct page___150 *, void *);
	sector_t (*bmap)(struct address_space___145 *, sector_t);
	void (*invalidatepage)(struct page___150 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___150 *, gfp_t);
	void (*freepage)(struct page___150 *);
	ssize_t (*direct_IO)(struct kiocb___145 *, struct iov_iter___79 *);
	int (*migratepage)(struct address_space___145 *, struct page___150 *, struct page___150 *, enum migrate_mode);
	bool (*isolate_page)(struct page___150 *, isolate_mode_t);
	void (*putback_page)(struct page___150 *);
	int (*launder_page)(struct page___150 *);
	int (*is_partially_uptodate)(struct page___150 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___150 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___145 *, struct page___150 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___145 *, sector_t *);
	void (*swap_deactivate)(struct file___145 *);
};

struct inode_operations___145 {
	struct dentry___145 * (*lookup)(struct inode___145 *, struct dentry___145 *, unsigned int);
	const char * (*get_link)(struct dentry___145 *, struct inode___145 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___145 *, int);
	struct posix_acl * (*get_acl)(struct inode___145 *, int, bool);
	int (*readlink)(struct dentry___145 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___145 *, struct dentry___145 *, umode_t, bool);
	int (*link)(struct dentry___145 *, struct inode___145 *, struct dentry___145 *);
	int (*unlink)(struct inode___145 *, struct dentry___145 *);
	int (*symlink)(struct user_namespace *, struct inode___145 *, struct dentry___145 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___145 *, struct dentry___145 *, umode_t);
	int (*rmdir)(struct inode___145 *, struct dentry___145 *);
	int (*mknod)(struct user_namespace *, struct inode___145 *, struct dentry___145 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___145 *, struct dentry___145 *, struct inode___145 *, struct dentry___145 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___145 *, struct iattr___145 *);
	int (*getattr)(struct user_namespace *, const struct path___145 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___145 *, char *, size_t);
	int (*fiemap)(struct inode___145 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___145 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___145 *, struct dentry___145 *, struct file___145 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___145 *, struct dentry___145 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___145 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___145 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___145 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___145 {
	void (*fl_copy_lock)(struct file_lock___145 *, struct file_lock___145 *);
	void (*fl_release_private)(struct file_lock___145 *);
};

struct fasync_struct___145;

struct lock_manager_operations___145;

struct file_lock___145 {
	struct file_lock___145 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___145 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___145 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___145 *fl_ops;
	const struct lock_manager_operations___145 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___145 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___145 *);
	int (*lm_grant)(struct file_lock___145 *, int);
	bool (*lm_break)(struct file_lock___145 *);
	int (*lm_change)(struct file_lock___145 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___145 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___145 *);
};

struct fasync_struct___145 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___145 *fa_next;
	struct file___145 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___145 {
	struct inode___145 * (*alloc_inode)(struct super_block___145 *);
	void (*destroy_inode)(struct inode___145 *);
	void (*free_inode)(struct inode___145 *);
	void (*dirty_inode)(struct inode___145 *, int);
	int (*write_inode)(struct inode___145 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___145 *);
	void (*evict_inode)(struct inode___145 *);
	void (*put_super)(struct super_block___145 *);
	int (*sync_fs)(struct super_block___145 *, int);
	int (*freeze_super)(struct super_block___145 *);
	int (*freeze_fs)(struct super_block___145 *);
	int (*thaw_super)(struct super_block___145 *);
	int (*unfreeze_fs)(struct super_block___145 *);
	int (*statfs)(struct dentry___145 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___145 *, int *, char *);
	void (*umount_begin)(struct super_block___145 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___145 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___145 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___145 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___145 *);
	ssize_t (*quota_read)(struct super_block___145 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___145 *, int, const char *, size_t, loff_t);
	struct dquot___145 ** (*get_dquots)(struct inode___145 *);
	long int (*nr_cached_objects)(struct super_block___145 *, struct shrink_control___53 *);
	long int (*free_cached_objects)(struct super_block___145 *, struct shrink_control___53 *);
	struct file___145 * (*real_loop)(struct file___145 *);
};

struct kernfs_root___134;

struct kernfs_elem_dir___134 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___134 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___134;

struct kernfs_root___134 {
	struct kernfs_node___134 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___134 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___134 {
	struct kernfs_node___134 *target_kn;
};

struct kernfs_ops___134;

struct kernfs_elem_attr___134 {
	const struct kernfs_ops___134 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___134 *notify_next;
};

struct kernfs_node___134 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___134 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___134 dir;
		struct kernfs_elem_symlink___134 symlink;
		struct kernfs_elem_attr___134 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___134;

struct kernfs_ops___134 {
	int (*open)(struct kernfs_open_file___134 *);
	void (*release)(struct kernfs_open_file___134 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___134 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___134 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___134 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___134 *, struct vm_area_struct___150 *);
};

struct kernfs_syscall_ops___134 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___134 *);
	int (*mkdir)(struct kernfs_node___134 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___134 *);
	int (*rename)(struct kernfs_node___134 *, struct kernfs_node___134 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___134 *, struct kernfs_root___134 *);
};

struct kernfs_open_file___134 {
	struct kernfs_node___134 *kn;
	struct file___145 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___134;

struct attribute_group___134 {
	const char *name;
	umode_t (*is_visible)(struct kobject___134 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___134 *, struct bin_attribute___134 *, int);
	struct attribute **attrs;
	struct bin_attribute___134 **bin_attrs;
};

struct bin_attribute___134 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___145 * (*f_mapping)();
	ssize_t (*read)(struct file___145 *, struct kobject___134 *, struct bin_attribute___134 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___145 *, struct kobject___134 *, struct bin_attribute___134 *, char *, loff_t, size_t);
	int (*mmap)(struct file___145 *, struct kobject___134 *, struct bin_attribute___134 *, struct vm_area_struct___150 *);
};

struct sysfs_ops___134 {
	ssize_t (*show)(struct kobject___134 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___134 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___134;

struct kset___134 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___134 kobj;
	const struct kset_uevent_ops___134 *uevent_ops;
};

struct kobj_type___134 {
	void (*release)(struct kobject___134 *);
	const struct sysfs_ops___134 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___134 **default_groups;
	const struct kobj_ns_type_operations___14 * (*child_ns_type)(struct kobject___134 *);
	const void * (*namespace)(struct kobject___134 *);
	void (*get_ownership)(struct kobject___134 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___134 {
	int (* const filter)(struct kset___134 *, struct kobject___134 *);
	const char * (* const name)(struct kset___134 *, struct kobject___134 *);
	int (* const uevent)(struct kset___134 *, struct kobject___134 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___131 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___131 *);
	int (*get)(char *, const struct kernel_param___131 *);
	void (*free)(void *);
};

struct kparam_array___131;

struct kernel_param___131 {
	const char *name;
	struct module___132 *mod;
	const struct kernel_param_ops___131 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___131 *arr;
	};
};

struct kparam_array___131 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___131 *ops;
	void *elem;
};

struct module_attribute___131 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___131 *, struct module_kobject___131 *, char *);
	ssize_t (*store)(struct module_attribute___131 *, struct module_kobject___131 *, const char *, size_t);
	void (*setup)(struct module___132 *, const char *);
	int (*test)(struct module___132 *);
	void (*free)(struct module___132 *);
};

struct ipc_namespace___7 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___145 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___25 ns;
};

struct fs_context___27;

struct dentry___146;

struct super_block___146;

struct module___133;

struct file_system_type___146 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___27 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___146 * (*mount)(struct file_system_type___146 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___146 *);
	struct module___133 *owner;
	struct file_system_type___146 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___146;

struct kiocb___146;

struct iov_iter___80;

struct poll_table_struct___92;

struct vm_area_struct___151;

struct inode___146;

struct file_lock___146;

struct page___151;

struct pipe_inode_info___44;

struct seq_file___125;

struct file_operations___146 {
	struct module___133 *owner;
	loff_t (*llseek)(struct file___146 *, loff_t, int);
	ssize_t (*read)(struct file___146 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___146 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___146 *, struct iov_iter___80 *);
	ssize_t (*write_iter)(struct kiocb___146 *, struct iov_iter___80 *);
	int (*iopoll)(struct kiocb___146 *, bool);
	int (*iterate)(struct file___146 *, struct dir_context *);
	int (*iterate_shared)(struct file___146 *, struct dir_context *);
	__poll_t (*poll)(struct file___146 *, struct poll_table_struct___92 *);
	long int (*unlocked_ioctl)(struct file___146 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___146 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___146 *, struct vm_area_struct___151 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___146 *, struct file___146 *);
	int (*flush)(struct file___146 *, fl_owner_t);
	int (*release)(struct inode___146 *, struct file___146 *);
	int (*fsync)(struct file___146 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___146 *, int);
	int (*lock)(struct file___146 *, int, struct file_lock___146 *);
	ssize_t (*sendpage)(struct file___146 *, struct page___151 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___146 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___146 *, long unsigned int);
	int (*flock)(struct file___146 *, int, struct file_lock___146 *);
	ssize_t (*splice_write)(struct pipe_inode_info___44 *, struct file___146 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___146 *, loff_t *, struct pipe_inode_info___44 *, size_t, unsigned int);
	int (*setlease)(struct file___146 *, long int, struct file_lock___146 **, void **);
	long int (*fallocate)(struct file___146 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___125 *, struct file___146 *);
	ssize_t (*copy_file_range)(struct file___146 *, loff_t, struct file___146 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___146 *, loff_t, struct file___146 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___146 *, loff_t, loff_t, int);
};

struct vmacache___151 {
	u64 seqnum;
	struct vm_area_struct___151 *vmas[4];
};

struct page_frag___151 {
	struct page___151 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___68;

struct debug_info___68 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___68 *hbp_break[16];
	struct perf_event___68 *hbp_watch[16];
};

struct thread_struct___68 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___68 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___152;

struct pid___129;

struct nsproxy___137;

struct signal_struct___147;

struct bio_list___66;

struct backing_dev_info___63;

struct io_context___66;

struct css_set___101;

struct perf_event_context___68;

struct mem_cgroup___54;

struct request_queue___66;

struct vm_struct___131;

struct task_struct___153 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___153 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___152 *mm;
	struct mm_struct___152 *active_mm;
	struct vmacache___151 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___153 *real_parent;
	struct task_struct___153 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___153 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___129 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___19 *ptracer_cred;
	const struct cred___19 *real_cred;
	const struct cred___19 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___137 *nsproxy;
	struct signal_struct___147 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___153 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___66 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___63 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___101 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___68 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___44 *splice_pipe;
	struct page_frag___151 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___54 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___54 *active_memcg;
	struct request_queue___66 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___153 *oom_reaper_list;
	struct vm_struct___131 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___68 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___135;

struct kobj_type___135;

struct kernfs_node___135;

struct kobject___135 {
	const char *name;
	struct list_head entry;
	struct kobject___135 *parent;
	struct kset___135 *kset;
	struct kobj_type___135 *ktype;
	struct kernfs_node___135 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___132 {
	struct kobject___135 kobj;
	struct module___133 *mod;
	struct kobject___135 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___132 {
	struct module___133 *mod;
	struct latch_tree_node node;
};

struct module_layout___132 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___132 mtn;
};

struct module_attribute___132;

struct kernel_param___132;

struct trace_event_call___62;

struct module___133 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___132 mkobj;
	struct module_attribute___132 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___135 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___132 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___132 core_layout;
	struct module_layout___132 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___62 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___68 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___153 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___68)(struct perf_event___68 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___68;

struct fasync_struct___146;

struct pid_namespace___129;

struct bpf_prog___22;

struct perf_cgroup___68;

struct perf_event___68 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___68 *group_leader;
	struct pmu___68 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___68 hw;
	struct perf_event_context___68 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___68 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___153 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___146 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___68 *aux_event;
	void (*destroy)(struct perf_event___68 *);
	struct callback_head callback_head;
	struct pid_namespace___129 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___68 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___68 orig_overflow_handler;
	struct bpf_prog___22 *prog;
	u64 bpf_cookie;
	struct trace_event_call___62 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___68 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___151 *pgtable_t___151;

struct address_space___146;

struct page_pool___35;

struct dev_pagemap___143;

struct page___151 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___146 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___35 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___151 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___151 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___152 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___143 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___143;

struct vm_area_struct___151 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___151 *vm_next;
	struct vm_area_struct___151 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___152 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___143 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___146 *vm_file;
	struct file___146 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___151;

struct mm_struct___152 {
	struct {
		struct vm_area_struct___151 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___146 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___151 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___153 *owner;
		struct user_namespace___19 *user_ns;
		struct file___146 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___146;

struct address_space___146 {
	struct inode___146 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___146 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___105;

struct page_pool_params___35 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___105 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___35 {
	u32 count;
	struct page___151 *cache[128];
};

struct page_pool___35 {
	struct page_pool_params___35 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___151 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___35 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___143;

struct dev_pagemap___143 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___143 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___146;

struct path___146 {
	struct vfsmount___146 *mnt;
	struct dentry___146 *dentry;
};

struct fown_struct___129 {
	rwlock_t lock;
	struct pid___129 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___146 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___146 f_path;
	struct inode___146 *f_inode;
	const struct file_operations___146 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___129 f_owner;
	const struct cred___19 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___146 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___143;

struct vm_operations_struct___143 {
	void (*open)(struct vm_area_struct___151 *);
	void (*close)(struct vm_area_struct___151 *);
	int (*may_split)(struct vm_area_struct___151 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___151 *);
	int (*mprotect)(struct vm_area_struct___151 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___143 *);
	vm_fault_t (*huge_fault)(struct vm_fault___143 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___143 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___151 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___143 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___143 *);
	int (*access)(struct vm_area_struct___151 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___151 *);
	int (*set_policy)(struct vm_area_struct___151 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___151 *, long unsigned int);
	struct page___151 * (*find_special_page)(struct vm_area_struct___151 *, long unsigned int);
};

struct core_thread___151 {
	struct task_struct___153 *task;
	struct core_thread___151 *next;
};

struct core_state___151 {
	atomic_t nr_threads;
	struct core_thread___151 dumper;
	struct completion startup;
};

struct vm_fault___143 {
	const struct {
		struct vm_area_struct___151 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___151 *cow_page;
	struct page___151 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___151 prealloc_pte;
};

struct pglist_data___61;

struct lruvec___61 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___61 *pgdat;
};

struct zone___61 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___61 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___61 {
	struct zone___61 *zone;
	int zone_idx;
};

struct zonelist___61 {
	struct zoneref___61 _zonerefs[321];
};

struct pglist_data___61 {
	struct zone___61 node_zones[5];
	struct zonelist___61 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___153 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___153 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___61 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___54 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___54 *memcg;
};

struct cgroup___101;

struct cgroup_subsys___101;

struct cgroup_subsys_state___101 {
	struct cgroup___101 *cgroup;
	struct cgroup_subsys___101 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___101 *parent;
};

struct cgroup_file___101 {
	struct kernfs_node___135 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___54;

struct mem_cgroup_per_node___54;

struct mem_cgroup___54 {
	struct cgroup_subsys_state___101 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___101 events_file;
	struct cgroup_file___101 events_local_file;
	struct cgroup_file___101 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___54 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___153 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___54 *nodeinfo[0];
	long: 64;
};

struct shrinker___54 {
	long unsigned int (*count_objects)(struct shrinker___54 *, struct shrink_control___54 *);
	long unsigned int (*scan_objects)(struct shrinker___54 *, struct shrink_control___54 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___143 {
	void (*page_free)(struct page___151 *);
	void (*kill)(struct dev_pagemap___143 *);
	void (*cleanup)(struct dev_pagemap___143 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___143 *);
};

struct upid___129 {
	int nr;
	struct pid_namespace___129 *ns;
};

struct pid_namespace___129 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___153 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___129 *parent;
	struct fs_pin *bacct;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	int reboot;
	struct ns_common___22 ns;
};

struct pid___129 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___129 numbers[1];
};

struct signal_struct___147 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___153 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___153 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___129 *pids[4];
	struct pid___129 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___152 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct ipc_namespace___8;

struct net___26;

struct cgroup_namespace___101;

struct nsproxy___137 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace___8 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___129 *pid_ns_for_children;
	struct net___26 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___101 *cgroup_ns;
};

struct bio___66;

struct bio_list___66 {
	struct bio___66 *head;
	struct bio___66 *tail;
};

struct bdi_writeback___63 {
	struct backing_dev_info___63 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___101 *memcg_css;
	struct cgroup_subsys_state___101 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___63 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___63 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___105 *dev;
	char dev_name[64];
	struct device___105 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___146 *debug_dir;
};

struct io_cq___66;

struct io_context___66 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___66 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___101 {
	struct cgroup_subsys_state___101 *subsys[14];
	refcount_t refcount;
	struct css_set___101 *dom_cset;
	struct cgroup___101 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___101 *mg_src_cgrp;
	struct cgroup___101 *mg_dst_cgrp;
	struct css_set___101 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___68 {
	struct pmu___68 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___153 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___68 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___44;

struct pipe_inode_info___44 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___151 *tmp_page;
	struct fasync_struct___146 *fasync_readers;
	struct fasync_struct___146 *fasync_writers;
	struct pipe_buffer___44 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___66;

struct blk_integrity___66 {
	const struct blk_integrity_profile___66 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___66 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___66 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___66;

struct elevator_queue___66;

struct blk_mq_ops___63;

struct blk_mq_hw_ctx___63;

struct gendisk___66;

struct blkcg_gq___63;

struct blk_mq_tag_set___63;

struct request_queue___66 {
	struct request___66 *last_merge;
	struct elevator_queue___66 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___63 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___63 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___66 *disk;
	struct kobject___135 kobj;
	struct kobject___135 *mq_kobj;
	struct blk_integrity___66 integrity;
	struct device___105 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___63 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___63 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___66 bio_split;
	struct dentry___146 *debugfs_dir;
	struct dentry___146 *sched_debugfs_dir;
	struct dentry___146 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___131 {
	struct vm_struct___131 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___151 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___146;

struct dentry___146 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___146 *d_parent;
	struct qstr d_name;
	struct inode___146 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___146 *d_op;
	struct super_block___146 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___146;

struct inode___146 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___146 *i_op;
	struct super_block___146 *i_sb;
	struct address_space___146 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___63 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___146 *i_fop;
		void (*free_inode)(struct inode___146 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___146 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___44 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___146 {
	int (*d_revalidate)(struct dentry___146 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___146 *, unsigned int);
	int (*d_hash)(const struct dentry___146 *, struct qstr *);
	int (*d_compare)(const struct dentry___146 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___146 *);
	int (*d_init)(struct dentry___146 *);
	void (*d_release)(struct dentry___146 *);
	void (*d_prune)(struct dentry___146 *);
	void (*d_iput)(struct dentry___146 *, struct inode___146 *);
	char * (*d_dname)(struct dentry___146 *, char *, int);
	struct vfsmount___146 * (*d_automount)(struct path___146 *);
	int (*d_manage)(const struct path___146 *, bool);
	struct dentry___146 * (*d_real)(struct dentry___146 *, const struct inode___146 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___146;

struct mem_dqinfo___146 {
	struct quota_format_type___146 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___146;

struct quota_info___146 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___146 *files[3];
	struct mem_dqinfo___146 info[3];
	const struct quota_format_ops___146 *ops[3];
};

struct rcuwait___147 {
	struct task_struct___153 *task;
};

struct percpu_rw_semaphore___147 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___147 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___146 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___147 rw_sem[3];
};

struct super_operations___146;

struct dquot_operations___146;

struct quotactl_ops___146;

struct block_device___67;

struct super_block___146 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___146 *s_type;
	const struct super_operations___146 *s_op;
	const struct dquot_operations___146 *dq_op;
	const struct quotactl_ops___146 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___146 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___67 *s_bdev;
	struct backing_dev_info___63 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___146 s_dquot;
	struct sb_writers___146 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___146 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___19 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___146 {
	struct dentry___146 *mnt_root;
	struct super_block___146 *mnt_sb;
	int mnt_flags;
	struct user_namespace___19 *mnt_userns;
};

struct psi_group___101 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___153 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___22;

struct cgroup_bpf___22 {
	struct bpf_prog_array___22 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___22 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___101;

struct cgroup_rstat_cpu___101;

struct cgroup___101 {
	struct cgroup_subsys_state___101 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___135 *kn;
	struct cgroup_file___101 procs_file;
	struct cgroup_file___101 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___101 *subsys[14];
	struct cgroup_root___101 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___101 *dom_cgrp;
	struct cgroup___101 *old_dom_cgrp;
	struct cgroup_rstat_cpu___101 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___101 psi;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___66 {
	struct request_queue___66 *q;
	struct io_context___66 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___71;

struct kiocb___146 {
	struct file___146 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___146 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___146 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___146 *ia_file;
};

struct dquot___146 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___146 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___146 {
	int qf_fmt_id;
	const struct quota_format_ops___146 *qf_ops;
	struct module___133 *qf_owner;
	struct quota_format_type___146 *qf_next;
};

struct quota_format_ops___146 {
	int (*check_quota_file)(struct super_block___146 *, int);
	int (*read_file_info)(struct super_block___146 *, int);
	int (*write_file_info)(struct super_block___146 *, int);
	int (*free_file_info)(struct super_block___146 *, int);
	int (*read_dqblk)(struct dquot___146 *);
	int (*commit_dqblk)(struct dquot___146 *);
	int (*release_dqblk)(struct dquot___146 *);
	int (*get_next_id)(struct super_block___146 *, struct kqid *);
};

struct dquot_operations___146 {
	int (*write_dquot)(struct dquot___146 *);
	struct dquot___146 * (*alloc_dquot)(struct super_block___146 *, int);
	void (*destroy_dquot)(struct dquot___146 *);
	int (*acquire_dquot)(struct dquot___146 *);
	int (*release_dquot)(struct dquot___146 *);
	int (*mark_dirty)(struct dquot___146 *);
	int (*write_info)(struct super_block___146 *, int);
	qsize_t * (*get_reserved_space)(struct inode___146 *);
	int (*get_projid)(struct inode___146 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___146 *, qsize_t *);
	int (*get_next_id)(struct super_block___146 *, struct kqid *);
};

struct quotactl_ops___146 {
	int (*quota_on)(struct super_block___146 *, int, int, const struct path___146 *);
	int (*quota_off)(struct super_block___146 *, int);
	int (*quota_enable)(struct super_block___146 *, unsigned int);
	int (*quota_disable)(struct super_block___146 *, unsigned int);
	int (*quota_sync)(struct super_block___146 *, int);
	int (*set_info)(struct super_block___146 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___146 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___146 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___146 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___146 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___146 *, unsigned int);
};

struct wait_page_queue___71 {
	struct page___151 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___63;

struct readahead_control___71;

struct address_space_operations___146 {
	int (*writepage)(struct page___151 *, struct writeback_control___63 *);
	int (*readpage)(struct file___146 *, struct page___151 *);
	int (*writepages)(struct address_space___146 *, struct writeback_control___63 *);
	int (*set_page_dirty)(struct page___151 *);
	int (*readpages)(struct file___146 *, struct address_space___146 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___71 *);
	int (*write_begin)(struct file___146 *, struct address_space___146 *, loff_t, unsigned int, unsigned int, struct page___151 **, void **);
	int (*write_end)(struct file___146 *, struct address_space___146 *, loff_t, unsigned int, unsigned int, struct page___151 *, void *);
	sector_t (*bmap)(struct address_space___146 *, sector_t);
	void (*invalidatepage)(struct page___151 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___151 *, gfp_t);
	void (*freepage)(struct page___151 *);
	ssize_t (*direct_IO)(struct kiocb___146 *, struct iov_iter___80 *);
	int (*migratepage)(struct address_space___146 *, struct page___151 *, struct page___151 *, enum migrate_mode);
	bool (*isolate_page)(struct page___151 *, isolate_mode_t);
	void (*putback_page)(struct page___151 *);
	int (*launder_page)(struct page___151 *);
	int (*is_partially_uptodate)(struct page___151 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___151 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___146 *, struct page___151 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___146 *, sector_t *);
	void (*swap_deactivate)(struct file___146 *);
};

struct writeback_control___63 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___63 *wb;
	struct inode___146 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___71 {
	struct file___146 *file;
	struct address_space___146 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___78;

struct iov_iter___80 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___78 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___44 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___146 {
	struct dentry___146 * (*lookup)(struct inode___146 *, struct dentry___146 *, unsigned int);
	const char * (*get_link)(struct dentry___146 *, struct inode___146 *, struct delayed_call *);
	int (*permission)(struct user_namespace___19 *, struct inode___146 *, int);
	struct posix_acl * (*get_acl)(struct inode___146 *, int, bool);
	int (*readlink)(struct dentry___146 *, char *, int);
	int (*create)(struct user_namespace___19 *, struct inode___146 *, struct dentry___146 *, umode_t, bool);
	int (*link)(struct dentry___146 *, struct inode___146 *, struct dentry___146 *);
	int (*unlink)(struct inode___146 *, struct dentry___146 *);
	int (*symlink)(struct user_namespace___19 *, struct inode___146 *, struct dentry___146 *, const char *);
	int (*mkdir)(struct user_namespace___19 *, struct inode___146 *, struct dentry___146 *, umode_t);
	int (*rmdir)(struct inode___146 *, struct dentry___146 *);
	int (*mknod)(struct user_namespace___19 *, struct inode___146 *, struct dentry___146 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___19 *, struct inode___146 *, struct dentry___146 *, struct inode___146 *, struct dentry___146 *, unsigned int);
	int (*setattr)(struct user_namespace___19 *, struct dentry___146 *, struct iattr___146 *);
	int (*getattr)(struct user_namespace___19 *, const struct path___146 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___146 *, char *, size_t);
	int (*fiemap)(struct inode___146 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___146 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___146 *, struct dentry___146 *, struct file___146 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___19 *, struct inode___146 *, struct dentry___146 *, umode_t);
	int (*set_acl)(struct user_namespace___19 *, struct inode___146 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___19 *, struct dentry___146 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___146 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___146 {
	void (*fl_copy_lock)(struct file_lock___146 *, struct file_lock___146 *);
	void (*fl_release_private)(struct file_lock___146 *);
};

struct lock_manager_operations___146;

struct file_lock___146 {
	struct file_lock___146 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___146 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___146 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___146 *fl_ops;
	const struct lock_manager_operations___146 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___146 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___146 *);
	int (*lm_grant)(struct file_lock___146 *, int);
	bool (*lm_break)(struct file_lock___146 *);
	int (*lm_change)(struct file_lock___146 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___146 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___146 *);
};

struct fasync_struct___146 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___146 *fa_next;
	struct file___146 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___146 {
	struct inode___146 * (*alloc_inode)(struct super_block___146 *);
	void (*destroy_inode)(struct inode___146 *);
	void (*free_inode)(struct inode___146 *);
	void (*dirty_inode)(struct inode___146 *, int);
	int (*write_inode)(struct inode___146 *, struct writeback_control___63 *);
	int (*drop_inode)(struct inode___146 *);
	void (*evict_inode)(struct inode___146 *);
	void (*put_super)(struct super_block___146 *);
	int (*sync_fs)(struct super_block___146 *, int);
	int (*freeze_super)(struct super_block___146 *);
	int (*freeze_fs)(struct super_block___146 *);
	int (*thaw_super)(struct super_block___146 *);
	int (*unfreeze_fs)(struct super_block___146 *);
	int (*statfs)(struct dentry___146 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___146 *, int *, char *);
	void (*umount_begin)(struct super_block___146 *);
	int (*show_options)(struct seq_file___125 *, struct dentry___146 *);
	int (*show_devname)(struct seq_file___125 *, struct dentry___146 *);
	int (*show_path)(struct seq_file___125 *, struct dentry___146 *);
	int (*show_stats)(struct seq_file___125 *, struct dentry___146 *);
	ssize_t (*quota_read)(struct super_block___146 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___146 *, int, const char *, size_t, loff_t);
	struct dquot___146 ** (*get_dquots)(struct inode___146 *);
	long int (*nr_cached_objects)(struct super_block___146 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___146 *, struct shrink_control___54 *);
	struct file___146 * (*real_loop)(struct file___146 *);
};

struct wakeup_source___105;

struct dev_pm_info___105 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___105 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___105 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___105;

struct bus_type___105;

struct device_driver___105;

struct dev_pm_domain___105;

struct fwnode_handle___105;

struct class___105;

struct attribute_group___135;

struct device___105 {
	struct kobject___135 kobj;
	struct device___105 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___105 *type;
	struct bus_type___105 *bus;
	struct device_driver___105 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___105 power;
	struct dev_pm_domain___105 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___105 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___105 *class;
	const struct attribute_group___135 **groups;
	void (*release)(struct device___105 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___67 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___146 *bd_inode;
	struct super_block___146 *bd_super;
	void *bd_claiming;
	struct device___105 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___135 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___66 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___146 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___94)(struct file___146 *, wait_queue_head_t *, struct poll_table_struct___92 *);

struct poll_table_struct___92 {
	poll_queue_proc___94 _qproc;
	__poll_t _key;
};

struct seq_operations___125;

struct seq_file___125 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___125 *op;
	int poll_event;
	const struct file___146 *file;
	void *private;
};

struct fc_log___27;

struct p_log___27 {
	const char *prefix;
	struct fc_log___27 *log;
};

struct fs_context_operations___27;

struct fs_context___27 {
	const struct fs_context_operations___27 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___146 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___146 *root;
	struct user_namespace___19 *user_ns;
	struct net___26 *net_ns;
	const struct cred___19 *cred;
	struct p_log___27 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___66(struct bio___66 *);

struct bio_vec___78 {
	struct page___151 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___66;

struct bio___66 {
	struct bio___66 *bi_next;
	struct block_device___67 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___66 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___63 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___66 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___78 *bi_io_vec;
	struct bio_set___66 *bi_pool;
	struct bio_vec___78 bi_inline_vecs[0];
};

struct fwnode_operations___105;

struct fwnode_handle___105 {
	struct fwnode_handle___105 *secondary;
	const struct fwnode_operations___105 *ops;
	struct device___105 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___105;

struct fwnode_endpoint___105;

struct fwnode_operations___105 {
	struct fwnode_handle___105 * (*get)(struct fwnode_handle___105 *);
	void (*put)(struct fwnode_handle___105 *);
	bool (*device_is_available)(const struct fwnode_handle___105 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___105 *, const struct device___105 *);
	bool (*property_present)(const struct fwnode_handle___105 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___105 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___105 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___105 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*get_parent)(const struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*get_next_child_node)(const struct fwnode_handle___105 *, struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*get_named_child_node)(const struct fwnode_handle___105 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___105 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___105 *);
	struct fwnode_handle___105 * (*graph_get_next_endpoint)(const struct fwnode_handle___105 *, struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*graph_get_remote_endpoint)(const struct fwnode_handle___105 *);
	struct fwnode_handle___105 * (*graph_get_port_parent)(struct fwnode_handle___105 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___105 *, struct fwnode_endpoint___105 *);
	int (*add_links)(struct fwnode_handle___105 *);
};

struct fwnode_endpoint___105 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___105 *local_fwnode;
};

struct fwnode_reference_args___105 {
	struct fwnode_handle___105 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___135;

struct kernfs_elem_dir___135 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___135 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___135;

struct kernfs_root___135 {
	struct kernfs_node___135 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___135 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___135 {
	struct kernfs_node___135 *target_kn;
};

struct kernfs_ops___135;

struct kernfs_elem_attr___135 {
	const struct kernfs_ops___135 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___135 *notify_next;
};

struct kernfs_node___135 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___135 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___135 dir;
		struct kernfs_elem_symlink___135 symlink;
		struct kernfs_elem_attr___135 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___135;

struct kernfs_ops___135 {
	int (*open)(struct kernfs_open_file___135 *);
	void (*release)(struct kernfs_open_file___135 *);
	int (*seq_show)(struct seq_file___125 *, void *);
	void * (*seq_start)(struct seq_file___125 *, loff_t *);
	void * (*seq_next)(struct seq_file___125 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___125 *, void *);
	ssize_t (*read)(struct kernfs_open_file___135 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___135 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___135 *, struct poll_table_struct___92 *);
	int (*mmap)(struct kernfs_open_file___135 *, struct vm_area_struct___151 *);
};

struct kernfs_syscall_ops___135 {
	int (*show_options)(struct seq_file___125 *, struct kernfs_root___135 *);
	int (*mkdir)(struct kernfs_node___135 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___135 *);
	int (*rename)(struct kernfs_node___135 *, struct kernfs_node___135 *, const char *);
	int (*show_path)(struct seq_file___125 *, struct kernfs_node___135 *, struct kernfs_root___135 *);
};

struct kernfs_open_file___135 {
	struct kernfs_node___135 *kn;
	struct file___146 *file;
	struct seq_file___125 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___143 *vm_ops;
};

struct sock___16;

struct kobj_ns_type_operations___15 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___16 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___26 *net;
} possible_net_t___22;

struct proto___15;

struct sock_common___15 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___15 *skc_prot;
	possible_net_t___22 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___16 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___24;

struct sk_buff_head___22 {
	struct sk_buff___24 *next;
	struct sk_buff___24 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___15 {
	struct cgroup___101 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___15;

struct socket_wq___15;

struct dst_entry___15;

struct socket___15;

struct net_device___26;

struct sock___16 {
	struct sock_common___15 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___22 sk_error_queue;
	struct sk_buff___24 *sk_rx_skb_cache;
	struct sk_buff_head___22 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___24 *head;
		struct sk_buff___24 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___15 *sk_filter;
	union {
		struct socket_wq___15 *sk_wq;
		struct socket_wq___15 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___15 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___15 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___24 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___24 *sk_tx_skb_cache;
	struct sk_buff_head___22 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___151 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___15 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___129 *sk_peer_pid;
	const struct cred___19 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___15 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___15 sk_cgrp_data;
	struct mem_cgroup___54 *sk_memcg;
	void (*sk_state_change)(struct sock___16 *);
	void (*sk_data_ready)(struct sock___16 *);
	void (*sk_write_space)(struct sock___16 *);
	void (*sk_error_report)(struct sock___16 *);
	int (*sk_backlog_rcv)(struct sock___16 *, struct sk_buff___24 *);
	struct sk_buff___24 * (*sk_validate_xmit_skb)(struct sock___16 *, struct net_device___26 *, struct sk_buff___24 *);
	void (*sk_destruct)(struct sock___16 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___135;

struct attribute_group___135 {
	const char *name;
	umode_t (*is_visible)(struct kobject___135 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___135 *, struct bin_attribute___135 *, int);
	struct attribute **attrs;
	struct bin_attribute___135 **bin_attrs;
};

struct bin_attribute___135 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___146 * (*f_mapping)();
	ssize_t (*read)(struct file___146 *, struct kobject___135 *, struct bin_attribute___135 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___146 *, struct kobject___135 *, struct bin_attribute___135 *, char *, loff_t, size_t);
	int (*mmap)(struct file___146 *, struct kobject___135 *, struct bin_attribute___135 *, struct vm_area_struct___151 *);
};

struct sysfs_ops___135 {
	ssize_t (*show)(struct kobject___135 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___135 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___135;

struct kset___135 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___135 kobj;
	const struct kset_uevent_ops___135 *uevent_ops;
};

struct kobj_type___135 {
	void (*release)(struct kobject___135 *);
	const struct sysfs_ops___135 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___135 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___135 *);
	const void * (*namespace)(struct kobject___135 *);
	void (*get_ownership)(struct kobject___135 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___135 {
	int (* const filter)(struct kset___135 *, struct kobject___135 *);
	const char * (* const name)(struct kset___135 *, struct kobject___135 *);
	int (* const uevent)(struct kset___135 *, struct kobject___135 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___132 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___132 *);
	int (*get)(char *, const struct kernel_param___132 *);
	void (*free)(void *);
};

struct kparam_array___132;

struct kernel_param___132 {
	const char *name;
	struct module___133 *mod;
	const struct kernel_param_ops___132 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___132 *arr;
	};
};

struct kparam_array___132 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___132 *ops;
	void *elem;
};

struct module_attribute___132 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___132 *, struct module_kobject___132 *, char *);
	ssize_t (*store)(struct module_attribute___132 *, struct module_kobject___132 *, const char *, size_t);
	void (*setup)(struct module___133 *, const char *);
	int (*test)(struct module___133 *);
	void (*free)(struct module___133 *);
};

struct trace_event_class___62;

struct trace_event_call___62 {
	struct list_head list;
	struct trace_event_class___62 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___62 *, struct perf_event___68 *);
};

struct ipc_namespace___8 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___146 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___22 ns;
};

struct fib_rules_ops___15;

struct fqdir___25;

struct fib_notifier_ops___15;

struct netns_ipv4___25 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___15 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___16 *fibnl;
	struct sock___16 **icmp_sk;
	struct sock___16 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___16 **tcp_sk;
	struct fqdir___25 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___15 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___15 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___15 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___15;

struct dst_ops___25 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___25 *);
	struct dst_entry___15 * (*check)(struct dst_entry___15 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___15 *);
	unsigned int (*mtu)(const struct dst_entry___15 *);
	u32 * (*cow_metrics)(struct dst_entry___15 *, long unsigned int);
	void (*destroy)(struct dst_entry___15 *);
	void (*ifdown)(struct dst_entry___15 *, struct net_device___26 *, int);
	struct dst_entry___15 * (*negative_advice)(struct dst_entry___15 *);
	void (*link_failure)(struct sk_buff___24 *);
	void (*update_pmtu)(struct dst_entry___15 *, struct sock___16 *, struct sk_buff___24 *, u32, bool);
	void (*redirect)(struct dst_entry___15 *, struct sock___16 *, struct sk_buff___24 *);
	int (*local_out)(struct net___26 *, struct sock___16 *, struct sk_buff___24 *);
	struct neighbour___15 * (*neigh_lookup)(const struct dst_entry___15 *, struct sk_buff___24 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___15 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___25 {
	struct dst_ops___25 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___25 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___15 *fib6_rules_ops;
	struct sock___16 **icmp_sk;
	struct sock___16 *ndisc_sk;
	struct sock___16 *tcp_sk;
	struct sock___16 *igmp_sk;
	struct sock___16 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___15 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___15 *notifier_ops;
	struct fib_notifier_ops___15 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___25 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___25 *fqdir;
};

struct netns_sctp___15 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___16 *ctl_sock;
	struct sock___16 *udp4_sock;
	struct sock___16 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___22 {
	struct bpf_prog_array___22 *run_array[2];
	struct bpf_prog___22 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___25 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___16 *nlsk;
	struct sock___16 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___25 xfrm4_dst_ops;
	struct dst_ops___25 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___26 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct idr netns_ids;
	struct ns_common___22 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___16 *rtnl;
	struct sock___16 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___26 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___25 ipv4;
	struct netns_ipv6___25 ipv6;
	struct netns_ieee802154_lowpan___25 ieee802154_lowpan;
	struct netns_sctp___15 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___22 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___22 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___25 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___16 *crypto_nlsk;
	struct sock___16 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___101 {
	struct ns_common___22 ns;
	struct user_namespace___19 *user_ns;
	struct ucounts___19 *ucounts;
	struct css_set___101 *root_cset;
};

struct msghdr___15 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___80 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___146 *msg_iocb;
};

struct fd___27 {
	struct file___146 *file;
	unsigned int flags;
};

struct fs_parameter___27 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___146 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___27 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___133 *owner;
	char *buffer[8];
};

struct fs_context_operations___27 {
	void (*free)(struct fs_context___27 *);
	int (*dup)(struct fs_context___27 *, struct fs_context___27 *);
	int (*parse_param)(struct fs_context___27 *, struct fs_parameter___27 *);
	int (*parse_monolithic)(struct fs_context___27 *, void *);
	int (*get_tree)(struct fs_context___27 *);
	int (*reconfigure)(struct fs_context___27 *);
};

typedef struct poll_table_struct___92 poll_table___28;

struct socket_wq___15 {
	wait_queue_head_t wait;
	struct fasync_struct___146 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___15;

struct socket___15 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___146 *file;
	struct sock___16 *sk;
	const struct proto_ops___15 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___15 wq;
};

typedef int (*sk_read_actor_t___15)(read_descriptor_t *, struct sk_buff___24 *, unsigned int, size_t);

struct proto_ops___15 {
	int family;
	struct module___133 *owner;
	int (*release)(struct socket___15 *);
	int (*bind)(struct socket___15 *, struct sockaddr *, int);
	int (*connect)(struct socket___15 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___15 *, struct socket___15 *);
	int (*accept)(struct socket___15 *, struct socket___15 *, int, bool);
	int (*getname)(struct socket___15 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___146 *, struct socket___15 *, struct poll_table_struct___92 *);
	int (*ioctl)(struct socket___15 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___15 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___15 *, void *, bool, bool);
	int (*listen)(struct socket___15 *, int);
	int (*shutdown)(struct socket___15 *, int);
	int (*setsockopt)(struct socket___15 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___15 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___125 *, struct socket___15 *);
	int (*sendmsg)(struct socket___15 *, struct msghdr___15 *, size_t);
	int (*recvmsg)(struct socket___15 *, struct msghdr___15 *, size_t, int);
	int (*mmap)(struct file___146 *, struct socket___15 *, struct vm_area_struct___151 *);
	ssize_t (*sendpage)(struct socket___15 *, struct page___151 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___15 *, loff_t *, struct pipe_inode_info___44 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___16 *, int);
	int (*peek_len)(struct socket___15 *);
	int (*read_sock)(struct sock___16 *, read_descriptor_t *, sk_read_actor_t___15);
	int (*sendpage_locked)(struct sock___16 *, struct page___151 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___16 *, struct msghdr___15 *, size_t);
	int (*set_rcvlowat)(struct sock___16 *, int);
};

struct sk_buff___24 {
	union {
		struct {
			struct sk_buff___24 *next;
			struct sk_buff___24 *prev;
			union {
				struct net_device___26 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___16 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___24 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___105 {
	int (*prepare)(struct device___105 *);
	void (*complete)(struct device___105 *);
	int (*suspend)(struct device___105 *);
	int (*resume)(struct device___105 *);
	int (*freeze)(struct device___105 *);
	int (*thaw)(struct device___105 *);
	int (*poweroff)(struct device___105 *);
	int (*restore)(struct device___105 *);
	int (*suspend_late)(struct device___105 *);
	int (*resume_early)(struct device___105 *);
	int (*freeze_late)(struct device___105 *);
	int (*thaw_early)(struct device___105 *);
	int (*poweroff_late)(struct device___105 *);
	int (*restore_early)(struct device___105 *);
	int (*suspend_noirq)(struct device___105 *);
	int (*resume_noirq)(struct device___105 *);
	int (*freeze_noirq)(struct device___105 *);
	int (*thaw_noirq)(struct device___105 *);
	int (*poweroff_noirq)(struct device___105 *);
	int (*restore_noirq)(struct device___105 *);
	int (*runtime_suspend)(struct device___105 *);
	int (*runtime_resume)(struct device___105 *);
	int (*runtime_idle)(struct device___105 *);
};

struct wakeup_source___105 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___105 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___105 {
	struct dev_pm_ops___105 ops;
	int (*start)(struct device___105 *);
	void (*detach)(struct device___105 *, bool);
	int (*activate)(struct device___105 *);
	void (*sync)(struct device___105 *);
	void (*dismiss)(struct device___105 *);
};

struct bus_type___105 {
	const char *name;
	const char *dev_name;
	struct device___105 *dev_root;
	const struct attribute_group___135 **bus_groups;
	const struct attribute_group___135 **dev_groups;
	const struct attribute_group___135 **drv_groups;
	int (*match)(struct device___105 *, struct device_driver___105 *);
	int (*uevent)(struct device___105 *, struct kobj_uevent_env *);
	int (*probe)(struct device___105 *);
	void (*sync_state)(struct device___105 *);
	void (*remove)(struct device___105 *);
	void (*shutdown)(struct device___105 *);
	int (*online)(struct device___105 *);
	int (*offline)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	int (*num_vf)(struct device___105 *);
	int (*dma_configure)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___105 {
	const char *name;
	struct bus_type___105 *bus;
	struct module___133 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___105 *);
	void (*sync_state)(struct device___105 *);
	int (*remove)(struct device___105 *);
	void (*shutdown)(struct device___105 *);
	int (*suspend)(struct device___105 *, pm_message_t);
	int (*resume)(struct device___105 *);
	const struct attribute_group___135 **groups;
	const struct attribute_group___135 **dev_groups;
	const struct dev_pm_ops___105 *pm;
	void (*coredump)(struct device___105 *);
	struct driver_private *p;
};

struct device_type___105 {
	const char *name;
	const struct attribute_group___135 **groups;
	int (*uevent)(struct device___105 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___105 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___105 *);
	const struct dev_pm_ops___105 *pm;
};

struct class___105 {
	const char *name;
	struct module___133 *owner;
	const struct attribute_group___135 **class_groups;
	const struct attribute_group___135 **dev_groups;
	struct kobject___135 *dev_kobj;
	int (*dev_uevent)(struct device___105 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___105 *, umode_t *);
	void (*class_release)(struct class___105 *);
	void (*dev_release)(struct device___105 *);
	int (*shutdown_pre)(struct device___105 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___105 *);
	void (*get_ownership)(struct device___105 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___105 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___44;

struct pipe_buffer___44 {
	struct page___151 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___44 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___44 {
	int (*confirm)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
	void (*release)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
	bool (*try_steal)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
	bool (*get)(struct pipe_inode_info___44 *, struct pipe_buffer___44 *);
};

typedef rx_handler_result_t rx_handler_func_t___22(struct sk_buff___24 **);

struct bpf_xdp_entity___22 {
	struct bpf_prog___22 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___22;

struct net_device_ops___22;

struct l3mdev_ops___15;

struct xfrmdev_ops___22;

struct header_ops___22;

struct netdev_rx_queue___22;

struct mini_Qdisc___22;

struct netdev_queue___22;

struct Qdisc___22;

struct rtnl_link_ops___22;

struct dcbnl_rtnl_ops___22;

struct net_device___26 {
	char name[16];
	struct netdev_name_node___22 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___22 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___15 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___22 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___22 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___135 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___22 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___22 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___22 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___22 *miniq_ingress;
	struct netdev_queue___22 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___22 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___22 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___22 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___22 = 0,
		NETREG_REGISTERED___22 = 1,
		NETREG_UNREGISTERING___22 = 2,
		NETREG_UNREGISTERED___22 = 3,
		NETREG_RELEASED___22 = 4,
		NETREG_DUMMY___22 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___22 = 0,
		RTNL_LINK_INITIALIZING___22 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___26 *);
	struct netpoll_info *npinfo;
	possible_net_t___22 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___105 dev;
	const struct attribute_group___135 *sysfs_groups[4];
	const struct attribute_group___135 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___22 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___22 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___22 xdp_state[3];
	long: 64;
};

struct netlink_callback___22 {
	struct sk_buff___24 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___24 *, struct netlink_callback___22 *);
	int (*done)(struct netlink_callback___22 *);
	void *data;
	struct module___133 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct seq_operations___125 {
	void * (*start)(struct seq_file___125 *, loff_t *);
	void (*stop)(struct seq_file___125 *, void *);
	void * (*next)(struct seq_file___125 *, void *, loff_t *);
	int (*show)(struct seq_file___125 *, void *);
};

struct bpf_iter_aux_info___24;

typedef int (*bpf_iter_init_seq_priv_t___23)(void *, struct bpf_iter_aux_info___24 *);

struct bpf_map___23;

struct bpf_iter_aux_info___24 {
	struct bpf_map___23 *map;
};

struct bpf_iter_seq_info___23 {
	const struct seq_operations___125 *seq_ops;
	bpf_iter_init_seq_priv_t___23 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___23;

struct bpf_map_ops___23 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___23 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___23 *, struct file___146 *);
	void (*map_free)(struct bpf_map___23 *);
	int (*map_get_next_key)(struct bpf_map___23 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___23 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___23 *, void *);
	int (*map_lookup_batch)(struct bpf_map___23 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___23 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___23 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___23 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___23 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___23 *, void *);
	int (*map_update_elem)(struct bpf_map___23 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___23 *, void *);
	int (*map_push_elem)(struct bpf_map___23 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___23 *, void *);
	int (*map_peek_elem)(struct bpf_map___23 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___23 *, struct file___146 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___23 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___23 *, void *, struct seq_file___125 *);
	int (*map_check_btf)(const struct bpf_map___23 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___23 *, struct bpf_prog_aux___23 *);
	void (*map_poke_untrack)(struct bpf_map___23 *, struct bpf_prog_aux___23 *);
	void (*map_poke_run)(struct bpf_map___23 *, u32, struct bpf_prog___22 *, struct bpf_prog___22 *);
	int (*map_direct_value_addr)(const struct bpf_map___23 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___23 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___23 *, struct vm_area_struct___151 *);
	__poll_t (*map_poll)(struct bpf_map___23 *, struct file___146 *, struct poll_table_struct___92 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___23 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___23 *, const struct bpf_map___23 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___23 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___23 *iter_seq_info;
};

struct bpf_map___23 {
	const struct bpf_map_ops___23 *ops;
	struct bpf_map___23 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___54 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___23;

struct bpf_jit_poke_descriptor___23;

struct bpf_prog_ops___22;

struct btf_mod_pair___23;

struct bpf_prog_offload___22;

struct bpf_prog_aux___23 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___22 *dst_prog;
	struct bpf_trampoline___23 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___22 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___23 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___22 *ops;
	struct bpf_map___23 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___23 *used_btfs;
	struct bpf_prog___22 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___23 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___22 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___22 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___23 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___22;

struct bpf_map_dev_ops___22 {
	int (*map_get_next_key)(struct bpf_offloaded_map___22 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___22 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___22 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___22 *, void *);
};

struct bpf_offloaded_map___22 {
	struct bpf_map___23 map;
	struct net_device___26 *netdev;
	const struct bpf_map_dev_ops___22 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___22 {
	int (*test_run)(struct bpf_prog___22 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___22 {
	struct bpf_prog___22 *prog;
	struct net_device___26 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___23 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___22 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___133 *mod;
};

struct bpf_jit_poke_descriptor___23 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___23 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___23 {
	struct btf *btf;
	struct module___133 *module;
};

struct bpf_prog_array_item___22 {
	struct bpf_prog___22 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___22 {
	struct callback_head rcu;
	struct bpf_prog_array_item___22 items[0];
};

struct cftype___101;

struct cgroup_subsys___101 {
	struct cgroup_subsys_state___101 * (*css_alloc)(struct cgroup_subsys_state___101 *);
	int (*css_online)(struct cgroup_subsys_state___101 *);
	void (*css_offline)(struct cgroup_subsys_state___101 *);
	void (*css_released)(struct cgroup_subsys_state___101 *);
	void (*css_free)(struct cgroup_subsys_state___101 *);
	void (*css_reset)(struct cgroup_subsys_state___101 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___101 *, int);
	int (*css_extra_stat_show)(struct seq_file___125 *, struct cgroup_subsys_state___101 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___153 *, struct css_set___101 *);
	void (*cancel_fork)(struct task_struct___153 *, struct css_set___101 *);
	void (*fork)(struct task_struct___153 *);
	void (*exit)(struct task_struct___153 *);
	void (*release)(struct task_struct___153 *);
	void (*bind)(struct cgroup_subsys_state___101 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___101 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___101 *dfl_cftypes;
	struct cftype___101 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___101 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___101 *updated_children;
	struct cgroup___101 *updated_next;
};

struct cgroup_root___101 {
	struct kernfs_root___135 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___101 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___101 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___101 *ss;
	struct list_head node;
	struct kernfs_ops___135 *kf_ops;
	int (*open)(struct kernfs_open_file___135 *);
	void (*release)(struct kernfs_open_file___135 *);
	u64 (*read_u64)(struct cgroup_subsys_state___101 *, struct cftype___101 *);
	s64 (*read_s64)(struct cgroup_subsys_state___101 *, struct cftype___101 *);
	int (*seq_show)(struct seq_file___125 *, void *);
	void * (*seq_start)(struct seq_file___125 *, loff_t *);
	void * (*seq_next)(struct seq_file___125 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___125 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___101 *, struct cftype___101 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___101 *, struct cftype___101 *, s64);
	ssize_t (*write)(struct kernfs_open_file___135 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___135 *, struct poll_table_struct___92 *);
};

struct perf_cpu_context___68;

struct perf_output_handle___68;

struct pmu___68 {
	struct list_head entry;
	struct module___133 *module;
	struct device___105 *dev;
	const struct attribute_group___135 **attr_groups;
	const struct attribute_group___135 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___68 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___68 *);
	void (*pmu_disable)(struct pmu___68 *);
	int (*event_init)(struct perf_event___68 *);
	void (*event_mapped)(struct perf_event___68 *, struct mm_struct___152 *);
	void (*event_unmapped)(struct perf_event___68 *, struct mm_struct___152 *);
	int (*add)(struct perf_event___68 *, int);
	void (*del)(struct perf_event___68 *, int);
	void (*start)(struct perf_event___68 *, int);
	void (*stop)(struct perf_event___68 *, int);
	void (*read)(struct perf_event___68 *);
	void (*start_txn)(struct pmu___68 *, unsigned int);
	int (*commit_txn)(struct pmu___68 *);
	void (*cancel_txn)(struct pmu___68 *);
	int (*event_idx)(struct perf_event___68 *);
	void (*sched_task)(struct perf_event_context___68 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___68 *, struct perf_event_context___68 *);
	void * (*setup_aux)(struct perf_event___68 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___68 *, struct perf_output_handle___68 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___68 *);
	int (*aux_output_match)(struct perf_event___68 *);
	int (*filter_match)(struct perf_event___68 *);
	int (*check_period)(struct perf_event___68 *, u64);
};

struct perf_cpu_context___68 {
	struct perf_event_context___68 ctx;
	struct perf_event_context___68 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___68 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___68 **heap;
	struct perf_event___68 *heap_default[2];
};

struct perf_output_handle___68 {
	struct perf_event___68 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___68 {
	struct cgroup_subsys_state___101 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___62 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___62 *);
	};
};

struct trace_event_class___62 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___62 *, enum trace_reg, void *);
	struct trace_event_fields___62 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___62 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___62 *);
};

struct syscall_metadata___34 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___62 *enter_event;
	struct trace_event_call___62 *exit_event;
};

struct inet_frags___25;

struct fqdir___25 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___25 *f;
	struct net___26 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___25;

struct inet_frags___25 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___25 *, const void *);
	void (*destructor)(struct inet_frag_queue___25 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___25 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___24 *fragments_tail;
	struct sk_buff___24 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___25 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___15;

struct fib_lookup_arg___15;

struct fib_rules_ops___15 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___15 *, struct flowi *, int, struct fib_lookup_arg___15 *);
	bool (*suppress)(struct fib_rule___15 *, int, struct fib_lookup_arg___15 *);
	int (*match)(struct fib_rule___15 *, struct flowi *, int);
	int (*configure)(struct fib_rule___15 *, struct sk_buff___24 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___15 *);
	int (*compare)(struct fib_rule___15 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___15 *, struct sk_buff___24 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___15 *);
	void (*flush_cache)(struct fib_rules_ops___15 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___133 *owner;
	struct net___26 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___15 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___26 *);
	int (*fib_dump)(struct net___26 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___133 *owner;
	struct callback_head rcu;
};

struct dst_entry___15 {
	struct net_device___26 *dev;
	struct dst_ops___25 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___24 *);
	int (*output)(struct net___26 *, struct sock___16 *, struct sk_buff___24 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___15;

struct neigh_parms___15;

struct neigh_ops___15;

struct neighbour___15 {
	struct neighbour___15 *next;
	struct neigh_table___15 *tbl;
	struct neigh_parms___15 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___22 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___15 *, struct sk_buff___24 *);
	const struct neigh_ops___15 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___26 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___22 {
	int (*ieee_getets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___26 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___26 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___26 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___26 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___26 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___26 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___26 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___26 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___26 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___26 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___26 *);
	u8 (*setstate)(struct net_device___26 *, u8);
	void (*getpermhwaddr)(struct net_device___26 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___26 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___26 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___26 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___26 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___26 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___26 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___26 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___26 *, int, u8 *);
	void (*setpfccfg)(struct net_device___26 *, int, u8);
	void (*getpfccfg)(struct net_device___26 *, int, u8 *);
	u8 (*setall)(struct net_device___26 *);
	u8 (*getcap)(struct net_device___26 *, int, u8 *);
	int (*getnumtcs)(struct net_device___26 *, int, u8 *);
	int (*setnumtcs)(struct net_device___26 *, int, u8);
	u8 (*getpfcstate)(struct net_device___26 *);
	void (*setpfcstate)(struct net_device___26 *, u8);
	void (*getbcncfg)(struct net_device___26 *, int, u32 *);
	void (*setbcncfg)(struct net_device___26 *, int, u32);
	void (*getbcnrp)(struct net_device___26 *, int, u8 *);
	void (*setbcnrp)(struct net_device___26 *, int, u8);
	int (*setapp)(struct net_device___26 *, u8, u16, u8);
	int (*getapp)(struct net_device___26 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___26 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___26 *, int, u8);
	u8 (*getdcbx)(struct net_device___26 *);
	u8 (*setdcbx)(struct net_device___26 *, u8);
	int (*peer_getappinfo)(struct net_device___26 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___26 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___26 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___26 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___26 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___26 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___22 {
	struct net_device___26 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___22 {
	struct net_device___26 *dev;
};

struct xdp_buff___22 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___22 *rxq;
	struct xdp_txq_info___22 *txq;
	u32 frame_sz;
};

struct xdp_frame___22 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___26 *dev_rx;
};

struct header_ops___22 {
	int (*create)(struct sk_buff___24 *, struct net_device___26 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___24 *, unsigned char *);
	int (*cache)(const struct neighbour___15 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___26 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___24 *);
};

struct netdev_queue___22 {
	struct net_device___26 *dev;
	struct Qdisc___22 *qdisc;
	struct Qdisc___22 *qdisc_sleeping;
	struct kobject___135 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___26 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___22 {
	struct sk_buff___24 *head;
	struct sk_buff___24 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___22;

struct Qdisc___22 {
	int (*enqueue)(struct sk_buff___24 *, struct Qdisc___22 *, struct sk_buff___24 **);
	struct sk_buff___24 * (*dequeue)(struct Qdisc___22 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___22 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___22 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___22 gso_skb;
	struct qdisc_skb_head___22 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___22 *next_sched;
	struct sk_buff_head___22 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___22 {
	struct xdp_rxq_info___22 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___135 kobj;
	struct net_device___26 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___22 {
	enum net_device_path_type type;
	const struct net_device___26 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___22 = 0,
				DEV_PATH_BR_VLAN_TAG___22 = 1,
				DEV_PATH_BR_VLAN_UNTAG___22 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___22 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___22 {
	const struct net_device___26 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___22 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___22 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___22 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___22 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___24 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___22 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___26 *dev;
	const char *name;
};

struct net_device_ops___22 {
	int (*ndo_init)(struct net_device___26 *);
	void (*ndo_uninit)(struct net_device___26 *);
	int (*ndo_open)(struct net_device___26 *);
	int (*ndo_stop)(struct net_device___26 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___24 *, struct net_device___26 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___24 *, struct net_device___26 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___26 *, struct sk_buff___24 *, struct net_device___26 *);
	void (*ndo_change_rx_flags)(struct net_device___26 *, int);
	void (*ndo_set_rx_mode)(struct net_device___26 *);
	int (*ndo_set_mac_address)(struct net_device___26 *, void *);
	int (*ndo_validate_addr)(struct net_device___26 *);
	int (*ndo_do_ioctl)(struct net_device___26 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___26 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___26 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___26 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___26 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___26 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___26 *, int);
	int (*ndo_neigh_setup)(struct net_device___26 *, struct neigh_parms___15 *);
	void (*ndo_tx_timeout)(struct net_device___26 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___26 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___26 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___26 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___26 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___26 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___26 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___26 *);
	int (*ndo_netpoll_setup)(struct net_device___26 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___26 *);
	int (*ndo_set_vf_mac)(struct net_device___26 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___26 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___26 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___26 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___26 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___26 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___26 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___26 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___26 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___26 *, int, struct sk_buff___24 *);
	int (*ndo_get_vf_guid)(struct net_device___26 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___26 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___26 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___26 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___26 *);
	int (*ndo_fcoe_disable)(struct net_device___26 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___26 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___26 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___26 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___26 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___26 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___26 *, const struct sk_buff___24 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___26 *, struct net_device___26 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___26 *, struct net_device___26 *);
	struct net_device___26 * (*ndo_get_xmit_slave)(struct net_device___26 *, struct sk_buff___24 *, bool);
	struct net_device___26 * (*ndo_sk_get_lower_dev)(struct net_device___26 *, struct sock___16 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___26 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___26 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___26 *, struct neighbour___15 *);
	void (*ndo_neigh_destroy)(struct net_device___26 *, struct neighbour___15 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___24 *, struct netlink_callback___22 *, struct net_device___26 *, struct net_device___26 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___24 *, struct nlattr **, struct net_device___26 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___26 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___24 *, u32, u32, struct net_device___26 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___26 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___26 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___26 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___26 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___26 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___26 *, struct net_device___26 *);
	void (*ndo_dfwd_del_station)(struct net_device___26 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___26 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___26 *);
	int (*ndo_change_proto_down)(struct net_device___26 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___26 *, struct sk_buff___24 *);
	void (*ndo_set_rx_headroom)(struct net_device___26 *, int);
	int (*ndo_bpf)(struct net_device___26 *, struct netdev_bpf___22 *);
	int (*ndo_xdp_xmit)(struct net_device___26 *, int, struct xdp_frame___22 **, u32);
	struct net_device___26 * (*ndo_xdp_get_xmit_slave)(struct net_device___26 *, struct xdp_buff___22 *);
	int (*ndo_xsk_wakeup)(struct net_device___26 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___26 *);
	int (*ndo_tunnel_ctl)(struct net_device___26 *, struct ip_tunnel_parm *, int);
	struct net_device___26 * (*ndo_get_peer_dev)(struct net_device___26 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___22 *, struct net_device_path___22 *);
};

struct neigh_parms___15 {
	possible_net_t___22 net;
	struct net_device___26 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___15 *);
	struct neigh_table___15 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___15 {
	u32 (*l3mdev_fib_table)(const struct net_device___26 *);
	struct sk_buff___24 * (*l3mdev_l3_rcv)(struct net_device___26 *, struct sk_buff___24 *, u16);
	struct sk_buff___24 * (*l3mdev_l3_out)(struct net_device___26 *, struct sock___16 *, struct sk_buff___24 *, u16);
	struct dst_entry___15 * (*l3mdev_link_scope_lookup)(const struct net_device___26 *, struct flowi6 *);
};

struct tcf_proto___22;

struct tcf_block___22;

struct mini_Qdisc___22 {
	struct tcf_proto___22 *filter_list;
	struct tcf_block___22 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___22 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___26 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___26 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___26 *, struct net_device___26 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___26 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___26 *, struct list_head *);
	size_t (*get_size)(const struct net_device___26 *);
	int (*fill_info)(struct sk_buff___24 *, const struct net_device___26 *);
	size_t (*get_xstats_size)(const struct net_device___26 *);
	int (*fill_xstats)(struct sk_buff___24 *, const struct net_device___26 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___26 *, struct net_device___26 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___26 *, const struct net_device___26 *);
	int (*fill_slave_info)(struct sk_buff___24 *, const struct net_device___26 *, const struct net_device___26 *);
	struct net___26 * (*get_link_net)(const struct net_device___26 *);
	size_t (*get_linkxstats_size)(const struct net_device___26 *, int);
	int (*fill_linkxstats)(struct sk_buff___24 *, const struct net_device___26 *, int *, int);
};

struct block_device_operations___66;

struct gendisk___66 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___67 *part0;
	const struct block_device_operations___66 *fops;
	struct request_queue___66 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___63 *bdi;
	struct kobject___135 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___135 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___66 {
	struct bio___66 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___78 *bip_vec;
	struct bio_vec___78 bip_inline_vecs[0];
};

struct blkcg___63;

struct blkg_policy_data___63;

struct blkcg_gq___63 {
	struct request_queue___66 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___63 *blkcg;
	struct blkcg_gq___63 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___63 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___66 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___66(struct request___66 *);

typedef void integrity_complete_fn___66(struct request___66 *, unsigned int);

struct blk_integrity_profile___66 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___66 *prepare_fn;
	integrity_complete_fn___66 *complete_fn;
	const char *name;
};

struct block_device_operations___66 {
	blk_qc_t (*submit_bio)(struct bio___66 *);
	int (*open)(struct block_device___67 *, fmode_t);
	void (*release)(struct gendisk___66 *, fmode_t);
	int (*rw_page)(struct block_device___67 *, sector_t, struct page___151 *, unsigned int);
	int (*ioctl)(struct block_device___67 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___67 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___66 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___66 *);
	int (*getgeo)(struct block_device___67 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___67 *, bool);
	void (*swap_slot_free_notify)(struct block_device___67 *, long unsigned int);
	int (*report_zones)(struct gendisk___66 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___66 *, umode_t *);
	struct module___133 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___66 *, sector_t *);
};

typedef void rq_end_io_fn___66(struct request___66 *, blk_status_t);

struct request___66 {
	struct request_queue___66 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___63 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___66 *bio;
	struct bio___66 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___78 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___66 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___66 *saved_end_io;
		} flush;
	};
	struct gendisk___66 *rq_disk;
	struct block_device___67 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___66 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___63 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___66 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___135 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___146 *debugfs_dir;
	struct dentry___146 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___66;

struct elevator_mq_ops___66 {
	int (*init_sched)(struct request_queue___66 *, struct elevator_type___66 *);
	void (*exit_sched)(struct elevator_queue___66 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___63 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___63 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___63 *);
	bool (*allow_merge)(struct request_queue___66 *, struct request___66 *, struct bio___66 *);
	bool (*bio_merge)(struct request_queue___66 *, struct bio___66 *, unsigned int);
	int (*request_merge)(struct request_queue___66 *, struct request___66 **, struct bio___66 *);
	void (*request_merged)(struct request_queue___66 *, struct request___66 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___66 *, struct request___66 *, struct request___66 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___66 *);
	void (*finish_request)(struct request___66 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___63 *, struct list_head *, bool);
	struct request___66 * (*dispatch_request)(struct blk_mq_hw_ctx___63 *);
	bool (*has_work)(struct blk_mq_hw_ctx___63 *);
	void (*completed_request)(struct request___66 *, u64);
	void (*requeue_request)(struct request___66 *);
	struct request___66 * (*former_request)(struct request_queue___66 *, struct request___66 *);
	struct request___66 * (*next_request)(struct request_queue___66 *, struct request___66 *);
	void (*init_icq)(struct io_cq___66 *);
	void (*exit_icq)(struct io_cq___66 *);
};

struct elv_fs_entry___66;

struct elevator_type___66 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___66 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___66 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___133 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___66 {
	struct elevator_type___66 *type;
	void *elevator_data;
	struct kobject___135 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___66 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___66 *, char *);
	ssize_t (*store)(struct elevator_queue___66 *, const char *, size_t);
};

struct blk_mq_queue_data___63;

struct blk_mq_ops___63 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___63 *, const struct blk_mq_queue_data___63 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___63 *);
	int (*get_budget)(struct request_queue___66 *);
	void (*put_budget)(struct request_queue___66 *, int);
	void (*set_rq_budget_token)(struct request___66 *, int);
	int (*get_rq_budget_token)(struct request___66 *);
	enum blk_eh_timer_return (*timeout)(struct request___66 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___63 *);
	void (*complete)(struct request___66 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___63 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___63 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___63 *, struct request___66 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___63 *, struct request___66 *, unsigned int);
	void (*initialize_rq_fn)(struct request___66 *);
	void (*cleanup_rq)(struct request___66 *);
	bool (*busy)(struct request_queue___66 *);
	int (*map_queues)(struct blk_mq_tag_set___63 *);
	void (*show_rq)(struct seq_file___125 *, struct request___66 *);
};

struct blk_mq_tag_set___63 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___63 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___63 {
	struct request___66 *rq;
	bool last;
};

struct blkcg_policy_data___63;

struct blkcg___63 {
	struct cgroup_subsys_state___101 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___63 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___63 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___63 {
	struct blkcg___63 *blkcg;
	int plid;
};

struct blkg_policy_data___63 {
	struct blkcg_gq___63 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___54 {
	struct mem_cgroup___54 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___54 {
	struct lruvec___61 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___54 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___54 *memcg;
};

struct obj_cgroup___54 {
	struct percpu_ref refcnt;
	struct mem_cgroup___54 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___22 {
	spinlock_t *lock;
	struct sk_buff___24 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___22;

struct Qdisc_ops___22 {
	struct Qdisc_ops___22 *next;
	const struct Qdisc_class_ops___22 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___24 *, struct Qdisc___22 *, struct sk_buff___24 **);
	struct sk_buff___24 * (*dequeue)(struct Qdisc___22 *);
	struct sk_buff___24 * (*peek)(struct Qdisc___22 *);
	int (*init)(struct Qdisc___22 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___22 *);
	void (*destroy)(struct Qdisc___22 *);
	int (*change)(struct Qdisc___22 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___22 *);
	int (*change_tx_queue_len)(struct Qdisc___22 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___22 *, unsigned int);
	int (*dump)(struct Qdisc___22 *, struct sk_buff___24 *);
	int (*dump_stats)(struct Qdisc___22 *, struct gnet_dump___22 *);
	void (*ingress_block_set)(struct Qdisc___22 *, u32);
	void (*egress_block_set)(struct Qdisc___22 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___22 *);
	u32 (*egress_block_get)(struct Qdisc___22 *);
	struct module___133 *owner;
};

struct Qdisc_class_ops___22 {
	unsigned int flags;
	struct netdev_queue___22 * (*select_queue)(struct Qdisc___22 *, struct tcmsg *);
	int (*graft)(struct Qdisc___22 *, long unsigned int, struct Qdisc___22 *, struct Qdisc___22 **, struct netlink_ext_ack *);
	struct Qdisc___22 * (*leaf)(struct Qdisc___22 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___22 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___22 *, u32);
	int (*change)(struct Qdisc___22 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___22 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___22 *, struct qdisc_walker *);
	struct tcf_block___22 * (*tcf_block)(struct Qdisc___22 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___22 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___22 *, long unsigned int);
	int (*dump)(struct Qdisc___22 *, long unsigned int, struct sk_buff___24 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___22 *, long unsigned int, struct gnet_dump___22 *);
};

struct tcf_chain___22;

struct tcf_block___22 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___26 *net;
	struct Qdisc___22 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___22 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___22;

struct tcf_proto_ops___22;

struct tcf_proto___22 {
	struct tcf_proto___22 *next;
	void *root;
	int (*classify)(struct sk_buff___24 *, const struct tcf_proto___22 *, struct tcf_result___22 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___22 *ops;
	struct tcf_chain___22 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___22 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___22 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___22 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___24 *, const struct tcf_proto___22 *, struct tcf_result___22 *);
	int (*init)(struct tcf_proto___22 *);
	void (*destroy)(struct tcf_proto___22 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___22 *, u32);
	void (*put)(struct tcf_proto___22 *, void *);
	int (*change)(struct net___26 *, struct sk_buff___24 *, struct tcf_proto___22 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___22 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___22 *);
	void (*walk)(struct tcf_proto___22 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___22 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___22 *, void *);
	void (*hw_del)(struct tcf_proto___22 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___26 *, struct tcf_chain___22 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___26 *, struct tcf_proto___22 *, void *, struct sk_buff___24 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___26 *, struct tcf_proto___22 *, void *, struct sk_buff___24 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___24 *, struct net___26 *, void *);
	struct module___133 *owner;
	int flags;
};

struct tcf_chain___22 {
	struct mutex filter_chain_lock;
	struct tcf_proto___22 *filter_chain;
	struct list_head list;
	struct tcf_block___22 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___22 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___15 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___22 *prog;
};

struct pneigh_entry___15;

struct neigh_hash_table___15;

struct neigh_table___15 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___26 *, __u32 *);
	bool (*key_eq)(const struct neighbour___15 *, const void *);
	int (*constructor)(struct neighbour___15 *);
	int (*pconstructor)(struct pneigh_entry___15 *);
	void (*pdestructor)(struct pneigh_entry___15 *);
	void (*proxy_redo)(struct sk_buff___24 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___26 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___15 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___22 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___15 *nht;
	struct pneigh_entry___15 **phash_buckets;
};

struct neigh_ops___15 {
	int family;
	void (*solicit)(struct neighbour___15 *, struct sk_buff___24 *);
	void (*error_report)(struct neighbour___15 *, struct sk_buff___24 *);
	int (*output)(struct neighbour___15 *, struct sk_buff___24 *);
	int (*connected_output)(struct neighbour___15 *, struct sk_buff___24 *);
};

struct pneigh_entry___15 {
	struct pneigh_entry___15 *next;
	possible_net_t___22 net;
	struct net_device___26 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___15 {
	struct neighbour___15 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___15 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___15 *ctarget;
	struct net___26 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___15 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___15 *rule;
	u32 table;
	int flags;
};

struct proto___15 {
	void (*close)(struct sock___16 *, long int);
	int (*pre_connect)(struct sock___16 *, struct sockaddr *, int);
	int (*connect)(struct sock___16 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___16 *, int);
	struct sock___16 * (*accept)(struct sock___16 *, int, int *, bool);
	int (*ioctl)(struct sock___16 *, int, long unsigned int);
	int (*init)(struct sock___16 *);
	void (*destroy)(struct sock___16 *);
	void (*shutdown)(struct sock___16 *, int);
	int (*setsockopt)(struct sock___16 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___16 *, int, int, char *, int *);
	void (*keepalive)(struct sock___16 *, int);
	int (*compat_ioctl)(struct sock___16 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___16 *, struct msghdr___15 *, size_t);
	int (*recvmsg)(struct sock___16 *, struct msghdr___15 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___16 *, struct page___151 *, int, size_t, int);
	int (*bind)(struct sock___16 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___16 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___16 *, struct sk_buff___24 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___16 *);
	int (*hash)(struct sock___16 *);
	void (*unhash)(struct sock___16 *);
	void (*rehash)(struct sock___16 *);
	int (*get_port)(struct sock___16 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___16 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___16 *, int);
	bool (*sock_is_readable)(struct sock___16 *);
	void (*enter_memory_pressure)(struct sock___16 *);
	void (*leave_memory_pressure)(struct sock___16 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___133 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___16 *, int);
};

struct mqueue_fs_context {
	struct ipc_namespace___8 *ipc_ns;
};

struct posix_msg_tree_node {
	struct rb_node rb_node;
	struct list_head msg_list;
	int priority;
};

struct ext_wait_queue {
	struct task_struct___153 *task;
	struct list_head list;
	struct msg_msg *msg;
	int state;
};

struct mqueue_inode_info {
	spinlock_t lock;
	struct inode___146 vfs_inode;
	wait_queue_head_t wait_q;
	struct rb_root msg_tree;
	struct rb_node *msg_tree_rightmost;
	struct posix_msg_tree_node *node_cache;
	struct mq_attr attr;
	struct sigevent notify;
	struct pid___129 *notify_owner;
	u32 notify_self_exec_id;
	struct user_namespace___19 *notify_user_ns;
	struct ucounts___19 *ucounts;
	struct sock___16 *notify_sock;
	struct sk_buff___24 *notify_cookie;
	struct ext_wait_queue e_wait_q[2];
	long unsigned int qsize;
};

struct compat_mq_attr {
	compat_long_t mq_flags;
	compat_long_t mq_maxmsg;
	compat_long_t mq_msgsize;
	compat_long_t mq_curmsgs;
	compat_long_t __reserved[4];
};

struct dentry___147;

struct super_block___147;

struct file_system_type___147 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___147 * (*mount)(struct file_system_type___147 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___147 *);
	struct module___8 *owner;
	struct file_system_type___147 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___147;

struct kiocb___147;

struct vm_area_struct___152;

struct inode___147;

struct file_lock___147;

struct page___152;

struct file_operations___147 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___147 *, loff_t, int);
	ssize_t (*read)(struct file___147 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___147 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___147 *, struct iov_iter___80 *);
	ssize_t (*write_iter)(struct kiocb___147 *, struct iov_iter___80 *);
	int (*iopoll)(struct kiocb___147 *, bool);
	int (*iterate)(struct file___147 *, struct dir_context *);
	int (*iterate_shared)(struct file___147 *, struct dir_context *);
	__poll_t (*poll)(struct file___147 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___147 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___147 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___147 *, struct vm_area_struct___152 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___147 *, struct file___147 *);
	int (*flush)(struct file___147 *, fl_owner_t);
	int (*release)(struct inode___147 *, struct file___147 *);
	int (*fsync)(struct file___147 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___147 *, int);
	int (*lock)(struct file___147 *, int, struct file_lock___147 *);
	ssize_t (*sendpage)(struct file___147 *, struct page___152 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___147 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___147 *, long unsigned int);
	int (*flock)(struct file___147 *, int, struct file_lock___147 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___147 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___147 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___147 *, long int, struct file_lock___147 **, void **);
	long int (*fallocate)(struct file___147 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___147 *);
	ssize_t (*copy_file_range)(struct file___147 *, loff_t, struct file___147 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___147 *, loff_t, struct file___147 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___147 *, loff_t, loff_t, int);
};

struct vmacache___152 {
	u64 seqnum;
	struct vm_area_struct___152 *vmas[4];
};

struct page_frag___152 {
	struct page___152 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___153;

struct cred___20;

struct nsproxy___138;

struct signal_struct___148;

struct task_struct___154 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___154 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___153 *mm;
	struct mm_struct___153 *active_mm;
	struct vmacache___152 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___154 *real_parent;
	struct task_struct___154 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___154 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___129 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___20 *ptracer_cred;
	const struct cred___20 *real_cred;
	const struct cred___20 *cred;
	struct key___3 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___138 *nsproxy;
	struct signal_struct___148 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___154 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___152 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___154 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___68 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct proc_ns_operations___26;

struct ns_common___26 {
	atomic_long_t stashed;
	const struct proc_ns_operations___26 *ops;
	unsigned int inum;
	refcount_t count;
};

struct ucounts___20;

struct user_namespace___20 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___20 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___26 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___3 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___3 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___20 *ucounts;
	long int ucount_max[16];
};

typedef struct page___152 *pgtable_t___152;

struct address_space___147;

struct page___152 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___147 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___35 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___152 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___152 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___153 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___143 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___152 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___152 *vm_next;
	struct vm_area_struct___152 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___153 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___147 *vm_file;
	struct file___147 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___152;

struct mm_struct___153 {
	struct {
		struct vm_area_struct___152 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___147 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___152 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___154 *owner;
		struct user_namespace___20 *user_ns;
		struct file___147 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___147;

struct address_space___147 {
	struct inode___147 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___147 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct vfsmount___147;

struct path___147 {
	struct vfsmount___147 *mnt;
	struct dentry___147 *dentry;
};

struct file___147 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___147 f_path;
	struct inode___147 *f_inode;
	const struct file_operations___147 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___129 f_owner;
	const struct cred___20 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___147 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct core_thread___152 {
	struct task_struct___154 *task;
	struct core_thread___152 *next;
};

struct core_state___152 {
	atomic_t nr_threads;
	struct core_thread___152 dumper;
	struct completion startup;
};

struct ucounts___20 {
	struct hlist_node node;
	struct user_namespace___20 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___148 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___154 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___154 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___129 *pids[4];
	struct pid___129 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___153 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___20 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___3 *session_keyring;
	struct key___3 *process_keyring;
	struct key___3 *thread_keyring;
	struct key___3 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___20 *user_ns;
	struct ucounts___20 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct ipc_namespace___9;

struct nsproxy___138 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace___9 *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct ipc_namespace___9 {
	struct ipc_ids ids[3];
	int sem_ctls[4];
	int used_sems;
	unsigned int msg_ctlmax;
	unsigned int msg_ctlmnb;
	unsigned int msg_ctlmni;
	atomic_t msg_bytes;
	atomic_t msg_hdrs;
	size_t shm_ctlmax;
	size_t shm_ctlall;
	long unsigned int shm_tot;
	int shm_ctlmni;
	int shm_rmid_forced;
	struct notifier_block ipcns_nb;
	struct vfsmount___147 *mq_mnt;
	unsigned int mq_queues_count;
	unsigned int mq_queues_max;
	unsigned int mq_msg_max;
	unsigned int mq_msgsize_max;
	unsigned int mq_msg_default;
	unsigned int mq_msgsize_default;
	struct user_namespace___20 *user_ns;
	struct ucounts___20 *ucounts;
	struct llist_node mnt_llist;
	struct ns_common___26 ns;
};

struct nsset___25 {
	unsigned int flags;
	struct nsproxy___138 *nsproxy;
	struct fs_struct *fs;
	const struct cred___20 *cred;
};

struct proc_ns_operations___26 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___26 * (*get)(struct task_struct___154 *);
	void (*put)(struct ns_common___26 *);
	int (*install)(struct nsset___25 *, struct ns_common___26 *);
	struct user_namespace___20 * (*owner)(struct ns_common___26 *);
	struct ns_common___26 * (*get_parent)(struct ns_common___26 *);
};

struct vfsmount___147 {
	struct dentry___147 *mnt_root;
	struct super_block___147 *mnt_sb;
	int mnt_flags;
	struct user_namespace___20 *mnt_userns;
};

struct dentry_operations___147;

struct dentry___147 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___147 *d_parent;
	struct qstr d_name;
	struct inode___147 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___147 *d_op;
	struct super_block___147 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___147;

struct inode___147 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___147 *i_op;
	struct super_block___147 *i_sb;
	struct address_space___147 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___147 *i_fop;
		void (*free_inode)(struct inode___147 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___147 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___44 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___147 {
	int (*d_revalidate)(struct dentry___147 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___147 *, unsigned int);
	int (*d_hash)(const struct dentry___147 *, struct qstr *);
	int (*d_compare)(const struct dentry___147 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___147 *);
	int (*d_init)(struct dentry___147 *);
	void (*d_release)(struct dentry___147 *);
	void (*d_prune)(struct dentry___147 *);
	void (*d_iput)(struct dentry___147 *, struct inode___147 *);
	char * (*d_dname)(struct dentry___147 *, char *, int);
	struct vfsmount___147 * (*d_automount)(struct path___147 *);
	int (*d_manage)(const struct path___147 *, bool);
	struct dentry___147 * (*d_real)(struct dentry___147 *, const struct inode___147 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___147;

struct mem_dqinfo___147 {
	struct quota_format_type___147 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___147;

struct quota_info___147 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___147 *files[3];
	struct mem_dqinfo___147 info[3];
	const struct quota_format_ops___147 *ops[3];
};

struct rcuwait___148 {
	struct task_struct___154 *task;
};

struct percpu_rw_semaphore___148 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___148 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___147 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___148 rw_sem[3];
};

struct super_operations___147;

struct dquot_operations___147;

struct quotactl_ops___147;

struct super_block___147 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___147 *s_type;
	const struct super_operations___147 *s_op;
	const struct dquot_operations___147 *dq_op;
	const struct quotactl_ops___147 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___147 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___3 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___147 s_dquot;
	struct sb_writers___147 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___147 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___20 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct kiocb___147 {
	struct file___147 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___147 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___147 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___147 *ia_file;
};

struct dquot___147 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___147 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___147 {
	int qf_fmt_id;
	const struct quota_format_ops___147 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___147 *qf_next;
};

struct quota_format_ops___147 {
	int (*check_quota_file)(struct super_block___147 *, int);
	int (*read_file_info)(struct super_block___147 *, int);
	int (*write_file_info)(struct super_block___147 *, int);
	int (*free_file_info)(struct super_block___147 *, int);
	int (*read_dqblk)(struct dquot___147 *);
	int (*commit_dqblk)(struct dquot___147 *);
	int (*release_dqblk)(struct dquot___147 *);
	int (*get_next_id)(struct super_block___147 *, struct kqid *);
};

struct dquot_operations___147 {
	int (*write_dquot)(struct dquot___147 *);
	struct dquot___147 * (*alloc_dquot)(struct super_block___147 *, int);
	void (*destroy_dquot)(struct dquot___147 *);
	int (*acquire_dquot)(struct dquot___147 *);
	int (*release_dquot)(struct dquot___147 *);
	int (*mark_dirty)(struct dquot___147 *);
	int (*write_info)(struct super_block___147 *, int);
	qsize_t * (*get_reserved_space)(struct inode___147 *);
	int (*get_projid)(struct inode___147 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___147 *, qsize_t *);
	int (*get_next_id)(struct super_block___147 *, struct kqid *);
};

struct quotactl_ops___147 {
	int (*quota_on)(struct super_block___147 *, int, int, const struct path___147 *);
	int (*quota_off)(struct super_block___147 *, int);
	int (*quota_enable)(struct super_block___147 *, unsigned int);
	int (*quota_disable)(struct super_block___147 *, unsigned int);
	int (*quota_sync)(struct super_block___147 *, int);
	int (*set_info)(struct super_block___147 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___147 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___147 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___147 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___147 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___147 *, unsigned int);
};

struct address_space_operations___147 {
	int (*writepage)(struct page___152 *, struct writeback_control___3 *);
	int (*readpage)(struct file___147 *, struct page___152 *);
	int (*writepages)(struct address_space___147 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___152 *);
	int (*readpages)(struct file___147 *, struct address_space___147 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___147 *, struct address_space___147 *, loff_t, unsigned int, unsigned int, struct page___152 **, void **);
	int (*write_end)(struct file___147 *, struct address_space___147 *, loff_t, unsigned int, unsigned int, struct page___152 *, void *);
	sector_t (*bmap)(struct address_space___147 *, sector_t);
	void (*invalidatepage)(struct page___152 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___152 *, gfp_t);
	void (*freepage)(struct page___152 *);
	ssize_t (*direct_IO)(struct kiocb___147 *, struct iov_iter___80 *);
	int (*migratepage)(struct address_space___147 *, struct page___152 *, struct page___152 *, enum migrate_mode);
	bool (*isolate_page)(struct page___152 *, isolate_mode_t);
	void (*putback_page)(struct page___152 *);
	int (*launder_page)(struct page___152 *);
	int (*is_partially_uptodate)(struct page___152 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___152 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___147 *, struct page___152 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___147 *, sector_t *);
	void (*swap_deactivate)(struct file___147 *);
};

struct inode_operations___147 {
	struct dentry___147 * (*lookup)(struct inode___147 *, struct dentry___147 *, unsigned int);
	const char * (*get_link)(struct dentry___147 *, struct inode___147 *, struct delayed_call *);
	int (*permission)(struct user_namespace___20 *, struct inode___147 *, int);
	struct posix_acl * (*get_acl)(struct inode___147 *, int, bool);
	int (*readlink)(struct dentry___147 *, char *, int);
	int (*create)(struct user_namespace___20 *, struct inode___147 *, struct dentry___147 *, umode_t, bool);
	int (*link)(struct dentry___147 *, struct inode___147 *, struct dentry___147 *);
	int (*unlink)(struct inode___147 *, struct dentry___147 *);
	int (*symlink)(struct user_namespace___20 *, struct inode___147 *, struct dentry___147 *, const char *);
	int (*mkdir)(struct user_namespace___20 *, struct inode___147 *, struct dentry___147 *, umode_t);
	int (*rmdir)(struct inode___147 *, struct dentry___147 *);
	int (*mknod)(struct user_namespace___20 *, struct inode___147 *, struct dentry___147 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___20 *, struct inode___147 *, struct dentry___147 *, struct inode___147 *, struct dentry___147 *, unsigned int);
	int (*setattr)(struct user_namespace___20 *, struct dentry___147 *, struct iattr___147 *);
	int (*getattr)(struct user_namespace___20 *, const struct path___147 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___147 *, char *, size_t);
	int (*fiemap)(struct inode___147 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___147 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___147 *, struct dentry___147 *, struct file___147 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___20 *, struct inode___147 *, struct dentry___147 *, umode_t);
	int (*set_acl)(struct user_namespace___20 *, struct inode___147 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___20 *, struct dentry___147 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___147 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___147 {
	void (*fl_copy_lock)(struct file_lock___147 *, struct file_lock___147 *);
	void (*fl_release_private)(struct file_lock___147 *);
};

struct fasync_struct___147;

struct lock_manager_operations___147;

struct file_lock___147 {
	struct file_lock___147 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___147 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___147 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___147 *fl_ops;
	const struct lock_manager_operations___147 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___147 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___147 *);
	int (*lm_grant)(struct file_lock___147 *, int);
	bool (*lm_break)(struct file_lock___147 *);
	int (*lm_change)(struct file_lock___147 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___147 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___147 *);
};

struct fasync_struct___147 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___147 *fa_next;
	struct file___147 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___147 {
	struct inode___147 * (*alloc_inode)(struct super_block___147 *);
	void (*destroy_inode)(struct inode___147 *);
	void (*free_inode)(struct inode___147 *);
	void (*dirty_inode)(struct inode___147 *, int);
	int (*write_inode)(struct inode___147 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___147 *);
	void (*evict_inode)(struct inode___147 *);
	void (*put_super)(struct super_block___147 *);
	int (*sync_fs)(struct super_block___147 *, int);
	int (*freeze_super)(struct super_block___147 *);
	int (*freeze_fs)(struct super_block___147 *);
	int (*thaw_super)(struct super_block___147 *);
	int (*unfreeze_fs)(struct super_block___147 *);
	int (*statfs)(struct dentry___147 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___147 *, int *, char *);
	void (*umount_begin)(struct super_block___147 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___147 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___147 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___147 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___147 *);
	ssize_t (*quota_read)(struct super_block___147 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___147 *, int, const char *, size_t, loff_t);
	struct dquot___147 ** (*get_dquots)(struct inode___147 *);
	long int (*nr_cached_objects)(struct super_block___147 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___147 *, struct shrink_control___54 *);
	struct file___147 * (*real_loop)(struct file___147 *);
};

struct key_user {
	struct rb_node node;
	struct mutex cons_lock;
	spinlock_t lock;
	refcount_t usage;
	atomic_t nkeys;
	atomic_t nikeys;
	kuid_t uid;
	int qnkeys;
	int qnbytes;
};

enum key_notification_subtype {
	NOTIFY_KEY_INSTANTIATED = 0,
	NOTIFY_KEY_UPDATED = 1,
	NOTIFY_KEY_LINKED = 2,
	NOTIFY_KEY_UNLINKED = 3,
	NOTIFY_KEY_CLEARED = 4,
	NOTIFY_KEY_REVOKED = 5,
	NOTIFY_KEY_INVALIDATED = 6,
	NOTIFY_KEY_SETATTR = 7,
};

struct key_notification {
	struct watch_notification___2 watch;
	__u32 key_id;
	__u32 aux;
};

struct assoc_array_edit;

struct dentry___148;

struct super_block___148;

struct module___134;

struct file_system_type___148 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___148 * (*mount)(struct file_system_type___148 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___148 *);
	struct module___134 *owner;
	struct file_system_type___148 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___148;

struct kiocb___148;

struct iov_iter___81;

struct vm_area_struct___153;

struct inode___148;

struct file_lock___148;

struct page___153;

struct pipe_inode_info___45;

struct seq_file___126;

struct file_operations___148 {
	struct module___134 *owner;
	loff_t (*llseek)(struct file___148 *, loff_t, int);
	ssize_t (*read)(struct file___148 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___148 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___148 *, struct iov_iter___81 *);
	ssize_t (*write_iter)(struct kiocb___148 *, struct iov_iter___81 *);
	int (*iopoll)(struct kiocb___148 *, bool);
	int (*iterate)(struct file___148 *, struct dir_context *);
	int (*iterate_shared)(struct file___148 *, struct dir_context *);
	__poll_t (*poll)(struct file___148 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___148 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___148 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___148 *, struct vm_area_struct___153 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___148 *, struct file___148 *);
	int (*flush)(struct file___148 *, fl_owner_t);
	int (*release)(struct inode___148 *, struct file___148 *);
	int (*fsync)(struct file___148 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___148 *, int);
	int (*lock)(struct file___148 *, int, struct file_lock___148 *);
	ssize_t (*sendpage)(struct file___148 *, struct page___153 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___148 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___148 *, long unsigned int);
	int (*flock)(struct file___148 *, int, struct file_lock___148 *);
	ssize_t (*splice_write)(struct pipe_inode_info___45 *, struct file___148 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___148 *, loff_t *, struct pipe_inode_info___45 *, size_t, unsigned int);
	int (*setlease)(struct file___148 *, long int, struct file_lock___148 **, void **);
	long int (*fallocate)(struct file___148 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___126 *, struct file___148 *);
	ssize_t (*copy_file_range)(struct file___148 *, loff_t, struct file___148 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___148 *, loff_t, struct file___148 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___148 *, loff_t, loff_t, int);
};

struct vmacache___153 {
	u64 seqnum;
	struct vm_area_struct___153 *vmas[4];
};

struct page_frag___153 {
	struct page___153 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___154;

struct pid___130;

struct cred___21;

struct key___5;

struct nsproxy___139;

struct signal_struct___149;

struct vm_struct___132;

struct task_struct___155 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___155 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___154 *mm;
	struct mm_struct___154 *active_mm;
	struct vmacache___153 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___155 *real_parent;
	struct task_struct___155 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___155 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___130 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___21 *ptracer_cred;
	const struct cred___21 *real_cred;
	const struct cred___21 *cred;
	struct key___5 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___139 *nsproxy;
	struct signal_struct___149 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___155 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___45 *splice_pipe;
	struct page_frag___153 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___155 *oom_reaper_list;
	struct vm_struct___132 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___68 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___136;

struct kobj_type___136;

struct kernfs_node___136;

struct kobject___136 {
	const char *name;
	struct list_head entry;
	struct kobject___136 *parent;
	struct kset___136 *kset;
	struct kobj_type___136 *ktype;
	struct kernfs_node___136 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___133 {
	struct kobject___136 kobj;
	struct module___134 *mod;
	struct kobject___136 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___133 {
	struct module___134 *mod;
	struct latch_tree_node node;
};

struct module_layout___133 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___133 mtn;
};

struct module_attribute___133;

struct kernel_param___133;

struct module___134 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___133 mkobj;
	struct module_attribute___133 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___136 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___133 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___133 core_layout;
	struct module_layout___133 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___130;

struct upid___130 {
	int nr;
	struct pid_namespace___130 *ns;
};

struct user_namespace___21;

struct ucounts___21;

struct pid_namespace___130 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___155 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___130 *parent;
	struct fs_pin *bacct;
	struct user_namespace___21 *user_ns;
	struct ucounts___21 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___130 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___130 numbers[1];
};

struct user_namespace___21 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___21 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___26 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___5 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___5 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___21 *ucounts;
	long int ucount_max[16];
};

typedef struct page___153 *pgtable_t___153;

struct address_space___148;

struct page_pool___36;

struct dev_pagemap___144;

struct page___153 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___148 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___36 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___153 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___153 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___154 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___144 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___21 {
	struct hlist_node node;
	struct user_namespace___21 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___144;

struct vm_area_struct___153 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___153 *vm_next;
	struct vm_area_struct___153 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___154 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___144 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___148 *vm_file;
	struct file___148 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___149 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___155 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___155 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___130 *pids[4];
	struct pid___130 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___154 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___153;

struct mm_struct___154 {
	struct {
		struct vm_area_struct___153 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___148 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___153 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___155 *owner;
		struct user_namespace___21 *user_ns;
		struct file___148 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___21 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___5 *session_keyring;
	struct key___5 *process_keyring;
	struct key___5 *thread_keyring;
	struct key___5 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___21 *user_ns;
	struct ucounts___21 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct key_type___3;

struct keyring_index_key___3 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___3 *type;
	struct key_tag *domain_tag;
	const char *description;
};

struct watch_list___3;

struct key_restriction___4;

struct key___5 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list___3 *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___3 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___3 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___4 *restrict_link;
};

struct net___27;

struct nsproxy___139 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___130 *pid_ns_for_children;
	struct net___27 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___148;

struct pipe_buffer___45;

struct pipe_inode_info___45 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___153 *tmp_page;
	struct fasync_struct___148 *fasync_readers;
	struct fasync_struct___148 *fasync_writers;
	struct pipe_buffer___45 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___132 {
	struct vm_struct___132 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___153 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___148;

struct address_space___148 {
	struct inode___148 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___148 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___106;

struct page_pool_params___36 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___106 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___36 {
	u32 count;
	struct page___153 *cache[128];
};

struct page_pool___36 {
	struct page_pool_params___36 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___153 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___36 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___144;

struct dev_pagemap___144 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___144 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___148;

struct path___148 {
	struct vfsmount___148 *mnt;
	struct dentry___148 *dentry;
};

struct fown_struct___130 {
	rwlock_t lock;
	struct pid___130 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___148 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___148 f_path;
	struct inode___148 *f_inode;
	const struct file_operations___148 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___130 f_owner;
	const struct cred___21 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___148 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___144;

struct vm_operations_struct___144 {
	void (*open)(struct vm_area_struct___153 *);
	void (*close)(struct vm_area_struct___153 *);
	int (*may_split)(struct vm_area_struct___153 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___153 *);
	int (*mprotect)(struct vm_area_struct___153 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___144 *);
	vm_fault_t (*huge_fault)(struct vm_fault___144 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___144 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___153 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___144 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___144 *);
	int (*access)(struct vm_area_struct___153 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___153 *);
	int (*set_policy)(struct vm_area_struct___153 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___153 *, long unsigned int);
	struct page___153 * (*find_special_page)(struct vm_area_struct___153 *, long unsigned int);
};

struct core_thread___153 {
	struct task_struct___155 *task;
	struct core_thread___153 *next;
};

struct core_state___153 {
	atomic_t nr_threads;
	struct core_thread___153 dumper;
	struct completion startup;
};

struct vm_fault___144 {
	const struct {
		struct vm_area_struct___153 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___153 *cow_page;
	struct page___153 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___153 prealloc_pte;
};

struct assoc_array_ops {
	long unsigned int (*get_key_chunk)(const void *, int);
	long unsigned int (*get_object_key_chunk)(const void *, int);
	bool (*compare_object)(const void *, const void *);
	int (*diff_objects)(const void *, const void *);
	void (*free_object)(void *);
};

typedef int (*request_key_actor_t___3)(struct key___5 *, void *);

struct key_match_data___3;

struct kernel_pkey_params___3;

struct key_type___3 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___5 *, struct key_preparsed_payload *);
	int (*update)(struct key___5 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___3 *);
	void (*match_free)(struct key_match_data___3 *);
	void (*revoke)(struct key___5 *);
	void (*destroy)(struct key___5 *);
	void (*describe)(const struct key___5 *, struct seq_file___126 *);
	long int (*read)(const struct key___5 *, char *, size_t);
	request_key_actor_t___3 request_key;
	struct key_restriction___4 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___3 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___3 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___3 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___5)(struct key___5 *, const struct key_type___3 *, const union key_payload *, struct key___5 *);

struct key_restriction___4 {
	key_restrict_link_func_t___5 check;
	struct key___5 *key;
	struct key_type___3 *keytype;
};

struct watch___3;

struct watch_list___3 {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch___3 *);
	spinlock_t lock;
};

struct dentry_operations___148;

struct dentry___148 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___148 *d_parent;
	struct qstr d_name;
	struct inode___148 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___148 *d_op;
	struct super_block___148 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___148;

struct inode___148 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___148 *i_op;
	struct super_block___148 *i_sb;
	struct address_space___148 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___148 *i_fop;
		void (*free_inode)(struct inode___148 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___148 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___45 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___148 {
	int (*d_revalidate)(struct dentry___148 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___148 *, unsigned int);
	int (*d_hash)(const struct dentry___148 *, struct qstr *);
	int (*d_compare)(const struct dentry___148 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___148 *);
	int (*d_init)(struct dentry___148 *);
	void (*d_release)(struct dentry___148 *);
	void (*d_prune)(struct dentry___148 *);
	void (*d_iput)(struct dentry___148 *, struct inode___148 *);
	char * (*d_dname)(struct dentry___148 *, char *, int);
	struct vfsmount___148 * (*d_automount)(struct path___148 *);
	int (*d_manage)(const struct path___148 *, bool);
	struct dentry___148 * (*d_real)(struct dentry___148 *, const struct inode___148 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___148;

struct mem_dqinfo___148 {
	struct quota_format_type___148 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___148;

struct quota_info___148 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___148 *files[3];
	struct mem_dqinfo___148 info[3];
	const struct quota_format_ops___148 *ops[3];
};

struct rcuwait___149 {
	struct task_struct___155 *task;
};

struct percpu_rw_semaphore___149 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___149 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___148 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___149 rw_sem[3];
};

struct super_operations___148;

struct dquot_operations___148;

struct quotactl_ops___148;

struct super_block___148 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___148 *s_type;
	const struct super_operations___148 *s_op;
	const struct dquot_operations___148 *dq_op;
	const struct quotactl_ops___148 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___148 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___5 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___148 s_dquot;
	struct sb_writers___148 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___148 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___21 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___148 {
	struct dentry___148 *mnt_root;
	struct super_block___148 *mnt_sb;
	int mnt_flags;
	struct user_namespace___21 *mnt_userns;
};

struct kiocb___148 {
	struct file___148 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___148 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___148 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___148 *ia_file;
};

struct dquot___148 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___148 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___148 {
	int qf_fmt_id;
	const struct quota_format_ops___148 *qf_ops;
	struct module___134 *qf_owner;
	struct quota_format_type___148 *qf_next;
};

struct quota_format_ops___148 {
	int (*check_quota_file)(struct super_block___148 *, int);
	int (*read_file_info)(struct super_block___148 *, int);
	int (*write_file_info)(struct super_block___148 *, int);
	int (*free_file_info)(struct super_block___148 *, int);
	int (*read_dqblk)(struct dquot___148 *);
	int (*commit_dqblk)(struct dquot___148 *);
	int (*release_dqblk)(struct dquot___148 *);
	int (*get_next_id)(struct super_block___148 *, struct kqid *);
};

struct dquot_operations___148 {
	int (*write_dquot)(struct dquot___148 *);
	struct dquot___148 * (*alloc_dquot)(struct super_block___148 *, int);
	void (*destroy_dquot)(struct dquot___148 *);
	int (*acquire_dquot)(struct dquot___148 *);
	int (*release_dquot)(struct dquot___148 *);
	int (*mark_dirty)(struct dquot___148 *);
	int (*write_info)(struct super_block___148 *, int);
	qsize_t * (*get_reserved_space)(struct inode___148 *);
	int (*get_projid)(struct inode___148 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___148 *, qsize_t *);
	int (*get_next_id)(struct super_block___148 *, struct kqid *);
};

struct quotactl_ops___148 {
	int (*quota_on)(struct super_block___148 *, int, int, const struct path___148 *);
	int (*quota_off)(struct super_block___148 *, int);
	int (*quota_enable)(struct super_block___148 *, unsigned int);
	int (*quota_disable)(struct super_block___148 *, unsigned int);
	int (*quota_sync)(struct super_block___148 *, int);
	int (*set_info)(struct super_block___148 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___148 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___148 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___148 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___148 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___148 *, unsigned int);
};

struct address_space_operations___148 {
	int (*writepage)(struct page___153 *, struct writeback_control___3 *);
	int (*readpage)(struct file___148 *, struct page___153 *);
	int (*writepages)(struct address_space___148 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___153 *);
	int (*readpages)(struct file___148 *, struct address_space___148 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___148 *, struct address_space___148 *, loff_t, unsigned int, unsigned int, struct page___153 **, void **);
	int (*write_end)(struct file___148 *, struct address_space___148 *, loff_t, unsigned int, unsigned int, struct page___153 *, void *);
	sector_t (*bmap)(struct address_space___148 *, sector_t);
	void (*invalidatepage)(struct page___153 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___153 *, gfp_t);
	void (*freepage)(struct page___153 *);
	ssize_t (*direct_IO)(struct kiocb___148 *, struct iov_iter___81 *);
	int (*migratepage)(struct address_space___148 *, struct page___153 *, struct page___153 *, enum migrate_mode);
	bool (*isolate_page)(struct page___153 *, isolate_mode_t);
	void (*putback_page)(struct page___153 *);
	int (*launder_page)(struct page___153 *);
	int (*is_partially_uptodate)(struct page___153 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___153 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___148 *, struct page___153 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___148 *, sector_t *);
	void (*swap_deactivate)(struct file___148 *);
};

struct bio_vec___79;

struct iov_iter___81 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___79 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___45 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___148 {
	struct dentry___148 * (*lookup)(struct inode___148 *, struct dentry___148 *, unsigned int);
	const char * (*get_link)(struct dentry___148 *, struct inode___148 *, struct delayed_call *);
	int (*permission)(struct user_namespace___21 *, struct inode___148 *, int);
	struct posix_acl * (*get_acl)(struct inode___148 *, int, bool);
	int (*readlink)(struct dentry___148 *, char *, int);
	int (*create)(struct user_namespace___21 *, struct inode___148 *, struct dentry___148 *, umode_t, bool);
	int (*link)(struct dentry___148 *, struct inode___148 *, struct dentry___148 *);
	int (*unlink)(struct inode___148 *, struct dentry___148 *);
	int (*symlink)(struct user_namespace___21 *, struct inode___148 *, struct dentry___148 *, const char *);
	int (*mkdir)(struct user_namespace___21 *, struct inode___148 *, struct dentry___148 *, umode_t);
	int (*rmdir)(struct inode___148 *, struct dentry___148 *);
	int (*mknod)(struct user_namespace___21 *, struct inode___148 *, struct dentry___148 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___21 *, struct inode___148 *, struct dentry___148 *, struct inode___148 *, struct dentry___148 *, unsigned int);
	int (*setattr)(struct user_namespace___21 *, struct dentry___148 *, struct iattr___148 *);
	int (*getattr)(struct user_namespace___21 *, const struct path___148 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___148 *, char *, size_t);
	int (*fiemap)(struct inode___148 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___148 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___148 *, struct dentry___148 *, struct file___148 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___21 *, struct inode___148 *, struct dentry___148 *, umode_t);
	int (*set_acl)(struct user_namespace___21 *, struct inode___148 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___21 *, struct dentry___148 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___148 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___148 {
	void (*fl_copy_lock)(struct file_lock___148 *, struct file_lock___148 *);
	void (*fl_release_private)(struct file_lock___148 *);
};

struct lock_manager_operations___148;

struct file_lock___148 {
	struct file_lock___148 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___148 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___148 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___148 *fl_ops;
	const struct lock_manager_operations___148 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___148 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___148 *);
	int (*lm_grant)(struct file_lock___148 *, int);
	bool (*lm_break)(struct file_lock___148 *);
	int (*lm_change)(struct file_lock___148 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___148 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___148 *);
};

struct fasync_struct___148 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___148 *fa_next;
	struct file___148 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___148 {
	struct inode___148 * (*alloc_inode)(struct super_block___148 *);
	void (*destroy_inode)(struct inode___148 *);
	void (*free_inode)(struct inode___148 *);
	void (*dirty_inode)(struct inode___148 *, int);
	int (*write_inode)(struct inode___148 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___148 *);
	void (*evict_inode)(struct inode___148 *);
	void (*put_super)(struct super_block___148 *);
	int (*sync_fs)(struct super_block___148 *, int);
	int (*freeze_super)(struct super_block___148 *);
	int (*freeze_fs)(struct super_block___148 *);
	int (*thaw_super)(struct super_block___148 *);
	int (*unfreeze_fs)(struct super_block___148 *);
	int (*statfs)(struct dentry___148 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___148 *, int *, char *);
	void (*umount_begin)(struct super_block___148 *);
	int (*show_options)(struct seq_file___126 *, struct dentry___148 *);
	int (*show_devname)(struct seq_file___126 *, struct dentry___148 *);
	int (*show_path)(struct seq_file___126 *, struct dentry___148 *);
	int (*show_stats)(struct seq_file___126 *, struct dentry___148 *);
	ssize_t (*quota_read)(struct super_block___148 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___148 *, int, const char *, size_t, loff_t);
	struct dquot___148 ** (*get_dquots)(struct inode___148 *);
	long int (*nr_cached_objects)(struct super_block___148 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___148 *, struct shrink_control___54 *);
	struct file___148 * (*real_loop)(struct file___148 *);
};

struct seq_operations___126;

struct seq_file___126 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___126 *op;
	int poll_event;
	const struct file___148 *file;
	void *private;
};

struct dev_pagemap_ops___144 {
	void (*page_free)(struct page___153 *);
	void (*kill)(struct dev_pagemap___144 *);
	void (*cleanup)(struct dev_pagemap___144 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___144 *);
};

struct seq_operations___126 {
	void * (*start)(struct seq_file___126 *, loff_t *);
	void (*stop)(struct seq_file___126 *, void *);
	void * (*next)(struct seq_file___126 *, void *, loff_t *);
	int (*show)(struct seq_file___126 *, void *);
};

struct fqdir___26;

struct netns_ipv4___26 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___26 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___26 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___26 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___24 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___24 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___24 *);
	int (*local_out)(struct net___27 *, struct sock *, struct sk_buff___24 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___24 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___26 {
	struct dst_ops___26 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___26 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___26 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___26 *fqdir;
};

struct netns_xfrm___26 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___26 xfrm4_dst_ops;
	struct dst_ops___26 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___27 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___21 *user_ns;
	struct ucounts___21 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___26 ipv4;
	struct netns_ipv6___26 ipv6;
	struct netns_ieee802154_lowpan___26 ieee802154_lowpan;
	struct netns_sctp___15 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___22 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___22 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___26 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct assoc_array_node {
	struct assoc_array_ptr *back_pointer;
	u8 parent_slot;
	struct assoc_array_ptr *slots[16];
	long unsigned int nr_leaves_on_branch;
};

struct assoc_array_shortcut {
	struct assoc_array_ptr *back_pointer;
	int parent_slot;
	int skip_to_level;
	struct assoc_array_ptr *next_node;
	long unsigned int index_key[0];
};

struct assoc_array_edit___2 {
	struct callback_head rcu;
	struct assoc_array *array;
	const struct assoc_array_ops *ops;
	const struct assoc_array_ops *ops_for_excised_subtree;
	struct assoc_array_ptr *leaf;
	struct assoc_array_ptr **leaf_p;
	struct assoc_array_ptr *dead_leaf;
	struct assoc_array_ptr *new_meta[3];
	struct assoc_array_ptr *excised_meta[1];
	struct assoc_array_ptr *excised_subtree;
	struct assoc_array_ptr **set_backpointers[16];
	struct assoc_array_ptr *set_backpointers_to;
	struct assoc_array_node *adjust_count_on;
	long int adjust_count_by;
	struct {
		struct assoc_array_ptr **ptr;
		struct assoc_array_ptr *to;
	} set[2];
	struct {
		u8 *p;
		u8 to;
	} set_parent_slot[1];
	u8 segment_cache[17];
};

struct bio_vec___79 {
	struct page___153 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct inet_frags___26;

struct fqdir___26 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___26 *f;
	struct net___27 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___26;

struct inet_frags___26 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___26 *, const void *);
	void (*destructor)(struct inet_frag_queue___26 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___26 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___24 *fragments_tail;
	struct sk_buff___24 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___26 *fqdir;
	struct callback_head rcu;
};

struct fwnode_operations___106;

struct fwnode_handle___106 {
	struct fwnode_handle___106 *secondary;
	const struct fwnode_operations___106 *ops;
	struct device___106 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___106;

struct fwnode_endpoint___106;

struct fwnode_operations___106 {
	struct fwnode_handle___106 * (*get)(struct fwnode_handle___106 *);
	void (*put)(struct fwnode_handle___106 *);
	bool (*device_is_available)(const struct fwnode_handle___106 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___106 *, const struct device___106 *);
	bool (*property_present)(const struct fwnode_handle___106 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___106 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___106 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___106 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*get_parent)(const struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*get_next_child_node)(const struct fwnode_handle___106 *, struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*get_named_child_node)(const struct fwnode_handle___106 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___106 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___106 *);
	struct fwnode_handle___106 * (*graph_get_next_endpoint)(const struct fwnode_handle___106 *, struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*graph_get_remote_endpoint)(const struct fwnode_handle___106 *);
	struct fwnode_handle___106 * (*graph_get_port_parent)(struct fwnode_handle___106 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___106 *, struct fwnode_endpoint___106 *);
	int (*add_links)(struct fwnode_handle___106 *);
};

struct wakeup_source___106;

struct dev_pm_info___106 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___106 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___106 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___106;

struct bus_type___106;

struct device_driver___106;

struct dev_pm_domain___106;

struct class___106;

struct attribute_group___136;

struct device___106 {
	struct kobject___136 kobj;
	struct device___106 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___106 *type;
	struct bus_type___106 *bus;
	struct device_driver___106 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___106 power;
	struct dev_pm_domain___106 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___106 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___106 *class;
	const struct attribute_group___136 **groups;
	void (*release)(struct device___106 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___106 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___106 *local_fwnode;
};

struct fwnode_reference_args___106 {
	struct fwnode_handle___106 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___136;

struct kernfs_elem_dir___136 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___136 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___136;

struct kernfs_root___136 {
	struct kernfs_node___136 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___136 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___136 {
	struct kernfs_node___136 *target_kn;
};

struct kernfs_ops___136;

struct kernfs_elem_attr___136 {
	const struct kernfs_ops___136 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___136 *notify_next;
};

struct kernfs_node___136 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___136 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___136 dir;
		struct kernfs_elem_symlink___136 symlink;
		struct kernfs_elem_attr___136 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___136;

struct kernfs_ops___136 {
	int (*open)(struct kernfs_open_file___136 *);
	void (*release)(struct kernfs_open_file___136 *);
	int (*seq_show)(struct seq_file___126 *, void *);
	void * (*seq_start)(struct seq_file___126 *, loff_t *);
	void * (*seq_next)(struct seq_file___126 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___126 *, void *);
	ssize_t (*read)(struct kernfs_open_file___136 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___136 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___136 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___136 *, struct vm_area_struct___153 *);
};

struct kernfs_syscall_ops___136 {
	int (*show_options)(struct seq_file___126 *, struct kernfs_root___136 *);
	int (*mkdir)(struct kernfs_node___136 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___136 *);
	int (*rename)(struct kernfs_node___136 *, struct kernfs_node___136 *, const char *);
	int (*show_path)(struct seq_file___126 *, struct kernfs_node___136 *, struct kernfs_root___136 *);
};

struct kernfs_open_file___136 {
	struct kernfs_node___136 *kn;
	struct file___148 *file;
	struct seq_file___126 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___144 *vm_ops;
};

struct bin_attribute___136;

struct attribute_group___136 {
	const char *name;
	umode_t (*is_visible)(struct kobject___136 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___136 *, struct bin_attribute___136 *, int);
	struct attribute **attrs;
	struct bin_attribute___136 **bin_attrs;
};

struct bin_attribute___136 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___148 * (*f_mapping)();
	ssize_t (*read)(struct file___148 *, struct kobject___136 *, struct bin_attribute___136 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___148 *, struct kobject___136 *, struct bin_attribute___136 *, char *, loff_t, size_t);
	int (*mmap)(struct file___148 *, struct kobject___136 *, struct bin_attribute___136 *, struct vm_area_struct___153 *);
};

struct sysfs_ops___136 {
	ssize_t (*show)(struct kobject___136 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___136 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___136;

struct kset___136 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___136 kobj;
	const struct kset_uevent_ops___136 *uevent_ops;
};

struct kobj_type___136 {
	void (*release)(struct kobject___136 *);
	const struct sysfs_ops___136 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___136 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___136 *);
	const void * (*namespace)(struct kobject___136 *);
	void (*get_ownership)(struct kobject___136 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___136 {
	int (* const filter)(struct kset___136 *, struct kobject___136 *);
	const char * (* const name)(struct kset___136 *, struct kobject___136 *);
	int (* const uevent)(struct kset___136 *, struct kobject___136 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___133 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___133 *);
	int (*get)(char *, const struct kernel_param___133 *);
	void (*free)(void *);
};

struct kparam_array___133;

struct kernel_param___133 {
	const char *name;
	struct module___134 *mod;
	const struct kernel_param_ops___133 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___133 *arr;
	};
};

struct kparam_array___133 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___133 *ops;
	void *elem;
};

struct module_attribute___133 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___133 *, struct module_kobject___133 *, char *);
	ssize_t (*store)(struct module_attribute___133 *, struct module_kobject___133 *, const char *, size_t);
	void (*setup)(struct module___134 *, const char *);
	int (*test)(struct module___134 *);
	void (*free)(struct module___134 *);
};

struct dev_pm_ops___106 {
	int (*prepare)(struct device___106 *);
	void (*complete)(struct device___106 *);
	int (*suspend)(struct device___106 *);
	int (*resume)(struct device___106 *);
	int (*freeze)(struct device___106 *);
	int (*thaw)(struct device___106 *);
	int (*poweroff)(struct device___106 *);
	int (*restore)(struct device___106 *);
	int (*suspend_late)(struct device___106 *);
	int (*resume_early)(struct device___106 *);
	int (*freeze_late)(struct device___106 *);
	int (*thaw_early)(struct device___106 *);
	int (*poweroff_late)(struct device___106 *);
	int (*restore_early)(struct device___106 *);
	int (*suspend_noirq)(struct device___106 *);
	int (*resume_noirq)(struct device___106 *);
	int (*freeze_noirq)(struct device___106 *);
	int (*thaw_noirq)(struct device___106 *);
	int (*poweroff_noirq)(struct device___106 *);
	int (*restore_noirq)(struct device___106 *);
	int (*runtime_suspend)(struct device___106 *);
	int (*runtime_resume)(struct device___106 *);
	int (*runtime_idle)(struct device___106 *);
};

struct wakeup_source___106 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___106 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___106 {
	struct dev_pm_ops___106 ops;
	int (*start)(struct device___106 *);
	void (*detach)(struct device___106 *, bool);
	int (*activate)(struct device___106 *);
	void (*sync)(struct device___106 *);
	void (*dismiss)(struct device___106 *);
};

struct bus_type___106 {
	const char *name;
	const char *dev_name;
	struct device___106 *dev_root;
	const struct attribute_group___136 **bus_groups;
	const struct attribute_group___136 **dev_groups;
	const struct attribute_group___136 **drv_groups;
	int (*match)(struct device___106 *, struct device_driver___106 *);
	int (*uevent)(struct device___106 *, struct kobj_uevent_env *);
	int (*probe)(struct device___106 *);
	void (*sync_state)(struct device___106 *);
	void (*remove)(struct device___106 *);
	void (*shutdown)(struct device___106 *);
	int (*online)(struct device___106 *);
	int (*offline)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	int (*num_vf)(struct device___106 *);
	int (*dma_configure)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___106 {
	const char *name;
	struct bus_type___106 *bus;
	struct module___134 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___106 *);
	void (*sync_state)(struct device___106 *);
	int (*remove)(struct device___106 *);
	void (*shutdown)(struct device___106 *);
	int (*suspend)(struct device___106 *, pm_message_t);
	int (*resume)(struct device___106 *);
	const struct attribute_group___136 **groups;
	const struct attribute_group___136 **dev_groups;
	const struct dev_pm_ops___106 *pm;
	void (*coredump)(struct device___106 *);
	struct driver_private *p;
};

struct device_type___106 {
	const char *name;
	const struct attribute_group___136 **groups;
	int (*uevent)(struct device___106 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___106 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___106 *);
	const struct dev_pm_ops___106 *pm;
};

struct class___106 {
	const char *name;
	struct module___134 *owner;
	const struct attribute_group___136 **class_groups;
	const struct attribute_group___136 **dev_groups;
	struct kobject___136 *dev_kobj;
	int (*dev_uevent)(struct device___106 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___106 *, umode_t *);
	void (*class_release)(struct class___106 *);
	void (*dev_release)(struct device___106 *);
	int (*shutdown_pre)(struct device___106 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___106 *);
	void (*get_ownership)(struct device___106 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___106 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___45;

struct pipe_buffer___45 {
	struct page___153 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___45 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___45 {
	int (*confirm)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
	void (*release)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
	bool (*try_steal)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
	bool (*get)(struct pipe_inode_info___45 *, struct pipe_buffer___45 *);
};

struct watch_queue {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___45 *pipe;
	struct hlist_head watches;
	struct page___153 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

struct key_match_data___3 {
	bool (*cmp)(const struct key___5 *, const struct key_match_data___3 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct kernel_pkey_params___3 {
	struct key___5 *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct watch___3 {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue *queue;
	struct hlist_node queue_node;
	struct watch_list___3 *watch_list;
	struct hlist_node list_node;
	const struct cred___21 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

struct keyring_search_context {
	struct keyring_index_key___3 index_key;
	const struct cred___21 *cred;
	struct key_match_data___3 match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	time64_t now;
};

struct keyring_read_iterator_context {
	size_t buflen;
	size_t count;
	key_serial_t *buffer;
};

struct dentry___149;

struct super_block___149;

struct module___135;

struct file_system_type___149 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___149 * (*mount)(struct file_system_type___149 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___149 *);
	struct module___135 *owner;
	struct file_system_type___149 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___149;

struct kiocb___149;

struct poll_table_struct___93;

struct vm_area_struct___154;

struct inode___149;

struct file_lock___149;

struct page___154;

struct seq_file___127;

struct file_operations___149 {
	struct module___135 *owner;
	loff_t (*llseek)(struct file___149 *, loff_t, int);
	ssize_t (*read)(struct file___149 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___149 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___149 *, struct iov_iter___81 *);
	ssize_t (*write_iter)(struct kiocb___149 *, struct iov_iter___81 *);
	int (*iopoll)(struct kiocb___149 *, bool);
	int (*iterate)(struct file___149 *, struct dir_context *);
	int (*iterate_shared)(struct file___149 *, struct dir_context *);
	__poll_t (*poll)(struct file___149 *, struct poll_table_struct___93 *);
	long int (*unlocked_ioctl)(struct file___149 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___149 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___149 *, struct vm_area_struct___154 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___149 *, struct file___149 *);
	int (*flush)(struct file___149 *, fl_owner_t);
	int (*release)(struct inode___149 *, struct file___149 *);
	int (*fsync)(struct file___149 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___149 *, int);
	int (*lock)(struct file___149 *, int, struct file_lock___149 *);
	ssize_t (*sendpage)(struct file___149 *, struct page___154 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___149 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___149 *, long unsigned int);
	int (*flock)(struct file___149 *, int, struct file_lock___149 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___149 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___149 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___149 *, long int, struct file_lock___149 **, void **);
	long int (*fallocate)(struct file___149 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___127 *, struct file___149 *);
	ssize_t (*copy_file_range)(struct file___149 *, loff_t, struct file___149 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___149 *, loff_t, struct file___149 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___149 *, loff_t, loff_t, int);
};

struct vmacache___154 {
	u64 seqnum;
	struct vm_area_struct___154 *vmas[4];
};

struct page_frag___154 {
	struct page___154 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___69;

struct debug_info___69 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___69 *hbp_break[16];
	struct perf_event___69 *hbp_watch[16];
};

struct thread_struct___69 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___69 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___155;

struct pid___131;

struct cred___22;

struct key___6;

struct nsproxy___140;

struct signal_struct___150;

struct css_set___102;

struct perf_event_context___69;

struct vm_struct___133;

struct task_struct___156 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___156 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___155 *mm;
	struct mm_struct___155 *active_mm;
	struct vmacache___154 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___156 *real_parent;
	struct task_struct___156 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___156 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___131 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___22 *ptracer_cred;
	const struct cred___22 *real_cred;
	const struct cred___22 *cred;
	struct key___6 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___140 *nsproxy;
	struct signal_struct___150 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___156 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___102 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___69 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___154 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___156 *oom_reaper_list;
	struct vm_struct___133 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___137;

struct kobj_type___137;

struct kernfs_node___137;

struct kobject___137 {
	const char *name;
	struct list_head entry;
	struct kobject___137 *parent;
	struct kset___137 *kset;
	struct kobj_type___137 *ktype;
	struct kernfs_node___137 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___134 {
	struct kobject___137 kobj;
	struct module___135 *mod;
	struct kobject___137 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___134 {
	struct module___135 *mod;
	struct latch_tree_node node;
};

struct module_layout___134 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___134 mtn;
};

struct module_attribute___134;

struct kernel_param___134;

struct trace_event_call___63;

struct module___135 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___134 mkobj;
	struct module_attribute___134 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___137 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___134 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___134 core_layout;
	struct module_layout___134 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___63 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___69 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___156 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___69)(struct perf_event___69 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___69;

struct fasync_struct___149;

struct pid_namespace___131;

struct perf_cgroup___69;

struct perf_event___69 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___69 *group_leader;
	struct pmu___69 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___69 hw;
	struct perf_event_context___69 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___69 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___156 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___149 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___69 *aux_event;
	void (*destroy)(struct perf_event___69 *);
	struct callback_head callback_head;
	struct pid_namespace___131 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___69 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___69 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___63 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___69 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___131 {
	int nr;
	struct pid_namespace___131 *ns;
};

struct user_namespace___22;

struct ucounts___22;

struct pid_namespace___131 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___156 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___131 *parent;
	struct fs_pin *bacct;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___131 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___131 numbers[1];
};

struct user_namespace___22 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___22 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___26 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___6 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___6 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___22 *ucounts;
	long int ucount_max[16];
};

typedef struct page___154 *pgtable_t___154;

struct address_space___149;

struct dev_pagemap___145;

struct page___154 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___149 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___36 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___154 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___154 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___155 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___145 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___22 {
	struct hlist_node node;
	struct user_namespace___22 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___145;

struct vm_area_struct___154 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___154 *vm_next;
	struct vm_area_struct___154 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___155 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___145 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___149 *vm_file;
	struct file___149 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___150 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___156 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___156 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___131 *pids[4];
	struct pid___131 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___155 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___154;

struct mm_struct___155 {
	struct {
		struct vm_area_struct___154 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___149 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___154 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___156 *owner;
		struct user_namespace___22 *user_ns;
		struct file___149 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___22 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___6 *session_keyring;
	struct key___6 *process_keyring;
	struct key___6 *thread_keyring;
	struct key___6 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct key_type___4;

struct keyring_index_key___4 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___4 *type;
	struct key_tag *domain_tag;
	const char *description;
};

struct watch_list___4;

struct key_restriction___5;

struct key___6 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list___4 *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___4 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___4 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___5 *restrict_link;
};

struct cgroup_namespace___102;

struct nsproxy___140 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___131 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___102 *cgroup_ns;
};

struct cgroup_subsys_state___102;

struct cgroup___102;

struct css_set___102 {
	struct cgroup_subsys_state___102 *subsys[14];
	refcount_t refcount;
	struct css_set___102 *dom_cset;
	struct cgroup___102 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___102 *mg_src_cgrp;
	struct cgroup___102 *mg_dst_cgrp;
	struct css_set___102 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___69 {
	struct pmu___69 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___156 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___69 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___133 {
	struct vm_struct___133 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___154 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___149;

struct address_space___149 {
	struct inode___149 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___149 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___145;

struct dev_pagemap___145 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___145 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___149;

struct path___149 {
	struct vfsmount___149 *mnt;
	struct dentry___149 *dentry;
};

struct fown_struct___131 {
	rwlock_t lock;
	struct pid___131 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___149 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___149 f_path;
	struct inode___149 *f_inode;
	const struct file_operations___149 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___131 f_owner;
	const struct cred___22 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___149 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___145;

struct vm_operations_struct___145 {
	void (*open)(struct vm_area_struct___154 *);
	void (*close)(struct vm_area_struct___154 *);
	int (*may_split)(struct vm_area_struct___154 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___154 *);
	int (*mprotect)(struct vm_area_struct___154 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___145 *);
	vm_fault_t (*huge_fault)(struct vm_fault___145 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___145 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___154 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___145 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___145 *);
	int (*access)(struct vm_area_struct___154 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___154 *);
	int (*set_policy)(struct vm_area_struct___154 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___154 *, long unsigned int);
	struct page___154 * (*find_special_page)(struct vm_area_struct___154 *, long unsigned int);
};

struct core_thread___154 {
	struct task_struct___156 *task;
	struct core_thread___154 *next;
};

struct core_state___154 {
	atomic_t nr_threads;
	struct core_thread___154 dumper;
	struct completion startup;
};

struct vm_fault___145 {
	const struct {
		struct vm_area_struct___154 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___154 *cow_page;
	struct page___154 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___154 prealloc_pte;
};

struct cgroup_subsys___102;

struct cgroup_subsys_state___102 {
	struct cgroup___102 *cgroup;
	struct cgroup_subsys___102 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___102 *parent;
};

struct cgroup_file___102 {
	struct kernfs_node___137 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___102 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___156 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___102;

struct cgroup_rstat_cpu___102;

struct cgroup___102 {
	struct cgroup_subsys_state___102 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___137 *kn;
	struct cgroup_file___102 procs_file;
	struct cgroup_file___102 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___102 *subsys[14];
	struct cgroup_root___102 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___102 *dom_cgrp;
	struct cgroup___102 *old_dom_cgrp;
	struct cgroup_rstat_cpu___102 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___102 psi;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct dentry_operations___149;

struct dentry___149 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___149 *d_parent;
	struct qstr d_name;
	struct inode___149 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___149 *d_op;
	struct super_block___149 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___149;

struct inode___149 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___149 *i_op;
	struct super_block___149 *i_sb;
	struct address_space___149 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___149 *i_fop;
		void (*free_inode)(struct inode___149 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___149 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___45 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___149 {
	int (*d_revalidate)(struct dentry___149 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___149 *, unsigned int);
	int (*d_hash)(const struct dentry___149 *, struct qstr *);
	int (*d_compare)(const struct dentry___149 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___149 *);
	int (*d_init)(struct dentry___149 *);
	void (*d_release)(struct dentry___149 *);
	void (*d_prune)(struct dentry___149 *);
	void (*d_iput)(struct dentry___149 *, struct inode___149 *);
	char * (*d_dname)(struct dentry___149 *, char *, int);
	struct vfsmount___149 * (*d_automount)(struct path___149 *);
	int (*d_manage)(const struct path___149 *, bool);
	struct dentry___149 * (*d_real)(struct dentry___149 *, const struct inode___149 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___149;

struct mem_dqinfo___149 {
	struct quota_format_type___149 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___149;

struct quota_info___149 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___149 *files[3];
	struct mem_dqinfo___149 info[3];
	const struct quota_format_ops___149 *ops[3];
};

struct rcuwait___150 {
	struct task_struct___156 *task;
};

struct percpu_rw_semaphore___150 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___150 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___149 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___150 rw_sem[3];
};

struct super_operations___149;

struct dquot_operations___149;

struct quotactl_ops___149;

struct super_block___149 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___149 *s_type;
	const struct super_operations___149 *s_op;
	const struct dquot_operations___149 *dq_op;
	const struct quotactl_ops___149 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___149 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___6 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___149 s_dquot;
	struct sb_writers___149 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___149 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___22 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___149 {
	struct dentry___149 *mnt_root;
	struct super_block___149 *mnt_sb;
	int mnt_flags;
	struct user_namespace___22 *mnt_userns;
};

typedef int (*request_key_actor_t___4)(struct key___6 *, void *);

struct key_match_data___4;

struct kernel_pkey_params___4;

struct key_type___4 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___6 *, struct key_preparsed_payload *);
	int (*update)(struct key___6 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___4 *);
	void (*match_free)(struct key_match_data___4 *);
	void (*revoke)(struct key___6 *);
	void (*destroy)(struct key___6 *);
	void (*describe)(const struct key___6 *, struct seq_file___127 *);
	long int (*read)(const struct key___6 *, char *, size_t);
	request_key_actor_t___4 request_key;
	struct key_restriction___5 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___4 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___4 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___4 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___6)(struct key___6 *, const struct key_type___4 *, const union key_payload *, struct key___6 *);

struct key_restriction___5 {
	key_restrict_link_func_t___6 check;
	struct key___6 *key;
	struct key_type___4 *keytype;
};

struct watch___4;

struct watch_list___4 {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch___4 *);
	spinlock_t lock;
};

struct kiocb___149 {
	struct file___149 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___149 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___149 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___149 *ia_file;
};

struct dquot___149 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___149 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___149 {
	int qf_fmt_id;
	const struct quota_format_ops___149 *qf_ops;
	struct module___135 *qf_owner;
	struct quota_format_type___149 *qf_next;
};

struct quota_format_ops___149 {
	int (*check_quota_file)(struct super_block___149 *, int);
	int (*read_file_info)(struct super_block___149 *, int);
	int (*write_file_info)(struct super_block___149 *, int);
	int (*free_file_info)(struct super_block___149 *, int);
	int (*read_dqblk)(struct dquot___149 *);
	int (*commit_dqblk)(struct dquot___149 *);
	int (*release_dqblk)(struct dquot___149 *);
	int (*get_next_id)(struct super_block___149 *, struct kqid *);
};

struct dquot_operations___149 {
	int (*write_dquot)(struct dquot___149 *);
	struct dquot___149 * (*alloc_dquot)(struct super_block___149 *, int);
	void (*destroy_dquot)(struct dquot___149 *);
	int (*acquire_dquot)(struct dquot___149 *);
	int (*release_dquot)(struct dquot___149 *);
	int (*mark_dirty)(struct dquot___149 *);
	int (*write_info)(struct super_block___149 *, int);
	qsize_t * (*get_reserved_space)(struct inode___149 *);
	int (*get_projid)(struct inode___149 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___149 *, qsize_t *);
	int (*get_next_id)(struct super_block___149 *, struct kqid *);
};

struct quotactl_ops___149 {
	int (*quota_on)(struct super_block___149 *, int, int, const struct path___149 *);
	int (*quota_off)(struct super_block___149 *, int);
	int (*quota_enable)(struct super_block___149 *, unsigned int);
	int (*quota_disable)(struct super_block___149 *, unsigned int);
	int (*quota_sync)(struct super_block___149 *, int);
	int (*set_info)(struct super_block___149 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___149 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___149 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___149 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___149 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___149 *, unsigned int);
};

struct address_space_operations___149 {
	int (*writepage)(struct page___154 *, struct writeback_control___3 *);
	int (*readpage)(struct file___149 *, struct page___154 *);
	int (*writepages)(struct address_space___149 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___154 *);
	int (*readpages)(struct file___149 *, struct address_space___149 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___149 *, struct address_space___149 *, loff_t, unsigned int, unsigned int, struct page___154 **, void **);
	int (*write_end)(struct file___149 *, struct address_space___149 *, loff_t, unsigned int, unsigned int, struct page___154 *, void *);
	sector_t (*bmap)(struct address_space___149 *, sector_t);
	void (*invalidatepage)(struct page___154 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___154 *, gfp_t);
	void (*freepage)(struct page___154 *);
	ssize_t (*direct_IO)(struct kiocb___149 *, struct iov_iter___81 *);
	int (*migratepage)(struct address_space___149 *, struct page___154 *, struct page___154 *, enum migrate_mode);
	bool (*isolate_page)(struct page___154 *, isolate_mode_t);
	void (*putback_page)(struct page___154 *);
	int (*launder_page)(struct page___154 *);
	int (*is_partially_uptodate)(struct page___154 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___154 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___149 *, struct page___154 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___149 *, sector_t *);
	void (*swap_deactivate)(struct file___149 *);
};

struct inode_operations___149 {
	struct dentry___149 * (*lookup)(struct inode___149 *, struct dentry___149 *, unsigned int);
	const char * (*get_link)(struct dentry___149 *, struct inode___149 *, struct delayed_call *);
	int (*permission)(struct user_namespace___22 *, struct inode___149 *, int);
	struct posix_acl * (*get_acl)(struct inode___149 *, int, bool);
	int (*readlink)(struct dentry___149 *, char *, int);
	int (*create)(struct user_namespace___22 *, struct inode___149 *, struct dentry___149 *, umode_t, bool);
	int (*link)(struct dentry___149 *, struct inode___149 *, struct dentry___149 *);
	int (*unlink)(struct inode___149 *, struct dentry___149 *);
	int (*symlink)(struct user_namespace___22 *, struct inode___149 *, struct dentry___149 *, const char *);
	int (*mkdir)(struct user_namespace___22 *, struct inode___149 *, struct dentry___149 *, umode_t);
	int (*rmdir)(struct inode___149 *, struct dentry___149 *);
	int (*mknod)(struct user_namespace___22 *, struct inode___149 *, struct dentry___149 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___22 *, struct inode___149 *, struct dentry___149 *, struct inode___149 *, struct dentry___149 *, unsigned int);
	int (*setattr)(struct user_namespace___22 *, struct dentry___149 *, struct iattr___149 *);
	int (*getattr)(struct user_namespace___22 *, const struct path___149 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___149 *, char *, size_t);
	int (*fiemap)(struct inode___149 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___149 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___149 *, struct dentry___149 *, struct file___149 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___22 *, struct inode___149 *, struct dentry___149 *, umode_t);
	int (*set_acl)(struct user_namespace___22 *, struct inode___149 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___22 *, struct dentry___149 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___149 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___149 {
	void (*fl_copy_lock)(struct file_lock___149 *, struct file_lock___149 *);
	void (*fl_release_private)(struct file_lock___149 *);
};

struct lock_manager_operations___149;

struct file_lock___149 {
	struct file_lock___149 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___149 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___149 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___149 *fl_ops;
	const struct lock_manager_operations___149 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___149 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___149 *);
	int (*lm_grant)(struct file_lock___149 *, int);
	bool (*lm_break)(struct file_lock___149 *);
	int (*lm_change)(struct file_lock___149 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___149 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___149 *);
};

struct fasync_struct___149 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___149 *fa_next;
	struct file___149 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___149 {
	struct inode___149 * (*alloc_inode)(struct super_block___149 *);
	void (*destroy_inode)(struct inode___149 *);
	void (*free_inode)(struct inode___149 *);
	void (*dirty_inode)(struct inode___149 *, int);
	int (*write_inode)(struct inode___149 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___149 *);
	void (*evict_inode)(struct inode___149 *);
	void (*put_super)(struct super_block___149 *);
	int (*sync_fs)(struct super_block___149 *, int);
	int (*freeze_super)(struct super_block___149 *);
	int (*freeze_fs)(struct super_block___149 *);
	int (*thaw_super)(struct super_block___149 *);
	int (*unfreeze_fs)(struct super_block___149 *);
	int (*statfs)(struct dentry___149 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___149 *, int *, char *);
	void (*umount_begin)(struct super_block___149 *);
	int (*show_options)(struct seq_file___127 *, struct dentry___149 *);
	int (*show_devname)(struct seq_file___127 *, struct dentry___149 *);
	int (*show_path)(struct seq_file___127 *, struct dentry___149 *);
	int (*show_stats)(struct seq_file___127 *, struct dentry___149 *);
	ssize_t (*quota_read)(struct super_block___149 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___149 *, int, const char *, size_t, loff_t);
	struct dquot___149 ** (*get_dquots)(struct inode___149 *);
	long int (*nr_cached_objects)(struct super_block___149 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___149 *, struct shrink_control___54 *);
	struct file___149 * (*real_loop)(struct file___149 *);
};

typedef void (*poll_queue_proc___95)(struct file___149 *, wait_queue_head_t *, struct poll_table_struct___93 *);

struct poll_table_struct___93 {
	poll_queue_proc___95 _qproc;
	__poll_t _key;
};

struct seq_operations___127;

struct seq_file___127 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___127 *op;
	int poll_event;
	const struct file___149 *file;
	void *private;
};

struct kernfs_root___137;

struct kernfs_elem_dir___137 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___137 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___137;

struct kernfs_root___137 {
	struct kernfs_node___137 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___137 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___137 {
	struct kernfs_node___137 *target_kn;
};

struct kernfs_ops___137;

struct kernfs_elem_attr___137 {
	const struct kernfs_ops___137 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___137 *notify_next;
};

struct kernfs_node___137 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___137 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___137 dir;
		struct kernfs_elem_symlink___137 symlink;
		struct kernfs_elem_attr___137 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___137;

struct kernfs_ops___137 {
	int (*open)(struct kernfs_open_file___137 *);
	void (*release)(struct kernfs_open_file___137 *);
	int (*seq_show)(struct seq_file___127 *, void *);
	void * (*seq_start)(struct seq_file___127 *, loff_t *);
	void * (*seq_next)(struct seq_file___127 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___127 *, void *);
	ssize_t (*read)(struct kernfs_open_file___137 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___137 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___137 *, struct poll_table_struct___93 *);
	int (*mmap)(struct kernfs_open_file___137 *, struct vm_area_struct___154 *);
};

struct kernfs_syscall_ops___137 {
	int (*show_options)(struct seq_file___127 *, struct kernfs_root___137 *);
	int (*mkdir)(struct kernfs_node___137 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___137 *);
	int (*rename)(struct kernfs_node___137 *, struct kernfs_node___137 *, const char *);
	int (*show_path)(struct seq_file___127 *, struct kernfs_node___137 *, struct kernfs_root___137 *);
};

struct kernfs_open_file___137 {
	struct kernfs_node___137 *kn;
	struct file___149 *file;
	struct seq_file___127 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___145 *vm_ops;
};

struct bin_attribute___137;

struct attribute_group___137 {
	const char *name;
	umode_t (*is_visible)(struct kobject___137 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___137 *, struct bin_attribute___137 *, int);
	struct attribute **attrs;
	struct bin_attribute___137 **bin_attrs;
};

struct bin_attribute___137 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___149 * (*f_mapping)();
	ssize_t (*read)(struct file___149 *, struct kobject___137 *, struct bin_attribute___137 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___149 *, struct kobject___137 *, struct bin_attribute___137 *, char *, loff_t, size_t);
	int (*mmap)(struct file___149 *, struct kobject___137 *, struct bin_attribute___137 *, struct vm_area_struct___154 *);
};

struct sysfs_ops___137 {
	ssize_t (*show)(struct kobject___137 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___137 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___137;

struct kset___137 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___137 kobj;
	const struct kset_uevent_ops___137 *uevent_ops;
};

struct kobj_type___137 {
	void (*release)(struct kobject___137 *);
	const struct sysfs_ops___137 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___137 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___137 *);
	const void * (*namespace)(struct kobject___137 *);
	void (*get_ownership)(struct kobject___137 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___137 {
	int (* const filter)(struct kset___137 *, struct kobject___137 *);
	const char * (* const name)(struct kset___137 *, struct kobject___137 *);
	int (* const uevent)(struct kset___137 *, struct kobject___137 *, struct kobj_uevent_env *);
};

struct wakeup_source___107;

struct device___107;

struct dev_pm_info___107 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___107 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___107 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___107;

struct bus_type___107;

struct device_driver___107;

struct dev_pm_domain___107;

struct fwnode_handle___107;

struct class___107;

struct device___107 {
	struct kobject___137 kobj;
	struct device___107 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___107 *type;
	struct bus_type___107 *bus;
	struct device_driver___107 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___107 power;
	struct dev_pm_domain___107 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___107 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___107 *class;
	const struct attribute_group___137 **groups;
	void (*release)(struct device___107 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___107 {
	int (*prepare)(struct device___107 *);
	void (*complete)(struct device___107 *);
	int (*suspend)(struct device___107 *);
	int (*resume)(struct device___107 *);
	int (*freeze)(struct device___107 *);
	int (*thaw)(struct device___107 *);
	int (*poweroff)(struct device___107 *);
	int (*restore)(struct device___107 *);
	int (*suspend_late)(struct device___107 *);
	int (*resume_early)(struct device___107 *);
	int (*freeze_late)(struct device___107 *);
	int (*thaw_early)(struct device___107 *);
	int (*poweroff_late)(struct device___107 *);
	int (*restore_early)(struct device___107 *);
	int (*suspend_noirq)(struct device___107 *);
	int (*resume_noirq)(struct device___107 *);
	int (*freeze_noirq)(struct device___107 *);
	int (*thaw_noirq)(struct device___107 *);
	int (*poweroff_noirq)(struct device___107 *);
	int (*restore_noirq)(struct device___107 *);
	int (*runtime_suspend)(struct device___107 *);
	int (*runtime_resume)(struct device___107 *);
	int (*runtime_idle)(struct device___107 *);
};

struct wakeup_source___107 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___107 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___107 {
	struct dev_pm_ops___107 ops;
	int (*start)(struct device___107 *);
	void (*detach)(struct device___107 *, bool);
	int (*activate)(struct device___107 *);
	void (*sync)(struct device___107 *);
	void (*dismiss)(struct device___107 *);
};

struct bus_type___107 {
	const char *name;
	const char *dev_name;
	struct device___107 *dev_root;
	const struct attribute_group___137 **bus_groups;
	const struct attribute_group___137 **dev_groups;
	const struct attribute_group___137 **drv_groups;
	int (*match)(struct device___107 *, struct device_driver___107 *);
	int (*uevent)(struct device___107 *, struct kobj_uevent_env *);
	int (*probe)(struct device___107 *);
	void (*sync_state)(struct device___107 *);
	void (*remove)(struct device___107 *);
	void (*shutdown)(struct device___107 *);
	int (*online)(struct device___107 *);
	int (*offline)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	int (*num_vf)(struct device___107 *);
	int (*dma_configure)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___107 {
	const char *name;
	struct bus_type___107 *bus;
	struct module___135 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___107 *);
	void (*sync_state)(struct device___107 *);
	int (*remove)(struct device___107 *);
	void (*shutdown)(struct device___107 *);
	int (*suspend)(struct device___107 *, pm_message_t);
	int (*resume)(struct device___107 *);
	const struct attribute_group___137 **groups;
	const struct attribute_group___137 **dev_groups;
	const struct dev_pm_ops___107 *pm;
	void (*coredump)(struct device___107 *);
	struct driver_private *p;
};

struct device_type___107 {
	const char *name;
	const struct attribute_group___137 **groups;
	int (*uevent)(struct device___107 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___107 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___107 *);
	const struct dev_pm_ops___107 *pm;
};

struct class___107 {
	const char *name;
	struct module___135 *owner;
	const struct attribute_group___137 **class_groups;
	const struct attribute_group___137 **dev_groups;
	struct kobject___137 *dev_kobj;
	int (*dev_uevent)(struct device___107 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___107 *, umode_t *);
	void (*class_release)(struct class___107 *);
	void (*dev_release)(struct device___107 *);
	int (*shutdown_pre)(struct device___107 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___107 *);
	void (*get_ownership)(struct device___107 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___107 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___107;

struct fwnode_handle___107 {
	struct fwnode_handle___107 *secondary;
	const struct fwnode_operations___107 *ops;
	struct device___107 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___145 {
	void (*page_free)(struct page___154 *);
	void (*kill)(struct dev_pagemap___145 *);
	void (*cleanup)(struct dev_pagemap___145 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___145 *);
};

struct seq_operations___127 {
	void * (*start)(struct seq_file___127 *, loff_t *);
	void (*stop)(struct seq_file___127 *, void *);
	void * (*next)(struct seq_file___127 *, void *, loff_t *);
	int (*show)(struct seq_file___127 *, void *);
};

struct fwnode_reference_args___107;

struct fwnode_endpoint___107;

struct fwnode_operations___107 {
	struct fwnode_handle___107 * (*get)(struct fwnode_handle___107 *);
	void (*put)(struct fwnode_handle___107 *);
	bool (*device_is_available)(const struct fwnode_handle___107 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___107 *, const struct device___107 *);
	bool (*property_present)(const struct fwnode_handle___107 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___107 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___107 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___107 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*get_parent)(const struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*get_next_child_node)(const struct fwnode_handle___107 *, struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*get_named_child_node)(const struct fwnode_handle___107 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___107 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___107 *);
	struct fwnode_handle___107 * (*graph_get_next_endpoint)(const struct fwnode_handle___107 *, struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*graph_get_remote_endpoint)(const struct fwnode_handle___107 *);
	struct fwnode_handle___107 * (*graph_get_port_parent)(struct fwnode_handle___107 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___107 *, struct fwnode_endpoint___107 *);
	int (*add_links)(struct fwnode_handle___107 *);
};

struct fwnode_endpoint___107 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___107 *local_fwnode;
};

struct fwnode_reference_args___107 {
	struct fwnode_handle___107 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___102 {
	struct ns_common___26 ns;
	struct user_namespace___22 *user_ns;
	struct ucounts___22 *ucounts;
	struct css_set___102 *root_cset;
};

struct kernel_param_ops___134 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___134 *);
	int (*get)(char *, const struct kernel_param___134 *);
	void (*free)(void *);
};

struct kparam_array___134;

struct kernel_param___134 {
	const char *name;
	struct module___135 *mod;
	const struct kernel_param_ops___134 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___134 *arr;
	};
};

struct kparam_array___134 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___134 *ops;
	void *elem;
};

struct module_attribute___134 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___134 *, struct module_kobject___134 *, char *);
	ssize_t (*store)(struct module_attribute___134 *, struct module_kobject___134 *, const char *, size_t);
	void (*setup)(struct module___135 *, const char *);
	int (*test)(struct module___135 *);
	void (*free)(struct module___135 *);
};

struct trace_event_class___63;

struct trace_event_call___63 {
	struct list_head list;
	struct trace_event_class___63 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___22 *prog_array;
	int (*perf_perm)(struct trace_event_call___63 *, struct perf_event___69 *);
};

struct cftype___102;

struct cgroup_subsys___102 {
	struct cgroup_subsys_state___102 * (*css_alloc)(struct cgroup_subsys_state___102 *);
	int (*css_online)(struct cgroup_subsys_state___102 *);
	void (*css_offline)(struct cgroup_subsys_state___102 *);
	void (*css_released)(struct cgroup_subsys_state___102 *);
	void (*css_free)(struct cgroup_subsys_state___102 *);
	void (*css_reset)(struct cgroup_subsys_state___102 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___102 *, int);
	int (*css_extra_stat_show)(struct seq_file___127 *, struct cgroup_subsys_state___102 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___156 *, struct css_set___102 *);
	void (*cancel_fork)(struct task_struct___156 *, struct css_set___102 *);
	void (*fork)(struct task_struct___156 *);
	void (*exit)(struct task_struct___156 *);
	void (*release)(struct task_struct___156 *);
	void (*bind)(struct cgroup_subsys_state___102 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___102 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___102 *dfl_cftypes;
	struct cftype___102 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___102 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___102 *updated_children;
	struct cgroup___102 *updated_next;
};

struct cgroup_root___102 {
	struct kernfs_root___137 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___102 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___102 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___102 *ss;
	struct list_head node;
	struct kernfs_ops___137 *kf_ops;
	int (*open)(struct kernfs_open_file___137 *);
	void (*release)(struct kernfs_open_file___137 *);
	u64 (*read_u64)(struct cgroup_subsys_state___102 *, struct cftype___102 *);
	s64 (*read_s64)(struct cgroup_subsys_state___102 *, struct cftype___102 *);
	int (*seq_show)(struct seq_file___127 *, void *);
	void * (*seq_start)(struct seq_file___127 *, loff_t *);
	void * (*seq_next)(struct seq_file___127 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___127 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___102 *, struct cftype___102 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___102 *, struct cftype___102 *, s64);
	ssize_t (*write)(struct kernfs_open_file___137 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___137 *, struct poll_table_struct___93 *);
};

struct perf_cpu_context___69;

struct perf_output_handle___69;

struct pmu___69 {
	struct list_head entry;
	struct module___135 *module;
	struct device___107 *dev;
	const struct attribute_group___137 **attr_groups;
	const struct attribute_group___137 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___69 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___69 *);
	void (*pmu_disable)(struct pmu___69 *);
	int (*event_init)(struct perf_event___69 *);
	void (*event_mapped)(struct perf_event___69 *, struct mm_struct___155 *);
	void (*event_unmapped)(struct perf_event___69 *, struct mm_struct___155 *);
	int (*add)(struct perf_event___69 *, int);
	void (*del)(struct perf_event___69 *, int);
	void (*start)(struct perf_event___69 *, int);
	void (*stop)(struct perf_event___69 *, int);
	void (*read)(struct perf_event___69 *);
	void (*start_txn)(struct pmu___69 *, unsigned int);
	int (*commit_txn)(struct pmu___69 *);
	void (*cancel_txn)(struct pmu___69 *);
	int (*event_idx)(struct perf_event___69 *);
	void (*sched_task)(struct perf_event_context___69 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___69 *, struct perf_event_context___69 *);
	void * (*setup_aux)(struct perf_event___69 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___69 *, struct perf_output_handle___69 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___69 *);
	int (*aux_output_match)(struct perf_event___69 *);
	int (*filter_match)(struct perf_event___69 *);
	int (*check_period)(struct perf_event___69 *, u64);
};

struct perf_cpu_context___69 {
	struct perf_event_context___69 ctx;
	struct perf_event_context___69 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___69 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___69 **heap;
	struct perf_event___69 *heap_default[2];
};

struct perf_output_handle___69 {
	struct perf_event___69 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___69 {
	struct cgroup_subsys_state___102 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___63 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___63 *);
	};
};

struct trace_event_class___63 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___63 *, enum trace_reg, void *);
	struct trace_event_fields___63 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___63 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___63 *);
};

struct syscall_metadata___35 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___63 *enter_event;
	struct trace_event_call___63 *exit_event;
};

struct keyctl_dh_params {
	union {
		__s32 private;
		__s32 priv;
	};
	__s32 prime;
	__s32 base;
};

struct keyctl_kdf_params {
	char *hashname;
	char *otherinfo;
	__u32 otherinfolen;
	__u32 __spare[8];
};

struct keyctl_pkey_query {
	__u32 supported_ops;
	__u32 key_size;
	__u16 max_data_size;
	__u16 max_sig_size;
	__u16 max_enc_size;
	__u16 max_dec_size;
	__u32 __spare[10];
};

struct keyctl_pkey_params {
	__s32 key_id;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	__u32 __spare[7];
};

struct kernel_pkey_params___4 {
	struct key___6 *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct request_key_auth {
	struct callback_head rcu;
	struct key___6 *target_key;
	struct key___6 *dest_keyring;
	const struct cred___22 *cred;
	void *callout_info;
	size_t callout_len;
	pid_t pid;
	char op[8];
};

struct key_match_data___4 {
	bool (*cmp)(const struct key___6 *, const struct key_match_data___4 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct watch_queue___4 {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___2 *pipe;
	struct hlist_head watches;
	struct page___154 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

struct watch___4 {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue___4 *queue;
	struct hlist_node queue_node;
	struct watch_list___4 *watch_list;
	struct hlist_node list_node;
	const struct cred___22 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

struct dentry___150;

struct super_block___150;

struct module___136;

struct file_system_type___150 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___150 * (*mount)(struct file_system_type___150 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___150 *);
	struct module___136 *owner;
	struct file_system_type___150 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___150;

struct kiocb___150;

struct iov_iter___82;

struct vm_area_struct___155;

struct inode___150;

struct file_lock___150;

struct page___155;

struct pipe_inode_info___46;

struct seq_file___128;

struct file_operations___150 {
	struct module___136 *owner;
	loff_t (*llseek)(struct file___150 *, loff_t, int);
	ssize_t (*read)(struct file___150 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___150 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___150 *, struct iov_iter___82 *);
	ssize_t (*write_iter)(struct kiocb___150 *, struct iov_iter___82 *);
	int (*iopoll)(struct kiocb___150 *, bool);
	int (*iterate)(struct file___150 *, struct dir_context *);
	int (*iterate_shared)(struct file___150 *, struct dir_context *);
	__poll_t (*poll)(struct file___150 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___150 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___150 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___150 *, struct vm_area_struct___155 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___150 *, struct file___150 *);
	int (*flush)(struct file___150 *, fl_owner_t);
	int (*release)(struct inode___150 *, struct file___150 *);
	int (*fsync)(struct file___150 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___150 *, int);
	int (*lock)(struct file___150 *, int, struct file_lock___150 *);
	ssize_t (*sendpage)(struct file___150 *, struct page___155 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___150 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___150 *, long unsigned int);
	int (*flock)(struct file___150 *, int, struct file_lock___150 *);
	ssize_t (*splice_write)(struct pipe_inode_info___46 *, struct file___150 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___150 *, loff_t *, struct pipe_inode_info___46 *, size_t, unsigned int);
	int (*setlease)(struct file___150 *, long int, struct file_lock___150 **, void **);
	long int (*fallocate)(struct file___150 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___128 *, struct file___150 *);
	ssize_t (*copy_file_range)(struct file___150 *, loff_t, struct file___150 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___150 *, loff_t, struct file___150 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___150 *, loff_t, loff_t, int);
};

struct vmacache___155 {
	u64 seqnum;
	struct vm_area_struct___155 *vmas[4];
};

struct page_frag___155 {
	struct page___155 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___156;

struct pid___132;

struct cred___23;

struct key___7;

struct nsproxy___141;

struct signal_struct___151;

struct vm_struct___134;

struct task_struct___157 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___157 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___156 *mm;
	struct mm_struct___156 *active_mm;
	struct vmacache___155 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___157 *real_parent;
	struct task_struct___157 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___157 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___132 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___23 *ptracer_cred;
	const struct cred___23 *real_cred;
	const struct cred___23 *cred;
	struct key___7 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___141 *nsproxy;
	struct signal_struct___151 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___157 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___46 *splice_pipe;
	struct page_frag___155 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___157 *oom_reaper_list;
	struct vm_struct___134 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___138;

struct kobj_type___138;

struct kernfs_node___138;

struct kobject___138 {
	const char *name;
	struct list_head entry;
	struct kobject___138 *parent;
	struct kset___138 *kset;
	struct kobj_type___138 *ktype;
	struct kernfs_node___138 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___135 {
	struct kobject___138 kobj;
	struct module___136 *mod;
	struct kobject___138 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___135 {
	struct module___136 *mod;
	struct latch_tree_node node;
};

struct module_layout___135 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___135 mtn;
};

struct module_attribute___135;

struct kernel_param___135;

struct module___136 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___135 mkobj;
	struct module_attribute___135 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___138 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___135 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___135 core_layout;
	struct module_layout___135 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___132;

struct upid___132 {
	int nr;
	struct pid_namespace___132 *ns;
};

struct user_namespace___23;

struct ucounts___23;

struct pid_namespace___132 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___157 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___132 *parent;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___132 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___132 numbers[1];
};

struct user_namespace___23 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___23 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___26 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___7 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___7 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___23 *ucounts;
	long int ucount_max[16];
};

typedef struct page___155 *pgtable_t___155;

struct address_space___150;

struct page_pool___37;

struct dev_pagemap___146;

struct page___155 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___150 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___37 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___155 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___155 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___156 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___146 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___23 {
	struct hlist_node node;
	struct user_namespace___23 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___146;

struct vm_area_struct___155 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___155 *vm_next;
	struct vm_area_struct___155 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___156 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___146 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___150 *vm_file;
	struct file___150 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___151 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___157 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___157 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___132 *pids[4];
	struct pid___132 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___156 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___155;

struct mm_struct___156 {
	struct {
		struct vm_area_struct___155 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___150 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___155 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___157 *owner;
		struct user_namespace___23 *user_ns;
		struct file___150 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___23 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___7 *session_keyring;
	struct key___7 *process_keyring;
	struct key___7 *thread_keyring;
	struct key___7 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct key_type___5;

struct keyring_index_key___5 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___5 *type;
	struct key_tag *domain_tag;
	const char *description;
};

struct watch_list___5;

struct key_restriction___6;

struct key___7 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list___5 *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___5 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___5 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___6 *restrict_link;
};

struct uts_namespace___9;

struct net___28;

struct nsproxy___141 {
	atomic_t count;
	struct uts_namespace___9 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___132 *pid_ns_for_children;
	struct net___28 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___150;

struct pipe_buffer___46;

struct watch_queue___5;

struct pipe_inode_info___46 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___155 *tmp_page;
	struct fasync_struct___150 *fasync_readers;
	struct fasync_struct___150 *fasync_writers;
	struct pipe_buffer___46 *bufs;
	struct user_struct *user;
	struct watch_queue___5 *watch_queue;
};

struct vm_struct___134 {
	struct vm_struct___134 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___155 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___150;

struct address_space___150 {
	struct inode___150 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___150 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___108;

struct page_pool_params___37 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___108 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___37 {
	u32 count;
	struct page___155 *cache[128];
};

struct page_pool___37 {
	struct page_pool_params___37 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___155 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___37 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___146;

struct dev_pagemap___146 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___146 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___150;

struct path___150 {
	struct vfsmount___150 *mnt;
	struct dentry___150 *dentry;
};

struct fown_struct___132 {
	rwlock_t lock;
	struct pid___132 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___150 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___150 f_path;
	struct inode___150 *f_inode;
	const struct file_operations___150 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___132 f_owner;
	const struct cred___23 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___150 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___146;

struct vm_operations_struct___146 {
	void (*open)(struct vm_area_struct___155 *);
	void (*close)(struct vm_area_struct___155 *);
	int (*may_split)(struct vm_area_struct___155 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___155 *);
	int (*mprotect)(struct vm_area_struct___155 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___146 *);
	vm_fault_t (*huge_fault)(struct vm_fault___146 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___146 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___155 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___146 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___146 *);
	int (*access)(struct vm_area_struct___155 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___155 *);
	int (*set_policy)(struct vm_area_struct___155 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___155 *, long unsigned int);
	struct page___155 * (*find_special_page)(struct vm_area_struct___155 *, long unsigned int);
};

struct core_thread___155 {
	struct task_struct___157 *task;
	struct core_thread___155 *next;
};

struct core_state___155 {
	atomic_t nr_threads;
	struct core_thread___155 dumper;
	struct completion startup;
};

struct vm_fault___146 {
	const struct {
		struct vm_area_struct___155 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___155 *cow_page;
	struct page___155 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___155 prealloc_pte;
};

struct kernel_pkey_params___5 {
	struct key___7 *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___150;

struct dentry___150 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___150 *d_parent;
	struct qstr d_name;
	struct inode___150 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___150 *d_op;
	struct super_block___150 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___150;

struct inode___150 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___150 *i_op;
	struct super_block___150 *i_sb;
	struct address_space___150 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___150 *i_fop;
		void (*free_inode)(struct inode___150 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___150 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___46 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___150 {
	int (*d_revalidate)(struct dentry___150 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___150 *, unsigned int);
	int (*d_hash)(const struct dentry___150 *, struct qstr *);
	int (*d_compare)(const struct dentry___150 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___150 *);
	int (*d_init)(struct dentry___150 *);
	void (*d_release)(struct dentry___150 *);
	void (*d_prune)(struct dentry___150 *);
	void (*d_iput)(struct dentry___150 *, struct inode___150 *);
	char * (*d_dname)(struct dentry___150 *, char *, int);
	struct vfsmount___150 * (*d_automount)(struct path___150 *);
	int (*d_manage)(const struct path___150 *, bool);
	struct dentry___150 * (*d_real)(struct dentry___150 *, const struct inode___150 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___150;

struct mem_dqinfo___150 {
	struct quota_format_type___150 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___150;

struct quota_info___150 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___150 *files[3];
	struct mem_dqinfo___150 info[3];
	const struct quota_format_ops___150 *ops[3];
};

struct rcuwait___151 {
	struct task_struct___157 *task;
};

struct percpu_rw_semaphore___151 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___151 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___150 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___151 rw_sem[3];
};

struct super_operations___150;

struct dquot_operations___150;

struct quotactl_ops___150;

struct super_block___150 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___150 *s_type;
	const struct super_operations___150 *s_op;
	const struct dquot_operations___150 *dq_op;
	const struct quotactl_ops___150 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___150 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___7 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___150 s_dquot;
	struct sb_writers___150 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___150 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___150 {
	struct dentry___150 *mnt_root;
	struct super_block___150 *mnt_sb;
	int mnt_flags;
	struct user_namespace___23 *mnt_userns;
};

typedef int (*request_key_actor_t___5)(struct key___7 *, void *);

struct key_match_data___5;

struct key_type___5 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___7 *, struct key_preparsed_payload *);
	int (*update)(struct key___7 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___5 *);
	void (*match_free)(struct key_match_data___5 *);
	void (*revoke)(struct key___7 *);
	void (*destroy)(struct key___7 *);
	void (*describe)(const struct key___7 *, struct seq_file___128 *);
	long int (*read)(const struct key___7 *, char *, size_t);
	request_key_actor_t___5 request_key;
	struct key_restriction___6 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___5 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___5 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___5 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___7)(struct key___7 *, const struct key_type___5 *, const union key_payload *, struct key___7 *);

struct key_restriction___6 {
	key_restrict_link_func_t___7 check;
	struct key___7 *key;
	struct key_type___5 *keytype;
};

struct watch___5;

struct watch_list___5 {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch___5 *);
	spinlock_t lock;
};

struct kiocb___150 {
	struct file___150 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___150 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___150 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___150 *ia_file;
};

struct dquot___150 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___150 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___150 {
	int qf_fmt_id;
	const struct quota_format_ops___150 *qf_ops;
	struct module___136 *qf_owner;
	struct quota_format_type___150 *qf_next;
};

struct quota_format_ops___150 {
	int (*check_quota_file)(struct super_block___150 *, int);
	int (*read_file_info)(struct super_block___150 *, int);
	int (*write_file_info)(struct super_block___150 *, int);
	int (*free_file_info)(struct super_block___150 *, int);
	int (*read_dqblk)(struct dquot___150 *);
	int (*commit_dqblk)(struct dquot___150 *);
	int (*release_dqblk)(struct dquot___150 *);
	int (*get_next_id)(struct super_block___150 *, struct kqid *);
};

struct dquot_operations___150 {
	int (*write_dquot)(struct dquot___150 *);
	struct dquot___150 * (*alloc_dquot)(struct super_block___150 *, int);
	void (*destroy_dquot)(struct dquot___150 *);
	int (*acquire_dquot)(struct dquot___150 *);
	int (*release_dquot)(struct dquot___150 *);
	int (*mark_dirty)(struct dquot___150 *);
	int (*write_info)(struct super_block___150 *, int);
	qsize_t * (*get_reserved_space)(struct inode___150 *);
	int (*get_projid)(struct inode___150 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___150 *, qsize_t *);
	int (*get_next_id)(struct super_block___150 *, struct kqid *);
};

struct quotactl_ops___150 {
	int (*quota_on)(struct super_block___150 *, int, int, const struct path___150 *);
	int (*quota_off)(struct super_block___150 *, int);
	int (*quota_enable)(struct super_block___150 *, unsigned int);
	int (*quota_disable)(struct super_block___150 *, unsigned int);
	int (*quota_sync)(struct super_block___150 *, int);
	int (*set_info)(struct super_block___150 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___150 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___150 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___150 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___150 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___150 *, unsigned int);
};

struct address_space_operations___150 {
	int (*writepage)(struct page___155 *, struct writeback_control___3 *);
	int (*readpage)(struct file___150 *, struct page___155 *);
	int (*writepages)(struct address_space___150 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___155 *);
	int (*readpages)(struct file___150 *, struct address_space___150 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___150 *, struct address_space___150 *, loff_t, unsigned int, unsigned int, struct page___155 **, void **);
	int (*write_end)(struct file___150 *, struct address_space___150 *, loff_t, unsigned int, unsigned int, struct page___155 *, void *);
	sector_t (*bmap)(struct address_space___150 *, sector_t);
	void (*invalidatepage)(struct page___155 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___155 *, gfp_t);
	void (*freepage)(struct page___155 *);
	ssize_t (*direct_IO)(struct kiocb___150 *, struct iov_iter___82 *);
	int (*migratepage)(struct address_space___150 *, struct page___155 *, struct page___155 *, enum migrate_mode);
	bool (*isolate_page)(struct page___155 *, isolate_mode_t);
	void (*putback_page)(struct page___155 *);
	int (*launder_page)(struct page___155 *);
	int (*is_partially_uptodate)(struct page___155 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___155 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___150 *, struct page___155 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___150 *, sector_t *);
	void (*swap_deactivate)(struct file___150 *);
};

struct bio_vec___80;

struct iov_iter___82 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___80 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___46 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___150 {
	struct dentry___150 * (*lookup)(struct inode___150 *, struct dentry___150 *, unsigned int);
	const char * (*get_link)(struct dentry___150 *, struct inode___150 *, struct delayed_call *);
	int (*permission)(struct user_namespace___23 *, struct inode___150 *, int);
	struct posix_acl * (*get_acl)(struct inode___150 *, int, bool);
	int (*readlink)(struct dentry___150 *, char *, int);
	int (*create)(struct user_namespace___23 *, struct inode___150 *, struct dentry___150 *, umode_t, bool);
	int (*link)(struct dentry___150 *, struct inode___150 *, struct dentry___150 *);
	int (*unlink)(struct inode___150 *, struct dentry___150 *);
	int (*symlink)(struct user_namespace___23 *, struct inode___150 *, struct dentry___150 *, const char *);
	int (*mkdir)(struct user_namespace___23 *, struct inode___150 *, struct dentry___150 *, umode_t);
	int (*rmdir)(struct inode___150 *, struct dentry___150 *);
	int (*mknod)(struct user_namespace___23 *, struct inode___150 *, struct dentry___150 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___23 *, struct inode___150 *, struct dentry___150 *, struct inode___150 *, struct dentry___150 *, unsigned int);
	int (*setattr)(struct user_namespace___23 *, struct dentry___150 *, struct iattr___150 *);
	int (*getattr)(struct user_namespace___23 *, const struct path___150 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___150 *, char *, size_t);
	int (*fiemap)(struct inode___150 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___150 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___150 *, struct dentry___150 *, struct file___150 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___23 *, struct inode___150 *, struct dentry___150 *, umode_t);
	int (*set_acl)(struct user_namespace___23 *, struct inode___150 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___23 *, struct dentry___150 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___150 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___150 {
	void (*fl_copy_lock)(struct file_lock___150 *, struct file_lock___150 *);
	void (*fl_release_private)(struct file_lock___150 *);
};

struct lock_manager_operations___150;

struct file_lock___150 {
	struct file_lock___150 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___150 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___150 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___150 *fl_ops;
	const struct lock_manager_operations___150 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___150 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___150 *);
	int (*lm_grant)(struct file_lock___150 *, int);
	bool (*lm_break)(struct file_lock___150 *);
	int (*lm_change)(struct file_lock___150 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___150 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___150 *);
};

struct fasync_struct___150 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___150 *fa_next;
	struct file___150 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___150 {
	struct inode___150 * (*alloc_inode)(struct super_block___150 *);
	void (*destroy_inode)(struct inode___150 *);
	void (*free_inode)(struct inode___150 *);
	void (*dirty_inode)(struct inode___150 *, int);
	int (*write_inode)(struct inode___150 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___150 *);
	void (*evict_inode)(struct inode___150 *);
	void (*put_super)(struct super_block___150 *);
	int (*sync_fs)(struct super_block___150 *, int);
	int (*freeze_super)(struct super_block___150 *);
	int (*freeze_fs)(struct super_block___150 *);
	int (*thaw_super)(struct super_block___150 *);
	int (*unfreeze_fs)(struct super_block___150 *);
	int (*statfs)(struct dentry___150 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___150 *, int *, char *);
	void (*umount_begin)(struct super_block___150 *);
	int (*show_options)(struct seq_file___128 *, struct dentry___150 *);
	int (*show_devname)(struct seq_file___128 *, struct dentry___150 *);
	int (*show_path)(struct seq_file___128 *, struct dentry___150 *);
	int (*show_stats)(struct seq_file___128 *, struct dentry___150 *);
	ssize_t (*quota_read)(struct super_block___150 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___150 *, int, const char *, size_t, loff_t);
	struct dquot___150 ** (*get_dquots)(struct inode___150 *);
	long int (*nr_cached_objects)(struct super_block___150 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___150 *, struct shrink_control___54 *);
	struct file___150 * (*real_loop)(struct file___150 *);
};

struct seq_operations___128;

struct seq_file___128 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___128 *op;
	int poll_event;
	const struct file___150 *file;
	void *private;
};

struct dev_pagemap_ops___146 {
	void (*page_free)(struct page___155 *);
	void (*kill)(struct dev_pagemap___146 *);
	void (*cleanup)(struct dev_pagemap___146 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___146 *);
};

struct uts_namespace___9 {
	struct new_utsname name;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct ns_common___26 ns;
};

struct fqdir___27;

struct netns_ipv4___27 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___27 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___27 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___27 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___24 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___24 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___24 *);
	int (*local_out)(struct net___28 *, struct sock *, struct sk_buff___24 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___24 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___27 {
	struct dst_ops___27 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___27 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___27 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___27 *fqdir;
};

struct netns_xfrm___27 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___27 xfrm4_dst_ops;
	struct dst_ops___27 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___28 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___27 ipv4;
	struct netns_ipv6___27 ipv6;
	struct netns_ieee802154_lowpan___27 ieee802154_lowpan;
	struct netns_sctp___15 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___22 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___22 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___27 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct seq_operations___128 {
	void * (*start)(struct seq_file___128 *, loff_t *);
	void (*stop)(struct seq_file___128 *, void *);
	void * (*next)(struct seq_file___128 *, void *, loff_t *);
	int (*show)(struct seq_file___128 *, void *);
};

struct fwnode_operations___108;

struct fwnode_handle___108 {
	struct fwnode_handle___108 *secondary;
	const struct fwnode_operations___108 *ops;
	struct device___108 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___108;

struct fwnode_endpoint___108;

struct fwnode_operations___108 {
	struct fwnode_handle___108 * (*get)(struct fwnode_handle___108 *);
	void (*put)(struct fwnode_handle___108 *);
	bool (*device_is_available)(const struct fwnode_handle___108 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___108 *, const struct device___108 *);
	bool (*property_present)(const struct fwnode_handle___108 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___108 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___108 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___108 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*get_parent)(const struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*get_next_child_node)(const struct fwnode_handle___108 *, struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*get_named_child_node)(const struct fwnode_handle___108 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___108 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___108 *);
	struct fwnode_handle___108 * (*graph_get_next_endpoint)(const struct fwnode_handle___108 *, struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*graph_get_remote_endpoint)(const struct fwnode_handle___108 *);
	struct fwnode_handle___108 * (*graph_get_port_parent)(struct fwnode_handle___108 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___108 *, struct fwnode_endpoint___108 *);
	int (*add_links)(struct fwnode_handle___108 *);
};

struct wakeup_source___108;

struct dev_pm_info___108 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___108 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___108 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___108;

struct bus_type___108;

struct device_driver___108;

struct dev_pm_domain___108;

struct class___108;

struct attribute_group___138;

struct device___108 {
	struct kobject___138 kobj;
	struct device___108 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___108 *type;
	struct bus_type___108 *bus;
	struct device_driver___108 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___108 power;
	struct dev_pm_domain___108 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___108 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___108 *class;
	const struct attribute_group___138 **groups;
	void (*release)(struct device___108 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___108 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___108 *local_fwnode;
};

struct fwnode_reference_args___108 {
	struct fwnode_handle___108 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___138;

struct kernfs_elem_dir___138 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___138 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___138;

struct kernfs_root___138 {
	struct kernfs_node___138 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___138 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___138 {
	struct kernfs_node___138 *target_kn;
};

struct kernfs_ops___138;

struct kernfs_elem_attr___138 {
	const struct kernfs_ops___138 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___138 *notify_next;
};

struct kernfs_node___138 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___138 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___138 dir;
		struct kernfs_elem_symlink___138 symlink;
		struct kernfs_elem_attr___138 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___138;

struct kernfs_ops___138 {
	int (*open)(struct kernfs_open_file___138 *);
	void (*release)(struct kernfs_open_file___138 *);
	int (*seq_show)(struct seq_file___128 *, void *);
	void * (*seq_start)(struct seq_file___128 *, loff_t *);
	void * (*seq_next)(struct seq_file___128 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___128 *, void *);
	ssize_t (*read)(struct kernfs_open_file___138 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___138 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___138 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___138 *, struct vm_area_struct___155 *);
};

struct kernfs_syscall_ops___138 {
	int (*show_options)(struct seq_file___128 *, struct kernfs_root___138 *);
	int (*mkdir)(struct kernfs_node___138 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___138 *);
	int (*rename)(struct kernfs_node___138 *, struct kernfs_node___138 *, const char *);
	int (*show_path)(struct seq_file___128 *, struct kernfs_node___138 *, struct kernfs_root___138 *);
};

struct kernfs_open_file___138 {
	struct kernfs_node___138 *kn;
	struct file___150 *file;
	struct seq_file___128 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___146 *vm_ops;
};

struct bin_attribute___138;

struct attribute_group___138 {
	const char *name;
	umode_t (*is_visible)(struct kobject___138 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___138 *, struct bin_attribute___138 *, int);
	struct attribute **attrs;
	struct bin_attribute___138 **bin_attrs;
};

struct bin_attribute___138 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___150 * (*f_mapping)();
	ssize_t (*read)(struct file___150 *, struct kobject___138 *, struct bin_attribute___138 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___150 *, struct kobject___138 *, struct bin_attribute___138 *, char *, loff_t, size_t);
	int (*mmap)(struct file___150 *, struct kobject___138 *, struct bin_attribute___138 *, struct vm_area_struct___155 *);
};

struct sysfs_ops___138 {
	ssize_t (*show)(struct kobject___138 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___138 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___138;

struct kset___138 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___138 kobj;
	const struct kset_uevent_ops___138 *uevent_ops;
};

struct kobj_type___138 {
	void (*release)(struct kobject___138 *);
	const struct sysfs_ops___138 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___138 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___138 *);
	const void * (*namespace)(struct kobject___138 *);
	void (*get_ownership)(struct kobject___138 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___138 {
	int (* const filter)(struct kset___138 *, struct kobject___138 *);
	const char * (* const name)(struct kset___138 *, struct kobject___138 *);
	int (* const uevent)(struct kset___138 *, struct kobject___138 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___135 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___135 *);
	int (*get)(char *, const struct kernel_param___135 *);
	void (*free)(void *);
};

struct kparam_array___135;

struct kernel_param___135 {
	const char *name;
	struct module___136 *mod;
	const struct kernel_param_ops___135 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___135 *arr;
	};
};

struct kparam_array___135 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___135 *ops;
	void *elem;
};

struct module_attribute___135 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___135 *, struct module_kobject___135 *, char *);
	ssize_t (*store)(struct module_attribute___135 *, struct module_kobject___135 *, const char *, size_t);
	void (*setup)(struct module___136 *, const char *);
	int (*test)(struct module___136 *);
	void (*free)(struct module___136 *);
};

struct bio_vec___80 {
	struct page___155 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct inet_frags___27;

struct fqdir___27 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___27 *f;
	struct net___28 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___27;

struct inet_frags___27 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___27 *, const void *);
	void (*destructor)(struct inet_frag_queue___27 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___27 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___24 *fragments_tail;
	struct sk_buff___24 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___27 *fqdir;
	struct callback_head rcu;
};

struct dev_pm_ops___108 {
	int (*prepare)(struct device___108 *);
	void (*complete)(struct device___108 *);
	int (*suspend)(struct device___108 *);
	int (*resume)(struct device___108 *);
	int (*freeze)(struct device___108 *);
	int (*thaw)(struct device___108 *);
	int (*poweroff)(struct device___108 *);
	int (*restore)(struct device___108 *);
	int (*suspend_late)(struct device___108 *);
	int (*resume_early)(struct device___108 *);
	int (*freeze_late)(struct device___108 *);
	int (*thaw_early)(struct device___108 *);
	int (*poweroff_late)(struct device___108 *);
	int (*restore_early)(struct device___108 *);
	int (*suspend_noirq)(struct device___108 *);
	int (*resume_noirq)(struct device___108 *);
	int (*freeze_noirq)(struct device___108 *);
	int (*thaw_noirq)(struct device___108 *);
	int (*poweroff_noirq)(struct device___108 *);
	int (*restore_noirq)(struct device___108 *);
	int (*runtime_suspend)(struct device___108 *);
	int (*runtime_resume)(struct device___108 *);
	int (*runtime_idle)(struct device___108 *);
};

struct wakeup_source___108 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___108 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___108 {
	struct dev_pm_ops___108 ops;
	int (*start)(struct device___108 *);
	void (*detach)(struct device___108 *, bool);
	int (*activate)(struct device___108 *);
	void (*sync)(struct device___108 *);
	void (*dismiss)(struct device___108 *);
};

struct bus_type___108 {
	const char *name;
	const char *dev_name;
	struct device___108 *dev_root;
	const struct attribute_group___138 **bus_groups;
	const struct attribute_group___138 **dev_groups;
	const struct attribute_group___138 **drv_groups;
	int (*match)(struct device___108 *, struct device_driver___108 *);
	int (*uevent)(struct device___108 *, struct kobj_uevent_env *);
	int (*probe)(struct device___108 *);
	void (*sync_state)(struct device___108 *);
	void (*remove)(struct device___108 *);
	void (*shutdown)(struct device___108 *);
	int (*online)(struct device___108 *);
	int (*offline)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	int (*num_vf)(struct device___108 *);
	int (*dma_configure)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___108 {
	const char *name;
	struct bus_type___108 *bus;
	struct module___136 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___108 *);
	void (*sync_state)(struct device___108 *);
	int (*remove)(struct device___108 *);
	void (*shutdown)(struct device___108 *);
	int (*suspend)(struct device___108 *, pm_message_t);
	int (*resume)(struct device___108 *);
	const struct attribute_group___138 **groups;
	const struct attribute_group___138 **dev_groups;
	const struct dev_pm_ops___108 *pm;
	void (*coredump)(struct device___108 *);
	struct driver_private *p;
};

struct device_type___108 {
	const char *name;
	const struct attribute_group___138 **groups;
	int (*uevent)(struct device___108 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___108 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___108 *);
	const struct dev_pm_ops___108 *pm;
};

struct class___108 {
	const char *name;
	struct module___136 *owner;
	const struct attribute_group___138 **class_groups;
	const struct attribute_group___138 **dev_groups;
	struct kobject___138 *dev_kobj;
	int (*dev_uevent)(struct device___108 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___108 *, umode_t *);
	void (*class_release)(struct class___108 *);
	void (*dev_release)(struct device___108 *);
	int (*shutdown_pre)(struct device___108 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___108 *);
	void (*get_ownership)(struct device___108 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___108 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___46;

struct pipe_buffer___46 {
	struct page___155 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___46 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___46 {
	int (*confirm)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
	void (*release)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
	bool (*try_steal)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
	bool (*get)(struct pipe_inode_info___46 *, struct pipe_buffer___46 *);
};

struct watch_queue___5 {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___46 *pipe;
	struct hlist_head watches;
	struct page___155 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

struct request_key_auth___2 {
	struct callback_head rcu;
	struct key___7 *target_key;
	struct key___7 *dest_keyring;
	const struct cred___23 *cred;
	void *callout_info;
	size_t callout_len;
	pid_t pid;
	char op[8];
};

struct key_match_data___5 {
	bool (*cmp)(const struct key___7 *, const struct key_match_data___5 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct watch___5 {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue___5 *queue;
	struct hlist_node queue_node;
	struct watch_list___5 *watch_list;
	struct hlist_node list_node;
	const struct cred___23 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

struct keyring_search_context___2 {
	struct keyring_index_key___5 index_key;
	const struct cred___23 *cred;
	struct key_match_data___5 match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	time64_t now;
};

struct subprocess_info___2 {
	struct work_struct work;
	struct completion *complete;
	const char *path;
	char **argv;
	char **envp;
	int wait;
	int retval;
	int (*init)(struct subprocess_info___2 *, struct cred___23 *);
	void (*cleanup)(struct subprocess_info___2 *);
	void *data;
};

struct dentry___151;

struct super_block___151;

struct file_system_type___151 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___151 * (*mount)(struct file_system_type___151 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___151 *);
	struct module___8 *owner;
	struct file_system_type___151 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___151;

struct kiocb___151;

struct vm_area_struct___156;

struct inode___151;

struct file_lock___151;

struct page___156;

struct seq_file___129;

struct file_operations___151 {
	struct module___8 *owner;
	loff_t (*llseek)(struct file___151 *, loff_t, int);
	ssize_t (*read)(struct file___151 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___151 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___151 *, struct iov_iter___82 *);
	ssize_t (*write_iter)(struct kiocb___151 *, struct iov_iter___82 *);
	int (*iopoll)(struct kiocb___151 *, bool);
	int (*iterate)(struct file___151 *, struct dir_context *);
	int (*iterate_shared)(struct file___151 *, struct dir_context *);
	__poll_t (*poll)(struct file___151 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___151 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___151 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___151 *, struct vm_area_struct___156 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___151 *, struct file___151 *);
	int (*flush)(struct file___151 *, fl_owner_t);
	int (*release)(struct inode___151 *, struct file___151 *);
	int (*fsync)(struct file___151 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___151 *, int);
	int (*lock)(struct file___151 *, int, struct file_lock___151 *);
	ssize_t (*sendpage)(struct file___151 *, struct page___156 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___151 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___151 *, long unsigned int);
	int (*flock)(struct file___151 *, int, struct file_lock___151 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___151 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___151 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___151 *, long int, struct file_lock___151 **, void **);
	long int (*fallocate)(struct file___151 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___129 *, struct file___151 *);
	ssize_t (*copy_file_range)(struct file___151 *, loff_t, struct file___151 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___151 *, loff_t, struct file___151 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___151 *, loff_t, loff_t, int);
};

struct vmacache___156 {
	u64 seqnum;
	struct vm_area_struct___156 *vmas[4];
};

struct page_frag___156 {
	struct page___156 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___157;

struct cred___24;

struct signal_struct___152;

struct vm_struct___135;

struct task_struct___158 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___158 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___157 *mm;
	struct mm_struct___157 *active_mm;
	struct vmacache___156 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___158 *real_parent;
	struct task_struct___158 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___158 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___132 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___24 *ptracer_cred;
	const struct cred___24 *real_cred;
	const struct cred___24 *cred;
	struct key___4 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___152 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___158 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___156 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___158 *oom_reaper_list;
	struct vm_struct___135 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___156 *pgtable_t___156;

struct address_space___151;

struct dev_pagemap___147;

struct page___156 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___151 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___37 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___156 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___156 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___157 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___147 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___147;

struct vm_area_struct___156 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___156 *vm_next;
	struct vm_area_struct___156 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___157 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___147 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___151 *vm_file;
	struct file___151 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___152 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___158 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___158 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___132 *pids[4];
	struct pid___132 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___157 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___156;

struct mm_struct___157 {
	struct {
		struct vm_area_struct___156 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___151 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___156 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___158 *owner;
		struct user_namespace *user_ns;
		struct file___151 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___24 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___4 *session_keyring;
	struct key___4 *process_keyring;
	struct key___4 *thread_keyring;
	struct key___4 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct key_type___6;

struct keyring_index_key___6 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___6 *type;
	struct key_tag *domain_tag;
	const char *description;
};

struct watch_list___6;

struct key_restriction___7;

struct key___4 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list___6 *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___6 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___6 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___7 *restrict_link;
};

struct vm_struct___135 {
	struct vm_struct___135 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___156 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___151;

struct dentry___151 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___151 *d_parent;
	struct qstr d_name;
	struct inode___151 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___151 *d_op;
	struct super_block___151 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___151;

struct address_space___151 {
	struct inode___151 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___151 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___151;

struct inode___151 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___151 *i_op;
	struct super_block___151 *i_sb;
	struct address_space___151 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___151 *i_fop;
		void (*free_inode)(struct inode___151 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___151 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___46 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___151;

struct path___151;

struct dentry_operations___151 {
	int (*d_revalidate)(struct dentry___151 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___151 *, unsigned int);
	int (*d_hash)(const struct dentry___151 *, struct qstr *);
	int (*d_compare)(const struct dentry___151 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___151 *);
	int (*d_init)(struct dentry___151 *);
	void (*d_release)(struct dentry___151 *);
	void (*d_prune)(struct dentry___151 *);
	void (*d_iput)(struct dentry___151 *, struct inode___151 *);
	char * (*d_dname)(struct dentry___151 *, char *, int);
	struct vfsmount___151 * (*d_automount)(struct path___151 *);
	int (*d_manage)(const struct path___151 *, bool);
	struct dentry___151 * (*d_real)(struct dentry___151 *, const struct inode___151 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___151;

struct mem_dqinfo___151 {
	struct quota_format_type___151 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___151;

struct quota_info___151 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___151 *files[3];
	struct mem_dqinfo___151 info[3];
	const struct quota_format_ops___151 *ops[3];
};

struct rcuwait___152 {
	struct task_struct___158 *task;
};

struct percpu_rw_semaphore___152 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___152 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___151 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___152 rw_sem[3];
};

struct super_operations___151;

struct dquot_operations___151;

struct quotactl_ops___151;

struct super_block___151 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___151 *s_type;
	const struct super_operations___151 *s_op;
	const struct dquot_operations___151 *dq_op;
	const struct quotactl_ops___151 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___151 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___4 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___151 s_dquot;
	struct sb_writers___151 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___151 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___151 {
	struct dentry___151 *mnt_root;
	struct super_block___151 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___151 {
	struct vfsmount___151 *mnt;
	struct dentry___151 *dentry;
};

struct dev_pagemap_ops___147;

struct dev_pagemap___147 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___147 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct file___151 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___151 f_path;
	struct inode___151 *f_inode;
	const struct file_operations___151 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___132 f_owner;
	const struct cred___24 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___151 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___147;

struct vm_operations_struct___147 {
	void (*open)(struct vm_area_struct___156 *);
	void (*close)(struct vm_area_struct___156 *);
	int (*may_split)(struct vm_area_struct___156 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___156 *);
	int (*mprotect)(struct vm_area_struct___156 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___147 *);
	vm_fault_t (*huge_fault)(struct vm_fault___147 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___147 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___156 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___147 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___147 *);
	int (*access)(struct vm_area_struct___156 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___156 *);
	int (*set_policy)(struct vm_area_struct___156 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___156 *, long unsigned int);
	struct page___156 * (*find_special_page)(struct vm_area_struct___156 *, long unsigned int);
};

struct core_thread___156 {
	struct task_struct___158 *task;
	struct core_thread___156 *next;
};

struct core_state___156 {
	atomic_t nr_threads;
	struct core_thread___156 dumper;
	struct completion startup;
};

struct vm_fault___147 {
	const struct {
		struct vm_area_struct___156 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___156 *cow_page;
	struct page___156 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___156 prealloc_pte;
};

typedef int (*request_key_actor_t___6)(struct key___4 *, void *);

struct key_match_data___6;

struct key_type___6 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___4 *, struct key_preparsed_payload *);
	int (*update)(struct key___4 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___6 *);
	void (*match_free)(struct key_match_data___6 *);
	void (*revoke)(struct key___4 *);
	void (*destroy)(struct key___4 *);
	void (*describe)(const struct key___4 *, struct seq_file___129 *);
	long int (*read)(const struct key___4 *, char *, size_t);
	request_key_actor_t___6 request_key;
	struct key_restriction___7 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___2 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___2 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___2 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___8)(struct key___4 *, const struct key_type___6 *, const union key_payload *, struct key___4 *);

struct key_restriction___7 {
	key_restrict_link_func_t___8 check;
	struct key___4 *key;
	struct key_type___6 *keytype;
};

struct watch___6;

struct watch_list___6 {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch___6 *);
	spinlock_t lock;
};

struct kiocb___151 {
	struct file___151 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___151 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___151 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___151 *ia_file;
};

struct dquot___151 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___151 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___151 {
	int qf_fmt_id;
	const struct quota_format_ops___151 *qf_ops;
	struct module___8 *qf_owner;
	struct quota_format_type___151 *qf_next;
};

struct quota_format_ops___151 {
	int (*check_quota_file)(struct super_block___151 *, int);
	int (*read_file_info)(struct super_block___151 *, int);
	int (*write_file_info)(struct super_block___151 *, int);
	int (*free_file_info)(struct super_block___151 *, int);
	int (*read_dqblk)(struct dquot___151 *);
	int (*commit_dqblk)(struct dquot___151 *);
	int (*release_dqblk)(struct dquot___151 *);
	int (*get_next_id)(struct super_block___151 *, struct kqid *);
};

struct dquot_operations___151 {
	int (*write_dquot)(struct dquot___151 *);
	struct dquot___151 * (*alloc_dquot)(struct super_block___151 *, int);
	void (*destroy_dquot)(struct dquot___151 *);
	int (*acquire_dquot)(struct dquot___151 *);
	int (*release_dquot)(struct dquot___151 *);
	int (*mark_dirty)(struct dquot___151 *);
	int (*write_info)(struct super_block___151 *, int);
	qsize_t * (*get_reserved_space)(struct inode___151 *);
	int (*get_projid)(struct inode___151 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___151 *, qsize_t *);
	int (*get_next_id)(struct super_block___151 *, struct kqid *);
};

struct quotactl_ops___151 {
	int (*quota_on)(struct super_block___151 *, int, int, const struct path___151 *);
	int (*quota_off)(struct super_block___151 *, int);
	int (*quota_enable)(struct super_block___151 *, unsigned int);
	int (*quota_disable)(struct super_block___151 *, unsigned int);
	int (*quota_sync)(struct super_block___151 *, int);
	int (*set_info)(struct super_block___151 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___151 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___151 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___151 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___151 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___151 *, unsigned int);
};

struct address_space_operations___151 {
	int (*writepage)(struct page___156 *, struct writeback_control___3 *);
	int (*readpage)(struct file___151 *, struct page___156 *);
	int (*writepages)(struct address_space___151 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___156 *);
	int (*readpages)(struct file___151 *, struct address_space___151 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___151 *, struct address_space___151 *, loff_t, unsigned int, unsigned int, struct page___156 **, void **);
	int (*write_end)(struct file___151 *, struct address_space___151 *, loff_t, unsigned int, unsigned int, struct page___156 *, void *);
	sector_t (*bmap)(struct address_space___151 *, sector_t);
	void (*invalidatepage)(struct page___156 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___156 *, gfp_t);
	void (*freepage)(struct page___156 *);
	ssize_t (*direct_IO)(struct kiocb___151 *, struct iov_iter___82 *);
	int (*migratepage)(struct address_space___151 *, struct page___156 *, struct page___156 *, enum migrate_mode);
	bool (*isolate_page)(struct page___156 *, isolate_mode_t);
	void (*putback_page)(struct page___156 *);
	int (*launder_page)(struct page___156 *);
	int (*is_partially_uptodate)(struct page___156 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___156 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___151 *, struct page___156 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___151 *, sector_t *);
	void (*swap_deactivate)(struct file___151 *);
};

struct inode_operations___151 {
	struct dentry___151 * (*lookup)(struct inode___151 *, struct dentry___151 *, unsigned int);
	const char * (*get_link)(struct dentry___151 *, struct inode___151 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___151 *, int);
	struct posix_acl * (*get_acl)(struct inode___151 *, int, bool);
	int (*readlink)(struct dentry___151 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___151 *, struct dentry___151 *, umode_t, bool);
	int (*link)(struct dentry___151 *, struct inode___151 *, struct dentry___151 *);
	int (*unlink)(struct inode___151 *, struct dentry___151 *);
	int (*symlink)(struct user_namespace *, struct inode___151 *, struct dentry___151 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___151 *, struct dentry___151 *, umode_t);
	int (*rmdir)(struct inode___151 *, struct dentry___151 *);
	int (*mknod)(struct user_namespace *, struct inode___151 *, struct dentry___151 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___151 *, struct dentry___151 *, struct inode___151 *, struct dentry___151 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___151 *, struct iattr___151 *);
	int (*getattr)(struct user_namespace *, const struct path___151 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___151 *, char *, size_t);
	int (*fiemap)(struct inode___151 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___151 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___151 *, struct dentry___151 *, struct file___151 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___151 *, struct dentry___151 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___151 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___151 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___151 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___151 {
	void (*fl_copy_lock)(struct file_lock___151 *, struct file_lock___151 *);
	void (*fl_release_private)(struct file_lock___151 *);
};

struct fasync_struct___151;

struct lock_manager_operations___151;

struct file_lock___151 {
	struct file_lock___151 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___151 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___151 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___151 *fl_ops;
	const struct lock_manager_operations___151 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___151 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___151 *);
	int (*lm_grant)(struct file_lock___151 *, int);
	bool (*lm_break)(struct file_lock___151 *);
	int (*lm_change)(struct file_lock___151 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___151 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___151 *);
};

struct fasync_struct___151 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___151 *fa_next;
	struct file___151 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___151 {
	struct inode___151 * (*alloc_inode)(struct super_block___151 *);
	void (*destroy_inode)(struct inode___151 *);
	void (*free_inode)(struct inode___151 *);
	void (*dirty_inode)(struct inode___151 *, int);
	int (*write_inode)(struct inode___151 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___151 *);
	void (*evict_inode)(struct inode___151 *);
	void (*put_super)(struct super_block___151 *);
	int (*sync_fs)(struct super_block___151 *, int);
	int (*freeze_super)(struct super_block___151 *);
	int (*freeze_fs)(struct super_block___151 *);
	int (*thaw_super)(struct super_block___151 *);
	int (*unfreeze_fs)(struct super_block___151 *);
	int (*statfs)(struct dentry___151 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___151 *, int *, char *);
	void (*umount_begin)(struct super_block___151 *);
	int (*show_options)(struct seq_file___129 *, struct dentry___151 *);
	int (*show_devname)(struct seq_file___129 *, struct dentry___151 *);
	int (*show_path)(struct seq_file___129 *, struct dentry___151 *);
	int (*show_stats)(struct seq_file___129 *, struct dentry___151 *);
	ssize_t (*quota_read)(struct super_block___151 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___151 *, int, const char *, size_t, loff_t);
	struct dquot___151 ** (*get_dquots)(struct inode___151 *);
	long int (*nr_cached_objects)(struct super_block___151 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___151 *, struct shrink_control___54 *);
	struct file___151 * (*real_loop)(struct file___151 *);
};

struct seq_operations___129;

struct seq_file___129 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___129 *op;
	int poll_event;
	const struct file___151 *file;
	void *private;
};

struct seq_operations___129 {
	void * (*start)(struct seq_file___129 *, loff_t *);
	void (*stop)(struct seq_file___129 *, void *);
	void * (*next)(struct seq_file___129 *, void *, loff_t *);
	int (*show)(struct seq_file___129 *, void *);
};

struct key_match_data___6 {
	bool (*cmp)(const struct key___4 *, const struct key_match_data___6 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct watch_queue___6 {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___2 *pipe;
	struct hlist_head watches;
	struct page___156 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

struct watch___6 {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue___6 *queue;
	struct hlist_node queue_node;
	struct watch_list___6 *watch_list;
	struct hlist_node list_node;
	const struct cred___24 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

struct dev_pagemap_ops___147 {
	void (*page_free)(struct page___156 *);
	void (*kill)(struct dev_pagemap___147 *);
	void (*cleanup)(struct dev_pagemap___147 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___147 *);
};

struct keyring_search_context___3 {
	struct keyring_index_key___6 index_key;
	const struct cred___24 *cred;
	struct key_match_data___6 match_data;
	unsigned int flags;
	int (*iterator)(const void *, void *);
	int skipped_ret;
	bool possessed;
	key_ref_t result;
	time64_t now;
};

struct request_key_auth___3 {
	struct callback_head rcu;
	struct key___4 *target_key;
	struct key___4 *dest_keyring;
	const struct cred___24 *cred;
	void *callout_info;
	size_t callout_len;
	pid_t pid;
	char op[8];
};

struct compat_keyctl_kdf_params {
	compat_uptr_t hashname;
	compat_uptr_t otherinfo;
	__u32 otherinfolen;
	__u32 __spare[8];
};

struct keyctl_dh_params___2 {
	union {
		__s32 private;
		__s32 priv;
	};
	int: 32;
	__s32 prime;
	__s32 base;
};

struct keyctl_pkey_params___2 {
	__s32 key_id;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	int: 32;
	__u32 __spare[7];
};

struct qspinlock___2 {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
	int: 32;
};

typedef struct qspinlock___2 arch_spinlock_t___2;

struct raw_spinlock___2 {
	arch_spinlock_t___2 raw_lock;
};

struct spinlock___2 {
	union {
		struct raw_spinlock___2 rlock;
	};
	int: 32;
};

typedef struct spinlock___2 spinlock_t___2;

struct wait_queue_head___2 {
	spinlock_t___2 lock;
	struct list_head head;
};

typedef struct wait_queue_head___2 wait_queue_head_t___2;

struct ctl_table___2;

typedef int proc_handler___2(struct ctl_table___2 *, int, void *, size_t *, loff_t *);

struct ctl_table_poll___2;

struct ctl_table___2 {
	const char *procname;
	void *data;
	int maxlen;
	umode_t mode;
	struct ctl_table___2 *child;
	proc_handler___2 *proc_handler;
	struct ctl_table_poll___2 *poll;
	void *extra1;
	void *extra2;
};

struct ctl_table_poll___2 {
	atomic_t event;
	wait_queue_head_t___2 wait;
};

struct kpp_request {
	struct crypto_async_request___3 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_kpp {
	struct crypto_tfm___7 base;
};

struct kpp_alg {
	int (*set_secret)(struct crypto_kpp *, const void *, unsigned int);
	int (*generate_public_key)(struct kpp_request *);
	int (*compute_shared_secret)(struct kpp_request *);
	unsigned int (*max_size)(struct crypto_kpp *);
	int (*init)(struct crypto_kpp *);
	void (*exit)(struct crypto_kpp *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___7 base;
};

struct dh {
	void *key;
	void *p;
	void *q;
	void *g;
	unsigned int key_size;
	unsigned int p_size;
	unsigned int q_size;
	unsigned int g_size;
};

struct dh_completion {
	struct completion completion;
	int err;
};

struct kdf_sdesc {
	struct shash_desc___6 shash;
	char ctx[0];
};

enum {
	Opt_err___6 = 0,
	Opt_enc = 1,
	Opt_hash = 2,
};

struct dentry___152;

struct super_block___152;

struct module___137;

struct file_system_type___152 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___152 * (*mount)(struct file_system_type___152 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___152 *);
	struct module___137 *owner;
	struct file_system_type___152 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___152;

struct kiocb___152;

struct poll_table_struct___94;

struct vm_area_struct___157;

struct inode___152;

struct file_lock___152;

struct page___157;

struct seq_file___130;

struct file_operations___152 {
	struct module___137 *owner;
	loff_t (*llseek)(struct file___152 *, loff_t, int);
	ssize_t (*read)(struct file___152 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___152 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___152 *, struct iov_iter___82 *);
	ssize_t (*write_iter)(struct kiocb___152 *, struct iov_iter___82 *);
	int (*iopoll)(struct kiocb___152 *, bool);
	int (*iterate)(struct file___152 *, struct dir_context *);
	int (*iterate_shared)(struct file___152 *, struct dir_context *);
	__poll_t (*poll)(struct file___152 *, struct poll_table_struct___94 *);
	long int (*unlocked_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___152 *, struct vm_area_struct___157 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___152 *, struct file___152 *);
	int (*flush)(struct file___152 *, fl_owner_t);
	int (*release)(struct inode___152 *, struct file___152 *);
	int (*fsync)(struct file___152 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___152 *, int);
	int (*lock)(struct file___152 *, int, struct file_lock___152 *);
	ssize_t (*sendpage)(struct file___152 *, struct page___157 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___152 *, long unsigned int);
	int (*flock)(struct file___152 *, int, struct file_lock___152 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___152 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___152 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___152 *, long int, struct file_lock___152 **, void **);
	long int (*fallocate)(struct file___152 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___130 *, struct file___152 *);
	ssize_t (*copy_file_range)(struct file___152 *, loff_t, struct file___152 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___152 *, loff_t, struct file___152 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___152 *, loff_t, loff_t, int);
};

struct vmacache___157 {
	u64 seqnum;
	struct vm_area_struct___157 *vmas[4];
};

struct page_frag___157 {
	struct page___157 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___158;

struct pid___133;

struct cred___25;

struct key___8;

struct nsproxy___142;

struct signal_struct___153;

struct vm_struct___136;

struct task_struct___159 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___159 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___158 *mm;
	struct mm_struct___158 *active_mm;
	struct vmacache___157 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___159 *real_parent;
	struct task_struct___159 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___159 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___133 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___25 *ptracer_cred;
	const struct cred___25 *real_cred;
	const struct cred___25 *cred;
	struct key___8 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___142 *nsproxy;
	struct signal_struct___153 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___159 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___157 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___159 *oom_reaper_list;
	struct vm_struct___136 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___139;

struct kobj_type___139;

struct kernfs_node___139;

struct kobject___139 {
	const char *name;
	struct list_head entry;
	struct kobject___139 *parent;
	struct kset___139 *kset;
	struct kobj_type___139 *ktype;
	struct kernfs_node___139 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___136 {
	struct kobject___139 kobj;
	struct module___137 *mod;
	struct kobject___139 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___136 {
	struct module___137 *mod;
	struct latch_tree_node node;
};

struct module_layout___136 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___136 mtn;
};

struct module_attribute___136;

struct kernel_param___136;

struct module___137 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___136 mkobj;
	struct module_attribute___136 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___139 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___136 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___136 core_layout;
	struct module_layout___136 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key_type___7;

struct keyring_index_key___7 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___7 *type;
	struct key_tag *domain_tag;
	const char *description;
};

typedef int (*request_key_actor_t___7)(struct key___8 *, void *);

struct key_match_data___7;

struct key_restriction___8;

struct key_type___7 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___8 *, struct key_preparsed_payload *);
	int (*update)(struct key___8 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___7 *);
	void (*match_free)(struct key_match_data___7 *);
	void (*revoke)(struct key___8 *);
	void (*destroy)(struct key___8 *);
	void (*describe)(const struct key___8 *, struct seq_file___130 *);
	long int (*read)(const struct key___8 *, char *, size_t);
	request_key_actor_t___7 request_key;
	struct key_restriction___8 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___2 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___2 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___2 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___9)(struct key___8 *, const struct key_type___7 *, const union key_payload *, struct key___8 *);

struct key___8 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___7 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___7 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___8 *restrict_link;
};

struct key_restriction___8 {
	key_restrict_link_func_t___9 check;
	struct key___8 *key;
	struct key_type___7 *keytype;
};

typedef struct page___157 *pgtable_t___157;

struct address_space___152;

struct dev_pagemap___148;

struct page___157 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___152 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___37 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___157 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___157 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___158 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___148 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___148;

struct vm_area_struct___157 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___157 *vm_next;
	struct vm_area_struct___157 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___158 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___148 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___152 *vm_file;
	struct file___152 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___157;

struct mm_struct___158 {
	struct {
		struct vm_area_struct___157 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___157 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___159 *owner;
		struct user_namespace *user_ns;
		struct file___152 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___152;

struct address_space___152 {
	struct inode___152 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___152 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___148;

struct dev_pagemap___148 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___148 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___152;

struct path___152 {
	struct vfsmount___152 *mnt;
	struct dentry___152 *dentry;
};

struct fown_struct___133 {
	rwlock_t lock;
	struct pid___133 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___152 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___152 f_path;
	struct inode___152 *f_inode;
	const struct file_operations___152 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___133 f_owner;
	const struct cred___25 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___152 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___148;

struct vm_operations_struct___148 {
	void (*open)(struct vm_area_struct___157 *);
	void (*close)(struct vm_area_struct___157 *);
	int (*may_split)(struct vm_area_struct___157 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___157 *);
	int (*mprotect)(struct vm_area_struct___157 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___148 *);
	vm_fault_t (*huge_fault)(struct vm_fault___148 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___148 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___157 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___148 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___148 *);
	int (*access)(struct vm_area_struct___157 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___157 *);
	int (*set_policy)(struct vm_area_struct___157 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___157 *, long unsigned int);
	struct page___157 * (*find_special_page)(struct vm_area_struct___157 *, long unsigned int);
};

struct core_thread___157 {
	struct task_struct___159 *task;
	struct core_thread___157 *next;
};

struct core_state___157 {
	atomic_t nr_threads;
	struct core_thread___157 dumper;
	struct completion startup;
};

struct vm_fault___148 {
	const struct {
		struct vm_area_struct___157 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___157 *cow_page;
	struct page___157 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___157 prealloc_pte;
};

struct kernfs_root___139;

struct kernfs_elem_dir___139 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___139 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___139;

struct kernfs_root___139 {
	struct kernfs_node___139 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___139 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___139 {
	struct kernfs_node___139 *target_kn;
};

struct kernfs_ops___139;

struct kernfs_elem_attr___139 {
	const struct kernfs_ops___139 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___139 *notify_next;
};

struct kernfs_node___139 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___139 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___139 dir;
		struct kernfs_elem_symlink___139 symlink;
		struct kernfs_elem_attr___139 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___139;

struct kernfs_ops___139 {
	int (*open)(struct kernfs_open_file___139 *);
	void (*release)(struct kernfs_open_file___139 *);
	int (*seq_show)(struct seq_file___130 *, void *);
	void * (*seq_start)(struct seq_file___130 *, loff_t *);
	void * (*seq_next)(struct seq_file___130 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___130 *, void *);
	ssize_t (*read)(struct kernfs_open_file___139 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___139 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___139 *, struct poll_table_struct___94 *);
	int (*mmap)(struct kernfs_open_file___139 *, struct vm_area_struct___157 *);
};

struct kernfs_syscall_ops___139 {
	int (*show_options)(struct seq_file___130 *, struct kernfs_root___139 *);
	int (*mkdir)(struct kernfs_node___139 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___139 *);
	int (*rename)(struct kernfs_node___139 *, struct kernfs_node___139 *, const char *);
	int (*show_path)(struct seq_file___130 *, struct kernfs_node___139 *, struct kernfs_root___139 *);
};

struct seq_operations___130;

struct seq_file___130 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___130 *op;
	int poll_event;
	const struct file___152 *file;
	void *private;
};

struct kernfs_open_file___139 {
	struct kernfs_node___139 *kn;
	struct file___152 *file;
	struct seq_file___130 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___148 *vm_ops;
};

typedef void (*poll_queue_proc___96)(struct file___152 *, wait_queue_head_t *, struct poll_table_struct___94 *);

struct poll_table_struct___94 {
	poll_queue_proc___96 _qproc;
	__poll_t _key;
};

struct pid_namespace___133;

struct upid___133 {
	int nr;
	struct pid_namespace___133 *ns;
};

struct pid_namespace___133 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___159 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___133 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___133 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___133 numbers[1];
};

struct signal_struct___153 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___159 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___159 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___133 *pids[4];
	struct pid___133 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___158 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___25 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___8 *session_keyring;
	struct key___8 *process_keyring;
	struct key___8 *thread_keyring;
	struct key___8 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct nsproxy___142 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___133 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___136 {
	struct vm_struct___136 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___157 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___139;

struct attribute_group___139 {
	const char *name;
	umode_t (*is_visible)(struct kobject___139 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___139 *, struct bin_attribute___139 *, int);
	struct attribute **attrs;
	struct bin_attribute___139 **bin_attrs;
};

struct bin_attribute___139 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___152 * (*f_mapping)();
	ssize_t (*read)(struct file___152 *, struct kobject___139 *, struct bin_attribute___139 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___152 *, struct kobject___139 *, struct bin_attribute___139 *, char *, loff_t, size_t);
	int (*mmap)(struct file___152 *, struct kobject___139 *, struct bin_attribute___139 *, struct vm_area_struct___157 *);
};

struct sysfs_ops___139 {
	ssize_t (*show)(struct kobject___139 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___139 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___139;

struct kset___139 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___139 kobj;
	const struct kset_uevent_ops___139 *uevent_ops;
};

struct kobj_type___139 {
	void (*release)(struct kobject___139 *);
	const struct sysfs_ops___139 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___139 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___139 *);
	const void * (*namespace)(struct kobject___139 *);
	void (*get_ownership)(struct kobject___139 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___139 {
	int (* const filter)(struct kset___139 *, struct kobject___139 *);
	const char * (* const name)(struct kset___139 *, struct kobject___139 *);
	int (* const uevent)(struct kset___139 *, struct kobject___139 *, struct kobj_uevent_env *);
};

struct dentry_operations___152;

struct dentry___152 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___152 *d_parent;
	struct qstr d_name;
	struct inode___152 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___152 *d_op;
	struct super_block___152 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___152;

struct cdev___24;

struct inode___152 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___152 *i_op;
	struct super_block___152 *i_sb;
	struct address_space___152 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___152 *i_fop;
		void (*free_inode)(struct inode___152 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___152 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___24 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___152 {
	int (*d_revalidate)(struct dentry___152 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___152 *, unsigned int);
	int (*d_hash)(const struct dentry___152 *, struct qstr *);
	int (*d_compare)(const struct dentry___152 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___152 *);
	int (*d_init)(struct dentry___152 *);
	void (*d_release)(struct dentry___152 *);
	void (*d_prune)(struct dentry___152 *);
	void (*d_iput)(struct dentry___152 *, struct inode___152 *);
	char * (*d_dname)(struct dentry___152 *, char *, int);
	struct vfsmount___152 * (*d_automount)(struct path___152 *);
	int (*d_manage)(const struct path___152 *, bool);
	struct dentry___152 * (*d_real)(struct dentry___152 *, const struct inode___152 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___152;

struct mem_dqinfo___152 {
	struct quota_format_type___152 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___152;

struct quota_info___152 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___152 *files[3];
	struct mem_dqinfo___152 info[3];
	const struct quota_format_ops___152 *ops[3];
};

struct rcuwait___153 {
	struct task_struct___159 *task;
};

struct percpu_rw_semaphore___153 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___153 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___152 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___153 rw_sem[3];
};

struct super_operations___152;

struct dquot_operations___152;

struct quotactl_ops___152;

struct super_block___152 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___152 *s_type;
	const struct super_operations___152 *s_op;
	const struct dquot_operations___152 *dq_op;
	const struct quotactl_ops___152 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___152 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___8 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___152 s_dquot;
	struct sb_writers___152 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___152 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___152 {
	struct dentry___152 *mnt_root;
	struct super_block___152 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___152 {
	struct file___152 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___152 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___152 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___152 *ia_file;
};

struct dquot___152 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___152 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___152 {
	int qf_fmt_id;
	const struct quota_format_ops___152 *qf_ops;
	struct module___137 *qf_owner;
	struct quota_format_type___152 *qf_next;
};

struct quota_format_ops___152 {
	int (*check_quota_file)(struct super_block___152 *, int);
	int (*read_file_info)(struct super_block___152 *, int);
	int (*write_file_info)(struct super_block___152 *, int);
	int (*free_file_info)(struct super_block___152 *, int);
	int (*read_dqblk)(struct dquot___152 *);
	int (*commit_dqblk)(struct dquot___152 *);
	int (*release_dqblk)(struct dquot___152 *);
	int (*get_next_id)(struct super_block___152 *, struct kqid *);
};

struct dquot_operations___152 {
	int (*write_dquot)(struct dquot___152 *);
	struct dquot___152 * (*alloc_dquot)(struct super_block___152 *, int);
	void (*destroy_dquot)(struct dquot___152 *);
	int (*acquire_dquot)(struct dquot___152 *);
	int (*release_dquot)(struct dquot___152 *);
	int (*mark_dirty)(struct dquot___152 *);
	int (*write_info)(struct super_block___152 *, int);
	qsize_t * (*get_reserved_space)(struct inode___152 *);
	int (*get_projid)(struct inode___152 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___152 *, qsize_t *);
	int (*get_next_id)(struct super_block___152 *, struct kqid *);
};

struct quotactl_ops___152 {
	int (*quota_on)(struct super_block___152 *, int, int, const struct path___152 *);
	int (*quota_off)(struct super_block___152 *, int);
	int (*quota_enable)(struct super_block___152 *, unsigned int);
	int (*quota_disable)(struct super_block___152 *, unsigned int);
	int (*quota_sync)(struct super_block___152 *, int);
	int (*set_info)(struct super_block___152 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___152 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___152 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___152 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___152 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___152 *, unsigned int);
};

struct address_space_operations___152 {
	int (*writepage)(struct page___157 *, struct writeback_control___3 *);
	int (*readpage)(struct file___152 *, struct page___157 *);
	int (*writepages)(struct address_space___152 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___157 *);
	int (*readpages)(struct file___152 *, struct address_space___152 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___152 *, struct address_space___152 *, loff_t, unsigned int, unsigned int, struct page___157 **, void **);
	int (*write_end)(struct file___152 *, struct address_space___152 *, loff_t, unsigned int, unsigned int, struct page___157 *, void *);
	sector_t (*bmap)(struct address_space___152 *, sector_t);
	void (*invalidatepage)(struct page___157 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___157 *, gfp_t);
	void (*freepage)(struct page___157 *);
	ssize_t (*direct_IO)(struct kiocb___152 *, struct iov_iter___82 *);
	int (*migratepage)(struct address_space___152 *, struct page___157 *, struct page___157 *, enum migrate_mode);
	bool (*isolate_page)(struct page___157 *, isolate_mode_t);
	void (*putback_page)(struct page___157 *);
	int (*launder_page)(struct page___157 *);
	int (*is_partially_uptodate)(struct page___157 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___157 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___152 *, struct page___157 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___152 *, sector_t *);
	void (*swap_deactivate)(struct file___152 *);
};

struct cdev___24 {
	struct kobject___139 kobj;
	struct module___137 *owner;
	const struct file_operations___152 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___152 {
	struct dentry___152 * (*lookup)(struct inode___152 *, struct dentry___152 *, unsigned int);
	const char * (*get_link)(struct dentry___152 *, struct inode___152 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___152 *, int);
	struct posix_acl * (*get_acl)(struct inode___152 *, int, bool);
	int (*readlink)(struct dentry___152 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___152 *, struct dentry___152 *, umode_t, bool);
	int (*link)(struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*unlink)(struct inode___152 *, struct dentry___152 *);
	int (*symlink)(struct user_namespace *, struct inode___152 *, struct dentry___152 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___152 *, struct dentry___152 *, umode_t);
	int (*rmdir)(struct inode___152 *, struct dentry___152 *);
	int (*mknod)(struct user_namespace *, struct inode___152 *, struct dentry___152 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___152 *, struct dentry___152 *, struct inode___152 *, struct dentry___152 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___152 *, struct iattr___152 *);
	int (*getattr)(struct user_namespace *, const struct path___152 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___152 *, char *, size_t);
	int (*fiemap)(struct inode___152 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___152 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___152 *, struct dentry___152 *, struct file___152 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___152 *, struct dentry___152 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___152 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___152 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___152 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___152 {
	void (*fl_copy_lock)(struct file_lock___152 *, struct file_lock___152 *);
	void (*fl_release_private)(struct file_lock___152 *);
};

struct fasync_struct___152;

struct lock_manager_operations___152;

struct file_lock___152 {
	struct file_lock___152 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___152 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___152 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___152 *fl_ops;
	const struct lock_manager_operations___152 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___152 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___152 *);
	int (*lm_grant)(struct file_lock___152 *, int);
	bool (*lm_break)(struct file_lock___152 *);
	int (*lm_change)(struct file_lock___152 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___152 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___152 *);
};

struct fasync_struct___152 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___152 *fa_next;
	struct file___152 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___152 {
	struct inode___152 * (*alloc_inode)(struct super_block___152 *);
	void (*destroy_inode)(struct inode___152 *);
	void (*free_inode)(struct inode___152 *);
	void (*dirty_inode)(struct inode___152 *, int);
	int (*write_inode)(struct inode___152 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___152 *);
	void (*evict_inode)(struct inode___152 *);
	void (*put_super)(struct super_block___152 *);
	int (*sync_fs)(struct super_block___152 *, int);
	int (*freeze_super)(struct super_block___152 *);
	int (*freeze_fs)(struct super_block___152 *);
	int (*thaw_super)(struct super_block___152 *);
	int (*unfreeze_fs)(struct super_block___152 *);
	int (*statfs)(struct dentry___152 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___152 *, int *, char *);
	void (*umount_begin)(struct super_block___152 *);
	int (*show_options)(struct seq_file___130 *, struct dentry___152 *);
	int (*show_devname)(struct seq_file___130 *, struct dentry___152 *);
	int (*show_path)(struct seq_file___130 *, struct dentry___152 *);
	int (*show_stats)(struct seq_file___130 *, struct dentry___152 *);
	ssize_t (*quota_read)(struct super_block___152 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___152 *, int, const char *, size_t, loff_t);
	struct dquot___152 ** (*get_dquots)(struct inode___152 *);
	long int (*nr_cached_objects)(struct super_block___152 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___152 *, struct shrink_control___54 *);
	struct file___152 * (*real_loop)(struct file___152 *);
};

struct kernel_param_ops___136 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___136 *);
	int (*get)(char *, const struct kernel_param___136 *);
	void (*free)(void *);
};

struct kparam_array___136;

struct kernel_param___136 {
	const char *name;
	struct module___137 *mod;
	const struct kernel_param_ops___136 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___136 *arr;
	};
};

struct kparam_array___136 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___136 *ops;
	void *elem;
};

struct module_attribute___136 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___136 *, struct module_kobject___136 *, char *);
	ssize_t (*store)(struct module_attribute___136 *, struct module_kobject___136 *, const char *, size_t);
	void (*setup)(struct module___137 *, const char *);
	int (*test)(struct module___137 *);
	void (*free)(struct module___137 *);
};

struct seq_operations___130 {
	void * (*start)(struct seq_file___130 *, loff_t *);
	void (*stop)(struct seq_file___130 *, void *);
	void * (*next)(struct seq_file___130 *, void *, loff_t *);
	int (*show)(struct seq_file___130 *, void *);
};

struct dev_pagemap_ops___148 {
	void (*page_free)(struct page___157 *);
	void (*kill)(struct dev_pagemap___148 *);
	void (*cleanup)(struct dev_pagemap___148 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___148 *);
};

enum tpm_duration {
	TPM_SHORT = 0,
	TPM_MEDIUM = 1,
	TPM_LONG = 2,
	TPM_LONG_LONG = 3,
	TPM_UNDEFINED = 4,
	TPM_NUM_DURATIONS = 4,
};

struct trusted_key_payload {
	struct callback_head rcu;
	unsigned int key_len;
	unsigned int blob_len;
	unsigned char migratable;
	unsigned char old_format;
	unsigned char key[129];
	unsigned char blob[512];
};

struct trusted_key_ops {
	unsigned char migratable;
	int (*init)();
	int (*seal)(struct trusted_key_payload *, char *);
	int (*unseal)(struct trusted_key_payload *, char *);
	int (*get_random)(unsigned char *, size_t);
	void (*exit)();
};

struct trusted_key_source {
	char *name;
	struct trusted_key_ops *ops;
};

struct key_match_data___7 {
	bool (*cmp)(const struct key___8 *, const struct key_match_data___7 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

enum {
	Opt_err___7 = 0,
	Opt_new = 1,
	Opt_load = 2,
	Opt_update = 3,
};

struct dentry___153;

struct super_block___153;

struct module___138;

struct file_system_type___153 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___153 * (*mount)(struct file_system_type___153 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___153 *);
	struct module___138 *owner;
	struct file_system_type___153 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___153;

struct kiocb___153;

struct poll_table_struct___95;

struct vm_area_struct___158;

struct inode___153;

struct file_lock___153;

struct page___158;

struct seq_file___131;

struct file_operations___153 {
	struct module___138 *owner;
	loff_t (*llseek)(struct file___153 *, loff_t, int);
	ssize_t (*read)(struct file___153 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___153 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___153 *, struct iov_iter___82 *);
	ssize_t (*write_iter)(struct kiocb___153 *, struct iov_iter___82 *);
	int (*iopoll)(struct kiocb___153 *, bool);
	int (*iterate)(struct file___153 *, struct dir_context *);
	int (*iterate_shared)(struct file___153 *, struct dir_context *);
	__poll_t (*poll)(struct file___153 *, struct poll_table_struct___95 *);
	long int (*unlocked_ioctl)(struct file___153 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___153 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___153 *, struct vm_area_struct___158 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___153 *, struct file___153 *);
	int (*flush)(struct file___153 *, fl_owner_t);
	int (*release)(struct inode___153 *, struct file___153 *);
	int (*fsync)(struct file___153 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___153 *, int);
	int (*lock)(struct file___153 *, int, struct file_lock___153 *);
	ssize_t (*sendpage)(struct file___153 *, struct page___158 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___153 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___153 *, long unsigned int);
	int (*flock)(struct file___153 *, int, struct file_lock___153 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___153 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___153 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___153 *, long int, struct file_lock___153 **, void **);
	long int (*fallocate)(struct file___153 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___131 *, struct file___153 *);
	ssize_t (*copy_file_range)(struct file___153 *, loff_t, struct file___153 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___153 *, loff_t, struct file___153 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___153 *, loff_t, loff_t, int);
};

struct vmacache___158 {
	u64 seqnum;
	struct vm_area_struct___158 *vmas[4];
};

struct page_frag___158 {
	struct page___158 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___159;

struct pid___134;

struct cred___26;

struct key___9;

struct nsproxy___143;

struct signal_struct___154;

struct vm_struct___137;

struct task_struct___160 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___160 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___159 *mm;
	struct mm_struct___159 *active_mm;
	struct vmacache___158 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___160 *real_parent;
	struct task_struct___160 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___160 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___134 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	struct key___9 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___143 *nsproxy;
	struct signal_struct___154 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___160 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___66 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___158 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___160 *oom_reaper_list;
	struct vm_struct___137 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___140;

struct kobj_type___140;

struct kernfs_node___140;

struct kobject___140 {
	const char *name;
	struct list_head entry;
	struct kobject___140 *parent;
	struct kset___140 *kset;
	struct kobj_type___140 *ktype;
	struct kernfs_node___140 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___137 {
	struct kobject___140 kobj;
	struct module___138 *mod;
	struct kobject___140 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___137 {
	struct module___138 *mod;
	struct latch_tree_node node;
};

struct module_layout___137 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___137 mtn;
};

struct module_attribute___137;

struct kernel_param___137;

struct module___138 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___137 mkobj;
	struct module_attribute___137 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___140 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___137 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___137 core_layout;
	struct module_layout___137 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___158 *pgtable_t___158;

struct address_space___153;

struct dev_pagemap___149;

struct page___158 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___153 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___37 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___158 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___158 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___159 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___149 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___149;

struct vm_area_struct___158 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___158 *vm_next;
	struct vm_area_struct___158 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___159 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___149 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___153 *vm_file;
	struct file___153 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___158;

struct mm_struct___159 {
	struct {
		struct vm_area_struct___158 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___153 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___158 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___160 *owner;
		struct user_namespace *user_ns;
		struct file___153 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___153;

struct address_space___153 {
	struct inode___153 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___153 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___149;

struct dev_pagemap___149 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___149 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___153;

struct path___153 {
	struct vfsmount___153 *mnt;
	struct dentry___153 *dentry;
};

struct fown_struct___134 {
	rwlock_t lock;
	struct pid___134 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___153 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___153 f_path;
	struct inode___153 *f_inode;
	const struct file_operations___153 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___134 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___153 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___149;

struct vm_operations_struct___149 {
	void (*open)(struct vm_area_struct___158 *);
	void (*close)(struct vm_area_struct___158 *);
	int (*may_split)(struct vm_area_struct___158 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___158 *);
	int (*mprotect)(struct vm_area_struct___158 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___149 *);
	vm_fault_t (*huge_fault)(struct vm_fault___149 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___149 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___158 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___149 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___149 *);
	int (*access)(struct vm_area_struct___158 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___158 *);
	int (*set_policy)(struct vm_area_struct___158 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___158 *, long unsigned int);
	struct page___158 * (*find_special_page)(struct vm_area_struct___158 *, long unsigned int);
};

struct core_thread___158 {
	struct task_struct___160 *task;
	struct core_thread___158 *next;
};

struct core_state___158 {
	atomic_t nr_threads;
	struct core_thread___158 dumper;
	struct completion startup;
};

struct vm_fault___149 {
	const struct {
		struct vm_area_struct___158 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___158 *cow_page;
	struct page___158 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___158 prealloc_pte;
};

struct key_type___8;

struct keyring_index_key___8 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___8 *type;
	struct key_tag *domain_tag;
	const char *description;
};

typedef int (*request_key_actor_t___8)(struct key___9 *, void *);

struct key_match_data___8;

struct key_restriction___9;

struct key_type___8 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___9 *, struct key_preparsed_payload *);
	int (*update)(struct key___9 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___8 *);
	void (*match_free)(struct key_match_data___8 *);
	void (*revoke)(struct key___9 *);
	void (*destroy)(struct key___9 *);
	void (*describe)(const struct key___9 *, struct seq_file___131 *);
	long int (*read)(const struct key___9 *, char *, size_t);
	request_key_actor_t___8 request_key;
	struct key_restriction___9 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___2 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___2 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___2 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___10)(struct key___9 *, const struct key_type___8 *, const union key_payload *, struct key___9 *);

struct key___9 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___8 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___8 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___9 *restrict_link;
};

struct key_restriction___9 {
	key_restrict_link_func_t___10 check;
	struct key___9 *key;
	struct key_type___8 *keytype;
};

struct hwrng {
	const char *name;
	int (*init)(struct hwrng *);
	void (*cleanup)(struct hwrng *);
	int (*data_present)(struct hwrng *, int);
	int (*data_read)(struct hwrng *, u32 *);
	int (*read)(struct hwrng *, void *, size_t, bool);
	long unsigned int priv;
	short unsigned int quality;
	struct list_head list;
	struct kref ref;
	struct completion cleanup_done;
};

struct irq_desc___17;

typedef void (*irq_flow_handler_t___17)(struct irq_desc___17 *);

struct irq_chip___16;

struct irq_domain___15;

struct irq_data___16 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___16 *chip;
	struct irq_domain___15 *domain;
	struct irq_data___16 *parent_data;
	void *chip_data;
};

struct irqaction___12;

struct irq_desc___17 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___16 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___17 handle_irq;
	struct irqaction___12 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___140 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___138 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kernfs_root___140;

struct kernfs_elem_dir___140 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___140 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___140;

struct kernfs_root___140 {
	struct kernfs_node___140 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___140 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___140 {
	struct kernfs_node___140 *target_kn;
};

struct kernfs_ops___140;

struct kernfs_elem_attr___140 {
	const struct kernfs_ops___140 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___140 *notify_next;
};

struct kernfs_node___140 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___140 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___140 dir;
		struct kernfs_elem_symlink___140 symlink;
		struct kernfs_elem_attr___140 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___140;

struct kernfs_ops___140 {
	int (*open)(struct kernfs_open_file___140 *);
	void (*release)(struct kernfs_open_file___140 *);
	int (*seq_show)(struct seq_file___131 *, void *);
	void * (*seq_start)(struct seq_file___131 *, loff_t *);
	void * (*seq_next)(struct seq_file___131 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___131 *, void *);
	ssize_t (*read)(struct kernfs_open_file___140 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___140 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___140 *, struct poll_table_struct___95 *);
	int (*mmap)(struct kernfs_open_file___140 *, struct vm_area_struct___158 *);
};

struct kernfs_syscall_ops___140 {
	int (*show_options)(struct seq_file___131 *, struct kernfs_root___140 *);
	int (*mkdir)(struct kernfs_node___140 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___140 *);
	int (*rename)(struct kernfs_node___140 *, struct kernfs_node___140 *, const char *);
	int (*show_path)(struct seq_file___131 *, struct kernfs_node___140 *, struct kernfs_root___140 *);
};

struct seq_operations___131;

struct seq_file___131 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___131 *op;
	int poll_event;
	const struct file___153 *file;
	void *private;
};

struct kernfs_open_file___140 {
	struct kernfs_node___140 *kn;
	struct file___153 *file;
	struct seq_file___131 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___149 *vm_ops;
};

typedef void (*poll_queue_proc___97)(struct file___153 *, wait_queue_head_t *, struct poll_table_struct___95 *);

struct poll_table_struct___95 {
	poll_queue_proc___97 _qproc;
	__poll_t _key;
};

struct pid_namespace___134;

struct upid___134 {
	int nr;
	struct pid_namespace___134 *ns;
};

struct pid_namespace___134 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___160 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___134 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___134 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___134 numbers[1];
};

struct signal_struct___154 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___160 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___160 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___134 *pids[4];
	struct pid___134 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___159 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___26 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___9 *session_keyring;
	struct key___9 *process_keyring;
	struct key___9 *thread_keyring;
	struct key___9 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct nsproxy___143 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___134 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___137 {
	struct vm_struct___137 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___158 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___140;

struct attribute_group___140 {
	const char *name;
	umode_t (*is_visible)(struct kobject___140 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___140 *, struct bin_attribute___140 *, int);
	struct attribute **attrs;
	struct bin_attribute___140 **bin_attrs;
};

struct bin_attribute___140 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___153 * (*f_mapping)();
	ssize_t (*read)(struct file___153 *, struct kobject___140 *, struct bin_attribute___140 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___153 *, struct kobject___140 *, struct bin_attribute___140 *, char *, loff_t, size_t);
	int (*mmap)(struct file___153 *, struct kobject___140 *, struct bin_attribute___140 *, struct vm_area_struct___158 *);
};

struct sysfs_ops___140 {
	ssize_t (*show)(struct kobject___140 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___140 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___140;

struct kset___140 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___140 kobj;
	const struct kset_uevent_ops___140 *uevent_ops;
};

struct kobj_type___140 {
	void (*release)(struct kobject___140 *);
	const struct sysfs_ops___140 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___140 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___140 *);
	const void * (*namespace)(struct kobject___140 *);
	void (*get_ownership)(struct kobject___140 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___140 {
	int (* const filter)(struct kset___140 *, struct kobject___140 *);
	const char * (* const name)(struct kset___140 *, struct kobject___140 *);
	int (* const uevent)(struct kset___140 *, struct kobject___140 *, struct kobj_uevent_env *);
};

struct fwnode_operations___109;

struct device___109;

struct fwnode_handle___109 {
	struct fwnode_handle___109 *secondary;
	const struct fwnode_operations___109 *ops;
	struct device___109 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___109;

struct fwnode_endpoint___109;

struct fwnode_operations___109 {
	struct fwnode_handle___109 * (*get)(struct fwnode_handle___109 *);
	void (*put)(struct fwnode_handle___109 *);
	bool (*device_is_available)(const struct fwnode_handle___109 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___109 *, const struct device___109 *);
	bool (*property_present)(const struct fwnode_handle___109 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___109 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___109 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___109 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*get_parent)(const struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*get_next_child_node)(const struct fwnode_handle___109 *, struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*get_named_child_node)(const struct fwnode_handle___109 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___109 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___109 *);
	struct fwnode_handle___109 * (*graph_get_next_endpoint)(const struct fwnode_handle___109 *, struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*graph_get_remote_endpoint)(const struct fwnode_handle___109 *);
	struct fwnode_handle___109 * (*graph_get_port_parent)(struct fwnode_handle___109 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___109 *, struct fwnode_endpoint___109 *);
	int (*add_links)(struct fwnode_handle___109 *);
};

struct wakeup_source___109;

struct dev_pm_info___109 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___109 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___109 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___109;

struct bus_type___109;

struct device_driver___109;

struct dev_pm_domain___109;

struct device_node___34;

struct class___109;

struct device___109 {
	struct kobject___140 kobj;
	struct device___109 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___109 *type;
	struct bus_type___109 *bus;
	struct device_driver___109 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___109 power;
	struct dev_pm_domain___109 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___15 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___34 *of_node;
	struct fwnode_handle___109 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___109 *class;
	const struct attribute_group___140 **groups;
	void (*release)(struct device___109 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___109 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___109 *local_fwnode;
};

struct fwnode_reference_args___109 {
	struct fwnode_handle___109 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___30 {
	char *name;
	int length;
	void *value;
	struct property___30 *next;
	long unsigned int _flags;
	struct bin_attribute___140 attr;
};

struct device_node___34 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___109 fwnode;
	struct property___30 *properties;
	struct property___30 *deadprops;
	struct device_node___34 *parent;
	struct device_node___34 *child;
	struct device_node___34 *sibling;
	struct kobject___140 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___14 {
	struct fwnode_handle___109 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___15 {
	int (*match)(struct irq_domain___15 *, struct device_node___34 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___15 *, struct irq_fwspec___14 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___15 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___15 *, unsigned int);
	int (*xlate)(struct irq_domain___15 *, struct device_node___34 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___15 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___15 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___15 *, struct irq_data___16 *, bool);
	void (*deactivate)(struct irq_domain___15 *, struct irq_data___16 *);
	int (*translate)(struct irq_domain___15 *, struct irq_fwspec___14 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___15;

struct irq_domain___15 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___15 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___109 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___15 *gc;
	struct irq_domain___15 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___16 *revmap[0];
};

struct irq_chip_generic___15;

struct irq_domain_chip_generic___15 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___15 *gc[0];
};

struct dev_pm_ops___109 {
	int (*prepare)(struct device___109 *);
	void (*complete)(struct device___109 *);
	int (*suspend)(struct device___109 *);
	int (*resume)(struct device___109 *);
	int (*freeze)(struct device___109 *);
	int (*thaw)(struct device___109 *);
	int (*poweroff)(struct device___109 *);
	int (*restore)(struct device___109 *);
	int (*suspend_late)(struct device___109 *);
	int (*resume_early)(struct device___109 *);
	int (*freeze_late)(struct device___109 *);
	int (*thaw_early)(struct device___109 *);
	int (*poweroff_late)(struct device___109 *);
	int (*restore_early)(struct device___109 *);
	int (*suspend_noirq)(struct device___109 *);
	int (*resume_noirq)(struct device___109 *);
	int (*freeze_noirq)(struct device___109 *);
	int (*thaw_noirq)(struct device___109 *);
	int (*poweroff_noirq)(struct device___109 *);
	int (*restore_noirq)(struct device___109 *);
	int (*runtime_suspend)(struct device___109 *);
	int (*runtime_resume)(struct device___109 *);
	int (*runtime_idle)(struct device___109 *);
};

struct wakeup_source___109 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___109 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___109 {
	struct dev_pm_ops___109 ops;
	int (*start)(struct device___109 *);
	void (*detach)(struct device___109 *, bool);
	int (*activate)(struct device___109 *);
	void (*sync)(struct device___109 *);
	void (*dismiss)(struct device___109 *);
};

struct bus_type___109 {
	const char *name;
	const char *dev_name;
	struct device___109 *dev_root;
	const struct attribute_group___140 **bus_groups;
	const struct attribute_group___140 **dev_groups;
	const struct attribute_group___140 **drv_groups;
	int (*match)(struct device___109 *, struct device_driver___109 *);
	int (*uevent)(struct device___109 *, struct kobj_uevent_env *);
	int (*probe)(struct device___109 *);
	void (*sync_state)(struct device___109 *);
	void (*remove)(struct device___109 *);
	void (*shutdown)(struct device___109 *);
	int (*online)(struct device___109 *);
	int (*offline)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	int (*num_vf)(struct device___109 *);
	int (*dma_configure)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___109 {
	const char *name;
	struct bus_type___109 *bus;
	struct module___138 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___109 *);
	void (*sync_state)(struct device___109 *);
	int (*remove)(struct device___109 *);
	void (*shutdown)(struct device___109 *);
	int (*suspend)(struct device___109 *, pm_message_t);
	int (*resume)(struct device___109 *);
	const struct attribute_group___140 **groups;
	const struct attribute_group___140 **dev_groups;
	const struct dev_pm_ops___109 *pm;
	void (*coredump)(struct device___109 *);
	struct driver_private *p;
};

struct device_type___109 {
	const char *name;
	const struct attribute_group___140 **groups;
	int (*uevent)(struct device___109 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___109 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___109 *);
	const struct dev_pm_ops___109 *pm;
};

struct class___109 {
	const char *name;
	struct module___138 *owner;
	const struct attribute_group___140 **class_groups;
	const struct attribute_group___140 **dev_groups;
	struct kobject___140 *dev_kobj;
	int (*dev_uevent)(struct device___109 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___109 *, umode_t *);
	void (*class_release)(struct class___109 *);
	void (*dev_release)(struct device___109 *);
	int (*shutdown_pre)(struct device___109 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___109 *);
	void (*get_ownership)(struct device___109 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___109 *pm;
	struct subsys_private *p;
};

struct dentry_operations___153;

struct dentry___153 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___153 *d_parent;
	struct qstr d_name;
	struct inode___153 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___153 *d_op;
	struct super_block___153 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___153;

struct cdev___25;

struct inode___153 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___153 *i_op;
	struct super_block___153 *i_sb;
	struct address_space___153 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___153 *i_fop;
		void (*free_inode)(struct inode___153 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___153 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___25 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___153 {
	int (*d_revalidate)(struct dentry___153 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___153 *, unsigned int);
	int (*d_hash)(const struct dentry___153 *, struct qstr *);
	int (*d_compare)(const struct dentry___153 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___153 *);
	int (*d_init)(struct dentry___153 *);
	void (*d_release)(struct dentry___153 *);
	void (*d_prune)(struct dentry___153 *);
	void (*d_iput)(struct dentry___153 *, struct inode___153 *);
	char * (*d_dname)(struct dentry___153 *, char *, int);
	struct vfsmount___153 * (*d_automount)(struct path___153 *);
	int (*d_manage)(const struct path___153 *, bool);
	struct dentry___153 * (*d_real)(struct dentry___153 *, const struct inode___153 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___153;

struct mem_dqinfo___153 {
	struct quota_format_type___153 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___153;

struct quota_info___153 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___153 *files[3];
	struct mem_dqinfo___153 info[3];
	const struct quota_format_ops___153 *ops[3];
};

struct rcuwait___154 {
	struct task_struct___160 *task;
};

struct percpu_rw_semaphore___154 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___154 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___153 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___154 rw_sem[3];
};

struct super_operations___153;

struct dquot_operations___153;

struct quotactl_ops___153;

struct super_block___153 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___153 *s_type;
	const struct super_operations___153 *s_op;
	const struct dquot_operations___153 *dq_op;
	const struct quotactl_ops___153 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___153 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___9 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___153 s_dquot;
	struct sb_writers___153 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___153 *s_d_op;
	int cleancache_poolid;
	struct shrinker___54 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___153 {
	struct dentry___153 *mnt_root;
	struct super_block___153 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___153 {
	struct file___153 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___153 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___71 *ki_waitq;
	};
};

struct iattr___153 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___153 *ia_file;
};

struct dquot___153 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___153 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___153 {
	int qf_fmt_id;
	const struct quota_format_ops___153 *qf_ops;
	struct module___138 *qf_owner;
	struct quota_format_type___153 *qf_next;
};

struct quota_format_ops___153 {
	int (*check_quota_file)(struct super_block___153 *, int);
	int (*read_file_info)(struct super_block___153 *, int);
	int (*write_file_info)(struct super_block___153 *, int);
	int (*free_file_info)(struct super_block___153 *, int);
	int (*read_dqblk)(struct dquot___153 *);
	int (*commit_dqblk)(struct dquot___153 *);
	int (*release_dqblk)(struct dquot___153 *);
	int (*get_next_id)(struct super_block___153 *, struct kqid *);
};

struct dquot_operations___153 {
	int (*write_dquot)(struct dquot___153 *);
	struct dquot___153 * (*alloc_dquot)(struct super_block___153 *, int);
	void (*destroy_dquot)(struct dquot___153 *);
	int (*acquire_dquot)(struct dquot___153 *);
	int (*release_dquot)(struct dquot___153 *);
	int (*mark_dirty)(struct dquot___153 *);
	int (*write_info)(struct super_block___153 *, int);
	qsize_t * (*get_reserved_space)(struct inode___153 *);
	int (*get_projid)(struct inode___153 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___153 *, qsize_t *);
	int (*get_next_id)(struct super_block___153 *, struct kqid *);
};

struct quotactl_ops___153 {
	int (*quota_on)(struct super_block___153 *, int, int, const struct path___153 *);
	int (*quota_off)(struct super_block___153 *, int);
	int (*quota_enable)(struct super_block___153 *, unsigned int);
	int (*quota_disable)(struct super_block___153 *, unsigned int);
	int (*quota_sync)(struct super_block___153 *, int);
	int (*set_info)(struct super_block___153 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___153 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___153 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___153 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___153 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___153 *, unsigned int);
};

struct address_space_operations___153 {
	int (*writepage)(struct page___158 *, struct writeback_control___3 *);
	int (*readpage)(struct file___153 *, struct page___158 *);
	int (*writepages)(struct address_space___153 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___158 *);
	int (*readpages)(struct file___153 *, struct address_space___153 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___153 *, struct address_space___153 *, loff_t, unsigned int, unsigned int, struct page___158 **, void **);
	int (*write_end)(struct file___153 *, struct address_space___153 *, loff_t, unsigned int, unsigned int, struct page___158 *, void *);
	sector_t (*bmap)(struct address_space___153 *, sector_t);
	void (*invalidatepage)(struct page___158 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___158 *, gfp_t);
	void (*freepage)(struct page___158 *);
	ssize_t (*direct_IO)(struct kiocb___153 *, struct iov_iter___82 *);
	int (*migratepage)(struct address_space___153 *, struct page___158 *, struct page___158 *, enum migrate_mode);
	bool (*isolate_page)(struct page___158 *, isolate_mode_t);
	void (*putback_page)(struct page___158 *);
	int (*launder_page)(struct page___158 *);
	int (*is_partially_uptodate)(struct page___158 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___158 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___153 *, struct page___158 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___153 *, sector_t *);
	void (*swap_deactivate)(struct file___153 *);
};

struct cdev___25 {
	struct kobject___140 kobj;
	struct module___138 *owner;
	const struct file_operations___153 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___153 {
	struct dentry___153 * (*lookup)(struct inode___153 *, struct dentry___153 *, unsigned int);
	const char * (*get_link)(struct dentry___153 *, struct inode___153 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___153 *, int);
	struct posix_acl * (*get_acl)(struct inode___153 *, int, bool);
	int (*readlink)(struct dentry___153 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___153 *, struct dentry___153 *, umode_t, bool);
	int (*link)(struct dentry___153 *, struct inode___153 *, struct dentry___153 *);
	int (*unlink)(struct inode___153 *, struct dentry___153 *);
	int (*symlink)(struct user_namespace *, struct inode___153 *, struct dentry___153 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___153 *, struct dentry___153 *, umode_t);
	int (*rmdir)(struct inode___153 *, struct dentry___153 *);
	int (*mknod)(struct user_namespace *, struct inode___153 *, struct dentry___153 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___153 *, struct dentry___153 *, struct inode___153 *, struct dentry___153 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___153 *, struct iattr___153 *);
	int (*getattr)(struct user_namespace *, const struct path___153 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___153 *, char *, size_t);
	int (*fiemap)(struct inode___153 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___153 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___153 *, struct dentry___153 *, struct file___153 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___153 *, struct dentry___153 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___153 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___153 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___153 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___153 {
	void (*fl_copy_lock)(struct file_lock___153 *, struct file_lock___153 *);
	void (*fl_release_private)(struct file_lock___153 *);
};

struct fasync_struct___153;

struct lock_manager_operations___153;

struct file_lock___153 {
	struct file_lock___153 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___153 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___153 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___153 *fl_ops;
	const struct lock_manager_operations___153 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___153 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___153 *);
	int (*lm_grant)(struct file_lock___153 *, int);
	bool (*lm_break)(struct file_lock___153 *);
	int (*lm_change)(struct file_lock___153 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___153 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___153 *);
};

struct fasync_struct___153 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___153 *fa_next;
	struct file___153 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___153 {
	struct inode___153 * (*alloc_inode)(struct super_block___153 *);
	void (*destroy_inode)(struct inode___153 *);
	void (*free_inode)(struct inode___153 *);
	void (*dirty_inode)(struct inode___153 *, int);
	int (*write_inode)(struct inode___153 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___153 *);
	void (*evict_inode)(struct inode___153 *);
	void (*put_super)(struct super_block___153 *);
	int (*sync_fs)(struct super_block___153 *, int);
	int (*freeze_super)(struct super_block___153 *);
	int (*freeze_fs)(struct super_block___153 *);
	int (*thaw_super)(struct super_block___153 *);
	int (*unfreeze_fs)(struct super_block___153 *);
	int (*statfs)(struct dentry___153 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___153 *, int *, char *);
	void (*umount_begin)(struct super_block___153 *);
	int (*show_options)(struct seq_file___131 *, struct dentry___153 *);
	int (*show_devname)(struct seq_file___131 *, struct dentry___153 *);
	int (*show_path)(struct seq_file___131 *, struct dentry___153 *);
	int (*show_stats)(struct seq_file___131 *, struct dentry___153 *);
	ssize_t (*quota_read)(struct super_block___153 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___153 *, int, const char *, size_t, loff_t);
	struct dquot___153 ** (*get_dquots)(struct inode___153 *);
	long int (*nr_cached_objects)(struct super_block___153 *, struct shrink_control___54 *);
	long int (*free_cached_objects)(struct super_block___153 *, struct shrink_control___54 *);
	struct file___153 * (*real_loop)(struct file___153 *);
};

struct kernel_param_ops___137 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___137 *);
	int (*get)(char *, const struct kernel_param___137 *);
	void (*free)(void *);
};

struct kparam_array___137;

struct kernel_param___137 {
	const char *name;
	struct module___138 *mod;
	const struct kernel_param_ops___137 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___137 *arr;
	};
};

struct kparam_array___137 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___137 *ops;
	void *elem;
};

struct module_attribute___137 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___137 *, struct module_kobject___137 *, char *);
	ssize_t (*store)(struct module_attribute___137 *, struct module_kobject___137 *, const char *, size_t);
	void (*setup)(struct module___138 *, const char *);
	int (*test)(struct module___138 *);
	void (*free)(struct module___138 *);
};

struct irq_chip___16 {
	struct device___109 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___16 *);
	void (*irq_shutdown)(struct irq_data___16 *);
	void (*irq_enable)(struct irq_data___16 *);
	void (*irq_disable)(struct irq_data___16 *);
	void (*irq_ack)(struct irq_data___16 *);
	void (*irq_mask)(struct irq_data___16 *);
	void (*irq_mask_ack)(struct irq_data___16 *);
	void (*irq_unmask)(struct irq_data___16 *);
	void (*irq_eoi)(struct irq_data___16 *);
	int (*irq_set_affinity)(struct irq_data___16 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___16 *);
	int (*irq_set_type)(struct irq_data___16 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___16 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___16 *);
	void (*irq_bus_sync_unlock)(struct irq_data___16 *);
	void (*irq_cpu_online)(struct irq_data___16 *);
	void (*irq_cpu_offline)(struct irq_data___16 *);
	void (*irq_suspend)(struct irq_data___16 *);
	void (*irq_resume)(struct irq_data___16 *);
	void (*irq_pm_shutdown)(struct irq_data___16 *);
	void (*irq_calc_mask)(struct irq_data___16 *);
	void (*irq_print_chip)(struct irq_data___16 *, struct seq_file___131 *);
	int (*irq_request_resources)(struct irq_data___16 *);
	void (*irq_release_resources)(struct irq_data___16 *);
	void (*irq_compose_msi_msg)(struct irq_data___16 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___16 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___16 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___16 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___16 *, void *);
	void (*ipi_send_single)(struct irq_data___16 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___16 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___16 *);
	void (*irq_nmi_teardown)(struct irq_data___16 *);
	long unsigned int flags;
};

struct irqaction___12 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___12 *next;
	irq_handler_t thread_fn;
	struct task_struct___160 *thread;
	struct irqaction___12 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___15 {
	struct irq_chip___16 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___17 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___15 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___15 *);
	void (*resume)(struct irq_chip_generic___15 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___15 *domain;
	struct list_head list;
	struct irq_chip_type___15 chip_types[0];
};

struct seq_operations___131 {
	void * (*start)(struct seq_file___131 *, loff_t *);
	void (*stop)(struct seq_file___131 *, void *);
	void * (*next)(struct seq_file___131 *, void *, loff_t *);
	int (*show)(struct seq_file___131 *, void *);
};

struct dev_pagemap_ops___149 {
	void (*page_free)(struct page___158 *);
	void (*kill)(struct dev_pagemap___149 *);
	void (*cleanup)(struct dev_pagemap___149 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___149 *);
};

struct tpm_digest {
	u16 alg_id;
	u8 digest[64];
};

struct tpm_bank_info {
	u16 alg_id;
	u16 digest_size;
	u16 crypto_id;
};

struct tpm_chip;

struct tpm_class_ops {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip *, u8);
	int (*recv)(struct tpm_chip *, u8 *, size_t);
	int (*send)(struct tpm_chip *, u8 *, size_t);
	void (*cancel)(struct tpm_chip *);
	u8 (*status)(struct tpm_chip *);
	void (*update_timeouts)(struct tpm_chip *, long unsigned int *);
	void (*update_durations)(struct tpm_chip *, long unsigned int *);
	int (*go_idle)(struct tpm_chip *);
	int (*cmd_ready)(struct tpm_chip *);
	int (*request_locality)(struct tpm_chip *, int);
	int (*relinquish_locality)(struct tpm_chip *, int);
	void (*clk_enable)(struct tpm_chip *, bool);
};

struct tpm_bios_log {
	void *bios_event_log;
	void *bios_event_log_end;
};

struct tpm_chip_seqops {
	struct tpm_chip *chip;
	const struct seq_operations___131 *seqops;
};

struct tpm_space {
	u32 context_tbl[3];
	u8 *context_buf;
	u32 session_tbl[3];
	u8 *session_buf;
	u32 buf_size;
};

struct tpm_chip {
	struct device___109 dev;
	struct device___109 devs;
	struct cdev___25 cdev;
	struct cdev___25 cdevs;
	struct rw_semaphore ops_sem;
	const struct tpm_class_ops *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops bin_log_seqops;
	struct tpm_chip_seqops ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___153 *bios_dir[3];
	const struct attribute_group___140 *groups[8];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

struct tpm_header {
	__be16 tag;
	__be32 length;
	union {
		__be32 ordinal;
		__be32 return_code;
	};
} __attribute__((packed));

enum tpm_buf_flags {
	TPM_BUF_OVERFLOW = 1,
};

struct tpm_buf {
	unsigned int flags;
	u8 *data;
};

struct trusted_key_options {
	uint16_t keytype;
	uint32_t keyhandle;
	unsigned char keyauth[20];
	uint32_t blobauth_len;
	unsigned char blobauth[20];
	uint32_t pcrinfo_len;
	unsigned char pcrinfo[64];
	int pcrlock;
	uint32_t hash;
	uint32_t policydigest_len;
	unsigned char policydigest[64];
	uint32_t policyhandle;
};

struct key_match_data___8 {
	bool (*cmp)(const struct key___9 *, const struct key_match_data___8 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct crypto_alg___14;

struct crypto_tfm___14 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___14 *);
	struct crypto_alg___14 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___14 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___14 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___14 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___14 *, u8 *, const u8 *);
};

struct compress_alg___14 {
	int (*coa_compress)(struct crypto_tfm___14 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___14 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___14 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___14 cipher;
		struct compress_alg___14 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___14 *);
	void (*cra_exit)(struct crypto_tfm___14 *);
	void (*cra_destroy)(struct crypto_alg___14 *);
	struct module___138 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___10;

struct shash_desc___7 {
	struct crypto_shash___10 *tfm;
	void *__ctx[0];
};

struct crypto_shash___10 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___14 base;
};

struct shash_alg___2 {
	int (*init)(struct shash_desc___7 *);
	int (*update)(struct shash_desc___7 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___7 *, u8 *);
	int (*finup)(struct shash_desc___7 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___7 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___7 *, void *);
	int (*import)(struct shash_desc___7 *, const void *);
	int (*setkey)(struct crypto_shash___10 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___10 *);
	void (*exit_tfm)(struct crypto_shash___10 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___14 base;
};

struct osapsess {
	uint32_t handle;
	unsigned char secret[20];
	unsigned char enonce[20];
};

enum {
	SEAL_keytype = 1,
	SRK_keytype = 4,
};

struct sdesc {
	struct shash_desc___7 shash;
	char ctx[0];
};

struct tpm_digests {
	unsigned char encauth[20];
	unsigned char pubauth[20];
	unsigned char xorwork[40];
	unsigned char xorhash[20];
	unsigned char nonceodd[20];
};

enum {
	Opt_err___8 = 0,
	Opt_keyhandle = 1,
	Opt_keyauth = 2,
	Opt_blobauth = 3,
	Opt_pcrinfo = 4,
	Opt_pcrlock = 5,
	Opt_migratable = 6,
	Opt_hash___2 = 7,
	Opt_policydigest = 8,
	Opt_policyhandle = 9,
};

typedef int (*asn1_action_t)(void *, size_t, unsigned char, const void *, size_t);

struct asn1_decoder {
	const unsigned char *machine;
	size_t machlen;
	const asn1_action_t *actions;
};

enum OID {
	OID_id_dsa_with_sha1 = 0,
	OID_id_dsa = 1,
	OID_id_ecPublicKey = 2,
	OID_id_prime192v1 = 3,
	OID_id_prime256v1 = 4,
	OID_id_ecdsa_with_sha1 = 5,
	OID_id_ecdsa_with_sha224 = 6,
	OID_id_ecdsa_with_sha256 = 7,
	OID_id_ecdsa_with_sha384 = 8,
	OID_id_ecdsa_with_sha512 = 9,
	OID_rsaEncryption = 10,
	OID_md2WithRSAEncryption = 11,
	OID_md3WithRSAEncryption = 12,
	OID_md4WithRSAEncryption = 13,
	OID_sha1WithRSAEncryption = 14,
	OID_sha256WithRSAEncryption = 15,
	OID_sha384WithRSAEncryption = 16,
	OID_sha512WithRSAEncryption = 17,
	OID_sha224WithRSAEncryption = 18,
	OID_data = 19,
	OID_signed_data = 20,
	OID_email_address = 21,
	OID_contentType = 22,
	OID_messageDigest = 23,
	OID_signingTime = 24,
	OID_smimeCapabilites = 25,
	OID_smimeAuthenticatedAttrs = 26,
	OID_md2 = 27,
	OID_md4 = 28,
	OID_md5 = 29,
	OID_mskrb5 = 30,
	OID_krb5 = 31,
	OID_krb5u2u = 32,
	OID_msIndirectData = 33,
	OID_msStatementType = 34,
	OID_msSpOpusInfo = 35,
	OID_msPeImageDataObjId = 36,
	OID_msIndividualSPKeyPurpose = 37,
	OID_msOutlookExpress = 38,
	OID_ntlmssp = 39,
	OID_spnego = 40,
	OID_IAKerb = 41,
	OID_PKU2U = 42,
	OID_Scram = 43,
	OID_certAuthInfoAccess = 44,
	OID_sha1 = 45,
	OID_id_ansip384r1 = 46,
	OID_sha256 = 47,
	OID_sha384 = 48,
	OID_sha512 = 49,
	OID_sha224 = 50,
	OID_commonName = 51,
	OID_surname = 52,
	OID_countryName = 53,
	OID_locality = 54,
	OID_stateOrProvinceName = 55,
	OID_organizationName = 56,
	OID_organizationUnitName = 57,
	OID_title = 58,
	OID_description = 59,
	OID_name = 60,
	OID_givenName = 61,
	OID_initials = 62,
	OID_generationalQualifier = 63,
	OID_subjectKeyIdentifier = 64,
	OID_keyUsage = 65,
	OID_subjectAltName = 66,
	OID_issuerAltName = 67,
	OID_basicConstraints = 68,
	OID_crlDistributionPoints = 69,
	OID_certPolicies = 70,
	OID_authorityKeyIdentifier = 71,
	OID_extKeyUsage = 72,
	OID_NetlogonMechanism = 73,
	OID_appleLocalKdcSupported = 74,
	OID_gostCPSignA = 75,
	OID_gostCPSignB = 76,
	OID_gostCPSignC = 77,
	OID_gost2012PKey256 = 78,
	OID_gost2012PKey512 = 79,
	OID_gost2012Digest256 = 80,
	OID_gost2012Digest512 = 81,
	OID_gost2012Signature256 = 82,
	OID_gost2012Signature512 = 83,
	OID_gostTC26Sign256A = 84,
	OID_gostTC26Sign256B = 85,
	OID_gostTC26Sign256C = 86,
	OID_gostTC26Sign256D = 87,
	OID_gostTC26Sign512A = 88,
	OID_gostTC26Sign512B = 89,
	OID_gostTC26Sign512C = 90,
	OID_sm2 = 91,
	OID_sm3 = 92,
	OID_SM2_with_SM3 = 93,
	OID_sm3WithRSAEncryption = 94,
	OID_TPMLoadableKey = 95,
	OID_TPMImportableKey = 96,
	OID_TPMSealedData = 97,
	OID__NR = 98,
};

enum tpm_algorithms {
	TPM_ALG_ERROR = 0,
	TPM_ALG_SHA1 = 4,
	TPM_ALG_KEYEDHASH = 8,
	TPM_ALG_SHA256 = 11,
	TPM_ALG_SHA384 = 12,
	TPM_ALG_SHA512 = 13,
	TPM_ALG_NULL = 16,
	TPM_ALG_SM3_256 = 18,
};

struct tpm_chip___2;

struct tpm_class_ops___2 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___2 *, u8);
	int (*recv)(struct tpm_chip___2 *, u8 *, size_t);
	int (*send)(struct tpm_chip___2 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___2 *);
	u8 (*status)(struct tpm_chip___2 *);
	void (*update_timeouts)(struct tpm_chip___2 *, long unsigned int *);
	void (*update_durations)(struct tpm_chip___2 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___2 *);
	int (*cmd_ready)(struct tpm_chip___2 *);
	int (*request_locality)(struct tpm_chip___2 *, int);
	int (*relinquish_locality)(struct tpm_chip___2 *, int);
	void (*clk_enable)(struct tpm_chip___2 *, bool);
};

struct tpm_chip_seqops___2 {
	struct tpm_chip___2 *chip;
	const struct seq_operations___39 *seqops;
};

struct tpm_chip___2 {
	struct device___19 dev;
	struct device___19 devs;
	struct cdev___17 cdev;
	struct cdev___17 cdevs;
	struct rw_semaphore ops_sem;
	const struct tpm_class_ops___2 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___2 bin_log_seqops;
	struct tpm_chip_seqops___2 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___41 *bios_dir[3];
	const struct attribute_group___40 *groups[8];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

enum tpm2_structures {
	TPM2_ST_NO_SESSIONS = 32769,
	TPM2_ST_SESSIONS = 32770,
};

enum tpm2_return_codes {
	TPM2_RC_SUCCESS = 0,
	TPM2_RC_HASH = 131,
	TPM2_RC_HANDLE = 139,
	TPM2_RC_INITIALIZE = 256,
	TPM2_RC_FAILURE = 257,
	TPM2_RC_DISABLED = 288,
	TPM2_RC_COMMAND_CODE = 323,
	TPM2_RC_TESTING = 2314,
	TPM2_RC_REFERENCE_H0 = 2320,
	TPM2_RC_RETRY = 2338,
};

enum tpm2_command_codes {
	TPM2_CC_FIRST = 287,
	TPM2_CC_HIERARCHY_CONTROL = 289,
	TPM2_CC_HIERARCHY_CHANGE_AUTH = 297,
	TPM2_CC_CREATE_PRIMARY = 305,
	TPM2_CC_SEQUENCE_COMPLETE = 318,
	TPM2_CC_SELF_TEST = 323,
	TPM2_CC_STARTUP = 324,
	TPM2_CC_SHUTDOWN = 325,
	TPM2_CC_NV_READ = 334,
	TPM2_CC_CREATE = 339,
	TPM2_CC_LOAD = 343,
	TPM2_CC_SEQUENCE_UPDATE = 348,
	TPM2_CC_UNSEAL = 350,
	TPM2_CC_CONTEXT_LOAD = 353,
	TPM2_CC_CONTEXT_SAVE = 354,
	TPM2_CC_FLUSH_CONTEXT = 357,
	TPM2_CC_VERIFY_SIGNATURE = 375,
	TPM2_CC_GET_CAPABILITY = 378,
	TPM2_CC_GET_RANDOM = 379,
	TPM2_CC_PCR_READ = 382,
	TPM2_CC_PCR_EXTEND = 386,
	TPM2_CC_EVENT_SEQUENCE_COMPLETE = 389,
	TPM2_CC_HASH_SEQUENCE_START = 390,
	TPM2_CC_CREATE_LOADED = 401,
	TPM2_CC_LAST = 403,
};

enum tpm2_permanent_handles {
	TPM2_RS_PW = 1073741833,
};

enum tpm2_object_attributes {
	TPM2_OA_FIXED_TPM = 2,
	TPM2_OA_FIXED_PARENT = 16,
	TPM2_OA_USER_WITH_AUTH = 64,
};

enum tpm2_session_attributes {
	TPM2_SA_CONTINUE_SESSION = 1,
};

struct tpm2_hash {
	unsigned int crypto_id;
	unsigned int tpm_id;
};

struct tpm2_key_context {
	u32 parent;
	const u8 *pub;
	u32 pub_len;
	const u8 *priv;
	u32 priv_len;
};

enum asn1_class {
	ASN1_UNIV = 0,
	ASN1_APPL = 1,
	ASN1_CONT = 2,
	ASN1_PRIV = 3,
};

enum asn1_method {
	ASN1_PRIM = 0,
	ASN1_CONS = 1,
};

enum asn1_tag {
	ASN1_EOC = 0,
	ASN1_BOOL = 1,
	ASN1_INT = 2,
	ASN1_BTS = 3,
	ASN1_OTS = 4,
	ASN1_NULL = 5,
	ASN1_OID = 6,
	ASN1_ODE = 7,
	ASN1_EXT = 8,
	ASN1_REAL = 9,
	ASN1_ENUM = 10,
	ASN1_EPDV = 11,
	ASN1_UTF8STR = 12,
	ASN1_RELOID = 13,
	ASN1_SEQ = 16,
	ASN1_SET = 17,
	ASN1_NUMSTR = 18,
	ASN1_PRNSTR = 19,
	ASN1_TEXSTR = 20,
	ASN1_VIDSTR = 21,
	ASN1_IA5STR = 22,
	ASN1_UNITIM = 23,
	ASN1_GENTIM = 24,
	ASN1_GRASTR = 25,
	ASN1_VISSTR = 26,
	ASN1_GENSTR = 27,
	ASN1_UNISTR = 28,
	ASN1_CHRSTR = 29,
	ASN1_BMPSTR = 30,
	ASN1_LONG_TAG = 31,
};

enum asn1_opcode {
	ASN1_OP_MATCH = 0,
	ASN1_OP_MATCH_OR_SKIP = 1,
	ASN1_OP_MATCH_ACT = 2,
	ASN1_OP_MATCH_ACT_OR_SKIP = 3,
	ASN1_OP_MATCH_JUMP = 4,
	ASN1_OP_MATCH_JUMP_OR_SKIP = 5,
	ASN1_OP_MATCH_ANY = 8,
	ASN1_OP_MATCH_ANY_OR_SKIP = 9,
	ASN1_OP_MATCH_ANY_ACT = 10,
	ASN1_OP_MATCH_ANY_ACT_OR_SKIP = 11,
	ASN1_OP_COND_MATCH_OR_SKIP = 17,
	ASN1_OP_COND_MATCH_ACT_OR_SKIP = 19,
	ASN1_OP_COND_MATCH_JUMP_OR_SKIP = 21,
	ASN1_OP_COND_MATCH_ANY = 24,
	ASN1_OP_COND_MATCH_ANY_OR_SKIP = 25,
	ASN1_OP_COND_MATCH_ANY_ACT = 26,
	ASN1_OP_COND_MATCH_ANY_ACT_OR_SKIP = 27,
	ASN1_OP_COND_FAIL = 28,
	ASN1_OP_COMPLETE = 29,
	ASN1_OP_ACT = 30,
	ASN1_OP_MAYBE_ACT = 31,
	ASN1_OP_END_SEQ = 32,
	ASN1_OP_END_SET = 33,
	ASN1_OP_END_SEQ_OF = 34,
	ASN1_OP_END_SET_OF = 35,
	ASN1_OP_END_SEQ_ACT = 36,
	ASN1_OP_END_SET_ACT = 37,
	ASN1_OP_END_SEQ_OF_ACT = 38,
	ASN1_OP_END_SET_OF_ACT = 39,
	ASN1_OP_RETURN = 40,
	ASN1_OP__NR = 41,
};

enum tpm2key_actions {
	ACT_tpm2_key_parent = 0,
	ACT_tpm2_key_priv = 1,
	ACT_tpm2_key_pub = 2,
	ACT_tpm2_key_type = 3,
	NR__tpm2key_actions = 4,
};

struct crypto_async_request___4;

typedef void (*crypto_completion_t___4)(struct crypto_async_request___4 *, int);

struct crypto_tfm___15;

struct crypto_async_request___4 {
	struct list_head list;
	crypto_completion_t___4 complete;
	void *data;
	struct crypto_tfm___15 *tfm;
	u32 flags;
};

struct crypto_alg___15;

struct crypto_tfm___15 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___15 *);
	struct crypto_alg___15 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___15 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___15 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___15 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___15 *, u8 *, const u8 *);
};

struct compress_alg___15 {
	int (*coa_compress)(struct crypto_tfm___15 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___15 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___2;

struct crypto_alg___15 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___2 *cra_type;
	union {
		struct cipher_alg___15 cipher;
		struct compress_alg___15 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___15 *);
	void (*cra_exit)(struct crypto_tfm___15 *);
	void (*cra_destroy)(struct crypto_alg___15 *);
	struct module___137 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___2;

struct crypto_type___2 {
	unsigned int (*ctxsize)(struct crypto_alg___15 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___15 *);
	int (*init)(struct crypto_tfm___15 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___15 *);
	void (*show)(struct seq_file___130 *, struct crypto_alg___15 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___15 *);
	void (*free)(struct crypto_instance___2 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_template___2;

struct crypto_spawn___2;

struct crypto_instance___2 {
	struct crypto_alg___15 alg;
	struct crypto_template___2 *tmpl;
	union {
		struct hlist_node list;
		struct crypto_spawn___2 *spawns;
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_spawn___2 {
	struct list_head list;
	struct crypto_alg___15 *alg;
	union {
		struct crypto_instance___2 *inst;
		struct crypto_spawn___2 *next;
	};
	const struct crypto_type___2 *frontend;
	u32 mask;
	bool dead;
	bool registered;
};

struct crypto_template___2 {
	struct list_head list;
	struct hlist_head instances;
	struct module___137 *module;
	int (*create)(struct crypto_template___2 *, struct rtattr **);
	char name[128];
};

struct crypto_shash___11 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct skcipher_request___3 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___4 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___6 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct skcipher_alg___3 {
	int (*setkey)(struct crypto_skcipher___6 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___3 *);
	int (*decrypt)(struct skcipher_request___3 *);
	int (*init)(struct crypto_skcipher___6 *);
	void (*exit)(struct crypto_skcipher___6 *);
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
	unsigned int chunksize;
	unsigned int walksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

enum {
	Opt_new___2 = 0,
	Opt_load___2 = 1,
	Opt_update___2 = 2,
	Opt_err___9 = 3,
};

enum {
	Opt_default = 0,
	Opt_ecryptfs = 1,
	Opt_enc32 = 2,
	Opt_error = 3,
};

enum derived_key_type {
	ENC_KEY = 0,
	AUTH_KEY = 1,
};

typedef int (*key_restrict_link_func_t___11)(struct key___9 *, const struct key_type *, const union key_payload *, struct key___9 *);

struct vfs_cap_data {
	__le32 magic_etc;
	struct {
		__le32 permitted;
		__le32 inheritable;
	} data[2];
};

struct vfs_ns_cap_data {
	__le32 magic_etc;
	struct {
		__le32 permitted;
		__le32 inheritable;
	} data[2];
	__le32 rootid;
};

struct dentry___154;

struct super_block___154;

struct module___139;

struct file_system_type___154 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___154 * (*mount)(struct file_system_type___154 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___154 *);
	struct module___139 *owner;
	struct file_system_type___154 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___154;

struct kiocb___154;

struct iov_iter___83;

struct vm_area_struct___159;

struct inode___154;

struct file_lock___154;

struct page___159;

struct pipe_inode_info___47;

struct seq_file___132;

struct file_operations___154 {
	struct module___139 *owner;
	loff_t (*llseek)(struct file___154 *, loff_t, int);
	ssize_t (*read)(struct file___154 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___154 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___154 *, struct iov_iter___83 *);
	ssize_t (*write_iter)(struct kiocb___154 *, struct iov_iter___83 *);
	int (*iopoll)(struct kiocb___154 *, bool);
	int (*iterate)(struct file___154 *, struct dir_context *);
	int (*iterate_shared)(struct file___154 *, struct dir_context *);
	__poll_t (*poll)(struct file___154 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___154 *, struct vm_area_struct___159 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___154 *, struct file___154 *);
	int (*flush)(struct file___154 *, fl_owner_t);
	int (*release)(struct inode___154 *, struct file___154 *);
	int (*fsync)(struct file___154 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___154 *, int);
	int (*lock)(struct file___154 *, int, struct file_lock___154 *);
	ssize_t (*sendpage)(struct file___154 *, struct page___159 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___154 *, long unsigned int);
	int (*flock)(struct file___154 *, int, struct file_lock___154 *);
	ssize_t (*splice_write)(struct pipe_inode_info___47 *, struct file___154 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___154 *, loff_t *, struct pipe_inode_info___47 *, size_t, unsigned int);
	int (*setlease)(struct file___154 *, long int, struct file_lock___154 **, void **);
	long int (*fallocate)(struct file___154 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___132 *, struct file___154 *);
	ssize_t (*copy_file_range)(struct file___154 *, loff_t, struct file___154 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___154 *, loff_t, struct file___154 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___154 *, loff_t, loff_t, int);
};

struct vmacache___159 {
	u64 seqnum;
	struct vm_area_struct___159 *vmas[4];
};

struct page_frag___159 {
	struct page___159 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___160;

struct pid___135;

struct nsproxy___144;

struct signal_struct___155;

struct bio_list___67;

struct backing_dev_info___64;

struct io_context___67;

struct css_set___103;

struct mem_cgroup___55;

struct request_queue___67;

struct vm_struct___138;

struct task_struct___161 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___161 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___160 *mm;
	struct mm_struct___160 *active_mm;
	struct vmacache___159 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___161 *real_parent;
	struct task_struct___161 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___161 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___135 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	struct key___7 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___144 *nsproxy;
	struct signal_struct___155 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___161 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___67 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___64 *backing_dev_info;
	struct io_context___67 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___103 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___47 *splice_pipe;
	struct page_frag___159 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___55 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___55 *active_memcg;
	struct request_queue___67 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___161 *oom_reaper_list;
	struct vm_struct___138 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___141;

struct kobj_type___141;

struct kernfs_node___141;

struct kobject___141 {
	const char *name;
	struct list_head entry;
	struct kobject___141 *parent;
	struct kset___141 *kset;
	struct kobj_type___141 *ktype;
	struct kernfs_node___141 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___138 {
	struct kobject___141 kobj;
	struct module___139 *mod;
	struct kobject___141 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___138 {
	struct module___139 *mod;
	struct latch_tree_node node;
};

struct module_layout___138 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___138 mtn;
};

struct module_attribute___138;

struct kernel_param___138;

struct module___139 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___138 mkobj;
	struct module_attribute___138 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___141 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___138 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___138 core_layout;
	struct module_layout___138 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___135;

struct upid___135 {
	int nr;
	struct pid_namespace___135 *ns;
};

struct pid_namespace___135 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___161 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___135 *parent;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___135 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___135 numbers[1];
};

typedef struct page___159 *pgtable_t___159;

struct address_space___154;

struct page_pool___38;

struct dev_pagemap___150;

struct page___159 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___154 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___38 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___159 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___159 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___160 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___150 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___150;

struct vm_area_struct___159 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___159 *vm_next;
	struct vm_area_struct___159 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___160 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___150 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___154 *vm_file;
	struct file___154 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___155 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___161 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___161 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___135 *pids[4];
	struct pid___135 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___160 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___27;

struct core_state___159;

struct mm_struct___160 {
	struct {
		struct vm_area_struct___159 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___27 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___159 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___161 *owner;
		struct user_namespace___23 *user_ns;
		struct file___154 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___103;

struct nsproxy___144 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___135 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___103 *cgroup_ns;
};

struct bio___67;

struct bio_list___67 {
	struct bio___67 *head;
	struct bio___67 *tail;
};

struct cgroup_subsys_state___103;

struct bdi_writeback___64 {
	struct backing_dev_info___64 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___103 *memcg_css;
	struct cgroup_subsys_state___103 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___110;

struct backing_dev_info___64 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___64 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___110 *dev;
	char dev_name[64];
	struct device___110 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___154 *debug_dir;
};

struct io_cq___67;

struct io_context___67 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___67 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___103;

struct css_set___103 {
	struct cgroup_subsys_state___103 *subsys[14];
	refcount_t refcount;
	struct css_set___103 *dom_cset;
	struct cgroup___103 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___103 *mg_src_cgrp;
	struct cgroup___103 *mg_dst_cgrp;
	struct css_set___103 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___154;

struct pipe_buffer___47;

struct pipe_inode_info___47 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___159 *tmp_page;
	struct fasync_struct___154 *fasync_readers;
	struct fasync_struct___154 *fasync_writers;
	struct pipe_buffer___47 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___103;

struct cgroup_subsys_state___103 {
	struct cgroup___103 *cgroup;
	struct cgroup_subsys___103 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___103 *parent;
};

struct cgroup_file___103 {
	struct kernfs_node___141 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___55;

struct mem_cgroup_per_node___55;

struct mem_cgroup___55 {
	struct cgroup_subsys_state___103 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___103 events_file;
	struct cgroup_file___103 events_local_file;
	struct cgroup_file___103 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___55 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___161 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___55 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___67;

struct blk_integrity___67 {
	const struct blk_integrity_profile___67 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___67 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___67 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___67;

struct elevator_queue___67;

struct blk_mq_ops___64;

struct blk_mq_hw_ctx___64;

struct gendisk___67;

struct blkcg_gq___64;

struct blk_mq_tag_set___64;

struct request_queue___67 {
	struct request___67 *last_merge;
	struct elevator_queue___67 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___64 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___64 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___67 *disk;
	struct kobject___141 kobj;
	struct kobject___141 *mq_kobj;
	struct blk_integrity___67 integrity;
	struct device___110 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___64 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___64 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___67 bio_split;
	struct dentry___154 *debugfs_dir;
	struct dentry___154 *sched_debugfs_dir;
	struct dentry___154 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___138 {
	struct vm_struct___138 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___159 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___154;

struct address_space___154 {
	struct inode___154 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___154 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___38 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___110 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___38 {
	u32 count;
	struct page___159 *cache[128];
};

struct page_pool___38 {
	struct page_pool_params___38 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___159 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___38 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___150;

struct dev_pagemap___150 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___150 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___154;

struct path___154 {
	struct vfsmount___154 *mnt;
	struct dentry___154 *dentry;
};

struct fown_struct___135 {
	rwlock_t lock;
	struct pid___135 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___154 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___154 f_path;
	struct inode___154 *f_inode;
	const struct file_operations___154 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___135 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___154 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___150;

struct vm_operations_struct___150 {
	void (*open)(struct vm_area_struct___159 *);
	void (*close)(struct vm_area_struct___159 *);
	int (*may_split)(struct vm_area_struct___159 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___159 *);
	int (*mprotect)(struct vm_area_struct___159 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___150 *);
	vm_fault_t (*huge_fault)(struct vm_fault___150 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___150 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___159 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___150 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___150 *);
	int (*access)(struct vm_area_struct___159 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___159 *);
	int (*set_policy)(struct vm_area_struct___159 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___159 *, long unsigned int);
	struct page___159 * (*find_special_page)(struct vm_area_struct___159 *, long unsigned int);
};

struct core_thread___159 {
	struct task_struct___161 *task;
	struct core_thread___159 *next;
};

struct core_state___159 {
	atomic_t nr_threads;
	struct core_thread___159 dumper;
	struct completion startup;
};

struct linux_binprm___28;

struct coredump_params___27;

struct linux_binfmt___27 {
	struct list_head lh;
	struct module___139 *module;
	int (*load_binary)(struct linux_binprm___28 *);
	int (*load_shlib)(struct file___154 *);
	int (*core_dump)(struct coredump_params___27 *);
	long unsigned int min_coredump;
};

struct vm_fault___150 {
	const struct {
		struct vm_area_struct___159 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___159 *cow_page;
	struct page___159 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___159 prealloc_pte;
};

struct psi_group___103 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___161 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___103;

struct cgroup_rstat_cpu___103;

struct cgroup___103 {
	struct cgroup_subsys_state___103 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___141 *kn;
	struct cgroup_file___103 procs_file;
	struct cgroup_file___103 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___103 *subsys[14];
	struct cgroup_root___103 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___103 *dom_cgrp;
	struct cgroup___103 *old_dom_cgrp;
	struct cgroup_rstat_cpu___103 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___103 psi;
	struct cgroup_bpf___22 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

typedef int (*key_restrict_link_func_t___12)(struct key___7 *, const struct key_type *, const union key_payload *, struct key___7 *);

struct pglist_data___62;

struct lruvec___62 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___62 *pgdat;
};

struct zone___62 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___62 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___62 {
	struct zone___62 *zone;
	int zone_idx;
};

struct zonelist___62 {
	struct zoneref___62 _zonerefs[321];
};

struct pglist_data___62 {
	struct zone___62 node_zones[5];
	struct zonelist___62 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___161 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___161 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___62 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___55 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___55 *memcg;
};

struct shrinker___55 {
	long unsigned int (*count_objects)(struct shrinker___55 *, struct shrink_control___55 *);
	long unsigned int (*scan_objects)(struct shrinker___55 *, struct shrink_control___55 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___150 {
	void (*page_free)(struct page___159 *);
	void (*kill)(struct dev_pagemap___150 *);
	void (*cleanup)(struct dev_pagemap___150 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___150 *);
};

struct dentry_operations___154;

struct dentry___154 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___154 *d_parent;
	struct qstr d_name;
	struct inode___154 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___154 *d_op;
	struct super_block___154 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___154;

struct inode___154 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___154 *i_op;
	struct super_block___154 *i_sb;
	struct address_space___154 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___64 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___154 *i_fop;
		void (*free_inode)(struct inode___154 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___154 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___47 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___154 {
	int (*d_revalidate)(struct dentry___154 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___154 *, unsigned int);
	int (*d_hash)(const struct dentry___154 *, struct qstr *);
	int (*d_compare)(const struct dentry___154 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___154 *);
	int (*d_init)(struct dentry___154 *);
	void (*d_release)(struct dentry___154 *);
	void (*d_prune)(struct dentry___154 *);
	void (*d_iput)(struct dentry___154 *, struct inode___154 *);
	char * (*d_dname)(struct dentry___154 *, char *, int);
	struct vfsmount___154 * (*d_automount)(struct path___154 *);
	int (*d_manage)(const struct path___154 *, bool);
	struct dentry___154 * (*d_real)(struct dentry___154 *, const struct inode___154 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___154;

struct mem_dqinfo___154 {
	struct quota_format_type___154 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___154;

struct quota_info___154 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___154 *files[3];
	struct mem_dqinfo___154 info[3];
	const struct quota_format_ops___154 *ops[3];
};

struct rcuwait___155 {
	struct task_struct___161 *task;
};

struct percpu_rw_semaphore___155 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___155 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___154 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___155 rw_sem[3];
};

struct super_operations___154;

struct dquot_operations___154;

struct quotactl_ops___154;

struct xattr_handler___19;

struct block_device___68;

struct super_block___154 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___154 *s_type;
	const struct super_operations___154 *s_op;
	const struct dquot_operations___154 *dq_op;
	const struct quotactl_ops___154 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___154 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___19 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___7 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___68 *s_bdev;
	struct backing_dev_info___64 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___154 s_dquot;
	struct sb_writers___154 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___154 *s_d_op;
	int cleancache_poolid;
	struct shrinker___55 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___154 {
	struct dentry___154 *mnt_root;
	struct super_block___154 *mnt_sb;
	int mnt_flags;
	struct user_namespace___23 *mnt_userns;
};

struct io_cq___67 {
	struct request_queue___67 *q;
	struct io_context___67 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___72;

struct kiocb___154 {
	struct file___154 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___154 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___72 *ki_waitq;
	};
};

struct iattr___154 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___154 *ia_file;
};

struct dquot___154 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___154 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___154 {
	int qf_fmt_id;
	const struct quota_format_ops___154 *qf_ops;
	struct module___139 *qf_owner;
	struct quota_format_type___154 *qf_next;
};

struct quota_format_ops___154 {
	int (*check_quota_file)(struct super_block___154 *, int);
	int (*read_file_info)(struct super_block___154 *, int);
	int (*write_file_info)(struct super_block___154 *, int);
	int (*free_file_info)(struct super_block___154 *, int);
	int (*read_dqblk)(struct dquot___154 *);
	int (*commit_dqblk)(struct dquot___154 *);
	int (*release_dqblk)(struct dquot___154 *);
	int (*get_next_id)(struct super_block___154 *, struct kqid *);
};

struct dquot_operations___154 {
	int (*write_dquot)(struct dquot___154 *);
	struct dquot___154 * (*alloc_dquot)(struct super_block___154 *, int);
	void (*destroy_dquot)(struct dquot___154 *);
	int (*acquire_dquot)(struct dquot___154 *);
	int (*release_dquot)(struct dquot___154 *);
	int (*mark_dirty)(struct dquot___154 *);
	int (*write_info)(struct super_block___154 *, int);
	qsize_t * (*get_reserved_space)(struct inode___154 *);
	int (*get_projid)(struct inode___154 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___154 *, qsize_t *);
	int (*get_next_id)(struct super_block___154 *, struct kqid *);
};

struct quotactl_ops___154 {
	int (*quota_on)(struct super_block___154 *, int, int, const struct path___154 *);
	int (*quota_off)(struct super_block___154 *, int);
	int (*quota_enable)(struct super_block___154 *, unsigned int);
	int (*quota_disable)(struct super_block___154 *, unsigned int);
	int (*quota_sync)(struct super_block___154 *, int);
	int (*set_info)(struct super_block___154 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___154 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___154 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___154 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___154 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___154 *, unsigned int);
};

struct wait_page_queue___72 {
	struct page___159 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___64;

struct readahead_control___72;

struct swap_info_struct___36;

struct address_space_operations___154 {
	int (*writepage)(struct page___159 *, struct writeback_control___64 *);
	int (*readpage)(struct file___154 *, struct page___159 *);
	int (*writepages)(struct address_space___154 *, struct writeback_control___64 *);
	int (*set_page_dirty)(struct page___159 *);
	int (*readpages)(struct file___154 *, struct address_space___154 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___72 *);
	int (*write_begin)(struct file___154 *, struct address_space___154 *, loff_t, unsigned int, unsigned int, struct page___159 **, void **);
	int (*write_end)(struct file___154 *, struct address_space___154 *, loff_t, unsigned int, unsigned int, struct page___159 *, void *);
	sector_t (*bmap)(struct address_space___154 *, sector_t);
	void (*invalidatepage)(struct page___159 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___159 *, gfp_t);
	void (*freepage)(struct page___159 *);
	ssize_t (*direct_IO)(struct kiocb___154 *, struct iov_iter___83 *);
	int (*migratepage)(struct address_space___154 *, struct page___159 *, struct page___159 *, enum migrate_mode);
	bool (*isolate_page)(struct page___159 *, isolate_mode_t);
	void (*putback_page)(struct page___159 *);
	int (*launder_page)(struct page___159 *);
	int (*is_partially_uptodate)(struct page___159 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___159 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___154 *, struct page___159 *);
	int (*swap_activate)(struct swap_info_struct___36 *, struct file___154 *, sector_t *);
	void (*swap_deactivate)(struct file___154 *);
};

struct writeback_control___64 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___64 *wb;
	struct inode___154 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___72 {
	struct file___154 *file;
	struct address_space___154 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___81;

struct iov_iter___83 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___81 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___47 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___36 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___68 *bdev;
	struct file___154 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___154 {
	struct dentry___154 * (*lookup)(struct inode___154 *, struct dentry___154 *, unsigned int);
	const char * (*get_link)(struct dentry___154 *, struct inode___154 *, struct delayed_call *);
	int (*permission)(struct user_namespace___23 *, struct inode___154 *, int);
	struct posix_acl * (*get_acl)(struct inode___154 *, int, bool);
	int (*readlink)(struct dentry___154 *, char *, int);
	int (*create)(struct user_namespace___23 *, struct inode___154 *, struct dentry___154 *, umode_t, bool);
	int (*link)(struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*unlink)(struct inode___154 *, struct dentry___154 *);
	int (*symlink)(struct user_namespace___23 *, struct inode___154 *, struct dentry___154 *, const char *);
	int (*mkdir)(struct user_namespace___23 *, struct inode___154 *, struct dentry___154 *, umode_t);
	int (*rmdir)(struct inode___154 *, struct dentry___154 *);
	int (*mknod)(struct user_namespace___23 *, struct inode___154 *, struct dentry___154 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___23 *, struct inode___154 *, struct dentry___154 *, struct inode___154 *, struct dentry___154 *, unsigned int);
	int (*setattr)(struct user_namespace___23 *, struct dentry___154 *, struct iattr___154 *);
	int (*getattr)(struct user_namespace___23 *, const struct path___154 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___154 *, char *, size_t);
	int (*fiemap)(struct inode___154 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___154 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___154 *, struct dentry___154 *, struct file___154 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___23 *, struct inode___154 *, struct dentry___154 *, umode_t);
	int (*set_acl)(struct user_namespace___23 *, struct inode___154 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___23 *, struct dentry___154 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___154 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___154 {
	void (*fl_copy_lock)(struct file_lock___154 *, struct file_lock___154 *);
	void (*fl_release_private)(struct file_lock___154 *);
};

struct lock_manager_operations___154;

struct file_lock___154 {
	struct file_lock___154 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___154 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___154 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___154 *fl_ops;
	const struct lock_manager_operations___154 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___154 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___154 *);
	int (*lm_grant)(struct file_lock___154 *, int);
	bool (*lm_break)(struct file_lock___154 *);
	int (*lm_change)(struct file_lock___154 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___154 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___154 *);
};

struct fasync_struct___154 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___154 *fa_next;
	struct file___154 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___154 {
	struct inode___154 * (*alloc_inode)(struct super_block___154 *);
	void (*destroy_inode)(struct inode___154 *);
	void (*free_inode)(struct inode___154 *);
	void (*dirty_inode)(struct inode___154 *, int);
	int (*write_inode)(struct inode___154 *, struct writeback_control___64 *);
	int (*drop_inode)(struct inode___154 *);
	void (*evict_inode)(struct inode___154 *);
	void (*put_super)(struct super_block___154 *);
	int (*sync_fs)(struct super_block___154 *, int);
	int (*freeze_super)(struct super_block___154 *);
	int (*freeze_fs)(struct super_block___154 *);
	int (*thaw_super)(struct super_block___154 *);
	int (*unfreeze_fs)(struct super_block___154 *);
	int (*statfs)(struct dentry___154 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___154 *, int *, char *);
	void (*umount_begin)(struct super_block___154 *);
	int (*show_options)(struct seq_file___132 *, struct dentry___154 *);
	int (*show_devname)(struct seq_file___132 *, struct dentry___154 *);
	int (*show_path)(struct seq_file___132 *, struct dentry___154 *);
	int (*show_stats)(struct seq_file___132 *, struct dentry___154 *);
	ssize_t (*quota_read)(struct super_block___154 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___154 *, int, const char *, size_t, loff_t);
	struct dquot___154 ** (*get_dquots)(struct inode___154 *);
	long int (*nr_cached_objects)(struct super_block___154 *, struct shrink_control___55 *);
	long int (*free_cached_objects)(struct super_block___154 *, struct shrink_control___55 *);
	struct file___154 * (*real_loop)(struct file___154 *);
};

struct xattr_handler___19 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___154 *);
	int (*get)(const struct xattr_handler___19 *, struct dentry___154 *, struct inode___154 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___19 *, struct user_namespace___23 *, struct dentry___154 *, struct inode___154 *, const char *, const void *, size_t, int);
};

struct wakeup_source___110;

struct dev_pm_info___110 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___110 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___110 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___110;

struct bus_type___110;

struct device_driver___110;

struct dev_pm_domain___110;

struct fwnode_handle___110;

struct class___110;

struct attribute_group___141;

struct device___110 {
	struct kobject___141 kobj;
	struct device___110 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___110 *type;
	struct bus_type___110 *bus;
	struct device_driver___110 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___110 power;
	struct dev_pm_domain___110 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___110 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___110 *class;
	const struct attribute_group___141 **groups;
	void (*release)(struct device___110 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___68 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___154 *bd_inode;
	struct super_block___154 *bd_super;
	void *bd_claiming;
	struct device___110 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___141 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___67 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___154 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___132;

struct seq_file___132 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___132 *op;
	int poll_event;
	const struct file___154 *file;
	void *private;
};

typedef void bio_end_io_t___67(struct bio___67 *);

struct bio_vec___81 {
	struct page___159 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___67;

struct bio___67 {
	struct bio___67 *bi_next;
	struct block_device___68 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___67 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___64 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___67 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___81 *bi_io_vec;
	struct bio_set___67 *bi_pool;
	struct bio_vec___81 bi_inline_vecs[0];
};

struct cgroup_namespace___103 {
	struct ns_common___26 ns;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct css_set___103 *root_cset;
};

struct msghdr___16 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___83 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___154 *msg_iocb;
};

struct xfrm_sec_ctx___2;

struct xfrm_user_sec_ctx___2;

struct fs_parameter___28;

struct socket___16;

struct sctp_endpoint;

struct bpf_map___24;

struct bpf_prog_aux___24;

union security_list_options {
	int (*binder_set_context_mgr)(const struct cred___26 *);
	int (*binder_transaction)(const struct cred___26 *, const struct cred___26 *);
	int (*binder_transfer_binder)(const struct cred___26 *, const struct cred___26 *);
	int (*binder_transfer_file)(const struct cred___26 *, const struct cred___26 *, struct file___154 *);
	int (*ptrace_access_check)(struct task_struct___161 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___161 *);
	int (*capget)(struct task_struct___161 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___26 *, const struct cred___26 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___26 *, struct user_namespace___23 *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___154 *);
	int (*quota_on)(struct dentry___154 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___160 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___28 *);
	int (*bprm_creds_from_file)(struct linux_binprm___28 *, struct file___154 *);
	int (*bprm_check_security)(struct linux_binprm___28 *);
	void (*bprm_committing_creds)(struct linux_binprm___28 *);
	void (*bprm_committed_creds)(struct linux_binprm___28 *);
	int (*fs_context_dup)(struct fs_context *, struct fs_context *);
	int (*fs_context_parse_param)(struct fs_context *, struct fs_parameter___28 *);
	int (*sb_alloc_security)(struct super_block___154 *);
	void (*sb_delete)(struct super_block___154 *);
	void (*sb_free_security)(struct super_block___154 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___154 *, void *);
	int (*sb_remount)(struct super_block___154 *, void *);
	int (*sb_kern_mount)(struct super_block___154 *);
	int (*sb_show_options)(struct seq_file___132 *, struct super_block___154 *);
	int (*sb_statfs)(struct dentry___154 *);
	int (*sb_mount)(const char *, const struct path___154 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___154 *, int);
	int (*sb_pivotroot)(const struct path___154 *, const struct path___154 *);
	int (*sb_set_mnt_opts)(struct super_block___154 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___154 *, struct super_block___154 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___154 *, const struct path___154 *);
	int (*dentry_init_security)(struct dentry___154 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___154 *, int, struct qstr *, const struct cred___26 *, struct cred___26 *);
	int (*path_unlink)(const struct path___154 *, struct dentry___154 *);
	int (*path_mkdir)(const struct path___154 *, struct dentry___154 *, umode_t);
	int (*path_rmdir)(const struct path___154 *, struct dentry___154 *);
	int (*path_mknod)(const struct path___154 *, struct dentry___154 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___154 *);
	int (*path_symlink)(const struct path___154 *, struct dentry___154 *, const char *);
	int (*path_link)(struct dentry___154 *, const struct path___154 *, struct dentry___154 *);
	int (*path_rename)(const struct path___154 *, struct dentry___154 *, const struct path___154 *, struct dentry___154 *);
	int (*path_chmod)(const struct path___154 *, umode_t);
	int (*path_chown)(const struct path___154 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___154 *);
	int (*path_notify)(const struct path___154 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___154 *);
	void (*inode_free_security)(struct inode___154 *);
	int (*inode_init_security)(struct inode___154 *, struct inode___154 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___154 *, const struct qstr *, const struct inode___154 *);
	int (*inode_create)(struct inode___154 *, struct dentry___154 *, umode_t);
	int (*inode_link)(struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*inode_unlink)(struct inode___154 *, struct dentry___154 *);
	int (*inode_symlink)(struct inode___154 *, struct dentry___154 *, const char *);
	int (*inode_mkdir)(struct inode___154 *, struct dentry___154 *, umode_t);
	int (*inode_rmdir)(struct inode___154 *, struct dentry___154 *);
	int (*inode_mknod)(struct inode___154 *, struct dentry___154 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___154 *, struct dentry___154 *, struct inode___154 *, struct dentry___154 *);
	int (*inode_readlink)(struct dentry___154 *);
	int (*inode_follow_link)(struct dentry___154 *, struct inode___154 *, bool);
	int (*inode_permission)(struct inode___154 *, int);
	int (*inode_setattr)(struct dentry___154 *, struct iattr___154 *);
	int (*inode_getattr)(const struct path___154 *);
	int (*inode_setxattr)(struct user_namespace___23 *, struct dentry___154 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___154 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___154 *, const char *);
	int (*inode_listxattr)(struct dentry___154 *);
	int (*inode_removexattr)(struct user_namespace___23 *, struct dentry___154 *, const char *);
	int (*inode_need_killpriv)(struct dentry___154 *);
	int (*inode_killpriv)(struct user_namespace___23 *, struct dentry___154 *);
	int (*inode_getsecurity)(struct user_namespace___23 *, struct inode___154 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___154 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___154 *, char *, size_t);
	void (*inode_getsecid)(struct inode___154 *, u32 *);
	int (*inode_copy_up)(struct dentry___154 *, struct cred___26 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___141 *, struct kernfs_node___141 *);
	int (*file_permission)(struct file___154 *, int);
	int (*file_alloc_security)(struct file___154 *);
	void (*file_free_security)(struct file___154 *);
	int (*file_ioctl)(struct file___154 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___154 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___159 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___154 *, unsigned int);
	int (*file_fcntl)(struct file___154 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___154 *);
	int (*file_send_sigiotask)(struct task_struct___161 *, struct fown_struct___135 *, int);
	int (*file_receive)(struct file___154 *);
	int (*file_open)(struct file___154 *);
	int (*task_alloc)(struct task_struct___161 *, long unsigned int);
	void (*task_free)(struct task_struct___161 *);
	int (*cred_alloc_blank)(struct cred___26 *, gfp_t);
	void (*cred_free)(struct cred___26 *);
	int (*cred_prepare)(struct cred___26 *, const struct cred___26 *, gfp_t);
	void (*cred_transfer)(struct cred___26 *, const struct cred___26 *);
	void (*cred_getsecid)(const struct cred___26 *, u32 *);
	int (*kernel_act_as)(struct cred___26 *, u32);
	int (*kernel_create_files_as)(struct cred___26 *, struct inode___154 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___154 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___154 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___26 *, const struct cred___26 *, int);
	int (*task_fix_setgid)(struct cred___26 *, const struct cred___26 *, int);
	int (*task_setpgid)(struct task_struct___161 *, pid_t);
	int (*task_getpgid)(struct task_struct___161 *);
	int (*task_getsid)(struct task_struct___161 *);
	void (*task_getsecid_subj)(struct task_struct___161 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___161 *, u32 *);
	int (*task_setnice)(struct task_struct___161 *, int);
	int (*task_setioprio)(struct task_struct___161 *, int);
	int (*task_getioprio)(struct task_struct___161 *);
	int (*task_prlimit)(const struct cred___26 *, const struct cred___26 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___161 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___161 *);
	int (*task_getscheduler)(struct task_struct___161 *);
	int (*task_movememory)(struct task_struct___161 *);
	int (*task_kill)(struct task_struct___161 *, struct kernel_siginfo *, int, const struct cred___26 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___161 *, struct inode___154 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___161 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___24 *);
	void (*d_instantiate)(struct dentry___154 *, struct inode___154 *);
	int (*getprocattr)(struct task_struct___161 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___154 *);
	int (*inode_notifysecctx)(struct inode___154 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___154 *, void *, u32);
	int (*inode_getsecctx)(struct inode___154 *, void **, u32 *);
	int (*post_notification)(const struct cred___26 *, const struct cred___26 *, struct watch_notification *);
	int (*watch_key)(struct key___7 *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___16 *, struct socket___16 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___16 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___16 *, struct socket___16 *);
	int (*socket_bind)(struct socket___16 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___16 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___16 *, int);
	int (*socket_accept)(struct socket___16 *, struct socket___16 *);
	int (*socket_sendmsg)(struct socket___16 *, struct msghdr___16 *, int);
	int (*socket_recvmsg)(struct socket___16 *, struct msghdr___16 *, int, int);
	int (*socket_getsockname)(struct socket___16 *);
	int (*socket_getpeername)(struct socket___16 *);
	int (*socket_getsockopt)(struct socket___16 *, int, int);
	int (*socket_setsockopt)(struct socket___16 *, int, int);
	int (*socket_shutdown)(struct socket___16 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___24 *);
	int (*socket_getpeersec_stream)(struct socket___16 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___16 *, struct sk_buff___24 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___16 *);
	int (*inet_conn_request)(const struct sock *, struct sk_buff___24 *, struct request_sock___5 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___5 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___24 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___5 *, struct flowi_common *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___24 *);
	int (*sctp_bind_connect)(struct sock *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock *, struct sock *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx___2 **, struct xfrm_user_sec_ctx___2 *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx___2 *, struct xfrm_sec_ctx___2 **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx___2 *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx___2 *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx___2 *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common *);
	int (*xfrm_decode_session)(struct sk_buff___24 *, u32 *, int);
	int (*key_alloc)(struct key___7 *, const struct cred___26 *, long unsigned int);
	void (*key_free)(struct key___7 *);
	int (*key_permission)(key_ref_t, const struct cred___26 *, enum key_need_perm);
	int (*key_getsecurity)(struct key___7 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___24 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog *);
	int (*bpf_map_alloc_security)(struct bpf_map___24 *);
	void (*bpf_map_free_security)(struct bpf_map___24 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___24 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___24 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event *);
	void (*perf_event_free)(struct perf_event *);
	int (*perf_event_read)(struct perf_event *);
	int (*perf_event_write)(struct perf_event *);
};

struct linux_binprm___28 {
	struct vm_area_struct___159 *vma;
	long unsigned int vma_pages;
	struct mm_struct___160 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___154 *executable;
	struct file___154 *interpreter;
	struct file___154 *file;
	struct cred___26 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct kernfs_root___141;

struct kernfs_elem_dir___141 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___141 *root;
	long unsigned int rev;
};

struct kernfs_elem_symlink___141 {
	struct kernfs_node___141 *target_kn;
};

struct kernfs_ops___141;

struct kernfs_elem_attr___141 {
	const struct kernfs_ops___141 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___141 *notify_next;
};

struct kernfs_node___141 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___141 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___141 dir;
		struct kernfs_elem_symlink___141 symlink;
		struct kernfs_elem_attr___141 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct socket_wq___16 {
	wait_queue_head_t wait;
	struct fasync_struct___154 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___16;

struct socket___16 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___154 *file;
	struct sock *sk;
	const struct proto_ops___16 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___16 wq;
};

struct bpf_map_ops___24;

struct bpf_map___24 {
	const struct bpf_map_ops___24 *ops;
	struct bpf_map___24 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___55 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___24;

struct bpf_jit_poke_descriptor___24;

struct btf_mod_pair___24;

struct bpf_prog_aux___24 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___24 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___24 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___22 *ops;
	struct bpf_map___24 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___24 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___24 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___22 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct security_hook_heads {
	struct hlist_head binder_set_context_mgr;
	struct hlist_head binder_transaction;
	struct hlist_head binder_transfer_binder;
	struct hlist_head binder_transfer_file;
	struct hlist_head ptrace_access_check;
	struct hlist_head ptrace_traceme;
	struct hlist_head capget;
	struct hlist_head capset;
	struct hlist_head capable;
	struct hlist_head quotactl;
	struct hlist_head quota_on;
	struct hlist_head syslog;
	struct hlist_head settime;
	struct hlist_head vm_enough_memory;
	struct hlist_head bprm_creds_for_exec;
	struct hlist_head bprm_creds_from_file;
	struct hlist_head bprm_check_security;
	struct hlist_head bprm_committing_creds;
	struct hlist_head bprm_committed_creds;
	struct hlist_head fs_context_dup;
	struct hlist_head fs_context_parse_param;
	struct hlist_head sb_alloc_security;
	struct hlist_head sb_delete;
	struct hlist_head sb_free_security;
	struct hlist_head sb_free_mnt_opts;
	struct hlist_head sb_eat_lsm_opts;
	struct hlist_head sb_mnt_opts_compat;
	struct hlist_head sb_remount;
	struct hlist_head sb_kern_mount;
	struct hlist_head sb_show_options;
	struct hlist_head sb_statfs;
	struct hlist_head sb_mount;
	struct hlist_head sb_umount;
	struct hlist_head sb_pivotroot;
	struct hlist_head sb_set_mnt_opts;
	struct hlist_head sb_clone_mnt_opts;
	struct hlist_head sb_add_mnt_opt;
	struct hlist_head move_mount;
	struct hlist_head dentry_init_security;
	struct hlist_head dentry_create_files_as;
	struct hlist_head path_unlink;
	struct hlist_head path_mkdir;
	struct hlist_head path_rmdir;
	struct hlist_head path_mknod;
	struct hlist_head path_truncate;
	struct hlist_head path_symlink;
	struct hlist_head path_link;
	struct hlist_head path_rename;
	struct hlist_head path_chmod;
	struct hlist_head path_chown;
	struct hlist_head path_chroot;
	struct hlist_head path_notify;
	struct hlist_head inode_alloc_security;
	struct hlist_head inode_free_security;
	struct hlist_head inode_init_security;
	struct hlist_head inode_init_security_anon;
	struct hlist_head inode_create;
	struct hlist_head inode_link;
	struct hlist_head inode_unlink;
	struct hlist_head inode_symlink;
	struct hlist_head inode_mkdir;
	struct hlist_head inode_rmdir;
	struct hlist_head inode_mknod;
	struct hlist_head inode_rename;
	struct hlist_head inode_readlink;
	struct hlist_head inode_follow_link;
	struct hlist_head inode_permission;
	struct hlist_head inode_setattr;
	struct hlist_head inode_getattr;
	struct hlist_head inode_setxattr;
	struct hlist_head inode_post_setxattr;
	struct hlist_head inode_getxattr;
	struct hlist_head inode_listxattr;
	struct hlist_head inode_removexattr;
	struct hlist_head inode_need_killpriv;
	struct hlist_head inode_killpriv;
	struct hlist_head inode_getsecurity;
	struct hlist_head inode_setsecurity;
	struct hlist_head inode_listsecurity;
	struct hlist_head inode_getsecid;
	struct hlist_head inode_copy_up;
	struct hlist_head inode_copy_up_xattr;
	struct hlist_head kernfs_init_security;
	struct hlist_head file_permission;
	struct hlist_head file_alloc_security;
	struct hlist_head file_free_security;
	struct hlist_head file_ioctl;
	struct hlist_head mmap_addr;
	struct hlist_head mmap_file;
	struct hlist_head file_mprotect;
	struct hlist_head file_lock;
	struct hlist_head file_fcntl;
	struct hlist_head file_set_fowner;
	struct hlist_head file_send_sigiotask;
	struct hlist_head file_receive;
	struct hlist_head file_open;
	struct hlist_head task_alloc;
	struct hlist_head task_free;
	struct hlist_head cred_alloc_blank;
	struct hlist_head cred_free;
	struct hlist_head cred_prepare;
	struct hlist_head cred_transfer;
	struct hlist_head cred_getsecid;
	struct hlist_head kernel_act_as;
	struct hlist_head kernel_create_files_as;
	struct hlist_head kernel_module_request;
	struct hlist_head kernel_load_data;
	struct hlist_head kernel_post_load_data;
	struct hlist_head kernel_read_file;
	struct hlist_head kernel_post_read_file;
	struct hlist_head task_fix_setuid;
	struct hlist_head task_fix_setgid;
	struct hlist_head task_setpgid;
	struct hlist_head task_getpgid;
	struct hlist_head task_getsid;
	struct hlist_head task_getsecid_subj;
	struct hlist_head task_getsecid_obj;
	struct hlist_head task_setnice;
	struct hlist_head task_setioprio;
	struct hlist_head task_getioprio;
	struct hlist_head task_prlimit;
	struct hlist_head task_setrlimit;
	struct hlist_head task_setscheduler;
	struct hlist_head task_getscheduler;
	struct hlist_head task_movememory;
	struct hlist_head task_kill;
	struct hlist_head task_prctl;
	struct hlist_head task_to_inode;
	struct hlist_head ipc_permission;
	struct hlist_head ipc_getsecid;
	struct hlist_head msg_msg_alloc_security;
	struct hlist_head msg_msg_free_security;
	struct hlist_head msg_queue_alloc_security;
	struct hlist_head msg_queue_free_security;
	struct hlist_head msg_queue_associate;
	struct hlist_head msg_queue_msgctl;
	struct hlist_head msg_queue_msgsnd;
	struct hlist_head msg_queue_msgrcv;
	struct hlist_head shm_alloc_security;
	struct hlist_head shm_free_security;
	struct hlist_head shm_associate;
	struct hlist_head shm_shmctl;
	struct hlist_head shm_shmat;
	struct hlist_head sem_alloc_security;
	struct hlist_head sem_free_security;
	struct hlist_head sem_associate;
	struct hlist_head sem_semctl;
	struct hlist_head sem_semop;
	struct hlist_head netlink_send;
	struct hlist_head d_instantiate;
	struct hlist_head getprocattr;
	struct hlist_head setprocattr;
	struct hlist_head ismaclabel;
	struct hlist_head secid_to_secctx;
	struct hlist_head secctx_to_secid;
	struct hlist_head release_secctx;
	struct hlist_head inode_invalidate_secctx;
	struct hlist_head inode_notifysecctx;
	struct hlist_head inode_setsecctx;
	struct hlist_head inode_getsecctx;
	struct hlist_head post_notification;
	struct hlist_head watch_key;
	struct hlist_head unix_stream_connect;
	struct hlist_head unix_may_send;
	struct hlist_head socket_create;
	struct hlist_head socket_post_create;
	struct hlist_head socket_socketpair;
	struct hlist_head socket_bind;
	struct hlist_head socket_connect;
	struct hlist_head socket_listen;
	struct hlist_head socket_accept;
	struct hlist_head socket_sendmsg;
	struct hlist_head socket_recvmsg;
	struct hlist_head socket_getsockname;
	struct hlist_head socket_getpeername;
	struct hlist_head socket_getsockopt;
	struct hlist_head socket_setsockopt;
	struct hlist_head socket_shutdown;
	struct hlist_head socket_sock_rcv_skb;
	struct hlist_head socket_getpeersec_stream;
	struct hlist_head socket_getpeersec_dgram;
	struct hlist_head sk_alloc_security;
	struct hlist_head sk_free_security;
	struct hlist_head sk_clone_security;
	struct hlist_head sk_getsecid;
	struct hlist_head sock_graft;
	struct hlist_head inet_conn_request;
	struct hlist_head inet_csk_clone;
	struct hlist_head inet_conn_established;
	struct hlist_head secmark_relabel_packet;
	struct hlist_head secmark_refcount_inc;
	struct hlist_head secmark_refcount_dec;
	struct hlist_head req_classify_flow;
	struct hlist_head tun_dev_alloc_security;
	struct hlist_head tun_dev_free_security;
	struct hlist_head tun_dev_create;
	struct hlist_head tun_dev_attach_queue;
	struct hlist_head tun_dev_attach;
	struct hlist_head tun_dev_open;
	struct hlist_head sctp_assoc_request;
	struct hlist_head sctp_bind_connect;
	struct hlist_head sctp_sk_clone;
	struct hlist_head ib_pkey_access;
	struct hlist_head ib_endport_manage_subnet;
	struct hlist_head ib_alloc_security;
	struct hlist_head ib_free_security;
	struct hlist_head xfrm_policy_alloc_security;
	struct hlist_head xfrm_policy_clone_security;
	struct hlist_head xfrm_policy_free_security;
	struct hlist_head xfrm_policy_delete_security;
	struct hlist_head xfrm_state_alloc;
	struct hlist_head xfrm_state_alloc_acquire;
	struct hlist_head xfrm_state_free_security;
	struct hlist_head xfrm_state_delete_security;
	struct hlist_head xfrm_policy_lookup;
	struct hlist_head xfrm_state_pol_flow_match;
	struct hlist_head xfrm_decode_session;
	struct hlist_head key_alloc;
	struct hlist_head key_free;
	struct hlist_head key_permission;
	struct hlist_head key_getsecurity;
	struct hlist_head audit_rule_init;
	struct hlist_head audit_rule_known;
	struct hlist_head audit_rule_match;
	struct hlist_head audit_rule_free;
	struct hlist_head bpf;
	struct hlist_head bpf_map;
	struct hlist_head bpf_prog;
	struct hlist_head bpf_map_alloc_security;
	struct hlist_head bpf_map_free_security;
	struct hlist_head bpf_prog_alloc_security;
	struct hlist_head bpf_prog_free_security;
	struct hlist_head locked_down;
	struct hlist_head lock_kernel_down;
	struct hlist_head perf_event_open;
	struct hlist_head perf_event_alloc;
	struct hlist_head perf_event_free;
	struct hlist_head perf_event_read;
	struct hlist_head perf_event_write;
};

struct lsm_id {
	const char *lsm;
	int slot;
};

struct security_hook_list {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options hook;
	struct lsm_id *lsmid;
};

enum lsm_order {
	LSM_ORDER_FIRST = 0,
	LSM_ORDER_MUTABLE = 0,
};

struct lsm_info {
	const char *name;
	enum lsm_order order;
	long unsigned int flags;
	int *enabled;
	int (*init)();
	struct lsm_blob_sizes *blobs;
};

struct fwnode_operations___110;

struct fwnode_handle___110 {
	struct fwnode_handle___110 *secondary;
	const struct fwnode_operations___110 *ops;
	struct device___110 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___110;

struct fwnode_endpoint___110;

struct fwnode_operations___110 {
	struct fwnode_handle___110 * (*get)(struct fwnode_handle___110 *);
	void (*put)(struct fwnode_handle___110 *);
	bool (*device_is_available)(const struct fwnode_handle___110 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___110 *, const struct device___110 *);
	bool (*property_present)(const struct fwnode_handle___110 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___110 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___110 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___110 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*get_parent)(const struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*get_next_child_node)(const struct fwnode_handle___110 *, struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*get_named_child_node)(const struct fwnode_handle___110 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___110 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___110 *);
	struct fwnode_handle___110 * (*graph_get_next_endpoint)(const struct fwnode_handle___110 *, struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*graph_get_remote_endpoint)(const struct fwnode_handle___110 *);
	struct fwnode_handle___110 * (*graph_get_port_parent)(struct fwnode_handle___110 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___110 *, struct fwnode_endpoint___110 *);
	int (*add_links)(struct fwnode_handle___110 *);
};

struct fwnode_endpoint___110 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___110 *local_fwnode;
};

struct fwnode_reference_args___110 {
	struct fwnode_handle___110 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_syscall_ops___141;

struct kernfs_root___141 {
	struct kernfs_node___141 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___141 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_open_file___141;

struct kernfs_ops___141 {
	int (*open)(struct kernfs_open_file___141 *);
	void (*release)(struct kernfs_open_file___141 *);
	int (*seq_show)(struct seq_file___132 *, void *);
	void * (*seq_start)(struct seq_file___132 *, loff_t *);
	void * (*seq_next)(struct seq_file___132 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___132 *, void *);
	ssize_t (*read)(struct kernfs_open_file___141 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___141 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___141 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___141 *, struct vm_area_struct___159 *);
};

struct kernfs_syscall_ops___141 {
	int (*show_options)(struct seq_file___132 *, struct kernfs_root___141 *);
	int (*mkdir)(struct kernfs_node___141 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___141 *);
	int (*rename)(struct kernfs_node___141 *, struct kernfs_node___141 *, const char *);
	int (*show_path)(struct seq_file___132 *, struct kernfs_node___141 *, struct kernfs_root___141 *);
};

struct kernfs_open_file___141 {
	struct kernfs_node___141 *kn;
	struct file___154 *file;
	struct seq_file___132 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___150 *vm_ops;
};

struct bin_attribute___141;

struct attribute_group___141 {
	const char *name;
	umode_t (*is_visible)(struct kobject___141 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___141 *, struct bin_attribute___141 *, int);
	struct attribute **attrs;
	struct bin_attribute___141 **bin_attrs;
};

struct bin_attribute___141 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___154 * (*f_mapping)();
	ssize_t (*read)(struct file___154 *, struct kobject___141 *, struct bin_attribute___141 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___154 *, struct kobject___141 *, struct bin_attribute___141 *, char *, loff_t, size_t);
	int (*mmap)(struct file___154 *, struct kobject___141 *, struct bin_attribute___141 *, struct vm_area_struct___159 *);
};

struct sysfs_ops___141 {
	ssize_t (*show)(struct kobject___141 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___141 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___141;

struct kset___141 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___141 kobj;
	const struct kset_uevent_ops___141 *uevent_ops;
};

struct kobj_type___141 {
	void (*release)(struct kobject___141 *);
	const struct sysfs_ops___141 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___141 **default_groups;
	const struct kobj_ns_type_operations___15 * (*child_ns_type)(struct kobject___141 *);
	const void * (*namespace)(struct kobject___141 *);
	void (*get_ownership)(struct kobject___141 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___141 {
	int (* const filter)(struct kset___141 *, struct kobject___141 *);
	const char * (* const name)(struct kset___141 *, struct kobject___141 *);
	int (* const uevent)(struct kset___141 *, struct kobject___141 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___138 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___138 *);
	int (*get)(char *, const struct kernel_param___138 *);
	void (*free)(void *);
};

struct kparam_array___138;

struct kernel_param___138 {
	const char *name;
	struct module___139 *mod;
	const struct kernel_param_ops___138 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___138 *arr;
	};
};

struct kparam_array___138 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___138 *ops;
	void *elem;
};

struct module_attribute___138 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___138 *, struct module_kobject___138 *, char *);
	ssize_t (*store)(struct module_attribute___138 *, struct module_kobject___138 *, const char *, size_t);
	void (*setup)(struct module___139 *, const char *);
	int (*test)(struct module___139 *);
	void (*free)(struct module___139 *);
};

struct seq_operations___132 {
	void * (*start)(struct seq_file___132 *, loff_t *);
	void (*stop)(struct seq_file___132 *, void *);
	void * (*next)(struct seq_file___132 *, void *, loff_t *);
	int (*show)(struct seq_file___132 *, void *);
};

struct bpf_iter_aux_info___25;

typedef int (*bpf_iter_init_seq_priv_t___24)(void *, struct bpf_iter_aux_info___25 *);

struct bpf_iter_aux_info___25 {
	struct bpf_map___24 *map;
};

struct bpf_iter_seq_info___24 {
	const struct seq_operations___132 *seq_ops;
	bpf_iter_init_seq_priv_t___24 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___24 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___24 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___24 *, struct file___154 *);
	void (*map_free)(struct bpf_map___24 *);
	int (*map_get_next_key)(struct bpf_map___24 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___24 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___24 *, void *);
	int (*map_lookup_batch)(struct bpf_map___24 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___24 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___24 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___24 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___24 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___24 *, void *);
	int (*map_update_elem)(struct bpf_map___24 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___24 *, void *);
	int (*map_push_elem)(struct bpf_map___24 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___24 *, void *);
	int (*map_peek_elem)(struct bpf_map___24 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___24 *, struct file___154 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___24 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___24 *, void *, struct seq_file___132 *);
	int (*map_check_btf)(const struct bpf_map___24 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___24 *, struct bpf_prog_aux___24 *);
	void (*map_poke_untrack)(struct bpf_map___24 *, struct bpf_prog_aux___24 *);
	void (*map_poke_run)(struct bpf_map___24 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___24 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___24 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___24 *, struct vm_area_struct___159 *);
	__poll_t (*map_poll)(struct bpf_map___24 *, struct file___154 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___24 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___24 *, const struct bpf_map___24 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___24 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___24 *iter_seq_info;
};

struct bpf_trampoline___24 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___139 *mod;
};

struct bpf_jit_poke_descriptor___24 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___24 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___24 {
	struct btf *btf;
	struct module___139 *module;
};

struct cftype___103;

struct cgroup_subsys___103 {
	struct cgroup_subsys_state___103 * (*css_alloc)(struct cgroup_subsys_state___103 *);
	int (*css_online)(struct cgroup_subsys_state___103 *);
	void (*css_offline)(struct cgroup_subsys_state___103 *);
	void (*css_released)(struct cgroup_subsys_state___103 *);
	void (*css_free)(struct cgroup_subsys_state___103 *);
	void (*css_reset)(struct cgroup_subsys_state___103 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___103 *, int);
	int (*css_extra_stat_show)(struct seq_file___132 *, struct cgroup_subsys_state___103 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___161 *, struct css_set___103 *);
	void (*cancel_fork)(struct task_struct___161 *, struct css_set___103 *);
	void (*fork)(struct task_struct___161 *);
	void (*exit)(struct task_struct___161 *);
	void (*release)(struct task_struct___161 *);
	void (*bind)(struct cgroup_subsys_state___103 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___103 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___103 *dfl_cftypes;
	struct cftype___103 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___103 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___103 *updated_children;
	struct cgroup___103 *updated_next;
};

struct cgroup_root___103 {
	struct kernfs_root___141 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___103 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___103 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___103 *ss;
	struct list_head node;
	struct kernfs_ops___141 *kf_ops;
	int (*open)(struct kernfs_open_file___141 *);
	void (*release)(struct kernfs_open_file___141 *);
	u64 (*read_u64)(struct cgroup_subsys_state___103 *, struct cftype___103 *);
	s64 (*read_s64)(struct cgroup_subsys_state___103 *, struct cftype___103 *);
	int (*seq_show)(struct seq_file___132 *, void *);
	void * (*seq_start)(struct seq_file___132 *, loff_t *);
	void * (*seq_next)(struct seq_file___132 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___132 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___103 *, struct cftype___103 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___103 *, struct cftype___103 *, s64);
	ssize_t (*write)(struct kernfs_open_file___141 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___141 *, struct poll_table_struct___5 *);
};

struct dev_pm_ops___110 {
	int (*prepare)(struct device___110 *);
	void (*complete)(struct device___110 *);
	int (*suspend)(struct device___110 *);
	int (*resume)(struct device___110 *);
	int (*freeze)(struct device___110 *);
	int (*thaw)(struct device___110 *);
	int (*poweroff)(struct device___110 *);
	int (*restore)(struct device___110 *);
	int (*suspend_late)(struct device___110 *);
	int (*resume_early)(struct device___110 *);
	int (*freeze_late)(struct device___110 *);
	int (*thaw_early)(struct device___110 *);
	int (*poweroff_late)(struct device___110 *);
	int (*restore_early)(struct device___110 *);
	int (*suspend_noirq)(struct device___110 *);
	int (*resume_noirq)(struct device___110 *);
	int (*freeze_noirq)(struct device___110 *);
	int (*thaw_noirq)(struct device___110 *);
	int (*poweroff_noirq)(struct device___110 *);
	int (*restore_noirq)(struct device___110 *);
	int (*runtime_suspend)(struct device___110 *);
	int (*runtime_resume)(struct device___110 *);
	int (*runtime_idle)(struct device___110 *);
};

struct wakeup_source___110 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___110 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___110 {
	struct dev_pm_ops___110 ops;
	int (*start)(struct device___110 *);
	void (*detach)(struct device___110 *, bool);
	int (*activate)(struct device___110 *);
	void (*sync)(struct device___110 *);
	void (*dismiss)(struct device___110 *);
};

struct bus_type___110 {
	const char *name;
	const char *dev_name;
	struct device___110 *dev_root;
	const struct attribute_group___141 **bus_groups;
	const struct attribute_group___141 **dev_groups;
	const struct attribute_group___141 **drv_groups;
	int (*match)(struct device___110 *, struct device_driver___110 *);
	int (*uevent)(struct device___110 *, struct kobj_uevent_env *);
	int (*probe)(struct device___110 *);
	void (*sync_state)(struct device___110 *);
	void (*remove)(struct device___110 *);
	void (*shutdown)(struct device___110 *);
	int (*online)(struct device___110 *);
	int (*offline)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	int (*num_vf)(struct device___110 *);
	int (*dma_configure)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___110 {
	const char *name;
	struct bus_type___110 *bus;
	struct module___139 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___110 *);
	void (*sync_state)(struct device___110 *);
	int (*remove)(struct device___110 *);
	void (*shutdown)(struct device___110 *);
	int (*suspend)(struct device___110 *, pm_message_t);
	int (*resume)(struct device___110 *);
	const struct attribute_group___141 **groups;
	const struct attribute_group___141 **dev_groups;
	const struct dev_pm_ops___110 *pm;
	void (*coredump)(struct device___110 *);
	struct driver_private *p;
};

struct device_type___110 {
	const char *name;
	const struct attribute_group___141 **groups;
	int (*uevent)(struct device___110 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___110 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___110 *);
	const struct dev_pm_ops___110 *pm;
};

struct class___110 {
	const char *name;
	struct module___139 *owner;
	const struct attribute_group___141 **class_groups;
	const struct attribute_group___141 **dev_groups;
	struct kobject___141 *dev_kobj;
	int (*dev_uevent)(struct device___110 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___110 *, umode_t *);
	void (*class_release)(struct class___110 *);
	void (*dev_release)(struct device___110 *);
	int (*shutdown_pre)(struct device___110 *);
	const struct kobj_ns_type_operations___15 *ns_type;
	const void * (*namespace)(struct device___110 *);
	void (*get_ownership)(struct device___110 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___110 *pm;
	struct subsys_private *p;
};

struct block_device_operations___67;

struct gendisk___67 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___68 *part0;
	const struct block_device_operations___67 *fops;
	struct request_queue___67 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___64 *bdi;
	struct kobject___141 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___141 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___67 {
	struct bio___67 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___81 *bip_vec;
	struct bio_vec___81 bip_inline_vecs[0];
};

struct blkcg___64;

struct blkg_policy_data___64;

struct blkcg_gq___64 {
	struct request_queue___67 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___64 *blkcg;
	struct blkcg_gq___64 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___64 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___67 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___67(struct request___67 *);

typedef void integrity_complete_fn___67(struct request___67 *, unsigned int);

struct blk_integrity_profile___67 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___67 *prepare_fn;
	integrity_complete_fn___67 *complete_fn;
	const char *name;
};

struct block_device_operations___67 {
	blk_qc_t (*submit_bio)(struct bio___67 *);
	int (*open)(struct block_device___68 *, fmode_t);
	void (*release)(struct gendisk___67 *, fmode_t);
	int (*rw_page)(struct block_device___68 *, sector_t, struct page___159 *, unsigned int);
	int (*ioctl)(struct block_device___68 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___68 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___67 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___67 *);
	int (*getgeo)(struct block_device___68 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___68 *, bool);
	void (*swap_slot_free_notify)(struct block_device___68 *, long unsigned int);
	int (*report_zones)(struct gendisk___67 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___67 *, umode_t *);
	struct module___139 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___67 *, sector_t *);
};

typedef void rq_end_io_fn___67(struct request___67 *, blk_status_t);

struct request___67 {
	struct request_queue___67 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___64 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___67 *bio;
	struct bio___67 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___81 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___67 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___67 *saved_end_io;
		} flush;
	};
	struct gendisk___67 *rq_disk;
	struct block_device___68 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___67 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___64 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___67 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___141 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___154 *debugfs_dir;
	struct dentry___154 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___67;

struct elevator_mq_ops___67 {
	int (*init_sched)(struct request_queue___67 *, struct elevator_type___67 *);
	void (*exit_sched)(struct elevator_queue___67 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___64 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___64 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___64 *);
	bool (*allow_merge)(struct request_queue___67 *, struct request___67 *, struct bio___67 *);
	bool (*bio_merge)(struct request_queue___67 *, struct bio___67 *, unsigned int);
	int (*request_merge)(struct request_queue___67 *, struct request___67 **, struct bio___67 *);
	void (*request_merged)(struct request_queue___67 *, struct request___67 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___67 *, struct request___67 *, struct request___67 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___67 *);
	void (*finish_request)(struct request___67 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___64 *, struct list_head *, bool);
	struct request___67 * (*dispatch_request)(struct blk_mq_hw_ctx___64 *);
	bool (*has_work)(struct blk_mq_hw_ctx___64 *);
	void (*completed_request)(struct request___67 *, u64);
	void (*requeue_request)(struct request___67 *);
	struct request___67 * (*former_request)(struct request_queue___67 *, struct request___67 *);
	struct request___67 * (*next_request)(struct request_queue___67 *, struct request___67 *);
	void (*init_icq)(struct io_cq___67 *);
	void (*exit_icq)(struct io_cq___67 *);
};

struct elv_fs_entry___67;

struct elevator_type___67 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___67 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___67 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___139 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___67 {
	struct elevator_type___67 *type;
	void *elevator_data;
	struct kobject___141 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___67 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___67 *, char *);
	ssize_t (*store)(struct elevator_queue___67 *, const char *, size_t);
};

struct blk_mq_queue_data___64;

struct blk_mq_ops___64 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___64 *, const struct blk_mq_queue_data___64 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___64 *);
	int (*get_budget)(struct request_queue___67 *);
	void (*put_budget)(struct request_queue___67 *, int);
	void (*set_rq_budget_token)(struct request___67 *, int);
	int (*get_rq_budget_token)(struct request___67 *);
	enum blk_eh_timer_return (*timeout)(struct request___67 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___64 *);
	void (*complete)(struct request___67 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___64 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___64 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___64 *, struct request___67 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___64 *, struct request___67 *, unsigned int);
	void (*initialize_rq_fn)(struct request___67 *);
	void (*cleanup_rq)(struct request___67 *);
	bool (*busy)(struct request_queue___67 *);
	int (*map_queues)(struct blk_mq_tag_set___64 *);
	void (*show_rq)(struct seq_file___132 *, struct request___67 *);
};

struct blk_mq_tag_set___64 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___64 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___64 {
	struct request___67 *rq;
	bool last;
};

struct blkcg_policy_data___64;

struct blkcg___64 {
	struct cgroup_subsys_state___103 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___64 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___64 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___64 {
	struct blkcg___64 *blkcg;
	int plid;
};

struct blkg_policy_data___64 {
	struct blkcg_gq___64 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___55 {
	struct mem_cgroup___55 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___55 {
	struct lruvec___62 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___55 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___55 *memcg;
};

struct obj_cgroup___55 {
	struct percpu_ref refcnt;
	struct mem_cgroup___55 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct proto_ops___16 {
	int family;
	struct module___139 *owner;
	int (*release)(struct socket___16 *);
	int (*bind)(struct socket___16 *, struct sockaddr *, int);
	int (*connect)(struct socket___16 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___16 *, struct socket___16 *);
	int (*accept)(struct socket___16 *, struct socket___16 *, int, bool);
	int (*getname)(struct socket___16 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___154 *, struct socket___16 *, struct poll_table_struct___5 *);
	int (*ioctl)(struct socket___16 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___16 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___16 *, void *, bool, bool);
	int (*listen)(struct socket___16 *, int);
	int (*shutdown)(struct socket___16 *, int);
	int (*setsockopt)(struct socket___16 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___16 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___132 *, struct socket___16 *);
	int (*sendmsg)(struct socket___16 *, struct msghdr___16 *, size_t);
	int (*recvmsg)(struct socket___16 *, struct msghdr___16 *, size_t, int);
	int (*mmap)(struct file___154 *, struct socket___16 *, struct vm_area_struct___159 *);
	ssize_t (*sendpage)(struct socket___16 *, struct page___159 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___16 *, loff_t *, struct pipe_inode_info___47 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock *, int);
	int (*peek_len)(struct socket___16 *);
	int (*read_sock)(struct sock *, read_descriptor_t *, sk_read_actor_t___15);
	int (*sendpage_locked)(struct sock *, struct page___159 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock *, struct msghdr___16 *, size_t);
	int (*set_rcvlowat)(struct sock *, int);
};

struct pipe_buf_operations___47;

struct pipe_buffer___47 {
	struct page___159 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___47 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___47 {
	int (*confirm)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
	void (*release)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
	bool (*try_steal)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
	bool (*get)(struct pipe_inode_info___47 *, struct pipe_buffer___47 *);
};

struct coredump_params___27 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___154 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dentry___155;

struct super_block___155;

struct module___140;

struct file_system_type___155 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___155 * (*mount)(struct file_system_type___155 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___155 *);
	struct module___140 *owner;
	struct file_system_type___155 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___155;

struct kiocb___155;

struct iov_iter___84;

struct poll_table_struct___96;

struct vm_area_struct___160;

struct inode___155;

struct file_lock___155;

struct page___160;

struct pipe_inode_info___48;

struct seq_file___133;

struct file_operations___155 {
	struct module___140 *owner;
	loff_t (*llseek)(struct file___155 *, loff_t, int);
	ssize_t (*read)(struct file___155 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___155 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___155 *, struct iov_iter___84 *);
	ssize_t (*write_iter)(struct kiocb___155 *, struct iov_iter___84 *);
	int (*iopoll)(struct kiocb___155 *, bool);
	int (*iterate)(struct file___155 *, struct dir_context *);
	int (*iterate_shared)(struct file___155 *, struct dir_context *);
	__poll_t (*poll)(struct file___155 *, struct poll_table_struct___96 *);
	long int (*unlocked_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___155 *, struct vm_area_struct___160 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___155 *, struct file___155 *);
	int (*flush)(struct file___155 *, fl_owner_t);
	int (*release)(struct inode___155 *, struct file___155 *);
	int (*fsync)(struct file___155 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___155 *, int);
	int (*lock)(struct file___155 *, int, struct file_lock___155 *);
	ssize_t (*sendpage)(struct file___155 *, struct page___160 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___155 *, long unsigned int);
	int (*flock)(struct file___155 *, int, struct file_lock___155 *);
	ssize_t (*splice_write)(struct pipe_inode_info___48 *, struct file___155 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___155 *, loff_t *, struct pipe_inode_info___48 *, size_t, unsigned int);
	int (*setlease)(struct file___155 *, long int, struct file_lock___155 **, void **);
	long int (*fallocate)(struct file___155 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___133 *, struct file___155 *);
	ssize_t (*copy_file_range)(struct file___155 *, loff_t, struct file___155 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___155 *, loff_t, struct file___155 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___155 *, loff_t, loff_t, int);
};

struct vmacache___160 {
	u64 seqnum;
	struct vm_area_struct___160 *vmas[4];
};

struct page_frag___160 {
	struct page___160 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___161;

struct pid___136;

struct nsproxy___145;

struct signal_struct___156;

struct bio_list___68;

struct backing_dev_info___65;

struct io_context___68;

struct css_set___104;

struct mem_cgroup___56;

struct request_queue___68;

struct vm_struct___139;

struct task_struct___162 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___162 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___161 *mm;
	struct mm_struct___161 *active_mm;
	struct vmacache___160 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___162 *real_parent;
	struct task_struct___162 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___162 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___136 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	struct key___7 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___145 *nsproxy;
	struct signal_struct___156 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___162 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___68 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___65 *backing_dev_info;
	struct io_context___68 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___104 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___48 *splice_pipe;
	struct page_frag___160 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___56 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___56 *active_memcg;
	struct request_queue___68 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___162 *oom_reaper_list;
	struct vm_struct___139 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___69 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___142;

struct kobj_type___142;

struct kernfs_node___142;

struct kobject___142 {
	const char *name;
	struct list_head entry;
	struct kobject___142 *parent;
	struct kset___142 *kset;
	struct kobj_type___142 *ktype;
	struct kernfs_node___142 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___139 {
	struct kobject___142 kobj;
	struct module___140 *mod;
	struct kobject___142 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___139 {
	struct module___140 *mod;
	struct latch_tree_node node;
};

struct module_layout___139 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___139 mtn;
};

struct module_attribute___139;

struct kernel_param___139;

struct module___140 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___139 mkobj;
	struct module_attribute___139 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___142 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___139 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___139 core_layout;
	struct module_layout___139 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___155;

struct path___155 {
	struct vfsmount___155 *mnt;
	struct dentry___155 *dentry;
};

struct fown_struct___136 {
	rwlock_t lock;
	struct pid___136 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___155;

struct file___155 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___155 f_path;
	struct inode___155 *f_inode;
	const struct file_operations___155 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___136 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___155 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___160 *pgtable_t___160;

struct page_pool___39;

struct dev_pagemap___151;

struct page___160 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___155 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___39 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___160 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___160 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___161 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___151 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___151;

struct vm_area_struct___160 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___160 *vm_next;
	struct vm_area_struct___160 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___161 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___151 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___155 *vm_file;
	struct file___155 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___160;

struct mm_struct___161 {
	struct {
		struct vm_area_struct___160 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___160 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___162 *owner;
		struct user_namespace___23 *user_ns;
		struct file___155 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___155;

struct address_space___155 {
	struct inode___155 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___155 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___111;

struct page_pool_params___39 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___111 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___39 {
	u32 count;
	struct page___160 *cache[128];
};

struct page_pool___39 {
	struct page_pool_params___39 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___160 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___39 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___151;

struct dev_pagemap___151 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___151 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___151;

struct vm_operations_struct___151 {
	void (*open)(struct vm_area_struct___160 *);
	void (*close)(struct vm_area_struct___160 *);
	int (*may_split)(struct vm_area_struct___160 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___160 *);
	int (*mprotect)(struct vm_area_struct___160 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___151 *);
	vm_fault_t (*huge_fault)(struct vm_fault___151 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___151 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___160 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___151 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___151 *);
	int (*access)(struct vm_area_struct___160 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___160 *);
	int (*set_policy)(struct vm_area_struct___160 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___160 *, long unsigned int);
	struct page___160 * (*find_special_page)(struct vm_area_struct___160 *, long unsigned int);
};

struct core_thread___160 {
	struct task_struct___162 *task;
	struct core_thread___160 *next;
};

struct core_state___160 {
	atomic_t nr_threads;
	struct core_thread___160 dumper;
	struct completion startup;
};

struct vm_fault___151 {
	const struct {
		struct vm_area_struct___160 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___160 *cow_page;
	struct page___160 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___160 prealloc_pte;
};

struct pid_namespace___136;

struct upid___136 {
	int nr;
	struct pid_namespace___136 *ns;
};

struct pid_namespace___136 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___162 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___136 *parent;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___136 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___136 numbers[1];
};

struct signal_struct___156 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___162 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___162 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___136 *pids[4];
	struct pid___136 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___161 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___29;

struct cgroup_namespace___104;

struct nsproxy___145 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___136 *pid_ns_for_children;
	struct net___29 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___104 *cgroup_ns;
};

struct bio___68;

struct bio_list___68 {
	struct bio___68 *head;
	struct bio___68 *tail;
};

struct cgroup_subsys_state___104;

struct bdi_writeback___65 {
	struct backing_dev_info___65 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___104 *memcg_css;
	struct cgroup_subsys_state___104 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___65 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___65 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___111 *dev;
	char dev_name[64];
	struct device___111 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___155 *debug_dir;
};

struct io_cq___68;

struct io_context___68 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___68 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___104;

struct css_set___104 {
	struct cgroup_subsys_state___104 *subsys[14];
	refcount_t refcount;
	struct css_set___104 *dom_cset;
	struct cgroup___104 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___104 *mg_src_cgrp;
	struct cgroup___104 *mg_dst_cgrp;
	struct css_set___104 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___155;

struct pipe_buffer___48;

struct pipe_inode_info___48 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___160 *tmp_page;
	struct fasync_struct___155 *fasync_readers;
	struct fasync_struct___155 *fasync_writers;
	struct pipe_buffer___48 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___104;

struct cgroup_subsys_state___104 {
	struct cgroup___104 *cgroup;
	struct cgroup_subsys___104 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___104 *parent;
};

struct cgroup_file___104 {
	struct kernfs_node___142 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___56;

struct mem_cgroup_per_node___56;

struct mem_cgroup___56 {
	struct cgroup_subsys_state___104 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___104 events_file;
	struct cgroup_file___104 events_local_file;
	struct cgroup_file___104 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___56 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___162 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___56 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___68;

struct blk_integrity___68 {
	const struct blk_integrity_profile___68 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___68 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___68 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___68;

struct elevator_queue___68;

struct blk_mq_ops___65;

struct blk_mq_hw_ctx___65;

struct gendisk___68;

struct blkcg_gq___65;

struct blk_mq_tag_set___65;

struct request_queue___68 {
	struct request___68 *last_merge;
	struct elevator_queue___68 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___65 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___65 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___68 *disk;
	struct kobject___142 kobj;
	struct kobject___142 *mq_kobj;
	struct blk_integrity___68 integrity;
	struct device___111 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___65 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___65 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___68 bio_split;
	struct dentry___155 *debugfs_dir;
	struct dentry___155 *sched_debugfs_dir;
	struct dentry___155 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___139 {
	struct vm_struct___139 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___160 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___63;

struct lruvec___63 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___63 *pgdat;
};

struct zone___63 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___63 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___63 {
	struct zone___63 *zone;
	int zone_idx;
};

struct zonelist___63 {
	struct zoneref___63 _zonerefs[321];
};

struct pglist_data___63 {
	struct zone___63 node_zones[5];
	struct zonelist___63 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___162 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___162 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___63 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___155;

struct dentry___155 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___155 *d_parent;
	struct qstr d_name;
	struct inode___155 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___155 *d_op;
	struct super_block___155 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___155;

struct inode___155 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___155 *i_op;
	struct super_block___155 *i_sb;
	struct address_space___155 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___65 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___155 *i_fop;
		void (*free_inode)(struct inode___155 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___155 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___48 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___155 {
	int (*d_revalidate)(struct dentry___155 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___155 *, unsigned int);
	int (*d_hash)(const struct dentry___155 *, struct qstr *);
	int (*d_compare)(const struct dentry___155 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___155 *);
	int (*d_init)(struct dentry___155 *);
	void (*d_release)(struct dentry___155 *);
	void (*d_prune)(struct dentry___155 *);
	void (*d_iput)(struct dentry___155 *, struct inode___155 *);
	char * (*d_dname)(struct dentry___155 *, char *, int);
	struct vfsmount___155 * (*d_automount)(struct path___155 *);
	int (*d_manage)(const struct path___155 *, bool);
	struct dentry___155 * (*d_real)(struct dentry___155 *, const struct inode___155 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___155;

struct mem_dqinfo___155 {
	struct quota_format_type___155 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___155;

struct quota_info___155 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___155 *files[3];
	struct mem_dqinfo___155 info[3];
	const struct quota_format_ops___155 *ops[3];
};

struct rcuwait___156 {
	struct task_struct___162 *task;
};

struct percpu_rw_semaphore___156 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___156 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___155 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___156 rw_sem[3];
};

struct shrink_control___56;

struct shrinker___56 {
	long unsigned int (*count_objects)(struct shrinker___56 *, struct shrink_control___56 *);
	long unsigned int (*scan_objects)(struct shrinker___56 *, struct shrink_control___56 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___155;

struct dquot_operations___155;

struct quotactl_ops___155;

struct xattr_handler___20;

struct block_device___69;

struct super_block___155 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___155 *s_type;
	const struct super_operations___155 *s_op;
	const struct dquot_operations___155 *dq_op;
	const struct quotactl_ops___155 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___155 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___20 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___7 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___69 *s_bdev;
	struct backing_dev_info___65 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___155 s_dquot;
	struct sb_writers___155 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___155 *s_d_op;
	int cleancache_poolid;
	struct shrinker___56 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___155 {
	struct dentry___155 *mnt_root;
	struct super_block___155 *mnt_sb;
	int mnt_flags;
	struct user_namespace___23 *mnt_userns;
};

struct shrink_control___56 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___56 *memcg;
};

struct psi_group___104 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___162 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___23;

struct cgroup_bpf___23 {
	struct bpf_prog_array___23 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___23 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___104;

struct cgroup_rstat_cpu___104;

struct cgroup___104 {
	struct cgroup_subsys_state___104 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___142 *kn;
	struct cgroup_file___104 procs_file;
	struct cgroup_file___104 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___104 *subsys[14];
	struct cgroup_root___104 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___104 *dom_cgrp;
	struct cgroup___104 *old_dom_cgrp;
	struct cgroup_rstat_cpu___104 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___104 psi;
	struct cgroup_bpf___23 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___68 {
	struct request_queue___68 *q;
	struct io_context___68 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___155 {
	struct file___155 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___155 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___72 *ki_waitq;
	};
};

struct iattr___155 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___155 *ia_file;
};

struct dquot___155 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___155 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___155 {
	int qf_fmt_id;
	const struct quota_format_ops___155 *qf_ops;
	struct module___140 *qf_owner;
	struct quota_format_type___155 *qf_next;
};

struct quota_format_ops___155 {
	int (*check_quota_file)(struct super_block___155 *, int);
	int (*read_file_info)(struct super_block___155 *, int);
	int (*write_file_info)(struct super_block___155 *, int);
	int (*free_file_info)(struct super_block___155 *, int);
	int (*read_dqblk)(struct dquot___155 *);
	int (*commit_dqblk)(struct dquot___155 *);
	int (*release_dqblk)(struct dquot___155 *);
	int (*get_next_id)(struct super_block___155 *, struct kqid *);
};

struct dquot_operations___155 {
	int (*write_dquot)(struct dquot___155 *);
	struct dquot___155 * (*alloc_dquot)(struct super_block___155 *, int);
	void (*destroy_dquot)(struct dquot___155 *);
	int (*acquire_dquot)(struct dquot___155 *);
	int (*release_dquot)(struct dquot___155 *);
	int (*mark_dirty)(struct dquot___155 *);
	int (*write_info)(struct super_block___155 *, int);
	qsize_t * (*get_reserved_space)(struct inode___155 *);
	int (*get_projid)(struct inode___155 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___155 *, qsize_t *);
	int (*get_next_id)(struct super_block___155 *, struct kqid *);
};

struct quotactl_ops___155 {
	int (*quota_on)(struct super_block___155 *, int, int, const struct path___155 *);
	int (*quota_off)(struct super_block___155 *, int);
	int (*quota_enable)(struct super_block___155 *, unsigned int);
	int (*quota_disable)(struct super_block___155 *, unsigned int);
	int (*quota_sync)(struct super_block___155 *, int);
	int (*set_info)(struct super_block___155 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___155 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___155 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___155 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___155 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___155 *, unsigned int);
};

struct writeback_control___65;

struct address_space_operations___155 {
	int (*writepage)(struct page___160 *, struct writeback_control___65 *);
	int (*readpage)(struct file___155 *, struct page___160 *);
	int (*writepages)(struct address_space___155 *, struct writeback_control___65 *);
	int (*set_page_dirty)(struct page___160 *);
	int (*readpages)(struct file___155 *, struct address_space___155 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___155 *, struct address_space___155 *, loff_t, unsigned int, unsigned int, struct page___160 **, void **);
	int (*write_end)(struct file___155 *, struct address_space___155 *, loff_t, unsigned int, unsigned int, struct page___160 *, void *);
	sector_t (*bmap)(struct address_space___155 *, sector_t);
	void (*invalidatepage)(struct page___160 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___160 *, gfp_t);
	void (*freepage)(struct page___160 *);
	ssize_t (*direct_IO)(struct kiocb___155 *, struct iov_iter___84 *);
	int (*migratepage)(struct address_space___155 *, struct page___160 *, struct page___160 *, enum migrate_mode);
	bool (*isolate_page)(struct page___160 *, isolate_mode_t);
	void (*putback_page)(struct page___160 *);
	int (*launder_page)(struct page___160 *);
	int (*is_partially_uptodate)(struct page___160 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___160 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___155 *, struct page___160 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___155 *, sector_t *);
	void (*swap_deactivate)(struct file___155 *);
};

struct writeback_control___65 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___65 *wb;
	struct inode___155 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___82;

struct iov_iter___84 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___82 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___48 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___155 {
	struct dentry___155 * (*lookup)(struct inode___155 *, struct dentry___155 *, unsigned int);
	const char * (*get_link)(struct dentry___155 *, struct inode___155 *, struct delayed_call *);
	int (*permission)(struct user_namespace___23 *, struct inode___155 *, int);
	struct posix_acl * (*get_acl)(struct inode___155 *, int, bool);
	int (*readlink)(struct dentry___155 *, char *, int);
	int (*create)(struct user_namespace___23 *, struct inode___155 *, struct dentry___155 *, umode_t, bool);
	int (*link)(struct dentry___155 *, struct inode___155 *, struct dentry___155 *);
	int (*unlink)(struct inode___155 *, struct dentry___155 *);
	int (*symlink)(struct user_namespace___23 *, struct inode___155 *, struct dentry___155 *, const char *);
	int (*mkdir)(struct user_namespace___23 *, struct inode___155 *, struct dentry___155 *, umode_t);
	int (*rmdir)(struct inode___155 *, struct dentry___155 *);
	int (*mknod)(struct user_namespace___23 *, struct inode___155 *, struct dentry___155 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___23 *, struct inode___155 *, struct dentry___155 *, struct inode___155 *, struct dentry___155 *, unsigned int);
	int (*setattr)(struct user_namespace___23 *, struct dentry___155 *, struct iattr___155 *);
	int (*getattr)(struct user_namespace___23 *, const struct path___155 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___155 *, char *, size_t);
	int (*fiemap)(struct inode___155 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___155 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___155 *, struct dentry___155 *, struct file___155 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___23 *, struct inode___155 *, struct dentry___155 *, umode_t);
	int (*set_acl)(struct user_namespace___23 *, struct inode___155 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___23 *, struct dentry___155 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___155 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___155 {
	void (*fl_copy_lock)(struct file_lock___155 *, struct file_lock___155 *);
	void (*fl_release_private)(struct file_lock___155 *);
};

struct lock_manager_operations___155;

struct file_lock___155 {
	struct file_lock___155 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___155 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___155 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___155 *fl_ops;
	const struct lock_manager_operations___155 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___155 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___155 *);
	int (*lm_grant)(struct file_lock___155 *, int);
	bool (*lm_break)(struct file_lock___155 *);
	int (*lm_change)(struct file_lock___155 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___155 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___155 *);
};

struct fasync_struct___155 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___155 *fa_next;
	struct file___155 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___155 {
	struct inode___155 * (*alloc_inode)(struct super_block___155 *);
	void (*destroy_inode)(struct inode___155 *);
	void (*free_inode)(struct inode___155 *);
	void (*dirty_inode)(struct inode___155 *, int);
	int (*write_inode)(struct inode___155 *, struct writeback_control___65 *);
	int (*drop_inode)(struct inode___155 *);
	void (*evict_inode)(struct inode___155 *);
	void (*put_super)(struct super_block___155 *);
	int (*sync_fs)(struct super_block___155 *, int);
	int (*freeze_super)(struct super_block___155 *);
	int (*freeze_fs)(struct super_block___155 *);
	int (*thaw_super)(struct super_block___155 *);
	int (*unfreeze_fs)(struct super_block___155 *);
	int (*statfs)(struct dentry___155 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___155 *, int *, char *);
	void (*umount_begin)(struct super_block___155 *);
	int (*show_options)(struct seq_file___133 *, struct dentry___155 *);
	int (*show_devname)(struct seq_file___133 *, struct dentry___155 *);
	int (*show_path)(struct seq_file___133 *, struct dentry___155 *);
	int (*show_stats)(struct seq_file___133 *, struct dentry___155 *);
	ssize_t (*quota_read)(struct super_block___155 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___155 *, int, const char *, size_t, loff_t);
	struct dquot___155 ** (*get_dquots)(struct inode___155 *);
	long int (*nr_cached_objects)(struct super_block___155 *, struct shrink_control___56 *);
	long int (*free_cached_objects)(struct super_block___155 *, struct shrink_control___56 *);
	struct file___155 * (*real_loop)(struct file___155 *);
};

struct xattr_handler___20 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___155 *);
	int (*get)(const struct xattr_handler___20 *, struct dentry___155 *, struct inode___155 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___20 *, struct user_namespace___23 *, struct dentry___155 *, struct inode___155 *, const char *, const void *, size_t, int);
};

struct wakeup_source___111;

struct dev_pm_info___111 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___111 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___111 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___111;

struct bus_type___111;

struct device_driver___111;

struct dev_pm_domain___111;

struct fwnode_handle___111;

struct class___111;

struct attribute_group___142;

struct device___111 {
	struct kobject___142 kobj;
	struct device___111 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___111 *type;
	struct bus_type___111 *bus;
	struct device_driver___111 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___111 power;
	struct dev_pm_domain___111 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___111 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___111 *class;
	const struct attribute_group___142 **groups;
	void (*release)(struct device___111 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___69 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___155 *bd_inode;
	struct super_block___155 *bd_super;
	void *bd_claiming;
	struct device___111 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___142 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___68 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___155 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___98)(struct file___155 *, wait_queue_head_t *, struct poll_table_struct___96 *);

struct poll_table_struct___96 {
	poll_queue_proc___98 _qproc;
	__poll_t _key;
};

struct seq_operations___133;

struct seq_file___133 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___133 *op;
	int poll_event;
	const struct file___155 *file;
	void *private;
};

typedef void bio_end_io_t___68(struct bio___68 *);

struct bio_vec___82 {
	struct page___160 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___68;

struct bio___68 {
	struct bio___68 *bi_next;
	struct block_device___69 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___68 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___65 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___68 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___82 *bi_io_vec;
	struct bio_set___68 *bi_pool;
	struct bio_vec___82 bi_inline_vecs[0];
};

struct kernfs_root___142;

struct kernfs_elem_dir___142 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___142 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___142;

struct kernfs_root___142 {
	struct kernfs_node___142 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___142 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___142 {
	struct kernfs_node___142 *target_kn;
};

struct kernfs_ops___142;

struct kernfs_elem_attr___142 {
	const struct kernfs_ops___142 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___142 *notify_next;
};

struct kernfs_node___142 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___142 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___142 dir;
		struct kernfs_elem_symlink___142 symlink;
		struct kernfs_elem_attr___142 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___142;

struct kernfs_ops___142 {
	int (*open)(struct kernfs_open_file___142 *);
	void (*release)(struct kernfs_open_file___142 *);
	int (*seq_show)(struct seq_file___133 *, void *);
	void * (*seq_start)(struct seq_file___133 *, loff_t *);
	void * (*seq_next)(struct seq_file___133 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___133 *, void *);
	ssize_t (*read)(struct kernfs_open_file___142 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___142 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___142 *, struct poll_table_struct___96 *);
	int (*mmap)(struct kernfs_open_file___142 *, struct vm_area_struct___160 *);
};

struct kernfs_syscall_ops___142 {
	int (*show_options)(struct seq_file___133 *, struct kernfs_root___142 *);
	int (*mkdir)(struct kernfs_node___142 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___142 *);
	int (*rename)(struct kernfs_node___142 *, struct kernfs_node___142 *, const char *);
	int (*show_path)(struct seq_file___133 *, struct kernfs_node___142 *, struct kernfs_root___142 *);
};

struct kernfs_open_file___142 {
	struct kernfs_node___142 *kn;
	struct file___155 *file;
	struct seq_file___133 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___151 *vm_ops;
};

struct sock___17;

struct kobj_ns_type_operations___16 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___17 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___29 *net;
} possible_net_t___23;

struct proto___16;

struct sock_common___16 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___16 *skc_prot;
	possible_net_t___23 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___17 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___25;

struct sk_buff_head___23 {
	struct sk_buff___25 *next;
	struct sk_buff___25 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___16 {
	struct cgroup___104 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___16;

struct socket_wq___17;

struct dst_entry___16;

struct socket___17;

struct net_device___27;

struct sock___17 {
	struct sock_common___16 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___23 sk_error_queue;
	struct sk_buff___25 *sk_rx_skb_cache;
	struct sk_buff_head___23 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___25 *head;
		struct sk_buff___25 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___16 *sk_filter;
	union {
		struct socket_wq___17 *sk_wq;
		struct socket_wq___17 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___16 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___16 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___25 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___25 *sk_tx_skb_cache;
	struct sk_buff_head___23 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___160 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___16 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___136 *sk_peer_pid;
	const struct cred___26 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___17 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___16 sk_cgrp_data;
	struct mem_cgroup___56 *sk_memcg;
	void (*sk_state_change)(struct sock___17 *);
	void (*sk_data_ready)(struct sock___17 *);
	void (*sk_write_space)(struct sock___17 *);
	void (*sk_error_report)(struct sock___17 *);
	int (*sk_backlog_rcv)(struct sock___17 *, struct sk_buff___25 *);
	struct sk_buff___25 * (*sk_validate_xmit_skb)(struct sock___17 *, struct net_device___27 *, struct sk_buff___25 *);
	void (*sk_destruct)(struct sock___17 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___142;

struct attribute_group___142 {
	const char *name;
	umode_t (*is_visible)(struct kobject___142 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___142 *, struct bin_attribute___142 *, int);
	struct attribute **attrs;
	struct bin_attribute___142 **bin_attrs;
};

struct bin_attribute___142 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___155 * (*f_mapping)();
	ssize_t (*read)(struct file___155 *, struct kobject___142 *, struct bin_attribute___142 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___155 *, struct kobject___142 *, struct bin_attribute___142 *, char *, loff_t, size_t);
	int (*mmap)(struct file___155 *, struct kobject___142 *, struct bin_attribute___142 *, struct vm_area_struct___160 *);
};

struct sysfs_ops___142 {
	ssize_t (*show)(struct kobject___142 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___142 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___142;

struct kset___142 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___142 kobj;
	const struct kset_uevent_ops___142 *uevent_ops;
};

struct kobj_type___142 {
	void (*release)(struct kobject___142 *);
	const struct sysfs_ops___142 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___142 **default_groups;
	const struct kobj_ns_type_operations___16 * (*child_ns_type)(struct kobject___142 *);
	const void * (*namespace)(struct kobject___142 *);
	void (*get_ownership)(struct kobject___142 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___142 {
	int (* const filter)(struct kset___142 *, struct kobject___142 *);
	const char * (* const name)(struct kset___142 *, struct kobject___142 *);
	int (* const uevent)(struct kset___142 *, struct kobject___142 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___139 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___139 *);
	int (*get)(char *, const struct kernel_param___139 *);
	void (*free)(void *);
};

struct kparam_array___139;

struct kernel_param___139 {
	const char *name;
	struct module___140 *mod;
	const struct kernel_param_ops___139 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___139 *arr;
	};
};

struct kparam_array___139 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___139 *ops;
	void *elem;
};

struct module_attribute___139 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___139 *, struct module_kobject___139 *, char *);
	ssize_t (*store)(struct module_attribute___139 *, struct module_kobject___139 *, const char *, size_t);
	void (*setup)(struct module___140 *, const char *);
	int (*test)(struct module___140 *);
	void (*free)(struct module___140 *);
};

struct dev_pagemap_ops___151 {
	void (*page_free)(struct page___160 *);
	void (*kill)(struct dev_pagemap___151 *);
	void (*cleanup)(struct dev_pagemap___151 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___151 *);
};

struct bpf_iter_aux_info___26;

typedef int (*bpf_iter_init_seq_priv_t___25)(void *, struct bpf_iter_aux_info___26 *);

struct bpf_map___25;

struct bpf_iter_aux_info___26 {
	struct bpf_map___25 *map;
};

struct bpf_iter_seq_info___25 {
	const struct seq_operations___133 *seq_ops;
	bpf_iter_init_seq_priv_t___25 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___133 {
	void * (*start)(struct seq_file___133 *, loff_t *);
	void (*stop)(struct seq_file___133 *, void *);
	void * (*next)(struct seq_file___133 *, void *, loff_t *);
	int (*show)(struct seq_file___133 *, void *);
};

struct bpf_prog_aux___25;

struct bpf_prog___23;

struct bpf_map_ops___25 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___25 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___25 *, struct file___155 *);
	void (*map_free)(struct bpf_map___25 *);
	int (*map_get_next_key)(struct bpf_map___25 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___25 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___25 *, void *);
	int (*map_lookup_batch)(struct bpf_map___25 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___25 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___25 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___25 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___25 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___25 *, void *);
	int (*map_update_elem)(struct bpf_map___25 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___25 *, void *);
	int (*map_push_elem)(struct bpf_map___25 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___25 *, void *);
	int (*map_peek_elem)(struct bpf_map___25 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___25 *, struct file___155 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___25 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___25 *, void *, struct seq_file___133 *);
	int (*map_check_btf)(const struct bpf_map___25 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___25 *, struct bpf_prog_aux___25 *);
	void (*map_poke_untrack)(struct bpf_map___25 *, struct bpf_prog_aux___25 *);
	void (*map_poke_run)(struct bpf_map___25 *, u32, struct bpf_prog___23 *, struct bpf_prog___23 *);
	int (*map_direct_value_addr)(const struct bpf_map___25 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___25 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___25 *, struct vm_area_struct___160 *);
	__poll_t (*map_poll)(struct bpf_map___25 *, struct file___155 *, struct poll_table_struct___96 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___25 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___25 *, const struct bpf_map___25 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___25 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___25 *iter_seq_info;
};

struct bpf_map___25 {
	const struct bpf_map_ops___25 *ops;
	struct bpf_map___25 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___56 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___25;

struct bpf_jit_poke_descriptor___25;

struct bpf_prog_ops___23;

struct btf_mod_pair___25;

struct bpf_prog_offload___23;

struct bpf_prog_aux___25 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___23 *dst_prog;
	struct bpf_trampoline___25 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___23 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___25 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___23 *ops;
	struct bpf_map___25 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___25 *used_btfs;
	struct bpf_prog___23 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___25 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___23 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___23 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___25 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___23;

struct bpf_map_dev_ops___23 {
	int (*map_get_next_key)(struct bpf_offloaded_map___23 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___23 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___23 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___23 *, void *);
};

struct bpf_offloaded_map___23 {
	struct bpf_map___25 map;
	struct net_device___27 *netdev;
	const struct bpf_map_dev_ops___23 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___23(struct sk_buff___25 **);

struct bpf_xdp_entity___23 {
	struct bpf_prog___23 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___23;

struct net_device_ops___23;

struct l3mdev_ops___16;

struct xfrmdev_ops___23;

struct header_ops___23;

struct netdev_rx_queue___23;

struct mini_Qdisc___23;

struct netdev_queue___23;

struct Qdisc___23;

struct rtnl_link_ops___23;

struct dcbnl_rtnl_ops___23;

struct net_device___27 {
	char name[16];
	struct netdev_name_node___23 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___23 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___16 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___23 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___23 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___142 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___23 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___23 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___23 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___23 *miniq_ingress;
	struct netdev_queue___23 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___23 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___23 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___23 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___23 = 0,
		NETREG_REGISTERED___23 = 1,
		NETREG_UNREGISTERING___23 = 2,
		NETREG_UNREGISTERED___23 = 3,
		NETREG_RELEASED___23 = 4,
		NETREG_DUMMY___23 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___23 = 0,
		RTNL_LINK_INITIALIZING___23 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___27 *);
	struct netpoll_info *npinfo;
	possible_net_t___23 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___111 dev;
	const struct attribute_group___142 *sysfs_groups[4];
	const struct attribute_group___142 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___23 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___23 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___23 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___23 {
	int (*test_run)(struct bpf_prog___23 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___23 {
	struct bpf_prog___23 *prog;
	struct net_device___27 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___25 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___23 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___140 *mod;
};

struct bpf_jit_poke_descriptor___25 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___25 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___25 {
	struct btf *btf;
	struct module___140 *module;
};

struct bpf_prog_array_item___23 {
	struct bpf_prog___23 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___23 {
	struct callback_head rcu;
	struct bpf_prog_array_item___23 items[0];
};

struct sk_buff___25 {
	union {
		struct {
			struct sk_buff___25 *next;
			struct sk_buff___25 *prev;
			union {
				struct net_device___27 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___17 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___25 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

enum lsm_event {
	LSM_POLICY_CHANGE = 0,
};

typedef int (*initxattrs___3)(struct inode___155 *, const struct xattr *, void *);

struct msghdr___17;

union security_list_options___2 {
	int (*binder_set_context_mgr)(const struct cred___26 *);
	int (*binder_transaction)(const struct cred___26 *, const struct cred___26 *);
	int (*binder_transfer_binder)(const struct cred___26 *, const struct cred___26 *);
	int (*binder_transfer_file)(const struct cred___26 *, const struct cred___26 *, struct file___155 *);
	int (*ptrace_access_check)(struct task_struct___162 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___162 *);
	int (*capget)(struct task_struct___162 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___26 *, const struct cred___26 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___26 *, struct user_namespace___23 *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___155 *);
	int (*quota_on)(struct dentry___155 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___161 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___2 *);
	int (*bprm_creds_from_file)(struct linux_binprm___2 *, struct file___155 *);
	int (*bprm_check_security)(struct linux_binprm___2 *);
	void (*bprm_committing_creds)(struct linux_binprm___2 *);
	void (*bprm_committed_creds)(struct linux_binprm___2 *);
	int (*fs_context_dup)(struct fs_context *, struct fs_context *);
	int (*fs_context_parse_param)(struct fs_context *, struct fs_parameter___28 *);
	int (*sb_alloc_security)(struct super_block___155 *);
	void (*sb_delete)(struct super_block___155 *);
	void (*sb_free_security)(struct super_block___155 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___155 *, void *);
	int (*sb_remount)(struct super_block___155 *, void *);
	int (*sb_kern_mount)(struct super_block___155 *);
	int (*sb_show_options)(struct seq_file___133 *, struct super_block___155 *);
	int (*sb_statfs)(struct dentry___155 *);
	int (*sb_mount)(const char *, const struct path___155 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___155 *, int);
	int (*sb_pivotroot)(const struct path___155 *, const struct path___155 *);
	int (*sb_set_mnt_opts)(struct super_block___155 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___155 *, struct super_block___155 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___155 *, const struct path___155 *);
	int (*dentry_init_security)(struct dentry___155 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___155 *, int, struct qstr *, const struct cred___26 *, struct cred___26 *);
	int (*path_unlink)(const struct path___155 *, struct dentry___155 *);
	int (*path_mkdir)(const struct path___155 *, struct dentry___155 *, umode_t);
	int (*path_rmdir)(const struct path___155 *, struct dentry___155 *);
	int (*path_mknod)(const struct path___155 *, struct dentry___155 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___155 *);
	int (*path_symlink)(const struct path___155 *, struct dentry___155 *, const char *);
	int (*path_link)(struct dentry___155 *, const struct path___155 *, struct dentry___155 *);
	int (*path_rename)(const struct path___155 *, struct dentry___155 *, const struct path___155 *, struct dentry___155 *);
	int (*path_chmod)(const struct path___155 *, umode_t);
	int (*path_chown)(const struct path___155 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___155 *);
	int (*path_notify)(const struct path___155 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___155 *);
	void (*inode_free_security)(struct inode___155 *);
	int (*inode_init_security)(struct inode___155 *, struct inode___155 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___155 *, const struct qstr *, const struct inode___155 *);
	int (*inode_create)(struct inode___155 *, struct dentry___155 *, umode_t);
	int (*inode_link)(struct dentry___155 *, struct inode___155 *, struct dentry___155 *);
	int (*inode_unlink)(struct inode___155 *, struct dentry___155 *);
	int (*inode_symlink)(struct inode___155 *, struct dentry___155 *, const char *);
	int (*inode_mkdir)(struct inode___155 *, struct dentry___155 *, umode_t);
	int (*inode_rmdir)(struct inode___155 *, struct dentry___155 *);
	int (*inode_mknod)(struct inode___155 *, struct dentry___155 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___155 *, struct dentry___155 *, struct inode___155 *, struct dentry___155 *);
	int (*inode_readlink)(struct dentry___155 *);
	int (*inode_follow_link)(struct dentry___155 *, struct inode___155 *, bool);
	int (*inode_permission)(struct inode___155 *, int);
	int (*inode_setattr)(struct dentry___155 *, struct iattr___155 *);
	int (*inode_getattr)(const struct path___155 *);
	int (*inode_setxattr)(struct user_namespace___23 *, struct dentry___155 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___155 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___155 *, const char *);
	int (*inode_listxattr)(struct dentry___155 *);
	int (*inode_removexattr)(struct user_namespace___23 *, struct dentry___155 *, const char *);
	int (*inode_need_killpriv)(struct dentry___155 *);
	int (*inode_killpriv)(struct user_namespace___23 *, struct dentry___155 *);
	int (*inode_getsecurity)(struct user_namespace___23 *, struct inode___155 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___155 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___155 *, char *, size_t);
	void (*inode_getsecid)(struct inode___155 *, u32 *);
	int (*inode_copy_up)(struct dentry___155 *, struct cred___26 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___142 *, struct kernfs_node___142 *);
	int (*file_permission)(struct file___155 *, int);
	int (*file_alloc_security)(struct file___155 *);
	void (*file_free_security)(struct file___155 *);
	int (*file_ioctl)(struct file___155 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___155 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___160 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___155 *, unsigned int);
	int (*file_fcntl)(struct file___155 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___155 *);
	int (*file_send_sigiotask)(struct task_struct___162 *, struct fown_struct___136 *, int);
	int (*file_receive)(struct file___155 *);
	int (*file_open)(struct file___155 *);
	int (*task_alloc)(struct task_struct___162 *, long unsigned int);
	void (*task_free)(struct task_struct___162 *);
	int (*cred_alloc_blank)(struct cred___26 *, gfp_t);
	void (*cred_free)(struct cred___26 *);
	int (*cred_prepare)(struct cred___26 *, const struct cred___26 *, gfp_t);
	void (*cred_transfer)(struct cred___26 *, const struct cred___26 *);
	void (*cred_getsecid)(const struct cred___26 *, u32 *);
	int (*kernel_act_as)(struct cred___26 *, u32);
	int (*kernel_create_files_as)(struct cred___26 *, struct inode___155 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___155 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___155 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___26 *, const struct cred___26 *, int);
	int (*task_fix_setgid)(struct cred___26 *, const struct cred___26 *, int);
	int (*task_setpgid)(struct task_struct___162 *, pid_t);
	int (*task_getpgid)(struct task_struct___162 *);
	int (*task_getsid)(struct task_struct___162 *);
	void (*task_getsecid_subj)(struct task_struct___162 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___162 *, u32 *);
	int (*task_setnice)(struct task_struct___162 *, int);
	int (*task_setioprio)(struct task_struct___162 *, int);
	int (*task_getioprio)(struct task_struct___162 *);
	int (*task_prlimit)(const struct cred___26 *, const struct cred___26 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___162 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___162 *);
	int (*task_getscheduler)(struct task_struct___162 *);
	int (*task_movememory)(struct task_struct___162 *);
	int (*task_kill)(struct task_struct___162 *, struct kernel_siginfo *, int, const struct cred___26 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___162 *, struct inode___155 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___162 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock___17 *, struct sk_buff___25 *);
	void (*d_instantiate)(struct dentry___155 *, struct inode___155 *);
	int (*getprocattr)(struct task_struct___162 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___155 *);
	int (*inode_notifysecctx)(struct inode___155 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___155 *, void *, u32);
	int (*inode_getsecctx)(struct inode___155 *, void **, u32 *);
	int (*post_notification)(const struct cred___26 *, const struct cred___26 *, struct watch_notification *);
	int (*watch_key)(struct key___7 *);
	int (*unix_stream_connect)(struct sock___17 *, struct sock___17 *, struct sock___17 *);
	int (*unix_may_send)(struct socket___17 *, struct socket___17 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___17 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___17 *, struct socket___17 *);
	int (*socket_bind)(struct socket___17 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___17 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___17 *, int);
	int (*socket_accept)(struct socket___17 *, struct socket___17 *);
	int (*socket_sendmsg)(struct socket___17 *, struct msghdr___17 *, int);
	int (*socket_recvmsg)(struct socket___17 *, struct msghdr___17 *, int, int);
	int (*socket_getsockname)(struct socket___17 *);
	int (*socket_getpeername)(struct socket___17 *);
	int (*socket_getsockopt)(struct socket___17 *, int, int);
	int (*socket_setsockopt)(struct socket___17 *, int, int);
	int (*socket_shutdown)(struct socket___17 *, int);
	int (*socket_sock_rcv_skb)(struct sock___17 *, struct sk_buff___25 *);
	int (*socket_getpeersec_stream)(struct socket___17 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___17 *, struct sk_buff___25 *, u32 *);
	int (*sk_alloc_security)(struct sock___17 *, int, gfp_t);
	void (*sk_free_security)(struct sock___17 *);
	void (*sk_clone_security)(const struct sock___17 *, struct sock___17 *);
	void (*sk_getsecid)(struct sock___17 *, u32 *);
	void (*sock_graft)(struct sock___17 *, struct socket___17 *);
	int (*inet_conn_request)(const struct sock___17 *, struct sk_buff___25 *, struct request_sock___5 *);
	void (*inet_csk_clone)(struct sock___17 *, const struct request_sock___5 *);
	void (*inet_conn_established)(struct sock___17 *, struct sk_buff___25 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___5 *, struct flowi_common *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock___17 *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___25 *);
	int (*sctp_bind_connect)(struct sock___17 *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock___17 *, struct sock___17 *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common *);
	int (*xfrm_decode_session)(struct sk_buff___25 *, u32 *, int);
	int (*key_alloc)(struct key___7 *, const struct cred___26 *, long unsigned int);
	void (*key_free)(struct key___7 *);
	int (*key_permission)(key_ref_t, const struct cred___26 *, enum key_need_perm);
	int (*key_getsecurity)(struct key___7 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___25 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog___23 *);
	int (*bpf_map_alloc_security)(struct bpf_map___25 *);
	void (*bpf_map_free_security)(struct bpf_map___25 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___25 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___25 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event *);
	void (*perf_event_free)(struct perf_event *);
	int (*perf_event_read)(struct perf_event *);
	int (*perf_event_write)(struct perf_event *);
};

struct socket_wq___17 {
	wait_queue_head_t wait;
	struct fasync_struct___155 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___17;

struct socket___17 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___155 *file;
	struct sock___17 *sk;
	const struct proto_ops___17 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___17 wq;
};

struct msghdr___17 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___84 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___155 *msg_iocb;
};

struct security_hook_list___2 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___2 hook;
	struct lsm_id *lsmid;
};

enum lsm_order___2 {
	LSM_ORDER_FIRST___2 = 4294967295,
	LSM_ORDER_MUTABLE___2 = 0,
};

struct lsm_info___2 {
	const char *name;
	enum lsm_order___2 order;
	long unsigned int flags;
	int *enabled;
	int (*init)();
	struct lsm_blob_sizes *blobs;
};

struct fib_rules_ops___16;

struct fqdir___28;

struct fib_notifier_ops___16;

struct netns_ipv4___28 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___16 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___17 *fibnl;
	struct sock___17 **icmp_sk;
	struct sock___17 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___17 **tcp_sk;
	struct fqdir___28 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___16 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___16 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___16 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___16;

struct dst_ops___28 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___28 *);
	struct dst_entry___16 * (*check)(struct dst_entry___16 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___16 *);
	unsigned int (*mtu)(const struct dst_entry___16 *);
	u32 * (*cow_metrics)(struct dst_entry___16 *, long unsigned int);
	void (*destroy)(struct dst_entry___16 *);
	void (*ifdown)(struct dst_entry___16 *, struct net_device___27 *, int);
	struct dst_entry___16 * (*negative_advice)(struct dst_entry___16 *);
	void (*link_failure)(struct sk_buff___25 *);
	void (*update_pmtu)(struct dst_entry___16 *, struct sock___17 *, struct sk_buff___25 *, u32, bool);
	void (*redirect)(struct dst_entry___16 *, struct sock___17 *, struct sk_buff___25 *);
	int (*local_out)(struct net___29 *, struct sock___17 *, struct sk_buff___25 *);
	struct neighbour___16 * (*neigh_lookup)(const struct dst_entry___16 *, struct sk_buff___25 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___16 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___28 {
	struct dst_ops___28 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___28 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___16 *fib6_rules_ops;
	struct sock___17 **icmp_sk;
	struct sock___17 *ndisc_sk;
	struct sock___17 *tcp_sk;
	struct sock___17 *igmp_sk;
	struct sock___17 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___16 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___16 *notifier_ops;
	struct fib_notifier_ops___16 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___28 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___28 *fqdir;
};

struct netns_sctp___16 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___17 *ctl_sock;
	struct sock___17 *udp4_sock;
	struct sock___17 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___23 {
	struct bpf_prog_array___23 *run_array[2];
	struct bpf_prog___23 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___28 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___17 *nlsk;
	struct sock___17 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___28 xfrm4_dst_ops;
	struct dst_ops___28 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___29 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___17 *rtnl;
	struct sock___17 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___27 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___28 ipv4;
	struct netns_ipv6___28 ipv6;
	struct netns_ieee802154_lowpan___28 ieee802154_lowpan;
	struct netns_sctp___16 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___23 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___23 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___28 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___17 *crypto_nlsk;
	struct sock___17 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___104 {
	struct ns_common___26 ns;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct css_set___104 *root_cset;
};

struct fwnode_operations___111;

struct fwnode_handle___111 {
	struct fwnode_handle___111 *secondary;
	const struct fwnode_operations___111 *ops;
	struct device___111 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___111;

struct fwnode_endpoint___111;

struct fwnode_operations___111 {
	struct fwnode_handle___111 * (*get)(struct fwnode_handle___111 *);
	void (*put)(struct fwnode_handle___111 *);
	bool (*device_is_available)(const struct fwnode_handle___111 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___111 *, const struct device___111 *);
	bool (*property_present)(const struct fwnode_handle___111 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___111 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___111 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___111 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*get_parent)(const struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*get_next_child_node)(const struct fwnode_handle___111 *, struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*get_named_child_node)(const struct fwnode_handle___111 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___111 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___111 *);
	struct fwnode_handle___111 * (*graph_get_next_endpoint)(const struct fwnode_handle___111 *, struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*graph_get_remote_endpoint)(const struct fwnode_handle___111 *);
	struct fwnode_handle___111 * (*graph_get_port_parent)(struct fwnode_handle___111 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___111 *, struct fwnode_endpoint___111 *);
	int (*add_links)(struct fwnode_handle___111 *);
};

struct fwnode_endpoint___111 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___111 *local_fwnode;
};

struct fwnode_reference_args___111 {
	struct fwnode_handle___111 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___111 {
	int (*prepare)(struct device___111 *);
	void (*complete)(struct device___111 *);
	int (*suspend)(struct device___111 *);
	int (*resume)(struct device___111 *);
	int (*freeze)(struct device___111 *);
	int (*thaw)(struct device___111 *);
	int (*poweroff)(struct device___111 *);
	int (*restore)(struct device___111 *);
	int (*suspend_late)(struct device___111 *);
	int (*resume_early)(struct device___111 *);
	int (*freeze_late)(struct device___111 *);
	int (*thaw_early)(struct device___111 *);
	int (*poweroff_late)(struct device___111 *);
	int (*restore_early)(struct device___111 *);
	int (*suspend_noirq)(struct device___111 *);
	int (*resume_noirq)(struct device___111 *);
	int (*freeze_noirq)(struct device___111 *);
	int (*thaw_noirq)(struct device___111 *);
	int (*poweroff_noirq)(struct device___111 *);
	int (*restore_noirq)(struct device___111 *);
	int (*runtime_suspend)(struct device___111 *);
	int (*runtime_resume)(struct device___111 *);
	int (*runtime_idle)(struct device___111 *);
};

struct wakeup_source___111 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___111 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___111 {
	struct dev_pm_ops___111 ops;
	int (*start)(struct device___111 *);
	void (*detach)(struct device___111 *, bool);
	int (*activate)(struct device___111 *);
	void (*sync)(struct device___111 *);
	void (*dismiss)(struct device___111 *);
};

struct bus_type___111 {
	const char *name;
	const char *dev_name;
	struct device___111 *dev_root;
	const struct attribute_group___142 **bus_groups;
	const struct attribute_group___142 **dev_groups;
	const struct attribute_group___142 **drv_groups;
	int (*match)(struct device___111 *, struct device_driver___111 *);
	int (*uevent)(struct device___111 *, struct kobj_uevent_env *);
	int (*probe)(struct device___111 *);
	void (*sync_state)(struct device___111 *);
	void (*remove)(struct device___111 *);
	void (*shutdown)(struct device___111 *);
	int (*online)(struct device___111 *);
	int (*offline)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	int (*num_vf)(struct device___111 *);
	int (*dma_configure)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___111 {
	const char *name;
	struct bus_type___111 *bus;
	struct module___140 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___111 *);
	void (*sync_state)(struct device___111 *);
	int (*remove)(struct device___111 *);
	void (*shutdown)(struct device___111 *);
	int (*suspend)(struct device___111 *, pm_message_t);
	int (*resume)(struct device___111 *);
	const struct attribute_group___142 **groups;
	const struct attribute_group___142 **dev_groups;
	const struct dev_pm_ops___111 *pm;
	void (*coredump)(struct device___111 *);
	struct driver_private *p;
};

struct device_type___111 {
	const char *name;
	const struct attribute_group___142 **groups;
	int (*uevent)(struct device___111 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___111 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___111 *);
	const struct dev_pm_ops___111 *pm;
};

struct class___111 {
	const char *name;
	struct module___140 *owner;
	const struct attribute_group___142 **class_groups;
	const struct attribute_group___142 **dev_groups;
	struct kobject___142 *dev_kobj;
	int (*dev_uevent)(struct device___111 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___111 *, umode_t *);
	void (*class_release)(struct class___111 *);
	void (*dev_release)(struct device___111 *);
	int (*shutdown_pre)(struct device___111 *);
	const struct kobj_ns_type_operations___16 *ns_type;
	const void * (*namespace)(struct device___111 *);
	void (*get_ownership)(struct device___111 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___111 *pm;
	struct subsys_private *p;
};

struct block_device_operations___68;

struct gendisk___68 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___69 *part0;
	const struct block_device_operations___68 *fops;
	struct request_queue___68 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___65 *bdi;
	struct kobject___142 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___142 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___68 {
	struct bio___68 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___82 *bip_vec;
	struct bio_vec___82 bip_inline_vecs[0];
};

struct blkcg___65;

struct blkg_policy_data___65;

struct blkcg_gq___65 {
	struct request_queue___68 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___65 *blkcg;
	struct blkcg_gq___65 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___65 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___68 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___68(struct request___68 *);

typedef void integrity_complete_fn___68(struct request___68 *, unsigned int);

struct blk_integrity_profile___68 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___68 *prepare_fn;
	integrity_complete_fn___68 *complete_fn;
	const char *name;
};

struct block_device_operations___68 {
	blk_qc_t (*submit_bio)(struct bio___68 *);
	int (*open)(struct block_device___69 *, fmode_t);
	void (*release)(struct gendisk___68 *, fmode_t);
	int (*rw_page)(struct block_device___69 *, sector_t, struct page___160 *, unsigned int);
	int (*ioctl)(struct block_device___69 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___69 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___68 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___68 *);
	int (*getgeo)(struct block_device___69 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___69 *, bool);
	void (*swap_slot_free_notify)(struct block_device___69 *, long unsigned int);
	int (*report_zones)(struct gendisk___68 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___68 *, umode_t *);
	struct module___140 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___68 *, sector_t *);
};

typedef void rq_end_io_fn___68(struct request___68 *, blk_status_t);

struct request___68 {
	struct request_queue___68 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___65 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___68 *bio;
	struct bio___68 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___82 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___68 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___68 *saved_end_io;
		} flush;
	};
	struct gendisk___68 *rq_disk;
	struct block_device___69 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___68 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___65 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___68 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___142 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___155 *debugfs_dir;
	struct dentry___155 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___68;

struct elevator_mq_ops___68 {
	int (*init_sched)(struct request_queue___68 *, struct elevator_type___68 *);
	void (*exit_sched)(struct elevator_queue___68 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___65 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___65 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___65 *);
	bool (*allow_merge)(struct request_queue___68 *, struct request___68 *, struct bio___68 *);
	bool (*bio_merge)(struct request_queue___68 *, struct bio___68 *, unsigned int);
	int (*request_merge)(struct request_queue___68 *, struct request___68 **, struct bio___68 *);
	void (*request_merged)(struct request_queue___68 *, struct request___68 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___68 *, struct request___68 *, struct request___68 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___68 *);
	void (*finish_request)(struct request___68 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___65 *, struct list_head *, bool);
	struct request___68 * (*dispatch_request)(struct blk_mq_hw_ctx___65 *);
	bool (*has_work)(struct blk_mq_hw_ctx___65 *);
	void (*completed_request)(struct request___68 *, u64);
	void (*requeue_request)(struct request___68 *);
	struct request___68 * (*former_request)(struct request_queue___68 *, struct request___68 *);
	struct request___68 * (*next_request)(struct request_queue___68 *, struct request___68 *);
	void (*init_icq)(struct io_cq___68 *);
	void (*exit_icq)(struct io_cq___68 *);
};

struct elv_fs_entry___68;

struct elevator_type___68 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___68 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___68 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___140 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___68 {
	struct elevator_type___68 *type;
	void *elevator_data;
	struct kobject___142 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___68 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___68 *, char *);
	ssize_t (*store)(struct elevator_queue___68 *, const char *, size_t);
};

struct blk_mq_queue_data___65;

struct blk_mq_ops___65 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___65 *, const struct blk_mq_queue_data___65 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___65 *);
	int (*get_budget)(struct request_queue___68 *);
	void (*put_budget)(struct request_queue___68 *, int);
	void (*set_rq_budget_token)(struct request___68 *, int);
	int (*get_rq_budget_token)(struct request___68 *);
	enum blk_eh_timer_return (*timeout)(struct request___68 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___65 *);
	void (*complete)(struct request___68 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___65 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___65 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___65 *, struct request___68 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___65 *, struct request___68 *, unsigned int);
	void (*initialize_rq_fn)(struct request___68 *);
	void (*cleanup_rq)(struct request___68 *);
	bool (*busy)(struct request_queue___68 *);
	int (*map_queues)(struct blk_mq_tag_set___65 *);
	void (*show_rq)(struct seq_file___133 *, struct request___68 *);
};

struct blk_mq_tag_set___65 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___65 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct cftype___104;

struct cgroup_subsys___104 {
	struct cgroup_subsys_state___104 * (*css_alloc)(struct cgroup_subsys_state___104 *);
	int (*css_online)(struct cgroup_subsys_state___104 *);
	void (*css_offline)(struct cgroup_subsys_state___104 *);
	void (*css_released)(struct cgroup_subsys_state___104 *);
	void (*css_free)(struct cgroup_subsys_state___104 *);
	void (*css_reset)(struct cgroup_subsys_state___104 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___104 *, int);
	int (*css_extra_stat_show)(struct seq_file___133 *, struct cgroup_subsys_state___104 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___162 *, struct css_set___104 *);
	void (*cancel_fork)(struct task_struct___162 *, struct css_set___104 *);
	void (*fork)(struct task_struct___162 *);
	void (*exit)(struct task_struct___162 *);
	void (*release)(struct task_struct___162 *);
	void (*bind)(struct cgroup_subsys_state___104 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___104 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___104 *dfl_cftypes;
	struct cftype___104 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___104 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___104 *updated_children;
	struct cgroup___104 *updated_next;
};

struct cgroup_root___104 {
	struct kernfs_root___142 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___104 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___104 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___104 *ss;
	struct list_head node;
	struct kernfs_ops___142 *kf_ops;
	int (*open)(struct kernfs_open_file___142 *);
	void (*release)(struct kernfs_open_file___142 *);
	u64 (*read_u64)(struct cgroup_subsys_state___104 *, struct cftype___104 *);
	s64 (*read_s64)(struct cgroup_subsys_state___104 *, struct cftype___104 *);
	int (*seq_show)(struct seq_file___133 *, void *);
	void * (*seq_start)(struct seq_file___133 *, loff_t *);
	void * (*seq_next)(struct seq_file___133 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___133 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___104 *, struct cftype___104 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___104 *, struct cftype___104 *, s64);
	ssize_t (*write)(struct kernfs_open_file___142 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___142 *, struct poll_table_struct___96 *);
};

struct blk_mq_queue_data___65 {
	struct request___68 *rq;
	bool last;
};

struct blkcg_policy_data___65;

struct blkcg___65 {
	struct cgroup_subsys_state___104 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___65 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___65 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___65 {
	struct blkcg___65 *blkcg;
	int plid;
};

struct blkg_policy_data___65 {
	struct blkcg_gq___65 *blkg;
	int plid;
};

struct inet_frags___28;

struct fqdir___28 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___28 *f;
	struct net___29 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___28;

struct inet_frags___28 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___28 *, const void *);
	void (*destructor)(struct inet_frag_queue___28 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___28 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___25 *fragments_tail;
	struct sk_buff___25 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___28 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___16;

struct fib_lookup_arg___16;

struct fib_rules_ops___16 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___16 *, struct flowi *, int, struct fib_lookup_arg___16 *);
	bool (*suppress)(struct fib_rule___16 *, int, struct fib_lookup_arg___16 *);
	int (*match)(struct fib_rule___16 *, struct flowi *, int);
	int (*configure)(struct fib_rule___16 *, struct sk_buff___25 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___16 *);
	int (*compare)(struct fib_rule___16 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___16 *, struct sk_buff___25 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___16 *);
	void (*flush_cache)(struct fib_rules_ops___16 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___140 *owner;
	struct net___29 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___16 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___29 *);
	int (*fib_dump)(struct net___29 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___140 *owner;
	struct callback_head rcu;
};

struct dst_entry___16 {
	struct net_device___27 *dev;
	struct dst_ops___28 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___25 *);
	int (*output)(struct net___29 *, struct sock___17 *, struct sk_buff___25 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___16;

struct neigh_parms___16;

struct neigh_ops___16;

struct neighbour___16 {
	struct neighbour___16 *next;
	struct neigh_table___16 *tbl;
	struct neigh_parms___16 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___23 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___16 *, struct sk_buff___25 *);
	const struct neigh_ops___16 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___27 *dev;
	u8 primary_key[0];
};

typedef int (*sk_read_actor_t___16)(read_descriptor_t *, struct sk_buff___25 *, unsigned int, size_t);

struct proto_ops___17 {
	int family;
	struct module___140 *owner;
	int (*release)(struct socket___17 *);
	int (*bind)(struct socket___17 *, struct sockaddr *, int);
	int (*connect)(struct socket___17 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___17 *, struct socket___17 *);
	int (*accept)(struct socket___17 *, struct socket___17 *, int, bool);
	int (*getname)(struct socket___17 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___155 *, struct socket___17 *, struct poll_table_struct___96 *);
	int (*ioctl)(struct socket___17 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___17 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___17 *, void *, bool, bool);
	int (*listen)(struct socket___17 *, int);
	int (*shutdown)(struct socket___17 *, int);
	int (*setsockopt)(struct socket___17 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___17 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___133 *, struct socket___17 *);
	int (*sendmsg)(struct socket___17 *, struct msghdr___17 *, size_t);
	int (*recvmsg)(struct socket___17 *, struct msghdr___17 *, size_t, int);
	int (*mmap)(struct file___155 *, struct socket___17 *, struct vm_area_struct___160 *);
	ssize_t (*sendpage)(struct socket___17 *, struct page___160 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___17 *, loff_t *, struct pipe_inode_info___48 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___17 *, int);
	int (*peek_len)(struct socket___17 *);
	int (*read_sock)(struct sock___17 *, read_descriptor_t *, sk_read_actor_t___16);
	int (*sendpage_locked)(struct sock___17 *, struct page___160 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___17 *, struct msghdr___17 *, size_t);
	int (*set_rcvlowat)(struct sock___17 *, int);
};

struct pipe_buf_operations___48;

struct pipe_buffer___48 {
	struct page___160 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___48 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___48 {
	int (*confirm)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
	void (*release)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
	bool (*try_steal)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
	bool (*get)(struct pipe_inode_info___48 *, struct pipe_buffer___48 *);
};

struct dcbnl_rtnl_ops___23 {
	int (*ieee_getets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___27 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___27 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___27 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___27 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___27 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___27 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___27 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___27 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___27 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___27 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___27 *);
	u8 (*setstate)(struct net_device___27 *, u8);
	void (*getpermhwaddr)(struct net_device___27 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___27 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___27 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___27 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___27 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___27 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___27 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___27 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___27 *, int, u8 *);
	void (*setpfccfg)(struct net_device___27 *, int, u8);
	void (*getpfccfg)(struct net_device___27 *, int, u8 *);
	u8 (*setall)(struct net_device___27 *);
	u8 (*getcap)(struct net_device___27 *, int, u8 *);
	int (*getnumtcs)(struct net_device___27 *, int, u8 *);
	int (*setnumtcs)(struct net_device___27 *, int, u8);
	u8 (*getpfcstate)(struct net_device___27 *);
	void (*setpfcstate)(struct net_device___27 *, u8);
	void (*getbcncfg)(struct net_device___27 *, int, u32 *);
	void (*setbcncfg)(struct net_device___27 *, int, u32);
	void (*getbcnrp)(struct net_device___27 *, int, u8 *);
	void (*setbcnrp)(struct net_device___27 *, int, u8);
	int (*setapp)(struct net_device___27 *, u8, u16, u8);
	int (*getapp)(struct net_device___27 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___27 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___27 *, int, u8);
	u8 (*getdcbx)(struct net_device___27 *);
	u8 (*setdcbx)(struct net_device___27 *, u8);
	int (*peer_getappinfo)(struct net_device___27 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___27 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___27 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___27 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___27 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___27 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___23 {
	struct net_device___27 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___23 {
	struct net_device___27 *dev;
};

struct xdp_buff___23 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___23 *rxq;
	struct xdp_txq_info___23 *txq;
	u32 frame_sz;
};

struct xdp_frame___23 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___27 *dev_rx;
};

struct netlink_callback___23 {
	struct sk_buff___25 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___25 *, struct netlink_callback___23 *);
	int (*done)(struct netlink_callback___23 *);
	void *data;
	struct module___140 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___23 {
	int (*create)(struct sk_buff___25 *, struct net_device___27 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___25 *, unsigned char *);
	int (*cache)(const struct neighbour___16 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___27 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___25 *);
};

struct netdev_queue___23 {
	struct net_device___27 *dev;
	struct Qdisc___23 *qdisc;
	struct Qdisc___23 *qdisc_sleeping;
	struct kobject___142 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___27 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___23 {
	struct sk_buff___25 *head;
	struct sk_buff___25 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___23;

struct Qdisc___23 {
	int (*enqueue)(struct sk_buff___25 *, struct Qdisc___23 *, struct sk_buff___25 **);
	struct sk_buff___25 * (*dequeue)(struct Qdisc___23 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___23 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___23 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___23 gso_skb;
	struct qdisc_skb_head___23 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___23 *next_sched;
	struct sk_buff_head___23 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___23 {
	struct xdp_rxq_info___23 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___142 kobj;
	struct net_device___27 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___23 {
	enum net_device_path_type type;
	const struct net_device___27 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___23 = 0,
				DEV_PATH_BR_VLAN_TAG___23 = 1,
				DEV_PATH_BR_VLAN_UNTAG___23 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___23 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___23 {
	const struct net_device___27 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___23 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___23 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___23 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___23 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___25 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___23 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___27 *dev;
	const char *name;
};

struct net_device_ops___23 {
	int (*ndo_init)(struct net_device___27 *);
	void (*ndo_uninit)(struct net_device___27 *);
	int (*ndo_open)(struct net_device___27 *);
	int (*ndo_stop)(struct net_device___27 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___25 *, struct net_device___27 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___25 *, struct net_device___27 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___27 *, struct sk_buff___25 *, struct net_device___27 *);
	void (*ndo_change_rx_flags)(struct net_device___27 *, int);
	void (*ndo_set_rx_mode)(struct net_device___27 *);
	int (*ndo_set_mac_address)(struct net_device___27 *, void *);
	int (*ndo_validate_addr)(struct net_device___27 *);
	int (*ndo_do_ioctl)(struct net_device___27 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___27 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___27 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___27 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___27 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___27 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___27 *, int);
	int (*ndo_neigh_setup)(struct net_device___27 *, struct neigh_parms___16 *);
	void (*ndo_tx_timeout)(struct net_device___27 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___27 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___27 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___27 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___27 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___27 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___27 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___27 *);
	int (*ndo_netpoll_setup)(struct net_device___27 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___27 *);
	int (*ndo_set_vf_mac)(struct net_device___27 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___27 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___27 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___27 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___27 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___27 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___27 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___27 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___27 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___27 *, int, struct sk_buff___25 *);
	int (*ndo_get_vf_guid)(struct net_device___27 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___27 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___27 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___27 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___27 *);
	int (*ndo_fcoe_disable)(struct net_device___27 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___27 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___27 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___27 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___27 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___27 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___27 *, const struct sk_buff___25 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___27 *, struct net_device___27 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___27 *, struct net_device___27 *);
	struct net_device___27 * (*ndo_get_xmit_slave)(struct net_device___27 *, struct sk_buff___25 *, bool);
	struct net_device___27 * (*ndo_sk_get_lower_dev)(struct net_device___27 *, struct sock___17 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___27 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___27 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___27 *, struct neighbour___16 *);
	void (*ndo_neigh_destroy)(struct net_device___27 *, struct neighbour___16 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___25 *, struct netlink_callback___23 *, struct net_device___27 *, struct net_device___27 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___25 *, struct nlattr **, struct net_device___27 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___27 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___25 *, u32, u32, struct net_device___27 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___27 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___27 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___27 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___27 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___27 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___27 *, struct net_device___27 *);
	void (*ndo_dfwd_del_station)(struct net_device___27 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___27 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___27 *);
	int (*ndo_change_proto_down)(struct net_device___27 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___27 *, struct sk_buff___25 *);
	void (*ndo_set_rx_headroom)(struct net_device___27 *, int);
	int (*ndo_bpf)(struct net_device___27 *, struct netdev_bpf___23 *);
	int (*ndo_xdp_xmit)(struct net_device___27 *, int, struct xdp_frame___23 **, u32);
	struct net_device___27 * (*ndo_xdp_get_xmit_slave)(struct net_device___27 *, struct xdp_buff___23 *);
	int (*ndo_xsk_wakeup)(struct net_device___27 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___27 *);
	int (*ndo_tunnel_ctl)(struct net_device___27 *, struct ip_tunnel_parm *, int);
	struct net_device___27 * (*ndo_get_peer_dev)(struct net_device___27 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___23 *, struct net_device_path___23 *);
};

struct neigh_parms___16 {
	possible_net_t___23 net;
	struct net_device___27 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___16 *);
	struct neigh_table___16 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___16 {
	u32 (*l3mdev_fib_table)(const struct net_device___27 *);
	struct sk_buff___25 * (*l3mdev_l3_rcv)(struct net_device___27 *, struct sk_buff___25 *, u16);
	struct sk_buff___25 * (*l3mdev_l3_out)(struct net_device___27 *, struct sock___17 *, struct sk_buff___25 *, u16);
	struct dst_entry___16 * (*l3mdev_link_scope_lookup)(const struct net_device___27 *, struct flowi6 *);
};

struct tcf_proto___23;

struct tcf_block___23;

struct mini_Qdisc___23 {
	struct tcf_proto___23 *filter_list;
	struct tcf_block___23 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___23 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___27 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___27 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___29 *, struct net_device___27 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___27 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___27 *, struct list_head *);
	size_t (*get_size)(const struct net_device___27 *);
	int (*fill_info)(struct sk_buff___25 *, const struct net_device___27 *);
	size_t (*get_xstats_size)(const struct net_device___27 *);
	int (*fill_xstats)(struct sk_buff___25 *, const struct net_device___27 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___27 *, struct net_device___27 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___27 *, const struct net_device___27 *);
	int (*fill_slave_info)(struct sk_buff___25 *, const struct net_device___27 *, const struct net_device___27 *);
	struct net___29 * (*get_link_net)(const struct net_device___27 *);
	size_t (*get_linkxstats_size)(const struct net_device___27 *, int);
	int (*fill_linkxstats)(struct sk_buff___25 *, const struct net_device___27 *, int *, int);
};

struct mem_cgroup_reclaim_iter___56 {
	struct mem_cgroup___56 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___56 {
	struct lruvec___63 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___56 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___56 *memcg;
};

struct obj_cgroup___56 {
	struct percpu_ref refcnt;
	struct mem_cgroup___56 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___23 {
	spinlock_t *lock;
	struct sk_buff___25 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___23;

struct Qdisc_ops___23 {
	struct Qdisc_ops___23 *next;
	const struct Qdisc_class_ops___23 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___25 *, struct Qdisc___23 *, struct sk_buff___25 **);
	struct sk_buff___25 * (*dequeue)(struct Qdisc___23 *);
	struct sk_buff___25 * (*peek)(struct Qdisc___23 *);
	int (*init)(struct Qdisc___23 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___23 *);
	void (*destroy)(struct Qdisc___23 *);
	int (*change)(struct Qdisc___23 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___23 *);
	int (*change_tx_queue_len)(struct Qdisc___23 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___23 *, unsigned int);
	int (*dump)(struct Qdisc___23 *, struct sk_buff___25 *);
	int (*dump_stats)(struct Qdisc___23 *, struct gnet_dump___23 *);
	void (*ingress_block_set)(struct Qdisc___23 *, u32);
	void (*egress_block_set)(struct Qdisc___23 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___23 *);
	u32 (*egress_block_get)(struct Qdisc___23 *);
	struct module___140 *owner;
};

struct Qdisc_class_ops___23 {
	unsigned int flags;
	struct netdev_queue___23 * (*select_queue)(struct Qdisc___23 *, struct tcmsg *);
	int (*graft)(struct Qdisc___23 *, long unsigned int, struct Qdisc___23 *, struct Qdisc___23 **, struct netlink_ext_ack *);
	struct Qdisc___23 * (*leaf)(struct Qdisc___23 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___23 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___23 *, u32);
	int (*change)(struct Qdisc___23 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___23 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___23 *, struct qdisc_walker *);
	struct tcf_block___23 * (*tcf_block)(struct Qdisc___23 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___23 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___23 *, long unsigned int);
	int (*dump)(struct Qdisc___23 *, long unsigned int, struct sk_buff___25 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___23 *, long unsigned int, struct gnet_dump___23 *);
};

struct tcf_chain___23;

struct tcf_block___23 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___29 *net;
	struct Qdisc___23 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___23 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___23;

struct tcf_proto_ops___23;

struct tcf_proto___23 {
	struct tcf_proto___23 *next;
	void *root;
	int (*classify)(struct sk_buff___25 *, const struct tcf_proto___23 *, struct tcf_result___23 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___23 *ops;
	struct tcf_chain___23 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___23 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___23 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___23 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___25 *, const struct tcf_proto___23 *, struct tcf_result___23 *);
	int (*init)(struct tcf_proto___23 *);
	void (*destroy)(struct tcf_proto___23 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___23 *, u32);
	void (*put)(struct tcf_proto___23 *, void *);
	int (*change)(struct net___29 *, struct sk_buff___25 *, struct tcf_proto___23 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___23 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___23 *);
	void (*walk)(struct tcf_proto___23 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___23 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___23 *, void *);
	void (*hw_del)(struct tcf_proto___23 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___29 *, struct tcf_chain___23 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___29 *, struct tcf_proto___23 *, void *, struct sk_buff___25 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___29 *, struct tcf_proto___23 *, void *, struct sk_buff___25 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___25 *, struct net___29 *, void *);
	struct module___140 *owner;
	int flags;
};

struct tcf_chain___23 {
	struct mutex filter_chain_lock;
	struct tcf_proto___23 *filter_chain;
	struct list_head list;
	struct tcf_block___23 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___23 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___16 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___23 *prog;
};

struct pneigh_entry___16;

struct neigh_hash_table___16;

struct neigh_table___16 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___27 *, __u32 *);
	bool (*key_eq)(const struct neighbour___16 *, const void *);
	int (*constructor)(struct neighbour___16 *);
	int (*pconstructor)(struct pneigh_entry___16 *);
	void (*pdestructor)(struct pneigh_entry___16 *);
	void (*proxy_redo)(struct sk_buff___25 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___27 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___16 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___23 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___16 *nht;
	struct pneigh_entry___16 **phash_buckets;
};

struct neigh_ops___16 {
	int family;
	void (*solicit)(struct neighbour___16 *, struct sk_buff___25 *);
	void (*error_report)(struct neighbour___16 *, struct sk_buff___25 *);
	int (*output)(struct neighbour___16 *, struct sk_buff___25 *);
	int (*connected_output)(struct neighbour___16 *, struct sk_buff___25 *);
};

struct pneigh_entry___16 {
	struct pneigh_entry___16 *next;
	possible_net_t___23 net;
	struct net_device___27 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___16 {
	struct neighbour___16 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___16 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___16 *ctarget;
	struct net___29 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___16 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___16 *rule;
	u32 table;
	int flags;
};

struct proto___16 {
	void (*close)(struct sock___17 *, long int);
	int (*pre_connect)(struct sock___17 *, struct sockaddr *, int);
	int (*connect)(struct sock___17 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___17 *, int);
	struct sock___17 * (*accept)(struct sock___17 *, int, int *, bool);
	int (*ioctl)(struct sock___17 *, int, long unsigned int);
	int (*init)(struct sock___17 *);
	void (*destroy)(struct sock___17 *);
	void (*shutdown)(struct sock___17 *, int);
	int (*setsockopt)(struct sock___17 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___17 *, int, int, char *, int *);
	void (*keepalive)(struct sock___17 *, int);
	int (*compat_ioctl)(struct sock___17 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___17 *, struct msghdr___17 *, size_t);
	int (*recvmsg)(struct sock___17 *, struct msghdr___17 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___17 *, struct page___160 *, int, size_t, int);
	int (*bind)(struct sock___17 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___17 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___17 *, struct sk_buff___25 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___17 *);
	int (*hash)(struct sock___17 *);
	void (*unhash)(struct sock___17 *);
	void (*rehash)(struct sock___17 *);
	int (*get_port)(struct sock___17 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___17 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___17 *, int);
	bool (*sock_is_readable)(struct sock___17 *);
	void (*enter_memory_pressure)(struct sock___17 *);
	void (*leave_memory_pressure)(struct sock___17 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___140 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___17 *, int);
};

struct tree_descr___5 {
	const char *name;
	const struct file_operations___140 *ops;
	int mode;
};

struct ethhdr {
	unsigned char h_dest[6];
	unsigned char h_source[6];
	__be16 h_proto;
};

struct ethtool_drvinfo {
	__u32 cmd;
	char driver[32];
	char version[32];
	char fw_version[32];
	char bus_info[32];
	char erom_version[32];
	char reserved2[12];
	__u32 n_priv_flags;
	__u32 n_stats;
	__u32 testinfo_len;
	__u32 eedump_len;
	__u32 regdump_len;
};

struct ethtool_wolinfo {
	__u32 cmd;
	__u32 supported;
	__u32 wolopts;
	__u8 sopass[6];
};

struct ethtool_tunable {
	__u32 cmd;
	__u32 id;
	__u32 type_id;
	__u32 len;
	void *data[0];
};

struct ethtool_regs {
	__u32 cmd;
	__u32 version;
	__u32 len;
	__u8 data[0];
};

struct ethtool_eeprom {
	__u32 cmd;
	__u32 magic;
	__u32 offset;
	__u32 len;
	__u8 data[0];
};

struct ethtool_eee {
	__u32 cmd;
	__u32 supported;
	__u32 advertised;
	__u32 lp_advertised;
	__u32 eee_active;
	__u32 eee_enabled;
	__u32 tx_lpi_enabled;
	__u32 tx_lpi_timer;
	__u32 reserved[2];
};

struct ethtool_modinfo {
	__u32 cmd;
	__u32 type;
	__u32 eeprom_len;
	__u32 reserved[8];
};

struct ethtool_coalesce {
	__u32 cmd;
	__u32 rx_coalesce_usecs;
	__u32 rx_max_coalesced_frames;
	__u32 rx_coalesce_usecs_irq;
	__u32 rx_max_coalesced_frames_irq;
	__u32 tx_coalesce_usecs;
	__u32 tx_max_coalesced_frames;
	__u32 tx_coalesce_usecs_irq;
	__u32 tx_max_coalesced_frames_irq;
	__u32 stats_block_coalesce_usecs;
	__u32 use_adaptive_rx_coalesce;
	__u32 use_adaptive_tx_coalesce;
	__u32 pkt_rate_low;
	__u32 rx_coalesce_usecs_low;
	__u32 rx_max_coalesced_frames_low;
	__u32 tx_coalesce_usecs_low;
	__u32 tx_max_coalesced_frames_low;
	__u32 pkt_rate_high;
	__u32 rx_coalesce_usecs_high;
	__u32 rx_max_coalesced_frames_high;
	__u32 tx_coalesce_usecs_high;
	__u32 tx_max_coalesced_frames_high;
	__u32 rate_sample_interval;
};

struct ethtool_ringparam {
	__u32 cmd;
	__u32 rx_max_pending;
	__u32 rx_mini_max_pending;
	__u32 rx_jumbo_max_pending;
	__u32 tx_max_pending;
	__u32 rx_pending;
	__u32 rx_mini_pending;
	__u32 rx_jumbo_pending;
	__u32 tx_pending;
};

struct ethtool_channels {
	__u32 cmd;
	__u32 max_rx;
	__u32 max_tx;
	__u32 max_other;
	__u32 max_combined;
	__u32 rx_count;
	__u32 tx_count;
	__u32 other_count;
	__u32 combined_count;
};

struct ethtool_pauseparam {
	__u32 cmd;
	__u32 autoneg;
	__u32 rx_pause;
	__u32 tx_pause;
};

enum ethtool_link_ext_state {
	ETHTOOL_LINK_EXT_STATE_AUTONEG = 0,
	ETHTOOL_LINK_EXT_STATE_LINK_TRAINING_FAILURE = 1,
	ETHTOOL_LINK_EXT_STATE_LINK_LOGICAL_MISMATCH = 2,
	ETHTOOL_LINK_EXT_STATE_BAD_SIGNAL_INTEGRITY = 3,
	ETHTOOL_LINK_EXT_STATE_NO_CABLE = 4,
	ETHTOOL_LINK_EXT_STATE_CABLE_ISSUE = 5,
	ETHTOOL_LINK_EXT_STATE_EEPROM_ISSUE = 6,
	ETHTOOL_LINK_EXT_STATE_CALIBRATION_FAILURE = 7,
	ETHTOOL_LINK_EXT_STATE_POWER_BUDGET_EXCEEDED = 8,
	ETHTOOL_LINK_EXT_STATE_OVERHEAT = 9,
};

enum ethtool_link_ext_substate_autoneg {
	ETHTOOL_LINK_EXT_SUBSTATE_AN_NO_PARTNER_DETECTED = 1,
	ETHTOOL_LINK_EXT_SUBSTATE_AN_ACK_NOT_RECEIVED = 2,
	ETHTOOL_LINK_EXT_SUBSTATE_AN_NEXT_PAGE_EXCHANGE_FAILED = 3,
	ETHTOOL_LINK_EXT_SUBSTATE_AN_NO_PARTNER_DETECTED_FORCE_MODE = 4,
	ETHTOOL_LINK_EXT_SUBSTATE_AN_FEC_MISMATCH_DURING_OVERRIDE = 5,
	ETHTOOL_LINK_EXT_SUBSTATE_AN_NO_HCD = 6,
};

enum ethtool_link_ext_substate_link_training {
	ETHTOOL_LINK_EXT_SUBSTATE_LT_KR_FRAME_LOCK_NOT_ACQUIRED = 1,
	ETHTOOL_LINK_EXT_SUBSTATE_LT_KR_LINK_INHIBIT_TIMEOUT = 2,
	ETHTOOL_LINK_EXT_SUBSTATE_LT_KR_LINK_PARTNER_DID_NOT_SET_RECEIVER_READY = 3,
	ETHTOOL_LINK_EXT_SUBSTATE_LT_REMOTE_FAULT = 4,
};

enum ethtool_link_ext_substate_link_logical_mismatch {
	ETHTOOL_LINK_EXT_SUBSTATE_LLM_PCS_DID_NOT_ACQUIRE_BLOCK_LOCK = 1,
	ETHTOOL_LINK_EXT_SUBSTATE_LLM_PCS_DID_NOT_ACQUIRE_AM_LOCK = 2,
	ETHTOOL_LINK_EXT_SUBSTATE_LLM_PCS_DID_NOT_GET_ALIGN_STATUS = 3,
	ETHTOOL_LINK_EXT_SUBSTATE_LLM_FC_FEC_IS_NOT_LOCKED = 4,
	ETHTOOL_LINK_EXT_SUBSTATE_LLM_RS_FEC_IS_NOT_LOCKED = 5,
};

enum ethtool_link_ext_substate_bad_signal_integrity {
	ETHTOOL_LINK_EXT_SUBSTATE_BSI_LARGE_NUMBER_OF_PHYSICAL_ERRORS = 1,
	ETHTOOL_LINK_EXT_SUBSTATE_BSI_UNSUPPORTED_RATE = 2,
	ETHTOOL_LINK_EXT_SUBSTATE_BSI_SERDES_REFERENCE_CLOCK_LOST = 3,
	ETHTOOL_LINK_EXT_SUBSTATE_BSI_SERDES_ALOS = 4,
};

enum ethtool_link_ext_substate_cable_issue {
	ETHTOOL_LINK_EXT_SUBSTATE_CI_UNSUPPORTED_CABLE = 1,
	ETHTOOL_LINK_EXT_SUBSTATE_CI_CABLE_TEST_FAILURE = 2,
};

struct ethtool_test {
	__u32 cmd;
	__u32 flags;
	__u32 reserved;
	__u32 len;
	__u64 data[0];
};

struct ethtool_stats {
	__u32 cmd;
	__u32 n_stats;
	__u64 data[0];
};

struct ethtool_tcpip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be16 psrc;
	__be16 pdst;
	__u8 tos;
};

struct ethtool_ah_espip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be32 spi;
	__u8 tos;
};

struct ethtool_usrip4_spec {
	__be32 ip4src;
	__be32 ip4dst;
	__be32 l4_4_bytes;
	__u8 tos;
	__u8 ip_ver;
	__u8 proto;
};

struct ethtool_tcpip6_spec {
	__be32 ip6src[4];
	__be32 ip6dst[4];
	__be16 psrc;
	__be16 pdst;
	__u8 tclass;
};

struct ethtool_ah_espip6_spec {
	__be32 ip6src[4];
	__be32 ip6dst[4];
	__be32 spi;
	__u8 tclass;
};

struct ethtool_usrip6_spec {
	__be32 ip6src[4];
	__be32 ip6dst[4];
	__be32 l4_4_bytes;
	__u8 tclass;
	__u8 l4_proto;
};

union ethtool_flow_union {
	struct ethtool_tcpip4_spec tcp_ip4_spec;
	struct ethtool_tcpip4_spec udp_ip4_spec;
	struct ethtool_tcpip4_spec sctp_ip4_spec;
	struct ethtool_ah_espip4_spec ah_ip4_spec;
	struct ethtool_ah_espip4_spec esp_ip4_spec;
	struct ethtool_usrip4_spec usr_ip4_spec;
	struct ethtool_tcpip6_spec tcp_ip6_spec;
	struct ethtool_tcpip6_spec udp_ip6_spec;
	struct ethtool_tcpip6_spec sctp_ip6_spec;
	struct ethtool_ah_espip6_spec ah_ip6_spec;
	struct ethtool_ah_espip6_spec esp_ip6_spec;
	struct ethtool_usrip6_spec usr_ip6_spec;
	struct ethhdr ether_spec;
	__u8 hdata[52];
};

struct ethtool_flow_ext {
	__u8 padding[2];
	unsigned char h_dest[6];
	__be16 vlan_etype;
	__be16 vlan_tci;
	__be32 data[2];
};

struct ethtool_rx_flow_spec {
	__u32 flow_type;
	union ethtool_flow_union h_u;
	struct ethtool_flow_ext h_ext;
	union ethtool_flow_union m_u;
	struct ethtool_flow_ext m_ext;
	__u64 ring_cookie;
	__u32 location;
};

struct ethtool_rxnfc {
	__u32 cmd;
	__u32 flow_type;
	__u64 data;
	struct ethtool_rx_flow_spec fs;
	union {
		__u32 rule_cnt;
		__u32 rss_context;
	};
	__u32 rule_locs[0];
};

struct ethtool_flash {
	__u32 cmd;
	__u32 region;
	char data[128];
};

struct ethtool_dump {
	__u32 cmd;
	__u32 version;
	__u32 flag;
	__u32 len;
	__u8 data[0];
};

struct ethtool_ts_info {
	__u32 cmd;
	__u32 so_timestamping;
	__s32 phc_index;
	__u32 tx_types;
	__u32 tx_reserved[3];
	__u32 rx_filters;
	__u32 rx_reserved[3];
};

struct ethtool_fecparam {
	__u32 cmd;
	__u32 active_fec;
	__u32 fec;
	__u32 reserved;
};

enum ethtool_link_mode_bit_indices {
	ETHTOOL_LINK_MODE_10baseT_Half_BIT = 0,
	ETHTOOL_LINK_MODE_10baseT_Full_BIT = 1,
	ETHTOOL_LINK_MODE_100baseT_Half_BIT = 2,
	ETHTOOL_LINK_MODE_100baseT_Full_BIT = 3,
	ETHTOOL_LINK_MODE_1000baseT_Half_BIT = 4,
	ETHTOOL_LINK_MODE_1000baseT_Full_BIT = 5,
	ETHTOOL_LINK_MODE_Autoneg_BIT = 6,
	ETHTOOL_LINK_MODE_TP_BIT = 7,
	ETHTOOL_LINK_MODE_AUI_BIT = 8,
	ETHTOOL_LINK_MODE_MII_BIT = 9,
	ETHTOOL_LINK_MODE_FIBRE_BIT = 10,
	ETHTOOL_LINK_MODE_BNC_BIT = 11,
	ETHTOOL_LINK_MODE_10000baseT_Full_BIT = 12,
	ETHTOOL_LINK_MODE_Pause_BIT = 13,
	ETHTOOL_LINK_MODE_Asym_Pause_BIT = 14,
	ETHTOOL_LINK_MODE_2500baseX_Full_BIT = 15,
	ETHTOOL_LINK_MODE_Backplane_BIT = 16,
	ETHTOOL_LINK_MODE_1000baseKX_Full_BIT = 17,
	ETHTOOL_LINK_MODE_10000baseKX4_Full_BIT = 18,
	ETHTOOL_LINK_MODE_10000baseKR_Full_BIT = 19,
	ETHTOOL_LINK_MODE_10000baseR_FEC_BIT = 20,
	ETHTOOL_LINK_MODE_20000baseMLD2_Full_BIT = 21,
	ETHTOOL_LINK_MODE_20000baseKR2_Full_BIT = 22,
	ETHTOOL_LINK_MODE_40000baseKR4_Full_BIT = 23,
	ETHTOOL_LINK_MODE_40000baseCR4_Full_BIT = 24,
	ETHTOOL_LINK_MODE_40000baseSR4_Full_BIT = 25,
	ETHTOOL_LINK_MODE_40000baseLR4_Full_BIT = 26,
	ETHTOOL_LINK_MODE_56000baseKR4_Full_BIT = 27,
	ETHTOOL_LINK_MODE_56000baseCR4_Full_BIT = 28,
	ETHTOOL_LINK_MODE_56000baseSR4_Full_BIT = 29,
	ETHTOOL_LINK_MODE_56000baseLR4_Full_BIT = 30,
	ETHTOOL_LINK_MODE_25000baseCR_Full_BIT = 31,
	ETHTOOL_LINK_MODE_25000baseKR_Full_BIT = 32,
	ETHTOOL_LINK_MODE_25000baseSR_Full_BIT = 33,
	ETHTOOL_LINK_MODE_50000baseCR2_Full_BIT = 34,
	ETHTOOL_LINK_MODE_50000baseKR2_Full_BIT = 35,
	ETHTOOL_LINK_MODE_100000baseKR4_Full_BIT = 36,
	ETHTOOL_LINK_MODE_100000baseSR4_Full_BIT = 37,
	ETHTOOL_LINK_MODE_100000baseCR4_Full_BIT = 38,
	ETHTOOL_LINK_MODE_100000baseLR4_ER4_Full_BIT = 39,
	ETHTOOL_LINK_MODE_50000baseSR2_Full_BIT = 40,
	ETHTOOL_LINK_MODE_1000baseX_Full_BIT = 41,
	ETHTOOL_LINK_MODE_10000baseCR_Full_BIT = 42,
	ETHTOOL_LINK_MODE_10000baseSR_Full_BIT = 43,
	ETHTOOL_LINK_MODE_10000baseLR_Full_BIT = 44,
	ETHTOOL_LINK_MODE_10000baseLRM_Full_BIT = 45,
	ETHTOOL_LINK_MODE_10000baseER_Full_BIT = 46,
	ETHTOOL_LINK_MODE_2500baseT_Full_BIT = 47,
	ETHTOOL_LINK_MODE_5000baseT_Full_BIT = 48,
	ETHTOOL_LINK_MODE_FEC_NONE_BIT = 49,
	ETHTOOL_LINK_MODE_FEC_RS_BIT = 50,
	ETHTOOL_LINK_MODE_FEC_BASER_BIT = 51,
	ETHTOOL_LINK_MODE_50000baseKR_Full_BIT = 52,
	ETHTOOL_LINK_MODE_50000baseSR_Full_BIT = 53,
	ETHTOOL_LINK_MODE_50000baseCR_Full_BIT = 54,
	ETHTOOL_LINK_MODE_50000baseLR_ER_FR_Full_BIT = 55,
	ETHTOOL_LINK_MODE_50000baseDR_Full_BIT = 56,
	ETHTOOL_LINK_MODE_100000baseKR2_Full_BIT = 57,
	ETHTOOL_LINK_MODE_100000baseSR2_Full_BIT = 58,
	ETHTOOL_LINK_MODE_100000baseCR2_Full_BIT = 59,
	ETHTOOL_LINK_MODE_100000baseLR2_ER2_FR2_Full_BIT = 60,
	ETHTOOL_LINK_MODE_100000baseDR2_Full_BIT = 61,
	ETHTOOL_LINK_MODE_200000baseKR4_Full_BIT = 62,
	ETHTOOL_LINK_MODE_200000baseSR4_Full_BIT = 63,
	ETHTOOL_LINK_MODE_200000baseLR4_ER4_FR4_Full_BIT = 64,
	ETHTOOL_LINK_MODE_200000baseDR4_Full_BIT = 65,
	ETHTOOL_LINK_MODE_200000baseCR4_Full_BIT = 66,
	ETHTOOL_LINK_MODE_100baseT1_Full_BIT = 67,
	ETHTOOL_LINK_MODE_1000baseT1_Full_BIT = 68,
	ETHTOOL_LINK_MODE_400000baseKR8_Full_BIT = 69,
	ETHTOOL_LINK_MODE_400000baseSR8_Full_BIT = 70,
	ETHTOOL_LINK_MODE_400000baseLR8_ER8_FR8_Full_BIT = 71,
	ETHTOOL_LINK_MODE_400000baseDR8_Full_BIT = 72,
	ETHTOOL_LINK_MODE_400000baseCR8_Full_BIT = 73,
	ETHTOOL_LINK_MODE_FEC_LLRS_BIT = 74,
	ETHTOOL_LINK_MODE_100000baseKR_Full_BIT = 75,
	ETHTOOL_LINK_MODE_100000baseSR_Full_BIT = 76,
	ETHTOOL_LINK_MODE_100000baseLR_ER_FR_Full_BIT = 77,
	ETHTOOL_LINK_MODE_100000baseCR_Full_BIT = 78,
	ETHTOOL_LINK_MODE_100000baseDR_Full_BIT = 79,
	ETHTOOL_LINK_MODE_200000baseKR2_Full_BIT = 80,
	ETHTOOL_LINK_MODE_200000baseSR2_Full_BIT = 81,
	ETHTOOL_LINK_MODE_200000baseLR2_ER2_FR2_Full_BIT = 82,
	ETHTOOL_LINK_MODE_200000baseDR2_Full_BIT = 83,
	ETHTOOL_LINK_MODE_200000baseCR2_Full_BIT = 84,
	ETHTOOL_LINK_MODE_400000baseKR4_Full_BIT = 85,
	ETHTOOL_LINK_MODE_400000baseSR4_Full_BIT = 86,
	ETHTOOL_LINK_MODE_400000baseLR4_ER4_FR4_Full_BIT = 87,
	ETHTOOL_LINK_MODE_400000baseDR4_Full_BIT = 88,
	ETHTOOL_LINK_MODE_400000baseCR4_Full_BIT = 89,
	ETHTOOL_LINK_MODE_100baseFX_Half_BIT = 90,
	ETHTOOL_LINK_MODE_100baseFX_Full_BIT = 91,
	__ETHTOOL_LINK_MODE_MASK_NBITS = 92,
};

struct ethtool_link_settings {
	__u32 cmd;
	__u32 speed;
	__u8 duplex;
	__u8 port;
	__u8 phy_address;
	__u8 autoneg;
	__u8 mdio_support;
	__u8 eth_tp_mdix;
	__u8 eth_tp_mdix_ctrl;
	__s8 link_mode_masks_nwords;
	__u8 transceiver;
	__u8 master_slave_cfg;
	__u8 master_slave_state;
	__u8 reserved1[1];
	__u32 reserved[7];
	__u32 link_mode_masks[0];
};

struct ethtool_link_ext_state_info {
	enum ethtool_link_ext_state link_ext_state;
	union {
		enum ethtool_link_ext_substate_autoneg autoneg;
		enum ethtool_link_ext_substate_link_training link_training;
		enum ethtool_link_ext_substate_link_logical_mismatch link_logical_mismatch;
		enum ethtool_link_ext_substate_bad_signal_integrity bad_signal_integrity;
		enum ethtool_link_ext_substate_cable_issue cable_issue;
		u32 __link_ext_substate;
	};
};

struct ethtool_link_ksettings {
	struct ethtool_link_settings base;
	struct {
		long unsigned int supported[2];
		long unsigned int advertising[2];
		long unsigned int lp_advertising[2];
	} link_modes;
	u32 lanes;
};

struct kernel_ethtool_coalesce {
	u8 use_cqe_mode_tx;
	u8 use_cqe_mode_rx;
};

struct ethtool_eth_mac_stats {
	u64 FramesTransmittedOK;
	u64 SingleCollisionFrames;
	u64 MultipleCollisionFrames;
	u64 FramesReceivedOK;
	u64 FrameCheckSequenceErrors;
	u64 AlignmentErrors;
	u64 OctetsTransmittedOK;
	u64 FramesWithDeferredXmissions;
	u64 LateCollisions;
	u64 FramesAbortedDueToXSColls;
	u64 FramesLostDueToIntMACXmitError;
	u64 CarrierSenseErrors;
	u64 OctetsReceivedOK;
	u64 FramesLostDueToIntMACRcvError;
	u64 MulticastFramesXmittedOK;
	u64 BroadcastFramesXmittedOK;
	u64 FramesWithExcessiveDeferral;
	u64 MulticastFramesReceivedOK;
	u64 BroadcastFramesReceivedOK;
	u64 InRangeLengthErrors;
	u64 OutOfRangeLengthField;
	u64 FrameTooLongErrors;
};

struct ethtool_eth_phy_stats {
	u64 SymbolErrorDuringCarrier;
};

struct ethtool_eth_ctrl_stats {
	u64 MACControlFramesTransmitted;
	u64 MACControlFramesReceived;
	u64 UnsupportedOpcodesReceived;
};

struct ethtool_pause_stats {
	u64 tx_pause_frames;
	u64 rx_pause_frames;
};

struct ethtool_fec_stat {
	u64 total;
	u64 lanes[8];
};

struct ethtool_fec_stats {
	struct ethtool_fec_stat corrected_blocks;
	struct ethtool_fec_stat uncorrectable_blocks;
	struct ethtool_fec_stat corrected_bits;
};

struct ethtool_rmon_hist_range {
	u16 low;
	u16 high;
};

struct ethtool_rmon_stats {
	u64 undersize_pkts;
	u64 oversize_pkts;
	u64 fragments;
	u64 jabbers;
	u64 hist[10];
	u64 hist_tx[10];
};

struct ethtool_module_eeprom {
	u32 offset;
	u32 length;
	u8 page;
	u8 bank;
	u8 i2c_address;
	u8 *data;
};

enum ib_uverbs_write_cmds {
	IB_USER_VERBS_CMD_GET_CONTEXT = 0,
	IB_USER_VERBS_CMD_QUERY_DEVICE = 1,
	IB_USER_VERBS_CMD_QUERY_PORT = 2,
	IB_USER_VERBS_CMD_ALLOC_PD = 3,
	IB_USER_VERBS_CMD_DEALLOC_PD = 4,
	IB_USER_VERBS_CMD_CREATE_AH = 5,
	IB_USER_VERBS_CMD_MODIFY_AH = 6,
	IB_USER_VERBS_CMD_QUERY_AH = 7,
	IB_USER_VERBS_CMD_DESTROY_AH = 8,
	IB_USER_VERBS_CMD_REG_MR = 9,
	IB_USER_VERBS_CMD_REG_SMR = 10,
	IB_USER_VERBS_CMD_REREG_MR = 11,
	IB_USER_VERBS_CMD_QUERY_MR = 12,
	IB_USER_VERBS_CMD_DEREG_MR = 13,
	IB_USER_VERBS_CMD_ALLOC_MW = 14,
	IB_USER_VERBS_CMD_BIND_MW = 15,
	IB_USER_VERBS_CMD_DEALLOC_MW = 16,
	IB_USER_VERBS_CMD_CREATE_COMP_CHANNEL = 17,
	IB_USER_VERBS_CMD_CREATE_CQ = 18,
	IB_USER_VERBS_CMD_RESIZE_CQ = 19,
	IB_USER_VERBS_CMD_DESTROY_CQ = 20,
	IB_USER_VERBS_CMD_POLL_CQ = 21,
	IB_USER_VERBS_CMD_PEEK_CQ = 22,
	IB_USER_VERBS_CMD_REQ_NOTIFY_CQ = 23,
	IB_USER_VERBS_CMD_CREATE_QP = 24,
	IB_USER_VERBS_CMD_QUERY_QP = 25,
	IB_USER_VERBS_CMD_MODIFY_QP = 26,
	IB_USER_VERBS_CMD_DESTROY_QP = 27,
	IB_USER_VERBS_CMD_POST_SEND = 28,
	IB_USER_VERBS_CMD_POST_RECV = 29,
	IB_USER_VERBS_CMD_ATTACH_MCAST = 30,
	IB_USER_VERBS_CMD_DETACH_MCAST = 31,
	IB_USER_VERBS_CMD_CREATE_SRQ = 32,
	IB_USER_VERBS_CMD_MODIFY_SRQ = 33,
	IB_USER_VERBS_CMD_QUERY_SRQ = 34,
	IB_USER_VERBS_CMD_DESTROY_SRQ = 35,
	IB_USER_VERBS_CMD_POST_SRQ_RECV = 36,
	IB_USER_VERBS_CMD_OPEN_XRCD = 37,
	IB_USER_VERBS_CMD_CLOSE_XRCD = 38,
	IB_USER_VERBS_CMD_CREATE_XSRQ = 39,
	IB_USER_VERBS_CMD_OPEN_QP = 40,
};

enum ib_uverbs_wc_opcode {
	IB_UVERBS_WC_SEND = 0,
	IB_UVERBS_WC_RDMA_WRITE = 1,
	IB_UVERBS_WC_RDMA_READ = 2,
	IB_UVERBS_WC_COMP_SWAP = 3,
	IB_UVERBS_WC_FETCH_ADD = 4,
	IB_UVERBS_WC_BIND_MW = 5,
	IB_UVERBS_WC_LOCAL_INV = 6,
	IB_UVERBS_WC_TSO = 7,
};

enum ib_uverbs_create_qp_mask {
	IB_UVERBS_CREATE_QP_MASK_IND_TABLE = 1,
};

enum ib_uverbs_wr_opcode {
	IB_UVERBS_WR_RDMA_WRITE = 0,
	IB_UVERBS_WR_RDMA_WRITE_WITH_IMM = 1,
	IB_UVERBS_WR_SEND = 2,
	IB_UVERBS_WR_SEND_WITH_IMM = 3,
	IB_UVERBS_WR_RDMA_READ = 4,
	IB_UVERBS_WR_ATOMIC_CMP_AND_SWP = 5,
	IB_UVERBS_WR_ATOMIC_FETCH_AND_ADD = 6,
	IB_UVERBS_WR_LOCAL_INV = 7,
	IB_UVERBS_WR_BIND_MW = 8,
	IB_UVERBS_WR_SEND_WITH_INV = 9,
	IB_UVERBS_WR_TSO = 10,
	IB_UVERBS_WR_RDMA_READ_WITH_INV = 11,
	IB_UVERBS_WR_MASKED_ATOMIC_CMP_AND_SWP = 12,
	IB_UVERBS_WR_MASKED_ATOMIC_FETCH_AND_ADD = 13,
};

enum ib_uverbs_access_flags {
	IB_UVERBS_ACCESS_LOCAL_WRITE = 1,
	IB_UVERBS_ACCESS_REMOTE_WRITE = 2,
	IB_UVERBS_ACCESS_REMOTE_READ = 4,
	IB_UVERBS_ACCESS_REMOTE_ATOMIC = 8,
	IB_UVERBS_ACCESS_MW_BIND = 16,
	IB_UVERBS_ACCESS_ZERO_BASED = 32,
	IB_UVERBS_ACCESS_ON_DEMAND = 64,
	IB_UVERBS_ACCESS_HUGETLB = 128,
	IB_UVERBS_ACCESS_RELAXED_ORDERING = 1048576,
	IB_UVERBS_ACCESS_OPTIONAL_RANGE = 1072693248,
};

enum ib_uverbs_srq_type {
	IB_UVERBS_SRQT_BASIC = 0,
	IB_UVERBS_SRQT_XRC = 1,
	IB_UVERBS_SRQT_TM = 2,
};

enum ib_uverbs_wq_type {
	IB_UVERBS_WQT_RQ = 0,
};

enum ib_uverbs_wq_flags {
	IB_UVERBS_WQ_FLAGS_CVLAN_STRIPPING = 1,
	IB_UVERBS_WQ_FLAGS_SCATTER_FCS = 2,
	IB_UVERBS_WQ_FLAGS_DELAY_DROP = 4,
	IB_UVERBS_WQ_FLAGS_PCI_WRITE_END_PADDING = 8,
};

enum ib_uverbs_qp_type {
	IB_UVERBS_QPT_RC = 2,
	IB_UVERBS_QPT_UC = 3,
	IB_UVERBS_QPT_UD = 4,
	IB_UVERBS_QPT_RAW_PACKET = 8,
	IB_UVERBS_QPT_XRC_INI = 9,
	IB_UVERBS_QPT_XRC_TGT = 10,
	IB_UVERBS_QPT_DRIVER = 255,
};

enum ib_uverbs_qp_create_flags {
	IB_UVERBS_QP_CREATE_BLOCK_MULTICAST_LOOPBACK = 2,
	IB_UVERBS_QP_CREATE_SCATTER_FCS = 256,
	IB_UVERBS_QP_CREATE_CVLAN_STRIPPING = 512,
	IB_UVERBS_QP_CREATE_PCI_WRITE_END_PADDING = 2048,
	IB_UVERBS_QP_CREATE_SQ_SIG_ALL = 4096,
};

enum ib_uverbs_gid_type {
	IB_UVERBS_GID_TYPE_IB = 0,
	IB_UVERBS_GID_TYPE_ROCE_V1 = 1,
	IB_UVERBS_GID_TYPE_ROCE_V2 = 2,
};

enum ib_poll_context {
	IB_POLL_SOFTIRQ = 0,
	IB_POLL_WORKQUEUE = 1,
	IB_POLL_UNBOUND_WORKQUEUE = 2,
	IB_POLL_LAST_POOL_TYPE = 2,
	IB_POLL_DIRECT = 3,
};

struct lsm_network_audit {
	int netif;
	const struct sock___14 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit {
	struct path___91 path;
	u16 cmd;
};

struct lsm_ibpkey_audit {
	u64 subnet_prefix;
	u16 pkey;
};

struct lsm_ibendport_audit {
	const char *dev_name;
	u8 port;
};

struct selinux_state;

struct selinux_audit_data {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	u32 requested;
	u32 audited;
	u32 denied;
	int result;
	struct selinux_state *state;
};

struct smack_audit_data;

struct apparmor_audit_data;

struct common_audit_data {
	char type;
	union {
		struct path___91 path;
		struct dentry___91 *dentry;
		struct inode___91 *inode;
		struct lsm_network_audit *net;
		int cap;
		int ipc_id;
		struct task_struct___98 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit *op;
		struct file___91 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data *selinux_audit_data;
		struct apparmor_audit_data *apparmor_audit_data;
	};
};

enum {
	POLICYDB_CAPABILITY_NETPEER = 0,
	POLICYDB_CAPABILITY_OPENPERM = 1,
	POLICYDB_CAPABILITY_EXTSOCKCLASS = 2,
	POLICYDB_CAPABILITY_ALWAYSNETWORK = 3,
	POLICYDB_CAPABILITY_CGROUPSECLABEL = 4,
	POLICYDB_CAPABILITY_NNP_NOSUID_TRANSITION = 5,
	POLICYDB_CAPABILITY_GENFS_SECLABEL_SYMLINKS = 6,
	POLICYDB_CAPABILITY_IOCTL_SKIP_CLOEXEC = 7,
	__POLICYDB_CAPABILITY_MAX = 8,
};

struct selinux_avc;

struct selinux_policy;

struct selinux_state {
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[8];
	struct page___96 *status_page;
	struct mutex status_lock;
	struct selinux_avc *avc;
	struct selinux_policy *policy;
	struct mutex policy_mutex;
};

struct avc_cache {
	struct hlist_head slots[512];
	spinlock_t slots_lock[512];
	atomic_t lru_hint;
	atomic_t active_nodes;
	u32 latest_notif;
};

struct selinux_avc {
	unsigned int avc_cache_threshold;
	struct avc_cache avc_cache;
};

struct av_decision {
	u32 allowed;
	u32 auditallow;
	u32 auditdeny;
	u32 seqno;
	u32 flags;
};

struct extended_perms_data {
	u32 p[8];
};

struct extended_perms_decision {
	u8 used;
	u8 driver;
	struct extended_perms_data *allowed;
	struct extended_perms_data *auditallow;
	struct extended_perms_data *dontaudit;
};

struct extended_perms {
	u16 len;
	struct extended_perms_data drivers;
};

struct avc_cache_stats {
	unsigned int lookups;
	unsigned int misses;
	unsigned int allocations;
	unsigned int reclaims;
	unsigned int frees;
};

struct security_class_mapping {
	const char *name;
	const char *perms[33];
};

struct trace_event_file___27;

struct trace_event_buffer___26 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___27 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___27 {
	struct list_head list;
	struct trace_event_call___50 *event_call;
	struct event_filter *filter;
	struct dentry___91 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_selinux_audited {
	struct trace_entry ent;
	u32 requested;
	u32 denied;
	u32 audited;
	int result;
	u32 __data_loc_scontext;
	u32 __data_loc_tcontext;
	u32 __data_loc_tclass;
	char __data[0];
};

struct trace_event_data_offsets_selinux_audited {
	u32 scontext;
	u32 tcontext;
	u32 tclass;
};

typedef void (*btf_trace_selinux_audited)(void *, struct selinux_audit_data *, char *, char *, const char *);

struct avc_xperms_node;

struct avc_entry {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	struct av_decision avd;
	struct avc_xperms_node *xp_node;
};

struct avc_xperms_node {
	struct extended_perms xp;
	struct list_head xpd_head;
};

struct avc_node {
	struct avc_entry ae;
	struct hlist_node list;
	struct callback_head rhead;
};

struct avc_xperms_decision_node {
	struct extended_perms_decision xpd;
	struct list_head xpd_list;
};

struct avc_callback_node {
	int (*callback)(u32);
	u32 events;
	struct avc_callback_node *next;
};

typedef __u16 __sum16;

struct fs_context___28;

struct fs_parameter_spec___19;

struct dentry___156;

struct super_block___156;

struct module___141;

struct file_system_type___156 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___28 *);
	const struct fs_parameter_spec___19 *parameters;
	struct dentry___156 * (*mount)(struct file_system_type___156 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___156 *);
	struct module___141 *owner;
	struct file_system_type___156 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___156;

struct kiocb___156;

struct iov_iter___85;

struct poll_table_struct___97;

struct vm_area_struct___161;

struct inode___156;

struct file_lock___156;

struct page___161;

struct pipe_inode_info___49;

struct seq_file___134;

struct file_operations___156 {
	struct module___141 *owner;
	loff_t (*llseek)(struct file___156 *, loff_t, int);
	ssize_t (*read)(struct file___156 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___156 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___156 *, struct iov_iter___85 *);
	ssize_t (*write_iter)(struct kiocb___156 *, struct iov_iter___85 *);
	int (*iopoll)(struct kiocb___156 *, bool);
	int (*iterate)(struct file___156 *, struct dir_context *);
	int (*iterate_shared)(struct file___156 *, struct dir_context *);
	__poll_t (*poll)(struct file___156 *, struct poll_table_struct___97 *);
	long int (*unlocked_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___156 *, struct vm_area_struct___161 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___156 *, struct file___156 *);
	int (*flush)(struct file___156 *, fl_owner_t);
	int (*release)(struct inode___156 *, struct file___156 *);
	int (*fsync)(struct file___156 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___156 *, int);
	int (*lock)(struct file___156 *, int, struct file_lock___156 *);
	ssize_t (*sendpage)(struct file___156 *, struct page___161 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___156 *, long unsigned int);
	int (*flock)(struct file___156 *, int, struct file_lock___156 *);
	ssize_t (*splice_write)(struct pipe_inode_info___49 *, struct file___156 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___156 *, loff_t *, struct pipe_inode_info___49 *, size_t, unsigned int);
	int (*setlease)(struct file___156 *, long int, struct file_lock___156 **, void **);
	long int (*fallocate)(struct file___156 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___134 *, struct file___156 *);
	ssize_t (*copy_file_range)(struct file___156 *, loff_t, struct file___156 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___156 *, loff_t, struct file___156 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___156 *, loff_t, loff_t, int);
};

struct vfsmount___156;

struct path___156 {
	struct vfsmount___156 *mnt;
	struct dentry___156 *dentry;
};

struct pid___137;

struct fown_struct___137 {
	rwlock_t lock;
	struct pid___137 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___156;

struct file___156 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___156 f_path;
	struct inode___156 *f_inode;
	const struct file_operations___156 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___137 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___156 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vmacache___161 {
	u64 seqnum;
	struct vm_area_struct___161 *vmas[4];
};

struct page_frag___161 {
	struct page___161 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___70;

struct debug_info___70 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___70 *hbp_break[16];
	struct perf_event___70 *hbp_watch[16];
};

struct thread_struct___70 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___70 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___162;

struct files_struct___19;

struct nsproxy___146;

struct signal_struct___157;

struct bio_list___69;

struct backing_dev_info___66;

struct io_context___69;

struct css_set___105;

struct perf_event_context___70;

struct mem_cgroup___57;

struct request_queue___69;

struct vm_struct___140;

struct task_struct___163 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___163 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___162 *mm;
	struct mm_struct___162 *active_mm;
	struct vmacache___161 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___163 *real_parent;
	struct task_struct___163 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___163 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___137 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	struct key___7 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___19 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___146 *nsproxy;
	struct signal_struct___157 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___163 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___69 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___66 *backing_dev_info;
	struct io_context___69 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___105 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___70 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___49 *splice_pipe;
	struct page_frag___161 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___57 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___57 *active_memcg;
	struct request_queue___69 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___163 *oom_reaper_list;
	struct vm_struct___140 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___143;

struct kobj_type___143;

struct kernfs_node___143;

struct kobject___143 {
	const char *name;
	struct list_head entry;
	struct kobject___143 *parent;
	struct kset___143 *kset;
	struct kobj_type___143 *ktype;
	struct kernfs_node___143 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___140 {
	struct kobject___143 kobj;
	struct module___141 *mod;
	struct kobject___143 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___140 {
	struct module___141 *mod;
	struct latch_tree_node node;
};

struct module_layout___140 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___140 mtn;
};

struct module_attribute___140;

struct kernel_param___140;

struct trace_event_call___64;

struct module___141 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___140 mkobj;
	struct module_attribute___140 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___143 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___140 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___140 core_layout;
	struct module_layout___140 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___64 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___70 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___163 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___70)(struct perf_event___70 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___70;

struct fasync_struct___156;

struct pid_namespace___137;

struct bpf_prog___24;

struct perf_cgroup___70;

struct perf_event___70 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___70 *group_leader;
	struct pmu___70 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___70 hw;
	struct perf_event_context___70 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___70 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___163 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___156 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___70 *aux_event;
	void (*destroy)(struct perf_event___70 *);
	struct callback_head callback_head;
	struct pid_namespace___137 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___70 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___70 orig_overflow_handler;
	struct bpf_prog___24 *prog;
	u64 bpf_cookie;
	struct trace_event_call___64 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___70 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___137 {
	int nr;
	struct pid_namespace___137 *ns;
};

struct pid_namespace___137 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___163 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___137 *parent;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___137 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___137 numbers[1];
};

typedef struct page___161 *pgtable_t___161;

struct page_pool___40;

struct dev_pagemap___152;

struct page___161 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___156 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___40 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___161 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___161 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___162 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___152 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___152;

struct vm_area_struct___161 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___161 *vm_next;
	struct vm_area_struct___161 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___162 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___152 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___156 *vm_file;
	struct file___156 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___12;

struct signal_struct___157 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___163 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___163 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___137 *pids[4];
	struct pid___137 *tty_old_pgrp;
	int leader;
	struct tty_struct___12 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___162 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___28;

struct core_state___161;

struct mm_struct___162 {
	struct {
		struct vm_area_struct___161 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___28 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___161 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___163 *owner;
		struct user_namespace___23 *user_ns;
		struct file___156 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___19 {
	unsigned int max_fds;
	struct file___156 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___19 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___19 *fdt;
	struct fdtable___19 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___156 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___30;

struct cgroup_namespace___105;

struct nsproxy___146 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___137 *pid_ns_for_children;
	struct net___30 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___105 *cgroup_ns;
};

struct bio___69;

struct bio_list___69 {
	struct bio___69 *head;
	struct bio___69 *tail;
};

struct cgroup_subsys_state___105;

struct bdi_writeback___66 {
	struct backing_dev_info___66 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___105 *memcg_css;
	struct cgroup_subsys_state___105 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___112;

struct backing_dev_info___66 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___66 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___112 *dev;
	char dev_name[64];
	struct device___112 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___156 *debug_dir;
};

struct io_cq___69;

struct io_context___69 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___69 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___105;

struct css_set___105 {
	struct cgroup_subsys_state___105 *subsys[14];
	refcount_t refcount;
	struct css_set___105 *dom_cset;
	struct cgroup___105 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___105 *mg_src_cgrp;
	struct cgroup___105 *mg_dst_cgrp;
	struct css_set___105 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___70 {
	struct pmu___70 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___163 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___70 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___49;

struct pipe_inode_info___49 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___161 *tmp_page;
	struct fasync_struct___156 *fasync_readers;
	struct fasync_struct___156 *fasync_writers;
	struct pipe_buffer___49 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___105;

struct cgroup_subsys_state___105 {
	struct cgroup___105 *cgroup;
	struct cgroup_subsys___105 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___105 *parent;
};

struct cgroup_file___105 {
	struct kernfs_node___143 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___57;

struct mem_cgroup_per_node___57;

struct mem_cgroup___57 {
	struct cgroup_subsys_state___105 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___105 events_file;
	struct cgroup_file___105 events_local_file;
	struct cgroup_file___105 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___57 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___163 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___57 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___69;

struct blk_integrity___69 {
	const struct blk_integrity_profile___69 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___69 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___69 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___69;

struct elevator_queue___69;

struct blk_mq_ops___66;

struct blk_mq_hw_ctx___66;

struct gendisk___69;

struct blkcg_gq___66;

struct blk_mq_tag_set___66;

struct request_queue___69 {
	struct request___69 *last_merge;
	struct elevator_queue___69 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___66 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___66 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___69 *disk;
	struct kobject___143 kobj;
	struct kobject___143 *mq_kobj;
	struct blk_integrity___69 integrity;
	struct device___112 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___66 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___66 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___69 bio_split;
	struct dentry___156 *debugfs_dir;
	struct dentry___156 *sched_debugfs_dir;
	struct dentry___156 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___140 {
	struct vm_struct___140 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___161 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___156;

struct address_space___156 {
	struct inode___156 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___156 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___40 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___112 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___40 {
	u32 count;
	struct page___161 *cache[128];
};

struct page_pool___40 {
	struct page_pool_params___40 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___161 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___40 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___152;

struct dev_pagemap___152 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___152 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___152;

struct vm_operations_struct___152 {
	void (*open)(struct vm_area_struct___161 *);
	void (*close)(struct vm_area_struct___161 *);
	int (*may_split)(struct vm_area_struct___161 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___161 *);
	int (*mprotect)(struct vm_area_struct___161 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___152 *);
	vm_fault_t (*huge_fault)(struct vm_fault___152 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___152 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___161 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___152 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___152 *);
	int (*access)(struct vm_area_struct___161 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___161 *);
	int (*set_policy)(struct vm_area_struct___161 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___161 *, long unsigned int);
	struct page___161 * (*find_special_page)(struct vm_area_struct___161 *, long unsigned int);
};

struct core_thread___161 {
	struct task_struct___163 *task;
	struct core_thread___161 *next;
};

struct core_state___161 {
	atomic_t nr_threads;
	struct core_thread___161 dumper;
	struct completion startup;
};

struct linux_binprm___29;

struct coredump_params___28;

struct linux_binfmt___28 {
	struct list_head lh;
	struct module___141 *module;
	int (*load_binary)(struct linux_binprm___29 *);
	int (*load_shlib)(struct file___156 *);
	int (*core_dump)(struct coredump_params___28 *);
	long unsigned int min_coredump;
};

struct vm_fault___152 {
	const struct {
		struct vm_area_struct___161 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___161 *cow_page;
	struct page___161 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___161 prealloc_pte;
};

struct psi_group___105 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___163 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___24;

struct cgroup_bpf___24 {
	struct bpf_prog_array___24 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___24 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___105;

struct cgroup_rstat_cpu___105;

struct cgroup___105 {
	struct cgroup_subsys_state___105 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___143 *kn;
	struct cgroup_file___105 procs_file;
	struct cgroup_file___105 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___105 *subsys[14];
	struct cgroup_root___105 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___105 *dom_cgrp;
	struct cgroup___105 *old_dom_cgrp;
	struct cgroup_rstat_cpu___105 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___105 psi;
	struct cgroup_bpf___24 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___64;

struct lruvec___64 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___64 *pgdat;
};

struct zone___64 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___64 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___64 {
	struct zone___64 *zone;
	int zone_idx;
};

struct zonelist___64 {
	struct zoneref___64 _zonerefs[321];
};

struct pglist_data___64 {
	struct zone___64 node_zones[5];
	struct zonelist___64 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___163 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___163 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___64 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct tty_driver___13;

struct tty_operations___13;

struct tty_ldisc___12;

struct tty_port___13;

struct tty_struct___12 {
	int magic;
	struct kref kref;
	struct device___112 *dev;
	struct tty_driver___13 *driver;
	const struct tty_operations___13 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___12 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___137 *pgrp;
		struct pid___137 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___12 *link;
	struct fasync_struct___156 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___13 *port;
};

struct shrink_control___57 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___57 *memcg;
};

struct shrinker___57 {
	long unsigned int (*count_objects)(struct shrinker___57 *, struct shrink_control___57 *);
	long unsigned int (*scan_objects)(struct shrinker___57 *, struct shrink_control___57 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___152 {
	void (*page_free)(struct page___161 *);
	void (*kill)(struct dev_pagemap___152 *);
	void (*cleanup)(struct dev_pagemap___152 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___152 *);
};

struct dentry_operations___156;

struct dentry___156 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___156 *d_parent;
	struct qstr d_name;
	struct inode___156 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___156 *d_op;
	struct super_block___156 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___156;

struct cdev___26;

struct inode___156 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___156 *i_op;
	struct super_block___156 *i_sb;
	struct address_space___156 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___66 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___156 *i_fop;
		void (*free_inode)(struct inode___156 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___156 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___49 *i_pipe;
		struct cdev___26 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___156 {
	int (*d_revalidate)(struct dentry___156 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___156 *, unsigned int);
	int (*d_hash)(const struct dentry___156 *, struct qstr *);
	int (*d_compare)(const struct dentry___156 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___156 *);
	int (*d_init)(struct dentry___156 *);
	void (*d_release)(struct dentry___156 *);
	void (*d_prune)(struct dentry___156 *);
	void (*d_iput)(struct dentry___156 *, struct inode___156 *);
	char * (*d_dname)(struct dentry___156 *, char *, int);
	struct vfsmount___156 * (*d_automount)(struct path___156 *);
	int (*d_manage)(const struct path___156 *, bool);
	struct dentry___156 * (*d_real)(struct dentry___156 *, const struct inode___156 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___156;

struct mem_dqinfo___156 {
	struct quota_format_type___156 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___156;

struct quota_info___156 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___156 *files[3];
	struct mem_dqinfo___156 info[3];
	const struct quota_format_ops___156 *ops[3];
};

struct rcuwait___157 {
	struct task_struct___163 *task;
};

struct percpu_rw_semaphore___157 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___157 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___156 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___157 rw_sem[3];
};

struct super_operations___156;

struct dquot_operations___156;

struct quotactl_ops___156;

struct xattr_handler___21;

struct block_device___70;

struct super_block___156 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___156 *s_type;
	const struct super_operations___156 *s_op;
	const struct dquot_operations___156 *dq_op;
	const struct quotactl_ops___156 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___156 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___21 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___7 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___70 *s_bdev;
	struct backing_dev_info___66 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___156 s_dquot;
	struct sb_writers___156 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___156 *s_d_op;
	int cleancache_poolid;
	struct shrinker___57 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___156 {
	struct dentry___156 *mnt_root;
	struct super_block___156 *mnt_sb;
	int mnt_flags;
	struct user_namespace___23 *mnt_userns;
};

struct io_cq___69 {
	struct request_queue___69 *q;
	struct io_context___69 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___73;

struct kiocb___156 {
	struct file___156 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___156 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___73 *ki_waitq;
	};
};

struct iattr___156 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___156 *ia_file;
};

struct dquot___156 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___156 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___156 {
	int qf_fmt_id;
	const struct quota_format_ops___156 *qf_ops;
	struct module___141 *qf_owner;
	struct quota_format_type___156 *qf_next;
};

struct quota_format_ops___156 {
	int (*check_quota_file)(struct super_block___156 *, int);
	int (*read_file_info)(struct super_block___156 *, int);
	int (*write_file_info)(struct super_block___156 *, int);
	int (*free_file_info)(struct super_block___156 *, int);
	int (*read_dqblk)(struct dquot___156 *);
	int (*commit_dqblk)(struct dquot___156 *);
	int (*release_dqblk)(struct dquot___156 *);
	int (*get_next_id)(struct super_block___156 *, struct kqid *);
};

struct dquot_operations___156 {
	int (*write_dquot)(struct dquot___156 *);
	struct dquot___156 * (*alloc_dquot)(struct super_block___156 *, int);
	void (*destroy_dquot)(struct dquot___156 *);
	int (*acquire_dquot)(struct dquot___156 *);
	int (*release_dquot)(struct dquot___156 *);
	int (*mark_dirty)(struct dquot___156 *);
	int (*write_info)(struct super_block___156 *, int);
	qsize_t * (*get_reserved_space)(struct inode___156 *);
	int (*get_projid)(struct inode___156 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___156 *, qsize_t *);
	int (*get_next_id)(struct super_block___156 *, struct kqid *);
};

struct quotactl_ops___156 {
	int (*quota_on)(struct super_block___156 *, int, int, const struct path___156 *);
	int (*quota_off)(struct super_block___156 *, int);
	int (*quota_enable)(struct super_block___156 *, unsigned int);
	int (*quota_disable)(struct super_block___156 *, unsigned int);
	int (*quota_sync)(struct super_block___156 *, int);
	int (*set_info)(struct super_block___156 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___156 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___156 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___156 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___156 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___156 *, unsigned int);
};

struct wait_page_queue___73 {
	struct page___161 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___66;

struct readahead_control___73;

struct swap_info_struct___37;

struct address_space_operations___156 {
	int (*writepage)(struct page___161 *, struct writeback_control___66 *);
	int (*readpage)(struct file___156 *, struct page___161 *);
	int (*writepages)(struct address_space___156 *, struct writeback_control___66 *);
	int (*set_page_dirty)(struct page___161 *);
	int (*readpages)(struct file___156 *, struct address_space___156 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___73 *);
	int (*write_begin)(struct file___156 *, struct address_space___156 *, loff_t, unsigned int, unsigned int, struct page___161 **, void **);
	int (*write_end)(struct file___156 *, struct address_space___156 *, loff_t, unsigned int, unsigned int, struct page___161 *, void *);
	sector_t (*bmap)(struct address_space___156 *, sector_t);
	void (*invalidatepage)(struct page___161 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___161 *, gfp_t);
	void (*freepage)(struct page___161 *);
	ssize_t (*direct_IO)(struct kiocb___156 *, struct iov_iter___85 *);
	int (*migratepage)(struct address_space___156 *, struct page___161 *, struct page___161 *, enum migrate_mode);
	bool (*isolate_page)(struct page___161 *, isolate_mode_t);
	void (*putback_page)(struct page___161 *);
	int (*launder_page)(struct page___161 *);
	int (*is_partially_uptodate)(struct page___161 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___161 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___156 *, struct page___161 *);
	int (*swap_activate)(struct swap_info_struct___37 *, struct file___156 *, sector_t *);
	void (*swap_deactivate)(struct file___156 *);
};

struct writeback_control___66 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___66 *wb;
	struct inode___156 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___73 {
	struct file___156 *file;
	struct address_space___156 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___83;

struct iov_iter___85 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___83 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___49 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___37 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___70 *bdev;
	struct file___156 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___26 {
	struct kobject___143 kobj;
	struct module___141 *owner;
	const struct file_operations___156 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___156 {
	struct dentry___156 * (*lookup)(struct inode___156 *, struct dentry___156 *, unsigned int);
	const char * (*get_link)(struct dentry___156 *, struct inode___156 *, struct delayed_call *);
	int (*permission)(struct user_namespace___23 *, struct inode___156 *, int);
	struct posix_acl * (*get_acl)(struct inode___156 *, int, bool);
	int (*readlink)(struct dentry___156 *, char *, int);
	int (*create)(struct user_namespace___23 *, struct inode___156 *, struct dentry___156 *, umode_t, bool);
	int (*link)(struct dentry___156 *, struct inode___156 *, struct dentry___156 *);
	int (*unlink)(struct inode___156 *, struct dentry___156 *);
	int (*symlink)(struct user_namespace___23 *, struct inode___156 *, struct dentry___156 *, const char *);
	int (*mkdir)(struct user_namespace___23 *, struct inode___156 *, struct dentry___156 *, umode_t);
	int (*rmdir)(struct inode___156 *, struct dentry___156 *);
	int (*mknod)(struct user_namespace___23 *, struct inode___156 *, struct dentry___156 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___23 *, struct inode___156 *, struct dentry___156 *, struct inode___156 *, struct dentry___156 *, unsigned int);
	int (*setattr)(struct user_namespace___23 *, struct dentry___156 *, struct iattr___156 *);
	int (*getattr)(struct user_namespace___23 *, const struct path___156 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___156 *, char *, size_t);
	int (*fiemap)(struct inode___156 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___156 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___156 *, struct dentry___156 *, struct file___156 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___23 *, struct inode___156 *, struct dentry___156 *, umode_t);
	int (*set_acl)(struct user_namespace___23 *, struct inode___156 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___23 *, struct dentry___156 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___156 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___156 {
	void (*fl_copy_lock)(struct file_lock___156 *, struct file_lock___156 *);
	void (*fl_release_private)(struct file_lock___156 *);
};

struct lock_manager_operations___156;

struct file_lock___156 {
	struct file_lock___156 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___156 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___156 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___156 *fl_ops;
	const struct lock_manager_operations___156 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___156 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___156 *);
	int (*lm_grant)(struct file_lock___156 *, int);
	bool (*lm_break)(struct file_lock___156 *);
	int (*lm_change)(struct file_lock___156 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___156 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___156 *);
};

struct fasync_struct___156 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___156 *fa_next;
	struct file___156 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___156 {
	struct inode___156 * (*alloc_inode)(struct super_block___156 *);
	void (*destroy_inode)(struct inode___156 *);
	void (*free_inode)(struct inode___156 *);
	void (*dirty_inode)(struct inode___156 *, int);
	int (*write_inode)(struct inode___156 *, struct writeback_control___66 *);
	int (*drop_inode)(struct inode___156 *);
	void (*evict_inode)(struct inode___156 *);
	void (*put_super)(struct super_block___156 *);
	int (*sync_fs)(struct super_block___156 *, int);
	int (*freeze_super)(struct super_block___156 *);
	int (*freeze_fs)(struct super_block___156 *);
	int (*thaw_super)(struct super_block___156 *);
	int (*unfreeze_fs)(struct super_block___156 *);
	int (*statfs)(struct dentry___156 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___156 *, int *, char *);
	void (*umount_begin)(struct super_block___156 *);
	int (*show_options)(struct seq_file___134 *, struct dentry___156 *);
	int (*show_devname)(struct seq_file___134 *, struct dentry___156 *);
	int (*show_path)(struct seq_file___134 *, struct dentry___156 *);
	int (*show_stats)(struct seq_file___134 *, struct dentry___156 *);
	ssize_t (*quota_read)(struct super_block___156 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___156 *, int, const char *, size_t, loff_t);
	struct dquot___156 ** (*get_dquots)(struct inode___156 *);
	long int (*nr_cached_objects)(struct super_block___156 *, struct shrink_control___57 *);
	long int (*free_cached_objects)(struct super_block___156 *, struct shrink_control___57 *);
	struct file___156 * (*real_loop)(struct file___156 *);
};

struct xattr_handler___21 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___156 *);
	int (*get)(const struct xattr_handler___21 *, struct dentry___156 *, struct inode___156 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___21 *, struct user_namespace___23 *, struct dentry___156 *, struct inode___156 *, const char *, const void *, size_t, int);
};

struct wakeup_source___112;

struct dev_pm_info___112 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___112 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___112 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___112;

struct bus_type___112;

struct device_driver___112;

struct dev_pm_domain___112;

struct fwnode_handle___112;

struct class___112;

struct attribute_group___143;

struct device___112 {
	struct kobject___143 kobj;
	struct device___112 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___112 *type;
	struct bus_type___112 *bus;
	struct device_driver___112 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___112 power;
	struct dev_pm_domain___112 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___112 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___112 *class;
	const struct attribute_group___143 **groups;
	void (*release)(struct device___112 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___70 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___156 *bd_inode;
	struct super_block___156 *bd_super;
	void *bd_claiming;
	struct device___112 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___143 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___69 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___156 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___99)(struct file___156 *, wait_queue_head_t *, struct poll_table_struct___97 *);

struct poll_table_struct___97 {
	poll_queue_proc___99 _qproc;
	__poll_t _key;
};

struct seq_operations___134;

struct seq_file___134 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___134 *op;
	int poll_event;
	const struct file___156 *file;
	void *private;
};

struct fc_log___28;

struct p_log___28 {
	const char *prefix;
	struct fc_log___28 *log;
};

struct fs_context_operations___28;

struct fs_context___28 {
	const struct fs_context_operations___28 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___156 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___156 *root;
	struct user_namespace___23 *user_ns;
	struct net___30 *net_ns;
	const struct cred___26 *cred;
	struct p_log___28 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int fs_param_type___19(struct p_log___28 *, const struct fs_parameter_spec___19 *, struct fs_parameter___28 *, struct fs_parse_result *);

struct fs_parameter_spec___19 {
	const char *name;
	fs_param_type___19 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___69(struct bio___69 *);

struct bio_vec___83 {
	struct page___161 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___69;

struct bio___69 {
	struct bio___69 *bi_next;
	struct block_device___70 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___69 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___66 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___69 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___83 *bi_io_vec;
	struct bio_set___69 *bi_pool;
	struct bio_vec___83 bi_inline_vecs[0];
};

struct ip_ra_chain___4;

struct fib_rules_ops___17;

struct sock___18;

struct fqdir___29;

struct tcp_congestion_ops___2;

struct fib_notifier_ops___17;

struct netns_ipv4___29 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___4 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___17 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___18 *fibnl;
	struct sock___18 **icmp_sk;
	struct sock___18 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___18 **tcp_sk;
	struct fqdir___29 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___2 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___17 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___17 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___17 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___17;

struct sk_buff___26;

struct neighbour___17;

struct dst_ops___29 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___29 *);
	struct dst_entry___17 * (*check)(struct dst_entry___17 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___17 *);
	unsigned int (*mtu)(const struct dst_entry___17 *);
	u32 * (*cow_metrics)(struct dst_entry___17 *, long unsigned int);
	void (*destroy)(struct dst_entry___17 *);
	void (*ifdown)(struct dst_entry___17 *, struct net_device___3 *, int);
	struct dst_entry___17 * (*negative_advice)(struct dst_entry___17 *);
	void (*link_failure)(struct sk_buff___26 *);
	void (*update_pmtu)(struct dst_entry___17 *, struct sock___18 *, struct sk_buff___26 *, u32, bool);
	void (*redirect)(struct dst_entry___17 *, struct sock___18 *, struct sk_buff___26 *);
	int (*local_out)(struct net___30 *, struct sock___18 *, struct sk_buff___26 *);
	struct neighbour___17 * (*neigh_lookup)(const struct dst_entry___17 *, struct sk_buff___26 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___17 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___29 {
	struct dst_ops___29 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___29 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___17 *fib6_rules_ops;
	struct sock___18 **icmp_sk;
	struct sock___18 *ndisc_sk;
	struct sock___18 *tcp_sk;
	struct sock___18 *igmp_sk;
	struct sock___18 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___17 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___17 *notifier_ops;
	struct fib_notifier_ops___17 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___29 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___29 *fqdir;
};

struct netns_sctp___17 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___18 *ctl_sock;
	struct sock___18 *udp4_sock;
	struct sock___18 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___24 {
	struct sk_buff___26 *next;
	struct sk_buff___26 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_bpf___24 {
	struct bpf_prog_array___24 *run_array[2];
	struct bpf_prog___24 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___29 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___18 *nlsk;
	struct sock___18 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___29 xfrm4_dst_ops;
	struct dst_ops___29 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___30 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___18 *rtnl;
	struct sock___18 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___3 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___29 ipv4;
	struct netns_ipv6___29 ipv6;
	struct netns_ieee802154_lowpan___29 ieee802154_lowpan;
	struct netns_sctp___17 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___24 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___24 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___29 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___18 *crypto_nlsk;
	struct sock___18 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___105 {
	struct ns_common___26 ns;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct css_set___105 *root_cset;
};

struct seq_operations___134 {
	void * (*start)(struct seq_file___134 *, loff_t *);
	void (*stop)(struct seq_file___134 *, void *);
	void * (*next)(struct seq_file___134 *, void *, loff_t *);
	int (*show)(struct seq_file___134 *, void *);
};

struct kernfs_root___143;

struct kernfs_elem_dir___143 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___143 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___143;

struct kernfs_root___143 {
	struct kernfs_node___143 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___143 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___143 {
	struct kernfs_node___143 *target_kn;
};

struct kernfs_ops___143;

struct kernfs_elem_attr___143 {
	const struct kernfs_ops___143 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___143 *notify_next;
};

struct kernfs_node___143 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___143 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___143 dir;
		struct kernfs_elem_symlink___143 symlink;
		struct kernfs_elem_attr___143 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___143;

struct kernfs_ops___143 {
	int (*open)(struct kernfs_open_file___143 *);
	void (*release)(struct kernfs_open_file___143 *);
	int (*seq_show)(struct seq_file___134 *, void *);
	void * (*seq_start)(struct seq_file___134 *, loff_t *);
	void * (*seq_next)(struct seq_file___134 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___134 *, void *);
	ssize_t (*read)(struct kernfs_open_file___143 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___143 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___143 *, struct poll_table_struct___97 *);
	int (*mmap)(struct kernfs_open_file___143 *, struct vm_area_struct___161 *);
};

struct kernfs_syscall_ops___143 {
	int (*show_options)(struct seq_file___134 *, struct kernfs_root___143 *);
	int (*mkdir)(struct kernfs_node___143 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___143 *);
	int (*rename)(struct kernfs_node___143 *, struct kernfs_node___143 *, const char *);
	int (*show_path)(struct seq_file___134 *, struct kernfs_node___143 *, struct kernfs_root___143 *);
};

struct kernfs_open_file___143 {
	struct kernfs_node___143 *kn;
	struct file___156 *file;
	struct seq_file___134 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___152 *vm_ops;
};

struct fwnode_operations___112;

struct fwnode_handle___112 {
	struct fwnode_handle___112 *secondary;
	const struct fwnode_operations___112 *ops;
	struct device___112 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___112;

struct fwnode_endpoint___112;

struct fwnode_operations___112 {
	struct fwnode_handle___112 * (*get)(struct fwnode_handle___112 *);
	void (*put)(struct fwnode_handle___112 *);
	bool (*device_is_available)(const struct fwnode_handle___112 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___112 *, const struct device___112 *);
	bool (*property_present)(const struct fwnode_handle___112 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___112 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___112 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___112 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*get_parent)(const struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*get_next_child_node)(const struct fwnode_handle___112 *, struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*get_named_child_node)(const struct fwnode_handle___112 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___112 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___112 *);
	struct fwnode_handle___112 * (*graph_get_next_endpoint)(const struct fwnode_handle___112 *, struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*graph_get_remote_endpoint)(const struct fwnode_handle___112 *);
	struct fwnode_handle___112 * (*graph_get_port_parent)(struct fwnode_handle___112 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___112 *, struct fwnode_endpoint___112 *);
	int (*add_links)(struct fwnode_handle___112 *);
};

struct fwnode_endpoint___112 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___112 *local_fwnode;
};

struct fwnode_reference_args___112 {
	struct fwnode_handle___112 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kobj_ns_type_operations___17 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___18 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___30 *net;
} possible_net_t___24;

struct proto___17;

struct sock_common___17 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___17 *skc_prot;
	possible_net_t___24 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___18 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___17 {
	struct cgroup___105 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___17;

struct socket_wq___18;

struct socket___18;

struct sock_reuseport___3;

struct sock___18 {
	struct sock_common___17 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___24 sk_error_queue;
	struct sk_buff___26 *sk_rx_skb_cache;
	struct sk_buff_head___24 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___26 *head;
		struct sk_buff___26 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___17 *sk_filter;
	union {
		struct socket_wq___18 *sk_wq;
		struct socket_wq___18 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___17 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___17 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___26 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___26 *sk_tx_skb_cache;
	struct sk_buff_head___24 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___161 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___17 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___137 *sk_peer_pid;
	const struct cred___26 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___18 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___17 sk_cgrp_data;
	struct mem_cgroup___57 *sk_memcg;
	void (*sk_state_change)(struct sock___18 *);
	void (*sk_data_ready)(struct sock___18 *);
	void (*sk_write_space)(struct sock___18 *);
	void (*sk_error_report)(struct sock___18 *);
	int (*sk_backlog_rcv)(struct sock___18 *, struct sk_buff___26 *);
	struct sk_buff___26 * (*sk_validate_xmit_skb)(struct sock___18 *, struct net_device___3 *, struct sk_buff___26 *);
	void (*sk_destruct)(struct sock___18 *);
	struct sock_reuseport___3 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___143;

struct attribute_group___143 {
	const char *name;
	umode_t (*is_visible)(struct kobject___143 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___143 *, struct bin_attribute___143 *, int);
	struct attribute **attrs;
	struct bin_attribute___143 **bin_attrs;
};

struct bin_attribute___143 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___156 * (*f_mapping)();
	ssize_t (*read)(struct file___156 *, struct kobject___143 *, struct bin_attribute___143 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___156 *, struct kobject___143 *, struct bin_attribute___143 *, char *, loff_t, size_t);
	int (*mmap)(struct file___156 *, struct kobject___143 *, struct bin_attribute___143 *, struct vm_area_struct___161 *);
};

struct sysfs_ops___143 {
	ssize_t (*show)(struct kobject___143 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___143 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___143;

struct kset___143 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___143 kobj;
	const struct kset_uevent_ops___143 *uevent_ops;
};

struct kobj_type___143 {
	void (*release)(struct kobject___143 *);
	const struct sysfs_ops___143 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___143 **default_groups;
	const struct kobj_ns_type_operations___17 * (*child_ns_type)(struct kobject___143 *);
	const void * (*namespace)(struct kobject___143 *);
	void (*get_ownership)(struct kobject___143 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___143 {
	int (* const filter)(struct kset___143 *, struct kobject___143 *);
	const char * (* const name)(struct kset___143 *, struct kobject___143 *);
	int (* const uevent)(struct kset___143 *, struct kobject___143 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___140 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___140 *);
	int (*get)(char *, const struct kernel_param___140 *);
	void (*free)(void *);
};

struct kparam_array___140;

struct kernel_param___140 {
	const char *name;
	struct module___141 *mod;
	const struct kernel_param_ops___140 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___140 *arr;
	};
};

struct kparam_array___140 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___140 *ops;
	void *elem;
};

struct module_attribute___140 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___140 *, struct module_kobject___140 *, char *);
	ssize_t (*store)(struct module_attribute___140 *, struct module_kobject___140 *, const char *, size_t);
	void (*setup)(struct module___141 *, const char *);
	int (*test)(struct module___141 *);
	void (*free)(struct module___141 *);
};

struct trace_event_class___64;

struct trace_event_call___64 {
	struct list_head list;
	struct trace_event_class___64 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___24 *prog_array;
	int (*perf_perm)(struct trace_event_call___64 *, struct perf_event___70 *);
};

struct bpf_iter_aux_info___27;

typedef int (*bpf_iter_init_seq_priv_t___26)(void *, struct bpf_iter_aux_info___27 *);

struct bpf_map___26;

struct bpf_iter_aux_info___27 {
	struct bpf_map___26 *map;
};

struct bpf_iter_seq_info___26 {
	const struct seq_operations___134 *seq_ops;
	bpf_iter_init_seq_priv_t___26 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___26;

struct bpf_map_ops___26 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___26 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___26 *, struct file___156 *);
	void (*map_free)(struct bpf_map___26 *);
	int (*map_get_next_key)(struct bpf_map___26 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___26 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___26 *, void *);
	int (*map_lookup_batch)(struct bpf_map___26 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___26 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___26 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___26 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___26 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___26 *, void *);
	int (*map_update_elem)(struct bpf_map___26 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___26 *, void *);
	int (*map_push_elem)(struct bpf_map___26 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___26 *, void *);
	int (*map_peek_elem)(struct bpf_map___26 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___26 *, struct file___156 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___26 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___26 *, void *, struct seq_file___134 *);
	int (*map_check_btf)(const struct bpf_map___26 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___26 *, struct bpf_prog_aux___26 *);
	void (*map_poke_untrack)(struct bpf_map___26 *, struct bpf_prog_aux___26 *);
	void (*map_poke_run)(struct bpf_map___26 *, u32, struct bpf_prog___24 *, struct bpf_prog___24 *);
	int (*map_direct_value_addr)(const struct bpf_map___26 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___26 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___26 *, struct vm_area_struct___161 *);
	__poll_t (*map_poll)(struct bpf_map___26 *, struct file___156 *, struct poll_table_struct___97 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___26 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___26 *, const struct bpf_map___26 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___26 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___26 *iter_seq_info;
};

struct bpf_map___26 {
	const struct bpf_map_ops___26 *ops;
	struct bpf_map___26 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___57 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___26;

struct bpf_jit_poke_descriptor___26;

struct bpf_prog_ops___24;

struct btf_mod_pair___26;

struct bpf_prog_offload___24;

struct bpf_prog_aux___26 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___24 *dst_prog;
	struct bpf_trampoline___26 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___24 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___26 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___24 *ops;
	struct bpf_map___26 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___26 *used_btfs;
	struct bpf_prog___24 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___26 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___24 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___24 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___26 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___24;

struct bpf_map_dev_ops___24 {
	int (*map_get_next_key)(struct bpf_offloaded_map___24 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___24 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___24 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___24 *, void *);
};

struct bpf_offloaded_map___24 {
	struct bpf_map___26 map;
	struct net_device___3 *netdev;
	const struct bpf_map_dev_ops___24 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___24(struct sk_buff___26 **);

struct bpf_xdp_entity___24 {
	struct bpf_prog___24 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___24;

struct net_device_ops___24;

struct ethtool_ops___2;

struct l3mdev_ops___17;

struct ndisc_ops___7;

struct xfrmdev_ops___24;

struct header_ops___24;

struct inet6_dev___7;

struct netdev_rx_queue___24;

struct mini_Qdisc___24;

struct netdev_queue___24;

struct Qdisc___24;

struct rtnl_link_ops___24;

struct dcbnl_rtnl_ops___24;

struct net_device___3 {
	char name[16];
	struct netdev_name_node___24 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___24 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___2 *ethtool_ops;
	const struct l3mdev_ops___17 *l3mdev_ops;
	const struct ndisc_ops___7 *ndisc_ops;
	const struct xfrmdev_ops___24 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___24 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___143 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___7 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___24 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___24 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___24 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___24 *miniq_ingress;
	struct netdev_queue___24 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___24 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___24 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___24 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___24 = 0,
		NETREG_REGISTERED___24 = 1,
		NETREG_UNREGISTERING___24 = 2,
		NETREG_UNREGISTERED___24 = 3,
		NETREG_RELEASED___24 = 4,
		NETREG_DUMMY___24 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___24 = 0,
		RTNL_LINK_INITIALIZING___24 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___3 *);
	struct netpoll_info *npinfo;
	possible_net_t___24 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___112 dev;
	const struct attribute_group___143 *sysfs_groups[4];
	const struct attribute_group___143 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___24 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___24 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___24 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___24 {
	int (*test_run)(struct bpf_prog___24 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___24 {
	struct bpf_prog___24 *prog;
	struct net_device___3 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___26 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___24 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___141 *mod;
};

struct bpf_jit_poke_descriptor___26 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___26 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___26 {
	struct btf *btf;
	struct module___141 *module;
};

struct bpf_prog_array_item___24 {
	struct bpf_prog___24 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___24 {
	struct callback_head rcu;
	struct bpf_prog_array_item___24 items[0];
};

struct sk_buff___26 {
	union {
		struct {
			struct sk_buff___26 *next;
			struct sk_buff___26 *prev;
			union {
				struct net_device___3 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___18 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___26 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___105;

struct cgroup_subsys___105 {
	struct cgroup_subsys_state___105 * (*css_alloc)(struct cgroup_subsys_state___105 *);
	int (*css_online)(struct cgroup_subsys_state___105 *);
	void (*css_offline)(struct cgroup_subsys_state___105 *);
	void (*css_released)(struct cgroup_subsys_state___105 *);
	void (*css_free)(struct cgroup_subsys_state___105 *);
	void (*css_reset)(struct cgroup_subsys_state___105 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___105 *, int);
	int (*css_extra_stat_show)(struct seq_file___134 *, struct cgroup_subsys_state___105 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___163 *, struct css_set___105 *);
	void (*cancel_fork)(struct task_struct___163 *, struct css_set___105 *);
	void (*fork)(struct task_struct___163 *);
	void (*exit)(struct task_struct___163 *);
	void (*release)(struct task_struct___163 *);
	void (*bind)(struct cgroup_subsys_state___105 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___105 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___105 *dfl_cftypes;
	struct cftype___105 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___105 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___105 *updated_children;
	struct cgroup___105 *updated_next;
};

struct cgroup_root___105 {
	struct kernfs_root___143 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___105 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___105 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___105 *ss;
	struct list_head node;
	struct kernfs_ops___143 *kf_ops;
	int (*open)(struct kernfs_open_file___143 *);
	void (*release)(struct kernfs_open_file___143 *);
	u64 (*read_u64)(struct cgroup_subsys_state___105 *, struct cftype___105 *);
	s64 (*read_s64)(struct cgroup_subsys_state___105 *, struct cftype___105 *);
	int (*seq_show)(struct seq_file___134 *, void *);
	void * (*seq_start)(struct seq_file___134 *, loff_t *);
	void * (*seq_next)(struct seq_file___134 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___134 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___105 *, struct cftype___105 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___105 *, struct cftype___105 *, s64);
	ssize_t (*write)(struct kernfs_open_file___143 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___143 *, struct poll_table_struct___97 *);
};

struct msghdr___18 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___85 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___156 *msg_iocb;
};

struct dev_pm_ops___112 {
	int (*prepare)(struct device___112 *);
	void (*complete)(struct device___112 *);
	int (*suspend)(struct device___112 *);
	int (*resume)(struct device___112 *);
	int (*freeze)(struct device___112 *);
	int (*thaw)(struct device___112 *);
	int (*poweroff)(struct device___112 *);
	int (*restore)(struct device___112 *);
	int (*suspend_late)(struct device___112 *);
	int (*resume_early)(struct device___112 *);
	int (*freeze_late)(struct device___112 *);
	int (*thaw_early)(struct device___112 *);
	int (*poweroff_late)(struct device___112 *);
	int (*restore_early)(struct device___112 *);
	int (*suspend_noirq)(struct device___112 *);
	int (*resume_noirq)(struct device___112 *);
	int (*freeze_noirq)(struct device___112 *);
	int (*thaw_noirq)(struct device___112 *);
	int (*poweroff_noirq)(struct device___112 *);
	int (*restore_noirq)(struct device___112 *);
	int (*runtime_suspend)(struct device___112 *);
	int (*runtime_resume)(struct device___112 *);
	int (*runtime_idle)(struct device___112 *);
};

struct wakeup_source___112 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___112 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___112 {
	struct dev_pm_ops___112 ops;
	int (*start)(struct device___112 *);
	void (*detach)(struct device___112 *, bool);
	int (*activate)(struct device___112 *);
	void (*sync)(struct device___112 *);
	void (*dismiss)(struct device___112 *);
};

struct bus_type___112 {
	const char *name;
	const char *dev_name;
	struct device___112 *dev_root;
	const struct attribute_group___143 **bus_groups;
	const struct attribute_group___143 **dev_groups;
	const struct attribute_group___143 **drv_groups;
	int (*match)(struct device___112 *, struct device_driver___112 *);
	int (*uevent)(struct device___112 *, struct kobj_uevent_env *);
	int (*probe)(struct device___112 *);
	void (*sync_state)(struct device___112 *);
	void (*remove)(struct device___112 *);
	void (*shutdown)(struct device___112 *);
	int (*online)(struct device___112 *);
	int (*offline)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	int (*num_vf)(struct device___112 *);
	int (*dma_configure)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___112 {
	const char *name;
	struct bus_type___112 *bus;
	struct module___141 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___112 *);
	void (*sync_state)(struct device___112 *);
	int (*remove)(struct device___112 *);
	void (*shutdown)(struct device___112 *);
	int (*suspend)(struct device___112 *, pm_message_t);
	int (*resume)(struct device___112 *);
	const struct attribute_group___143 **groups;
	const struct attribute_group___143 **dev_groups;
	const struct dev_pm_ops___112 *pm;
	void (*coredump)(struct device___112 *);
	struct driver_private *p;
};

struct device_type___112 {
	const char *name;
	const struct attribute_group___143 **groups;
	int (*uevent)(struct device___112 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___112 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___112 *);
	const struct dev_pm_ops___112 *pm;
};

struct class___112 {
	const char *name;
	struct module___141 *owner;
	const struct attribute_group___143 **class_groups;
	const struct attribute_group___143 **dev_groups;
	struct kobject___143 *dev_kobj;
	int (*dev_uevent)(struct device___112 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___112 *, umode_t *);
	void (*class_release)(struct class___112 *);
	void (*dev_release)(struct device___112 *);
	int (*shutdown_pre)(struct device___112 *);
	const struct kobj_ns_type_operations___17 *ns_type;
	const void * (*namespace)(struct device___112 *);
	void (*get_ownership)(struct device___112 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___112 *pm;
	struct subsys_private *p;
};

struct block_device_operations___69;

struct gendisk___69 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___70 *part0;
	const struct block_device_operations___69 *fops;
	struct request_queue___69 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___66 *bdi;
	struct kobject___143 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___143 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___69 {
	struct bio___69 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___83 *bip_vec;
	struct bio_vec___83 bip_inline_vecs[0];
};

struct blkcg___66;

struct blkg_policy_data___66;

struct blkcg_gq___66 {
	struct request_queue___69 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___66 *blkcg;
	struct blkcg_gq___66 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___66 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___69 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___69(struct request___69 *);

typedef void integrity_complete_fn___69(struct request___69 *, unsigned int);

struct blk_integrity_profile___69 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___69 *prepare_fn;
	integrity_complete_fn___69 *complete_fn;
	const char *name;
};

struct block_device_operations___69 {
	blk_qc_t (*submit_bio)(struct bio___69 *);
	int (*open)(struct block_device___70 *, fmode_t);
	void (*release)(struct gendisk___69 *, fmode_t);
	int (*rw_page)(struct block_device___70 *, sector_t, struct page___161 *, unsigned int);
	int (*ioctl)(struct block_device___70 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___70 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___69 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___69 *);
	int (*getgeo)(struct block_device___70 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___70 *, bool);
	void (*swap_slot_free_notify)(struct block_device___70 *, long unsigned int);
	int (*report_zones)(struct gendisk___69 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___69 *, umode_t *);
	struct module___141 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___69 *, sector_t *);
};

typedef void rq_end_io_fn___69(struct request___69 *, blk_status_t);

struct request___69 {
	struct request_queue___69 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___66 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___69 *bio;
	struct bio___69 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___83 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___69 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___69 *saved_end_io;
		} flush;
	};
	struct gendisk___69 *rq_disk;
	struct block_device___70 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___69 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___66 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___69 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___143 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___156 *debugfs_dir;
	struct dentry___156 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___69;

struct elevator_mq_ops___69 {
	int (*init_sched)(struct request_queue___69 *, struct elevator_type___69 *);
	void (*exit_sched)(struct elevator_queue___69 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___66 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___66 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___66 *);
	bool (*allow_merge)(struct request_queue___69 *, struct request___69 *, struct bio___69 *);
	bool (*bio_merge)(struct request_queue___69 *, struct bio___69 *, unsigned int);
	int (*request_merge)(struct request_queue___69 *, struct request___69 **, struct bio___69 *);
	void (*request_merged)(struct request_queue___69 *, struct request___69 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___69 *, struct request___69 *, struct request___69 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___69 *);
	void (*finish_request)(struct request___69 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___66 *, struct list_head *, bool);
	struct request___69 * (*dispatch_request)(struct blk_mq_hw_ctx___66 *);
	bool (*has_work)(struct blk_mq_hw_ctx___66 *);
	void (*completed_request)(struct request___69 *, u64);
	void (*requeue_request)(struct request___69 *);
	struct request___69 * (*former_request)(struct request_queue___69 *, struct request___69 *);
	struct request___69 * (*next_request)(struct request_queue___69 *, struct request___69 *);
	void (*init_icq)(struct io_cq___69 *);
	void (*exit_icq)(struct io_cq___69 *);
};

struct elv_fs_entry___69;

struct elevator_type___69 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___69 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___69 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___141 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___69 {
	struct elevator_type___69 *type;
	void *elevator_data;
	struct kobject___143 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___69 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___69 *, char *);
	ssize_t (*store)(struct elevator_queue___69 *, const char *, size_t);
};

struct blk_mq_queue_data___66;

struct blk_mq_ops___66 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___66 *, const struct blk_mq_queue_data___66 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___66 *);
	int (*get_budget)(struct request_queue___69 *);
	void (*put_budget)(struct request_queue___69 *, int);
	void (*set_rq_budget_token)(struct request___69 *, int);
	int (*get_rq_budget_token)(struct request___69 *);
	enum blk_eh_timer_return (*timeout)(struct request___69 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___66 *);
	void (*complete)(struct request___69 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___66 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___66 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___66 *, struct request___69 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___66 *, struct request___69 *, unsigned int);
	void (*initialize_rq_fn)(struct request___69 *);
	void (*cleanup_rq)(struct request___69 *);
	bool (*busy)(struct request_queue___69 *);
	int (*map_queues)(struct blk_mq_tag_set___66 *);
	void (*show_rq)(struct seq_file___134 *, struct request___69 *);
};

struct blk_mq_tag_set___66 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___66 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___66 {
	struct request___69 *rq;
	bool last;
};

struct blkcg_policy_data___66;

struct blkcg___66 {
	struct cgroup_subsys_state___105 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___66 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___66 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___66 {
	struct blkcg___66 *blkcg;
	int plid;
};

struct blkg_policy_data___66 {
	struct blkcg_gq___66 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___57 {
	struct mem_cgroup___57 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___57 {
	struct lruvec___64 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___57 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___57 *memcg;
};

struct obj_cgroup___57 {
	struct percpu_ref refcnt;
	struct mem_cgroup___57 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct request_sock___8;

union security_list_options___3 {
	int (*binder_set_context_mgr)(const struct cred___26 *);
	int (*binder_transaction)(const struct cred___26 *, const struct cred___26 *);
	int (*binder_transfer_binder)(const struct cred___26 *, const struct cred___26 *);
	int (*binder_transfer_file)(const struct cred___26 *, const struct cred___26 *, struct file___156 *);
	int (*ptrace_access_check)(struct task_struct___163 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___163 *);
	int (*capget)(struct task_struct___163 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___26 *, const struct cred___26 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___26 *, struct user_namespace___23 *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___156 *);
	int (*quota_on)(struct dentry___156 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___162 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___29 *);
	int (*bprm_creds_from_file)(struct linux_binprm___29 *, struct file___156 *);
	int (*bprm_check_security)(struct linux_binprm___29 *);
	void (*bprm_committing_creds)(struct linux_binprm___29 *);
	void (*bprm_committed_creds)(struct linux_binprm___29 *);
	int (*fs_context_dup)(struct fs_context___28 *, struct fs_context___28 *);
	int (*fs_context_parse_param)(struct fs_context___28 *, struct fs_parameter___28 *);
	int (*sb_alloc_security)(struct super_block___156 *);
	void (*sb_delete)(struct super_block___156 *);
	void (*sb_free_security)(struct super_block___156 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___156 *, void *);
	int (*sb_remount)(struct super_block___156 *, void *);
	int (*sb_kern_mount)(struct super_block___156 *);
	int (*sb_show_options)(struct seq_file___134 *, struct super_block___156 *);
	int (*sb_statfs)(struct dentry___156 *);
	int (*sb_mount)(const char *, const struct path___156 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___156 *, int);
	int (*sb_pivotroot)(const struct path___156 *, const struct path___156 *);
	int (*sb_set_mnt_opts)(struct super_block___156 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___156 *, struct super_block___156 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___156 *, const struct path___156 *);
	int (*dentry_init_security)(struct dentry___156 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___156 *, int, struct qstr *, const struct cred___26 *, struct cred___26 *);
	int (*path_unlink)(const struct path___156 *, struct dentry___156 *);
	int (*path_mkdir)(const struct path___156 *, struct dentry___156 *, umode_t);
	int (*path_rmdir)(const struct path___156 *, struct dentry___156 *);
	int (*path_mknod)(const struct path___156 *, struct dentry___156 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___156 *);
	int (*path_symlink)(const struct path___156 *, struct dentry___156 *, const char *);
	int (*path_link)(struct dentry___156 *, const struct path___156 *, struct dentry___156 *);
	int (*path_rename)(const struct path___156 *, struct dentry___156 *, const struct path___156 *, struct dentry___156 *);
	int (*path_chmod)(const struct path___156 *, umode_t);
	int (*path_chown)(const struct path___156 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___156 *);
	int (*path_notify)(const struct path___156 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___156 *);
	void (*inode_free_security)(struct inode___156 *);
	int (*inode_init_security)(struct inode___156 *, struct inode___156 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___156 *, const struct qstr *, const struct inode___156 *);
	int (*inode_create)(struct inode___156 *, struct dentry___156 *, umode_t);
	int (*inode_link)(struct dentry___156 *, struct inode___156 *, struct dentry___156 *);
	int (*inode_unlink)(struct inode___156 *, struct dentry___156 *);
	int (*inode_symlink)(struct inode___156 *, struct dentry___156 *, const char *);
	int (*inode_mkdir)(struct inode___156 *, struct dentry___156 *, umode_t);
	int (*inode_rmdir)(struct inode___156 *, struct dentry___156 *);
	int (*inode_mknod)(struct inode___156 *, struct dentry___156 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___156 *, struct dentry___156 *, struct inode___156 *, struct dentry___156 *);
	int (*inode_readlink)(struct dentry___156 *);
	int (*inode_follow_link)(struct dentry___156 *, struct inode___156 *, bool);
	int (*inode_permission)(struct inode___156 *, int);
	int (*inode_setattr)(struct dentry___156 *, struct iattr___156 *);
	int (*inode_getattr)(const struct path___156 *);
	int (*inode_setxattr)(struct user_namespace___23 *, struct dentry___156 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___156 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___156 *, const char *);
	int (*inode_listxattr)(struct dentry___156 *);
	int (*inode_removexattr)(struct user_namespace___23 *, struct dentry___156 *, const char *);
	int (*inode_need_killpriv)(struct dentry___156 *);
	int (*inode_killpriv)(struct user_namespace___23 *, struct dentry___156 *);
	int (*inode_getsecurity)(struct user_namespace___23 *, struct inode___156 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___156 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___156 *, char *, size_t);
	void (*inode_getsecid)(struct inode___156 *, u32 *);
	int (*inode_copy_up)(struct dentry___156 *, struct cred___26 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___143 *, struct kernfs_node___143 *);
	int (*file_permission)(struct file___156 *, int);
	int (*file_alloc_security)(struct file___156 *);
	void (*file_free_security)(struct file___156 *);
	int (*file_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___161 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___156 *, unsigned int);
	int (*file_fcntl)(struct file___156 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___156 *);
	int (*file_send_sigiotask)(struct task_struct___163 *, struct fown_struct___137 *, int);
	int (*file_receive)(struct file___156 *);
	int (*file_open)(struct file___156 *);
	int (*task_alloc)(struct task_struct___163 *, long unsigned int);
	void (*task_free)(struct task_struct___163 *);
	int (*cred_alloc_blank)(struct cred___26 *, gfp_t);
	void (*cred_free)(struct cred___26 *);
	int (*cred_prepare)(struct cred___26 *, const struct cred___26 *, gfp_t);
	void (*cred_transfer)(struct cred___26 *, const struct cred___26 *);
	void (*cred_getsecid)(const struct cred___26 *, u32 *);
	int (*kernel_act_as)(struct cred___26 *, u32);
	int (*kernel_create_files_as)(struct cred___26 *, struct inode___156 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___156 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___156 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___26 *, const struct cred___26 *, int);
	int (*task_fix_setgid)(struct cred___26 *, const struct cred___26 *, int);
	int (*task_setpgid)(struct task_struct___163 *, pid_t);
	int (*task_getpgid)(struct task_struct___163 *);
	int (*task_getsid)(struct task_struct___163 *);
	void (*task_getsecid_subj)(struct task_struct___163 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___163 *, u32 *);
	int (*task_setnice)(struct task_struct___163 *, int);
	int (*task_setioprio)(struct task_struct___163 *, int);
	int (*task_getioprio)(struct task_struct___163 *);
	int (*task_prlimit)(const struct cred___26 *, const struct cred___26 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___163 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___163 *);
	int (*task_getscheduler)(struct task_struct___163 *);
	int (*task_movememory)(struct task_struct___163 *);
	int (*task_kill)(struct task_struct___163 *, struct kernel_siginfo *, int, const struct cred___26 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___163 *, struct inode___156 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___163 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock___18 *, struct sk_buff___26 *);
	void (*d_instantiate)(struct dentry___156 *, struct inode___156 *);
	int (*getprocattr)(struct task_struct___163 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___156 *);
	int (*inode_notifysecctx)(struct inode___156 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___156 *, void *, u32);
	int (*inode_getsecctx)(struct inode___156 *, void **, u32 *);
	int (*post_notification)(const struct cred___26 *, const struct cred___26 *, struct watch_notification *);
	int (*watch_key)(struct key___7 *);
	int (*unix_stream_connect)(struct sock___18 *, struct sock___18 *, struct sock___18 *);
	int (*unix_may_send)(struct socket___18 *, struct socket___18 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___18 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___18 *, struct socket___18 *);
	int (*socket_bind)(struct socket___18 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___18 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___18 *, int);
	int (*socket_accept)(struct socket___18 *, struct socket___18 *);
	int (*socket_sendmsg)(struct socket___18 *, struct msghdr___18 *, int);
	int (*socket_recvmsg)(struct socket___18 *, struct msghdr___18 *, int, int);
	int (*socket_getsockname)(struct socket___18 *);
	int (*socket_getpeername)(struct socket___18 *);
	int (*socket_getsockopt)(struct socket___18 *, int, int);
	int (*socket_setsockopt)(struct socket___18 *, int, int);
	int (*socket_shutdown)(struct socket___18 *, int);
	int (*socket_sock_rcv_skb)(struct sock___18 *, struct sk_buff___26 *);
	int (*socket_getpeersec_stream)(struct socket___18 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___18 *, struct sk_buff___26 *, u32 *);
	int (*sk_alloc_security)(struct sock___18 *, int, gfp_t);
	void (*sk_free_security)(struct sock___18 *);
	void (*sk_clone_security)(const struct sock___18 *, struct sock___18 *);
	void (*sk_getsecid)(struct sock___18 *, u32 *);
	void (*sock_graft)(struct sock___18 *, struct socket___18 *);
	int (*inet_conn_request)(const struct sock___18 *, struct sk_buff___26 *, struct request_sock___8 *);
	void (*inet_csk_clone)(struct sock___18 *, const struct request_sock___8 *);
	void (*inet_conn_established)(struct sock___18 *, struct sk_buff___26 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___8 *, struct flowi_common *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock___18 *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___26 *);
	int (*sctp_bind_connect)(struct sock___18 *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock___18 *, struct sock___18 *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common *);
	int (*xfrm_decode_session)(struct sk_buff___26 *, u32 *, int);
	int (*key_alloc)(struct key___7 *, const struct cred___26 *, long unsigned int);
	void (*key_free)(struct key___7 *);
	int (*key_permission)(key_ref_t, const struct cred___26 *, enum key_need_perm);
	int (*key_getsecurity)(struct key___7 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___26 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog___24 *);
	int (*bpf_map_alloc_security)(struct bpf_map___26 *);
	void (*bpf_map_free_security)(struct bpf_map___26 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___26 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___26 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event___70 *);
	void (*perf_event_free)(struct perf_event___70 *);
	int (*perf_event_read)(struct perf_event___70 *);
	int (*perf_event_write)(struct perf_event___70 *);
};

struct linux_binprm___29 {
	struct vm_area_struct___161 *vma;
	long unsigned int vma_pages;
	struct mm_struct___162 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___156 *executable;
	struct file___156 *interpreter;
	struct file___156 *file;
	struct cred___26 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct fs_parameter___28 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___156 *file;
	};
	size_t size;
	int dirfd;
};

struct socket_wq___18 {
	wait_queue_head_t wait;
	struct fasync_struct___156 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___18;

struct socket___18 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___156 *file;
	struct sock___18 *sk;
	const struct proto_ops___18 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___18 wq;
};

struct request_sock_ops___7;

struct request_sock___8 {
	struct sock_common___17 __req_common;
	struct request_sock___8 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___7 *rsk_ops;
	struct sock___18 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

enum sctp_endpoint_type {
	SCTP_EP_TYPE_SOCKET = 0,
	SCTP_EP_TYPE_ASSOCIATION = 1,
};

struct sctp_chunk;

struct sctp_inq {
	struct list_head in_chunk_list;
	struct sctp_chunk *in_progress;
	struct work_struct immediate;
};

struct sctp_bind_addr {
	__u16 port;
	struct list_head address_list;
};

struct sctp_ep_common {
	struct hlist_node node;
	int hashent;
	enum sctp_endpoint_type type;
	refcount_t refcnt;
	bool dead;
	struct sock___18 *sk;
	struct net___30 *net;
	struct sctp_inq inqueue;
	struct sctp_bind_addr bind_addr;
};

struct sctp_hmac_algo_param;

struct sctp_chunks_param;

struct sctp_endpoint {
	struct sctp_ep_common base;
	struct list_head asocs;
	__u8 secret_key[32];
	__u8 *digest;
	__u32 sndbuf_policy;
	__u32 rcvbuf_policy;
	struct crypto_shash___6 **auth_hmacs;
	struct sctp_hmac_algo_param *auth_hmacs_list;
	struct sctp_chunks_param *auth_chunk_list;
	struct list_head endpoint_shared_keys;
	__u16 active_key_id;
	__u8 ecn_enable: 1;
	__u8 auth_enable: 1;
	__u8 intl_enable: 1;
	__u8 prsctp_enable: 1;
	__u8 asconf_enable: 1;
	__u8 reconf_enable: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 strreset_enable;
	u32 secid;
	u32 peer_secid;
	struct callback_head rcu;
};

struct security_hook_list___3 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___3 hook;
	struct lsm_id *lsmid;
};

struct perf_cpu_context___70;

struct perf_output_handle___70;

struct pmu___70 {
	struct list_head entry;
	struct module___141 *module;
	struct device___112 *dev;
	const struct attribute_group___143 **attr_groups;
	const struct attribute_group___143 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___70 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___70 *);
	void (*pmu_disable)(struct pmu___70 *);
	int (*event_init)(struct perf_event___70 *);
	void (*event_mapped)(struct perf_event___70 *, struct mm_struct___162 *);
	void (*event_unmapped)(struct perf_event___70 *, struct mm_struct___162 *);
	int (*add)(struct perf_event___70 *, int);
	void (*del)(struct perf_event___70 *, int);
	void (*start)(struct perf_event___70 *, int);
	void (*stop)(struct perf_event___70 *, int);
	void (*read)(struct perf_event___70 *);
	void (*start_txn)(struct pmu___70 *, unsigned int);
	int (*commit_txn)(struct pmu___70 *);
	void (*cancel_txn)(struct pmu___70 *);
	int (*event_idx)(struct perf_event___70 *);
	void (*sched_task)(struct perf_event_context___70 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___70 *, struct perf_event_context___70 *);
	void * (*setup_aux)(struct perf_event___70 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___70 *, struct perf_output_handle___70 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___70 *);
	int (*aux_output_match)(struct perf_event___70 *);
	int (*filter_match)(struct perf_event___70 *);
	int (*check_period)(struct perf_event___70 *, u64);
};

struct perf_cpu_context___70 {
	struct perf_event_context___70 ctx;
	struct perf_event_context___70 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___70 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___70 **heap;
	struct perf_event___70 *heap_default[2];
};

struct perf_output_handle___70 {
	struct perf_event___70 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___70 {
	struct cgroup_subsys_state___105 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___64 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___64 *);
	};
};

struct trace_event_class___64 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___64 *, enum trace_reg, void *);
	struct trace_event_fields___64 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___64 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___64 *);
};

struct fc_log___28 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___141 *owner;
	char *buffer[8];
};

struct fs_context_operations___28 {
	void (*free)(struct fs_context___28 *);
	int (*dup)(struct fs_context___28 *, struct fs_context___28 *);
	int (*parse_param)(struct fs_context___28 *, struct fs_parameter___28 *);
	int (*parse_monolithic)(struct fs_context___28 *, void *);
	int (*get_tree)(struct fs_context___28 *);
	int (*reconfigure)(struct fs_context___28 *);
};

typedef int (*sk_read_actor_t___17)(read_descriptor_t *, struct sk_buff___26 *, unsigned int, size_t);

struct proto_ops___18 {
	int family;
	struct module___141 *owner;
	int (*release)(struct socket___18 *);
	int (*bind)(struct socket___18 *, struct sockaddr *, int);
	int (*connect)(struct socket___18 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___18 *, struct socket___18 *);
	int (*accept)(struct socket___18 *, struct socket___18 *, int, bool);
	int (*getname)(struct socket___18 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___156 *, struct socket___18 *, struct poll_table_struct___97 *);
	int (*ioctl)(struct socket___18 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___18 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___18 *, void *, bool, bool);
	int (*listen)(struct socket___18 *, int);
	int (*shutdown)(struct socket___18 *, int);
	int (*setsockopt)(struct socket___18 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___18 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___134 *, struct socket___18 *);
	int (*sendmsg)(struct socket___18 *, struct msghdr___18 *, size_t);
	int (*recvmsg)(struct socket___18 *, struct msghdr___18 *, size_t, int);
	int (*mmap)(struct file___156 *, struct socket___18 *, struct vm_area_struct___161 *);
	ssize_t (*sendpage)(struct socket___18 *, struct page___161 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___18 *, loff_t *, struct pipe_inode_info___49 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___18 *, int);
	int (*peek_len)(struct socket___18 *);
	int (*read_sock)(struct sock___18 *, read_descriptor_t *, sk_read_actor_t___17);
	int (*sendpage_locked)(struct sock___18 *, struct page___161 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___18 *, struct msghdr___18 *, size_t);
	int (*set_rcvlowat)(struct sock___18 *, int);
};

struct sockaddr_in6 {
	short unsigned int sin6_family;
	__be16 sin6_port;
	__be32 sin6_flowinfo;
	struct in6_addr sin6_addr;
	__u32 sin6_scope_id;
};

struct pipe_buf_operations___49;

struct pipe_buffer___49 {
	struct page___161 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___49 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___49 {
	int (*confirm)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
	void (*release)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
	bool (*try_steal)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
	bool (*get)(struct pipe_inode_info___49 *, struct pipe_buffer___49 *);
};

struct in_addr {
	__be32 s_addr;
};

struct sockaddr_in {
	__kernel_sa_family_t sin_family;
	__be16 sin_port;
	struct in_addr sin_addr;
	unsigned char __pad[8];
};

struct inet_frags___29;

struct fqdir___29 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___29 *f;
	struct net___30 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___29;

struct inet_frags___29 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___29 *, const void *);
	void (*destructor)(struct inet_frag_queue___29 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___29 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___26 *fragments_tail;
	struct sk_buff___26 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___29 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___4 {
	struct ip_ra_chain___4 *next;
	struct sock___18 *sk;
	union {
		void (*destructor)(struct sock___18 *);
		struct sock___18 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___17;

struct fib_lookup_arg___17;

struct fib_rules_ops___17 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___17 *, struct flowi *, int, struct fib_lookup_arg___17 *);
	bool (*suppress)(struct fib_rule___17 *, int, struct fib_lookup_arg___17 *);
	int (*match)(struct fib_rule___17 *, struct flowi *, int);
	int (*configure)(struct fib_rule___17 *, struct sk_buff___26 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___17 *);
	int (*compare)(struct fib_rule___17 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___17 *, struct sk_buff___26 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___17 *);
	void (*flush_cache)(struct fib_rules_ops___17 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___141 *owner;
	struct net___30 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___2 {
	u32 (*ssthresh)(struct sock___18 *);
	void (*cong_avoid)(struct sock___18 *, u32, u32);
	void (*set_state)(struct sock___18 *, u8);
	void (*cwnd_event)(struct sock___18 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___18 *, u32);
	void (*pkts_acked)(struct sock___18 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___18 *);
	void (*cong_control)(struct sock___18 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___18 *);
	u32 (*sndbuf_expand)(struct sock___18 *);
	size_t (*get_info)(struct sock___18 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___141 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___18 *);
	void (*release)(struct sock___18 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___17 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___30 *);
	int (*fib_dump)(struct net___30 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___141 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___4;

struct dst_entry___17 {
	struct net_device___3 *dev;
	struct dst_ops___29 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___26 *);
	int (*output)(struct net___30 *, struct sock___18 *, struct sk_buff___26 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___4 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___17;

struct neigh_parms___17;

struct neigh_ops___17;

struct neighbour___17 {
	struct neighbour___17 *next;
	struct neigh_table___17 *tbl;
	struct neigh_parms___17 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___24 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___17 *, struct sk_buff___26 *);
	const struct neigh_ops___17 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___3 *dev;
	u8 primary_key[0];
};

struct nf_hook_state;

typedef unsigned int nf_hookfn(void *, struct sk_buff___26 *, const struct nf_hook_state *);

struct nf_hook_entry {
	nf_hookfn *hook;
	void *priv;
};

struct nf_hook_entries {
	u16 num_hook_entries;
	struct nf_hook_entry hooks[0];
};

struct pernet_operations___3 {
	struct list_head list;
	int (*init)(struct net___30 *);
	void (*pre_exit)(struct net___30 *);
	void (*exit)(struct net___30 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___24 {
	int (*ieee_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___3 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___3 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___3 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___3 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___3 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___3 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___3 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___3 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___3 *);
	u8 (*setstate)(struct net_device___3 *, u8);
	void (*getpermhwaddr)(struct net_device___3 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___3 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___3 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___3 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___3 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___3 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___3 *, int, u8 *);
	void (*setpfccfg)(struct net_device___3 *, int, u8);
	void (*getpfccfg)(struct net_device___3 *, int, u8 *);
	u8 (*setall)(struct net_device___3 *);
	u8 (*getcap)(struct net_device___3 *, int, u8 *);
	int (*getnumtcs)(struct net_device___3 *, int, u8 *);
	int (*setnumtcs)(struct net_device___3 *, int, u8);
	u8 (*getpfcstate)(struct net_device___3 *);
	void (*setpfcstate)(struct net_device___3 *, u8);
	void (*getbcncfg)(struct net_device___3 *, int, u32 *);
	void (*setbcncfg)(struct net_device___3 *, int, u32);
	void (*getbcnrp)(struct net_device___3 *, int, u8 *);
	void (*setbcnrp)(struct net_device___3 *, int, u8);
	int (*setapp)(struct net_device___3 *, u8, u16, u8);
	int (*getapp)(struct net_device___3 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___3 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___3 *, int, u8);
	u8 (*getdcbx)(struct net_device___3 *);
	u8 (*setdcbx)(struct net_device___3 *, u8);
	int (*peer_getappinfo)(struct net_device___3 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___3 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___3 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___3 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___3 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___3 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___24 {
	struct net_device___3 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___24 {
	struct net_device___3 *dev;
};

struct xdp_buff___24 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___24 *rxq;
	struct xdp_txq_info___24 *txq;
	u32 frame_sz;
};

struct xdp_frame___24 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___3 *dev_rx;
};

struct netlink_callback___24 {
	struct sk_buff___26 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___26 *, struct netlink_callback___24 *);
	int (*done)(struct netlink_callback___24 *);
	void *data;
	struct module___141 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___24 {
	int (*create)(struct sk_buff___26 *, struct net_device___3 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___26 *, unsigned char *);
	int (*cache)(const struct neighbour___17 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___3 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___26 *);
};

struct netdev_queue___24 {
	struct net_device___3 *dev;
	struct Qdisc___24 *qdisc;
	struct Qdisc___24 *qdisc_sleeping;
	struct kobject___143 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___3 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___24 {
	struct sk_buff___26 *head;
	struct sk_buff___26 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___24;

struct Qdisc___24 {
	int (*enqueue)(struct sk_buff___26 *, struct Qdisc___24 *, struct sk_buff___26 **);
	struct sk_buff___26 * (*dequeue)(struct Qdisc___24 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___24 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___24 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___24 gso_skb;
	struct qdisc_skb_head___24 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___24 *next_sched;
	struct sk_buff_head___24 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___24 {
	struct xdp_rxq_info___24 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___143 kobj;
	struct net_device___3 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___24 {
	enum net_device_path_type type;
	const struct net_device___3 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___24 = 0,
				DEV_PATH_BR_VLAN_TAG___24 = 1,
				DEV_PATH_BR_VLAN_UNTAG___24 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___24 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___24 {
	const struct net_device___3 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___24 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___24 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___24 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___24 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___26 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___24 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___3 *dev;
	const char *name;
};

struct net_device_ops___24 {
	int (*ndo_init)(struct net_device___3 *);
	void (*ndo_uninit)(struct net_device___3 *);
	int (*ndo_open)(struct net_device___3 *);
	int (*ndo_stop)(struct net_device___3 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___26 *, struct net_device___3 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___26 *, struct net_device___3 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___3 *, struct sk_buff___26 *, struct net_device___3 *);
	void (*ndo_change_rx_flags)(struct net_device___3 *, int);
	void (*ndo_set_rx_mode)(struct net_device___3 *);
	int (*ndo_set_mac_address)(struct net_device___3 *, void *);
	int (*ndo_validate_addr)(struct net_device___3 *);
	int (*ndo_do_ioctl)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___3 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___3 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___3 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___3 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___3 *, int);
	int (*ndo_neigh_setup)(struct net_device___3 *, struct neigh_parms___17 *);
	void (*ndo_tx_timeout)(struct net_device___3 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___3 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___3 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___3 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___3 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___3 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___3 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___3 *);
	int (*ndo_netpoll_setup)(struct net_device___3 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___3 *);
	int (*ndo_set_vf_mac)(struct net_device___3 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___3 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___3 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___3 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___3 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___3 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___3 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___3 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___3 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___3 *, int, struct sk_buff___26 *);
	int (*ndo_get_vf_guid)(struct net_device___3 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___3 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___3 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___3 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___3 *);
	int (*ndo_fcoe_disable)(struct net_device___3 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___3 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___3 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___3 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___3 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___3 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___3 *, const struct sk_buff___26 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___3 *, struct net_device___3 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___3 *, struct net_device___3 *);
	struct net_device___3 * (*ndo_get_xmit_slave)(struct net_device___3 *, struct sk_buff___26 *, bool);
	struct net_device___3 * (*ndo_sk_get_lower_dev)(struct net_device___3 *, struct sock___18 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___3 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___3 *, struct neighbour___17 *);
	void (*ndo_neigh_destroy)(struct net_device___3 *, struct neighbour___17 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___26 *, struct netlink_callback___24 *, struct net_device___3 *, struct net_device___3 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___26 *, struct nlattr **, struct net_device___3 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___3 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___26 *, u32, u32, struct net_device___3 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___3 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___3 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___3 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___3 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___3 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___3 *, struct net_device___3 *);
	void (*ndo_dfwd_del_station)(struct net_device___3 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___3 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___3 *);
	int (*ndo_change_proto_down)(struct net_device___3 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___3 *, struct sk_buff___26 *);
	void (*ndo_set_rx_headroom)(struct net_device___3 *, int);
	int (*ndo_bpf)(struct net_device___3 *, struct netdev_bpf___24 *);
	int (*ndo_xdp_xmit)(struct net_device___3 *, int, struct xdp_frame___24 **, u32);
	struct net_device___3 * (*ndo_xdp_get_xmit_slave)(struct net_device___3 *, struct xdp_buff___24 *);
	int (*ndo_xsk_wakeup)(struct net_device___3 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___3 *);
	int (*ndo_tunnel_ctl)(struct net_device___3 *, struct ip_tunnel_parm *, int);
	struct net_device___3 * (*ndo_get_peer_dev)(struct net_device___3 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___24 *, struct net_device_path___24 *);
};

struct neigh_parms___17 {
	possible_net_t___24 net;
	struct net_device___3 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___17 *);
	struct neigh_table___17 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___2 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___3 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___3 *);
	void (*get_regs)(struct net_device___3 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___3 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___3 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___3 *);
	void (*set_msglevel)(struct net_device___3 *, u32);
	int (*nway_reset)(struct net_device___3 *);
	u32 (*get_link)(struct net_device___3 *);
	int (*get_link_ext_state)(struct net_device___3 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___3 *);
	int (*get_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___3 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___3 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___3 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___3 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___3 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___3 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___3 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___3 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___3 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___3 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___3 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___3 *);
	void (*complete)(struct net_device___3 *);
	u32 (*get_priv_flags)(struct net_device___3 *);
	int (*set_priv_flags)(struct net_device___3 *, u32);
	int (*get_sset_count)(struct net_device___3 *, int);
	int (*get_rxnfc)(struct net_device___3 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___3 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___3 *, struct ethtool_flash *);
	int (*reset)(struct net_device___3 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___3 *);
	u32 (*get_rxfh_indir_size)(struct net_device___3 *);
	int (*get_rxfh)(struct net_device___3 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___3 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___3 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___3 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___3 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___3 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___3 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___3 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___3 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___3 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___3 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___3 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___3 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___3 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___3 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___3 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___3 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___3 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___3 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___3 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___3 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___3 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___3 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___3 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___3 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___3 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___3 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___3 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___3 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___3 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___17 {
	u32 (*l3mdev_fib_table)(const struct net_device___3 *);
	struct sk_buff___26 * (*l3mdev_l3_rcv)(struct net_device___3 *, struct sk_buff___26 *, u16);
	struct sk_buff___26 * (*l3mdev_l3_out)(struct net_device___3 *, struct sock___18 *, struct sk_buff___26 *, u16);
	struct dst_entry___17 * (*l3mdev_link_scope_lookup)(const struct net_device___3 *, struct flowi6 *);
};

struct ndisc_ops___7 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___3 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___3 *, struct neighbour___17 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___3 *, u8, struct neighbour___17 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___3 *, struct sk_buff___26 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___30 *, struct net_device___3 *, const struct prefix_info *, struct inet6_dev___7 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___7;

struct inet6_dev___7 {
	struct net_device___3 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___7 *mc_list;
	struct ifmcaddr6___7 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___24 mc_query_queue;
	struct sk_buff_head___24 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___17 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___24;

struct tcf_block___24;

struct mini_Qdisc___24 {
	struct tcf_proto___24 *filter_list;
	struct tcf_block___24 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___24 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___3 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___3 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___30 *, struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___3 *, struct list_head *);
	size_t (*get_size)(const struct net_device___3 *);
	int (*fill_info)(struct sk_buff___26 *, const struct net_device___3 *);
	size_t (*get_xstats_size)(const struct net_device___3 *);
	int (*fill_xstats)(struct sk_buff___26 *, const struct net_device___3 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___3 *, struct net_device___3 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___3 *, const struct net_device___3 *);
	int (*fill_slave_info)(struct sk_buff___26 *, const struct net_device___3 *, const struct net_device___3 *);
	struct net___30 * (*get_link_net)(const struct net_device___3 *);
	size_t (*get_linkxstats_size)(const struct net_device___3 *, int);
	int (*fill_linkxstats)(struct sk_buff___26 *, const struct net_device___3 *, int *, int);
};

struct nf_hook_state {
	u8 hook;
	u8 pf;
	struct net_device___3 *in;
	struct net_device___3 *out;
	struct sock___18 *sk;
	struct net___30 *net;
	int (*okfn)(struct net___30 *, struct sock___18 *, struct sk_buff___26 *);
};

enum nf_hook_ops_type {
	NF_HOOK_OP_UNDEFINED = 0,
	NF_HOOK_OP_NF_TABLES = 1,
};

struct nf_hook_ops {
	nf_hookfn *hook;
	struct net_device___3 *dev;
	void *priv;
	u8 pf;
	enum nf_hook_ops_type hook_ops_type: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	unsigned int hooknum;
	int priority;
};

enum nf_ip_hook_priorities {
	NF_IP_PRI_FIRST = 2147483648,
	NF_IP_PRI_RAW_BEFORE_DEFRAG = 4294966846,
	NF_IP_PRI_CONNTRACK_DEFRAG = 4294966896,
	NF_IP_PRI_RAW = 4294966996,
	NF_IP_PRI_SELINUX_FIRST = 4294967071,
	NF_IP_PRI_CONNTRACK = 4294967096,
	NF_IP_PRI_MANGLE = 4294967146,
	NF_IP_PRI_NAT_DST = 4294967196,
	NF_IP_PRI_FILTER = 0,
	NF_IP_PRI_SECURITY = 50,
	NF_IP_PRI_NAT_SRC = 100,
	NF_IP_PRI_SELINUX_LAST = 225,
	NF_IP_PRI_CONNTRACK_HELPER = 300,
	NF_IP_PRI_CONNTRACK_CONFIRM = 2147483647,
	NF_IP_PRI_LAST = 2147483647,
};

enum nf_ip6_hook_priorities {
	NF_IP6_PRI_FIRST = 2147483648,
	NF_IP6_PRI_RAW_BEFORE_DEFRAG = 4294966846,
	NF_IP6_PRI_CONNTRACK_DEFRAG = 4294966896,
	NF_IP6_PRI_RAW = 4294966996,
	NF_IP6_PRI_SELINUX_FIRST = 4294967071,
	NF_IP6_PRI_CONNTRACK = 4294967096,
	NF_IP6_PRI_MANGLE = 4294967146,
	NF_IP6_PRI_NAT_DST = 4294967196,
	NF_IP6_PRI_FILTER = 0,
	NF_IP6_PRI_SECURITY = 50,
	NF_IP6_PRI_NAT_SRC = 100,
	NF_IP6_PRI_SELINUX_LAST = 225,
	NF_IP6_PRI_CONNTRACK_HELPER = 300,
	NF_IP6_PRI_LAST = 2147483647,
};

struct gnet_dump___24 {
	spinlock_t *lock;
	struct sk_buff___26 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___24;

struct Qdisc_ops___24 {
	struct Qdisc_ops___24 *next;
	const struct Qdisc_class_ops___24 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___26 *, struct Qdisc___24 *, struct sk_buff___26 **);
	struct sk_buff___26 * (*dequeue)(struct Qdisc___24 *);
	struct sk_buff___26 * (*peek)(struct Qdisc___24 *);
	int (*init)(struct Qdisc___24 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___24 *);
	void (*destroy)(struct Qdisc___24 *);
	int (*change)(struct Qdisc___24 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___24 *);
	int (*change_tx_queue_len)(struct Qdisc___24 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___24 *, unsigned int);
	int (*dump)(struct Qdisc___24 *, struct sk_buff___26 *);
	int (*dump_stats)(struct Qdisc___24 *, struct gnet_dump___24 *);
	void (*ingress_block_set)(struct Qdisc___24 *, u32);
	void (*egress_block_set)(struct Qdisc___24 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___24 *);
	u32 (*egress_block_get)(struct Qdisc___24 *);
	struct module___141 *owner;
};

struct Qdisc_class_ops___24 {
	unsigned int flags;
	struct netdev_queue___24 * (*select_queue)(struct Qdisc___24 *, struct tcmsg *);
	int (*graft)(struct Qdisc___24 *, long unsigned int, struct Qdisc___24 *, struct Qdisc___24 **, struct netlink_ext_ack *);
	struct Qdisc___24 * (*leaf)(struct Qdisc___24 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___24 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___24 *, u32);
	int (*change)(struct Qdisc___24 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___24 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___24 *, struct qdisc_walker *);
	struct tcf_block___24 * (*tcf_block)(struct Qdisc___24 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___24 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___24 *, long unsigned int);
	int (*dump)(struct Qdisc___24 *, long unsigned int, struct sk_buff___26 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___24 *, long unsigned int, struct gnet_dump___24 *);
};

struct tcf_chain___24;

struct tcf_block___24 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___30 *net;
	struct Qdisc___24 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___24 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___24;

struct tcf_proto_ops___24;

struct tcf_proto___24 {
	struct tcf_proto___24 *next;
	void *root;
	int (*classify)(struct sk_buff___26 *, const struct tcf_proto___24 *, struct tcf_result___24 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___24 *ops;
	struct tcf_chain___24 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___24 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___24 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___24 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___26 *, const struct tcf_proto___24 *, struct tcf_result___24 *);
	int (*init)(struct tcf_proto___24 *);
	void (*destroy)(struct tcf_proto___24 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___24 *, u32);
	void (*put)(struct tcf_proto___24 *, void *);
	int (*change)(struct net___30 *, struct sk_buff___26 *, struct tcf_proto___24 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___24 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___24 *);
	void (*walk)(struct tcf_proto___24 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___24 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___24 *, void *);
	void (*hw_del)(struct tcf_proto___24 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___30 *, struct tcf_chain___24 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___30 *, struct tcf_proto___24 *, void *, struct sk_buff___26 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___30 *, struct tcf_proto___24 *, void *, struct sk_buff___26 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___26 *, struct net___30 *, void *);
	struct module___141 *owner;
	int flags;
};

struct tcf_chain___24 {
	struct mutex filter_chain_lock;
	struct tcf_proto___24 *filter_chain;
	struct list_head list;
	struct tcf_block___24 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___24 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___17 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___24 *prog;
};

struct pneigh_entry___17;

struct neigh_hash_table___17;

struct neigh_table___17 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___3 *, __u32 *);
	bool (*key_eq)(const struct neighbour___17 *, const void *);
	int (*constructor)(struct neighbour___17 *);
	int (*pconstructor)(struct pneigh_entry___17 *);
	void (*pdestructor)(struct pneigh_entry___17 *);
	void (*proxy_redo)(struct sk_buff___26 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___3 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___17 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___24 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___17 *nht;
	struct pneigh_entry___17 **phash_buckets;
};

struct neigh_ops___17 {
	int family;
	void (*solicit)(struct neighbour___17 *, struct sk_buff___26 *);
	void (*error_report)(struct neighbour___17 *, struct sk_buff___26 *);
	int (*output)(struct neighbour___17 *, struct sk_buff___26 *);
	int (*connected_output)(struct neighbour___17 *, struct sk_buff___26 *);
};

struct pneigh_entry___17 {
	struct pneigh_entry___17 *next;
	possible_net_t___24 net;
	struct net_device___3 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___17 {
	struct neighbour___17 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___4 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___30 *, struct sock___18 *, struct sk_buff___26 *);
	int (*orig_input)(struct sk_buff___26 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___17 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___17 *ctarget;
	struct net___30 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___17 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___17 *rule;
	u32 table;
	int flags;
};

struct timewait_sock_ops___7;

struct proto___17 {
	void (*close)(struct sock___18 *, long int);
	int (*pre_connect)(struct sock___18 *, struct sockaddr *, int);
	int (*connect)(struct sock___18 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___18 *, int);
	struct sock___18 * (*accept)(struct sock___18 *, int, int *, bool);
	int (*ioctl)(struct sock___18 *, int, long unsigned int);
	int (*init)(struct sock___18 *);
	void (*destroy)(struct sock___18 *);
	void (*shutdown)(struct sock___18 *, int);
	int (*setsockopt)(struct sock___18 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___18 *, int, int, char *, int *);
	void (*keepalive)(struct sock___18 *, int);
	int (*compat_ioctl)(struct sock___18 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___18 *, struct msghdr___18 *, size_t);
	int (*recvmsg)(struct sock___18 *, struct msghdr___18 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___18 *, struct page___161 *, int, size_t, int);
	int (*bind)(struct sock___18 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___18 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___18 *, struct sk_buff___26 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___18 *);
	int (*hash)(struct sock___18 *);
	void (*unhash)(struct sock___18 *);
	void (*rehash)(struct sock___18 *);
	int (*get_port)(struct sock___18 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___18 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___18 *, int);
	bool (*sock_is_readable)(struct sock___18 *);
	void (*enter_memory_pressure)(struct sock___18 *);
	void (*leave_memory_pressure)(struct sock___18 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___7 *rsk_prot;
	struct timewait_sock_ops___7 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___141 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___18 *, int);
};

struct sock_reuseport___3 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___24 *prog;
	struct sock___18 *socks[0];
};

struct request_sock_ops___7 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___18 *, struct request_sock___8 *);
	void (*send_ack)(const struct sock___18 *, struct sk_buff___26 *, struct request_sock___8 *);
	void (*send_reset)(const struct sock___18 *, struct sk_buff___26 *);
	void (*destructor)(struct request_sock___8 *);
	void (*syn_ack_timeout)(const struct request_sock___8 *);
};

struct timewait_sock_ops___7 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___18 *, struct sock___18 *, void *);
	void (*twsk_destructor)(struct sock___18 *);
};

struct socket_alloc {
	struct socket___18 socket;
	struct inode___156 vfs_inode;
	long: 64;
};

struct ip_options {
	__be32 faddr;
	__be32 nexthop;
	unsigned char optlen;
	unsigned char srr;
	unsigned char rr;
	unsigned char ts;
	unsigned char is_strictroute: 1;
	unsigned char srr_is_hit: 1;
	unsigned char is_changed: 1;
	unsigned char rr_needaddr: 1;
	unsigned char ts_needtime: 1;
	unsigned char ts_needaddr: 1;
	long: 39;
	long: 64;
	unsigned char router_alert;
	unsigned char cipso;
	unsigned char __pad2;
	unsigned char __data[0];
};

struct ip_options_rcu {
	struct callback_head rcu;
	struct ip_options opt;
};

struct ipv6_opt_hdr;

struct ipv6_rt_hdr;

struct ipv6_txoptions {
	refcount_t refcnt;
	int tot_len;
	__u16 opt_flen;
	__u16 opt_nflen;
	struct ipv6_opt_hdr *hopopt;
	struct ipv6_opt_hdr *dst0opt;
	struct ipv6_rt_hdr *srcrt;
	struct ipv6_opt_hdr *dst1opt;
	struct callback_head rcu;
};

struct inet_cork {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___17 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full {
	struct inet_cork base;
	struct flowi fl;
};

struct ipv6_pinfo;

struct ip_mc_socklist;

struct inet_sock {
	struct sock___18 sk;
	struct ipv6_pinfo *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full cork;
};

struct in6_pktinfo {
	struct in6_addr ipi6_addr;
	int ipi6_ifindex;
};

struct inet6_cork {
	struct ipv6_txoptions *opt;
	u8 hop_limit;
	u8 tclass;
};

struct ipv6_mc_socklist;

struct ipv6_ac_socklist;

struct ipv6_fl_socklist;

struct ipv6_pinfo {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___26 *pktoptions;
	struct sk_buff___26 *rxpmtu;
	struct inet6_cork cork;
};

struct tcphdr {
	__be16 source;
	__be16 dest;
	__be32 seq;
	__be32 ack_seq;
	__u16 res1: 4;
	__u16 doff: 4;
	__u16 fin: 1;
	__u16 syn: 1;
	__u16 rst: 1;
	__u16 psh: 1;
	__u16 ack: 1;
	__u16 urg: 1;
	__u16 ece: 1;
	__u16 cwr: 1;
	long: 47;
	long: 64;
	__be16 window;
	__sum16 check;
	__be16 urg_ptr;
};

struct iphdr {
	__u8 ihl: 4;
	__u8 version: 4;
	__u8 tos;
	__be16 tot_len;
	__be16 id;
	__be16 frag_off;
	__u8 ttl;
	__u8 protocol;
	__sum16 check;
	__be32 saddr;
	__be32 daddr;
};

struct ipv6_rt_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
};

struct ipv6_opt_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
};

struct ipv6hdr {
	__u8 priority: 4;
	__u8 version: 4;
	__u8 flow_lbl[3];
	__be16 payload_len;
	__u8 nexthdr;
	__u8 hop_limit;
	struct in6_addr saddr;
	struct in6_addr daddr;
};

struct udphdr {
	__be16 source;
	__be16 dest;
	__be16 len;
	__sum16 check;
};

struct inet6_skb_parm {
	int iif;
	__be16 ra;
	__u16 dst0;
	__u16 srcrt;
	__u16 dst1;
	__u16 lastopt;
	__u16 nhoff;
	__u16 flags;
	__u16 dsthao;
	__u16 frag_max_size;
	__u16 srhoff;
};

struct ip6_sf_socklist;

struct ipv6_mc_socklist {
	struct in6_addr addr;
	int ifindex;
	unsigned int sfmode;
	struct ipv6_mc_socklist *next;
	struct ip6_sf_socklist *sflist;
	struct callback_head rcu;
};

struct ipv6_ac_socklist {
	struct in6_addr acl_addr;
	int acl_ifindex;
	struct ipv6_ac_socklist *acl_next;
};

struct ip6_flowlabel;

struct ipv6_fl_socklist {
	struct ipv6_fl_socklist *next;
	struct ip6_flowlabel *fl;
	struct callback_head rcu;
};

struct ip6_sf_socklist {
	unsigned int sl_max;
	unsigned int sl_count;
	struct callback_head rcu;
	struct in6_addr sl_addr[0];
};

struct ifmcaddr6___7 {
	struct in6_addr mca_addr;
	struct inet6_dev___7 *idev;
	struct ifmcaddr6___7 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel {
	struct ip6_flowlabel *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___137 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___30 *fl_net;
};

struct inet_skb_parm {
	int iif;
	struct ip_options opt;
	u16 flags;
	u16 frag_max_size;
};

struct tty_operations___13 {
	struct tty_struct___12 * (*lookup)(struct tty_driver___13 *, struct file___156 *, int);
	int (*install)(struct tty_driver___13 *, struct tty_struct___12 *);
	void (*remove)(struct tty_driver___13 *, struct tty_struct___12 *);
	int (*open)(struct tty_struct___12 *, struct file___156 *);
	void (*close)(struct tty_struct___12 *, struct file___156 *);
	void (*shutdown)(struct tty_struct___12 *);
	void (*cleanup)(struct tty_struct___12 *);
	int (*write)(struct tty_struct___12 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___12 *, unsigned char);
	void (*flush_chars)(struct tty_struct___12 *);
	unsigned int (*write_room)(struct tty_struct___12 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___12 *);
	int (*ioctl)(struct tty_struct___12 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___12 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___12 *, struct ktermios *);
	void (*throttle)(struct tty_struct___12 *);
	void (*unthrottle)(struct tty_struct___12 *);
	void (*stop)(struct tty_struct___12 *);
	void (*start)(struct tty_struct___12 *);
	void (*hangup)(struct tty_struct___12 *);
	int (*break_ctl)(struct tty_struct___12 *, int);
	void (*flush_buffer)(struct tty_struct___12 *);
	void (*set_ldisc)(struct tty_struct___12 *);
	void (*wait_until_sent)(struct tty_struct___12 *, int);
	void (*send_xchar)(struct tty_struct___12 *, char);
	int (*tiocmget)(struct tty_struct___12 *);
	int (*tiocmset)(struct tty_struct___12 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___12 *, struct winsize *);
	int (*get_icount)(struct tty_struct___12 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___12 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___12 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___12 *, struct seq_file___134 *);
	int (*poll_init)(struct tty_driver___13 *, int, char *);
	int (*poll_get_char)(struct tty_driver___13 *, int);
	void (*poll_put_char)(struct tty_driver___13 *, int, char);
	int (*proc_show)(struct seq_file___134 *, void *);
};

struct tty_driver___13 {
	int magic;
	struct kref kref;
	struct cdev___26 **cdevs;
	struct module___141 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___13 *other;
	struct tty_struct___12 **ttys;
	struct tty_port___13 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___13 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___12;

struct tty_port_client_operations___12;

struct tty_port___13 {
	struct tty_bufhead buf;
	struct tty_struct___12 *tty;
	struct tty_struct___12 *itty;
	const struct tty_port_operations___12 *ops;
	const struct tty_port_client_operations___12 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___12 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___12 *);
	void (*close)(struct tty_struct___12 *);
	void (*flush_buffer)(struct tty_struct___12 *);
	ssize_t (*read)(struct tty_struct___12 *, struct file___156 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___12 *, struct file___156 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___12 *, struct file___156 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___12 *, struct file___156 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___12 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___12 *, struct file___156 *, struct poll_table_struct___97 *);
	int (*hangup)(struct tty_struct___12 *);
	void (*receive_buf)(struct tty_struct___12 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___12 *);
	void (*dcd_change)(struct tty_struct___12 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___12 *, const unsigned char *, const char *, int);
	struct module___141 *owner;
};

struct tty_ldisc___12 {
	struct tty_ldisc_ops___12 *ops;
	struct tty_struct___12 *tty;
};

struct tty_port_operations___12 {
	int (*carrier_raised)(struct tty_port___13 *);
	void (*dtr_rts)(struct tty_port___13 *, int);
	void (*shutdown)(struct tty_port___13 *);
	int (*activate)(struct tty_port___13 *, struct tty_struct___12 *);
	void (*destruct)(struct tty_port___13 *);
};

struct tty_port_client_operations___12 {
	int (*receive_buf)(struct tty_port___13 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___13 *);
};

struct tty_file_private {
	struct tty_struct___12 *tty;
	struct file___156 *file;
	struct list_head list;
};

struct netlbl_lsm_cache {
	refcount_t refcount;
	void (*free)(const void *);
	void *data;
};

struct netlbl_lsm_catmap {
	u32 startbit;
	u64 bitmap[4];
	struct netlbl_lsm_catmap *next;
};

struct netlbl_lsm_secattr {
	u32 flags;
	u32 type;
	char *domain;
	struct netlbl_lsm_cache *cache;
	struct {
		struct {
			struct netlbl_lsm_catmap *cat;
			u32 lvl;
		} mls;
		struct lsmblob lsmblob;
	} attr;
};

struct dccp_hdr {
	__be16 dccph_sport;
	__be16 dccph_dport;
	__u8 dccph_doff;
	__u8 dccph_cscov: 4;
	__u8 dccph_ccval: 4;
	long: 44;
	__sum16 dccph_checksum;
	__u8 dccph_x: 1;
	__u8 dccph_type: 4;
	__u8 dccph_reserved: 3;
	long: 5;
	long: 64;
	__u8 dccph_seq2;
	__be16 dccph_seq;
};

enum dccp_state {
	DCCP_OPEN = 1,
	DCCP_REQUESTING = 2,
	DCCP_LISTEN = 10,
	DCCP_RESPOND = 3,
	DCCP_ACTIVE_CLOSEREQ = 4,
	DCCP_PASSIVE_CLOSE = 8,
	DCCP_CLOSING = 11,
	DCCP_TIME_WAIT = 6,
	DCCP_CLOSED = 7,
	DCCP_NEW_SYN_RECV = 12,
	DCCP_PARTOPEN = 13,
	DCCP_PASSIVE_CLOSEREQ = 14,
	DCCP_MAX_STATES = 15,
};

typedef __s32 sctp_assoc_t;

enum sctp_msg_flags {
	MSG_NOTIFICATION = 32768,
};

struct sctp_initmsg {
	__u16 sinit_num_ostreams;
	__u16 sinit_max_instreams;
	__u16 sinit_max_attempts;
	__u16 sinit_max_init_timeo;
};

struct sctp_sndrcvinfo {
	__u16 sinfo_stream;
	__u16 sinfo_ssn;
	__u16 sinfo_flags;
	__u32 sinfo_ppid;
	__u32 sinfo_context;
	__u32 sinfo_timetolive;
	__u32 sinfo_tsn;
	__u32 sinfo_cumtsn;
	sctp_assoc_t sinfo_assoc_id;
};

struct sctp_rtoinfo {
	sctp_assoc_t srto_assoc_id;
	__u32 srto_initial;
	__u32 srto_max;
	__u32 srto_min;
};

struct sctp_assocparams {
	sctp_assoc_t sasoc_assoc_id;
	__u16 sasoc_asocmaxrxt;
	__u16 sasoc_number_peer_destinations;
	__u32 sasoc_peer_rwnd;
	__u32 sasoc_local_rwnd;
	__u32 sasoc_cookie_life;
};

struct sctp_paddrparams {
	sctp_assoc_t spp_assoc_id;
	struct __kernel_sockaddr_storage spp_address;
	__u32 spp_hbinterval;
	__u16 spp_pathmaxrxt;
	__u32 spp_pathmtu;
	__u32 spp_sackdelay;
	__u32 spp_flags;
	__u32 spp_ipv6_flowlabel;
	__u8 spp_dscp;
	char: 8;
} __attribute__((packed));

struct sctphdr {
	__be16 source;
	__be16 dest;
	__be32 vtag;
	__le32 checksum;
};

struct sctp_chunkhdr {
	__u8 type;
	__u8 flags;
	__be16 length;
};

enum sctp_cid {
	SCTP_CID_DATA = 0,
	SCTP_CID_INIT = 1,
	SCTP_CID_INIT_ACK = 2,
	SCTP_CID_SACK = 3,
	SCTP_CID_HEARTBEAT = 4,
	SCTP_CID_HEARTBEAT_ACK = 5,
	SCTP_CID_ABORT = 6,
	SCTP_CID_SHUTDOWN = 7,
	SCTP_CID_SHUTDOWN_ACK = 8,
	SCTP_CID_ERROR = 9,
	SCTP_CID_COOKIE_ECHO = 10,
	SCTP_CID_COOKIE_ACK = 11,
	SCTP_CID_ECN_ECNE = 12,
	SCTP_CID_ECN_CWR = 13,
	SCTP_CID_SHUTDOWN_COMPLETE = 14,
	SCTP_CID_AUTH = 15,
	SCTP_CID_I_DATA = 64,
	SCTP_CID_FWD_TSN = 192,
	SCTP_CID_ASCONF = 193,
	SCTP_CID_I_FWD_TSN = 194,
	SCTP_CID_ASCONF_ACK = 128,
	SCTP_CID_RECONF = 130,
	SCTP_CID_PAD = 132,
};

struct sctp_paramhdr {
	__be16 type;
	__be16 length;
};

enum sctp_param {
	SCTP_PARAM_HEARTBEAT_INFO = 256,
	SCTP_PARAM_IPV4_ADDRESS = 1280,
	SCTP_PARAM_IPV6_ADDRESS = 1536,
	SCTP_PARAM_STATE_COOKIE = 1792,
	SCTP_PARAM_UNRECOGNIZED_PARAMETERS = 2048,
	SCTP_PARAM_COOKIE_PRESERVATIVE = 2304,
	SCTP_PARAM_HOST_NAME_ADDRESS = 2816,
	SCTP_PARAM_SUPPORTED_ADDRESS_TYPES = 3072,
	SCTP_PARAM_ECN_CAPABLE = 128,
	SCTP_PARAM_RANDOM = 640,
	SCTP_PARAM_CHUNKS = 896,
	SCTP_PARAM_HMAC_ALGO = 1152,
	SCTP_PARAM_SUPPORTED_EXT = 2176,
	SCTP_PARAM_FWD_TSN_SUPPORT = 192,
	SCTP_PARAM_ADD_IP = 448,
	SCTP_PARAM_DEL_IP = 704,
	SCTP_PARAM_ERR_CAUSE = 960,
	SCTP_PARAM_SET_PRIMARY = 1216,
	SCTP_PARAM_SUCCESS_REPORT = 1472,
	SCTP_PARAM_ADAPTATION_LAYER_IND = 1728,
	SCTP_PARAM_RESET_OUT_REQUEST = 3328,
	SCTP_PARAM_RESET_IN_REQUEST = 3584,
	SCTP_PARAM_RESET_TSN_REQUEST = 3840,
	SCTP_PARAM_RESET_RESPONSE = 4096,
	SCTP_PARAM_RESET_ADD_OUT_STREAMS = 4352,
	SCTP_PARAM_RESET_ADD_IN_STREAMS = 4608,
};

struct sctp_datahdr {
	__be32 tsn;
	__be16 stream;
	__be16 ssn;
	__u32 ppid;
	__u8 payload[0];
};

struct sctp_idatahdr {
	__be32 tsn;
	__be16 stream;
	__be16 reserved;
	__be32 mid;
	union {
		__u32 ppid;
		__be32 fsn;
	};
	__u8 payload[0];
};

struct sctp_inithdr {
	__be32 init_tag;
	__be32 a_rwnd;
	__be16 num_outbound_streams;
	__be16 num_inbound_streams;
	__be32 initial_tsn;
	__u8 params[0];
};

struct sctp_init_chunk {
	struct sctp_chunkhdr chunk_hdr;
	struct sctp_inithdr init_hdr;
};

struct sctp_ipv4addr_param {
	struct sctp_paramhdr param_hdr;
	struct in_addr addr;
};

struct sctp_ipv6addr_param {
	struct sctp_paramhdr param_hdr;
	struct in6_addr addr;
};

struct sctp_cookie_preserve_param {
	struct sctp_paramhdr param_hdr;
	__be32 lifespan_increment;
};

struct sctp_hostname_param {
	struct sctp_paramhdr param_hdr;
	uint8_t hostname[0];
};

struct sctp_supported_addrs_param {
	struct sctp_paramhdr param_hdr;
	__be16 types[0];
};

struct sctp_adaptation_ind_param {
	struct sctp_paramhdr param_hdr;
	__be32 adaptation_ind;
};

struct sctp_supported_ext_param {
	struct sctp_paramhdr param_hdr;
	__u8 chunks[0];
};

struct sctp_random_param {
	struct sctp_paramhdr param_hdr;
	__u8 random_val[0];
};

struct sctp_chunks_param {
	struct sctp_paramhdr param_hdr;
	__u8 chunks[0];
};

struct sctp_hmac_algo_param {
	struct sctp_paramhdr param_hdr;
	__be16 hmac_ids[0];
};

struct sctp_cookie_param {
	struct sctp_paramhdr p;
	__u8 body[0];
};

struct sctp_gap_ack_block {
	__be16 start;
	__be16 end;
};

union sctp_sack_variable {
	struct sctp_gap_ack_block gab;
	__be32 dup;
};

struct sctp_sackhdr {
	__be32 cum_tsn_ack;
	__be32 a_rwnd;
	__be16 num_gap_ack_blocks;
	__be16 num_dup_tsns;
	union sctp_sack_variable variable[0];
};

struct sctp_heartbeathdr {
	struct sctp_paramhdr info;
};

struct sctp_shutdownhdr {
	__be32 cum_tsn_ack;
};

struct sctp_errhdr {
	__be16 cause;
	__be16 length;
	__u8 variable[0];
};

struct sctp_ecnehdr {
	__be32 lowest_tsn;
};

struct sctp_cwrhdr {
	__be32 lowest_tsn;
};

struct sctp_fwdtsn_skip {
	__be16 stream;
	__be16 ssn;
};

struct sctp_fwdtsn_hdr {
	__be32 new_cum_tsn;
	struct sctp_fwdtsn_skip skip[0];
};

struct sctp_ifwdtsn_skip {
	__be16 stream;
	__u8 reserved;
	__u8 flags;
	__be32 mid;
};

struct sctp_ifwdtsn_hdr {
	__be32 new_cum_tsn;
	struct sctp_ifwdtsn_skip skip[0];
};

struct sctp_addip_param {
	struct sctp_paramhdr param_hdr;
	__be32 crr_id;
};

struct sctp_addiphdr {
	__be32 serial;
	__u8 params[0];
};

struct sctp_authhdr {
	__be16 shkey_id;
	__be16 hmac_id;
	__u8 hmac[0];
};

union sctp_addr {
	struct sockaddr_in v4;
	struct sockaddr_in6 v6;
	struct sockaddr sa;
};

struct sctp_cookie {
	__u32 my_vtag;
	__u32 peer_vtag;
	__u32 my_ttag;
	__u32 peer_ttag;
	ktime_t expiration;
	__u16 sinit_num_ostreams;
	__u16 sinit_max_instreams;
	__u32 initial_tsn;
	union sctp_addr peer_addr;
	__u16 my_port;
	__u8 prsctp_capable;
	__u8 padding;
	__u32 adaptation_ind;
	__u8 auth_random[36];
	__u8 auth_hmacs[10];
	__u8 auth_chunks[20];
	__u32 raw_addr_list_len;
	struct sctp_init_chunk peer_init[0];
};

struct sctp_tsnmap {
	long unsigned int *tsn_map;
	__u32 base_tsn;
	__u32 cumulative_tsn_ack_point;
	__u32 max_tsn_seen;
	__u16 len;
	__u16 pending_data;
	__u16 num_dup_tsns;
	__be32 dup_tsns[16];
};

struct sctp_inithdr_host {
	__u32 init_tag;
	__u32 a_rwnd;
	__u16 num_outbound_streams;
	__u16 num_inbound_streams;
	__u32 initial_tsn;
};

enum sctp_state {
	SCTP_STATE_CLOSED = 0,
	SCTP_STATE_COOKIE_WAIT = 1,
	SCTP_STATE_COOKIE_ECHOED = 2,
	SCTP_STATE_ESTABLISHED = 3,
	SCTP_STATE_SHUTDOWN_PENDING = 4,
	SCTP_STATE_SHUTDOWN_SENT = 5,
	SCTP_STATE_SHUTDOWN_RECEIVED = 6,
	SCTP_STATE_SHUTDOWN_ACK_SENT = 7,
};

struct sctp_stream_out_ext;

struct sctp_stream_out {
	union {
		__u32 mid;
		__u16 ssn;
	};
	__u32 mid_uo;
	struct sctp_stream_out_ext *ext;
	__u8 state;
};

struct sctp_stream_in {
	union {
		__u32 mid;
		__u16 ssn;
	};
	__u32 mid_uo;
	__u32 fsn;
	__u32 fsn_uo;
	char pd_mode;
	char pd_mode_uo;
};

struct sctp_stream_interleave;

struct sctp_stream {
	struct {
		struct __genradix tree;
		struct sctp_stream_out type[0];
	} out;
	struct {
		struct __genradix tree;
		struct sctp_stream_in type[0];
	} in;
	__u16 outcnt;
	__u16 incnt;
	struct sctp_stream_out *out_curr;
	union {
		struct {
			struct list_head prio_list;
		};
		struct {
			struct list_head rr_list;
			struct sctp_stream_out_ext *rr_next;
		};
	};
	struct sctp_stream_interleave *si;
};

struct sctp_sched_ops;

struct sctp_association;

struct sctp_outq {
	struct sctp_association *asoc;
	struct list_head out_chunk_list;
	struct sctp_sched_ops *sched;
	unsigned int out_qlen;
	unsigned int error;
	struct list_head control_chunk_list;
	struct list_head sacked;
	struct list_head retransmit;
	struct list_head abandoned;
	__u32 outstanding_bytes;
	char fast_rtx;
	char cork;
};

struct sctp_ulpq {
	char pd_mode;
	struct sctp_association *asoc;
	struct sk_buff_head___24 reasm;
	struct sk_buff_head___24 reasm_uo;
	struct sk_buff_head___24 lobby;
};

struct sctp_priv_assoc_stats {
	struct __kernel_sockaddr_storage obs_rto_ipaddr;
	__u64 max_obs_rto;
	__u64 isacks;
	__u64 osacks;
	__u64 opackets;
	__u64 ipackets;
	__u64 rtxchunks;
	__u64 outofseqtsns;
	__u64 idupchunks;
	__u64 gapcnt;
	__u64 ouodchunks;
	__u64 iuodchunks;
	__u64 oodchunks;
	__u64 iodchunks;
	__u64 octrlchunks;
	__u64 ictrlchunks;
};

struct sctp_transport;

struct sctp_auth_bytes;

struct sctp_shared_key;

struct sctp_association {
	struct sctp_ep_common base;
	struct list_head asocs;
	sctp_assoc_t assoc_id;
	struct sctp_endpoint *ep;
	struct sctp_cookie c;
	struct {
		struct list_head transport_addr_list;
		__u32 rwnd;
		__u16 transport_count;
		__u16 port;
		struct sctp_transport *primary_path;
		union sctp_addr primary_addr;
		struct sctp_transport *active_path;
		struct sctp_transport *retran_path;
		struct sctp_transport *last_sent_to;
		struct sctp_transport *last_data_from;
		struct sctp_tsnmap tsn_map;
		__be16 addip_disabled_mask;
		__u16 ecn_capable: 1;
		__u16 ipv4_address: 1;
		__u16 ipv6_address: 1;
		__u16 hostname_address: 1;
		__u16 asconf_capable: 1;
		__u16 prsctp_capable: 1;
		__u16 reconf_capable: 1;
		__u16 intl_capable: 1;
		__u16 auth_capable: 1;
		__u16 sack_needed: 1;
		__u16 sack_generation: 1;
		__u16 zero_window_announced: 1;
		long: 31;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
		__u32 sack_cnt;
		__u32 adaptation_ind;
		struct sctp_inithdr_host i;
		void *cookie;
		int cookie_len;
		__u32 addip_serial;
		struct sctp_random_param *peer_random;
		struct sctp_chunks_param *peer_chunks;
		struct sctp_hmac_algo_param *peer_hmacs;
	} peer;
	enum sctp_state state;
	int overall_error_count;
	ktime_t cookie_life;
	long unsigned int rto_initial;
	long unsigned int rto_max;
	long unsigned int rto_min;
	int max_burst;
	int max_retrans;
	__u16 pf_retrans;
	__u16 ps_retrans;
	__u16 max_init_attempts;
	__u16 init_retries;
	long unsigned int max_init_timeo;
	long unsigned int hbinterval;
	long unsigned int probe_interval;
	__be16 encap_port;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	__u8 pmtu_pending;
	__u32 pathmtu;
	__u32 param_flags;
	__u32 sackfreq;
	long unsigned int sackdelay;
	long unsigned int timeouts[12];
	struct timer_list timers[12];
	struct sctp_transport *shutdown_last_sent_to;
	struct sctp_transport *init_last_sent_to;
	int shutdown_retries;
	__u32 next_tsn;
	__u32 ctsn_ack_point;
	__u32 adv_peer_ack_point;
	__u32 highest_sacked;
	__u32 fast_recovery_exit;
	__u8 fast_recovery;
	__u16 unack_data;
	__u32 rtx_data_chunks;
	__u32 rwnd;
	__u32 a_rwnd;
	__u32 rwnd_over;
	__u32 rwnd_press;
	int sndbuf_used;
	atomic_t rmem_alloc;
	wait_queue_head_t wait;
	__u32 frag_point;
	__u32 user_frag;
	int init_err_counter;
	int init_cycle;
	__u16 default_stream;
	__u16 default_flags;
	__u32 default_ppid;
	__u32 default_context;
	__u32 default_timetolive;
	__u32 default_rcv_context;
	struct sctp_stream stream;
	struct sctp_outq outqueue;
	struct sctp_ulpq ulpq;
	__u32 last_ecne_tsn;
	__u32 last_cwr_tsn;
	int numduptsns;
	struct sctp_chunk *addip_last_asconf;
	struct list_head asconf_ack_list;
	struct list_head addip_chunk_list;
	__u32 addip_serial;
	int src_out_of_asoc_ok;
	union sctp_addr *asconf_addr_del_pending;
	struct sctp_transport *new_transport;
	struct list_head endpoint_shared_keys;
	struct sctp_auth_bytes *asoc_shared_key;
	struct sctp_shared_key *shkey;
	__u16 default_hmac_id;
	__u16 active_key_id;
	__u8 need_ecne: 1;
	__u8 temp: 1;
	__u8 pf_expose: 2;
	__u8 force_delay: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 strreset_enable;
	__u8 strreset_outstanding;
	__u32 strreset_outseq;
	__u32 strreset_inseq;
	__u32 strreset_result[2];
	struct sctp_chunk *strreset_chunk;
	struct sctp_priv_assoc_stats stats;
	int sent_cnt_removable;
	__u16 subscribe;
	__u64 abandoned_unsent[3];
	__u64 abandoned_sent[3];
	struct callback_head rcu;
};

struct sctp_auth_bytes {
	refcount_t refcnt;
	__u32 len;
	__u8 data[0];
};

struct sctp_shared_key {
	struct list_head key_list;
	struct sctp_auth_bytes *key;
	refcount_t refcnt;
	__u16 key_id;
	__u8 deactivated;
};

enum {
	SCTP_MAX_STREAM = 65535,
};

enum sctp_event_timeout {
	SCTP_EVENT_TIMEOUT_NONE = 0,
	SCTP_EVENT_TIMEOUT_T1_COOKIE = 1,
	SCTP_EVENT_TIMEOUT_T1_INIT = 2,
	SCTP_EVENT_TIMEOUT_T2_SHUTDOWN = 3,
	SCTP_EVENT_TIMEOUT_T3_RTX = 4,
	SCTP_EVENT_TIMEOUT_T4_RTO = 5,
	SCTP_EVENT_TIMEOUT_T5_SHUTDOWN_GUARD = 6,
	SCTP_EVENT_TIMEOUT_HEARTBEAT = 7,
	SCTP_EVENT_TIMEOUT_RECONF = 8,
	SCTP_EVENT_TIMEOUT_PROBE = 9,
	SCTP_EVENT_TIMEOUT_SACK = 10,
	SCTP_EVENT_TIMEOUT_AUTOCLOSE = 11,
};

enum {
	SCTP_MAX_DUP_TSNS = 16,
};

enum sctp_scope {
	SCTP_SCOPE_GLOBAL = 0,
	SCTP_SCOPE_PRIVATE = 1,
	SCTP_SCOPE_LINK = 2,
	SCTP_SCOPE_LOOPBACK = 3,
	SCTP_SCOPE_UNUSABLE = 4,
};

enum {
	SCTP_AUTH_HMAC_ID_RESERVED_0 = 0,
	SCTP_AUTH_HMAC_ID_SHA1 = 1,
	SCTP_AUTH_HMAC_ID_RESERVED_2 = 2,
	SCTP_AUTH_HMAC_ID_SHA256 = 3,
	__SCTP_AUTH_HMAC_MAX = 4,
};

struct sctp_ulpevent {
	struct sctp_association *asoc;
	struct sctp_chunk *chunk;
	unsigned int rmem_len;
	union {
		__u32 mid;
		__u16 ssn;
	};
	union {
		__u32 ppid;
		__u32 fsn;
	};
	__u32 tsn;
	__u32 cumtsn;
	__u16 stream;
	__u16 flags;
	__u16 msg_flags;
} __attribute__((packed));

union sctp_addr_param;

union sctp_params {
	void *v;
	struct sctp_paramhdr *p;
	struct sctp_cookie_preserve_param *life;
	struct sctp_hostname_param *dns;
	struct sctp_cookie_param *cookie;
	struct sctp_supported_addrs_param *sat;
	struct sctp_ipv4addr_param *v4;
	struct sctp_ipv6addr_param *v6;
	union sctp_addr_param *addr;
	struct sctp_adaptation_ind_param *aind;
	struct sctp_supported_ext_param *ext;
	struct sctp_random_param *random;
	struct sctp_chunks_param *chunks;
	struct sctp_hmac_algo_param *hmac_algo;
	struct sctp_addip_param *addip;
};

struct sctp_sender_hb_info;

struct sctp_signed_cookie;

struct sctp_datamsg;

struct sctp_chunk {
	struct list_head list;
	refcount_t refcnt;
	int sent_count;
	union {
		struct list_head transmitted_list;
		struct list_head stream_list;
	};
	struct list_head frag_list;
	struct sk_buff___26 *skb;
	union {
		struct sk_buff___26 *head_skb;
		struct sctp_shared_key *shkey;
	};
	union sctp_params param_hdr;
	union {
		__u8 *v;
		struct sctp_datahdr *data_hdr;
		struct sctp_inithdr *init_hdr;
		struct sctp_sackhdr *sack_hdr;
		struct sctp_heartbeathdr *hb_hdr;
		struct sctp_sender_hb_info *hbs_hdr;
		struct sctp_shutdownhdr *shutdown_hdr;
		struct sctp_signed_cookie *cookie_hdr;
		struct sctp_ecnehdr *ecne_hdr;
		struct sctp_cwrhdr *ecn_cwr_hdr;
		struct sctp_errhdr *err_hdr;
		struct sctp_addiphdr *addip_hdr;
		struct sctp_fwdtsn_hdr *fwdtsn_hdr;
		struct sctp_authhdr *auth_hdr;
		struct sctp_idatahdr *idata_hdr;
		struct sctp_ifwdtsn_hdr *ifwdtsn_hdr;
	} subh;
	__u8 *chunk_end;
	struct sctp_chunkhdr *chunk_hdr;
	struct sctphdr *sctp_hdr;
	struct sctp_sndrcvinfo sinfo;
	struct sctp_association *asoc;
	struct sctp_ep_common *rcvr;
	long unsigned int sent_at;
	union sctp_addr source;
	union sctp_addr dest;
	struct sctp_datamsg *msg;
	struct sctp_transport *transport;
	struct sk_buff___26 *auth_chunk;
	__u16 rtt_in_progress: 1;
	__u16 has_tsn: 1;
	__u16 has_ssn: 1;
	__u16 singleton: 1;
	__u16 end_of_packet: 1;
	__u16 ecn_ce_done: 1;
	__u16 pdiscard: 1;
	__u16 tsn_gap_acked: 1;
	__u16 data_accepted: 1;
	__u16 auth: 1;
	__u16 has_asconf: 1;
	__u16 pmtu_probe: 1;
	__u16 tsn_missing_report: 2;
	__u16 fast_retransmit: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sctp_stream_interleave {
	__u16 data_chunk_len;
	__u16 ftsn_chunk_len;
	struct sctp_chunk * (*make_datafrag)(const struct sctp_association *, const struct sctp_sndrcvinfo *, int, __u8, gfp_t);
	void (*assign_number)(struct sctp_chunk *);
	bool (*validate_data)(struct sctp_chunk *);
	int (*ulpevent_data)(struct sctp_ulpq *, struct sctp_chunk *, gfp_t);
	int (*enqueue_event)(struct sctp_ulpq *, struct sctp_ulpevent *);
	void (*renege_events)(struct sctp_ulpq *, struct sctp_chunk *, gfp_t);
	void (*start_pd)(struct sctp_ulpq *, gfp_t);
	void (*abort_pd)(struct sctp_ulpq *, gfp_t);
	void (*generate_ftsn)(struct sctp_outq *, __u32);
	bool (*validate_ftsn)(struct sctp_chunk *);
	void (*report_ftsn)(struct sctp_ulpq *, __u32);
	void (*handle_ftsn)(struct sctp_ulpq *, struct sctp_chunk *);
};

struct sctp_bind_bucket {
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct hlist_node node;
	struct hlist_head owner;
	struct net___30 *net;
};

enum sctp_socket_type {
	SCTP_SOCKET_UDP = 0,
	SCTP_SOCKET_UDP_HIGH_BANDWIDTH = 1,
	SCTP_SOCKET_TCP = 2,
};

struct sctp_pf;

struct sctp_sock {
	struct inet_sock inet;
	enum sctp_socket_type type;
	int: 32;
	struct sctp_pf *pf;
	struct crypto_shash___6 *hmac;
	char *sctp_hmac_alg;
	struct sctp_endpoint *ep;
	struct sctp_bind_bucket *bind_hash;
	__u16 default_stream;
	short: 16;
	__u32 default_ppid;
	__u16 default_flags;
	short: 16;
	__u32 default_context;
	__u32 default_timetolive;
	__u32 default_rcv_context;
	int max_burst;
	__u32 hbinterval;
	__u32 probe_interval;
	__be16 udp_port;
	__be16 encap_port;
	__u16 pathmaxrxt;
	short: 16;
	__u32 flowlabel;
	__u8 dscp;
	char: 8;
	__u16 pf_retrans;
	__u16 ps_retrans;
	short: 16;
	__u32 pathmtu;
	__u32 sackdelay;
	__u32 sackfreq;
	__u32 param_flags;
	__u32 default_ss;
	struct sctp_rtoinfo rtoinfo;
	struct sctp_paddrparams paddrparam;
	struct sctp_assocparams assocparams;
	__u16 subscribe;
	struct sctp_initmsg initmsg;
	short: 16;
	int user_frag;
	__u32 autoclose;
	__u32 adaptation_ind;
	__u32 pd_point;
	__u16 nodelay: 1;
	__u16 pf_expose: 2;
	__u16 reuse: 1;
	__u16 disable_fragments: 1;
	__u16 v4mapped: 1;
	__u16 frag_interleave: 1;
	__u16 recvrcvinfo: 1;
	__u16 recvnxtinfo: 1;
	__u16 data_ready_signalled: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t pd_mode;
	struct sk_buff_head___24 pd_lobby;
	struct list_head auto_asconf_list;
	int do_auto_asconf;
	int: 32;
} __attribute__((packed));

struct sctp_af;

struct sctp_pf {
	void (*event_msgname)(struct sctp_ulpevent *, char *, int *);
	void (*skb_msgname)(struct sk_buff___26 *, char *, int *);
	int (*af_supported)(sa_family_t, struct sctp_sock *);
	int (*cmp_addr)(const union sctp_addr *, const union sctp_addr *, struct sctp_sock *);
	int (*bind_verify)(struct sctp_sock *, union sctp_addr *);
	int (*send_verify)(struct sctp_sock *, union sctp_addr *);
	int (*supported_addrs)(const struct sctp_sock *, __be16 *);
	struct sock___18 * (*create_accept_sk)(struct sock___18 *, struct sctp_association *, bool);
	int (*addr_to_user)(struct sctp_sock *, union sctp_addr *);
	void (*to_sk_saddr)(union sctp_addr *, struct sock___18 *);
	void (*to_sk_daddr)(union sctp_addr *, struct sock___18 *);
	void (*copy_ip_options)(struct sock___18 *, struct sock___18 *);
	struct sctp_af *af;
};

struct sctp_signed_cookie {
	__u8 signature[32];
	__u32 __pad;
	struct sctp_cookie c;
} __attribute__((packed));

union sctp_addr_param {
	struct sctp_paramhdr p;
	struct sctp_ipv4addr_param v4;
	struct sctp_ipv6addr_param v6;
};

struct sctp_sender_hb_info {
	struct sctp_paramhdr param_hdr;
	union sctp_addr daddr;
	long unsigned int sent_at;
	__u64 hb_nonce;
	__u32 probe_size;
};

struct sctp_af {
	int (*sctp_xmit)(struct sk_buff___26 *, struct sctp_transport *);
	int (*setsockopt)(struct sock___18 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___18 *, int, int, char *, int *);
	void (*get_dst)(struct sctp_transport *, union sctp_addr *, struct flowi *, struct sock___18 *);
	void (*get_saddr)(struct sctp_sock *, struct sctp_transport *, struct flowi *);
	void (*copy_addrlist)(struct list_head *, struct net_device___3 *);
	int (*cmp_addr)(const union sctp_addr *, const union sctp_addr *);
	void (*addr_copy)(union sctp_addr *, union sctp_addr *);
	void (*from_skb)(union sctp_addr *, struct sk_buff___26 *, int);
	void (*from_sk)(union sctp_addr *, struct sock___18 *);
	bool (*from_addr_param)(union sctp_addr *, union sctp_addr_param *, __be16, int);
	int (*to_addr_param)(const union sctp_addr *, union sctp_addr_param *);
	int (*addr_valid)(union sctp_addr *, struct sctp_sock *, const struct sk_buff___26 *);
	enum sctp_scope (*scope)(union sctp_addr *);
	void (*inaddr_any)(union sctp_addr *, __be16);
	int (*is_any)(const union sctp_addr *);
	int (*available)(union sctp_addr *, struct sctp_sock *);
	int (*skb_iif)(const struct sk_buff___26 *);
	int (*is_ce)(const struct sk_buff___26 *);
	void (*seq_dump_addr)(struct seq_file___134 *, union sctp_addr *);
	void (*ecn_capable)(struct sock___18 *);
	__u16 net_header_len;
	int sockaddr_len;
	int (*ip_options_len)(struct sock___18 *);
	sa_family_t sa_family;
	struct list_head list;
};

struct sctp_packet {
	__u16 source_port;
	__u16 destination_port;
	__u32 vtag;
	struct list_head chunk_list;
	size_t overhead;
	size_t size;
	size_t max_size;
	struct sctp_transport *transport;
	struct sctp_chunk *auth;
	u8 has_cookie_echo: 1;
	u8 has_sack: 1;
	u8 has_auth: 1;
	u8 has_data: 1;
	u8 ipfragok: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sctp_transport {
	struct list_head transports;
	struct rhlist_head node;
	refcount_t refcnt;
	__u32 rto_pending: 1;
	__u32 hb_sent: 1;
	__u32 pmtu_pending: 1;
	__u32 dst_pending_confirm: 1;
	__u32 sack_generation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 dst_cookie;
	struct flowi fl;
	union sctp_addr ipaddr;
	struct sctp_af *af_specific;
	struct sctp_association *asoc;
	long unsigned int rto;
	__u32 rtt;
	__u32 rttvar;
	__u32 srtt;
	__u32 cwnd;
	__u32 ssthresh;
	__u32 partial_bytes_acked;
	__u32 flight_size;
	__u32 burst_limited;
	struct dst_entry___17 *dst;
	union sctp_addr saddr;
	long unsigned int hbinterval;
	long unsigned int probe_interval;
	long unsigned int sackdelay;
	__u32 sackfreq;
	atomic_t mtu_info;
	ktime_t last_time_heard;
	long unsigned int last_time_sent;
	long unsigned int last_time_ecne_reduced;
	__be16 encap_port;
	__u16 pathmaxrxt;
	__u32 flowlabel;
	__u8 dscp;
	__u16 pf_retrans;
	__u16 ps_retrans;
	__u32 pathmtu;
	__u32 param_flags;
	int init_sent_count;
	int state;
	short unsigned int error_count;
	struct timer_list T3_rtx_timer;
	struct timer_list hb_timer;
	struct timer_list proto_unreach_timer;
	struct timer_list reconf_timer;
	struct timer_list probe_timer;
	struct list_head transmitted;
	struct sctp_packet packet;
	struct list_head send_ready;
	struct {
		__u32 next_tsn_at_change;
		char changeover_active;
		char cycling_changeover;
		char cacc_saw_newack;
	} cacc;
	struct {
		__u32 last_rtx_chunks;
		__u16 pmtu;
		__u16 probe_size;
		__u16 probe_high;
		__u8 probe_count: 3;
		__u8 raise_count: 5;
		long: 19;
		long: 64;
		__u8 state;
	} pl;
	__u64 hb_nonce;
	struct callback_head rcu;
};

struct sctp_datamsg {
	struct list_head chunks;
	refcount_t refcnt;
	long unsigned int expires_at;
	int send_error;
	u8 send_failed: 1;
	u8 can_delay: 1;
	u8 abandoned: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sctp_stream_priorities {
	struct list_head prio_sched;
	struct list_head active;
	struct sctp_stream_out_ext *next;
	__u16 prio;
};

struct sctp_stream_out_ext {
	__u64 abandoned_unsent[3];
	__u64 abandoned_sent[3];
	struct list_head outq;
	union {
		struct {
			struct list_head prio_list;
			struct sctp_stream_priorities *prio_head;
		};
		struct {
			struct list_head rr_list;
		};
	};
};

struct lsm_network_audit___2 {
	int netif;
	const struct sock___18 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___2 {
	struct path___156 path;
	u16 cmd;
};

struct selinux_state___2;

struct selinux_audit_data___2 {
	u32 ssid;
	u32 tsid;
	u16 tclass;
	u32 requested;
	u32 audited;
	u32 denied;
	int result;
	struct selinux_state___2 *state;
};

struct common_audit_data___2 {
	char type;
	union {
		struct path___156 path;
		struct dentry___156 *dentry;
		struct inode___156 *inode;
		struct lsm_network_audit___2 *net;
		int cap;
		int ipc_id;
		struct task_struct___163 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___2 *op;
		struct file___156 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data *apparmor_audit_data;
	};
};

struct selinux_avc___2;

struct selinux_state___2 {
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[8];
	struct page___161 *status_page;
	struct mutex status_lock;
	struct selinux_avc___2 *avc;
	struct selinux_policy *policy;
	struct mutex policy_mutex;
};

struct coredump_params___28 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___156 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct task_security_struct {
	u32 osid;
	u32 sid;
	u32 exec_sid;
	u32 create_sid;
	u32 keycreate_sid;
	u32 sockcreate_sid;
};

enum label_initialized {
	LABEL_INVALID = 0,
	LABEL_INITIALIZED = 1,
	LABEL_PENDING = 2,
};

struct inode_security_struct {
	struct inode___156 *inode;
	struct list_head list;
	u32 task_sid;
	u32 sid;
	u16 sclass;
	unsigned char initialized;
	spinlock_t lock;
};

struct file_security_struct {
	u32 sid;
	u32 fown_sid;
	u32 isid;
	u32 pseqno;
};

struct superblock_security_struct {
	u32 sid;
	u32 def_sid;
	u32 mntpoint_sid;
	short unsigned int behavior;
	short unsigned int flags;
	struct mutex lock;
	struct list_head isec_head;
	spinlock_t isec_lock;
};

struct msg_security_struct {
	u32 sid;
};

struct ipc_security_struct {
	u16 sclass;
	u32 sid;
};

struct sk_security_struct {
	enum {
		NLBL_UNSET = 0,
		NLBL_REQUIRE = 1,
		NLBL_LABELED = 2,
		NLBL_REQSKB = 3,
		NLBL_CONNLABELED = 4,
	} nlbl_state;
	struct netlbl_lsm_secattr *nlbl_secattr;
	u32 sid;
	u32 peer_sid;
	u16 sclass;
	enum {
		SCTP_ASSOC_UNSET = 0,
		SCTP_ASSOC_SET = 1,
	} sctp_assoc_state;
};

struct tun_security_struct {
	u32 sid;
};

struct key_security_struct {
	u32 sid;
};

struct ib_security_struct {
	u32 sid;
};

struct bpf_security_struct {
	u32 sid;
};

struct perf_event_security_struct {
	u32 sid;
};

struct selinux_mnt_opts {
	const char *fscontext;
	const char *context;
	const char *rootcontext;
	const char *defcontext;
	u32 fscontext_sid;
	u32 context_sid;
	u32 rootcontext_sid;
	u32 defcontext_sid;
};

enum {
	Opt_error___2 = 4294967295,
	Opt_context = 0,
	Opt_defcontext = 1,
	Opt_fscontext = 2,
	Opt_rootcontext = 3,
	Opt_seclabel = 4,
};

struct tree_descr___6 {
	const char *name;
	const struct file_operations___156 *ops;
	int mode;
};

struct selinux_policy_convert_data;

struct selinux_load_state {
	struct selinux_policy *policy;
	struct selinux_policy_convert_data *convert_data;
};

enum sel_inos {
	SEL_ROOT_INO = 2,
	SEL_LOAD = 3,
	SEL_ENFORCE = 4,
	SEL_CONTEXT = 5,
	SEL_ACCESS = 6,
	SEL_CREATE = 7,
	SEL_RELABEL = 8,
	SEL_USER = 9,
	SEL_POLICYVERS = 10,
	SEL_COMMIT_BOOLS = 11,
	SEL_MLS = 12,
	SEL_DISABLE = 13,
	SEL_MEMBER = 14,
	SEL_CHECKREQPROT = 15,
	SEL_COMPAT_NET = 16,
	SEL_REJECT_UNKNOWN = 17,
	SEL_DENY_UNKNOWN = 18,
	SEL_STATUS = 19,
	SEL_POLICY = 20,
	SEL_VALIDATE_TRANS = 21,
	SEL_INO_NEXT = 22,
};

struct selinux_fs_info {
	struct dentry___156 *bool_dir;
	unsigned int bool_num;
	char **bool_pending_names;
	unsigned int *bool_pending_values;
	struct dentry___156 *class_dir;
	long unsigned int last_class_ino;
	bool policy_opened;
	struct dentry___156 *policycap_dir;
	long unsigned int last_ino;
	struct selinux_state___2 *state;
	struct super_block___156 *sb;
};

struct policy_load_memory {
	size_t len;
	void *data;
};

enum {
	SELNL_MSG_SETENFORCE = 16,
	SELNL_MSG_POLICYLOAD = 17,
	SELNL_MSG_MAX = 18,
};

enum selinux_nlgroups {
	SELNLGRP_NONE = 0,
	SELNLGRP_AVC = 1,
	__SELNLGRP_MAX = 2,
};

struct selnl_msg_setenforce {
	__s32 val;
};

struct selnl_msg_policyload {
	__u32 seqno;
};

enum {
	XFRM_MSG_BASE = 16,
	XFRM_MSG_NEWSA = 16,
	XFRM_MSG_DELSA = 17,
	XFRM_MSG_GETSA = 18,
	XFRM_MSG_NEWPOLICY = 19,
	XFRM_MSG_DELPOLICY = 20,
	XFRM_MSG_GETPOLICY = 21,
	XFRM_MSG_ALLOCSPI = 22,
	XFRM_MSG_ACQUIRE = 23,
	XFRM_MSG_EXPIRE = 24,
	XFRM_MSG_UPDPOLICY = 25,
	XFRM_MSG_UPDSA = 26,
	XFRM_MSG_POLEXPIRE = 27,
	XFRM_MSG_FLUSHSA = 28,
	XFRM_MSG_FLUSHPOLICY = 29,
	XFRM_MSG_NEWAE = 30,
	XFRM_MSG_GETAE = 31,
	XFRM_MSG_REPORT = 32,
	XFRM_MSG_MIGRATE = 33,
	XFRM_MSG_NEWSADINFO = 34,
	XFRM_MSG_GETSADINFO = 35,
	XFRM_MSG_NEWSPDINFO = 36,
	XFRM_MSG_GETSPDINFO = 37,
	XFRM_MSG_MAPPING = 38,
	XFRM_MSG_SETDEFAULT = 39,
	XFRM_MSG_GETDEFAULT = 40,
	__XFRM_MSG_MAX = 41,
};

enum {
	RTM_BASE = 16,
	RTM_NEWLINK = 16,
	RTM_DELLINK = 17,
	RTM_GETLINK = 18,
	RTM_SETLINK = 19,
	RTM_NEWADDR = 20,
	RTM_DELADDR = 21,
	RTM_GETADDR = 22,
	RTM_NEWROUTE = 24,
	RTM_DELROUTE = 25,
	RTM_GETROUTE = 26,
	RTM_NEWNEIGH = 28,
	RTM_DELNEIGH = 29,
	RTM_GETNEIGH = 30,
	RTM_NEWRULE = 32,
	RTM_DELRULE = 33,
	RTM_GETRULE = 34,
	RTM_NEWQDISC = 36,
	RTM_DELQDISC = 37,
	RTM_GETQDISC = 38,
	RTM_NEWTCLASS = 40,
	RTM_DELTCLASS = 41,
	RTM_GETTCLASS = 42,
	RTM_NEWTFILTER = 44,
	RTM_DELTFILTER = 45,
	RTM_GETTFILTER = 46,
	RTM_NEWACTION = 48,
	RTM_DELACTION = 49,
	RTM_GETACTION = 50,
	RTM_NEWPREFIX = 52,
	RTM_GETMULTICAST = 58,
	RTM_GETANYCAST = 62,
	RTM_NEWNEIGHTBL = 64,
	RTM_GETNEIGHTBL = 66,
	RTM_SETNEIGHTBL = 67,
	RTM_NEWNDUSEROPT = 68,
	RTM_NEWADDRLABEL = 72,
	RTM_DELADDRLABEL = 73,
	RTM_GETADDRLABEL = 74,
	RTM_GETDCB = 78,
	RTM_SETDCB = 79,
	RTM_NEWNETCONF = 80,
	RTM_DELNETCONF = 81,
	RTM_GETNETCONF = 82,
	RTM_NEWMDB = 84,
	RTM_DELMDB = 85,
	RTM_GETMDB = 86,
	RTM_NEWNSID = 88,
	RTM_DELNSID = 89,
	RTM_GETNSID = 90,
	RTM_NEWSTATS = 92,
	RTM_GETSTATS = 94,
	RTM_NEWCACHEREPORT = 96,
	RTM_NEWCHAIN = 100,
	RTM_DELCHAIN = 101,
	RTM_GETCHAIN = 102,
	RTM_NEWNEXTHOP = 104,
	RTM_DELNEXTHOP = 105,
	RTM_GETNEXTHOP = 106,
	RTM_NEWLINKPROP = 108,
	RTM_DELLINKPROP = 109,
	RTM_GETLINKPROP = 110,
	RTM_NEWVLAN = 112,
	RTM_DELVLAN = 113,
	RTM_GETVLAN = 114,
	RTM_NEWNEXTHOPBUCKET = 116,
	RTM_DELNEXTHOPBUCKET = 117,
	RTM_GETNEXTHOPBUCKET = 118,
	__RTM_MAX = 119,
};

struct nlmsg_perm {
	u16 nlmsg_type;
	u32 perm;
};

struct dentry___157;

struct super_block___157;

struct module___142;

struct file_system_type___157 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___157 * (*mount)(struct file_system_type___157 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___157 *);
	struct module___142 *owner;
	struct file_system_type___157 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___157;

struct kiocb___157;

struct iov_iter___86;

struct poll_table_struct___98;

struct vm_area_struct___162;

struct inode___157;

struct file_lock___157;

struct page___162;

struct pipe_inode_info___50;

struct seq_file___135;

struct file_operations___157 {
	struct module___142 *owner;
	loff_t (*llseek)(struct file___157 *, loff_t, int);
	ssize_t (*read)(struct file___157 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___157 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___157 *, struct iov_iter___86 *);
	ssize_t (*write_iter)(struct kiocb___157 *, struct iov_iter___86 *);
	int (*iopoll)(struct kiocb___157 *, bool);
	int (*iterate)(struct file___157 *, struct dir_context *);
	int (*iterate_shared)(struct file___157 *, struct dir_context *);
	__poll_t (*poll)(struct file___157 *, struct poll_table_struct___98 *);
	long int (*unlocked_ioctl)(struct file___157 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___157 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___157 *, struct vm_area_struct___162 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___157 *, struct file___157 *);
	int (*flush)(struct file___157 *, fl_owner_t);
	int (*release)(struct inode___157 *, struct file___157 *);
	int (*fsync)(struct file___157 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___157 *, int);
	int (*lock)(struct file___157 *, int, struct file_lock___157 *);
	ssize_t (*sendpage)(struct file___157 *, struct page___162 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___157 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___157 *, long unsigned int);
	int (*flock)(struct file___157 *, int, struct file_lock___157 *);
	ssize_t (*splice_write)(struct pipe_inode_info___50 *, struct file___157 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___157 *, loff_t *, struct pipe_inode_info___50 *, size_t, unsigned int);
	int (*setlease)(struct file___157 *, long int, struct file_lock___157 **, void **);
	long int (*fallocate)(struct file___157 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___135 *, struct file___157 *);
	ssize_t (*copy_file_range)(struct file___157 *, loff_t, struct file___157 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___157 *, loff_t, struct file___157 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___157 *, loff_t, loff_t, int);
};

struct vmacache___162 {
	u64 seqnum;
	struct vm_area_struct___162 *vmas[4];
};

struct page_frag___162 {
	struct page___162 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___163;

struct pid___138;

struct nsproxy___147;

struct signal_struct___158;

struct bio_list___70;

struct backing_dev_info___67;

struct io_context___70;

struct css_set___106;

struct mem_cgroup___58;

struct request_queue___70;

struct vm_struct___141;

struct task_struct___164 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___164 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___163 *mm;
	struct mm_struct___163 *active_mm;
	struct vmacache___162 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___164 *real_parent;
	struct task_struct___164 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___164 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___138 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	struct key___7 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___147 *nsproxy;
	struct signal_struct___158 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___164 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___70 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___67 *backing_dev_info;
	struct io_context___70 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___106 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___50 *splice_pipe;
	struct page_frag___162 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___58 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___58 *active_memcg;
	struct request_queue___70 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___164 *oom_reaper_list;
	struct vm_struct___141 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___144;

struct kobj_type___144;

struct kernfs_node___144;

struct kobject___144 {
	const char *name;
	struct list_head entry;
	struct kobject___144 *parent;
	struct kset___144 *kset;
	struct kobj_type___144 *ktype;
	struct kernfs_node___144 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___141 {
	struct kobject___144 kobj;
	struct module___142 *mod;
	struct kobject___144 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___141 {
	struct module___142 *mod;
	struct latch_tree_node node;
};

struct module_layout___141 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___141 mtn;
};

struct module_attribute___141;

struct kernel_param___141;

struct module___142 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___141 mkobj;
	struct module_attribute___141 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___144 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___141 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___141 core_layout;
	struct module_layout___141 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___162 *pgtable_t___162;

struct address_space___157;

struct page_pool___41;

struct dev_pagemap___153;

struct page___162 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___157 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___41 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___162 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___162 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___163 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___153 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___153;

struct vm_area_struct___162 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___162 *vm_next;
	struct vm_area_struct___162 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___163 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___153 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___157 *vm_file;
	struct file___157 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___29;

struct core_state___162;

struct mm_struct___163 {
	struct {
		struct vm_area_struct___162 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___157 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___29 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___162 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___164 *owner;
		struct user_namespace___23 *user_ns;
		struct file___157 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___157;

struct address_space___157 {
	struct inode___157 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___157 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___113;

struct page_pool_params___41 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___113 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___41 {
	u32 count;
	struct page___162 *cache[128];
};

struct page_pool___41 {
	struct page_pool_params___41 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___162 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___41 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___153;

struct dev_pagemap___153 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___153 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___157;

struct path___157 {
	struct vfsmount___157 *mnt;
	struct dentry___157 *dentry;
};

struct fown_struct___138 {
	rwlock_t lock;
	struct pid___138 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___157 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___157 f_path;
	struct inode___157 *f_inode;
	const struct file_operations___157 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___138 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___157 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___153;

struct vm_operations_struct___153 {
	void (*open)(struct vm_area_struct___162 *);
	void (*close)(struct vm_area_struct___162 *);
	int (*may_split)(struct vm_area_struct___162 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___162 *);
	int (*mprotect)(struct vm_area_struct___162 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___153 *);
	vm_fault_t (*huge_fault)(struct vm_fault___153 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___153 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___162 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___153 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___153 *);
	int (*access)(struct vm_area_struct___162 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___162 *);
	int (*set_policy)(struct vm_area_struct___162 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___162 *, long unsigned int);
	struct page___162 * (*find_special_page)(struct vm_area_struct___162 *, long unsigned int);
};

struct core_thread___162 {
	struct task_struct___164 *task;
	struct core_thread___162 *next;
};

struct core_state___162 {
	atomic_t nr_threads;
	struct core_thread___162 dumper;
	struct completion startup;
};

struct linux_binprm___30;

struct coredump_params___29;

struct linux_binfmt___29 {
	struct list_head lh;
	struct module___142 *module;
	int (*load_binary)(struct linux_binprm___30 *);
	int (*load_shlib)(struct file___157 *);
	int (*core_dump)(struct coredump_params___29 *);
	long unsigned int min_coredump;
};

struct vm_fault___153 {
	const struct {
		struct vm_area_struct___162 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___162 *cow_page;
	struct page___162 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___162 prealloc_pte;
};

struct pglist_data___65;

struct lruvec___65 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___65 *pgdat;
};

struct zone___65 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___65 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___65 {
	struct zone___65 *zone;
	int zone_idx;
};

struct zonelist___65 {
	struct zoneref___65 _zonerefs[321];
};

struct pglist_data___65 {
	struct zone___65 node_zones[5];
	struct zonelist___65 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___164 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___164 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___65 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___138;

struct upid___138 {
	int nr;
	struct pid_namespace___138 *ns;
};

struct pid_namespace___138 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___164 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___138 *parent;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___138 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___138 numbers[1];
};

struct signal_struct___158 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___164 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___164 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___138 *pids[4];
	struct pid___138 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___163 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___31;

struct cgroup_namespace___106;

struct nsproxy___147 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___138 *pid_ns_for_children;
	struct net___31 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___106 *cgroup_ns;
};

struct bio___70;

struct bio_list___70 {
	struct bio___70 *head;
	struct bio___70 *tail;
};

struct cgroup_subsys_state___106;

struct bdi_writeback___67 {
	struct backing_dev_info___67 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___106 *memcg_css;
	struct cgroup_subsys_state___106 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___67 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___67 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___113 *dev;
	char dev_name[64];
	struct device___113 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___157 *debug_dir;
};

struct io_cq___70;

struct io_context___70 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___70 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___106;

struct css_set___106 {
	struct cgroup_subsys_state___106 *subsys[14];
	refcount_t refcount;
	struct css_set___106 *dom_cset;
	struct cgroup___106 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___106 *mg_src_cgrp;
	struct cgroup___106 *mg_dst_cgrp;
	struct css_set___106 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___157;

struct pipe_buffer___50;

struct pipe_inode_info___50 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___162 *tmp_page;
	struct fasync_struct___157 *fasync_readers;
	struct fasync_struct___157 *fasync_writers;
	struct pipe_buffer___50 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___106;

struct cgroup_subsys_state___106 {
	struct cgroup___106 *cgroup;
	struct cgroup_subsys___106 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___106 *parent;
};

struct cgroup_file___106 {
	struct kernfs_node___144 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___58;

struct mem_cgroup_per_node___58;

struct mem_cgroup___58 {
	struct cgroup_subsys_state___106 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___106 events_file;
	struct cgroup_file___106 events_local_file;
	struct cgroup_file___106 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___58 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___164 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___58 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___70;

struct blk_integrity___70 {
	const struct blk_integrity_profile___70 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___70 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___70 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___70;

struct elevator_queue___70;

struct blk_mq_ops___67;

struct blk_mq_hw_ctx___67;

struct gendisk___70;

struct blkcg_gq___67;

struct blk_mq_tag_set___67;

struct request_queue___70 {
	struct request___70 *last_merge;
	struct elevator_queue___70 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___67 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___67 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___70 *disk;
	struct kobject___144 kobj;
	struct kobject___144 *mq_kobj;
	struct blk_integrity___70 integrity;
	struct device___113 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___67 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___67 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___70 bio_split;
	struct dentry___157 *debugfs_dir;
	struct dentry___157 *sched_debugfs_dir;
	struct dentry___157 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___141 {
	struct vm_struct___141 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___162 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___84 {
	struct page___162 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___86 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___84 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___50 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___19 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___86 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___157 *msg_iocb;
};

struct kiocb___157 {
	struct file___157 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___157 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___73 *ki_waitq;
	};
};

struct net_device___28;

struct sock___19;

struct sk_buff___27 {
	union {
		struct {
			struct sk_buff___27 *next;
			struct sk_buff___27 *prev;
			union {
				struct net_device___28 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___19 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___27 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___30;

struct fqdir___30 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___30 *f;
	struct net___31 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___30;

struct inet_frags___30 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___30 *, const void *);
	void (*destructor)(struct inet_frag_queue___30 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___5;

struct fib_rules_ops___18;

struct fib_notifier_ops___18;

struct netns_ipv4___30 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___5 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___18 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___19 *fibnl;
	struct sock___19 **icmp_sk;
	struct sock___19 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___19 **tcp_sk;
	struct fqdir___30 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___18 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___18 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___18 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___18;

struct neighbour___18;

struct dst_ops___30 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___30 *);
	struct dst_entry___18 * (*check)(struct dst_entry___18 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___18 *);
	unsigned int (*mtu)(const struct dst_entry___18 *);
	u32 * (*cow_metrics)(struct dst_entry___18 *, long unsigned int);
	void (*destroy)(struct dst_entry___18 *);
	void (*ifdown)(struct dst_entry___18 *, struct net_device___28 *, int);
	struct dst_entry___18 * (*negative_advice)(struct dst_entry___18 *);
	void (*link_failure)(struct sk_buff___27 *);
	void (*update_pmtu)(struct dst_entry___18 *, struct sock___19 *, struct sk_buff___27 *, u32, bool);
	void (*redirect)(struct dst_entry___18 *, struct sock___19 *, struct sk_buff___27 *);
	int (*local_out)(struct net___31 *, struct sock___19 *, struct sk_buff___27 *);
	struct neighbour___18 * (*neigh_lookup)(const struct dst_entry___18 *, struct sk_buff___27 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___18 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___30 {
	struct dst_ops___30 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___30 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___18 *fib6_rules_ops;
	struct sock___19 **icmp_sk;
	struct sock___19 *ndisc_sk;
	struct sock___19 *tcp_sk;
	struct sock___19 *igmp_sk;
	struct sock___19 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___18 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___18 *notifier_ops;
	struct fib_notifier_ops___18 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___30 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___30 *fqdir;
};

struct netns_sctp___18 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___19 *ctl_sock;
	struct sock___19 *udp4_sock;
	struct sock___19 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___25 {
	struct sk_buff___27 *next;
	struct sk_buff___27 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___25;

struct bpf_prog___25;

struct netns_bpf___25 {
	struct bpf_prog_array___25 *run_array[2];
	struct bpf_prog___25 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___30 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___19 *nlsk;
	struct sock___19 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___30 xfrm4_dst_ops;
	struct dst_ops___30 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___31 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___19 *rtnl;
	struct sock___19 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___28 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___30 ipv4;
	struct netns_ipv6___30 ipv6;
	struct netns_ieee802154_lowpan___30 ieee802154_lowpan;
	struct netns_sctp___18 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___25 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___25 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___30 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___19 *crypto_nlsk;
	struct sock___19 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___30 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___27 *fragments_tail;
	struct sk_buff___27 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___30 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___5 {
	struct ip_ra_chain___5 *next;
	struct sock___19 *sk;
	union {
		void (*destructor)(struct sock___19 *);
		struct sock___19 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___18;

struct fib_lookup_arg___18;

struct fib_rules_ops___18 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___18 *, struct flowi *, int, struct fib_lookup_arg___18 *);
	bool (*suppress)(struct fib_rule___18 *, int, struct fib_lookup_arg___18 *);
	int (*match)(struct fib_rule___18 *, struct flowi *, int);
	int (*configure)(struct fib_rule___18 *, struct sk_buff___27 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___18 *);
	int (*compare)(struct fib_rule___18 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___18 *, struct sk_buff___27 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___18 *);
	void (*flush_cache)(struct fib_rules_ops___18 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___142 *owner;
	struct net___31 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___31 *net;
} possible_net_t___25;

struct proto___18;

struct sock_common___18 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___18 *skc_prot;
	possible_net_t___25 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___19 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___18 {
	struct cgroup___106 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___18;

struct socket_wq___19;

struct socket___19;

struct sock___19 {
	struct sock_common___18 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___25 sk_error_queue;
	struct sk_buff___27 *sk_rx_skb_cache;
	struct sk_buff_head___25 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___27 *head;
		struct sk_buff___27 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___18 *sk_filter;
	union {
		struct socket_wq___19 *sk_wq;
		struct socket_wq___19 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___18 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___18 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___27 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___27 *sk_tx_skb_cache;
	struct sk_buff_head___25 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___162 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___18 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___138 *sk_peer_pid;
	const struct cred___26 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___19 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___18 sk_cgrp_data;
	struct mem_cgroup___58 *sk_memcg;
	void (*sk_state_change)(struct sock___19 *);
	void (*sk_data_ready)(struct sock___19 *);
	void (*sk_write_space)(struct sock___19 *);
	void (*sk_error_report)(struct sock___19 *);
	int (*sk_backlog_rcv)(struct sock___19 *, struct sk_buff___27 *);
	struct sk_buff___27 * (*sk_validate_xmit_skb)(struct sock___19 *, struct net_device___28 *, struct sk_buff___27 *);
	void (*sk_destruct)(struct sock___19 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct fib_notifier_ops___18 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___31 *);
	int (*fib_dump)(struct net___31 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___142 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___5;

struct dst_entry___18 {
	struct net_device___28 *dev;
	struct dst_ops___30 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___27 *);
	int (*output)(struct net___31 *, struct sock___19 *, struct sk_buff___27 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___5 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___25(struct sk_buff___27 **);

struct wakeup_source___113;

struct dev_pm_info___113 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___113 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___113 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___113;

struct bus_type___113;

struct device_driver___113;

struct dev_pm_domain___113;

struct fwnode_handle___113;

struct class___113;

struct attribute_group___144;

struct device___113 {
	struct kobject___144 kobj;
	struct device___113 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___113 *type;
	struct bus_type___113 *bus;
	struct device_driver___113 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___113 power;
	struct dev_pm_domain___113 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___113 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___113 *class;
	const struct attribute_group___144 **groups;
	void (*release)(struct device___113 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___25 {
	struct bpf_prog___25 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___25;

struct net_device_ops___25;

struct ethtool_ops___3;

struct l3mdev_ops___18;

struct ndisc_ops___8;

struct xfrmdev_ops___25;

struct header_ops___25;

struct inet6_dev___8;

struct netdev_rx_queue___25;

struct mini_Qdisc___25;

struct netdev_queue___25;

struct Qdisc___25;

struct rtnl_link_ops___25;

struct dcbnl_rtnl_ops___25;

struct net_device___28 {
	char name[16];
	struct netdev_name_node___25 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___25 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___3 *ethtool_ops;
	const struct l3mdev_ops___18 *l3mdev_ops;
	const struct ndisc_ops___8 *ndisc_ops;
	const struct xfrmdev_ops___25 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___25 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___144 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___8 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___25 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___25 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___25 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___25 *miniq_ingress;
	struct netdev_queue___25 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___25 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___25 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___25 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___25 = 0,
		NETREG_REGISTERED___25 = 1,
		NETREG_UNREGISTERING___25 = 2,
		NETREG_UNREGISTERED___25 = 3,
		NETREG_RELEASED___25 = 4,
		NETREG_DUMMY___25 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___25 = 0,
		RTNL_LINK_INITIALIZING___25 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___28 *);
	struct netpoll_info *npinfo;
	possible_net_t___25 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___113 dev;
	const struct attribute_group___144 *sysfs_groups[4];
	const struct attribute_group___144 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___25 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___25 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___25 xdp_state[3];
	long: 64;
};

struct neigh_table___18;

struct neigh_parms___18;

struct neigh_ops___18;

struct neighbour___18 {
	struct neighbour___18 *next;
	struct neigh_table___18 *tbl;
	struct neigh_parms___18 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___25 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___18 *, struct sk_buff___27 *);
	const struct neigh_ops___18 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___28 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___25 {
	struct bpf_prog___25 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___25 {
	struct callback_head rcu;
	struct bpf_prog_array_item___25 items[0];
};

struct bpf_prog_aux___27;

struct bpf_prog___25 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___27 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___157;

struct dentry___157 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___157 *d_parent;
	struct qstr d_name;
	struct inode___157 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___157 *d_op;
	struct super_block___157 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___157;

struct inode___157 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___157 *i_op;
	struct super_block___157 *i_sb;
	struct address_space___157 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___67 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___157 *i_fop;
		void (*free_inode)(struct inode___157 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___157 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___50 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___157 {
	int (*d_revalidate)(struct dentry___157 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___157 *, unsigned int);
	int (*d_hash)(const struct dentry___157 *, struct qstr *);
	int (*d_compare)(const struct dentry___157 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___157 *);
	int (*d_init)(struct dentry___157 *);
	void (*d_release)(struct dentry___157 *);
	void (*d_prune)(struct dentry___157 *);
	void (*d_iput)(struct dentry___157 *, struct inode___157 *);
	char * (*d_dname)(struct dentry___157 *, char *, int);
	struct vfsmount___157 * (*d_automount)(struct path___157 *);
	int (*d_manage)(const struct path___157 *, bool);
	struct dentry___157 * (*d_real)(struct dentry___157 *, const struct inode___157 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___157;

struct mem_dqinfo___157 {
	struct quota_format_type___157 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___157;

struct quota_info___157 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___157 *files[3];
	struct mem_dqinfo___157 info[3];
	const struct quota_format_ops___157 *ops[3];
};

struct rcuwait___158 {
	struct task_struct___164 *task;
};

struct percpu_rw_semaphore___158 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___158 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___157 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___158 rw_sem[3];
};

struct shrink_control___58;

struct shrinker___58 {
	long unsigned int (*count_objects)(struct shrinker___58 *, struct shrink_control___58 *);
	long unsigned int (*scan_objects)(struct shrinker___58 *, struct shrink_control___58 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___157;

struct dquot_operations___157;

struct quotactl_ops___157;

struct block_device___71;

struct super_block___157 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___157 *s_type;
	const struct super_operations___157 *s_op;
	const struct dquot_operations___157 *dq_op;
	const struct quotactl_ops___157 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___157 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___7 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___71 *s_bdev;
	struct backing_dev_info___67 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___157 s_dquot;
	struct sb_writers___157 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___157 *s_d_op;
	int cleancache_poolid;
	struct shrinker___58 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___157 {
	struct dentry___157 *mnt_root;
	struct super_block___157 *mnt_sb;
	int mnt_flags;
	struct user_namespace___23 *mnt_userns;
};

struct shrink_control___58 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___58 *memcg;
};

struct psi_group___106 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___164 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___25 {
	struct bpf_prog_array___25 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___25 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___106;

struct cgroup_rstat_cpu___106;

struct cgroup___106 {
	struct cgroup_subsys_state___106 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___144 *kn;
	struct cgroup_file___106 procs_file;
	struct cgroup_file___106 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___106 *subsys[14];
	struct cgroup_root___106 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___106 *dom_cgrp;
	struct cgroup___106 *old_dom_cgrp;
	struct cgroup_rstat_cpu___106 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___106 psi;
	struct cgroup_bpf___25 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___70 {
	struct request_queue___70 *q;
	struct io_context___70 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___157 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___157 *ia_file;
};

struct dquot___157 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___157 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___157 {
	int qf_fmt_id;
	const struct quota_format_ops___157 *qf_ops;
	struct module___142 *qf_owner;
	struct quota_format_type___157 *qf_next;
};

struct quota_format_ops___157 {
	int (*check_quota_file)(struct super_block___157 *, int);
	int (*read_file_info)(struct super_block___157 *, int);
	int (*write_file_info)(struct super_block___157 *, int);
	int (*free_file_info)(struct super_block___157 *, int);
	int (*read_dqblk)(struct dquot___157 *);
	int (*commit_dqblk)(struct dquot___157 *);
	int (*release_dqblk)(struct dquot___157 *);
	int (*get_next_id)(struct super_block___157 *, struct kqid *);
};

struct dquot_operations___157 {
	int (*write_dquot)(struct dquot___157 *);
	struct dquot___157 * (*alloc_dquot)(struct super_block___157 *, int);
	void (*destroy_dquot)(struct dquot___157 *);
	int (*acquire_dquot)(struct dquot___157 *);
	int (*release_dquot)(struct dquot___157 *);
	int (*mark_dirty)(struct dquot___157 *);
	int (*write_info)(struct super_block___157 *, int);
	qsize_t * (*get_reserved_space)(struct inode___157 *);
	int (*get_projid)(struct inode___157 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___157 *, qsize_t *);
	int (*get_next_id)(struct super_block___157 *, struct kqid *);
};

struct quotactl_ops___157 {
	int (*quota_on)(struct super_block___157 *, int, int, const struct path___157 *);
	int (*quota_off)(struct super_block___157 *, int);
	int (*quota_enable)(struct super_block___157 *, unsigned int);
	int (*quota_disable)(struct super_block___157 *, unsigned int);
	int (*quota_sync)(struct super_block___157 *, int);
	int (*set_info)(struct super_block___157 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___157 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___157 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___157 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___157 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___157 *, unsigned int);
};

struct writeback_control___67;

struct address_space_operations___157 {
	int (*writepage)(struct page___162 *, struct writeback_control___67 *);
	int (*readpage)(struct file___157 *, struct page___162 *);
	int (*writepages)(struct address_space___157 *, struct writeback_control___67 *);
	int (*set_page_dirty)(struct page___162 *);
	int (*readpages)(struct file___157 *, struct address_space___157 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___157 *, struct address_space___157 *, loff_t, unsigned int, unsigned int, struct page___162 **, void **);
	int (*write_end)(struct file___157 *, struct address_space___157 *, loff_t, unsigned int, unsigned int, struct page___162 *, void *);
	sector_t (*bmap)(struct address_space___157 *, sector_t);
	void (*invalidatepage)(struct page___162 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___162 *, gfp_t);
	void (*freepage)(struct page___162 *);
	ssize_t (*direct_IO)(struct kiocb___157 *, struct iov_iter___86 *);
	int (*migratepage)(struct address_space___157 *, struct page___162 *, struct page___162 *, enum migrate_mode);
	bool (*isolate_page)(struct page___162 *, isolate_mode_t);
	void (*putback_page)(struct page___162 *);
	int (*launder_page)(struct page___162 *);
	int (*is_partially_uptodate)(struct page___162 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___162 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___157 *, struct page___162 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___157 *, sector_t *);
	void (*swap_deactivate)(struct file___157 *);
};

struct writeback_control___67 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___67 *wb;
	struct inode___157 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___157 {
	struct dentry___157 * (*lookup)(struct inode___157 *, struct dentry___157 *, unsigned int);
	const char * (*get_link)(struct dentry___157 *, struct inode___157 *, struct delayed_call *);
	int (*permission)(struct user_namespace___23 *, struct inode___157 *, int);
	struct posix_acl * (*get_acl)(struct inode___157 *, int, bool);
	int (*readlink)(struct dentry___157 *, char *, int);
	int (*create)(struct user_namespace___23 *, struct inode___157 *, struct dentry___157 *, umode_t, bool);
	int (*link)(struct dentry___157 *, struct inode___157 *, struct dentry___157 *);
	int (*unlink)(struct inode___157 *, struct dentry___157 *);
	int (*symlink)(struct user_namespace___23 *, struct inode___157 *, struct dentry___157 *, const char *);
	int (*mkdir)(struct user_namespace___23 *, struct inode___157 *, struct dentry___157 *, umode_t);
	int (*rmdir)(struct inode___157 *, struct dentry___157 *);
	int (*mknod)(struct user_namespace___23 *, struct inode___157 *, struct dentry___157 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___23 *, struct inode___157 *, struct dentry___157 *, struct inode___157 *, struct dentry___157 *, unsigned int);
	int (*setattr)(struct user_namespace___23 *, struct dentry___157 *, struct iattr___157 *);
	int (*getattr)(struct user_namespace___23 *, const struct path___157 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___157 *, char *, size_t);
	int (*fiemap)(struct inode___157 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___157 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___157 *, struct dentry___157 *, struct file___157 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___23 *, struct inode___157 *, struct dentry___157 *, umode_t);
	int (*set_acl)(struct user_namespace___23 *, struct inode___157 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___23 *, struct dentry___157 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___157 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___157 {
	void (*fl_copy_lock)(struct file_lock___157 *, struct file_lock___157 *);
	void (*fl_release_private)(struct file_lock___157 *);
};

struct lock_manager_operations___157;

struct file_lock___157 {
	struct file_lock___157 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___157 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___157 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___157 *fl_ops;
	const struct lock_manager_operations___157 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___157 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___157 *);
	int (*lm_grant)(struct file_lock___157 *, int);
	bool (*lm_break)(struct file_lock___157 *);
	int (*lm_change)(struct file_lock___157 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___157 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___157 *);
};

struct fasync_struct___157 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___157 *fa_next;
	struct file___157 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___157 {
	struct inode___157 * (*alloc_inode)(struct super_block___157 *);
	void (*destroy_inode)(struct inode___157 *);
	void (*free_inode)(struct inode___157 *);
	void (*dirty_inode)(struct inode___157 *, int);
	int (*write_inode)(struct inode___157 *, struct writeback_control___67 *);
	int (*drop_inode)(struct inode___157 *);
	void (*evict_inode)(struct inode___157 *);
	void (*put_super)(struct super_block___157 *);
	int (*sync_fs)(struct super_block___157 *, int);
	int (*freeze_super)(struct super_block___157 *);
	int (*freeze_fs)(struct super_block___157 *);
	int (*thaw_super)(struct super_block___157 *);
	int (*unfreeze_fs)(struct super_block___157 *);
	int (*statfs)(struct dentry___157 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___157 *, int *, char *);
	void (*umount_begin)(struct super_block___157 *);
	int (*show_options)(struct seq_file___135 *, struct dentry___157 *);
	int (*show_devname)(struct seq_file___135 *, struct dentry___157 *);
	int (*show_path)(struct seq_file___135 *, struct dentry___157 *);
	int (*show_stats)(struct seq_file___135 *, struct dentry___157 *);
	ssize_t (*quota_read)(struct super_block___157 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___157 *, int, const char *, size_t, loff_t);
	struct dquot___157 ** (*get_dquots)(struct inode___157 *);
	long int (*nr_cached_objects)(struct super_block___157 *, struct shrink_control___58 *);
	long int (*free_cached_objects)(struct super_block___157 *, struct shrink_control___58 *);
	struct file___157 * (*real_loop)(struct file___157 *);
};

struct block_device___71 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___157 *bd_inode;
	struct super_block___157 *bd_super;
	void *bd_claiming;
	struct device___113 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___144 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___70 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___157 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___100)(struct file___157 *, wait_queue_head_t *, struct poll_table_struct___98 *);

struct poll_table_struct___98 {
	poll_queue_proc___100 _qproc;
	__poll_t _key;
};

struct seq_operations___135;

struct seq_file___135 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___135 *op;
	int poll_event;
	const struct file___157 *file;
	void *private;
};

typedef void bio_end_io_t___70(struct bio___70 *);

struct bio_integrity_payload___70;

struct bio___70 {
	struct bio___70 *bi_next;
	struct block_device___71 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___70 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___67 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___70 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___84 *bi_io_vec;
	struct bio_set___70 *bi_pool;
	struct bio_vec___84 bi_inline_vecs[0];
};

struct dev_pagemap_ops___153 {
	void (*page_free)(struct page___162 *);
	void (*kill)(struct dev_pagemap___153 *);
	void (*cleanup)(struct dev_pagemap___153 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___153 *);
};

struct fwnode_operations___113;

struct fwnode_handle___113 {
	struct fwnode_handle___113 *secondary;
	const struct fwnode_operations___113 *ops;
	struct device___113 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___113;

struct fwnode_endpoint___113;

struct fwnode_operations___113 {
	struct fwnode_handle___113 * (*get)(struct fwnode_handle___113 *);
	void (*put)(struct fwnode_handle___113 *);
	bool (*device_is_available)(const struct fwnode_handle___113 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___113 *, const struct device___113 *);
	bool (*property_present)(const struct fwnode_handle___113 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___113 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___113 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___113 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*get_parent)(const struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*get_next_child_node)(const struct fwnode_handle___113 *, struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*get_named_child_node)(const struct fwnode_handle___113 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___113 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___113 *);
	struct fwnode_handle___113 * (*graph_get_next_endpoint)(const struct fwnode_handle___113 *, struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*graph_get_remote_endpoint)(const struct fwnode_handle___113 *);
	struct fwnode_handle___113 * (*graph_get_port_parent)(struct fwnode_handle___113 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___113 *, struct fwnode_endpoint___113 *);
	int (*add_links)(struct fwnode_handle___113 *);
};

struct fwnode_endpoint___113 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___113 *local_fwnode;
};

struct fwnode_reference_args___113 {
	struct fwnode_handle___113 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___144;

struct kernfs_elem_dir___144 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___144 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___144;

struct kernfs_root___144 {
	struct kernfs_node___144 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___144 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___144 {
	struct kernfs_node___144 *target_kn;
};

struct kernfs_ops___144;

struct kernfs_elem_attr___144 {
	const struct kernfs_ops___144 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___144 *notify_next;
};

struct kernfs_node___144 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___144 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___144 dir;
		struct kernfs_elem_symlink___144 symlink;
		struct kernfs_elem_attr___144 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___144;

struct kernfs_ops___144 {
	int (*open)(struct kernfs_open_file___144 *);
	void (*release)(struct kernfs_open_file___144 *);
	int (*seq_show)(struct seq_file___135 *, void *);
	void * (*seq_start)(struct seq_file___135 *, loff_t *);
	void * (*seq_next)(struct seq_file___135 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___135 *, void *);
	ssize_t (*read)(struct kernfs_open_file___144 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___144 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___144 *, struct poll_table_struct___98 *);
	int (*mmap)(struct kernfs_open_file___144 *, struct vm_area_struct___162 *);
};

struct kernfs_syscall_ops___144 {
	int (*show_options)(struct seq_file___135 *, struct kernfs_root___144 *);
	int (*mkdir)(struct kernfs_node___144 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___144 *);
	int (*rename)(struct kernfs_node___144 *, struct kernfs_node___144 *, const char *);
	int (*show_path)(struct seq_file___135 *, struct kernfs_node___144 *, struct kernfs_root___144 *);
};

struct kernfs_open_file___144 {
	struct kernfs_node___144 *kn;
	struct file___157 *file;
	struct seq_file___135 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___153 *vm_ops;
};

struct kobj_ns_type_operations___18 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___19 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___144;

struct attribute_group___144 {
	const char *name;
	umode_t (*is_visible)(struct kobject___144 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___144 *, struct bin_attribute___144 *, int);
	struct attribute **attrs;
	struct bin_attribute___144 **bin_attrs;
};

struct bin_attribute___144 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___157 * (*f_mapping)();
	ssize_t (*read)(struct file___157 *, struct kobject___144 *, struct bin_attribute___144 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___157 *, struct kobject___144 *, struct bin_attribute___144 *, char *, loff_t, size_t);
	int (*mmap)(struct file___157 *, struct kobject___144 *, struct bin_attribute___144 *, struct vm_area_struct___162 *);
};

struct sysfs_ops___144 {
	ssize_t (*show)(struct kobject___144 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___144 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___144;

struct kset___144 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___144 kobj;
	const struct kset_uevent_ops___144 *uevent_ops;
};

struct kobj_type___144 {
	void (*release)(struct kobject___144 *);
	const struct sysfs_ops___144 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___144 **default_groups;
	const struct kobj_ns_type_operations___18 * (*child_ns_type)(struct kobject___144 *);
	const void * (*namespace)(struct kobject___144 *);
	void (*get_ownership)(struct kobject___144 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___144 {
	int (* const filter)(struct kset___144 *, struct kobject___144 *);
	const char * (* const name)(struct kset___144 *, struct kobject___144 *);
	int (* const uevent)(struct kset___144 *, struct kobject___144 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___141 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___141 *);
	int (*get)(char *, const struct kernel_param___141 *);
	void (*free)(void *);
};

struct kparam_array___141;

struct kernel_param___141 {
	const char *name;
	struct module___142 *mod;
	const struct kernel_param_ops___141 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___141 *arr;
	};
};

struct kparam_array___141 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___141 *ops;
	void *elem;
};

struct module_attribute___141 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___141 *, struct module_kobject___141 *, char *);
	ssize_t (*store)(struct module_attribute___141 *, struct module_kobject___141 *, const char *, size_t);
	void (*setup)(struct module___142 *, const char *);
	int (*test)(struct module___142 *);
	void (*free)(struct module___142 *);
};

struct cgroup_namespace___106 {
	struct ns_common___26 ns;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct css_set___106 *root_cset;
};

struct socket_wq___19 {
	wait_queue_head_t wait;
	struct fasync_struct___157 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___19;

struct socket___19 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___157 *file;
	struct sock___19 *sk;
	const struct proto_ops___19 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___19 wq;
};

typedef int (*sk_read_actor_t___18)(read_descriptor_t *, struct sk_buff___27 *, unsigned int, size_t);

struct proto_ops___19 {
	int family;
	struct module___142 *owner;
	int (*release)(struct socket___19 *);
	int (*bind)(struct socket___19 *, struct sockaddr *, int);
	int (*connect)(struct socket___19 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___19 *, struct socket___19 *);
	int (*accept)(struct socket___19 *, struct socket___19 *, int, bool);
	int (*getname)(struct socket___19 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___157 *, struct socket___19 *, struct poll_table_struct___98 *);
	int (*ioctl)(struct socket___19 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___19 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___19 *, void *, bool, bool);
	int (*listen)(struct socket___19 *, int);
	int (*shutdown)(struct socket___19 *, int);
	int (*setsockopt)(struct socket___19 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___19 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___135 *, struct socket___19 *);
	int (*sendmsg)(struct socket___19 *, struct msghdr___19 *, size_t);
	int (*recvmsg)(struct socket___19 *, struct msghdr___19 *, size_t, int);
	int (*mmap)(struct file___157 *, struct socket___19 *, struct vm_area_struct___162 *);
	ssize_t (*sendpage)(struct socket___19 *, struct page___162 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___19 *, loff_t *, struct pipe_inode_info___50 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___19 *, int);
	int (*peek_len)(struct socket___19 *);
	int (*read_sock)(struct sock___19 *, read_descriptor_t *, sk_read_actor_t___18);
	int (*sendpage_locked)(struct sock___19 *, struct page___162 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___19 *, struct msghdr___19 *, size_t);
	int (*set_rcvlowat)(struct sock___19 *, int);
};

struct dev_pm_ops___113 {
	int (*prepare)(struct device___113 *);
	void (*complete)(struct device___113 *);
	int (*suspend)(struct device___113 *);
	int (*resume)(struct device___113 *);
	int (*freeze)(struct device___113 *);
	int (*thaw)(struct device___113 *);
	int (*poweroff)(struct device___113 *);
	int (*restore)(struct device___113 *);
	int (*suspend_late)(struct device___113 *);
	int (*resume_early)(struct device___113 *);
	int (*freeze_late)(struct device___113 *);
	int (*thaw_early)(struct device___113 *);
	int (*poweroff_late)(struct device___113 *);
	int (*restore_early)(struct device___113 *);
	int (*suspend_noirq)(struct device___113 *);
	int (*resume_noirq)(struct device___113 *);
	int (*freeze_noirq)(struct device___113 *);
	int (*thaw_noirq)(struct device___113 *);
	int (*poweroff_noirq)(struct device___113 *);
	int (*restore_noirq)(struct device___113 *);
	int (*runtime_suspend)(struct device___113 *);
	int (*runtime_resume)(struct device___113 *);
	int (*runtime_idle)(struct device___113 *);
};

struct wakeup_source___113 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___113 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___113 {
	struct dev_pm_ops___113 ops;
	int (*start)(struct device___113 *);
	void (*detach)(struct device___113 *, bool);
	int (*activate)(struct device___113 *);
	void (*sync)(struct device___113 *);
	void (*dismiss)(struct device___113 *);
};

struct bus_type___113 {
	const char *name;
	const char *dev_name;
	struct device___113 *dev_root;
	const struct attribute_group___144 **bus_groups;
	const struct attribute_group___144 **dev_groups;
	const struct attribute_group___144 **drv_groups;
	int (*match)(struct device___113 *, struct device_driver___113 *);
	int (*uevent)(struct device___113 *, struct kobj_uevent_env *);
	int (*probe)(struct device___113 *);
	void (*sync_state)(struct device___113 *);
	void (*remove)(struct device___113 *);
	void (*shutdown)(struct device___113 *);
	int (*online)(struct device___113 *);
	int (*offline)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	int (*num_vf)(struct device___113 *);
	int (*dma_configure)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___113 {
	const char *name;
	struct bus_type___113 *bus;
	struct module___142 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___113 *);
	void (*sync_state)(struct device___113 *);
	int (*remove)(struct device___113 *);
	void (*shutdown)(struct device___113 *);
	int (*suspend)(struct device___113 *, pm_message_t);
	int (*resume)(struct device___113 *);
	const struct attribute_group___144 **groups;
	const struct attribute_group___144 **dev_groups;
	const struct dev_pm_ops___113 *pm;
	void (*coredump)(struct device___113 *);
	struct driver_private *p;
};

struct device_type___113 {
	const char *name;
	const struct attribute_group___144 **groups;
	int (*uevent)(struct device___113 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___113 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___113 *);
	const struct dev_pm_ops___113 *pm;
};

struct class___113 {
	const char *name;
	struct module___142 *owner;
	const struct attribute_group___144 **class_groups;
	const struct attribute_group___144 **dev_groups;
	struct kobject___144 *dev_kobj;
	int (*dev_uevent)(struct device___113 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___113 *, umode_t *);
	void (*class_release)(struct class___113 *);
	void (*dev_release)(struct device___113 *);
	int (*shutdown_pre)(struct device___113 *);
	const struct kobj_ns_type_operations___18 *ns_type;
	const void * (*namespace)(struct device___113 *);
	void (*get_ownership)(struct device___113 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___113 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___50;

struct pipe_buffer___50 {
	struct page___162 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___50 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___50 {
	int (*confirm)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
	void (*release)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
	bool (*try_steal)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
	bool (*get)(struct pipe_inode_info___50 *, struct pipe_buffer___50 *);
};

struct seq_operations___135 {
	void * (*start)(struct seq_file___135 *, loff_t *);
	void (*stop)(struct seq_file___135 *, void *);
	void * (*next)(struct seq_file___135 *, void *, loff_t *);
	int (*show)(struct seq_file___135 *, void *);
};

struct dcbnl_rtnl_ops___25 {
	int (*ieee_getets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___28 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___28 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___28 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___28 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___28 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___28 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___28 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___28 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___28 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___28 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___28 *);
	u8 (*setstate)(struct net_device___28 *, u8);
	void (*getpermhwaddr)(struct net_device___28 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___28 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___28 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___28 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___28 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___28 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___28 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___28 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___28 *, int, u8 *);
	void (*setpfccfg)(struct net_device___28 *, int, u8);
	void (*getpfccfg)(struct net_device___28 *, int, u8 *);
	u8 (*setall)(struct net_device___28 *);
	u8 (*getcap)(struct net_device___28 *, int, u8 *);
	int (*getnumtcs)(struct net_device___28 *, int, u8 *);
	int (*setnumtcs)(struct net_device___28 *, int, u8);
	u8 (*getpfcstate)(struct net_device___28 *);
	void (*setpfcstate)(struct net_device___28 *, u8);
	void (*getbcncfg)(struct net_device___28 *, int, u32 *);
	void (*setbcncfg)(struct net_device___28 *, int, u32);
	void (*getbcnrp)(struct net_device___28 *, int, u8 *);
	void (*setbcnrp)(struct net_device___28 *, int, u8);
	int (*setapp)(struct net_device___28 *, u8, u16, u8);
	int (*getapp)(struct net_device___28 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___28 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___28 *, int, u8);
	u8 (*getdcbx)(struct net_device___28 *);
	u8 (*setdcbx)(struct net_device___28 *, u8);
	int (*peer_getappinfo)(struct net_device___28 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___28 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___28 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___28 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___28 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___28 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___28;

typedef int (*bpf_iter_init_seq_priv_t___27)(void *, struct bpf_iter_aux_info___28 *);

struct bpf_map___27;

struct bpf_iter_aux_info___28 {
	struct bpf_map___27 *map;
};

struct bpf_iter_seq_info___27 {
	const struct seq_operations___135 *seq_ops;
	bpf_iter_init_seq_priv_t___27 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___27 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___27 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___27 *, struct file___157 *);
	void (*map_free)(struct bpf_map___27 *);
	int (*map_get_next_key)(struct bpf_map___27 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___27 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___27 *, void *);
	int (*map_lookup_batch)(struct bpf_map___27 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___27 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___27 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___27 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___27 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___27 *, void *);
	int (*map_update_elem)(struct bpf_map___27 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___27 *, void *);
	int (*map_push_elem)(struct bpf_map___27 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___27 *, void *);
	int (*map_peek_elem)(struct bpf_map___27 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___27 *, struct file___157 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___27 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___27 *, void *, struct seq_file___135 *);
	int (*map_check_btf)(const struct bpf_map___27 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___27 *, struct bpf_prog_aux___27 *);
	void (*map_poke_untrack)(struct bpf_map___27 *, struct bpf_prog_aux___27 *);
	void (*map_poke_run)(struct bpf_map___27 *, u32, struct bpf_prog___25 *, struct bpf_prog___25 *);
	int (*map_direct_value_addr)(const struct bpf_map___27 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___27 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___27 *, struct vm_area_struct___162 *);
	__poll_t (*map_poll)(struct bpf_map___27 *, struct file___157 *, struct poll_table_struct___98 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___27 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___27 *, const struct bpf_map___27 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___27 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___27 *iter_seq_info;
};

struct bpf_map___27 {
	const struct bpf_map_ops___27 *ops;
	struct bpf_map___27 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___58 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___27;

struct bpf_jit_poke_descriptor___27;

struct bpf_prog_ops___25;

struct btf_mod_pair___27;

struct bpf_prog_offload___25;

struct bpf_prog_aux___27 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___25 *dst_prog;
	struct bpf_trampoline___27 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___25 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___27 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___25 *ops;
	struct bpf_map___27 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___27 *used_btfs;
	struct bpf_prog___25 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___27 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___25 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___25;

struct bpf_map_dev_ops___25 {
	int (*map_get_next_key)(struct bpf_offloaded_map___25 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___25 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___25 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___25 *, void *);
};

struct bpf_offloaded_map___25 {
	struct bpf_map___27 map;
	struct net_device___28 *netdev;
	const struct bpf_map_dev_ops___25 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___25 {
	int (*test_run)(struct bpf_prog___25 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___25 {
	struct bpf_prog___25 *prog;
	struct net_device___28 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___27 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___25 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___142 *mod;
};

struct bpf_jit_poke_descriptor___27 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___27 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___27 {
	struct btf *btf;
	struct module___142 *module;
};

struct cftype___106;

struct cgroup_subsys___106 {
	struct cgroup_subsys_state___106 * (*css_alloc)(struct cgroup_subsys_state___106 *);
	int (*css_online)(struct cgroup_subsys_state___106 *);
	void (*css_offline)(struct cgroup_subsys_state___106 *);
	void (*css_released)(struct cgroup_subsys_state___106 *);
	void (*css_free)(struct cgroup_subsys_state___106 *);
	void (*css_reset)(struct cgroup_subsys_state___106 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___106 *, int);
	int (*css_extra_stat_show)(struct seq_file___135 *, struct cgroup_subsys_state___106 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___164 *, struct css_set___106 *);
	void (*cancel_fork)(struct task_struct___164 *, struct css_set___106 *);
	void (*fork)(struct task_struct___164 *);
	void (*exit)(struct task_struct___164 *);
	void (*release)(struct task_struct___164 *);
	void (*bind)(struct cgroup_subsys_state___106 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___106 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___106 *dfl_cftypes;
	struct cftype___106 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___106 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___106 *updated_children;
	struct cgroup___106 *updated_next;
};

struct cgroup_root___106 {
	struct kernfs_root___144 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___106 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___106 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___106 *ss;
	struct list_head node;
	struct kernfs_ops___144 *kf_ops;
	int (*open)(struct kernfs_open_file___144 *);
	void (*release)(struct kernfs_open_file___144 *);
	u64 (*read_u64)(struct cgroup_subsys_state___106 *, struct cftype___106 *);
	s64 (*read_s64)(struct cgroup_subsys_state___106 *, struct cftype___106 *);
	int (*seq_show)(struct seq_file___135 *, void *);
	void * (*seq_start)(struct seq_file___135 *, loff_t *);
	void * (*seq_next)(struct seq_file___135 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___135 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___106 *, struct cftype___106 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___106 *, struct cftype___106 *, s64);
	ssize_t (*write)(struct kernfs_open_file___144 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___144 *, struct poll_table_struct___98 *);
};

struct xdp_rxq_info___25 {
	struct net_device___28 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___25 {
	struct net_device___28 *dev;
};

struct xdp_buff___25 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___25 *rxq;
	struct xdp_txq_info___25 *txq;
	u32 frame_sz;
};

struct xdp_frame___25 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___28 *dev_rx;
};

struct netlink_callback___25 {
	struct sk_buff___27 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___27 *, struct netlink_callback___25 *);
	int (*done)(struct netlink_callback___25 *);
	void *data;
	struct module___142 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___25 {
	int (*create)(struct sk_buff___27 *, struct net_device___28 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___27 *, unsigned char *);
	int (*cache)(const struct neighbour___18 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___28 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___27 *);
};

struct netdev_queue___25 {
	struct net_device___28 *dev;
	struct Qdisc___25 *qdisc;
	struct Qdisc___25 *qdisc_sleeping;
	struct kobject___144 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___28 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___25 {
	struct sk_buff___27 *head;
	struct sk_buff___27 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___25;

struct Qdisc___25 {
	int (*enqueue)(struct sk_buff___27 *, struct Qdisc___25 *, struct sk_buff___27 **);
	struct sk_buff___27 * (*dequeue)(struct Qdisc___25 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___25 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___25 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___25 gso_skb;
	struct qdisc_skb_head___25 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___25 *next_sched;
	struct sk_buff_head___25 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___25 {
	struct xdp_rxq_info___25 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___144 kobj;
	struct net_device___28 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___25 {
	enum net_device_path_type type;
	const struct net_device___28 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___25 = 0,
				DEV_PATH_BR_VLAN_TAG___25 = 1,
				DEV_PATH_BR_VLAN_UNTAG___25 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___25 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___25 {
	const struct net_device___28 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___25 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___25 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___25 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___25 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___27 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___25 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___28 *dev;
	const char *name;
};

struct net_device_ops___25 {
	int (*ndo_init)(struct net_device___28 *);
	void (*ndo_uninit)(struct net_device___28 *);
	int (*ndo_open)(struct net_device___28 *);
	int (*ndo_stop)(struct net_device___28 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___27 *, struct net_device___28 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___27 *, struct net_device___28 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___28 *, struct sk_buff___27 *, struct net_device___28 *);
	void (*ndo_change_rx_flags)(struct net_device___28 *, int);
	void (*ndo_set_rx_mode)(struct net_device___28 *);
	int (*ndo_set_mac_address)(struct net_device___28 *, void *);
	int (*ndo_validate_addr)(struct net_device___28 *);
	int (*ndo_do_ioctl)(struct net_device___28 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___28 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___28 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___28 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___28 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___28 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___28 *, int);
	int (*ndo_neigh_setup)(struct net_device___28 *, struct neigh_parms___18 *);
	void (*ndo_tx_timeout)(struct net_device___28 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___28 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___28 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___28 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___28 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___28 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___28 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___28 *);
	int (*ndo_netpoll_setup)(struct net_device___28 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___28 *);
	int (*ndo_set_vf_mac)(struct net_device___28 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___28 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___28 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___28 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___28 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___28 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___28 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___28 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___28 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___28 *, int, struct sk_buff___27 *);
	int (*ndo_get_vf_guid)(struct net_device___28 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___28 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___28 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___28 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___28 *);
	int (*ndo_fcoe_disable)(struct net_device___28 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___28 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___28 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___28 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___28 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___28 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___28 *, const struct sk_buff___27 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___28 *, struct net_device___28 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___28 *, struct net_device___28 *);
	struct net_device___28 * (*ndo_get_xmit_slave)(struct net_device___28 *, struct sk_buff___27 *, bool);
	struct net_device___28 * (*ndo_sk_get_lower_dev)(struct net_device___28 *, struct sock___19 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___28 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___28 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___28 *, struct neighbour___18 *);
	void (*ndo_neigh_destroy)(struct net_device___28 *, struct neighbour___18 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___27 *, struct netlink_callback___25 *, struct net_device___28 *, struct net_device___28 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___27 *, struct nlattr **, struct net_device___28 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___28 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___27 *, u32, u32, struct net_device___28 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___28 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___28 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___28 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___28 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___28 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___28 *, struct net_device___28 *);
	void (*ndo_dfwd_del_station)(struct net_device___28 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___28 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___28 *);
	int (*ndo_change_proto_down)(struct net_device___28 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___28 *, struct sk_buff___27 *);
	void (*ndo_set_rx_headroom)(struct net_device___28 *, int);
	int (*ndo_bpf)(struct net_device___28 *, struct netdev_bpf___25 *);
	int (*ndo_xdp_xmit)(struct net_device___28 *, int, struct xdp_frame___25 **, u32);
	struct net_device___28 * (*ndo_xdp_get_xmit_slave)(struct net_device___28 *, struct xdp_buff___25 *);
	int (*ndo_xsk_wakeup)(struct net_device___28 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___28 *);
	int (*ndo_tunnel_ctl)(struct net_device___28 *, struct ip_tunnel_parm *, int);
	struct net_device___28 * (*ndo_get_peer_dev)(struct net_device___28 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___25 *, struct net_device_path___25 *);
};

struct neigh_parms___18 {
	possible_net_t___25 net;
	struct net_device___28 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___18 *);
	struct neigh_table___18 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___3 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___28 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___28 *);
	void (*get_regs)(struct net_device___28 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___28 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___28 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___28 *);
	void (*set_msglevel)(struct net_device___28 *, u32);
	int (*nway_reset)(struct net_device___28 *);
	u32 (*get_link)(struct net_device___28 *);
	int (*get_link_ext_state)(struct net_device___28 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___28 *);
	int (*get_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___28 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___28 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___28 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___28 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___28 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___28 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___28 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___28 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___28 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___28 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___28 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___28 *);
	void (*complete)(struct net_device___28 *);
	u32 (*get_priv_flags)(struct net_device___28 *);
	int (*set_priv_flags)(struct net_device___28 *, u32);
	int (*get_sset_count)(struct net_device___28 *, int);
	int (*get_rxnfc)(struct net_device___28 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___28 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___28 *, struct ethtool_flash *);
	int (*reset)(struct net_device___28 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___28 *);
	u32 (*get_rxfh_indir_size)(struct net_device___28 *);
	int (*get_rxfh)(struct net_device___28 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___28 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___28 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___28 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___28 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___28 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___28 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___28 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___28 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___28 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___28 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___28 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___28 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___28 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___28 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___28 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___28 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___28 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___28 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___28 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___28 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___28 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___28 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___28 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___28 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___28 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___28 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___28 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___28 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___28 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___28 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___18 {
	u32 (*l3mdev_fib_table)(const struct net_device___28 *);
	struct sk_buff___27 * (*l3mdev_l3_rcv)(struct net_device___28 *, struct sk_buff___27 *, u16);
	struct sk_buff___27 * (*l3mdev_l3_out)(struct net_device___28 *, struct sock___19 *, struct sk_buff___27 *, u16);
	struct dst_entry___18 * (*l3mdev_link_scope_lookup)(const struct net_device___28 *, struct flowi6 *);
};

struct ndisc_ops___8 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___28 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___28 *, struct neighbour___18 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___28 *, u8, struct neighbour___18 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___28 *, struct sk_buff___27 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___31 *, struct net_device___28 *, const struct prefix_info *, struct inet6_dev___8 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___8;

struct inet6_dev___8 {
	struct net_device___28 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___8 *mc_list;
	struct ifmcaddr6___8 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___25 mc_query_queue;
	struct sk_buff_head___25 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___18 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___25;

struct tcf_block___25;

struct mini_Qdisc___25 {
	struct tcf_proto___25 *filter_list;
	struct tcf_block___25 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___25 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___28 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___28 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___31 *, struct net_device___28 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___28 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___28 *, struct list_head *);
	size_t (*get_size)(const struct net_device___28 *);
	int (*fill_info)(struct sk_buff___27 *, const struct net_device___28 *);
	size_t (*get_xstats_size)(const struct net_device___28 *);
	int (*fill_xstats)(struct sk_buff___27 *, const struct net_device___28 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___28 *, struct net_device___28 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___28 *, const struct net_device___28 *);
	int (*fill_slave_info)(struct sk_buff___27 *, const struct net_device___28 *, const struct net_device___28 *);
	struct net___31 * (*get_link_net)(const struct net_device___28 *);
	size_t (*get_linkxstats_size)(const struct net_device___28 *, int);
	int (*fill_linkxstats)(struct sk_buff___27 *, const struct net_device___28 *, int *, int);
};

struct netdev_notifier_info___2 {
	struct net_device___28 *dev;
	struct netlink_ext_ack *extack;
};

struct selinux_state___3 {
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[8];
	struct page___162 *status_page;
	struct mutex status_lock;
	struct selinux_avc___2 *avc;
	struct selinux_policy *policy;
	struct mutex policy_mutex;
};

struct linux_binprm___30 {
	struct vm_area_struct___162 *vma;
	long unsigned int vma_pages;
	struct mm_struct___163 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___157 *executable;
	struct file___157 *interpreter;
	struct file___157 *file;
	struct cred___26 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___29 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___157 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct request_sock_ops___8;

struct request_sock___9 {
	struct sock_common___18 __req_common;
	struct request_sock___9 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___8 *rsk_ops;
	struct sock___19 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct block_device_operations___70;

struct gendisk___70 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___71 *part0;
	const struct block_device_operations___70 *fops;
	struct request_queue___70 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___67 *bdi;
	struct kobject___144 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___144 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___70 {
	struct bio___70 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___84 *bip_vec;
	struct bio_vec___84 bip_inline_vecs[0];
};

struct blkcg___67;

struct blkg_policy_data___67;

struct blkcg_gq___67 {
	struct request_queue___70 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___67 *blkcg;
	struct blkcg_gq___67 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___67 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___70 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___70(struct request___70 *);

typedef void integrity_complete_fn___70(struct request___70 *, unsigned int);

struct blk_integrity_profile___70 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___70 *prepare_fn;
	integrity_complete_fn___70 *complete_fn;
	const char *name;
};

struct block_device_operations___70 {
	blk_qc_t (*submit_bio)(struct bio___70 *);
	int (*open)(struct block_device___71 *, fmode_t);
	void (*release)(struct gendisk___70 *, fmode_t);
	int (*rw_page)(struct block_device___71 *, sector_t, struct page___162 *, unsigned int);
	int (*ioctl)(struct block_device___71 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___71 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___70 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___70 *);
	int (*getgeo)(struct block_device___71 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___71 *, bool);
	void (*swap_slot_free_notify)(struct block_device___71 *, long unsigned int);
	int (*report_zones)(struct gendisk___70 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___70 *, umode_t *);
	struct module___142 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___70 *, sector_t *);
};

typedef void rq_end_io_fn___70(struct request___70 *, blk_status_t);

struct request___70 {
	struct request_queue___70 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___67 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___70 *bio;
	struct bio___70 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___84 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___70 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___70 *saved_end_io;
		} flush;
	};
	struct gendisk___70 *rq_disk;
	struct block_device___71 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___70 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___67 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___70 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___144 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___157 *debugfs_dir;
	struct dentry___157 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___70;

struct elevator_mq_ops___70 {
	int (*init_sched)(struct request_queue___70 *, struct elevator_type___70 *);
	void (*exit_sched)(struct elevator_queue___70 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___67 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___67 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___67 *);
	bool (*allow_merge)(struct request_queue___70 *, struct request___70 *, struct bio___70 *);
	bool (*bio_merge)(struct request_queue___70 *, struct bio___70 *, unsigned int);
	int (*request_merge)(struct request_queue___70 *, struct request___70 **, struct bio___70 *);
	void (*request_merged)(struct request_queue___70 *, struct request___70 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___70 *, struct request___70 *, struct request___70 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___70 *);
	void (*finish_request)(struct request___70 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___67 *, struct list_head *, bool);
	struct request___70 * (*dispatch_request)(struct blk_mq_hw_ctx___67 *);
	bool (*has_work)(struct blk_mq_hw_ctx___67 *);
	void (*completed_request)(struct request___70 *, u64);
	void (*requeue_request)(struct request___70 *);
	struct request___70 * (*former_request)(struct request_queue___70 *, struct request___70 *);
	struct request___70 * (*next_request)(struct request_queue___70 *, struct request___70 *);
	void (*init_icq)(struct io_cq___70 *);
	void (*exit_icq)(struct io_cq___70 *);
};

struct elv_fs_entry___70;

struct elevator_type___70 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___70 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___70 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___142 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___70 {
	struct elevator_type___70 *type;
	void *elevator_data;
	struct kobject___144 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___70 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___70 *, char *);
	ssize_t (*store)(struct elevator_queue___70 *, const char *, size_t);
};

struct blk_mq_queue_data___67;

struct blk_mq_ops___67 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___67 *, const struct blk_mq_queue_data___67 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___67 *);
	int (*get_budget)(struct request_queue___70 *);
	void (*put_budget)(struct request_queue___70 *, int);
	void (*set_rq_budget_token)(struct request___70 *, int);
	int (*get_rq_budget_token)(struct request___70 *);
	enum blk_eh_timer_return (*timeout)(struct request___70 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___67 *);
	void (*complete)(struct request___70 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___67 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___67 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___67 *, struct request___70 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___67 *, struct request___70 *, unsigned int);
	void (*initialize_rq_fn)(struct request___70 *);
	void (*cleanup_rq)(struct request___70 *);
	bool (*busy)(struct request_queue___70 *);
	int (*map_queues)(struct blk_mq_tag_set___67 *);
	void (*show_rq)(struct seq_file___135 *, struct request___70 *);
};

struct blk_mq_tag_set___67 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___67 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___67 {
	struct request___70 *rq;
	bool last;
};

struct blkcg_policy_data___67;

struct blkcg___67 {
	struct cgroup_subsys_state___106 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___67 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___67 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___67 {
	struct blkcg___67 *blkcg;
	int plid;
};

struct blkg_policy_data___67 {
	struct blkcg_gq___67 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___58 {
	struct mem_cgroup___58 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___58 {
	struct lruvec___65 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___58 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___58 *memcg;
};

struct obj_cgroup___58 {
	struct percpu_ref refcnt;
	struct mem_cgroup___58 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___25 {
	spinlock_t *lock;
	struct sk_buff___27 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___25;

struct Qdisc_ops___25 {
	struct Qdisc_ops___25 *next;
	const struct Qdisc_class_ops___25 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___27 *, struct Qdisc___25 *, struct sk_buff___27 **);
	struct sk_buff___27 * (*dequeue)(struct Qdisc___25 *);
	struct sk_buff___27 * (*peek)(struct Qdisc___25 *);
	int (*init)(struct Qdisc___25 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___25 *);
	void (*destroy)(struct Qdisc___25 *);
	int (*change)(struct Qdisc___25 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___25 *);
	int (*change_tx_queue_len)(struct Qdisc___25 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___25 *, unsigned int);
	int (*dump)(struct Qdisc___25 *, struct sk_buff___27 *);
	int (*dump_stats)(struct Qdisc___25 *, struct gnet_dump___25 *);
	void (*ingress_block_set)(struct Qdisc___25 *, u32);
	void (*egress_block_set)(struct Qdisc___25 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___25 *);
	u32 (*egress_block_get)(struct Qdisc___25 *);
	struct module___142 *owner;
};

struct Qdisc_class_ops___25 {
	unsigned int flags;
	struct netdev_queue___25 * (*select_queue)(struct Qdisc___25 *, struct tcmsg *);
	int (*graft)(struct Qdisc___25 *, long unsigned int, struct Qdisc___25 *, struct Qdisc___25 **, struct netlink_ext_ack *);
	struct Qdisc___25 * (*leaf)(struct Qdisc___25 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___25 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___25 *, u32);
	int (*change)(struct Qdisc___25 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___25 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___25 *, struct qdisc_walker *);
	struct tcf_block___25 * (*tcf_block)(struct Qdisc___25 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___25 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___25 *, long unsigned int);
	int (*dump)(struct Qdisc___25 *, long unsigned int, struct sk_buff___27 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___25 *, long unsigned int, struct gnet_dump___25 *);
};

struct tcf_chain___25;

struct tcf_block___25 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___31 *net;
	struct Qdisc___25 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___25 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___25;

struct tcf_proto_ops___25;

struct tcf_proto___25 {
	struct tcf_proto___25 *next;
	void *root;
	int (*classify)(struct sk_buff___27 *, const struct tcf_proto___25 *, struct tcf_result___25 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___25 *ops;
	struct tcf_chain___25 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___25 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___25 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___25 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___27 *, const struct tcf_proto___25 *, struct tcf_result___25 *);
	int (*init)(struct tcf_proto___25 *);
	void (*destroy)(struct tcf_proto___25 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___25 *, u32);
	void (*put)(struct tcf_proto___25 *, void *);
	int (*change)(struct net___31 *, struct sk_buff___27 *, struct tcf_proto___25 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___25 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___25 *);
	void (*walk)(struct tcf_proto___25 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___25 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___25 *, void *);
	void (*hw_del)(struct tcf_proto___25 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___31 *, struct tcf_chain___25 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___31 *, struct tcf_proto___25 *, void *, struct sk_buff___27 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___31 *, struct tcf_proto___25 *, void *, struct sk_buff___27 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___27 *, struct net___31 *, void *);
	struct module___142 *owner;
	int flags;
};

struct tcf_chain___25 {
	struct mutex filter_chain_lock;
	struct tcf_proto___25 *filter_chain;
	struct list_head list;
	struct tcf_block___25 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___25 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___18 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___25 *prog;
};

struct pneigh_entry___18;

struct neigh_hash_table___18;

struct neigh_table___18 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___28 *, __u32 *);
	bool (*key_eq)(const struct neighbour___18 *, const void *);
	int (*constructor)(struct neighbour___18 *);
	int (*pconstructor)(struct pneigh_entry___18 *);
	void (*pdestructor)(struct pneigh_entry___18 *);
	void (*proxy_redo)(struct sk_buff___27 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___28 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___18 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___25 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___18 *nht;
	struct pneigh_entry___18 **phash_buckets;
};

struct neigh_ops___18 {
	int family;
	void (*solicit)(struct neighbour___18 *, struct sk_buff___27 *);
	void (*error_report)(struct neighbour___18 *, struct sk_buff___27 *);
	int (*output)(struct neighbour___18 *, struct sk_buff___27 *);
	int (*connected_output)(struct neighbour___18 *, struct sk_buff___27 *);
};

struct pneigh_entry___18 {
	struct pneigh_entry___18 *next;
	possible_net_t___25 net;
	struct net_device___28 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___18 {
	struct neighbour___18 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___5 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___31 *, struct sock___19 *, struct sk_buff___27 *);
	int (*orig_input)(struct sk_buff___27 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___18 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___18 *ctarget;
	struct net___31 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___18 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___18 *rule;
	u32 table;
	int flags;
};

struct timewait_sock_ops___8;

struct proto___18 {
	void (*close)(struct sock___19 *, long int);
	int (*pre_connect)(struct sock___19 *, struct sockaddr *, int);
	int (*connect)(struct sock___19 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___19 *, int);
	struct sock___19 * (*accept)(struct sock___19 *, int, int *, bool);
	int (*ioctl)(struct sock___19 *, int, long unsigned int);
	int (*init)(struct sock___19 *);
	void (*destroy)(struct sock___19 *);
	void (*shutdown)(struct sock___19 *, int);
	int (*setsockopt)(struct sock___19 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___19 *, int, int, char *, int *);
	void (*keepalive)(struct sock___19 *, int);
	int (*compat_ioctl)(struct sock___19 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___19 *, struct msghdr___19 *, size_t);
	int (*recvmsg)(struct sock___19 *, struct msghdr___19 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___19 *, struct page___162 *, int, size_t, int);
	int (*bind)(struct sock___19 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___19 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___19 *, struct sk_buff___27 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___19 *);
	int (*hash)(struct sock___19 *);
	void (*unhash)(struct sock___19 *);
	void (*rehash)(struct sock___19 *);
	int (*get_port)(struct sock___19 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___19 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___19 *, int);
	bool (*sock_is_readable)(struct sock___19 *);
	void (*enter_memory_pressure)(struct sock___19 *);
	void (*leave_memory_pressure)(struct sock___19 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___8 *rsk_prot;
	struct timewait_sock_ops___8 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___142 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___19 *, int);
};

struct request_sock_ops___8 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___19 *, struct request_sock___9 *);
	void (*send_ack)(const struct sock___19 *, struct sk_buff___27 *, struct request_sock___9 *);
	void (*send_reset)(const struct sock___19 *, struct sk_buff___27 *);
	void (*destructor)(struct request_sock___9 *);
	void (*syn_ack_timeout)(const struct request_sock___9 *);
};

struct timewait_sock_ops___8 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___19 *, struct sock___19 *, void *);
	void (*twsk_destructor)(struct sock___19 *);
};

struct ifmcaddr6___8 {
	struct in6_addr mca_addr;
	struct inet6_dev___8 *idev;
	struct ifmcaddr6___8 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct netif_security_struct {
	struct net___31 *ns;
	int ifindex;
	u32 sid;
};

struct sel_netif {
	struct list_head list;
	struct netif_security_struct nsec;
	struct callback_head callback_head;
};

struct netnode_security_struct {
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} addr;
	u32 sid;
	u16 family;
};

struct sel_netnode_bkt {
	unsigned int size;
	struct list_head list;
};

struct sel_netnode {
	struct netnode_security_struct nsec;
	struct list_head list;
	struct callback_head rcu;
};

struct netport_security_struct {
	u32 sid;
	u16 port;
	u8 protocol;
};

struct sel_netport_bkt {
	int size;
	struct list_head list;
};

struct sel_netport {
	struct netport_security_struct psec;
	struct list_head list;
	struct callback_head rcu;
};

struct dentry___158;

struct super_block___158;

struct module___143;

struct file_system_type___158 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___158 * (*mount)(struct file_system_type___158 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___158 *);
	struct module___143 *owner;
	struct file_system_type___158 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___158;

struct kiocb___158;

struct iov_iter___87;

struct poll_table_struct___99;

struct vm_area_struct___163;

struct inode___158;

struct file_lock___158;

struct page___163;

struct pipe_inode_info___51;

struct seq_file___136;

struct file_operations___158 {
	struct module___143 *owner;
	loff_t (*llseek)(struct file___158 *, loff_t, int);
	ssize_t (*read)(struct file___158 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___158 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___158 *, struct iov_iter___87 *);
	ssize_t (*write_iter)(struct kiocb___158 *, struct iov_iter___87 *);
	int (*iopoll)(struct kiocb___158 *, bool);
	int (*iterate)(struct file___158 *, struct dir_context *);
	int (*iterate_shared)(struct file___158 *, struct dir_context *);
	__poll_t (*poll)(struct file___158 *, struct poll_table_struct___99 *);
	long int (*unlocked_ioctl)(struct file___158 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___158 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___158 *, struct vm_area_struct___163 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___158 *, struct file___158 *);
	int (*flush)(struct file___158 *, fl_owner_t);
	int (*release)(struct inode___158 *, struct file___158 *);
	int (*fsync)(struct file___158 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___158 *, int);
	int (*lock)(struct file___158 *, int, struct file_lock___158 *);
	ssize_t (*sendpage)(struct file___158 *, struct page___163 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___158 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___158 *, long unsigned int);
	int (*flock)(struct file___158 *, int, struct file_lock___158 *);
	ssize_t (*splice_write)(struct pipe_inode_info___51 *, struct file___158 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___158 *, loff_t *, struct pipe_inode_info___51 *, size_t, unsigned int);
	int (*setlease)(struct file___158 *, long int, struct file_lock___158 **, void **);
	long int (*fallocate)(struct file___158 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___136 *, struct file___158 *);
	ssize_t (*copy_file_range)(struct file___158 *, loff_t, struct file___158 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___158 *, loff_t, struct file___158 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___158 *, loff_t, loff_t, int);
};

struct vmacache___163 {
	u64 seqnum;
	struct vm_area_struct___163 *vmas[4];
};

struct page_frag___163 {
	struct page___163 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___164;

struct pid___139;

struct nsproxy___148;

struct signal_struct___159;

struct bio_list___71;

struct backing_dev_info___68;

struct io_context___71;

struct css_set___107;

struct mem_cgroup___59;

struct request_queue___71;

struct vm_struct___142;

struct task_struct___165 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___165 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___164 *mm;
	struct mm_struct___164 *active_mm;
	struct vmacache___163 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___165 *real_parent;
	struct task_struct___165 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___165 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___139 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___26 *ptracer_cred;
	const struct cred___26 *real_cred;
	const struct cred___26 *cred;
	struct key___7 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___148 *nsproxy;
	struct signal_struct___159 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___165 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___71 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___68 *backing_dev_info;
	struct io_context___71 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___107 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___51 *splice_pipe;
	struct page_frag___163 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___59 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___59 *active_memcg;
	struct request_queue___71 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___165 *oom_reaper_list;
	struct vm_struct___142 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___145;

struct kobj_type___145;

struct kernfs_node___145;

struct kobject___145 {
	const char *name;
	struct list_head entry;
	struct kobject___145 *parent;
	struct kset___145 *kset;
	struct kobj_type___145 *ktype;
	struct kernfs_node___145 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___142 {
	struct kobject___145 kobj;
	struct module___143 *mod;
	struct kobject___145 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___142 {
	struct module___143 *mod;
	struct latch_tree_node node;
};

struct module_layout___142 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___142 mtn;
};

struct module_attribute___142;

struct kernel_param___142;

struct module___143 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___142 mkobj;
	struct module_attribute___142 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___145 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___142 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___142 core_layout;
	struct module_layout___142 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___163 *pgtable_t___163;

struct address_space___158;

struct page_pool___42;

struct dev_pagemap___154;

struct page___163 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___158 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___42 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___163 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___163 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___164 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___154 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___154;

struct vm_area_struct___163 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___163 *vm_next;
	struct vm_area_struct___163 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___164 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___154 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___158 *vm_file;
	struct file___158 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___163;

struct mm_struct___164 {
	struct {
		struct vm_area_struct___163 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___158 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___163 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___165 *owner;
		struct user_namespace___23 *user_ns;
		struct file___158 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___158;

struct address_space___158 {
	struct inode___158 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___158 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___114;

struct page_pool_params___42 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___114 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___42 {
	u32 count;
	struct page___163 *cache[128];
};

struct page_pool___42 {
	struct page_pool_params___42 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___163 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___42 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___154;

struct dev_pagemap___154 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___154 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___158;

struct path___158 {
	struct vfsmount___158 *mnt;
	struct dentry___158 *dentry;
};

struct fown_struct___139 {
	rwlock_t lock;
	struct pid___139 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___158 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___158 f_path;
	struct inode___158 *f_inode;
	const struct file_operations___158 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___139 f_owner;
	const struct cred___26 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___158 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___154;

struct vm_operations_struct___154 {
	void (*open)(struct vm_area_struct___163 *);
	void (*close)(struct vm_area_struct___163 *);
	int (*may_split)(struct vm_area_struct___163 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___163 *);
	int (*mprotect)(struct vm_area_struct___163 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___154 *);
	vm_fault_t (*huge_fault)(struct vm_fault___154 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___154 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___163 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___154 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___154 *);
	int (*access)(struct vm_area_struct___163 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___163 *);
	int (*set_policy)(struct vm_area_struct___163 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___163 *, long unsigned int);
	struct page___163 * (*find_special_page)(struct vm_area_struct___163 *, long unsigned int);
};

struct core_thread___163 {
	struct task_struct___165 *task;
	struct core_thread___163 *next;
};

struct core_state___163 {
	atomic_t nr_threads;
	struct core_thread___163 dumper;
	struct completion startup;
};

struct vm_fault___154 {
	const struct {
		struct vm_area_struct___163 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___163 *cow_page;
	struct page___163 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___163 prealloc_pte;
};

struct pglist_data___66;

struct lruvec___66 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___66 *pgdat;
};

struct zone___66 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___66 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___66 {
	struct zone___66 *zone;
	int zone_idx;
};

struct zonelist___66 {
	struct zoneref___66 _zonerefs[321];
};

struct pglist_data___66 {
	struct zone___66 node_zones[5];
	struct zonelist___66 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___165 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___165 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___66 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___59 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___59 *memcg;
};

struct cgroup___107;

struct cgroup_subsys___107;

struct cgroup_subsys_state___107 {
	struct cgroup___107 *cgroup;
	struct cgroup_subsys___107 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___107 *parent;
};

struct cgroup_file___107 {
	struct kernfs_node___145 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___59;

struct mem_cgroup_per_node___59;

struct mem_cgroup___59 {
	struct cgroup_subsys_state___107 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___107 events_file;
	struct cgroup_file___107 events_local_file;
	struct cgroup_file___107 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___59 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___165 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___59 *nodeinfo[0];
	long: 64;
};

struct shrinker___59 {
	long unsigned int (*count_objects)(struct shrinker___59 *, struct shrink_control___59 *);
	long unsigned int (*scan_objects)(struct shrinker___59 *, struct shrink_control___59 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___154 {
	void (*page_free)(struct page___163 *);
	void (*kill)(struct dev_pagemap___154 *);
	void (*cleanup)(struct dev_pagemap___154 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___154 *);
};

struct pid_namespace___139;

struct upid___139 {
	int nr;
	struct pid_namespace___139 *ns;
};

struct pid_namespace___139 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___165 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___139 *parent;
	struct fs_pin *bacct;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___139 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___139 numbers[1];
};

struct signal_struct___159 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___165 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___165 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___139 *pids[4];
	struct pid___139 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___164 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___32;

struct cgroup_namespace___107;

struct nsproxy___148 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___139 *pid_ns_for_children;
	struct net___32 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___107 *cgroup_ns;
};

struct bio___71;

struct bio_list___71 {
	struct bio___71 *head;
	struct bio___71 *tail;
};

struct bdi_writeback___68 {
	struct backing_dev_info___68 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___107 *memcg_css;
	struct cgroup_subsys_state___107 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___68 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___68 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___114 *dev;
	char dev_name[64];
	struct device___114 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___158 *debug_dir;
};

struct io_cq___71;

struct io_context___71 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___71 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___107 {
	struct cgroup_subsys_state___107 *subsys[14];
	refcount_t refcount;
	struct css_set___107 *dom_cset;
	struct cgroup___107 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___107 *mg_src_cgrp;
	struct cgroup___107 *mg_dst_cgrp;
	struct css_set___107 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___158;

struct pipe_buffer___51;

struct pipe_inode_info___51 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___163 *tmp_page;
	struct fasync_struct___158 *fasync_readers;
	struct fasync_struct___158 *fasync_writers;
	struct pipe_buffer___51 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___71;

struct blk_integrity___71 {
	const struct blk_integrity_profile___71 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___71 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___71 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___71;

struct elevator_queue___71;

struct blk_mq_ops___68;

struct blk_mq_hw_ctx___68;

struct gendisk___71;

struct blkcg_gq___68;

struct blk_mq_tag_set___68;

struct request_queue___71 {
	struct request___71 *last_merge;
	struct elevator_queue___71 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___68 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___68 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___71 *disk;
	struct kobject___145 kobj;
	struct kobject___145 *mq_kobj;
	struct blk_integrity___71 integrity;
	struct device___114 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___68 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___68 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___71 bio_split;
	struct dentry___158 *debugfs_dir;
	struct dentry___158 *sched_debugfs_dir;
	struct dentry___158 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___142 {
	struct vm_struct___142 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___163 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___158;

struct dentry___158 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___158 *d_parent;
	struct qstr d_name;
	struct inode___158 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___158 *d_op;
	struct super_block___158 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___158;

struct inode___158 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___158 *i_op;
	struct super_block___158 *i_sb;
	struct address_space___158 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___68 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___158 *i_fop;
		void (*free_inode)(struct inode___158 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___158 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___51 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___158 {
	int (*d_revalidate)(struct dentry___158 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___158 *, unsigned int);
	int (*d_hash)(const struct dentry___158 *, struct qstr *);
	int (*d_compare)(const struct dentry___158 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___158 *);
	int (*d_init)(struct dentry___158 *);
	void (*d_release)(struct dentry___158 *);
	void (*d_prune)(struct dentry___158 *);
	void (*d_iput)(struct dentry___158 *, struct inode___158 *);
	char * (*d_dname)(struct dentry___158 *, char *, int);
	struct vfsmount___158 * (*d_automount)(struct path___158 *);
	int (*d_manage)(const struct path___158 *, bool);
	struct dentry___158 * (*d_real)(struct dentry___158 *, const struct inode___158 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___158;

struct mem_dqinfo___158 {
	struct quota_format_type___158 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___158;

struct quota_info___158 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___158 *files[3];
	struct mem_dqinfo___158 info[3];
	const struct quota_format_ops___158 *ops[3];
};

struct rcuwait___159 {
	struct task_struct___165 *task;
};

struct percpu_rw_semaphore___159 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___159 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___158 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___159 rw_sem[3];
};

struct super_operations___158;

struct dquot_operations___158;

struct quotactl_ops___158;

struct block_device___72;

struct super_block___158 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___158 *s_type;
	const struct super_operations___158 *s_op;
	const struct dquot_operations___158 *dq_op;
	const struct quotactl_ops___158 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___158 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___7 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___72 *s_bdev;
	struct backing_dev_info___68 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___158 s_dquot;
	struct sb_writers___158 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___158 *s_d_op;
	int cleancache_poolid;
	struct shrinker___59 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___23 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___158 {
	struct dentry___158 *mnt_root;
	struct super_block___158 *mnt_sb;
	int mnt_flags;
	struct user_namespace___23 *mnt_userns;
};

struct psi_group___107 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___165 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___26;

struct cgroup_bpf___26 {
	struct bpf_prog_array___26 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___26 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___107;

struct cgroup_rstat_cpu___107;

struct cgroup___107 {
	struct cgroup_subsys_state___107 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___145 *kn;
	struct cgroup_file___107 procs_file;
	struct cgroup_file___107 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___107 *subsys[14];
	struct cgroup_root___107 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___107 *dom_cgrp;
	struct cgroup___107 *old_dom_cgrp;
	struct cgroup_rstat_cpu___107 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___107 psi;
	struct cgroup_bpf___26 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___71 {
	struct request_queue___71 *q;
	struct io_context___71 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___158 {
	struct file___158 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___158 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___73 *ki_waitq;
	};
};

struct iattr___158 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___158 *ia_file;
};

struct dquot___158 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___158 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___158 {
	int qf_fmt_id;
	const struct quota_format_ops___158 *qf_ops;
	struct module___143 *qf_owner;
	struct quota_format_type___158 *qf_next;
};

struct quota_format_ops___158 {
	int (*check_quota_file)(struct super_block___158 *, int);
	int (*read_file_info)(struct super_block___158 *, int);
	int (*write_file_info)(struct super_block___158 *, int);
	int (*free_file_info)(struct super_block___158 *, int);
	int (*read_dqblk)(struct dquot___158 *);
	int (*commit_dqblk)(struct dquot___158 *);
	int (*release_dqblk)(struct dquot___158 *);
	int (*get_next_id)(struct super_block___158 *, struct kqid *);
};

struct dquot_operations___158 {
	int (*write_dquot)(struct dquot___158 *);
	struct dquot___158 * (*alloc_dquot)(struct super_block___158 *, int);
	void (*destroy_dquot)(struct dquot___158 *);
	int (*acquire_dquot)(struct dquot___158 *);
	int (*release_dquot)(struct dquot___158 *);
	int (*mark_dirty)(struct dquot___158 *);
	int (*write_info)(struct super_block___158 *, int);
	qsize_t * (*get_reserved_space)(struct inode___158 *);
	int (*get_projid)(struct inode___158 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___158 *, qsize_t *);
	int (*get_next_id)(struct super_block___158 *, struct kqid *);
};

struct quotactl_ops___158 {
	int (*quota_on)(struct super_block___158 *, int, int, const struct path___158 *);
	int (*quota_off)(struct super_block___158 *, int);
	int (*quota_enable)(struct super_block___158 *, unsigned int);
	int (*quota_disable)(struct super_block___158 *, unsigned int);
	int (*quota_sync)(struct super_block___158 *, int);
	int (*set_info)(struct super_block___158 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___158 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___158 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___158 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___158 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___158 *, unsigned int);
};

struct writeback_control___68;

struct address_space_operations___158 {
	int (*writepage)(struct page___163 *, struct writeback_control___68 *);
	int (*readpage)(struct file___158 *, struct page___163 *);
	int (*writepages)(struct address_space___158 *, struct writeback_control___68 *);
	int (*set_page_dirty)(struct page___163 *);
	int (*readpages)(struct file___158 *, struct address_space___158 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___158 *, struct address_space___158 *, loff_t, unsigned int, unsigned int, struct page___163 **, void **);
	int (*write_end)(struct file___158 *, struct address_space___158 *, loff_t, unsigned int, unsigned int, struct page___163 *, void *);
	sector_t (*bmap)(struct address_space___158 *, sector_t);
	void (*invalidatepage)(struct page___163 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___163 *, gfp_t);
	void (*freepage)(struct page___163 *);
	ssize_t (*direct_IO)(struct kiocb___158 *, struct iov_iter___87 *);
	int (*migratepage)(struct address_space___158 *, struct page___163 *, struct page___163 *, enum migrate_mode);
	bool (*isolate_page)(struct page___163 *, isolate_mode_t);
	void (*putback_page)(struct page___163 *);
	int (*launder_page)(struct page___163 *);
	int (*is_partially_uptodate)(struct page___163 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___163 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___158 *, struct page___163 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___158 *, sector_t *);
	void (*swap_deactivate)(struct file___158 *);
};

struct writeback_control___68 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___68 *wb;
	struct inode___158 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___85;

struct iov_iter___87 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___85 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___51 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___158 {
	struct dentry___158 * (*lookup)(struct inode___158 *, struct dentry___158 *, unsigned int);
	const char * (*get_link)(struct dentry___158 *, struct inode___158 *, struct delayed_call *);
	int (*permission)(struct user_namespace___23 *, struct inode___158 *, int);
	struct posix_acl * (*get_acl)(struct inode___158 *, int, bool);
	int (*readlink)(struct dentry___158 *, char *, int);
	int (*create)(struct user_namespace___23 *, struct inode___158 *, struct dentry___158 *, umode_t, bool);
	int (*link)(struct dentry___158 *, struct inode___158 *, struct dentry___158 *);
	int (*unlink)(struct inode___158 *, struct dentry___158 *);
	int (*symlink)(struct user_namespace___23 *, struct inode___158 *, struct dentry___158 *, const char *);
	int (*mkdir)(struct user_namespace___23 *, struct inode___158 *, struct dentry___158 *, umode_t);
	int (*rmdir)(struct inode___158 *, struct dentry___158 *);
	int (*mknod)(struct user_namespace___23 *, struct inode___158 *, struct dentry___158 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___23 *, struct inode___158 *, struct dentry___158 *, struct inode___158 *, struct dentry___158 *, unsigned int);
	int (*setattr)(struct user_namespace___23 *, struct dentry___158 *, struct iattr___158 *);
	int (*getattr)(struct user_namespace___23 *, const struct path___158 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___158 *, char *, size_t);
	int (*fiemap)(struct inode___158 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___158 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___158 *, struct dentry___158 *, struct file___158 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___23 *, struct inode___158 *, struct dentry___158 *, umode_t);
	int (*set_acl)(struct user_namespace___23 *, struct inode___158 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___23 *, struct dentry___158 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___158 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___158 {
	void (*fl_copy_lock)(struct file_lock___158 *, struct file_lock___158 *);
	void (*fl_release_private)(struct file_lock___158 *);
};

struct lock_manager_operations___158;

struct file_lock___158 {
	struct file_lock___158 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___158 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___158 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___158 *fl_ops;
	const struct lock_manager_operations___158 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___158 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___158 *);
	int (*lm_grant)(struct file_lock___158 *, int);
	bool (*lm_break)(struct file_lock___158 *);
	int (*lm_change)(struct file_lock___158 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___158 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___158 *);
};

struct fasync_struct___158 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___158 *fa_next;
	struct file___158 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___158 {
	struct inode___158 * (*alloc_inode)(struct super_block___158 *);
	void (*destroy_inode)(struct inode___158 *);
	void (*free_inode)(struct inode___158 *);
	void (*dirty_inode)(struct inode___158 *, int);
	int (*write_inode)(struct inode___158 *, struct writeback_control___68 *);
	int (*drop_inode)(struct inode___158 *);
	void (*evict_inode)(struct inode___158 *);
	void (*put_super)(struct super_block___158 *);
	int (*sync_fs)(struct super_block___158 *, int);
	int (*freeze_super)(struct super_block___158 *);
	int (*freeze_fs)(struct super_block___158 *);
	int (*thaw_super)(struct super_block___158 *);
	int (*unfreeze_fs)(struct super_block___158 *);
	int (*statfs)(struct dentry___158 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___158 *, int *, char *);
	void (*umount_begin)(struct super_block___158 *);
	int (*show_options)(struct seq_file___136 *, struct dentry___158 *);
	int (*show_devname)(struct seq_file___136 *, struct dentry___158 *);
	int (*show_path)(struct seq_file___136 *, struct dentry___158 *);
	int (*show_stats)(struct seq_file___136 *, struct dentry___158 *);
	ssize_t (*quota_read)(struct super_block___158 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___158 *, int, const char *, size_t, loff_t);
	struct dquot___158 ** (*get_dquots)(struct inode___158 *);
	long int (*nr_cached_objects)(struct super_block___158 *, struct shrink_control___59 *);
	long int (*free_cached_objects)(struct super_block___158 *, struct shrink_control___59 *);
	struct file___158 * (*real_loop)(struct file___158 *);
};

struct wakeup_source___114;

struct dev_pm_info___114 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___114 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___114 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___114;

struct bus_type___114;

struct device_driver___114;

struct dev_pm_domain___114;

struct fwnode_handle___114;

struct class___114;

struct attribute_group___145;

struct device___114 {
	struct kobject___145 kobj;
	struct device___114 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___114 *type;
	struct bus_type___114 *bus;
	struct device_driver___114 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___114 power;
	struct dev_pm_domain___114 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___114 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___114 *class;
	const struct attribute_group___145 **groups;
	void (*release)(struct device___114 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___72 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___158 *bd_inode;
	struct super_block___158 *bd_super;
	void *bd_claiming;
	struct device___114 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___145 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___71 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___158 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___101)(struct file___158 *, wait_queue_head_t *, struct poll_table_struct___99 *);

struct poll_table_struct___99 {
	poll_queue_proc___101 _qproc;
	__poll_t _key;
};

struct seq_operations___136;

struct seq_file___136 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___136 *op;
	int poll_event;
	const struct file___158 *file;
	void *private;
};

typedef void bio_end_io_t___71(struct bio___71 *);

struct bio_vec___85 {
	struct page___163 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___71;

struct bio___71 {
	struct bio___71 *bi_next;
	struct block_device___72 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___71 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___68 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___71 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___85 *bi_io_vec;
	struct bio_set___71 *bi_pool;
	struct bio_vec___85 bi_inline_vecs[0];
};

struct ip_ra_chain___6;

struct fib_rules_ops___19;

struct sock___20;

struct fqdir___31;

struct fib_notifier_ops___19;

struct netns_ipv4___31 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___6 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___19 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___20 *fibnl;
	struct sock___20 **icmp_sk;
	struct sock___20 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___20 **tcp_sk;
	struct fqdir___31 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___19 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___19 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___19 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___19;

struct net_device___29;

struct sk_buff___28;

struct neighbour___19;

struct dst_ops___31 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___31 *);
	struct dst_entry___19 * (*check)(struct dst_entry___19 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___19 *);
	unsigned int (*mtu)(const struct dst_entry___19 *);
	u32 * (*cow_metrics)(struct dst_entry___19 *, long unsigned int);
	void (*destroy)(struct dst_entry___19 *);
	void (*ifdown)(struct dst_entry___19 *, struct net_device___29 *, int);
	struct dst_entry___19 * (*negative_advice)(struct dst_entry___19 *);
	void (*link_failure)(struct sk_buff___28 *);
	void (*update_pmtu)(struct dst_entry___19 *, struct sock___20 *, struct sk_buff___28 *, u32, bool);
	void (*redirect)(struct dst_entry___19 *, struct sock___20 *, struct sk_buff___28 *);
	int (*local_out)(struct net___32 *, struct sock___20 *, struct sk_buff___28 *);
	struct neighbour___19 * (*neigh_lookup)(const struct dst_entry___19 *, struct sk_buff___28 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___19 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___31 {
	struct dst_ops___31 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___31 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___19 *fib6_rules_ops;
	struct sock___20 **icmp_sk;
	struct sock___20 *ndisc_sk;
	struct sock___20 *tcp_sk;
	struct sock___20 *igmp_sk;
	struct sock___20 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___19 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___19 *notifier_ops;
	struct fib_notifier_ops___19 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___31 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___31 *fqdir;
};

struct netns_sctp___19 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___20 *ctl_sock;
	struct sock___20 *udp4_sock;
	struct sock___20 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___26 {
	struct sk_buff___28 *next;
	struct sk_buff___28 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___26;

struct netns_bpf___26 {
	struct bpf_prog_array___26 *run_array[2];
	struct bpf_prog___26 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___31 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___20 *nlsk;
	struct sock___20 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___31 xfrm4_dst_ops;
	struct dst_ops___31 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___32 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___20 *rtnl;
	struct sock___20 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___29 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___31 ipv4;
	struct netns_ipv6___31 ipv6;
	struct netns_ieee802154_lowpan___31 ieee802154_lowpan;
	struct netns_sctp___19 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___26 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___26 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___31 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___20 *crypto_nlsk;
	struct sock___20 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___107 {
	struct ns_common___26 ns;
	struct user_namespace___23 *user_ns;
	struct ucounts___23 *ucounts;
	struct css_set___107 *root_cset;
};

struct msghdr___20 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___87 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___158 *msg_iocb;
};

struct fwnode_operations___114;

struct fwnode_handle___114 {
	struct fwnode_handle___114 *secondary;
	const struct fwnode_operations___114 *ops;
	struct device___114 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___114;

struct fwnode_endpoint___114;

struct fwnode_operations___114 {
	struct fwnode_handle___114 * (*get)(struct fwnode_handle___114 *);
	void (*put)(struct fwnode_handle___114 *);
	bool (*device_is_available)(const struct fwnode_handle___114 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___114 *, const struct device___114 *);
	bool (*property_present)(const struct fwnode_handle___114 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___114 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___114 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___114 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*get_parent)(const struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*get_next_child_node)(const struct fwnode_handle___114 *, struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*get_named_child_node)(const struct fwnode_handle___114 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___114 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___114 *);
	struct fwnode_handle___114 * (*graph_get_next_endpoint)(const struct fwnode_handle___114 *, struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*graph_get_remote_endpoint)(const struct fwnode_handle___114 *);
	struct fwnode_handle___114 * (*graph_get_port_parent)(struct fwnode_handle___114 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___114 *, struct fwnode_endpoint___114 *);
	int (*add_links)(struct fwnode_handle___114 *);
};

struct fwnode_endpoint___114 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___114 *local_fwnode;
};

struct fwnode_reference_args___114 {
	struct fwnode_handle___114 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___145;

struct kernfs_elem_dir___145 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___145 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___145;

struct kernfs_root___145 {
	struct kernfs_node___145 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___145 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___145 {
	struct kernfs_node___145 *target_kn;
};

struct kernfs_ops___145;

struct kernfs_elem_attr___145 {
	const struct kernfs_ops___145 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___145 *notify_next;
};

struct kernfs_node___145 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___145 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___145 dir;
		struct kernfs_elem_symlink___145 symlink;
		struct kernfs_elem_attr___145 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___145;

struct kernfs_ops___145 {
	int (*open)(struct kernfs_open_file___145 *);
	void (*release)(struct kernfs_open_file___145 *);
	int (*seq_show)(struct seq_file___136 *, void *);
	void * (*seq_start)(struct seq_file___136 *, loff_t *);
	void * (*seq_next)(struct seq_file___136 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___136 *, void *);
	ssize_t (*read)(struct kernfs_open_file___145 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___145 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___145 *, struct poll_table_struct___99 *);
	int (*mmap)(struct kernfs_open_file___145 *, struct vm_area_struct___163 *);
};

struct kernfs_syscall_ops___145 {
	int (*show_options)(struct seq_file___136 *, struct kernfs_root___145 *);
	int (*mkdir)(struct kernfs_node___145 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___145 *);
	int (*rename)(struct kernfs_node___145 *, struct kernfs_node___145 *, const char *);
	int (*show_path)(struct seq_file___136 *, struct kernfs_node___145 *, struct kernfs_root___145 *);
};

struct kernfs_open_file___145 {
	struct kernfs_node___145 *kn;
	struct file___158 *file;
	struct seq_file___136 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___154 *vm_ops;
};

struct kobj_ns_type_operations___19 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___20 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___32 *net;
} possible_net_t___26;

struct proto___19;

struct sock_common___19 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___19 *skc_prot;
	possible_net_t___26 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___20 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___19 {
	struct cgroup___107 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___19;

struct socket_wq___20;

struct socket___20;

struct sock___20 {
	struct sock_common___19 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___26 sk_error_queue;
	struct sk_buff___28 *sk_rx_skb_cache;
	struct sk_buff_head___26 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___28 *head;
		struct sk_buff___28 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___19 *sk_filter;
	union {
		struct socket_wq___20 *sk_wq;
		struct socket_wq___20 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___19 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___19 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___28 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___28 *sk_tx_skb_cache;
	struct sk_buff_head___26 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___163 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___19 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___139 *sk_peer_pid;
	const struct cred___26 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___20 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___19 sk_cgrp_data;
	struct mem_cgroup___59 *sk_memcg;
	void (*sk_state_change)(struct sock___20 *);
	void (*sk_data_ready)(struct sock___20 *);
	void (*sk_write_space)(struct sock___20 *);
	void (*sk_error_report)(struct sock___20 *);
	int (*sk_backlog_rcv)(struct sock___20 *, struct sk_buff___28 *);
	struct sk_buff___28 * (*sk_validate_xmit_skb)(struct sock___20 *, struct net_device___29 *, struct sk_buff___28 *);
	void (*sk_destruct)(struct sock___20 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___145;

struct attribute_group___145 {
	const char *name;
	umode_t (*is_visible)(struct kobject___145 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___145 *, struct bin_attribute___145 *, int);
	struct attribute **attrs;
	struct bin_attribute___145 **bin_attrs;
};

struct bin_attribute___145 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___158 * (*f_mapping)();
	ssize_t (*read)(struct file___158 *, struct kobject___145 *, struct bin_attribute___145 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___158 *, struct kobject___145 *, struct bin_attribute___145 *, char *, loff_t, size_t);
	int (*mmap)(struct file___158 *, struct kobject___145 *, struct bin_attribute___145 *, struct vm_area_struct___163 *);
};

struct sysfs_ops___145 {
	ssize_t (*show)(struct kobject___145 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___145 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___145;

struct kset___145 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___145 kobj;
	const struct kset_uevent_ops___145 *uevent_ops;
};

struct kobj_type___145 {
	void (*release)(struct kobject___145 *);
	const struct sysfs_ops___145 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___145 **default_groups;
	const struct kobj_ns_type_operations___19 * (*child_ns_type)(struct kobject___145 *);
	const void * (*namespace)(struct kobject___145 *);
	void (*get_ownership)(struct kobject___145 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___145 {
	int (* const filter)(struct kset___145 *, struct kobject___145 *);
	const char * (* const name)(struct kset___145 *, struct kobject___145 *);
	int (* const uevent)(struct kset___145 *, struct kobject___145 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___142 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___142 *);
	int (*get)(char *, const struct kernel_param___142 *);
	void (*free)(void *);
};

struct kparam_array___142;

struct kernel_param___142 {
	const char *name;
	struct module___143 *mod;
	const struct kernel_param_ops___142 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___142 *arr;
	};
};

struct kparam_array___142 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___142 *ops;
	void *elem;
};

struct module_attribute___142 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___142 *, struct module_kobject___142 *, char *);
	ssize_t (*store)(struct module_attribute___142 *, struct module_kobject___142 *, const char *, size_t);
	void (*setup)(struct module___143 *, const char *);
	int (*test)(struct module___143 *);
	void (*free)(struct module___143 *);
};

struct socket_wq___20 {
	wait_queue_head_t wait;
	struct fasync_struct___158 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___20;

struct socket___20 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___158 *file;
	struct sock___20 *sk;
	const struct proto_ops___20 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___20 wq;
};

typedef int (*sk_read_actor_t___19)(read_descriptor_t *, struct sk_buff___28 *, unsigned int, size_t);

struct proto_ops___20 {
	int family;
	struct module___143 *owner;
	int (*release)(struct socket___20 *);
	int (*bind)(struct socket___20 *, struct sockaddr *, int);
	int (*connect)(struct socket___20 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___20 *, struct socket___20 *);
	int (*accept)(struct socket___20 *, struct socket___20 *, int, bool);
	int (*getname)(struct socket___20 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___158 *, struct socket___20 *, struct poll_table_struct___99 *);
	int (*ioctl)(struct socket___20 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___20 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___20 *, void *, bool, bool);
	int (*listen)(struct socket___20 *, int);
	int (*shutdown)(struct socket___20 *, int);
	int (*setsockopt)(struct socket___20 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___20 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___136 *, struct socket___20 *);
	int (*sendmsg)(struct socket___20 *, struct msghdr___20 *, size_t);
	int (*recvmsg)(struct socket___20 *, struct msghdr___20 *, size_t, int);
	int (*mmap)(struct file___158 *, struct socket___20 *, struct vm_area_struct___163 *);
	ssize_t (*sendpage)(struct socket___20 *, struct page___163 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___20 *, loff_t *, struct pipe_inode_info___51 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___20 *, int);
	int (*peek_len)(struct socket___20 *);
	int (*read_sock)(struct sock___20 *, read_descriptor_t *, sk_read_actor_t___19);
	int (*sendpage_locked)(struct sock___20 *, struct page___163 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___20 *, struct msghdr___20 *, size_t);
	int (*set_rcvlowat)(struct sock___20 *, int);
};

struct sk_buff___28 {
	union {
		struct {
			struct sk_buff___28 *next;
			struct sk_buff___28 *prev;
			union {
				struct net_device___29 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___20 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___28 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___114 {
	int (*prepare)(struct device___114 *);
	void (*complete)(struct device___114 *);
	int (*suspend)(struct device___114 *);
	int (*resume)(struct device___114 *);
	int (*freeze)(struct device___114 *);
	int (*thaw)(struct device___114 *);
	int (*poweroff)(struct device___114 *);
	int (*restore)(struct device___114 *);
	int (*suspend_late)(struct device___114 *);
	int (*resume_early)(struct device___114 *);
	int (*freeze_late)(struct device___114 *);
	int (*thaw_early)(struct device___114 *);
	int (*poweroff_late)(struct device___114 *);
	int (*restore_early)(struct device___114 *);
	int (*suspend_noirq)(struct device___114 *);
	int (*resume_noirq)(struct device___114 *);
	int (*freeze_noirq)(struct device___114 *);
	int (*thaw_noirq)(struct device___114 *);
	int (*poweroff_noirq)(struct device___114 *);
	int (*restore_noirq)(struct device___114 *);
	int (*runtime_suspend)(struct device___114 *);
	int (*runtime_resume)(struct device___114 *);
	int (*runtime_idle)(struct device___114 *);
};

struct wakeup_source___114 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___114 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___114 {
	struct dev_pm_ops___114 ops;
	int (*start)(struct device___114 *);
	void (*detach)(struct device___114 *, bool);
	int (*activate)(struct device___114 *);
	void (*sync)(struct device___114 *);
	void (*dismiss)(struct device___114 *);
};

struct bus_type___114 {
	const char *name;
	const char *dev_name;
	struct device___114 *dev_root;
	const struct attribute_group___145 **bus_groups;
	const struct attribute_group___145 **dev_groups;
	const struct attribute_group___145 **drv_groups;
	int (*match)(struct device___114 *, struct device_driver___114 *);
	int (*uevent)(struct device___114 *, struct kobj_uevent_env *);
	int (*probe)(struct device___114 *);
	void (*sync_state)(struct device___114 *);
	void (*remove)(struct device___114 *);
	void (*shutdown)(struct device___114 *);
	int (*online)(struct device___114 *);
	int (*offline)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	int (*num_vf)(struct device___114 *);
	int (*dma_configure)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___114 {
	const char *name;
	struct bus_type___114 *bus;
	struct module___143 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___114 *);
	void (*sync_state)(struct device___114 *);
	int (*remove)(struct device___114 *);
	void (*shutdown)(struct device___114 *);
	int (*suspend)(struct device___114 *, pm_message_t);
	int (*resume)(struct device___114 *);
	const struct attribute_group___145 **groups;
	const struct attribute_group___145 **dev_groups;
	const struct dev_pm_ops___114 *pm;
	void (*coredump)(struct device___114 *);
	struct driver_private *p;
};

struct device_type___114 {
	const char *name;
	const struct attribute_group___145 **groups;
	int (*uevent)(struct device___114 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___114 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___114 *);
	const struct dev_pm_ops___114 *pm;
};

struct class___114 {
	const char *name;
	struct module___143 *owner;
	const struct attribute_group___145 **class_groups;
	const struct attribute_group___145 **dev_groups;
	struct kobject___145 *dev_kobj;
	int (*dev_uevent)(struct device___114 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___114 *, umode_t *);
	void (*class_release)(struct class___114 *);
	void (*dev_release)(struct device___114 *);
	int (*shutdown_pre)(struct device___114 *);
	const struct kobj_ns_type_operations___19 *ns_type;
	const void * (*namespace)(struct device___114 *);
	void (*get_ownership)(struct device___114 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___114 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___51;

struct pipe_buffer___51 {
	struct page___163 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___51 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___51 {
	int (*confirm)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
	void (*release)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
	bool (*try_steal)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
	bool (*get)(struct pipe_inode_info___51 *, struct pipe_buffer___51 *);
};

typedef rx_handler_result_t rx_handler_func_t___26(struct sk_buff___28 **);

struct bpf_xdp_entity___26 {
	struct bpf_prog___26 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___26;

struct net_device_ops___26;

struct ethtool_ops___4;

struct l3mdev_ops___19;

struct ndisc_ops___9;

struct xfrmdev_ops___26;

struct header_ops___26;

struct inet6_dev___9;

struct netdev_rx_queue___26;

struct mini_Qdisc___26;

struct netdev_queue___26;

struct Qdisc___26;

struct rtnl_link_ops___26;

struct dcbnl_rtnl_ops___26;

struct net_device___29 {
	char name[16];
	struct netdev_name_node___26 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___26 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___4 *ethtool_ops;
	const struct l3mdev_ops___19 *l3mdev_ops;
	const struct ndisc_ops___9 *ndisc_ops;
	const struct xfrmdev_ops___26 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___26 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___145 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___9 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___26 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___26 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___26 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___26 *miniq_ingress;
	struct netdev_queue___26 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___26 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___26 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___26 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___26 = 0,
		NETREG_REGISTERED___26 = 1,
		NETREG_UNREGISTERING___26 = 2,
		NETREG_UNREGISTERED___26 = 3,
		NETREG_RELEASED___26 = 4,
		NETREG_DUMMY___26 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___26 = 0,
		RTNL_LINK_INITIALIZING___26 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___29 *);
	struct netpoll_info *npinfo;
	possible_net_t___26 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___114 dev;
	const struct attribute_group___145 *sysfs_groups[4];
	const struct attribute_group___145 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___26 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___26 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___26 xdp_state[3];
	long: 64;
};

struct netlink_callback___26 {
	struct sk_buff___28 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___28 *, struct netlink_callback___26 *);
	int (*done)(struct netlink_callback___26 *);
	void *data;
	struct module___143 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_ops___4 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___29 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___29 *);
	void (*get_regs)(struct net_device___29 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___29 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___29 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___29 *);
	void (*set_msglevel)(struct net_device___29 *, u32);
	int (*nway_reset)(struct net_device___29 *);
	u32 (*get_link)(struct net_device___29 *);
	int (*get_link_ext_state)(struct net_device___29 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___29 *);
	int (*get_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___29 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___29 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___29 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___29 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___29 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___29 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___29 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___29 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___29 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___29 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___29 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___29 *);
	void (*complete)(struct net_device___29 *);
	u32 (*get_priv_flags)(struct net_device___29 *);
	int (*set_priv_flags)(struct net_device___29 *, u32);
	int (*get_sset_count)(struct net_device___29 *, int);
	int (*get_rxnfc)(struct net_device___29 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___29 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___29 *, struct ethtool_flash *);
	int (*reset)(struct net_device___29 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___29 *);
	u32 (*get_rxfh_indir_size)(struct net_device___29 *);
	int (*get_rxfh)(struct net_device___29 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___29 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___29 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___29 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___29 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___29 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___29 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___29 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___29 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___29 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___29 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___29 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___29 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___29 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___29 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___29 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___29 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___29 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___29 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___29 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___29 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___29 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___29 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___29 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___29 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___29 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___29 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___29 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___29 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___29 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___29 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct inet_frags___31;

struct fqdir___31 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___31 *f;
	struct net___32 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___31;

struct inet_frags___31 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___31 *, const void *);
	void (*destructor)(struct inet_frag_queue___31 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___31 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___28 *fragments_tail;
	struct sk_buff___28 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___31 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___6 {
	struct ip_ra_chain___6 *next;
	struct sock___20 *sk;
	union {
		void (*destructor)(struct sock___20 *);
		struct sock___20 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___19;

struct fib_lookup_arg___19;

struct fib_rules_ops___19 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___19 *, struct flowi *, int, struct fib_lookup_arg___19 *);
	bool (*suppress)(struct fib_rule___19 *, int, struct fib_lookup_arg___19 *);
	int (*match)(struct fib_rule___19 *, struct flowi *, int);
	int (*configure)(struct fib_rule___19 *, struct sk_buff___28 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___19 *);
	int (*compare)(struct fib_rule___19 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___19 *, struct sk_buff___28 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___19 *);
	void (*flush_cache)(struct fib_rules_ops___19 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___143 *owner;
	struct net___32 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___19 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___32 *);
	int (*fib_dump)(struct net___32 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___143 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___6;

struct dst_entry___19 {
	struct net_device___29 *dev;
	struct dst_ops___31 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___28 *);
	int (*output)(struct net___32 *, struct sock___20 *, struct sk_buff___28 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___6 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___19;

struct neigh_parms___19;

struct neigh_ops___19;

struct neighbour___19 {
	struct neighbour___19 *next;
	struct neigh_table___19 *tbl;
	struct neigh_parms___19 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___26 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___19 *, struct sk_buff___28 *);
	const struct neigh_ops___19 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___29 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___26 {
	struct bpf_prog___26 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___26 {
	struct callback_head rcu;
	struct bpf_prog_array_item___26 items[0];
};

struct bpf_prog_aux___28;

struct bpf_prog___26 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___28 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___136 {
	void * (*start)(struct seq_file___136 *, loff_t *);
	void (*stop)(struct seq_file___136 *, void *);
	void * (*next)(struct seq_file___136 *, void *, loff_t *);
	int (*show)(struct seq_file___136 *, void *);
};

struct dcbnl_rtnl_ops___26 {
	int (*ieee_getets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___29 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___29 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___29 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___29 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___29 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___29 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___29 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___29 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___29 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___29 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___29 *);
	u8 (*setstate)(struct net_device___29 *, u8);
	void (*getpermhwaddr)(struct net_device___29 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___29 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___29 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___29 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___29 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___29 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___29 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___29 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___29 *, int, u8 *);
	void (*setpfccfg)(struct net_device___29 *, int, u8);
	void (*getpfccfg)(struct net_device___29 *, int, u8 *);
	u8 (*setall)(struct net_device___29 *);
	u8 (*getcap)(struct net_device___29 *, int, u8 *);
	int (*getnumtcs)(struct net_device___29 *, int, u8 *);
	int (*setnumtcs)(struct net_device___29 *, int, u8);
	u8 (*getpfcstate)(struct net_device___29 *);
	void (*setpfcstate)(struct net_device___29 *, u8);
	void (*getbcncfg)(struct net_device___29 *, int, u32 *);
	void (*setbcncfg)(struct net_device___29 *, int, u32);
	void (*getbcnrp)(struct net_device___29 *, int, u8 *);
	void (*setbcnrp)(struct net_device___29 *, int, u8);
	int (*setapp)(struct net_device___29 *, u8, u16, u8);
	int (*getapp)(struct net_device___29 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___29 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___29 *, int, u8);
	u8 (*getdcbx)(struct net_device___29 *);
	u8 (*setdcbx)(struct net_device___29 *, u8);
	int (*peer_getappinfo)(struct net_device___29 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___29 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___29 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___29 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___29 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___29 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___29;

typedef int (*bpf_iter_init_seq_priv_t___28)(void *, struct bpf_iter_aux_info___29 *);

struct bpf_map___28;

struct bpf_iter_aux_info___29 {
	struct bpf_map___28 *map;
};

struct bpf_iter_seq_info___28 {
	const struct seq_operations___136 *seq_ops;
	bpf_iter_init_seq_priv_t___28 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___28 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___28 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___28 *, struct file___158 *);
	void (*map_free)(struct bpf_map___28 *);
	int (*map_get_next_key)(struct bpf_map___28 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___28 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___28 *, void *);
	int (*map_lookup_batch)(struct bpf_map___28 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___28 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___28 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___28 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___28 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___28 *, void *);
	int (*map_update_elem)(struct bpf_map___28 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___28 *, void *);
	int (*map_push_elem)(struct bpf_map___28 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___28 *, void *);
	int (*map_peek_elem)(struct bpf_map___28 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___28 *, struct file___158 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___28 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___28 *, void *, struct seq_file___136 *);
	int (*map_check_btf)(const struct bpf_map___28 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___28 *, struct bpf_prog_aux___28 *);
	void (*map_poke_untrack)(struct bpf_map___28 *, struct bpf_prog_aux___28 *);
	void (*map_poke_run)(struct bpf_map___28 *, u32, struct bpf_prog___26 *, struct bpf_prog___26 *);
	int (*map_direct_value_addr)(const struct bpf_map___28 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___28 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___28 *, struct vm_area_struct___163 *);
	__poll_t (*map_poll)(struct bpf_map___28 *, struct file___158 *, struct poll_table_struct___99 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___28 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___28 *, const struct bpf_map___28 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___28 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___28 *iter_seq_info;
};

struct bpf_map___28 {
	const struct bpf_map_ops___28 *ops;
	struct bpf_map___28 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___59 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___28;

struct bpf_jit_poke_descriptor___28;

struct bpf_prog_ops___26;

struct btf_mod_pair___28;

struct bpf_prog_offload___26;

struct bpf_prog_aux___28 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___26 *dst_prog;
	struct bpf_trampoline___28 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___26 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___28 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___26 *ops;
	struct bpf_map___28 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___28 *used_btfs;
	struct bpf_prog___26 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___28 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___26 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___26;

struct bpf_map_dev_ops___26 {
	int (*map_get_next_key)(struct bpf_offloaded_map___26 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___26 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___26 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___26 *, void *);
};

struct bpf_offloaded_map___26 {
	struct bpf_map___28 map;
	struct net_device___29 *netdev;
	const struct bpf_map_dev_ops___26 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___26 {
	int (*test_run)(struct bpf_prog___26 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___26 {
	struct bpf_prog___26 *prog;
	struct net_device___29 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___28 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___26 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___143 *mod;
};

struct bpf_jit_poke_descriptor___28 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___28 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___28 {
	struct btf *btf;
	struct module___143 *module;
};

struct cftype___107;

struct cgroup_subsys___107 {
	struct cgroup_subsys_state___107 * (*css_alloc)(struct cgroup_subsys_state___107 *);
	int (*css_online)(struct cgroup_subsys_state___107 *);
	void (*css_offline)(struct cgroup_subsys_state___107 *);
	void (*css_released)(struct cgroup_subsys_state___107 *);
	void (*css_free)(struct cgroup_subsys_state___107 *);
	void (*css_reset)(struct cgroup_subsys_state___107 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___107 *, int);
	int (*css_extra_stat_show)(struct seq_file___136 *, struct cgroup_subsys_state___107 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___165 *, struct css_set___107 *);
	void (*cancel_fork)(struct task_struct___165 *, struct css_set___107 *);
	void (*fork)(struct task_struct___165 *);
	void (*exit)(struct task_struct___165 *);
	void (*release)(struct task_struct___165 *);
	void (*bind)(struct cgroup_subsys_state___107 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___107 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___107 *dfl_cftypes;
	struct cftype___107 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___107 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___107 *updated_children;
	struct cgroup___107 *updated_next;
};

struct cgroup_root___107 {
	struct kernfs_root___145 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___107 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___107 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___107 *ss;
	struct list_head node;
	struct kernfs_ops___145 *kf_ops;
	int (*open)(struct kernfs_open_file___145 *);
	void (*release)(struct kernfs_open_file___145 *);
	u64 (*read_u64)(struct cgroup_subsys_state___107 *, struct cftype___107 *);
	s64 (*read_s64)(struct cgroup_subsys_state___107 *, struct cftype___107 *);
	int (*seq_show)(struct seq_file___136 *, void *);
	void * (*seq_start)(struct seq_file___136 *, loff_t *);
	void * (*seq_next)(struct seq_file___136 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___136 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___107 *, struct cftype___107 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___107 *, struct cftype___107 *, s64);
	ssize_t (*write)(struct kernfs_open_file___145 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___145 *, struct poll_table_struct___99 *);
};

struct xdp_rxq_info___26 {
	struct net_device___29 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___26 {
	struct net_device___29 *dev;
};

struct xdp_buff___26 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___26 *rxq;
	struct xdp_txq_info___26 *txq;
	u32 frame_sz;
};

struct xdp_frame___26 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___29 *dev_rx;
};

struct header_ops___26 {
	int (*create)(struct sk_buff___28 *, struct net_device___29 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___28 *, unsigned char *);
	int (*cache)(const struct neighbour___19 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___29 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___28 *);
};

struct netdev_queue___26 {
	struct net_device___29 *dev;
	struct Qdisc___26 *qdisc;
	struct Qdisc___26 *qdisc_sleeping;
	struct kobject___145 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___29 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___26 {
	struct sk_buff___28 *head;
	struct sk_buff___28 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___26;

struct Qdisc___26 {
	int (*enqueue)(struct sk_buff___28 *, struct Qdisc___26 *, struct sk_buff___28 **);
	struct sk_buff___28 * (*dequeue)(struct Qdisc___26 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___26 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___26 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___26 gso_skb;
	struct qdisc_skb_head___26 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___26 *next_sched;
	struct sk_buff_head___26 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___26 {
	struct xdp_rxq_info___26 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___145 kobj;
	struct net_device___29 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___26 {
	enum net_device_path_type type;
	const struct net_device___29 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___26 = 0,
				DEV_PATH_BR_VLAN_TAG___26 = 1,
				DEV_PATH_BR_VLAN_UNTAG___26 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___26 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___26 {
	const struct net_device___29 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___26 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___26 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___26 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___26 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___28 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___26 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___29 *dev;
	const char *name;
};

struct net_device_ops___26 {
	int (*ndo_init)(struct net_device___29 *);
	void (*ndo_uninit)(struct net_device___29 *);
	int (*ndo_open)(struct net_device___29 *);
	int (*ndo_stop)(struct net_device___29 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___28 *, struct net_device___29 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___28 *, struct net_device___29 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___29 *, struct sk_buff___28 *, struct net_device___29 *);
	void (*ndo_change_rx_flags)(struct net_device___29 *, int);
	void (*ndo_set_rx_mode)(struct net_device___29 *);
	int (*ndo_set_mac_address)(struct net_device___29 *, void *);
	int (*ndo_validate_addr)(struct net_device___29 *);
	int (*ndo_do_ioctl)(struct net_device___29 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___29 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___29 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___29 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___29 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___29 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___29 *, int);
	int (*ndo_neigh_setup)(struct net_device___29 *, struct neigh_parms___19 *);
	void (*ndo_tx_timeout)(struct net_device___29 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___29 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___29 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___29 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___29 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___29 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___29 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___29 *);
	int (*ndo_netpoll_setup)(struct net_device___29 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___29 *);
	int (*ndo_set_vf_mac)(struct net_device___29 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___29 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___29 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___29 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___29 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___29 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___29 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___29 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___29 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___29 *, int, struct sk_buff___28 *);
	int (*ndo_get_vf_guid)(struct net_device___29 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___29 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___29 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___29 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___29 *);
	int (*ndo_fcoe_disable)(struct net_device___29 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___29 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___29 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___29 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___29 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___29 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___29 *, const struct sk_buff___28 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___29 *, struct net_device___29 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___29 *, struct net_device___29 *);
	struct net_device___29 * (*ndo_get_xmit_slave)(struct net_device___29 *, struct sk_buff___28 *, bool);
	struct net_device___29 * (*ndo_sk_get_lower_dev)(struct net_device___29 *, struct sock___20 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___29 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___29 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___29 *, struct neighbour___19 *);
	void (*ndo_neigh_destroy)(struct net_device___29 *, struct neighbour___19 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___28 *, struct netlink_callback___26 *, struct net_device___29 *, struct net_device___29 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___28 *, struct nlattr **, struct net_device___29 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___29 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___28 *, u32, u32, struct net_device___29 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___29 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___29 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___29 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___29 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___29 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___29 *, struct net_device___29 *);
	void (*ndo_dfwd_del_station)(struct net_device___29 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___29 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___29 *);
	int (*ndo_change_proto_down)(struct net_device___29 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___29 *, struct sk_buff___28 *);
	void (*ndo_set_rx_headroom)(struct net_device___29 *, int);
	int (*ndo_bpf)(struct net_device___29 *, struct netdev_bpf___26 *);
	int (*ndo_xdp_xmit)(struct net_device___29 *, int, struct xdp_frame___26 **, u32);
	struct net_device___29 * (*ndo_xdp_get_xmit_slave)(struct net_device___29 *, struct xdp_buff___26 *);
	int (*ndo_xsk_wakeup)(struct net_device___29 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___29 *);
	int (*ndo_tunnel_ctl)(struct net_device___29 *, struct ip_tunnel_parm *, int);
	struct net_device___29 * (*ndo_get_peer_dev)(struct net_device___29 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___26 *, struct net_device_path___26 *);
};

struct neigh_parms___19 {
	possible_net_t___26 net;
	struct net_device___29 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___19 *);
	struct neigh_table___19 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___19 {
	u32 (*l3mdev_fib_table)(const struct net_device___29 *);
	struct sk_buff___28 * (*l3mdev_l3_rcv)(struct net_device___29 *, struct sk_buff___28 *, u16);
	struct sk_buff___28 * (*l3mdev_l3_out)(struct net_device___29 *, struct sock___20 *, struct sk_buff___28 *, u16);
	struct dst_entry___19 * (*l3mdev_link_scope_lookup)(const struct net_device___29 *, struct flowi6 *);
};

struct ndisc_ops___9 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___29 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___29 *, struct neighbour___19 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___29 *, u8, struct neighbour___19 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___29 *, struct sk_buff___28 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___32 *, struct net_device___29 *, const struct prefix_info *, struct inet6_dev___9 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___9;

struct inet6_dev___9 {
	struct net_device___29 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___9 *mc_list;
	struct ifmcaddr6___9 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___26 mc_query_queue;
	struct sk_buff_head___26 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___19 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___26;

struct tcf_block___26;

struct mini_Qdisc___26 {
	struct tcf_proto___26 *filter_list;
	struct tcf_block___26 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___26 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___29 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___29 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___32 *, struct net_device___29 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___29 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___29 *, struct list_head *);
	size_t (*get_size)(const struct net_device___29 *);
	int (*fill_info)(struct sk_buff___28 *, const struct net_device___29 *);
	size_t (*get_xstats_size)(const struct net_device___29 *);
	int (*fill_xstats)(struct sk_buff___28 *, const struct net_device___29 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___29 *, struct net_device___29 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___29 *, const struct net_device___29 *);
	int (*fill_slave_info)(struct sk_buff___28 *, const struct net_device___29 *, const struct net_device___29 *);
	struct net___32 * (*get_link_net)(const struct net_device___29 *);
	size_t (*get_linkxstats_size)(const struct net_device___29 *, int);
	int (*fill_linkxstats)(struct sk_buff___28 *, const struct net_device___29 *, int *, int);
};

struct block_device_operations___71;

struct gendisk___71 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___72 *part0;
	const struct block_device_operations___71 *fops;
	struct request_queue___71 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___68 *bdi;
	struct kobject___145 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___145 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___71 {
	struct bio___71 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___85 *bip_vec;
	struct bio_vec___85 bip_inline_vecs[0];
};

struct blkcg___68;

struct blkg_policy_data___68;

struct blkcg_gq___68 {
	struct request_queue___71 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___68 *blkcg;
	struct blkcg_gq___68 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___68 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___71 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___71(struct request___71 *);

typedef void integrity_complete_fn___71(struct request___71 *, unsigned int);

struct blk_integrity_profile___71 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___71 *prepare_fn;
	integrity_complete_fn___71 *complete_fn;
	const char *name;
};

struct block_device_operations___71 {
	blk_qc_t (*submit_bio)(struct bio___71 *);
	int (*open)(struct block_device___72 *, fmode_t);
	void (*release)(struct gendisk___71 *, fmode_t);
	int (*rw_page)(struct block_device___72 *, sector_t, struct page___163 *, unsigned int);
	int (*ioctl)(struct block_device___72 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___72 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___71 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___71 *);
	int (*getgeo)(struct block_device___72 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___72 *, bool);
	void (*swap_slot_free_notify)(struct block_device___72 *, long unsigned int);
	int (*report_zones)(struct gendisk___71 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___71 *, umode_t *);
	struct module___143 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___71 *, sector_t *);
};

typedef void rq_end_io_fn___71(struct request___71 *, blk_status_t);

struct request___71 {
	struct request_queue___71 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___68 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___71 *bio;
	struct bio___71 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___85 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___71 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___71 *saved_end_io;
		} flush;
	};
	struct gendisk___71 *rq_disk;
	struct block_device___72 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___71 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___68 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___71 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___145 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___158 *debugfs_dir;
	struct dentry___158 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___71;

struct elevator_mq_ops___71 {
	int (*init_sched)(struct request_queue___71 *, struct elevator_type___71 *);
	void (*exit_sched)(struct elevator_queue___71 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___68 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___68 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___68 *);
	bool (*allow_merge)(struct request_queue___71 *, struct request___71 *, struct bio___71 *);
	bool (*bio_merge)(struct request_queue___71 *, struct bio___71 *, unsigned int);
	int (*request_merge)(struct request_queue___71 *, struct request___71 **, struct bio___71 *);
	void (*request_merged)(struct request_queue___71 *, struct request___71 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___71 *, struct request___71 *, struct request___71 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___71 *);
	void (*finish_request)(struct request___71 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___68 *, struct list_head *, bool);
	struct request___71 * (*dispatch_request)(struct blk_mq_hw_ctx___68 *);
	bool (*has_work)(struct blk_mq_hw_ctx___68 *);
	void (*completed_request)(struct request___71 *, u64);
	void (*requeue_request)(struct request___71 *);
	struct request___71 * (*former_request)(struct request_queue___71 *, struct request___71 *);
	struct request___71 * (*next_request)(struct request_queue___71 *, struct request___71 *);
	void (*init_icq)(struct io_cq___71 *);
	void (*exit_icq)(struct io_cq___71 *);
};

struct elv_fs_entry___71;

struct elevator_type___71 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___71 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___71 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___143 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___71 {
	struct elevator_type___71 *type;
	void *elevator_data;
	struct kobject___145 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___71 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___71 *, char *);
	ssize_t (*store)(struct elevator_queue___71 *, const char *, size_t);
};

struct blk_mq_queue_data___68;

struct blk_mq_ops___68 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___68 *, const struct blk_mq_queue_data___68 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___68 *);
	int (*get_budget)(struct request_queue___71 *);
	void (*put_budget)(struct request_queue___71 *, int);
	void (*set_rq_budget_token)(struct request___71 *, int);
	int (*get_rq_budget_token)(struct request___71 *);
	enum blk_eh_timer_return (*timeout)(struct request___71 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___68 *);
	void (*complete)(struct request___71 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___68 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___68 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___68 *, struct request___71 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___68 *, struct request___71 *, unsigned int);
	void (*initialize_rq_fn)(struct request___71 *);
	void (*cleanup_rq)(struct request___71 *);
	bool (*busy)(struct request_queue___71 *);
	int (*map_queues)(struct blk_mq_tag_set___68 *);
	void (*show_rq)(struct seq_file___136 *, struct request___71 *);
};

struct blk_mq_tag_set___68 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___68 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___68 {
	struct request___71 *rq;
	bool last;
};

struct blkcg_policy_data___68;

struct blkcg___68 {
	struct cgroup_subsys_state___107 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___68 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___68 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___68 {
	struct blkcg___68 *blkcg;
	int plid;
};

struct blkg_policy_data___68 {
	struct blkcg_gq___68 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___59 {
	struct mem_cgroup___59 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___59 {
	struct lruvec___66 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___59 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___59 *memcg;
};

struct obj_cgroup___59 {
	struct percpu_ref refcnt;
	struct mem_cgroup___59 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___26 {
	spinlock_t *lock;
	struct sk_buff___28 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___26;

struct Qdisc_ops___26 {
	struct Qdisc_ops___26 *next;
	const struct Qdisc_class_ops___26 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___28 *, struct Qdisc___26 *, struct sk_buff___28 **);
	struct sk_buff___28 * (*dequeue)(struct Qdisc___26 *);
	struct sk_buff___28 * (*peek)(struct Qdisc___26 *);
	int (*init)(struct Qdisc___26 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___26 *);
	void (*destroy)(struct Qdisc___26 *);
	int (*change)(struct Qdisc___26 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___26 *);
	int (*change_tx_queue_len)(struct Qdisc___26 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___26 *, unsigned int);
	int (*dump)(struct Qdisc___26 *, struct sk_buff___28 *);
	int (*dump_stats)(struct Qdisc___26 *, struct gnet_dump___26 *);
	void (*ingress_block_set)(struct Qdisc___26 *, u32);
	void (*egress_block_set)(struct Qdisc___26 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___26 *);
	u32 (*egress_block_get)(struct Qdisc___26 *);
	struct module___143 *owner;
};

struct Qdisc_class_ops___26 {
	unsigned int flags;
	struct netdev_queue___26 * (*select_queue)(struct Qdisc___26 *, struct tcmsg *);
	int (*graft)(struct Qdisc___26 *, long unsigned int, struct Qdisc___26 *, struct Qdisc___26 **, struct netlink_ext_ack *);
	struct Qdisc___26 * (*leaf)(struct Qdisc___26 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___26 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___26 *, u32);
	int (*change)(struct Qdisc___26 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___26 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___26 *, struct qdisc_walker *);
	struct tcf_block___26 * (*tcf_block)(struct Qdisc___26 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___26 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___26 *, long unsigned int);
	int (*dump)(struct Qdisc___26 *, long unsigned int, struct sk_buff___28 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___26 *, long unsigned int, struct gnet_dump___26 *);
};

struct tcf_chain___26;

struct tcf_block___26 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___32 *net;
	struct Qdisc___26 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___26 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___26;

struct tcf_proto_ops___26;

struct tcf_proto___26 {
	struct tcf_proto___26 *next;
	void *root;
	int (*classify)(struct sk_buff___28 *, const struct tcf_proto___26 *, struct tcf_result___26 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___26 *ops;
	struct tcf_chain___26 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___26 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___26 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___26 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___28 *, const struct tcf_proto___26 *, struct tcf_result___26 *);
	int (*init)(struct tcf_proto___26 *);
	void (*destroy)(struct tcf_proto___26 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___26 *, u32);
	void (*put)(struct tcf_proto___26 *, void *);
	int (*change)(struct net___32 *, struct sk_buff___28 *, struct tcf_proto___26 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___26 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___26 *);
	void (*walk)(struct tcf_proto___26 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___26 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___26 *, void *);
	void (*hw_del)(struct tcf_proto___26 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___32 *, struct tcf_chain___26 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___32 *, struct tcf_proto___26 *, void *, struct sk_buff___28 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___32 *, struct tcf_proto___26 *, void *, struct sk_buff___28 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___28 *, struct net___32 *, void *);
	struct module___143 *owner;
	int flags;
};

struct tcf_chain___26 {
	struct mutex filter_chain_lock;
	struct tcf_proto___26 *filter_chain;
	struct list_head list;
	struct tcf_block___26 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___26 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___19 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___26 *prog;
};

struct pneigh_entry___19;

struct neigh_hash_table___19;

struct neigh_table___19 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___29 *, __u32 *);
	bool (*key_eq)(const struct neighbour___19 *, const void *);
	int (*constructor)(struct neighbour___19 *);
	int (*pconstructor)(struct pneigh_entry___19 *);
	void (*pdestructor)(struct pneigh_entry___19 *);
	void (*proxy_redo)(struct sk_buff___28 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___29 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___19 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___26 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___19 *nht;
	struct pneigh_entry___19 **phash_buckets;
};

struct neigh_ops___19 {
	int family;
	void (*solicit)(struct neighbour___19 *, struct sk_buff___28 *);
	void (*error_report)(struct neighbour___19 *, struct sk_buff___28 *);
	int (*output)(struct neighbour___19 *, struct sk_buff___28 *);
	int (*connected_output)(struct neighbour___19 *, struct sk_buff___28 *);
};

struct pneigh_entry___19 {
	struct pneigh_entry___19 *next;
	possible_net_t___26 net;
	struct net_device___29 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___19 {
	struct neighbour___19 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___6 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___32 *, struct sock___20 *, struct sk_buff___28 *);
	int (*orig_input)(struct sk_buff___28 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___19 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___19 *ctarget;
	struct net___32 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___19 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___19 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___9;

struct timewait_sock_ops___9;

struct proto___19 {
	void (*close)(struct sock___20 *, long int);
	int (*pre_connect)(struct sock___20 *, struct sockaddr *, int);
	int (*connect)(struct sock___20 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___20 *, int);
	struct sock___20 * (*accept)(struct sock___20 *, int, int *, bool);
	int (*ioctl)(struct sock___20 *, int, long unsigned int);
	int (*init)(struct sock___20 *);
	void (*destroy)(struct sock___20 *);
	void (*shutdown)(struct sock___20 *, int);
	int (*setsockopt)(struct sock___20 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___20 *, int, int, char *, int *);
	void (*keepalive)(struct sock___20 *, int);
	int (*compat_ioctl)(struct sock___20 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___20 *, struct msghdr___20 *, size_t);
	int (*recvmsg)(struct sock___20 *, struct msghdr___20 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___20 *, struct page___163 *, int, size_t, int);
	int (*bind)(struct sock___20 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___20 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___20 *, struct sk_buff___28 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___20 *);
	int (*hash)(struct sock___20 *);
	void (*unhash)(struct sock___20 *);
	void (*rehash)(struct sock___20 *);
	int (*get_port)(struct sock___20 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___20 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___20 *, int);
	bool (*sock_is_readable)(struct sock___20 *);
	void (*enter_memory_pressure)(struct sock___20 *);
	void (*leave_memory_pressure)(struct sock___20 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___9 *rsk_prot;
	struct timewait_sock_ops___9 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___143 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___20 *, int);
};

struct request_sock___10;

struct request_sock_ops___9 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___20 *, struct request_sock___10 *);
	void (*send_ack)(const struct sock___20 *, struct sk_buff___28 *, struct request_sock___10 *);
	void (*send_reset)(const struct sock___20 *, struct sk_buff___28 *);
	void (*destructor)(struct request_sock___10 *);
	void (*syn_ack_timeout)(const struct request_sock___10 *);
};

struct timewait_sock_ops___9 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___20 *, struct sock___20 *, void *);
	void (*twsk_destructor)(struct sock___20 *);
};

struct request_sock___10 {
	struct sock_common___19 __req_common;
	struct request_sock___10 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___9 *rsk_ops;
	struct sock___20 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___9 {
	struct in6_addr mca_addr;
	struct inet6_dev___9 *idev;
	struct ifmcaddr6___9 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct selinux_state___4 {
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[8];
	struct page___163 *status_page;
	struct mutex status_lock;
	struct selinux_avc___2 *avc;
	struct selinux_policy *policy;
	struct mutex policy_mutex;
};

struct selinux_kernel_status {
	u32 version;
	u32 sequence;
	u32 enforcing;
	u32 policyload;
	u32 deny_unknown;
};

struct ebitmap_node {
	struct ebitmap_node *next;
	long unsigned int maps[6];
	u32 startbit;
};

struct ebitmap {
	struct ebitmap_node *node;
	u32 highbit;
};

struct policy_file {
	char *data;
	size_t len;
};

struct hashtab_node {
	void *key;
	void *datum;
	struct hashtab_node *next;
};

struct hashtab {
	struct hashtab_node **htable;
	u32 size;
	u32 nel;
};

struct hashtab_info {
	u32 slots_used;
	u32 max_chain_len;
};

struct hashtab_key_params {
	u32 (*hash)(const void *);
	int (*cmp)(const void *, const void *);
};

struct symtab {
	struct hashtab table;
	u32 nprim;
};

struct mls_level {
	u32 sens;
	struct ebitmap cat;
};

struct mls_range {
	struct mls_level level[2];
};

struct context {
	u32 user;
	u32 role;
	u32 type;
	u32 len;
	struct mls_range range;
	char *str;
};

struct sidtab_str_cache;

struct sidtab_entry {
	u32 sid;
	u32 hash;
	struct context context;
	struct sidtab_str_cache *cache;
	struct hlist_node list;
};

struct sidtab_str_cache {
	struct callback_head rcu_member;
	struct list_head lru_member;
	struct sidtab_entry *parent;
	u32 len;
	char str[0];
};

struct sidtab_node_inner;

struct sidtab_node_leaf;

union sidtab_entry_inner {
	struct sidtab_node_inner *ptr_inner;
	struct sidtab_node_leaf *ptr_leaf;
};

struct sidtab_node_inner {
	union sidtab_entry_inner entries[512];
};

struct sidtab_node_leaf {
	struct sidtab_entry entries[39];
};

struct sidtab_isid_entry {
	int set;
	struct sidtab_entry entry;
};

struct sidtab;

struct sidtab_convert_params {
	int (*func)(struct context *, struct context *, void *);
	void *args;
	struct sidtab *target;
};

struct sidtab {
	union sidtab_entry_inner roots[4];
	u32 count;
	struct sidtab_convert_params *convert;
	bool frozen;
	spinlock_t lock;
	u32 cache_free_slots;
	struct list_head cache_lru_list;
	spinlock_t cache_lock;
	struct sidtab_isid_entry isids[27];
	struct hlist_head context_to_sid[512];
};

struct avtab_key {
	u16 source_type;
	u16 target_type;
	u16 target_class;
	u16 specified;
};

struct avtab_extended_perms {
	u8 specified;
	u8 driver;
	struct extended_perms_data perms;
};

struct avtab_datum {
	union {
		u32 data;
		struct avtab_extended_perms *xperms;
	} u;
};

struct avtab_node {
	struct avtab_key key;
	struct avtab_datum datum;
	struct avtab_node *next;
};

struct avtab {
	struct avtab_node **htable;
	u32 nel;
	u32 nslot;
	u32 mask;
};

struct type_set;

struct constraint_expr {
	u32 expr_type;
	u32 attr;
	u32 op;
	struct ebitmap names;
	struct type_set *type_names;
	struct constraint_expr *next;
};

struct type_set {
	struct ebitmap types;
	struct ebitmap negset;
	u32 flags;
};

struct constraint_node {
	u32 permissions;
	struct constraint_expr *expr;
	struct constraint_node *next;
};

struct common_datum {
	u32 value;
	struct symtab permissions;
};

struct class_datum {
	u32 value;
	char *comkey;
	struct common_datum *comdatum;
	struct symtab permissions;
	struct constraint_node *constraints;
	struct constraint_node *validatetrans;
	char default_user;
	char default_role;
	char default_type;
	char default_range;
};

struct role_datum {
	u32 value;
	u32 bounds;
	struct ebitmap dominates;
	struct ebitmap types;
};

struct role_allow {
	u32 role;
	u32 new_role;
	struct role_allow *next;
};

struct type_datum {
	u32 value;
	u32 bounds;
	unsigned char primary;
	unsigned char attribute;
};

struct user_datum {
	u32 value;
	u32 bounds;
	struct ebitmap roles;
	struct mls_range range;
	struct mls_level dfltlevel;
};

struct cond_bool_datum {
	__u32 value;
	int state;
};

struct ocontext {
	union {
		char *name;
		struct {
			u8 protocol;
			u16 low_port;
			u16 high_port;
		} port;
		struct {
			u32 addr;
			u32 mask;
		} node;
		struct {
			u32 addr[4];
			u32 mask[4];
		} node6;
		struct {
			u64 subnet_prefix;
			u16 low_pkey;
			u16 high_pkey;
		} ibpkey;
		struct {
			char *dev_name;
			u8 port;
		} ibendport;
	} u;
	union {
		u32 sclass;
		u32 behavior;
	} v;
	struct context context[2];
	u32 sid[2];
	struct ocontext *next;
};

struct genfs {
	char *fstype;
	struct ocontext *head;
	struct genfs *next;
};

struct cond_node;

struct policydb {
	int mls_enabled;
	struct symtab symtab[8];
	char **sym_val_to_name[8];
	struct class_datum **class_val_to_struct;
	struct role_datum **role_val_to_struct;
	struct user_datum **user_val_to_struct;
	struct type_datum **type_val_to_struct;
	struct avtab te_avtab;
	struct hashtab role_tr;
	struct ebitmap filename_trans_ttypes;
	struct hashtab filename_trans;
	u32 compat_filename_trans_count;
	struct cond_bool_datum **bool_val_to_struct;
	struct avtab te_cond_avtab;
	struct cond_node *cond_list;
	u32 cond_list_len;
	struct role_allow *role_allow;
	struct ocontext *ocontexts[9];
	struct genfs *genfs;
	struct hashtab range_tr;
	struct ebitmap *type_attr_map_array;
	struct ebitmap policycaps;
	struct ebitmap permissive_map;
	size_t len;
	unsigned int policyvers;
	unsigned int reject_unknown;
	unsigned int allow_unknown;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 process_class;
	u32 process_trans_perms;
};

struct perm_datum {
	u32 value;
};

struct role_trans_key {
	u32 role;
	u32 type;
	u32 tclass;
};

struct role_trans_datum {
	u32 new_role;
};

struct filename_trans_key {
	u32 ttype;
	u16 tclass;
	const char *name;
};

struct filename_trans_datum {
	struct ebitmap stypes;
	u32 otype;
	struct filename_trans_datum *next;
};

struct level_datum {
	struct mls_level *level;
	unsigned char isalias;
};

struct cat_datum {
	u32 value;
	unsigned char isalias;
};

struct range_trans {
	u32 source_type;
	u32 target_type;
	u32 target_class;
};

struct cond_expr_node;

struct cond_expr {
	struct cond_expr_node *nodes;
	u32 len;
};

struct cond_av_list {
	struct avtab_node **nodes;
	u32 len;
};

struct cond_node {
	int cur_state;
	struct cond_expr expr;
	struct cond_av_list true_list;
	struct cond_av_list false_list;
};

struct policy_data {
	struct policydb *p;
	void *fp;
};

struct cond_expr_node {
	u32 expr_type;
	u32 bool;
};

struct policydb_compat_info {
	int version;
	int sym_num;
	int ocon_num;
};

struct policydb___2 {
	int mls_enabled;
	struct symtab symtab[8];
	char **sym_val_to_name[8];
	struct class_datum **class_val_to_struct;
	struct role_datum **role_val_to_struct;
	struct user_datum **user_val_to_struct;
	struct type_datum **type_val_to_struct;
	struct avtab te_avtab;
	struct hashtab role_tr;
	struct ebitmap filename_trans_ttypes;
	struct hashtab filename_trans;
	u32 compat_filename_trans_count;
	struct cond_bool_datum **bool_val_to_struct;
	struct avtab te_cond_avtab;
	struct cond_node *cond_list;
	u32 cond_list_len;
	struct role_allow *role_allow;
	struct ocontext *ocontexts[9];
	struct genfs *genfs;
	struct hashtab range_tr;
	struct ebitmap *type_attr_map_array;
	struct ebitmap policycaps;
	struct ebitmap permissive_map;
	size_t len;
	unsigned int policyvers;
	unsigned int reject_unknown: 1;
	unsigned int allow_unknown: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 process_class;
	u32 process_trans_perms;
};

struct selinux_mapping;

struct selinux_map {
	struct selinux_mapping *mapping;
	u16 size;
};

struct selinux_policy {
	struct sidtab *sidtab;
	struct policydb___2 policydb;
	struct selinux_map map;
	u32 latest_granting;
};

struct convert_context_args {
	struct selinux_state___2 *state;
	struct policydb___2 *oldp;
	struct policydb___2 *newp;
};

struct selinux_policy_convert_data {
	struct convert_context_args args;
	struct sidtab_convert_params sidtab_params;
};

struct selinux_mapping {
	u16 value;
	unsigned int num_perms;
	u32 perms[32];
};

struct selinux_audit_rule {
	u32 au_seqno;
	struct context au_ctxt;
};

struct cond_insertf_data {
	struct policydb *p;
	struct avtab_node **dst;
	struct cond_av_list *other;
};

struct rt6key {
	struct in6_addr addr;
	int plen;
};

struct rtable;

struct fnhe_hash_bucket;

struct fib_nh_common {
	struct net_device___3 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___4 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable **nhc_pcpu_rth_output;
	struct rtable *nhc_rth_input;
	struct fnhe_hash_bucket *nhc_exceptions;
};

struct rt6_exception_bucket;

struct fib6_nh {
	struct fib_nh_common nh_common;
	long unsigned int last_probe;
	struct rt6_info **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node;

struct dst_metrics;

struct nexthop;

struct fib6_info {
	struct fib6_table *fib6_table;
	struct fib6_info *fib6_next;
	struct fib6_node *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh fib6_nh[0];
};

struct uncached_list;

struct rt6_info {
	struct dst_entry___17 dst;
	struct fib6_info *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___7 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct rt6_statistics {
	__u32 fib_nodes;
	__u32 fib_route_nodes;
	__u32 fib_rt_entries;
	__u32 fib_rt_cache;
	__u32 fib_discarded_routes;
	atomic_t fib_rt_alloc;
	atomic_t fib_rt_uncache;
};

struct fib6_node {
	struct fib6_node *parent;
	struct fib6_node *left;
	struct fib6_node *right;
	struct fib6_node *subtree;
	struct fib6_info *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

typedef union {
	__be32 a4;
	__be32 a6[4];
	struct in6_addr in6;
} xfrm_address_t;

struct xfrm_id {
	xfrm_address_t daddr;
	__be32 spi;
	__u8 proto;
};

struct xfrm_selector {
	xfrm_address_t daddr;
	xfrm_address_t saddr;
	__be16 dport;
	__be16 dport_mask;
	__be16 sport;
	__be16 sport_mask;
	__u16 family;
	__u8 prefixlen_d;
	__u8 prefixlen_s;
	__u8 proto;
	int ifindex;
	__kernel_uid32_t user;
};

struct xfrm_lifetime_cfg {
	__u64 soft_byte_limit;
	__u64 hard_byte_limit;
	__u64 soft_packet_limit;
	__u64 hard_packet_limit;
	__u64 soft_add_expires_seconds;
	__u64 hard_add_expires_seconds;
	__u64 soft_use_expires_seconds;
	__u64 hard_use_expires_seconds;
};

struct xfrm_lifetime_cur {
	__u64 bytes;
	__u64 packets;
	__u64 add_time;
	__u64 use_time;
};

struct xfrm_replay_state {
	__u32 oseq;
	__u32 seq;
	__u32 bitmap;
};

struct xfrm_replay_state_esn {
	unsigned int bmp_len;
	__u32 oseq;
	__u32 seq;
	__u32 oseq_hi;
	__u32 seq_hi;
	__u32 replay_window;
	__u32 bmp[0];
};

struct xfrm_algo {
	char alg_name[64];
	unsigned int alg_key_len;
	char alg_key[0];
};

struct xfrm_algo_auth {
	char alg_name[64];
	unsigned int alg_key_len;
	unsigned int alg_trunc_len;
	char alg_key[0];
};

struct xfrm_algo_aead {
	char alg_name[64];
	unsigned int alg_key_len;
	unsigned int alg_icv_len;
	char alg_key[0];
};

struct xfrm_stats {
	__u32 replay_window;
	__u32 replay;
	__u32 integrity_failed;
};

enum {
	XFRM_POLICY_TYPE_MAIN = 0,
	XFRM_POLICY_TYPE_SUB = 1,
	XFRM_POLICY_TYPE_MAX = 2,
	XFRM_POLICY_TYPE_ANY = 255,
};

struct xfrm_encap_tmpl {
	__u16 encap_type;
	__be16 encap_sport;
	__be16 encap_dport;
	xfrm_address_t encap_oa;
};

enum xfrm_attr_type_t {
	XFRMA_UNSPEC = 0,
	XFRMA_ALG_AUTH = 1,
	XFRMA_ALG_CRYPT = 2,
	XFRMA_ALG_COMP = 3,
	XFRMA_ENCAP = 4,
	XFRMA_TMPL = 5,
	XFRMA_SA = 6,
	XFRMA_POLICY = 7,
	XFRMA_SEC_CTX = 8,
	XFRMA_LTIME_VAL = 9,
	XFRMA_REPLAY_VAL = 10,
	XFRMA_REPLAY_THRESH = 11,
	XFRMA_ETIMER_THRESH = 12,
	XFRMA_SRCADDR = 13,
	XFRMA_COADDR = 14,
	XFRMA_LASTUSED = 15,
	XFRMA_POLICY_TYPE = 16,
	XFRMA_MIGRATE = 17,
	XFRMA_ALG_AEAD = 18,
	XFRMA_KMADDRESS = 19,
	XFRMA_ALG_AUTH_TRUNC = 20,
	XFRMA_MARK = 21,
	XFRMA_TFCPAD = 22,
	XFRMA_REPLAY_ESN_VAL = 23,
	XFRMA_SA_EXTRA_FLAGS = 24,
	XFRMA_PROTO = 25,
	XFRMA_ADDRESS_FILTER = 26,
	XFRMA_PAD = 27,
	XFRMA_OFFLOAD_DEV = 28,
	XFRMA_SET_MARK = 29,
	XFRMA_SET_MARK_MASK = 30,
	XFRMA_IF_ID = 31,
	XFRMA_MTIMER_THRESH = 32,
	__XFRMA_MAX = 33,
};

struct xfrm_mark {
	__u32 v;
	__u32 m;
};

struct xfrm_address_filter {
	xfrm_address_t saddr;
	xfrm_address_t daddr;
	__u16 family;
	__u8 splen;
	__u8 dplen;
};

struct xfrm_state_walk {
	struct list_head all;
	u8 state;
	u8 dying;
	u8 proto;
	u32 seq;
	struct xfrm_address_filter *filter;
};

enum xfrm_replay_mode {
	XFRM_REPLAY_MODE_LEGACY = 0,
	XFRM_REPLAY_MODE_BMP = 1,
	XFRM_REPLAY_MODE_ESN = 2,
};

struct xfrm_state_offload {
	struct net_device___3 *dev;
	struct net_device___3 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_mode {
	u8 encap;
	u8 family;
	u8 flags;
};

struct xfrm_type;

struct xfrm_type_offload;

struct xfrm_state {
	possible_net_t___24 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___18 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___161 xfrag;
	const struct xfrm_type *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct dst_metrics {
	u32 metrics[17];
	refcount_t refcnt;
};

struct xfrm_policy_walk_entry {
	struct list_head all;
	u8 dead;
};

struct xfrm_policy_queue {
	struct sk_buff_head___24 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_tmpl {
	struct xfrm_id id;
	xfrm_address_t saddr;
	short unsigned int encap_family;
	u32 reqid;
	u8 mode;
	u8 share;
	u8 optional;
	u8 allalgs;
	u32 aalgos;
	u32 ealgos;
	u32 calgos;
};

struct xfrm_policy {
	possible_net_t___24 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct udp_hslot;

struct udp_table {
	struct udp_hslot *hash;
	struct udp_hslot *hash2;
	unsigned int mask;
	unsigned int log;
};

struct fib_nh_exception {
	struct fib_nh_exception *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable *fnhe_rth_input;
	struct rtable *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable {
	struct dst_entry___17 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket {
	struct fib_nh_exception *chain;
};

struct rt6_exception_bucket {
	struct hlist_head chain;
	int depth;
};

struct xfrm_type {
	struct module___141 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state *);
	void (*destructor)(struct xfrm_state *);
	int (*input)(struct xfrm_state *, struct sk_buff___26 *);
	int (*output)(struct xfrm_state *, struct sk_buff___26 *);
	int (*reject)(struct xfrm_state *, struct sk_buff___26 *, const struct flowi *);
};

struct xfrm_type_offload {
	struct module___141 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state *, struct sk_buff___26 *);
	int (*input_tail)(struct xfrm_state *, struct sk_buff___26 *);
	int (*xmit)(struct xfrm_state *, struct sk_buff___26 *, netdev_features_t);
};

struct xfrm_dst {
	union {
		struct dst_entry___17 dst;
		struct rtable rt;
		struct rt6_info rt6;
	} u;
	struct dst_entry___17 *route;
	struct dst_entry___17 *child;
	struct dst_entry___17 *path;
	struct xfrm_policy *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_offload {
	struct {
		__u32 low;
		__u32 hi;
	} seq;
	__u32 flags;
	__u32 status;
	__u8 proto;
	__u8 inner_ipproto;
};

struct sec_path {
	int len;
	int olen;
	struct xfrm_state *xvec[6];
	struct xfrm_offload ovec[1];
};

struct udp_hslot {
	struct hlist_head head;
	int count;
	spinlock_t lock;
};

struct pkey_security_struct {
	u64 subnet_prefix;
	u16 pkey;
	u32 sid;
};

struct sel_ib_pkey_bkt {
	int size;
	struct list_head list;
};

struct sel_ib_pkey {
	struct pkey_security_struct psec;
	struct list_head list;
	struct callback_head rcu;
};

typedef int (*key_restrict_link_func_t___13)(struct key___8 *, const struct key_type *, const union key_payload *, struct key___8 *);

struct selinux_state___5 {
	bool enforcing;
	bool checkreqprot;
	bool initialized;
	bool policycap[8];
	struct page___157 *status_page;
	struct mutex status_lock;
	struct selinux_avc___2 *avc;
	struct selinux_policy *policy;
	struct mutex policy_mutex;
};

struct fs_context___29;

struct fs_parameter_spec___20;

struct dentry___159;

struct super_block___159;

struct module___144;

struct file_system_type___159 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___29 *);
	const struct fs_parameter_spec___20 *parameters;
	struct dentry___159 * (*mount)(struct file_system_type___159 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___159 *);
	struct module___144 *owner;
	struct file_system_type___159 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___159;

struct kiocb___159;

struct iov_iter___88;

struct poll_table_struct___100;

struct vm_area_struct___164;

struct inode___159;

struct file_lock___159;

struct page___164;

struct pipe_inode_info___52;

struct seq_file___137;

struct file_operations___159 {
	struct module___144 *owner;
	loff_t (*llseek)(struct file___159 *, loff_t, int);
	ssize_t (*read)(struct file___159 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___159 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___159 *, struct iov_iter___88 *);
	ssize_t (*write_iter)(struct kiocb___159 *, struct iov_iter___88 *);
	int (*iopoll)(struct kiocb___159 *, bool);
	int (*iterate)(struct file___159 *, struct dir_context *);
	int (*iterate_shared)(struct file___159 *, struct dir_context *);
	__poll_t (*poll)(struct file___159 *, struct poll_table_struct___100 *);
	long int (*unlocked_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___159 *, struct vm_area_struct___164 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___159 *, struct file___159 *);
	int (*flush)(struct file___159 *, fl_owner_t);
	int (*release)(struct inode___159 *, struct file___159 *);
	int (*fsync)(struct file___159 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___159 *, int);
	int (*lock)(struct file___159 *, int, struct file_lock___159 *);
	ssize_t (*sendpage)(struct file___159 *, struct page___164 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___159 *, long unsigned int);
	int (*flock)(struct file___159 *, int, struct file_lock___159 *);
	ssize_t (*splice_write)(struct pipe_inode_info___52 *, struct file___159 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___159 *, loff_t *, struct pipe_inode_info___52 *, size_t, unsigned int);
	int (*setlease)(struct file___159 *, long int, struct file_lock___159 **, void **);
	long int (*fallocate)(struct file___159 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___137 *, struct file___159 *);
	ssize_t (*copy_file_range)(struct file___159 *, loff_t, struct file___159 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___159 *, loff_t, struct file___159 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___159 *, loff_t, loff_t, int);
};

struct vmacache___164 {
	u64 seqnum;
	struct vm_area_struct___164 *vmas[4];
};

struct page_frag___164 {
	struct page___164 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___165;

struct pid___140;

struct cred___27;

struct key___10;

struct nsproxy___149;

struct signal_struct___160;

struct bio_list___72;

struct backing_dev_info___69;

struct io_context___72;

struct css_set___108;

struct mem_cgroup___60;

struct request_queue___72;

struct vm_struct___143;

struct task_struct___166 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___166 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___165 *mm;
	struct mm_struct___165 *active_mm;
	struct vmacache___164 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___166 *real_parent;
	struct task_struct___166 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___166 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___140 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___149 *nsproxy;
	struct signal_struct___160 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___166 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___72 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___69 *backing_dev_info;
	struct io_context___72 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___108 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___52 *splice_pipe;
	struct page_frag___164 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___60 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___60 *active_memcg;
	struct request_queue___72 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___166 *oom_reaper_list;
	struct vm_struct___143 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___146;

struct kobj_type___146;

struct kernfs_node___146;

struct kobject___146 {
	const char *name;
	struct list_head entry;
	struct kobject___146 *parent;
	struct kset___146 *kset;
	struct kobj_type___146 *ktype;
	struct kernfs_node___146 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___143 {
	struct kobject___146 kobj;
	struct module___144 *mod;
	struct kobject___146 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___143 {
	struct module___144 *mod;
	struct latch_tree_node node;
};

struct module_layout___143 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___143 mtn;
};

struct module_attribute___143;

struct kernel_param___143;

struct module___144 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___143 mkobj;
	struct module_attribute___143 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___146 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___143 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___143 core_layout;
	struct module_layout___143 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___164 *pgtable_t___164;

struct address_space___159;

struct page_pool___43;

struct dev_pagemap___155;

struct page___164 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___159 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___43 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___164 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___164 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___165 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___155 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___155;

struct vm_area_struct___164 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___164 *vm_next;
	struct vm_area_struct___164 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___165 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___155 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___159 *vm_file;
	struct file___159 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___30;

struct core_state___164;

struct user_namespace___24;

struct mm_struct___165 {
	struct {
		struct vm_area_struct___164 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___30 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___164 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___166 *owner;
		struct user_namespace___24 *user_ns;
		struct file___159 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___159;

struct address_space___159 {
	struct inode___159 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___159 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___115;

struct page_pool_params___43 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___115 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___43 {
	u32 count;
	struct page___164 *cache[128];
};

struct page_pool___43 {
	struct page_pool_params___43 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___164 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___43 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___155;

struct dev_pagemap___155 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___155 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___159;

struct path___159 {
	struct vfsmount___159 *mnt;
	struct dentry___159 *dentry;
};

struct fown_struct___140 {
	rwlock_t lock;
	struct pid___140 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___159 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___159 f_path;
	struct inode___159 *f_inode;
	const struct file_operations___159 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___140 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___159 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___155;

struct vm_operations_struct___155 {
	void (*open)(struct vm_area_struct___164 *);
	void (*close)(struct vm_area_struct___164 *);
	int (*may_split)(struct vm_area_struct___164 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___164 *);
	int (*mprotect)(struct vm_area_struct___164 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___155 *);
	vm_fault_t (*huge_fault)(struct vm_fault___155 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___155 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___164 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___155 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___155 *);
	int (*access)(struct vm_area_struct___164 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___164 *);
	int (*set_policy)(struct vm_area_struct___164 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___164 *, long unsigned int);
	struct page___164 * (*find_special_page)(struct vm_area_struct___164 *, long unsigned int);
};

struct core_thread___164 {
	struct task_struct___166 *task;
	struct core_thread___164 *next;
};

struct core_state___164 {
	atomic_t nr_threads;
	struct core_thread___164 dumper;
	struct completion startup;
};

struct linux_binprm___31;

struct coredump_params___30;

struct linux_binfmt___30 {
	struct list_head lh;
	struct module___144 *module;
	int (*load_binary)(struct linux_binprm___31 *);
	int (*load_shlib)(struct file___159 *);
	int (*core_dump)(struct coredump_params___30 *);
	long unsigned int min_coredump;
};

struct ucounts___24;

struct user_namespace___24 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___24 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___26 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___10 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___10 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___24 *ucounts;
	long int ucount_max[16];
};

struct vm_fault___155 {
	const struct {
		struct vm_area_struct___164 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___164 *cow_page;
	struct page___164 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___164 prealloc_pte;
};

struct pglist_data___67;

struct lruvec___67 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___67 *pgdat;
};

struct zone___67 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___67 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___67 {
	struct zone___67 *zone;
	int zone_idx;
};

struct zonelist___67 {
	struct zoneref___67 _zonerefs[321];
};

struct pglist_data___67 {
	struct zone___67 node_zones[5];
	struct zonelist___67 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___166 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___166 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___67 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___60 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___60 *memcg;
};

struct cgroup___108;

struct cgroup_subsys___108;

struct cgroup_subsys_state___108 {
	struct cgroup___108 *cgroup;
	struct cgroup_subsys___108 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___108 *parent;
};

struct cgroup_file___108 {
	struct kernfs_node___146 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___60;

struct mem_cgroup_per_node___60;

struct mem_cgroup___60 {
	struct cgroup_subsys_state___108 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___108 events_file;
	struct cgroup_file___108 events_local_file;
	struct cgroup_file___108 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___60 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___166 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___60 *nodeinfo[0];
	long: 64;
};

struct shrinker___60 {
	long unsigned int (*count_objects)(struct shrinker___60 *, struct shrink_control___60 *);
	long unsigned int (*scan_objects)(struct shrinker___60 *, struct shrink_control___60 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___155 {
	void (*page_free)(struct page___164 *);
	void (*kill)(struct dev_pagemap___155 *);
	void (*cleanup)(struct dev_pagemap___155 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___155 *);
};

struct pid_namespace___140;

struct upid___140 {
	int nr;
	struct pid_namespace___140 *ns;
};

struct pid_namespace___140 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___166 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___140 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___140 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___140 numbers[1];
};

struct ucounts___24 {
	struct hlist_node node;
	struct user_namespace___24 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct signal_struct___160 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___166 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___166 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___140 *pids[4];
	struct pid___140 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___165 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___27 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___10 *session_keyring;
	struct key___10 *process_keyring;
	struct key___10 *thread_keyring;
	struct key___10 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct watch_list___7;

struct key_restriction___10;

struct key___10 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list___7 *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___8 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___8 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___10 *restrict_link;
};

struct net___33;

struct cgroup_namespace___108;

struct nsproxy___149 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___140 *pid_ns_for_children;
	struct net___33 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___108 *cgroup_ns;
};

struct bio___72;

struct bio_list___72 {
	struct bio___72 *head;
	struct bio___72 *tail;
};

struct bdi_writeback___69 {
	struct backing_dev_info___69 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___108 *memcg_css;
	struct cgroup_subsys_state___108 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___69 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___69 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___115 *dev;
	char dev_name[64];
	struct device___115 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___159 *debug_dir;
};

struct io_cq___72;

struct io_context___72 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___72 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___108 {
	struct cgroup_subsys_state___108 *subsys[14];
	refcount_t refcount;
	struct css_set___108 *dom_cset;
	struct cgroup___108 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___108 *mg_src_cgrp;
	struct cgroup___108 *mg_dst_cgrp;
	struct css_set___108 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___159;

struct pipe_buffer___52;

struct watch_queue___7;

struct pipe_inode_info___52 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___164 *tmp_page;
	struct fasync_struct___159 *fasync_readers;
	struct fasync_struct___159 *fasync_writers;
	struct pipe_buffer___52 *bufs;
	struct user_struct *user;
	struct watch_queue___7 *watch_queue;
};

struct blk_integrity_profile___72;

struct blk_integrity___72 {
	const struct blk_integrity_profile___72 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___72 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___72 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___72;

struct elevator_queue___72;

struct blk_mq_ops___69;

struct blk_mq_hw_ctx___69;

struct gendisk___72;

struct blkcg_gq___69;

struct blk_mq_tag_set___69;

struct request_queue___72 {
	struct request___72 *last_merge;
	struct elevator_queue___72 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___69 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___69 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___72 *disk;
	struct kobject___146 kobj;
	struct kobject___146 *mq_kobj;
	struct blk_integrity___72 integrity;
	struct device___115 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___69 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___69 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___72 bio_split;
	struct dentry___159 *debugfs_dir;
	struct dentry___159 *sched_debugfs_dir;
	struct dentry___159 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___143 {
	struct vm_struct___143 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___164 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___159;

struct dentry___159 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___159 *d_parent;
	struct qstr d_name;
	struct inode___159 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___159 *d_op;
	struct super_block___159 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___159;

struct inode___159 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___159 *i_op;
	struct super_block___159 *i_sb;
	struct address_space___159 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___69 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___159 *i_fop;
		void (*free_inode)(struct inode___159 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___159 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___52 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___159 {
	int (*d_revalidate)(struct dentry___159 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___159 *, unsigned int);
	int (*d_hash)(const struct dentry___159 *, struct qstr *);
	int (*d_compare)(const struct dentry___159 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___159 *);
	int (*d_init)(struct dentry___159 *);
	void (*d_release)(struct dentry___159 *);
	void (*d_prune)(struct dentry___159 *);
	void (*d_iput)(struct dentry___159 *, struct inode___159 *);
	char * (*d_dname)(struct dentry___159 *, char *, int);
	struct vfsmount___159 * (*d_automount)(struct path___159 *);
	int (*d_manage)(const struct path___159 *, bool);
	struct dentry___159 * (*d_real)(struct dentry___159 *, const struct inode___159 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___159;

struct mem_dqinfo___159 {
	struct quota_format_type___159 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___159;

struct quota_info___159 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___159 *files[3];
	struct mem_dqinfo___159 info[3];
	const struct quota_format_ops___159 *ops[3];
};

struct rcuwait___160 {
	struct task_struct___166 *task;
};

struct percpu_rw_semaphore___160 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___160 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___159 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___160 rw_sem[3];
};

struct super_operations___159;

struct dquot_operations___159;

struct quotactl_ops___159;

struct xattr_handler___22;

struct block_device___73;

struct super_block___159 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___159 *s_type;
	const struct super_operations___159 *s_op;
	const struct dquot_operations___159 *dq_op;
	const struct quotactl_ops___159 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___159 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___22 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___73 *s_bdev;
	struct backing_dev_info___69 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___159 s_dquot;
	struct sb_writers___159 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___159 *s_d_op;
	int cleancache_poolid;
	struct shrinker___60 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___159 {
	struct dentry___159 *mnt_root;
	struct super_block___159 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct psi_group___108 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___166 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___27;

struct cgroup_bpf___27 {
	struct bpf_prog_array___27 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___27 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___108;

struct cgroup_rstat_cpu___108;

struct cgroup___108 {
	struct cgroup_subsys_state___108 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___146 *kn;
	struct cgroup_file___108 procs_file;
	struct cgroup_file___108 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___108 *subsys[14];
	struct cgroup_root___108 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___108 *dom_cgrp;
	struct cgroup___108 *old_dom_cgrp;
	struct cgroup_rstat_cpu___108 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___108 psi;
	struct cgroup_bpf___27 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

typedef int (*key_restrict_link_func_t___14)(struct key___10 *, const struct key_type *, const union key_payload *, struct key___10 *);

struct key_restriction___10 {
	key_restrict_link_func_t___14 check;
	struct key___10 *key;
	struct key_type *keytype;
};

struct watch___7;

struct watch_list___7 {
	struct callback_head rcu;
	struct hlist_head watchers;
	void (*release_watch)(struct watch___7 *);
	spinlock_t lock;
};

struct io_cq___72 {
	struct request_queue___72 *q;
	struct io_context___72 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___74;

struct kiocb___159 {
	struct file___159 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___159 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___159 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___159 *ia_file;
};

struct dquot___159 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___159 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___159 {
	int qf_fmt_id;
	const struct quota_format_ops___159 *qf_ops;
	struct module___144 *qf_owner;
	struct quota_format_type___159 *qf_next;
};

struct quota_format_ops___159 {
	int (*check_quota_file)(struct super_block___159 *, int);
	int (*read_file_info)(struct super_block___159 *, int);
	int (*write_file_info)(struct super_block___159 *, int);
	int (*free_file_info)(struct super_block___159 *, int);
	int (*read_dqblk)(struct dquot___159 *);
	int (*commit_dqblk)(struct dquot___159 *);
	int (*release_dqblk)(struct dquot___159 *);
	int (*get_next_id)(struct super_block___159 *, struct kqid *);
};

struct dquot_operations___159 {
	int (*write_dquot)(struct dquot___159 *);
	struct dquot___159 * (*alloc_dquot)(struct super_block___159 *, int);
	void (*destroy_dquot)(struct dquot___159 *);
	int (*acquire_dquot)(struct dquot___159 *);
	int (*release_dquot)(struct dquot___159 *);
	int (*mark_dirty)(struct dquot___159 *);
	int (*write_info)(struct super_block___159 *, int);
	qsize_t * (*get_reserved_space)(struct inode___159 *);
	int (*get_projid)(struct inode___159 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___159 *, qsize_t *);
	int (*get_next_id)(struct super_block___159 *, struct kqid *);
};

struct quotactl_ops___159 {
	int (*quota_on)(struct super_block___159 *, int, int, const struct path___159 *);
	int (*quota_off)(struct super_block___159 *, int);
	int (*quota_enable)(struct super_block___159 *, unsigned int);
	int (*quota_disable)(struct super_block___159 *, unsigned int);
	int (*quota_sync)(struct super_block___159 *, int);
	int (*set_info)(struct super_block___159 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___159 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___159 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___159 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___159 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___159 *, unsigned int);
};

struct wait_page_queue___74 {
	struct page___164 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___69;

struct readahead_control___74;

struct address_space_operations___159 {
	int (*writepage)(struct page___164 *, struct writeback_control___69 *);
	int (*readpage)(struct file___159 *, struct page___164 *);
	int (*writepages)(struct address_space___159 *, struct writeback_control___69 *);
	int (*set_page_dirty)(struct page___164 *);
	int (*readpages)(struct file___159 *, struct address_space___159 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___74 *);
	int (*write_begin)(struct file___159 *, struct address_space___159 *, loff_t, unsigned int, unsigned int, struct page___164 **, void **);
	int (*write_end)(struct file___159 *, struct address_space___159 *, loff_t, unsigned int, unsigned int, struct page___164 *, void *);
	sector_t (*bmap)(struct address_space___159 *, sector_t);
	void (*invalidatepage)(struct page___164 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___164 *, gfp_t);
	void (*freepage)(struct page___164 *);
	ssize_t (*direct_IO)(struct kiocb___159 *, struct iov_iter___88 *);
	int (*migratepage)(struct address_space___159 *, struct page___164 *, struct page___164 *, enum migrate_mode);
	bool (*isolate_page)(struct page___164 *, isolate_mode_t);
	void (*putback_page)(struct page___164 *);
	int (*launder_page)(struct page___164 *);
	int (*is_partially_uptodate)(struct page___164 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___164 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___159 *, struct page___164 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___159 *, sector_t *);
	void (*swap_deactivate)(struct file___159 *);
};

struct writeback_control___69 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___69 *wb;
	struct inode___159 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___74 {
	struct file___159 *file;
	struct address_space___159 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___86;

struct iov_iter___88 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___86 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___52 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___159 {
	struct dentry___159 * (*lookup)(struct inode___159 *, struct dentry___159 *, unsigned int);
	const char * (*get_link)(struct dentry___159 *, struct inode___159 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___159 *, int);
	struct posix_acl * (*get_acl)(struct inode___159 *, int, bool);
	int (*readlink)(struct dentry___159 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___159 *, struct dentry___159 *, umode_t, bool);
	int (*link)(struct dentry___159 *, struct inode___159 *, struct dentry___159 *);
	int (*unlink)(struct inode___159 *, struct dentry___159 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___159 *, struct dentry___159 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___159 *, struct dentry___159 *, umode_t);
	int (*rmdir)(struct inode___159 *, struct dentry___159 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___159 *, struct dentry___159 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___159 *, struct dentry___159 *, struct inode___159 *, struct dentry___159 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___159 *, struct iattr___159 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___159 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___159 *, char *, size_t);
	int (*fiemap)(struct inode___159 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___159 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___159 *, struct dentry___159 *, struct file___159 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___159 *, struct dentry___159 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___159 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___159 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___159 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___159 {
	void (*fl_copy_lock)(struct file_lock___159 *, struct file_lock___159 *);
	void (*fl_release_private)(struct file_lock___159 *);
};

struct lock_manager_operations___159;

struct file_lock___159 {
	struct file_lock___159 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___159 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___159 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___159 *fl_ops;
	const struct lock_manager_operations___159 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___159 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___159 *);
	int (*lm_grant)(struct file_lock___159 *, int);
	bool (*lm_break)(struct file_lock___159 *);
	int (*lm_change)(struct file_lock___159 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___159 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___159 *);
};

struct fasync_struct___159 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___159 *fa_next;
	struct file___159 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___159 {
	struct inode___159 * (*alloc_inode)(struct super_block___159 *);
	void (*destroy_inode)(struct inode___159 *);
	void (*free_inode)(struct inode___159 *);
	void (*dirty_inode)(struct inode___159 *, int);
	int (*write_inode)(struct inode___159 *, struct writeback_control___69 *);
	int (*drop_inode)(struct inode___159 *);
	void (*evict_inode)(struct inode___159 *);
	void (*put_super)(struct super_block___159 *);
	int (*sync_fs)(struct super_block___159 *, int);
	int (*freeze_super)(struct super_block___159 *);
	int (*freeze_fs)(struct super_block___159 *);
	int (*thaw_super)(struct super_block___159 *);
	int (*unfreeze_fs)(struct super_block___159 *);
	int (*statfs)(struct dentry___159 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___159 *, int *, char *);
	void (*umount_begin)(struct super_block___159 *);
	int (*show_options)(struct seq_file___137 *, struct dentry___159 *);
	int (*show_devname)(struct seq_file___137 *, struct dentry___159 *);
	int (*show_path)(struct seq_file___137 *, struct dentry___159 *);
	int (*show_stats)(struct seq_file___137 *, struct dentry___159 *);
	ssize_t (*quota_read)(struct super_block___159 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___159 *, int, const char *, size_t, loff_t);
	struct dquot___159 ** (*get_dquots)(struct inode___159 *);
	long int (*nr_cached_objects)(struct super_block___159 *, struct shrink_control___60 *);
	long int (*free_cached_objects)(struct super_block___159 *, struct shrink_control___60 *);
	struct file___159 * (*real_loop)(struct file___159 *);
};

struct xattr_handler___22 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___159 *);
	int (*get)(const struct xattr_handler___22 *, struct dentry___159 *, struct inode___159 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___22 *, struct user_namespace___24 *, struct dentry___159 *, struct inode___159 *, const char *, const void *, size_t, int);
};

struct wakeup_source___115;

struct dev_pm_info___115 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___115 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___115 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___115;

struct bus_type___115;

struct device_driver___115;

struct dev_pm_domain___115;

struct fwnode_handle___115;

struct class___115;

struct attribute_group___146;

struct device___115 {
	struct kobject___146 kobj;
	struct device___115 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___115 *type;
	struct bus_type___115 *bus;
	struct device_driver___115 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___115 power;
	struct dev_pm_domain___115 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___115 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___115 *class;
	const struct attribute_group___146 **groups;
	void (*release)(struct device___115 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___73 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___159 *bd_inode;
	struct super_block___159 *bd_super;
	void *bd_claiming;
	struct device___115 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___146 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___72 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___159 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___102)(struct file___159 *, wait_queue_head_t *, struct poll_table_struct___100 *);

struct poll_table_struct___100 {
	poll_queue_proc___102 _qproc;
	__poll_t _key;
};

struct seq_operations___137;

struct seq_file___137 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___137 *op;
	int poll_event;
	const struct file___159 *file;
	void *private;
};

struct fc_log___29;

struct p_log___29 {
	const char *prefix;
	struct fc_log___29 *log;
};

struct fs_context_operations___29;

struct fs_context___29 {
	const struct fs_context_operations___29 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___159 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___159 *root;
	struct user_namespace___24 *user_ns;
	struct net___33 *net_ns;
	const struct cred___27 *cred;
	struct p_log___29 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___29;

typedef int fs_param_type___20(struct p_log___29 *, const struct fs_parameter_spec___20 *, struct fs_parameter___29 *, struct fs_parse_result *);

struct fs_parameter_spec___20 {
	const char *name;
	fs_param_type___20 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___72(struct bio___72 *);

struct bio_vec___86 {
	struct page___164 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___72;

struct bio___72 {
	struct bio___72 *bi_next;
	struct block_device___73 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___72 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___69 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___72 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___86 *bi_io_vec;
	struct bio_set___72 *bi_pool;
	struct bio_vec___86 bi_inline_vecs[0];
};

struct ip_ra_chain___7;

struct fib_rules_ops___20;

struct sock___21;

struct fqdir___32;

struct fib_notifier_ops___20;

struct netns_ipv4___32 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___7 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___20 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___21 *fibnl;
	struct sock___21 **icmp_sk;
	struct sock___21 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___21 **tcp_sk;
	struct fqdir___32 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___20 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___20 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___20 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___20;

struct net_device___30;

struct sk_buff___29;

struct neighbour___20;

struct dst_ops___32 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___32 *);
	struct dst_entry___20 * (*check)(struct dst_entry___20 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___20 *);
	unsigned int (*mtu)(const struct dst_entry___20 *);
	u32 * (*cow_metrics)(struct dst_entry___20 *, long unsigned int);
	void (*destroy)(struct dst_entry___20 *);
	void (*ifdown)(struct dst_entry___20 *, struct net_device___30 *, int);
	struct dst_entry___20 * (*negative_advice)(struct dst_entry___20 *);
	void (*link_failure)(struct sk_buff___29 *);
	void (*update_pmtu)(struct dst_entry___20 *, struct sock___21 *, struct sk_buff___29 *, u32, bool);
	void (*redirect)(struct dst_entry___20 *, struct sock___21 *, struct sk_buff___29 *);
	int (*local_out)(struct net___33 *, struct sock___21 *, struct sk_buff___29 *);
	struct neighbour___20 * (*neigh_lookup)(const struct dst_entry___20 *, struct sk_buff___29 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___20 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___32 {
	struct dst_ops___32 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___32 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___20 *fib6_rules_ops;
	struct sock___21 **icmp_sk;
	struct sock___21 *ndisc_sk;
	struct sock___21 *tcp_sk;
	struct sock___21 *igmp_sk;
	struct sock___21 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___20 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___20 *notifier_ops;
	struct fib_notifier_ops___20 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___32 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___32 *fqdir;
};

struct netns_sctp___20 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___21 *ctl_sock;
	struct sock___21 *udp4_sock;
	struct sock___21 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___27 {
	struct sk_buff___29 *next;
	struct sk_buff___29 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___27;

struct netns_bpf___27 {
	struct bpf_prog_array___27 *run_array[2];
	struct bpf_prog___27 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___32 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___21 *nlsk;
	struct sock___21 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___32 xfrm4_dst_ops;
	struct dst_ops___32 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___33 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___21 *rtnl;
	struct sock___21 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___30 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___32 ipv4;
	struct netns_ipv6___32 ipv6;
	struct netns_ieee802154_lowpan___32 ieee802154_lowpan;
	struct netns_sctp___20 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___27 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___27 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___32 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___21 *crypto_nlsk;
	struct sock___21 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___108 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___108 *root_cset;
};

struct seq_operations___137 {
	void * (*start)(struct seq_file___137 *, loff_t *);
	void (*stop)(struct seq_file___137 *, void *);
	void * (*next)(struct seq_file___137 *, void *, loff_t *);
	int (*show)(struct seq_file___137 *, void *);
};

struct fwnode_operations___115;

struct fwnode_handle___115 {
	struct fwnode_handle___115 *secondary;
	const struct fwnode_operations___115 *ops;
	struct device___115 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___115;

struct fwnode_endpoint___115;

struct fwnode_operations___115 {
	struct fwnode_handle___115 * (*get)(struct fwnode_handle___115 *);
	void (*put)(struct fwnode_handle___115 *);
	bool (*device_is_available)(const struct fwnode_handle___115 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___115 *, const struct device___115 *);
	bool (*property_present)(const struct fwnode_handle___115 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___115 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___115 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___115 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*get_parent)(const struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*get_next_child_node)(const struct fwnode_handle___115 *, struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*get_named_child_node)(const struct fwnode_handle___115 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___115 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___115 *);
	struct fwnode_handle___115 * (*graph_get_next_endpoint)(const struct fwnode_handle___115 *, struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*graph_get_remote_endpoint)(const struct fwnode_handle___115 *);
	struct fwnode_handle___115 * (*graph_get_port_parent)(struct fwnode_handle___115 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___115 *, struct fwnode_endpoint___115 *);
	int (*add_links)(struct fwnode_handle___115 *);
};

struct fwnode_endpoint___115 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___115 *local_fwnode;
};

struct fwnode_reference_args___115 {
	struct fwnode_handle___115 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___146;

struct kernfs_elem_dir___146 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___146 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___146;

struct kernfs_root___146 {
	struct kernfs_node___146 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___146 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___146 {
	struct kernfs_node___146 *target_kn;
};

struct kernfs_ops___146;

struct kernfs_elem_attr___146 {
	const struct kernfs_ops___146 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___146 *notify_next;
};

struct kernfs_node___146 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___146 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___146 dir;
		struct kernfs_elem_symlink___146 symlink;
		struct kernfs_elem_attr___146 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___146;

struct kernfs_ops___146 {
	int (*open)(struct kernfs_open_file___146 *);
	void (*release)(struct kernfs_open_file___146 *);
	int (*seq_show)(struct seq_file___137 *, void *);
	void * (*seq_start)(struct seq_file___137 *, loff_t *);
	void * (*seq_next)(struct seq_file___137 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___137 *, void *);
	ssize_t (*read)(struct kernfs_open_file___146 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___146 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___146 *, struct poll_table_struct___100 *);
	int (*mmap)(struct kernfs_open_file___146 *, struct vm_area_struct___164 *);
};

struct kernfs_syscall_ops___146 {
	int (*show_options)(struct seq_file___137 *, struct kernfs_root___146 *);
	int (*mkdir)(struct kernfs_node___146 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___146 *);
	int (*rename)(struct kernfs_node___146 *, struct kernfs_node___146 *, const char *);
	int (*show_path)(struct seq_file___137 *, struct kernfs_node___146 *, struct kernfs_root___146 *);
};

struct kernfs_open_file___146 {
	struct kernfs_node___146 *kn;
	struct file___159 *file;
	struct seq_file___137 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___155 *vm_ops;
};

struct kobj_ns_type_operations___20 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___21 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___33 *net;
} possible_net_t___27;

struct proto___20;

struct sock_common___20 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___20 *skc_prot;
	possible_net_t___27 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___21 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___20 {
	struct cgroup___108 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___20;

struct socket_wq___21;

struct socket___21;

struct sock___21 {
	struct sock_common___20 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___27 sk_error_queue;
	struct sk_buff___29 *sk_rx_skb_cache;
	struct sk_buff_head___27 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___29 *head;
		struct sk_buff___29 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___20 *sk_filter;
	union {
		struct socket_wq___21 *sk_wq;
		struct socket_wq___21 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___20 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___20 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___29 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___29 *sk_tx_skb_cache;
	struct sk_buff_head___27 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___164 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___20 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___140 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___21 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___20 sk_cgrp_data;
	struct mem_cgroup___60 *sk_memcg;
	void (*sk_state_change)(struct sock___21 *);
	void (*sk_data_ready)(struct sock___21 *);
	void (*sk_write_space)(struct sock___21 *);
	void (*sk_error_report)(struct sock___21 *);
	int (*sk_backlog_rcv)(struct sock___21 *, struct sk_buff___29 *);
	struct sk_buff___29 * (*sk_validate_xmit_skb)(struct sock___21 *, struct net_device___30 *, struct sk_buff___29 *);
	void (*sk_destruct)(struct sock___21 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___146;

struct attribute_group___146 {
	const char *name;
	umode_t (*is_visible)(struct kobject___146 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___146 *, struct bin_attribute___146 *, int);
	struct attribute **attrs;
	struct bin_attribute___146 **bin_attrs;
};

struct bin_attribute___146 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___159 * (*f_mapping)();
	ssize_t (*read)(struct file___159 *, struct kobject___146 *, struct bin_attribute___146 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___159 *, struct kobject___146 *, struct bin_attribute___146 *, char *, loff_t, size_t);
	int (*mmap)(struct file___159 *, struct kobject___146 *, struct bin_attribute___146 *, struct vm_area_struct___164 *);
};

struct sysfs_ops___146 {
	ssize_t (*show)(struct kobject___146 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___146 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___146;

struct kset___146 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___146 kobj;
	const struct kset_uevent_ops___146 *uevent_ops;
};

struct kobj_type___146 {
	void (*release)(struct kobject___146 *);
	const struct sysfs_ops___146 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___146 **default_groups;
	const struct kobj_ns_type_operations___20 * (*child_ns_type)(struct kobject___146 *);
	const void * (*namespace)(struct kobject___146 *);
	void (*get_ownership)(struct kobject___146 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___146 {
	int (* const filter)(struct kset___146 *, struct kobject___146 *);
	const char * (* const name)(struct kset___146 *, struct kobject___146 *);
	int (* const uevent)(struct kset___146 *, struct kobject___146 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___143 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___143 *);
	int (*get)(char *, const struct kernel_param___143 *);
	void (*free)(void *);
};

struct kparam_array___143;

struct kernel_param___143 {
	const char *name;
	struct module___144 *mod;
	const struct kernel_param_ops___143 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___143 *arr;
	};
};

struct kparam_array___143 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___143 *ops;
	void *elem;
};

struct module_attribute___143 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___143 *, struct module_kobject___143 *, char *);
	ssize_t (*store)(struct module_attribute___143 *, struct module_kobject___143 *, const char *, size_t);
	void (*setup)(struct module___144 *, const char *);
	int (*test)(struct module___144 *);
	void (*free)(struct module___144 *);
};

struct msghdr___21 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___88 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___159 *msg_iocb;
};

struct socket_wq___21 {
	wait_queue_head_t wait;
	struct fasync_struct___159 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___21;

struct socket___21 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___159 *file;
	struct sock___21 *sk;
	const struct proto_ops___21 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___21 wq;
};

typedef int (*sk_read_actor_t___20)(read_descriptor_t *, struct sk_buff___29 *, unsigned int, size_t);

struct proto_ops___21 {
	int family;
	struct module___144 *owner;
	int (*release)(struct socket___21 *);
	int (*bind)(struct socket___21 *, struct sockaddr *, int);
	int (*connect)(struct socket___21 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___21 *, struct socket___21 *);
	int (*accept)(struct socket___21 *, struct socket___21 *, int, bool);
	int (*getname)(struct socket___21 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___159 *, struct socket___21 *, struct poll_table_struct___100 *);
	int (*ioctl)(struct socket___21 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___21 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___21 *, void *, bool, bool);
	int (*listen)(struct socket___21 *, int);
	int (*shutdown)(struct socket___21 *, int);
	int (*setsockopt)(struct socket___21 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___21 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___137 *, struct socket___21 *);
	int (*sendmsg)(struct socket___21 *, struct msghdr___21 *, size_t);
	int (*recvmsg)(struct socket___21 *, struct msghdr___21 *, size_t, int);
	int (*mmap)(struct file___159 *, struct socket___21 *, struct vm_area_struct___164 *);
	ssize_t (*sendpage)(struct socket___21 *, struct page___164 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___21 *, loff_t *, struct pipe_inode_info___52 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___21 *, int);
	int (*peek_len)(struct socket___21 *);
	int (*read_sock)(struct sock___21 *, read_descriptor_t *, sk_read_actor_t___20);
	int (*sendpage_locked)(struct sock___21 *, struct page___164 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___21 *, struct msghdr___21 *, size_t);
	int (*set_rcvlowat)(struct sock___21 *, int);
};

struct sk_buff___29 {
	union {
		struct {
			struct sk_buff___29 *next;
			struct sk_buff___29 *prev;
			union {
				struct net_device___30 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___21 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___29 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___115 {
	int (*prepare)(struct device___115 *);
	void (*complete)(struct device___115 *);
	int (*suspend)(struct device___115 *);
	int (*resume)(struct device___115 *);
	int (*freeze)(struct device___115 *);
	int (*thaw)(struct device___115 *);
	int (*poweroff)(struct device___115 *);
	int (*restore)(struct device___115 *);
	int (*suspend_late)(struct device___115 *);
	int (*resume_early)(struct device___115 *);
	int (*freeze_late)(struct device___115 *);
	int (*thaw_early)(struct device___115 *);
	int (*poweroff_late)(struct device___115 *);
	int (*restore_early)(struct device___115 *);
	int (*suspend_noirq)(struct device___115 *);
	int (*resume_noirq)(struct device___115 *);
	int (*freeze_noirq)(struct device___115 *);
	int (*thaw_noirq)(struct device___115 *);
	int (*poweroff_noirq)(struct device___115 *);
	int (*restore_noirq)(struct device___115 *);
	int (*runtime_suspend)(struct device___115 *);
	int (*runtime_resume)(struct device___115 *);
	int (*runtime_idle)(struct device___115 *);
};

struct wakeup_source___115 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___115 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___115 {
	struct dev_pm_ops___115 ops;
	int (*start)(struct device___115 *);
	void (*detach)(struct device___115 *, bool);
	int (*activate)(struct device___115 *);
	void (*sync)(struct device___115 *);
	void (*dismiss)(struct device___115 *);
};

struct bus_type___115 {
	const char *name;
	const char *dev_name;
	struct device___115 *dev_root;
	const struct attribute_group___146 **bus_groups;
	const struct attribute_group___146 **dev_groups;
	const struct attribute_group___146 **drv_groups;
	int (*match)(struct device___115 *, struct device_driver___115 *);
	int (*uevent)(struct device___115 *, struct kobj_uevent_env *);
	int (*probe)(struct device___115 *);
	void (*sync_state)(struct device___115 *);
	void (*remove)(struct device___115 *);
	void (*shutdown)(struct device___115 *);
	int (*online)(struct device___115 *);
	int (*offline)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	int (*num_vf)(struct device___115 *);
	int (*dma_configure)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___115 {
	const char *name;
	struct bus_type___115 *bus;
	struct module___144 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___115 *);
	void (*sync_state)(struct device___115 *);
	int (*remove)(struct device___115 *);
	void (*shutdown)(struct device___115 *);
	int (*suspend)(struct device___115 *, pm_message_t);
	int (*resume)(struct device___115 *);
	const struct attribute_group___146 **groups;
	const struct attribute_group___146 **dev_groups;
	const struct dev_pm_ops___115 *pm;
	void (*coredump)(struct device___115 *);
	struct driver_private *p;
};

struct device_type___115 {
	const char *name;
	const struct attribute_group___146 **groups;
	int (*uevent)(struct device___115 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___115 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___115 *);
	const struct dev_pm_ops___115 *pm;
};

struct class___115 {
	const char *name;
	struct module___144 *owner;
	const struct attribute_group___146 **class_groups;
	const struct attribute_group___146 **dev_groups;
	struct kobject___146 *dev_kobj;
	int (*dev_uevent)(struct device___115 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___115 *, umode_t *);
	void (*class_release)(struct class___115 *);
	void (*dev_release)(struct device___115 *);
	int (*shutdown_pre)(struct device___115 *);
	const struct kobj_ns_type_operations___20 *ns_type;
	const void * (*namespace)(struct device___115 *);
	void (*get_ownership)(struct device___115 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___115 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___52;

struct pipe_buffer___52 {
	struct page___164 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___52 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___52 {
	int (*confirm)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
	void (*release)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
	bool (*try_steal)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
	bool (*get)(struct pipe_inode_info___52 *, struct pipe_buffer___52 *);
};

struct watch_queue___7 {
	struct callback_head rcu;
	struct watch_filter *filter;
	struct pipe_inode_info___52 *pipe;
	struct hlist_head watches;
	struct page___164 **notes;
	long unsigned int *notes_bitmap;
	struct kref usage;
	spinlock_t lock;
	unsigned int nr_notes;
	unsigned int nr_pages;
	bool defunct;
};

typedef rx_handler_result_t rx_handler_func_t___27(struct sk_buff___29 **);

struct bpf_xdp_entity___27 {
	struct bpf_prog___27 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___27;

struct net_device_ops___27;

struct ethtool_ops___5;

struct l3mdev_ops___20;

struct ndisc_ops___10;

struct xfrmdev_ops___27;

struct header_ops___27;

struct inet6_dev___10;

struct netdev_rx_queue___27;

struct mini_Qdisc___27;

struct netdev_queue___27;

struct Qdisc___27;

struct rtnl_link_ops___27;

struct dcbnl_rtnl_ops___27;

struct net_device___30 {
	char name[16];
	struct netdev_name_node___27 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___27 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___5 *ethtool_ops;
	const struct l3mdev_ops___20 *l3mdev_ops;
	const struct ndisc_ops___10 *ndisc_ops;
	const struct xfrmdev_ops___27 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___27 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___146 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___10 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___27 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___27 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___27 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___27 *miniq_ingress;
	struct netdev_queue___27 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___27 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___27 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___27 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___27 = 0,
		NETREG_REGISTERED___27 = 1,
		NETREG_UNREGISTERING___27 = 2,
		NETREG_UNREGISTERED___27 = 3,
		NETREG_RELEASED___27 = 4,
		NETREG_DUMMY___27 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___27 = 0,
		RTNL_LINK_INITIALIZING___27 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___30 *);
	struct netpoll_info *npinfo;
	possible_net_t___27 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___115 dev;
	const struct attribute_group___146 *sysfs_groups[4];
	const struct attribute_group___146 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___27 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___27 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___27 xdp_state[3];
	long: 64;
};

struct inet_frags___32;

struct fqdir___32 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___32 *f;
	struct net___33 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___32;

struct inet_frags___32 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___32 *, const void *);
	void (*destructor)(struct inet_frag_queue___32 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___32 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___29 *fragments_tail;
	struct sk_buff___29 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___32 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___7 {
	struct ip_ra_chain___7 *next;
	struct sock___21 *sk;
	union {
		void (*destructor)(struct sock___21 *);
		struct sock___21 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___20;

struct fib_lookup_arg___20;

struct fib_rules_ops___20 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___20 *, struct flowi *, int, struct fib_lookup_arg___20 *);
	bool (*suppress)(struct fib_rule___20 *, int, struct fib_lookup_arg___20 *);
	int (*match)(struct fib_rule___20 *, struct flowi *, int);
	int (*configure)(struct fib_rule___20 *, struct sk_buff___29 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___20 *);
	int (*compare)(struct fib_rule___20 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___20 *, struct sk_buff___29 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___20 *);
	void (*flush_cache)(struct fib_rules_ops___20 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___144 *owner;
	struct net___33 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___20 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___33 *);
	int (*fib_dump)(struct net___33 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___144 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___7;

struct dst_entry___20 {
	struct net_device___30 *dev;
	struct dst_ops___32 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___29 *);
	int (*output)(struct net___33 *, struct sock___21 *, struct sk_buff___29 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___7 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___20;

struct neigh_parms___20;

struct neigh_ops___20;

struct neighbour___20 {
	struct neighbour___20 *next;
	struct neigh_table___20 *tbl;
	struct neigh_parms___20 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___27 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___20 *, struct sk_buff___29 *);
	const struct neigh_ops___20 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___30 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___27 {
	struct bpf_prog___27 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___27 {
	struct callback_head rcu;
	struct bpf_prog_array_item___27 items[0];
};

struct bpf_prog_aux___29;

struct bpf_prog___27 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___29 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dcbnl_rtnl_ops___27 {
	int (*ieee_getets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___30 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___30 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___30 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___30 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___30 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___30 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___30 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___30 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___30 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___30 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___30 *);
	u8 (*setstate)(struct net_device___30 *, u8);
	void (*getpermhwaddr)(struct net_device___30 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___30 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___30 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___30 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___30 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___30 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___30 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___30 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___30 *, int, u8 *);
	void (*setpfccfg)(struct net_device___30 *, int, u8);
	void (*getpfccfg)(struct net_device___30 *, int, u8 *);
	u8 (*setall)(struct net_device___30 *);
	u8 (*getcap)(struct net_device___30 *, int, u8 *);
	int (*getnumtcs)(struct net_device___30 *, int, u8 *);
	int (*setnumtcs)(struct net_device___30 *, int, u8);
	u8 (*getpfcstate)(struct net_device___30 *);
	void (*setpfcstate)(struct net_device___30 *, u8);
	void (*getbcncfg)(struct net_device___30 *, int, u32 *);
	void (*setbcncfg)(struct net_device___30 *, int, u32);
	void (*getbcnrp)(struct net_device___30 *, int, u8 *);
	void (*setbcnrp)(struct net_device___30 *, int, u8);
	int (*setapp)(struct net_device___30 *, u8, u16, u8);
	int (*getapp)(struct net_device___30 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___30 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___30 *, int, u8);
	u8 (*getdcbx)(struct net_device___30 *);
	u8 (*setdcbx)(struct net_device___30 *, u8);
	int (*peer_getappinfo)(struct net_device___30 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___30 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___30 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___30 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___30 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___30 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___30;

typedef int (*bpf_iter_init_seq_priv_t___29)(void *, struct bpf_iter_aux_info___30 *);

struct bpf_map___29;

struct bpf_iter_aux_info___30 {
	struct bpf_map___29 *map;
};

struct bpf_iter_seq_info___29 {
	const struct seq_operations___137 *seq_ops;
	bpf_iter_init_seq_priv_t___29 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___29 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___29 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___29 *, struct file___159 *);
	void (*map_free)(struct bpf_map___29 *);
	int (*map_get_next_key)(struct bpf_map___29 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___29 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___29 *, void *);
	int (*map_lookup_batch)(struct bpf_map___29 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___29 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___29 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___29 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___29 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___29 *, void *);
	int (*map_update_elem)(struct bpf_map___29 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___29 *, void *);
	int (*map_push_elem)(struct bpf_map___29 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___29 *, void *);
	int (*map_peek_elem)(struct bpf_map___29 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___29 *, struct file___159 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___29 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___29 *, void *, struct seq_file___137 *);
	int (*map_check_btf)(const struct bpf_map___29 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___29 *, struct bpf_prog_aux___29 *);
	void (*map_poke_untrack)(struct bpf_map___29 *, struct bpf_prog_aux___29 *);
	void (*map_poke_run)(struct bpf_map___29 *, u32, struct bpf_prog___27 *, struct bpf_prog___27 *);
	int (*map_direct_value_addr)(const struct bpf_map___29 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___29 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___29 *, struct vm_area_struct___164 *);
	__poll_t (*map_poll)(struct bpf_map___29 *, struct file___159 *, struct poll_table_struct___100 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___29 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___29 *, const struct bpf_map___29 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___29 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___29 *iter_seq_info;
};

struct bpf_map___29 {
	const struct bpf_map_ops___29 *ops;
	struct bpf_map___29 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___60 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___29;

struct bpf_jit_poke_descriptor___29;

struct bpf_prog_ops___27;

struct btf_mod_pair___29;

struct bpf_prog_offload___27;

struct bpf_prog_aux___29 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___27 *dst_prog;
	struct bpf_trampoline___29 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___27 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___29 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___27 *ops;
	struct bpf_map___29 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___29 *used_btfs;
	struct bpf_prog___27 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___29 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___27 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___27;

struct bpf_map_dev_ops___27 {
	int (*map_get_next_key)(struct bpf_offloaded_map___27 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___27 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___27 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___27 *, void *);
};

struct bpf_offloaded_map___27 {
	struct bpf_map___29 map;
	struct net_device___30 *netdev;
	const struct bpf_map_dev_ops___27 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___27 {
	int (*test_run)(struct bpf_prog___27 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___27 {
	struct bpf_prog___27 *prog;
	struct net_device___30 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___29 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___27 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___144 *mod;
};

struct bpf_jit_poke_descriptor___29 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___29 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___29 {
	struct btf *btf;
	struct module___144 *module;
};

struct cftype___108;

struct cgroup_subsys___108 {
	struct cgroup_subsys_state___108 * (*css_alloc)(struct cgroup_subsys_state___108 *);
	int (*css_online)(struct cgroup_subsys_state___108 *);
	void (*css_offline)(struct cgroup_subsys_state___108 *);
	void (*css_released)(struct cgroup_subsys_state___108 *);
	void (*css_free)(struct cgroup_subsys_state___108 *);
	void (*css_reset)(struct cgroup_subsys_state___108 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___108 *, int);
	int (*css_extra_stat_show)(struct seq_file___137 *, struct cgroup_subsys_state___108 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___166 *, struct css_set___108 *);
	void (*cancel_fork)(struct task_struct___166 *, struct css_set___108 *);
	void (*fork)(struct task_struct___166 *);
	void (*exit)(struct task_struct___166 *);
	void (*release)(struct task_struct___166 *);
	void (*bind)(struct cgroup_subsys_state___108 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___108 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___108 *dfl_cftypes;
	struct cftype___108 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___108 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___108 *updated_children;
	struct cgroup___108 *updated_next;
};

struct cgroup_root___108 {
	struct kernfs_root___146 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___108 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___108 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___108 *ss;
	struct list_head node;
	struct kernfs_ops___146 *kf_ops;
	int (*open)(struct kernfs_open_file___146 *);
	void (*release)(struct kernfs_open_file___146 *);
	u64 (*read_u64)(struct cgroup_subsys_state___108 *, struct cftype___108 *);
	s64 (*read_s64)(struct cgroup_subsys_state___108 *, struct cftype___108 *);
	int (*seq_show)(struct seq_file___137 *, void *);
	void * (*seq_start)(struct seq_file___137 *, loff_t *);
	void * (*seq_next)(struct seq_file___137 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___137 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___108 *, struct cftype___108 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___108 *, struct cftype___108 *, s64);
	ssize_t (*write)(struct kernfs_open_file___146 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___146 *, struct poll_table_struct___100 *);
};

struct xdp_rxq_info___27 {
	struct net_device___30 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___27 {
	struct net_device___30 *dev;
};

struct xdp_buff___27 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___27 *rxq;
	struct xdp_txq_info___27 *txq;
	u32 frame_sz;
};

struct xdp_frame___27 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___30 *dev_rx;
};

struct netlink_callback___27 {
	struct sk_buff___29 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___29 *, struct netlink_callback___27 *);
	int (*done)(struct netlink_callback___27 *);
	void *data;
	struct module___144 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___27 {
	int (*create)(struct sk_buff___29 *, struct net_device___30 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___29 *, unsigned char *);
	int (*cache)(const struct neighbour___20 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___30 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___29 *);
};

struct netdev_queue___27 {
	struct net_device___30 *dev;
	struct Qdisc___27 *qdisc;
	struct Qdisc___27 *qdisc_sleeping;
	struct kobject___146 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___30 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___27 {
	struct sk_buff___29 *head;
	struct sk_buff___29 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___27;

struct Qdisc___27 {
	int (*enqueue)(struct sk_buff___29 *, struct Qdisc___27 *, struct sk_buff___29 **);
	struct sk_buff___29 * (*dequeue)(struct Qdisc___27 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___27 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___27 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___27 gso_skb;
	struct qdisc_skb_head___27 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___27 *next_sched;
	struct sk_buff_head___27 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___27 {
	struct xdp_rxq_info___27 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___146 kobj;
	struct net_device___30 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___27 {
	enum net_device_path_type type;
	const struct net_device___30 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___27 = 0,
				DEV_PATH_BR_VLAN_TAG___27 = 1,
				DEV_PATH_BR_VLAN_UNTAG___27 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___27 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___27 {
	const struct net_device___30 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___27 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___27 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___27 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___27 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___29 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___27 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___30 *dev;
	const char *name;
};

struct net_device_ops___27 {
	int (*ndo_init)(struct net_device___30 *);
	void (*ndo_uninit)(struct net_device___30 *);
	int (*ndo_open)(struct net_device___30 *);
	int (*ndo_stop)(struct net_device___30 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___29 *, struct net_device___30 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___29 *, struct net_device___30 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___30 *, struct sk_buff___29 *, struct net_device___30 *);
	void (*ndo_change_rx_flags)(struct net_device___30 *, int);
	void (*ndo_set_rx_mode)(struct net_device___30 *);
	int (*ndo_set_mac_address)(struct net_device___30 *, void *);
	int (*ndo_validate_addr)(struct net_device___30 *);
	int (*ndo_do_ioctl)(struct net_device___30 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___30 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___30 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___30 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___30 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___30 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___30 *, int);
	int (*ndo_neigh_setup)(struct net_device___30 *, struct neigh_parms___20 *);
	void (*ndo_tx_timeout)(struct net_device___30 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___30 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___30 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___30 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___30 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___30 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___30 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___30 *);
	int (*ndo_netpoll_setup)(struct net_device___30 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___30 *);
	int (*ndo_set_vf_mac)(struct net_device___30 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___30 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___30 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___30 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___30 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___30 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___30 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___30 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___30 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___30 *, int, struct sk_buff___29 *);
	int (*ndo_get_vf_guid)(struct net_device___30 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___30 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___30 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___30 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___30 *);
	int (*ndo_fcoe_disable)(struct net_device___30 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___30 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___30 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___30 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___30 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___30 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___30 *, const struct sk_buff___29 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___30 *, struct net_device___30 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___30 *, struct net_device___30 *);
	struct net_device___30 * (*ndo_get_xmit_slave)(struct net_device___30 *, struct sk_buff___29 *, bool);
	struct net_device___30 * (*ndo_sk_get_lower_dev)(struct net_device___30 *, struct sock___21 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___30 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___30 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___30 *, struct neighbour___20 *);
	void (*ndo_neigh_destroy)(struct net_device___30 *, struct neighbour___20 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___29 *, struct netlink_callback___27 *, struct net_device___30 *, struct net_device___30 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___29 *, struct nlattr **, struct net_device___30 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___30 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___29 *, u32, u32, struct net_device___30 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___30 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___30 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___30 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___30 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___30 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___30 *, struct net_device___30 *);
	void (*ndo_dfwd_del_station)(struct net_device___30 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___30 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___30 *);
	int (*ndo_change_proto_down)(struct net_device___30 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___30 *, struct sk_buff___29 *);
	void (*ndo_set_rx_headroom)(struct net_device___30 *, int);
	int (*ndo_bpf)(struct net_device___30 *, struct netdev_bpf___27 *);
	int (*ndo_xdp_xmit)(struct net_device___30 *, int, struct xdp_frame___27 **, u32);
	struct net_device___30 * (*ndo_xdp_get_xmit_slave)(struct net_device___30 *, struct xdp_buff___27 *);
	int (*ndo_xsk_wakeup)(struct net_device___30 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___30 *);
	int (*ndo_tunnel_ctl)(struct net_device___30 *, struct ip_tunnel_parm *, int);
	struct net_device___30 * (*ndo_get_peer_dev)(struct net_device___30 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___27 *, struct net_device_path___27 *);
};

struct neigh_parms___20 {
	possible_net_t___27 net;
	struct net_device___30 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___20 *);
	struct neigh_table___20 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___5 {
	u32 cap_link_lanes_supported;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___30 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___30 *);
	void (*get_regs)(struct net_device___30 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___30 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___30 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___30 *);
	void (*set_msglevel)(struct net_device___30 *, u32);
	int (*nway_reset)(struct net_device___30 *);
	u32 (*get_link)(struct net_device___30 *);
	int (*get_link_ext_state)(struct net_device___30 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___30 *);
	int (*get_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___30 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___30 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___30 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___30 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___30 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___30 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___30 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___30 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___30 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___30 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___30 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___30 *);
	void (*complete)(struct net_device___30 *);
	u32 (*get_priv_flags)(struct net_device___30 *);
	int (*set_priv_flags)(struct net_device___30 *, u32);
	int (*get_sset_count)(struct net_device___30 *, int);
	int (*get_rxnfc)(struct net_device___30 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___30 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___30 *, struct ethtool_flash *);
	int (*reset)(struct net_device___30 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___30 *);
	u32 (*get_rxfh_indir_size)(struct net_device___30 *);
	int (*get_rxfh)(struct net_device___30 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___30 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___30 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___30 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___30 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___30 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___30 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___30 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___30 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___30 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___30 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___30 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___30 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___30 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___30 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___30 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___30 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___30 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___30 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___30 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___30 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___30 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___30 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___30 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___30 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___30 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___30 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___30 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___30 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___30 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___30 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___20 {
	u32 (*l3mdev_fib_table)(const struct net_device___30 *);
	struct sk_buff___29 * (*l3mdev_l3_rcv)(struct net_device___30 *, struct sk_buff___29 *, u16);
	struct sk_buff___29 * (*l3mdev_l3_out)(struct net_device___30 *, struct sock___21 *, struct sk_buff___29 *, u16);
	struct dst_entry___20 * (*l3mdev_link_scope_lookup)(const struct net_device___30 *, struct flowi6 *);
};

struct ndisc_ops___10 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___30 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___30 *, struct neighbour___20 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___30 *, u8, struct neighbour___20 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___30 *, struct sk_buff___29 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___33 *, struct net_device___30 *, const struct prefix_info *, struct inet6_dev___10 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___10;

struct inet6_dev___10 {
	struct net_device___30 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___10 *mc_list;
	struct ifmcaddr6___10 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___27 mc_query_queue;
	struct sk_buff_head___27 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___20 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___27;

struct tcf_block___27;

struct mini_Qdisc___27 {
	struct tcf_proto___27 *filter_list;
	struct tcf_block___27 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___27 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___30 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___30 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___33 *, struct net_device___30 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___30 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___30 *, struct list_head *);
	size_t (*get_size)(const struct net_device___30 *);
	int (*fill_info)(struct sk_buff___29 *, const struct net_device___30 *);
	size_t (*get_xstats_size)(const struct net_device___30 *);
	int (*fill_xstats)(struct sk_buff___29 *, const struct net_device___30 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___30 *, struct net_device___30 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___30 *, const struct net_device___30 *);
	int (*fill_slave_info)(struct sk_buff___29 *, const struct net_device___30 *, const struct net_device___30 *);
	struct net___33 * (*get_link_net)(const struct net_device___30 *);
	size_t (*get_linkxstats_size)(const struct net_device___30 *, int);
	int (*fill_linkxstats)(struct sk_buff___29 *, const struct net_device___30 *, int *, int);
};

struct block_device_operations___72;

struct gendisk___72 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___73 *part0;
	const struct block_device_operations___72 *fops;
	struct request_queue___72 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___69 *bdi;
	struct kobject___146 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___146 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___72 {
	struct bio___72 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___86 *bip_vec;
	struct bio_vec___86 bip_inline_vecs[0];
};

struct blkcg___69;

struct blkg_policy_data___69;

struct blkcg_gq___69 {
	struct request_queue___72 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___69 *blkcg;
	struct blkcg_gq___69 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___69 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___72 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___72(struct request___72 *);

typedef void integrity_complete_fn___72(struct request___72 *, unsigned int);

struct blk_integrity_profile___72 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___72 *prepare_fn;
	integrity_complete_fn___72 *complete_fn;
	const char *name;
};

struct block_device_operations___72 {
	blk_qc_t (*submit_bio)(struct bio___72 *);
	int (*open)(struct block_device___73 *, fmode_t);
	void (*release)(struct gendisk___72 *, fmode_t);
	int (*rw_page)(struct block_device___73 *, sector_t, struct page___164 *, unsigned int);
	int (*ioctl)(struct block_device___73 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___73 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___72 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___72 *);
	int (*getgeo)(struct block_device___73 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___73 *, bool);
	void (*swap_slot_free_notify)(struct block_device___73 *, long unsigned int);
	int (*report_zones)(struct gendisk___72 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___72 *, umode_t *);
	struct module___144 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___72 *, sector_t *);
};

typedef void rq_end_io_fn___72(struct request___72 *, blk_status_t);

struct request___72 {
	struct request_queue___72 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___69 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___72 *bio;
	struct bio___72 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___86 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___72 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___72 *saved_end_io;
		} flush;
	};
	struct gendisk___72 *rq_disk;
	struct block_device___73 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___72 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___69 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___72 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___146 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___159 *debugfs_dir;
	struct dentry___159 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___72;

struct elevator_mq_ops___72 {
	int (*init_sched)(struct request_queue___72 *, struct elevator_type___72 *);
	void (*exit_sched)(struct elevator_queue___72 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___69 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___69 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___69 *);
	bool (*allow_merge)(struct request_queue___72 *, struct request___72 *, struct bio___72 *);
	bool (*bio_merge)(struct request_queue___72 *, struct bio___72 *, unsigned int);
	int (*request_merge)(struct request_queue___72 *, struct request___72 **, struct bio___72 *);
	void (*request_merged)(struct request_queue___72 *, struct request___72 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___72 *, struct request___72 *, struct request___72 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___72 *);
	void (*finish_request)(struct request___72 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___69 *, struct list_head *, bool);
	struct request___72 * (*dispatch_request)(struct blk_mq_hw_ctx___69 *);
	bool (*has_work)(struct blk_mq_hw_ctx___69 *);
	void (*completed_request)(struct request___72 *, u64);
	void (*requeue_request)(struct request___72 *);
	struct request___72 * (*former_request)(struct request_queue___72 *, struct request___72 *);
	struct request___72 * (*next_request)(struct request_queue___72 *, struct request___72 *);
	void (*init_icq)(struct io_cq___72 *);
	void (*exit_icq)(struct io_cq___72 *);
};

struct elv_fs_entry___72;

struct elevator_type___72 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___72 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___72 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___144 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___72 {
	struct elevator_type___72 *type;
	void *elevator_data;
	struct kobject___146 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___72 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___72 *, char *);
	ssize_t (*store)(struct elevator_queue___72 *, const char *, size_t);
};

struct blk_mq_queue_data___69;

struct blk_mq_ops___69 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___69 *, const struct blk_mq_queue_data___69 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___69 *);
	int (*get_budget)(struct request_queue___72 *);
	void (*put_budget)(struct request_queue___72 *, int);
	void (*set_rq_budget_token)(struct request___72 *, int);
	int (*get_rq_budget_token)(struct request___72 *);
	enum blk_eh_timer_return (*timeout)(struct request___72 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___69 *);
	void (*complete)(struct request___72 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___69 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___69 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___69 *, struct request___72 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___69 *, struct request___72 *, unsigned int);
	void (*initialize_rq_fn)(struct request___72 *);
	void (*cleanup_rq)(struct request___72 *);
	bool (*busy)(struct request_queue___72 *);
	int (*map_queues)(struct blk_mq_tag_set___69 *);
	void (*show_rq)(struct seq_file___137 *, struct request___72 *);
};

struct blk_mq_tag_set___69 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___69 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___69 {
	struct request___72 *rq;
	bool last;
};

struct blkcg_policy_data___69;

struct blkcg___69 {
	struct cgroup_subsys_state___108 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___69 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___69 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___69 {
	struct blkcg___69 *blkcg;
	int plid;
};

struct blkg_policy_data___69 {
	struct blkcg_gq___69 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___60 {
	struct mem_cgroup___60 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___60 {
	struct lruvec___67 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___60 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___60 *memcg;
};

struct obj_cgroup___60 {
	struct percpu_ref refcnt;
	struct mem_cgroup___60 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___27 {
	spinlock_t *lock;
	struct sk_buff___29 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___27;

struct Qdisc_ops___27 {
	struct Qdisc_ops___27 *next;
	const struct Qdisc_class_ops___27 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___29 *, struct Qdisc___27 *, struct sk_buff___29 **);
	struct sk_buff___29 * (*dequeue)(struct Qdisc___27 *);
	struct sk_buff___29 * (*peek)(struct Qdisc___27 *);
	int (*init)(struct Qdisc___27 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___27 *);
	void (*destroy)(struct Qdisc___27 *);
	int (*change)(struct Qdisc___27 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___27 *);
	int (*change_tx_queue_len)(struct Qdisc___27 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___27 *, unsigned int);
	int (*dump)(struct Qdisc___27 *, struct sk_buff___29 *);
	int (*dump_stats)(struct Qdisc___27 *, struct gnet_dump___27 *);
	void (*ingress_block_set)(struct Qdisc___27 *, u32);
	void (*egress_block_set)(struct Qdisc___27 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___27 *);
	u32 (*egress_block_get)(struct Qdisc___27 *);
	struct module___144 *owner;
};

struct Qdisc_class_ops___27 {
	unsigned int flags;
	struct netdev_queue___27 * (*select_queue)(struct Qdisc___27 *, struct tcmsg *);
	int (*graft)(struct Qdisc___27 *, long unsigned int, struct Qdisc___27 *, struct Qdisc___27 **, struct netlink_ext_ack *);
	struct Qdisc___27 * (*leaf)(struct Qdisc___27 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___27 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___27 *, u32);
	int (*change)(struct Qdisc___27 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___27 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___27 *, struct qdisc_walker *);
	struct tcf_block___27 * (*tcf_block)(struct Qdisc___27 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___27 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___27 *, long unsigned int);
	int (*dump)(struct Qdisc___27 *, long unsigned int, struct sk_buff___29 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___27 *, long unsigned int, struct gnet_dump___27 *);
};

struct tcf_chain___27;

struct tcf_block___27 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___33 *net;
	struct Qdisc___27 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___27 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___27;

struct tcf_proto_ops___27;

struct tcf_proto___27 {
	struct tcf_proto___27 *next;
	void *root;
	int (*classify)(struct sk_buff___29 *, const struct tcf_proto___27 *, struct tcf_result___27 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___27 *ops;
	struct tcf_chain___27 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___27 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___27 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___27 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___29 *, const struct tcf_proto___27 *, struct tcf_result___27 *);
	int (*init)(struct tcf_proto___27 *);
	void (*destroy)(struct tcf_proto___27 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___27 *, u32);
	void (*put)(struct tcf_proto___27 *, void *);
	int (*change)(struct net___33 *, struct sk_buff___29 *, struct tcf_proto___27 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___27 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___27 *);
	void (*walk)(struct tcf_proto___27 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___27 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___27 *, void *);
	void (*hw_del)(struct tcf_proto___27 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___33 *, struct tcf_chain___27 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___33 *, struct tcf_proto___27 *, void *, struct sk_buff___29 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___33 *, struct tcf_proto___27 *, void *, struct sk_buff___29 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___29 *, struct net___33 *, void *);
	struct module___144 *owner;
	int flags;
};

struct tcf_chain___27 {
	struct mutex filter_chain_lock;
	struct tcf_proto___27 *filter_chain;
	struct list_head list;
	struct tcf_block___27 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___27 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___20 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___27 *prog;
};

struct pneigh_entry___20;

struct neigh_hash_table___20;

struct neigh_table___20 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___30 *, __u32 *);
	bool (*key_eq)(const struct neighbour___20 *, const void *);
	int (*constructor)(struct neighbour___20 *);
	int (*pconstructor)(struct pneigh_entry___20 *);
	void (*pdestructor)(struct pneigh_entry___20 *);
	void (*proxy_redo)(struct sk_buff___29 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___30 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___20 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___27 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___20 *nht;
	struct pneigh_entry___20 **phash_buckets;
};

struct neigh_ops___20 {
	int family;
	void (*solicit)(struct neighbour___20 *, struct sk_buff___29 *);
	void (*error_report)(struct neighbour___20 *, struct sk_buff___29 *);
	int (*output)(struct neighbour___20 *, struct sk_buff___29 *);
	int (*connected_output)(struct neighbour___20 *, struct sk_buff___29 *);
};

struct pneigh_entry___20 {
	struct pneigh_entry___20 *next;
	possible_net_t___27 net;
	struct net_device___30 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___20 {
	struct neighbour___20 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___7 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___33 *, struct sock___21 *, struct sk_buff___29 *);
	int (*orig_input)(struct sk_buff___29 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___20 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___20 *ctarget;
	struct net___33 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___20 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___20 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___10;

struct timewait_sock_ops___10;

struct proto___20 {
	void (*close)(struct sock___21 *, long int);
	int (*pre_connect)(struct sock___21 *, struct sockaddr *, int);
	int (*connect)(struct sock___21 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___21 *, int);
	struct sock___21 * (*accept)(struct sock___21 *, int, int *, bool);
	int (*ioctl)(struct sock___21 *, int, long unsigned int);
	int (*init)(struct sock___21 *);
	void (*destroy)(struct sock___21 *);
	void (*shutdown)(struct sock___21 *, int);
	int (*setsockopt)(struct sock___21 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___21 *, int, int, char *, int *);
	void (*keepalive)(struct sock___21 *, int);
	int (*compat_ioctl)(struct sock___21 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___21 *, struct msghdr___21 *, size_t);
	int (*recvmsg)(struct sock___21 *, struct msghdr___21 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___21 *, struct page___164 *, int, size_t, int);
	int (*bind)(struct sock___21 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___21 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___21 *, struct sk_buff___29 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___21 *);
	int (*hash)(struct sock___21 *);
	void (*unhash)(struct sock___21 *);
	void (*rehash)(struct sock___21 *);
	int (*get_port)(struct sock___21 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___21 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___21 *, int);
	bool (*sock_is_readable)(struct sock___21 *);
	void (*enter_memory_pressure)(struct sock___21 *);
	void (*leave_memory_pressure)(struct sock___21 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___10 *rsk_prot;
	struct timewait_sock_ops___10 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___144 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___21 *, int);
};

struct request_sock___11;

struct request_sock_ops___10 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___21 *, struct request_sock___11 *);
	void (*send_ack)(const struct sock___21 *, struct sk_buff___29 *, struct request_sock___11 *);
	void (*send_reset)(const struct sock___21 *, struct sk_buff___29 *);
	void (*destructor)(struct request_sock___11 *);
	void (*syn_ack_timeout)(const struct request_sock___11 *);
};

struct timewait_sock_ops___10 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___21 *, struct sock___21 *, void *);
	void (*twsk_destructor)(struct sock___21 *);
};

struct socket_alloc___2 {
	struct socket___21 socket;
	struct inode___159 vfs_inode;
	long: 64;
};

struct request_sock___11 {
	struct sock_common___20 __req_common;
	struct request_sock___11 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___10 *rsk_ops;
	struct sock___21 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct tcphdr___2 {
	__be16 source;
	__be16 dest;
	__be32 seq;
	__be32 ack_seq;
	__u16 res1: 4;
	__u16 doff: 4;
	__u16 fin;
	__u16 syn;
	__u16 rst;
	__u16 psh;
	__u16 ack;
	__u16 urg;
	__u16 ece;
	__u16 cwr;
	long: 32;
	long: 64;
	__be16 window;
	__sum16 check;
	__be16 urg_ptr;
};

struct ifmcaddr6___10 {
	struct in6_addr mca_addr;
	struct inet6_dev___10 *idev;
	struct ifmcaddr6___10 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct linux_binprm___31 {
	struct vm_area_struct___164 *vma;
	long unsigned int vma_pages;
	struct mm_struct___165 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___159 *executable;
	struct file___159 *interpreter;
	struct file___159 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___30 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___159 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct fs_parameter___29 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___159 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___29 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___144 *owner;
	char *buffer[8];
};

struct fs_context_operations___29 {
	void (*free)(struct fs_context___29 *);
	int (*dup)(struct fs_context___29 *, struct fs_context___29 *);
	int (*parse_param)(struct fs_context___29 *, struct fs_parameter___29 *);
	int (*parse_monolithic)(struct fs_context___29 *, void *);
	int (*get_tree)(struct fs_context___29 *);
	int (*reconfigure)(struct fs_context___29 *);
};

struct watch___7 {
	union {
		struct callback_head rcu;
		u32 info_id;
	};
	struct watch_queue___7 *queue;
	struct hlist_node queue_node;
	struct watch_list___7 *watch_list;
	struct hlist_node list_node;
	const struct cred___27 *cred;
	void *private;
	u64 id;
	struct kref usage;
};

union security_list_options___4 {
	int (*binder_set_context_mgr)(const struct cred___27 *);
	int (*binder_transaction)(const struct cred___27 *, const struct cred___27 *);
	int (*binder_transfer_binder)(const struct cred___27 *, const struct cred___27 *);
	int (*binder_transfer_file)(const struct cred___27 *, const struct cred___27 *, struct file___159 *);
	int (*ptrace_access_check)(struct task_struct___166 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___166 *);
	int (*capget)(struct task_struct___166 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___27 *, const struct cred___27 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___27 *, struct user_namespace___24 *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___159 *);
	int (*quota_on)(struct dentry___159 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___165 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___31 *);
	int (*bprm_creds_from_file)(struct linux_binprm___31 *, struct file___159 *);
	int (*bprm_check_security)(struct linux_binprm___31 *);
	void (*bprm_committing_creds)(struct linux_binprm___31 *);
	void (*bprm_committed_creds)(struct linux_binprm___31 *);
	int (*fs_context_dup)(struct fs_context___29 *, struct fs_context___29 *);
	int (*fs_context_parse_param)(struct fs_context___29 *, struct fs_parameter___29 *);
	int (*sb_alloc_security)(struct super_block___159 *);
	void (*sb_delete)(struct super_block___159 *);
	void (*sb_free_security)(struct super_block___159 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___159 *, void *);
	int (*sb_remount)(struct super_block___159 *, void *);
	int (*sb_kern_mount)(struct super_block___159 *);
	int (*sb_show_options)(struct seq_file___137 *, struct super_block___159 *);
	int (*sb_statfs)(struct dentry___159 *);
	int (*sb_mount)(const char *, const struct path___159 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___159 *, int);
	int (*sb_pivotroot)(const struct path___159 *, const struct path___159 *);
	int (*sb_set_mnt_opts)(struct super_block___159 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___159 *, struct super_block___159 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___159 *, const struct path___159 *);
	int (*dentry_init_security)(struct dentry___159 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___159 *, int, struct qstr *, const struct cred___27 *, struct cred___27 *);
	int (*path_unlink)(const struct path___159 *, struct dentry___159 *);
	int (*path_mkdir)(const struct path___159 *, struct dentry___159 *, umode_t);
	int (*path_rmdir)(const struct path___159 *, struct dentry___159 *);
	int (*path_mknod)(const struct path___159 *, struct dentry___159 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___159 *);
	int (*path_symlink)(const struct path___159 *, struct dentry___159 *, const char *);
	int (*path_link)(struct dentry___159 *, const struct path___159 *, struct dentry___159 *);
	int (*path_rename)(const struct path___159 *, struct dentry___159 *, const struct path___159 *, struct dentry___159 *);
	int (*path_chmod)(const struct path___159 *, umode_t);
	int (*path_chown)(const struct path___159 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___159 *);
	int (*path_notify)(const struct path___159 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___159 *);
	void (*inode_free_security)(struct inode___159 *);
	int (*inode_init_security)(struct inode___159 *, struct inode___159 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___159 *, const struct qstr *, const struct inode___159 *);
	int (*inode_create)(struct inode___159 *, struct dentry___159 *, umode_t);
	int (*inode_link)(struct dentry___159 *, struct inode___159 *, struct dentry___159 *);
	int (*inode_unlink)(struct inode___159 *, struct dentry___159 *);
	int (*inode_symlink)(struct inode___159 *, struct dentry___159 *, const char *);
	int (*inode_mkdir)(struct inode___159 *, struct dentry___159 *, umode_t);
	int (*inode_rmdir)(struct inode___159 *, struct dentry___159 *);
	int (*inode_mknod)(struct inode___159 *, struct dentry___159 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___159 *, struct dentry___159 *, struct inode___159 *, struct dentry___159 *);
	int (*inode_readlink)(struct dentry___159 *);
	int (*inode_follow_link)(struct dentry___159 *, struct inode___159 *, bool);
	int (*inode_permission)(struct inode___159 *, int);
	int (*inode_setattr)(struct dentry___159 *, struct iattr___159 *);
	int (*inode_getattr)(const struct path___159 *);
	int (*inode_setxattr)(struct user_namespace___24 *, struct dentry___159 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___159 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___159 *, const char *);
	int (*inode_listxattr)(struct dentry___159 *);
	int (*inode_removexattr)(struct user_namespace___24 *, struct dentry___159 *, const char *);
	int (*inode_need_killpriv)(struct dentry___159 *);
	int (*inode_killpriv)(struct user_namespace___24 *, struct dentry___159 *);
	int (*inode_getsecurity)(struct user_namespace___24 *, struct inode___159 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___159 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___159 *, char *, size_t);
	void (*inode_getsecid)(struct inode___159 *, u32 *);
	int (*inode_copy_up)(struct dentry___159 *, struct cred___27 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___146 *, struct kernfs_node___146 *);
	int (*file_permission)(struct file___159 *, int);
	int (*file_alloc_security)(struct file___159 *);
	void (*file_free_security)(struct file___159 *);
	int (*file_ioctl)(struct file___159 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___159 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___164 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___159 *, unsigned int);
	int (*file_fcntl)(struct file___159 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___159 *);
	int (*file_send_sigiotask)(struct task_struct___166 *, struct fown_struct___140 *, int);
	int (*file_receive)(struct file___159 *);
	int (*file_open)(struct file___159 *);
	int (*task_alloc)(struct task_struct___166 *, long unsigned int);
	void (*task_free)(struct task_struct___166 *);
	int (*cred_alloc_blank)(struct cred___27 *, gfp_t);
	void (*cred_free)(struct cred___27 *);
	int (*cred_prepare)(struct cred___27 *, const struct cred___27 *, gfp_t);
	void (*cred_transfer)(struct cred___27 *, const struct cred___27 *);
	void (*cred_getsecid)(const struct cred___27 *, u32 *);
	int (*kernel_act_as)(struct cred___27 *, u32);
	int (*kernel_create_files_as)(struct cred___27 *, struct inode___159 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___159 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___159 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___27 *, const struct cred___27 *, int);
	int (*task_fix_setgid)(struct cred___27 *, const struct cred___27 *, int);
	int (*task_setpgid)(struct task_struct___166 *, pid_t);
	int (*task_getpgid)(struct task_struct___166 *);
	int (*task_getsid)(struct task_struct___166 *);
	void (*task_getsecid_subj)(struct task_struct___166 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___166 *, u32 *);
	int (*task_setnice)(struct task_struct___166 *, int);
	int (*task_setioprio)(struct task_struct___166 *, int);
	int (*task_getioprio)(struct task_struct___166 *);
	int (*task_prlimit)(const struct cred___27 *, const struct cred___27 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___166 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___166 *);
	int (*task_getscheduler)(struct task_struct___166 *);
	int (*task_movememory)(struct task_struct___166 *);
	int (*task_kill)(struct task_struct___166 *, struct kernel_siginfo *, int, const struct cred___27 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___166 *, struct inode___159 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___166 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock___21 *, struct sk_buff___29 *);
	void (*d_instantiate)(struct dentry___159 *, struct inode___159 *);
	int (*getprocattr)(struct task_struct___166 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___159 *);
	int (*inode_notifysecctx)(struct inode___159 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___159 *, void *, u32);
	int (*inode_getsecctx)(struct inode___159 *, void **, u32 *);
	int (*post_notification)(const struct cred___27 *, const struct cred___27 *, struct watch_notification___2 *);
	int (*watch_key)(struct key___10 *);
	int (*unix_stream_connect)(struct sock___21 *, struct sock___21 *, struct sock___21 *);
	int (*unix_may_send)(struct socket___21 *, struct socket___21 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___21 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___21 *, struct socket___21 *);
	int (*socket_bind)(struct socket___21 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___21 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___21 *, int);
	int (*socket_accept)(struct socket___21 *, struct socket___21 *);
	int (*socket_sendmsg)(struct socket___21 *, struct msghdr___21 *, int);
	int (*socket_recvmsg)(struct socket___21 *, struct msghdr___21 *, int, int);
	int (*socket_getsockname)(struct socket___21 *);
	int (*socket_getpeername)(struct socket___21 *);
	int (*socket_getsockopt)(struct socket___21 *, int, int);
	int (*socket_setsockopt)(struct socket___21 *, int, int);
	int (*socket_shutdown)(struct socket___21 *, int);
	int (*socket_sock_rcv_skb)(struct sock___21 *, struct sk_buff___29 *);
	int (*socket_getpeersec_stream)(struct socket___21 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___21 *, struct sk_buff___29 *, u32 *);
	int (*sk_alloc_security)(struct sock___21 *, int, gfp_t);
	void (*sk_free_security)(struct sock___21 *);
	void (*sk_clone_security)(const struct sock___21 *, struct sock___21 *);
	void (*sk_getsecid)(struct sock___21 *, u32 *);
	void (*sock_graft)(struct sock___21 *, struct socket___21 *);
	int (*inet_conn_request)(const struct sock___21 *, struct sk_buff___29 *, struct request_sock___11 *);
	void (*inet_csk_clone)(struct sock___21 *, const struct request_sock___11 *);
	void (*inet_conn_established)(struct sock___21 *, struct sk_buff___29 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___11 *, struct flowi_common *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock___21 *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___29 *);
	int (*sctp_bind_connect)(struct sock___21 *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock___21 *, struct sock___21 *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common *);
	int (*xfrm_decode_session)(struct sk_buff___29 *, u32 *, int);
	int (*key_alloc)(struct key___10 *, const struct cred___27 *, long unsigned int);
	void (*key_free)(struct key___10 *);
	int (*key_permission)(key_ref_t, const struct cred___27 *, enum key_need_perm);
	int (*key_getsecurity)(struct key___10 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___29 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog___27 *);
	int (*bpf_map_alloc_security)(struct bpf_map___29 *);
	void (*bpf_map_free_security)(struct bpf_map___29 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___29 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___29 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event *);
	void (*perf_event_free)(struct perf_event *);
	int (*perf_event_read)(struct perf_event *);
	int (*perf_event_write)(struct perf_event *);
};

struct security_hook_list___4 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___4 hook;
	struct lsm_id *lsmid;
};

struct lsm_network_audit___3 {
	int netif;
	const struct sock___21 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___3 {
	struct path___159 path;
	u16 cmd;
};

struct smack_audit_data {
	const char *function;
	char *subject;
	char *object;
	char *request;
	int result;
};

struct common_audit_data___3 {
	char type;
	union {
		struct path___159 path;
		struct dentry___159 *dentry;
		struct inode___159 *inode;
		struct lsm_network_audit___3 *net;
		int cap;
		int ipc_id;
		struct task_struct___166 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___3 *op;
		struct file___159 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data *apparmor_audit_data;
	};
};

struct smack_known {
	struct list_head list;
	struct hlist_node smk_hashed;
	char *smk_known;
	u32 smk_secid;
	struct netlbl_lsm_secattr smk_netlabel;
	struct list_head smk_rules;
	struct mutex smk_rules_lock;
};

struct superblock_smack {
	struct smack_known *smk_root;
	struct smack_known *smk_floor;
	struct smack_known *smk_hat;
	struct smack_known *smk_default;
	int smk_flags;
};

struct socket_smack {
	struct smack_known *smk_out;
	struct smack_known *smk_in;
	struct smack_known *smk_packet;
	int smk_state;
};

struct inode_smack {
	struct smack_known *smk_inode;
	struct smack_known *smk_task;
	struct smack_known *smk_mmap;
	int smk_flags;
};

struct task_smack {
	struct smack_known *smk_task;
	struct smack_known *smk_forked;
	struct list_head smk_rules;
	struct mutex smk_rules_lock;
	struct list_head smk_relabel;
};

struct smack_rule {
	struct list_head list;
	struct smack_known *smk_subject;
	struct smack_known *smk_object;
	int smk_access;
};

struct smk_net4addr {
	struct list_head list;
	struct in_addr smk_host;
	struct in_addr smk_mask;
	int smk_masks;
	struct smack_known *smk_label;
};

struct smk_net6addr {
	struct list_head list;
	struct in6_addr smk_host;
	struct in6_addr smk_mask;
	int smk_masks;
	struct smack_known *smk_label;
};

struct smack_known_list_elem {
	struct list_head list;
	struct smack_known *smk_label;
};

enum {
	Opt_error___3 = 4294967295,
	Opt_fsdefault = 0,
	Opt_fsfloor = 1,
	Opt_fshat = 2,
	Opt_fsroot = 3,
	Opt_fstransmute = 4,
};

struct smk_audit_info {
	struct common_audit_data___3 a;
	struct smack_audit_data sad;
};

struct smack_mnt_opts {
	const char *fsdefault;
	const char *fsfloor;
	const char *fshat;
	const char *fsroot;
	const char *fstransmute;
};

struct smk_audit_info___2 {
	struct common_audit_data___2 a;
	struct smack_audit_data sad;
};

struct netlbl_audit {
	struct lsmblob lsmdata;
	kuid_t loginuid;
	unsigned int sessionid;
};

struct cipso_v4_std_map_tbl {
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} lvl;
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} cat;
};

struct cipso_v4_doi {
	u32 doi;
	u32 type;
	union {
		struct cipso_v4_std_map_tbl *std;
	} map;
	u8 tags[5];
	refcount_t refcount;
	struct list_head list;
	struct callback_head rcu;
};

enum smk_inos {
	SMK_ROOT_INO = 2,
	SMK_LOAD = 3,
	SMK_CIPSO = 4,
	SMK_DOI = 5,
	SMK_DIRECT = 6,
	SMK_AMBIENT = 7,
	SMK_NET4ADDR = 8,
	SMK_ONLYCAP = 9,
	SMK_LOGGING = 10,
	SMK_LOAD_SELF = 11,
	SMK_ACCESSES = 12,
	SMK_MAPPED = 13,
	SMK_LOAD2 = 14,
	SMK_LOAD_SELF2 = 15,
	SMK_ACCESS2 = 16,
	SMK_CIPSO2 = 17,
	SMK_REVOKE_SUBJ = 18,
	SMK_CHANGE_RULE = 19,
	SMK_SYSLOG = 20,
	SMK_PTRACE = 21,
	SMK_NET6ADDR = 23,
	SMK_RELABEL_SELF = 24,
};

struct smack_parsed_rule {
	struct smack_known *smk_subject;
	struct smack_known *smk_object;
	int smk_access1;
	int smk_access2;
};

struct dentry___160;

struct super_block___160;

struct file_system_type___160 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___160 * (*mount)(struct file_system_type___160 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___160 *);
	struct module___4 *owner;
	struct file_system_type___160 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___160;

struct kiocb___160;

struct iov_iter___89;

struct poll_table_struct___101;

struct vm_area_struct___165;

struct inode___160;

struct file_lock___160;

struct page___165;

struct pipe_inode_info___53;

struct seq_file___138;

struct file_operations___160 {
	struct module___4 *owner;
	loff_t (*llseek)(struct file___160 *, loff_t, int);
	ssize_t (*read)(struct file___160 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___160 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___160 *, struct iov_iter___89 *);
	ssize_t (*write_iter)(struct kiocb___160 *, struct iov_iter___89 *);
	int (*iopoll)(struct kiocb___160 *, bool);
	int (*iterate)(struct file___160 *, struct dir_context *);
	int (*iterate_shared)(struct file___160 *, struct dir_context *);
	__poll_t (*poll)(struct file___160 *, struct poll_table_struct___101 *);
	long int (*unlocked_ioctl)(struct file___160 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___160 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___160 *, struct vm_area_struct___165 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___160 *, struct file___160 *);
	int (*flush)(struct file___160 *, fl_owner_t);
	int (*release)(struct inode___160 *, struct file___160 *);
	int (*fsync)(struct file___160 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___160 *, int);
	int (*lock)(struct file___160 *, int, struct file_lock___160 *);
	ssize_t (*sendpage)(struct file___160 *, struct page___165 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___160 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___160 *, long unsigned int);
	int (*flock)(struct file___160 *, int, struct file_lock___160 *);
	ssize_t (*splice_write)(struct pipe_inode_info___53 *, struct file___160 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___160 *, loff_t *, struct pipe_inode_info___53 *, size_t, unsigned int);
	int (*setlease)(struct file___160 *, long int, struct file_lock___160 **, void **);
	long int (*fallocate)(struct file___160 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___138 *, struct file___160 *);
	ssize_t (*copy_file_range)(struct file___160 *, loff_t, struct file___160 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___160 *, loff_t, struct file___160 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___160 *, loff_t, loff_t, int);
};

struct vmacache___165 {
	u64 seqnum;
	struct vm_area_struct___165 *vmas[4];
};

struct page_frag___165 {
	struct page___165 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___166;

struct pid___141;

struct nsproxy___150;

struct signal_struct___161;

struct bio_list___73;

struct backing_dev_info___70;

struct io_context___73;

struct css_set___109;

struct mem_cgroup___61;

struct request_queue___73;

struct vm_struct___144;

struct task_struct___167 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___167 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___166 *mm;
	struct mm_struct___166 *active_mm;
	struct vmacache___165 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___167 *real_parent;
	struct task_struct___167 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___167 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___141 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___150 *nsproxy;
	struct signal_struct___161 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___167 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___73 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___70 *backing_dev_info;
	struct io_context___73 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___109 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___53 *splice_pipe;
	struct page_frag___165 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___61 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___61 *active_memcg;
	struct request_queue___73 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___167 *oom_reaper_list;
	struct vm_struct___144 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___147;

struct kobj_type___147;

struct kernfs_node___147;

struct kobject___147 {
	const char *name;
	struct list_head entry;
	struct kobject___147 *parent;
	struct kset___147 *kset;
	struct kobj_type___147 *ktype;
	struct kernfs_node___147 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___144 {
	struct kobject___147 kobj;
	struct module___4 *mod;
	struct kobject___147 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___144 {
	struct module___4 *mod;
	struct latch_tree_node node;
};

struct module_layout___144 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___144 mtn;
};

struct module_attribute___144;

struct kernel_param___144;

struct module___4 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___144 mkobj;
	struct module_attribute___144 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___147 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___144 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___144 core_layout;
	struct module_layout___144 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___160;

struct dentry___160 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___160 *d_parent;
	struct qstr d_name;
	struct inode___160 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___160 *d_op;
	struct super_block___160 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___160;

struct address_space___160 {
	struct inode___160 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___160 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___160;

struct bdi_writeback___70;

struct inode___160 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___160 *i_op;
	struct super_block___160 *i_sb;
	struct address_space___160 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___70 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___160 *i_fop;
		void (*free_inode)(struct inode___160 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___160 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___53 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___160;

struct path___160;

struct dentry_operations___160 {
	int (*d_revalidate)(struct dentry___160 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___160 *, unsigned int);
	int (*d_hash)(const struct dentry___160 *, struct qstr *);
	int (*d_compare)(const struct dentry___160 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___160 *);
	int (*d_init)(struct dentry___160 *);
	void (*d_release)(struct dentry___160 *);
	void (*d_prune)(struct dentry___160 *);
	void (*d_iput)(struct dentry___160 *, struct inode___160 *);
	char * (*d_dname)(struct dentry___160 *, char *, int);
	struct vfsmount___160 * (*d_automount)(struct path___160 *);
	int (*d_manage)(const struct path___160 *, bool);
	struct dentry___160 * (*d_real)(struct dentry___160 *, const struct inode___160 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___160;

struct mem_dqinfo___160 {
	struct quota_format_type___160 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___160;

struct quota_info___160 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___160 *files[3];
	struct mem_dqinfo___160 info[3];
	const struct quota_format_ops___160 *ops[3];
};

struct rcuwait___161 {
	struct task_struct___167 *task;
};

struct percpu_rw_semaphore___161 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___161 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___160 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___161 rw_sem[3];
};

struct shrink_control___61;

struct shrinker___61 {
	long unsigned int (*count_objects)(struct shrinker___61 *, struct shrink_control___61 *);
	long unsigned int (*scan_objects)(struct shrinker___61 *, struct shrink_control___61 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___160;

struct dquot_operations___160;

struct quotactl_ops___160;

struct block_device___74;

struct super_block___160 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___160 *s_type;
	const struct super_operations___160 *s_op;
	const struct dquot_operations___160 *dq_op;
	const struct quotactl_ops___160 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___160 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___74 *s_bdev;
	struct backing_dev_info___70 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___160 s_dquot;
	struct sb_writers___160 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___160 *s_d_op;
	int cleancache_poolid;
	struct shrinker___61 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___160 {
	struct dentry___160 *mnt_root;
	struct super_block___160 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct path___160 {
	struct vfsmount___160 *mnt;
	struct dentry___160 *dentry;
};

struct pid_namespace___141;

struct upid___141 {
	int nr;
	struct pid_namespace___141 *ns;
};

struct pid_namespace___141 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___167 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___141 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___141 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___141 numbers[1];
};

typedef struct page___165 *pgtable_t___165;

struct page_pool___44;

struct dev_pagemap___156;

struct page___165 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___160 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___44 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___165 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___165 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___166 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___156 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___156;

struct vm_area_struct___165 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___165 *vm_next;
	struct vm_area_struct___165 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___166 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___156 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___160 *vm_file;
	struct file___160 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___161 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___167 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___167 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___141 *pids[4];
	struct pid___141 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___166 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___165;

struct mm_struct___166 {
	struct {
		struct vm_area_struct___165 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___160 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___165 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___167 *owner;
		struct user_namespace___24 *user_ns;
		struct file___160 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___109;

struct nsproxy___150 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___141 *pid_ns_for_children;
	struct net___3 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___109 *cgroup_ns;
};

struct bio___73;

struct bio_list___73 {
	struct bio___73 *head;
	struct bio___73 *tail;
};

struct cgroup_subsys_state___109;

struct bdi_writeback___70 {
	struct backing_dev_info___70 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___109 *memcg_css;
	struct cgroup_subsys_state___109 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___116;

struct backing_dev_info___70 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___70 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___116 *dev;
	char dev_name[64];
	struct device___116 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___160 *debug_dir;
};

struct io_cq___73;

struct io_context___73 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___73 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___109;

struct css_set___109 {
	struct cgroup_subsys_state___109 *subsys[14];
	refcount_t refcount;
	struct css_set___109 *dom_cset;
	struct cgroup___109 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___109 *mg_src_cgrp;
	struct cgroup___109 *mg_dst_cgrp;
	struct css_set___109 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___160;

struct pipe_buffer___53;

struct pipe_inode_info___53 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___165 *tmp_page;
	struct fasync_struct___160 *fasync_readers;
	struct fasync_struct___160 *fasync_writers;
	struct pipe_buffer___53 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___109;

struct cgroup_subsys_state___109 {
	struct cgroup___109 *cgroup;
	struct cgroup_subsys___109 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___109 *parent;
};

struct cgroup_file___109 {
	struct kernfs_node___147 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___61;

struct mem_cgroup_per_node___61;

struct mem_cgroup___61 {
	struct cgroup_subsys_state___109 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___109 events_file;
	struct cgroup_file___109 events_local_file;
	struct cgroup_file___109 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___61 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___167 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___61 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___73;

struct blk_integrity___73 {
	const struct blk_integrity_profile___73 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___73 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___73 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___73;

struct elevator_queue___73;

struct blk_mq_ops___70;

struct blk_mq_hw_ctx___70;

struct gendisk___73;

struct blkcg_gq___70;

struct blk_mq_tag_set___70;

struct request_queue___73 {
	struct request___73 *last_merge;
	struct elevator_queue___73 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___70 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___70 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___73 *disk;
	struct kobject___147 kobj;
	struct kobject___147 *mq_kobj;
	struct blk_integrity___73 integrity;
	struct device___116 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___70 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___70 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___73 bio_split;
	struct dentry___160 *debugfs_dir;
	struct dentry___160 *sched_debugfs_dir;
	struct dentry___160 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___144 {
	struct vm_struct___144 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___165 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___61 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___61 *memcg;
};

struct page_pool_params___44 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___116 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___44 {
	u32 count;
	struct page___165 *cache[128];
};

struct page_pool___44 {
	struct page_pool_params___44 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___165 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___44 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___156;

struct dev_pagemap___156 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___156 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___141 {
	rwlock_t lock;
	struct pid___141 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___160 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___160 f_path;
	struct inode___160 *f_inode;
	const struct file_operations___160 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___141 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___160 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___156;

struct vm_operations_struct___156 {
	void (*open)(struct vm_area_struct___165 *);
	void (*close)(struct vm_area_struct___165 *);
	int (*may_split)(struct vm_area_struct___165 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___165 *);
	int (*mprotect)(struct vm_area_struct___165 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___156 *);
	vm_fault_t (*huge_fault)(struct vm_fault___156 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___156 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___165 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___156 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___156 *);
	int (*access)(struct vm_area_struct___165 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___165 *);
	int (*set_policy)(struct vm_area_struct___165 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___165 *, long unsigned int);
	struct page___165 * (*find_special_page)(struct vm_area_struct___165 *, long unsigned int);
};

struct core_thread___165 {
	struct task_struct___167 *task;
	struct core_thread___165 *next;
};

struct core_state___165 {
	atomic_t nr_threads;
	struct core_thread___165 dumper;
	struct completion startup;
};

struct vm_fault___156 {
	const struct {
		struct vm_area_struct___165 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___165 *cow_page;
	struct page___165 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___165 prealloc_pte;
};

struct pglist_data___68;

struct lruvec___68 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___68 *pgdat;
};

struct zone___68 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___68 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___68 {
	struct zone___68 *zone;
	int zone_idx;
};

struct zonelist___68 {
	struct zoneref___68 _zonerefs[321];
};

struct pglist_data___68 {
	struct zone___68 node_zones[5];
	struct zonelist___68 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___167 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___167 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___68 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___109 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___167 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___28;

struct cgroup_bpf___28 {
	struct bpf_prog_array___28 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___28 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___109;

struct cgroup_rstat_cpu___109;

struct cgroup___109 {
	struct cgroup_subsys_state___109 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___147 *kn;
	struct cgroup_file___109 procs_file;
	struct cgroup_file___109 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___109 *subsys[14];
	struct cgroup_root___109 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___109 *dom_cgrp;
	struct cgroup___109 *old_dom_cgrp;
	struct cgroup_rstat_cpu___109 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___109 psi;
	struct cgroup_bpf___28 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___73 {
	struct request_queue___73 *q;
	struct io_context___73 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___160 {
	struct file___160 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___160 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___160 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___160 *ia_file;
};

struct dquot___160 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___160 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___160 {
	int qf_fmt_id;
	const struct quota_format_ops___160 *qf_ops;
	struct module___4 *qf_owner;
	struct quota_format_type___160 *qf_next;
};

struct quota_format_ops___160 {
	int (*check_quota_file)(struct super_block___160 *, int);
	int (*read_file_info)(struct super_block___160 *, int);
	int (*write_file_info)(struct super_block___160 *, int);
	int (*free_file_info)(struct super_block___160 *, int);
	int (*read_dqblk)(struct dquot___160 *);
	int (*commit_dqblk)(struct dquot___160 *);
	int (*release_dqblk)(struct dquot___160 *);
	int (*get_next_id)(struct super_block___160 *, struct kqid *);
};

struct dquot_operations___160 {
	int (*write_dquot)(struct dquot___160 *);
	struct dquot___160 * (*alloc_dquot)(struct super_block___160 *, int);
	void (*destroy_dquot)(struct dquot___160 *);
	int (*acquire_dquot)(struct dquot___160 *);
	int (*release_dquot)(struct dquot___160 *);
	int (*mark_dirty)(struct dquot___160 *);
	int (*write_info)(struct super_block___160 *, int);
	qsize_t * (*get_reserved_space)(struct inode___160 *);
	int (*get_projid)(struct inode___160 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___160 *, qsize_t *);
	int (*get_next_id)(struct super_block___160 *, struct kqid *);
};

struct quotactl_ops___160 {
	int (*quota_on)(struct super_block___160 *, int, int, const struct path___160 *);
	int (*quota_off)(struct super_block___160 *, int);
	int (*quota_enable)(struct super_block___160 *, unsigned int);
	int (*quota_disable)(struct super_block___160 *, unsigned int);
	int (*quota_sync)(struct super_block___160 *, int);
	int (*set_info)(struct super_block___160 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___160 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___160 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___160 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___160 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___160 *, unsigned int);
};

struct writeback_control___70;

struct address_space_operations___160 {
	int (*writepage)(struct page___165 *, struct writeback_control___70 *);
	int (*readpage)(struct file___160 *, struct page___165 *);
	int (*writepages)(struct address_space___160 *, struct writeback_control___70 *);
	int (*set_page_dirty)(struct page___165 *);
	int (*readpages)(struct file___160 *, struct address_space___160 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___160 *, struct address_space___160 *, loff_t, unsigned int, unsigned int, struct page___165 **, void **);
	int (*write_end)(struct file___160 *, struct address_space___160 *, loff_t, unsigned int, unsigned int, struct page___165 *, void *);
	sector_t (*bmap)(struct address_space___160 *, sector_t);
	void (*invalidatepage)(struct page___165 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___165 *, gfp_t);
	void (*freepage)(struct page___165 *);
	ssize_t (*direct_IO)(struct kiocb___160 *, struct iov_iter___89 *);
	int (*migratepage)(struct address_space___160 *, struct page___165 *, struct page___165 *, enum migrate_mode);
	bool (*isolate_page)(struct page___165 *, isolate_mode_t);
	void (*putback_page)(struct page___165 *);
	int (*launder_page)(struct page___165 *);
	int (*is_partially_uptodate)(struct page___165 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___165 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___160 *, struct page___165 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___160 *, sector_t *);
	void (*swap_deactivate)(struct file___160 *);
};

struct writeback_control___70 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___70 *wb;
	struct inode___160 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___87;

struct iov_iter___89 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___87 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___53 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___160 {
	struct dentry___160 * (*lookup)(struct inode___160 *, struct dentry___160 *, unsigned int);
	const char * (*get_link)(struct dentry___160 *, struct inode___160 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___160 *, int);
	struct posix_acl * (*get_acl)(struct inode___160 *, int, bool);
	int (*readlink)(struct dentry___160 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___160 *, struct dentry___160 *, umode_t, bool);
	int (*link)(struct dentry___160 *, struct inode___160 *, struct dentry___160 *);
	int (*unlink)(struct inode___160 *, struct dentry___160 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___160 *, struct dentry___160 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___160 *, struct dentry___160 *, umode_t);
	int (*rmdir)(struct inode___160 *, struct dentry___160 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___160 *, struct dentry___160 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___160 *, struct dentry___160 *, struct inode___160 *, struct dentry___160 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___160 *, struct iattr___160 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___160 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___160 *, char *, size_t);
	int (*fiemap)(struct inode___160 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___160 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___160 *, struct dentry___160 *, struct file___160 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___160 *, struct dentry___160 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___160 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___160 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___160 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___160 {
	void (*fl_copy_lock)(struct file_lock___160 *, struct file_lock___160 *);
	void (*fl_release_private)(struct file_lock___160 *);
};

struct lock_manager_operations___160;

struct file_lock___160 {
	struct file_lock___160 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___160 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___160 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___160 *fl_ops;
	const struct lock_manager_operations___160 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___160 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___160 *);
	int (*lm_grant)(struct file_lock___160 *, int);
	bool (*lm_break)(struct file_lock___160 *);
	int (*lm_change)(struct file_lock___160 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___160 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___160 *);
};

struct fasync_struct___160 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___160 *fa_next;
	struct file___160 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___160 {
	struct inode___160 * (*alloc_inode)(struct super_block___160 *);
	void (*destroy_inode)(struct inode___160 *);
	void (*free_inode)(struct inode___160 *);
	void (*dirty_inode)(struct inode___160 *, int);
	int (*write_inode)(struct inode___160 *, struct writeback_control___70 *);
	int (*drop_inode)(struct inode___160 *);
	void (*evict_inode)(struct inode___160 *);
	void (*put_super)(struct super_block___160 *);
	int (*sync_fs)(struct super_block___160 *, int);
	int (*freeze_super)(struct super_block___160 *);
	int (*freeze_fs)(struct super_block___160 *);
	int (*thaw_super)(struct super_block___160 *);
	int (*unfreeze_fs)(struct super_block___160 *);
	int (*statfs)(struct dentry___160 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___160 *, int *, char *);
	void (*umount_begin)(struct super_block___160 *);
	int (*show_options)(struct seq_file___138 *, struct dentry___160 *);
	int (*show_devname)(struct seq_file___138 *, struct dentry___160 *);
	int (*show_path)(struct seq_file___138 *, struct dentry___160 *);
	int (*show_stats)(struct seq_file___138 *, struct dentry___160 *);
	ssize_t (*quota_read)(struct super_block___160 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___160 *, int, const char *, size_t, loff_t);
	struct dquot___160 ** (*get_dquots)(struct inode___160 *);
	long int (*nr_cached_objects)(struct super_block___160 *, struct shrink_control___61 *);
	long int (*free_cached_objects)(struct super_block___160 *, struct shrink_control___61 *);
	struct file___160 * (*real_loop)(struct file___160 *);
};

struct wakeup_source___116;

struct dev_pm_info___116 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___116 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___116 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___116;

struct bus_type___116;

struct device_driver___116;

struct dev_pm_domain___116;

struct fwnode_handle___116;

struct class___116;

struct attribute_group___147;

struct device___116 {
	struct kobject___147 kobj;
	struct device___116 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___116 *type;
	struct bus_type___116 *bus;
	struct device_driver___116 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___116 power;
	struct dev_pm_domain___116 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___116 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___116 *class;
	const struct attribute_group___147 **groups;
	void (*release)(struct device___116 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___74 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___160 *bd_inode;
	struct super_block___160 *bd_super;
	void *bd_claiming;
	struct device___116 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___147 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___73 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___160 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___103)(struct file___160 *, wait_queue_head_t *, struct poll_table_struct___101 *);

struct poll_table_struct___101 {
	poll_queue_proc___103 _qproc;
	__poll_t _key;
};

struct seq_operations___138;

struct seq_file___138 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___138 *op;
	int poll_event;
	const struct file___160 *file;
	void *private;
};

typedef void bio_end_io_t___73(struct bio___73 *);

struct bio_vec___87 {
	struct page___165 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___73;

struct bio___73 {
	struct bio___73 *bi_next;
	struct block_device___74 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___73 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___70 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___73 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___87 *bi_io_vec;
	struct bio_set___73 *bi_pool;
	struct bio_vec___87 bi_inline_vecs[0];
};

struct dev_pagemap_ops___156 {
	void (*page_free)(struct page___165 *);
	void (*kill)(struct dev_pagemap___156 *);
	void (*cleanup)(struct dev_pagemap___156 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___156 *);
};

struct fwnode_operations___116;

struct fwnode_handle___116 {
	struct fwnode_handle___116 *secondary;
	const struct fwnode_operations___116 *ops;
	struct device___116 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___116;

struct fwnode_endpoint___116;

struct fwnode_operations___116 {
	struct fwnode_handle___116 * (*get)(struct fwnode_handle___116 *);
	void (*put)(struct fwnode_handle___116 *);
	bool (*device_is_available)(const struct fwnode_handle___116 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___116 *, const struct device___116 *);
	bool (*property_present)(const struct fwnode_handle___116 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___116 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___116 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___116 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*get_parent)(const struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*get_next_child_node)(const struct fwnode_handle___116 *, struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*get_named_child_node)(const struct fwnode_handle___116 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___116 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___116 *);
	struct fwnode_handle___116 * (*graph_get_next_endpoint)(const struct fwnode_handle___116 *, struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*graph_get_remote_endpoint)(const struct fwnode_handle___116 *);
	struct fwnode_handle___116 * (*graph_get_port_parent)(struct fwnode_handle___116 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___116 *, struct fwnode_endpoint___116 *);
	int (*add_links)(struct fwnode_handle___116 *);
};

struct fwnode_endpoint___116 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___116 *local_fwnode;
};

struct fwnode_reference_args___116 {
	struct fwnode_handle___116 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___147;

struct kernfs_elem_dir___147 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___147 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___147;

struct kernfs_root___147 {
	struct kernfs_node___147 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___147 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___147 {
	struct kernfs_node___147 *target_kn;
};

struct kernfs_ops___147;

struct kernfs_elem_attr___147 {
	const struct kernfs_ops___147 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___147 *notify_next;
};

struct kernfs_node___147 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___147 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___147 dir;
		struct kernfs_elem_symlink___147 symlink;
		struct kernfs_elem_attr___147 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___147;

struct kernfs_ops___147 {
	int (*open)(struct kernfs_open_file___147 *);
	void (*release)(struct kernfs_open_file___147 *);
	int (*seq_show)(struct seq_file___138 *, void *);
	void * (*seq_start)(struct seq_file___138 *, loff_t *);
	void * (*seq_next)(struct seq_file___138 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___138 *, void *);
	ssize_t (*read)(struct kernfs_open_file___147 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___147 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___147 *, struct poll_table_struct___101 *);
	int (*mmap)(struct kernfs_open_file___147 *, struct vm_area_struct___165 *);
};

struct kernfs_syscall_ops___147 {
	int (*show_options)(struct seq_file___138 *, struct kernfs_root___147 *);
	int (*mkdir)(struct kernfs_node___147 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___147 *);
	int (*rename)(struct kernfs_node___147 *, struct kernfs_node___147 *, const char *);
	int (*show_path)(struct seq_file___138 *, struct kernfs_node___147 *, struct kernfs_root___147 *);
};

struct kernfs_open_file___147 {
	struct kernfs_node___147 *kn;
	struct file___160 *file;
	struct seq_file___138 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___156 *vm_ops;
};

struct sock___22;

struct kobj_ns_type_operations___21 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___22 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___3 *net;
} possible_net_t___28;

struct proto___21;

struct sock_common___21 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___21 *skc_prot;
	possible_net_t___28 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___22 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___28 {
	struct sk_buff___2 *next;
	struct sk_buff___2 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___21 {
	struct cgroup___109 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___21;

struct socket_wq___22;

struct dst_entry___21;

struct socket___22;

struct sock_reuseport___4;

struct sock___22 {
	struct sock_common___21 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___28 sk_error_queue;
	struct sk_buff___2 *sk_rx_skb_cache;
	struct sk_buff_head___28 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___2 *head;
		struct sk_buff___2 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___21 *sk_filter;
	union {
		struct socket_wq___22 *sk_wq;
		struct socket_wq___22 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___21 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___21 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___2 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___2 *sk_tx_skb_cache;
	struct sk_buff_head___28 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___165 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___21 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___141 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___22 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___21 sk_cgrp_data;
	struct mem_cgroup___61 *sk_memcg;
	void (*sk_state_change)(struct sock___22 *);
	void (*sk_data_ready)(struct sock___22 *);
	void (*sk_write_space)(struct sock___22 *);
	void (*sk_error_report)(struct sock___22 *);
	int (*sk_backlog_rcv)(struct sock___22 *, struct sk_buff___2 *);
	struct sk_buff___2 * (*sk_validate_xmit_skb)(struct sock___22 *, struct net_device___2 *, struct sk_buff___2 *);
	void (*sk_destruct)(struct sock___22 *);
	struct sock_reuseport___4 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___147;

struct attribute_group___147 {
	const char *name;
	umode_t (*is_visible)(struct kobject___147 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___147 *, struct bin_attribute___147 *, int);
	struct attribute **attrs;
	struct bin_attribute___147 **bin_attrs;
};

struct bin_attribute___147 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___160 * (*f_mapping)();
	ssize_t (*read)(struct file___160 *, struct kobject___147 *, struct bin_attribute___147 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___160 *, struct kobject___147 *, struct bin_attribute___147 *, char *, loff_t, size_t);
	int (*mmap)(struct file___160 *, struct kobject___147 *, struct bin_attribute___147 *, struct vm_area_struct___165 *);
};

struct sysfs_ops___147 {
	ssize_t (*show)(struct kobject___147 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___147 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___147;

struct kset___147 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___147 kobj;
	const struct kset_uevent_ops___147 *uevent_ops;
};

struct kobj_type___147 {
	void (*release)(struct kobject___147 *);
	const struct sysfs_ops___147 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___147 **default_groups;
	const struct kobj_ns_type_operations___21 * (*child_ns_type)(struct kobject___147 *);
	const void * (*namespace)(struct kobject___147 *);
	void (*get_ownership)(struct kobject___147 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___147 {
	int (* const filter)(struct kset___147 *, struct kobject___147 *);
	const char * (* const name)(struct kset___147 *, struct kobject___147 *);
	int (* const uevent)(struct kset___147 *, struct kobject___147 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___144 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___144 *);
	int (*get)(char *, const struct kernel_param___144 *);
	void (*free)(void *);
};

struct kparam_array___144;

struct kernel_param___144 {
	const char *name;
	struct module___4 *mod;
	const struct kernel_param_ops___144 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___144 *arr;
	};
};

struct kparam_array___144 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___144 *ops;
	void *elem;
};

struct module_attribute___144 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___144 *, struct module_kobject___144 *, char *);
	ssize_t (*store)(struct module_attribute___144 *, struct module_kobject___144 *, const char *, size_t);
	void (*setup)(struct module___4 *, const char *);
	int (*test)(struct module___4 *);
	void (*free)(struct module___4 *);
};

struct ip_ra_chain___8;

struct fib_rules_ops___21;

struct fqdir___33;

struct tcp_congestion_ops___3;

struct fib_notifier_ops___21;

struct netns_ipv4___33 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___8 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___21 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___22 *fibnl;
	struct sock___22 **icmp_sk;
	struct sock___22 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___22 **tcp_sk;
	struct fqdir___33 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___3 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___21 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___21 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___21 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___21;

struct dst_ops___33 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___33 *);
	struct dst_entry___21 * (*check)(struct dst_entry___21 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___21 *);
	unsigned int (*mtu)(const struct dst_entry___21 *);
	u32 * (*cow_metrics)(struct dst_entry___21 *, long unsigned int);
	void (*destroy)(struct dst_entry___21 *);
	void (*ifdown)(struct dst_entry___21 *, struct net_device___2 *, int);
	struct dst_entry___21 * (*negative_advice)(struct dst_entry___21 *);
	void (*link_failure)(struct sk_buff___2 *);
	void (*update_pmtu)(struct dst_entry___21 *, struct sock___22 *, struct sk_buff___2 *, u32, bool);
	void (*redirect)(struct dst_entry___21 *, struct sock___22 *, struct sk_buff___2 *);
	int (*local_out)(struct net___3 *, struct sock___22 *, struct sk_buff___2 *);
	struct neighbour___21 * (*neigh_lookup)(const struct dst_entry___21 *, struct sk_buff___2 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___21 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___33 {
	struct dst_ops___33 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___33 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___21 *fib6_rules_ops;
	struct sock___22 **icmp_sk;
	struct sock___22 *ndisc_sk;
	struct sock___22 *tcp_sk;
	struct sock___22 *igmp_sk;
	struct sock___22 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___21 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___21 *notifier_ops;
	struct fib_notifier_ops___21 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___33 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___33 *fqdir;
};

struct netns_sctp___21 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___22 *ctl_sock;
	struct sock___22 *udp4_sock;
	struct sock___22 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___2;

struct netns_nf___2 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___2 *hooks_ipv4[5];
	struct nf_hook_entries___2 *hooks_ipv6[5];
	struct nf_hook_entries___2 *hooks_arp[3];
	struct nf_hook_entries___2 *hooks_bridge[5];
	struct nf_hook_entries___2 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___28;

struct netns_bpf___28 {
	struct bpf_prog_array___28 *run_array[2];
	struct bpf_prog___28 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___33 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___22 *nlsk;
	struct sock___22 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___33 xfrm4_dst_ops;
	struct dst_ops___33 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___3 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___22 *rtnl;
	struct sock___22 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___2 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___33 ipv4;
	struct netns_ipv6___33 ipv6;
	struct netns_ieee802154_lowpan___33 ieee802154_lowpan;
	struct netns_sctp___21 sctp;
	struct netns_nf___2 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___28 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___28 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___33 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___22 *crypto_nlsk;
	struct sock___22 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___109 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___109 *root_cset;
};

struct msghdr___22 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___89 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___160 *msg_iocb;
};

struct socket_wq___22 {
	wait_queue_head_t wait;
	struct fasync_struct___160 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___22;

struct socket___22 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___160 *file;
	struct sock___22 *sk;
	const struct proto_ops___22 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___22 wq;
};

typedef int (*sk_read_actor_t___21)(read_descriptor_t *, struct sk_buff___2 *, unsigned int, size_t);

struct proto_ops___22 {
	int family;
	struct module___4 *owner;
	int (*release)(struct socket___22 *);
	int (*bind)(struct socket___22 *, struct sockaddr *, int);
	int (*connect)(struct socket___22 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___22 *, struct socket___22 *);
	int (*accept)(struct socket___22 *, struct socket___22 *, int, bool);
	int (*getname)(struct socket___22 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___160 *, struct socket___22 *, struct poll_table_struct___101 *);
	int (*ioctl)(struct socket___22 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___22 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___22 *, void *, bool, bool);
	int (*listen)(struct socket___22 *, int);
	int (*shutdown)(struct socket___22 *, int);
	int (*setsockopt)(struct socket___22 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___22 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___138 *, struct socket___22 *);
	int (*sendmsg)(struct socket___22 *, struct msghdr___22 *, size_t);
	int (*recvmsg)(struct socket___22 *, struct msghdr___22 *, size_t, int);
	int (*mmap)(struct file___160 *, struct socket___22 *, struct vm_area_struct___165 *);
	ssize_t (*sendpage)(struct socket___22 *, struct page___165 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___22 *, loff_t *, struct pipe_inode_info___53 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___22 *, int);
	int (*peek_len)(struct socket___22 *);
	int (*read_sock)(struct sock___22 *, read_descriptor_t *, sk_read_actor_t___21);
	int (*sendpage_locked)(struct sock___22 *, struct page___165 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___22 *, struct msghdr___22 *, size_t);
	int (*set_rcvlowat)(struct sock___22 *, int);
};

struct sk_buff___2 {
	union {
		struct {
			struct sk_buff___2 *next;
			struct sk_buff___2 *prev;
			union {
				struct net_device___2 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___22 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___2 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___116 {
	int (*prepare)(struct device___116 *);
	void (*complete)(struct device___116 *);
	int (*suspend)(struct device___116 *);
	int (*resume)(struct device___116 *);
	int (*freeze)(struct device___116 *);
	int (*thaw)(struct device___116 *);
	int (*poweroff)(struct device___116 *);
	int (*restore)(struct device___116 *);
	int (*suspend_late)(struct device___116 *);
	int (*resume_early)(struct device___116 *);
	int (*freeze_late)(struct device___116 *);
	int (*thaw_early)(struct device___116 *);
	int (*poweroff_late)(struct device___116 *);
	int (*restore_early)(struct device___116 *);
	int (*suspend_noirq)(struct device___116 *);
	int (*resume_noirq)(struct device___116 *);
	int (*freeze_noirq)(struct device___116 *);
	int (*thaw_noirq)(struct device___116 *);
	int (*poweroff_noirq)(struct device___116 *);
	int (*restore_noirq)(struct device___116 *);
	int (*runtime_suspend)(struct device___116 *);
	int (*runtime_resume)(struct device___116 *);
	int (*runtime_idle)(struct device___116 *);
};

struct wakeup_source___116 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___116 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___116 {
	struct dev_pm_ops___116 ops;
	int (*start)(struct device___116 *);
	void (*detach)(struct device___116 *, bool);
	int (*activate)(struct device___116 *);
	void (*sync)(struct device___116 *);
	void (*dismiss)(struct device___116 *);
};

struct bus_type___116 {
	const char *name;
	const char *dev_name;
	struct device___116 *dev_root;
	const struct attribute_group___147 **bus_groups;
	const struct attribute_group___147 **dev_groups;
	const struct attribute_group___147 **drv_groups;
	int (*match)(struct device___116 *, struct device_driver___116 *);
	int (*uevent)(struct device___116 *, struct kobj_uevent_env *);
	int (*probe)(struct device___116 *);
	void (*sync_state)(struct device___116 *);
	void (*remove)(struct device___116 *);
	void (*shutdown)(struct device___116 *);
	int (*online)(struct device___116 *);
	int (*offline)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	int (*num_vf)(struct device___116 *);
	int (*dma_configure)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___116 {
	const char *name;
	struct bus_type___116 *bus;
	struct module___4 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___116 *);
	void (*sync_state)(struct device___116 *);
	int (*remove)(struct device___116 *);
	void (*shutdown)(struct device___116 *);
	int (*suspend)(struct device___116 *, pm_message_t);
	int (*resume)(struct device___116 *);
	const struct attribute_group___147 **groups;
	const struct attribute_group___147 **dev_groups;
	const struct dev_pm_ops___116 *pm;
	void (*coredump)(struct device___116 *);
	struct driver_private *p;
};

struct device_type___116 {
	const char *name;
	const struct attribute_group___147 **groups;
	int (*uevent)(struct device___116 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___116 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___116 *);
	const struct dev_pm_ops___116 *pm;
};

struct class___116 {
	const char *name;
	struct module___4 *owner;
	const struct attribute_group___147 **class_groups;
	const struct attribute_group___147 **dev_groups;
	struct kobject___147 *dev_kobj;
	int (*dev_uevent)(struct device___116 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___116 *, umode_t *);
	void (*class_release)(struct class___116 *);
	void (*dev_release)(struct device___116 *);
	int (*shutdown_pre)(struct device___116 *);
	const struct kobj_ns_type_operations___21 *ns_type;
	const void * (*namespace)(struct device___116 *);
	void (*get_ownership)(struct device___116 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___116 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___53;

struct pipe_buffer___53 {
	struct page___165 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___53 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___53 {
	int (*confirm)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
	void (*release)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
	bool (*try_steal)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
	bool (*get)(struct pipe_inode_info___53 *, struct pipe_buffer___53 *);
};

typedef rx_handler_result_t rx_handler_func_t___28(struct sk_buff___2 **);

struct bpf_xdp_entity___28 {
	struct bpf_prog___28 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___28;

struct net_device_ops___28;

struct ethtool_ops___6;

struct l3mdev_ops___21;

struct ndisc_ops___11;

struct xfrmdev_ops___28;

struct header_ops___28;

struct inet6_dev___11;

struct netdev_rx_queue___28;

struct mini_Qdisc___28;

struct netdev_queue___28;

struct Qdisc___28;

struct rtnl_link_ops___28;

struct dcbnl_rtnl_ops___28;

struct net_device___2 {
	char name[16];
	struct netdev_name_node___28 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___28 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___6 *ethtool_ops;
	const struct l3mdev_ops___21 *l3mdev_ops;
	const struct ndisc_ops___11 *ndisc_ops;
	const struct xfrmdev_ops___28 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___28 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___147 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___11 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___28 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___28 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___28 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___28 *miniq_ingress;
	struct netdev_queue___28 *ingress_queue;
	struct nf_hook_entries___2 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___28 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___28 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___28 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___28 = 0,
		NETREG_REGISTERED___28 = 1,
		NETREG_UNREGISTERING___28 = 2,
		NETREG_UNREGISTERED___28 = 3,
		NETREG_RELEASED___28 = 4,
		NETREG_DUMMY___28 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___28 = 0,
		RTNL_LINK_INITIALIZING___28 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___2 *);
	struct netpoll_info *npinfo;
	possible_net_t___28 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___116 dev;
	const struct attribute_group___147 *sysfs_groups[4];
	const struct attribute_group___147 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___28 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___28 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___28 xdp_state[3];
	long: 64;
};

struct inet_frags___33;

struct fqdir___33 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___33 *f;
	struct net___3 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___33;

struct inet_frags___33 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___33 *, const void *);
	void (*destructor)(struct inet_frag_queue___33 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___33 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___2 *fragments_tail;
	struct sk_buff___2 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___33 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___8 {
	struct ip_ra_chain___8 *next;
	struct sock___22 *sk;
	union {
		void (*destructor)(struct sock___22 *);
		struct sock___22 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___21;

struct fib_lookup_arg___21;

struct fib_rules_ops___21 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___21 *, struct flowi *, int, struct fib_lookup_arg___21 *);
	bool (*suppress)(struct fib_rule___21 *, int, struct fib_lookup_arg___21 *);
	int (*match)(struct fib_rule___21 *, struct flowi *, int);
	int (*configure)(struct fib_rule___21 *, struct sk_buff___2 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___21 *);
	int (*compare)(struct fib_rule___21 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___21 *, struct sk_buff___2 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___21 *);
	void (*flush_cache)(struct fib_rules_ops___21 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___4 *owner;
	struct net___3 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___3 {
	u32 (*ssthresh)(struct sock___22 *);
	void (*cong_avoid)(struct sock___22 *, u32, u32);
	void (*set_state)(struct sock___22 *, u8);
	void (*cwnd_event)(struct sock___22 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___22 *, u32);
	void (*pkts_acked)(struct sock___22 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___22 *);
	void (*cong_control)(struct sock___22 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___22 *);
	u32 (*sndbuf_expand)(struct sock___22 *);
	size_t (*get_info)(struct sock___22 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___4 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___22 *);
	void (*release)(struct sock___22 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___21 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___3 *);
	int (*fib_dump)(struct net___3 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___4 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___8;

struct dst_entry___21 {
	struct net_device___2 *dev;
	struct dst_ops___33 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___2 *);
	int (*output)(struct net___3 *, struct sock___22 *, struct sk_buff___2 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___8 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___21;

struct neigh_parms___21;

struct neigh_ops___21;

struct neighbour___21 {
	struct neighbour___21 *next;
	struct neigh_table___21 *tbl;
	struct neigh_parms___21 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___28 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___21 *, struct sk_buff___2 *);
	const struct neigh_ops___21 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___2 *dev;
	u8 primary_key[0];
};

struct nf_hook_state___2;

typedef unsigned int nf_hookfn___2(void *, struct sk_buff___2 *, const struct nf_hook_state___2 *);

struct nf_hook_entry___2 {
	nf_hookfn___2 *hook;
	void *priv;
};

struct nf_hook_entries___2 {
	u16 num_hook_entries;
	struct nf_hook_entry___2 hooks[0];
};

struct bpf_prog_array_item___28 {
	struct bpf_prog___28 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___28 {
	struct callback_head rcu;
	struct bpf_prog_array_item___28 items[0];
};

struct bpf_prog_aux___30;

struct bpf_prog___28 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___30 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___138 {
	void * (*start)(struct seq_file___138 *, loff_t *);
	void (*stop)(struct seq_file___138 *, void *);
	void * (*next)(struct seq_file___138 *, void *, loff_t *);
	int (*show)(struct seq_file___138 *, void *);
};

struct pernet_operations___4 {
	struct list_head list;
	int (*init)(struct net___3 *);
	void (*pre_exit)(struct net___3 *);
	void (*exit)(struct net___3 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___28 {
	int (*ieee_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___2 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___2 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___2 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___2 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___2 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___2 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___2 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___2 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___2 *);
	u8 (*setstate)(struct net_device___2 *, u8);
	void (*getpermhwaddr)(struct net_device___2 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___2 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___2 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___2 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___2 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___2 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___2 *, int, u8 *);
	void (*setpfccfg)(struct net_device___2 *, int, u8);
	void (*getpfccfg)(struct net_device___2 *, int, u8 *);
	u8 (*setall)(struct net_device___2 *);
	u8 (*getcap)(struct net_device___2 *, int, u8 *);
	int (*getnumtcs)(struct net_device___2 *, int, u8 *);
	int (*setnumtcs)(struct net_device___2 *, int, u8);
	u8 (*getpfcstate)(struct net_device___2 *);
	void (*setpfcstate)(struct net_device___2 *, u8);
	void (*getbcncfg)(struct net_device___2 *, int, u32 *);
	void (*setbcncfg)(struct net_device___2 *, int, u32);
	void (*getbcnrp)(struct net_device___2 *, int, u8 *);
	void (*setbcnrp)(struct net_device___2 *, int, u8);
	int (*setapp)(struct net_device___2 *, u8, u16, u8);
	int (*getapp)(struct net_device___2 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___2 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___2 *, int, u8);
	u8 (*getdcbx)(struct net_device___2 *);
	u8 (*setdcbx)(struct net_device___2 *, u8);
	int (*peer_getappinfo)(struct net_device___2 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___2 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___2 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___2 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___2 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___2 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___31;

typedef int (*bpf_iter_init_seq_priv_t___30)(void *, struct bpf_iter_aux_info___31 *);

struct bpf_map___30;

struct bpf_iter_aux_info___31 {
	struct bpf_map___30 *map;
};

struct bpf_iter_seq_info___30 {
	const struct seq_operations___138 *seq_ops;
	bpf_iter_init_seq_priv_t___30 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___30 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___30 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___30 *, struct file___160 *);
	void (*map_free)(struct bpf_map___30 *);
	int (*map_get_next_key)(struct bpf_map___30 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___30 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___30 *, void *);
	int (*map_lookup_batch)(struct bpf_map___30 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___30 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___30 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___30 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___30 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___30 *, void *);
	int (*map_update_elem)(struct bpf_map___30 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___30 *, void *);
	int (*map_push_elem)(struct bpf_map___30 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___30 *, void *);
	int (*map_peek_elem)(struct bpf_map___30 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___30 *, struct file___160 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___30 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___30 *, void *, struct seq_file___138 *);
	int (*map_check_btf)(const struct bpf_map___30 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___30 *, struct bpf_prog_aux___30 *);
	void (*map_poke_untrack)(struct bpf_map___30 *, struct bpf_prog_aux___30 *);
	void (*map_poke_run)(struct bpf_map___30 *, u32, struct bpf_prog___28 *, struct bpf_prog___28 *);
	int (*map_direct_value_addr)(const struct bpf_map___30 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___30 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___30 *, struct vm_area_struct___165 *);
	__poll_t (*map_poll)(struct bpf_map___30 *, struct file___160 *, struct poll_table_struct___101 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___30 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___30 *, const struct bpf_map___30 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___30 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___30 *iter_seq_info;
};

struct bpf_map___30 {
	const struct bpf_map_ops___30 *ops;
	struct bpf_map___30 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___61 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___30;

struct bpf_jit_poke_descriptor___30;

struct bpf_prog_ops___28;

struct btf_mod_pair___30;

struct bpf_prog_offload___28;

struct bpf_prog_aux___30 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___28 *dst_prog;
	struct bpf_trampoline___30 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___28 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___30 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___28 *ops;
	struct bpf_map___30 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___30 *used_btfs;
	struct bpf_prog___28 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___30 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___28 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___28;

struct bpf_map_dev_ops___28 {
	int (*map_get_next_key)(struct bpf_offloaded_map___28 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___28 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___28 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___28 *, void *);
};

struct bpf_offloaded_map___28 {
	struct bpf_map___30 map;
	struct net_device___2 *netdev;
	const struct bpf_map_dev_ops___28 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___28 {
	int (*test_run)(struct bpf_prog___28 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___28 {
	struct bpf_prog___28 *prog;
	struct net_device___2 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___30 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___28 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___4 *mod;
};

struct bpf_jit_poke_descriptor___30 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___30 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___30 {
	struct btf *btf;
	struct module___4 *module;
};

struct cftype___109;

struct cgroup_subsys___109 {
	struct cgroup_subsys_state___109 * (*css_alloc)(struct cgroup_subsys_state___109 *);
	int (*css_online)(struct cgroup_subsys_state___109 *);
	void (*css_offline)(struct cgroup_subsys_state___109 *);
	void (*css_released)(struct cgroup_subsys_state___109 *);
	void (*css_free)(struct cgroup_subsys_state___109 *);
	void (*css_reset)(struct cgroup_subsys_state___109 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___109 *, int);
	int (*css_extra_stat_show)(struct seq_file___138 *, struct cgroup_subsys_state___109 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___167 *, struct css_set___109 *);
	void (*cancel_fork)(struct task_struct___167 *, struct css_set___109 *);
	void (*fork)(struct task_struct___167 *);
	void (*exit)(struct task_struct___167 *);
	void (*release)(struct task_struct___167 *);
	void (*bind)(struct cgroup_subsys_state___109 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___109 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___109 *dfl_cftypes;
	struct cftype___109 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___109 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___109 *updated_children;
	struct cgroup___109 *updated_next;
};

struct cgroup_root___109 {
	struct kernfs_root___147 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___109 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___109 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___109 *ss;
	struct list_head node;
	struct kernfs_ops___147 *kf_ops;
	int (*open)(struct kernfs_open_file___147 *);
	void (*release)(struct kernfs_open_file___147 *);
	u64 (*read_u64)(struct cgroup_subsys_state___109 *, struct cftype___109 *);
	s64 (*read_s64)(struct cgroup_subsys_state___109 *, struct cftype___109 *);
	int (*seq_show)(struct seq_file___138 *, void *);
	void * (*seq_start)(struct seq_file___138 *, loff_t *);
	void * (*seq_next)(struct seq_file___138 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___138 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___109 *, struct cftype___109 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___109 *, struct cftype___109 *, s64);
	ssize_t (*write)(struct kernfs_open_file___147 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___147 *, struct poll_table_struct___101 *);
};

struct xdp_rxq_info___28 {
	struct net_device___2 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___28 {
	struct net_device___2 *dev;
};

struct xdp_buff___28 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___28 *rxq;
	struct xdp_txq_info___28 *txq;
	u32 frame_sz;
};

struct xdp_frame___28 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___2 *dev_rx;
};

struct netlink_callback___28 {
	struct sk_buff___2 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___2 *, struct netlink_callback___28 *);
	int (*done)(struct netlink_callback___28 *);
	void *data;
	struct module___4 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___28 {
	int (*create)(struct sk_buff___2 *, struct net_device___2 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___2 *, unsigned char *);
	int (*cache)(const struct neighbour___21 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___2 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___2 *);
};

struct netdev_queue___28 {
	struct net_device___2 *dev;
	struct Qdisc___28 *qdisc;
	struct Qdisc___28 *qdisc_sleeping;
	struct kobject___147 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___2 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___28 {
	struct sk_buff___2 *head;
	struct sk_buff___2 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___28;

struct Qdisc___28 {
	int (*enqueue)(struct sk_buff___2 *, struct Qdisc___28 *, struct sk_buff___2 **);
	struct sk_buff___2 * (*dequeue)(struct Qdisc___28 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___28 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___28 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___28 gso_skb;
	struct qdisc_skb_head___28 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___28 *next_sched;
	struct sk_buff_head___28 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___28 {
	struct xdp_rxq_info___28 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___147 kobj;
	struct net_device___2 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___28 {
	enum net_device_path_type type;
	const struct net_device___2 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___28 = 0,
				DEV_PATH_BR_VLAN_TAG___28 = 1,
				DEV_PATH_BR_VLAN_UNTAG___28 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___28 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___28 {
	const struct net_device___2 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___28 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___28 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___28 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___28 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___2 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___28 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___2 *dev;
	const char *name;
};

struct net_device_ops___28 {
	int (*ndo_init)(struct net_device___2 *);
	void (*ndo_uninit)(struct net_device___2 *);
	int (*ndo_open)(struct net_device___2 *);
	int (*ndo_stop)(struct net_device___2 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___2 *, struct net_device___2 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___2 *, struct net_device___2 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___2 *, struct sk_buff___2 *, struct net_device___2 *);
	void (*ndo_change_rx_flags)(struct net_device___2 *, int);
	void (*ndo_set_rx_mode)(struct net_device___2 *);
	int (*ndo_set_mac_address)(struct net_device___2 *, void *);
	int (*ndo_validate_addr)(struct net_device___2 *);
	int (*ndo_do_ioctl)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___2 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___2 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___2 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___2 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___2 *, int);
	int (*ndo_neigh_setup)(struct net_device___2 *, struct neigh_parms___21 *);
	void (*ndo_tx_timeout)(struct net_device___2 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___2 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___2 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___2 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___2 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___2 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___2 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___2 *);
	int (*ndo_netpoll_setup)(struct net_device___2 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___2 *);
	int (*ndo_set_vf_mac)(struct net_device___2 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___2 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___2 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___2 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___2 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___2 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___2 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___2 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___2 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___2 *, int, struct sk_buff___2 *);
	int (*ndo_get_vf_guid)(struct net_device___2 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___2 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___2 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___2 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___2 *);
	int (*ndo_fcoe_disable)(struct net_device___2 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___2 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___2 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___2 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___2 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___2 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___2 *, const struct sk_buff___2 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___2 *, struct net_device___2 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___2 *, struct net_device___2 *);
	struct net_device___2 * (*ndo_get_xmit_slave)(struct net_device___2 *, struct sk_buff___2 *, bool);
	struct net_device___2 * (*ndo_sk_get_lower_dev)(struct net_device___2 *, struct sock___22 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___2 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___2 *, struct neighbour___21 *);
	void (*ndo_neigh_destroy)(struct net_device___2 *, struct neighbour___21 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___2 *, struct netlink_callback___28 *, struct net_device___2 *, struct net_device___2 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___2 *, struct nlattr **, struct net_device___2 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___2 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___2 *, u32, u32, struct net_device___2 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___2 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___2 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___2 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___2 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___2 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___2 *, struct net_device___2 *);
	void (*ndo_dfwd_del_station)(struct net_device___2 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___2 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___2 *);
	int (*ndo_change_proto_down)(struct net_device___2 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___2 *, struct sk_buff___2 *);
	void (*ndo_set_rx_headroom)(struct net_device___2 *, int);
	int (*ndo_bpf)(struct net_device___2 *, struct netdev_bpf___28 *);
	int (*ndo_xdp_xmit)(struct net_device___2 *, int, struct xdp_frame___28 **, u32);
	struct net_device___2 * (*ndo_xdp_get_xmit_slave)(struct net_device___2 *, struct xdp_buff___28 *);
	int (*ndo_xsk_wakeup)(struct net_device___2 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___2 *);
	int (*ndo_tunnel_ctl)(struct net_device___2 *, struct ip_tunnel_parm *, int);
	struct net_device___2 * (*ndo_get_peer_dev)(struct net_device___2 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___28 *, struct net_device_path___28 *);
};

struct neigh_parms___21 {
	possible_net_t___28 net;
	struct net_device___2 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___21 *);
	struct neigh_table___21 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___6 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___2 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___2 *);
	void (*get_regs)(struct net_device___2 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___2 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___2 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___2 *);
	void (*set_msglevel)(struct net_device___2 *, u32);
	int (*nway_reset)(struct net_device___2 *);
	u32 (*get_link)(struct net_device___2 *);
	int (*get_link_ext_state)(struct net_device___2 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___2 *);
	int (*get_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___2 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___2 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___2 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___2 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___2 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___2 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___2 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___2 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___2 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___2 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___2 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___2 *);
	void (*complete)(struct net_device___2 *);
	u32 (*get_priv_flags)(struct net_device___2 *);
	int (*set_priv_flags)(struct net_device___2 *, u32);
	int (*get_sset_count)(struct net_device___2 *, int);
	int (*get_rxnfc)(struct net_device___2 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___2 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___2 *, struct ethtool_flash *);
	int (*reset)(struct net_device___2 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___2 *);
	u32 (*get_rxfh_indir_size)(struct net_device___2 *);
	int (*get_rxfh)(struct net_device___2 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___2 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___2 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___2 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___2 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___2 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___2 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___2 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___2 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___2 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___2 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___2 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___2 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___2 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___2 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___2 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___2 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___2 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___2 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___2 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___2 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___2 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___2 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___2 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___2 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___2 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___2 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___2 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___2 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___2 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___21 {
	u32 (*l3mdev_fib_table)(const struct net_device___2 *);
	struct sk_buff___2 * (*l3mdev_l3_rcv)(struct net_device___2 *, struct sk_buff___2 *, u16);
	struct sk_buff___2 * (*l3mdev_l3_out)(struct net_device___2 *, struct sock___22 *, struct sk_buff___2 *, u16);
	struct dst_entry___21 * (*l3mdev_link_scope_lookup)(const struct net_device___2 *, struct flowi6 *);
};

struct ndisc_ops___11 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___2 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___2 *, struct neighbour___21 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___2 *, u8, struct neighbour___21 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___2 *, struct sk_buff___2 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___3 *, struct net_device___2 *, const struct prefix_info *, struct inet6_dev___11 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___11;

struct inet6_dev___11 {
	struct net_device___2 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___11 *mc_list;
	struct ifmcaddr6___11 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___28 mc_query_queue;
	struct sk_buff_head___28 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___21 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___28;

struct tcf_block___28;

struct mini_Qdisc___28 {
	struct tcf_proto___28 *filter_list;
	struct tcf_block___28 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___28 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___2 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___2 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___3 *, struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___2 *, struct list_head *);
	size_t (*get_size)(const struct net_device___2 *);
	int (*fill_info)(struct sk_buff___2 *, const struct net_device___2 *);
	size_t (*get_xstats_size)(const struct net_device___2 *);
	int (*fill_xstats)(struct sk_buff___2 *, const struct net_device___2 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___2 *, struct net_device___2 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___2 *, const struct net_device___2 *);
	int (*fill_slave_info)(struct sk_buff___2 *, const struct net_device___2 *, const struct net_device___2 *);
	struct net___3 * (*get_link_net)(const struct net_device___2 *);
	size_t (*get_linkxstats_size)(const struct net_device___2 *, int);
	int (*fill_linkxstats)(struct sk_buff___2 *, const struct net_device___2 *, int *, int);
};

struct nf_hook_state___2 {
	u8 hook;
	u8 pf;
	struct net_device___2 *in;
	struct net_device___2 *out;
	struct sock___22 *sk;
	struct net___3 *net;
	int (*okfn)(struct net___3 *, struct sock___22 *, struct sk_buff___2 *);
};

struct nf_hook_ops___2 {
	nf_hookfn___2 *hook;
	struct net_device___2 *dev;
	void *priv;
	u8 pf;
	enum nf_hook_ops_type hook_ops_type: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	unsigned int hooknum;
	int priority;
};

struct block_device_operations___73;

struct gendisk___73 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___74 *part0;
	const struct block_device_operations___73 *fops;
	struct request_queue___73 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___70 *bdi;
	struct kobject___147 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___147 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___73 {
	struct bio___73 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___87 *bip_vec;
	struct bio_vec___87 bip_inline_vecs[0];
};

struct blkcg___70;

struct blkg_policy_data___70;

struct blkcg_gq___70 {
	struct request_queue___73 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___70 *blkcg;
	struct blkcg_gq___70 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___70 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___73 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___73(struct request___73 *);

typedef void integrity_complete_fn___73(struct request___73 *, unsigned int);

struct blk_integrity_profile___73 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___73 *prepare_fn;
	integrity_complete_fn___73 *complete_fn;
	const char *name;
};

struct block_device_operations___73 {
	blk_qc_t (*submit_bio)(struct bio___73 *);
	int (*open)(struct block_device___74 *, fmode_t);
	void (*release)(struct gendisk___73 *, fmode_t);
	int (*rw_page)(struct block_device___74 *, sector_t, struct page___165 *, unsigned int);
	int (*ioctl)(struct block_device___74 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___74 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___73 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___73 *);
	int (*getgeo)(struct block_device___74 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___74 *, bool);
	void (*swap_slot_free_notify)(struct block_device___74 *, long unsigned int);
	int (*report_zones)(struct gendisk___73 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___73 *, umode_t *);
	struct module___4 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___73 *, sector_t *);
};

typedef void rq_end_io_fn___73(struct request___73 *, blk_status_t);

struct request___73 {
	struct request_queue___73 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___70 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___73 *bio;
	struct bio___73 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___87 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___73 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___73 *saved_end_io;
		} flush;
	};
	struct gendisk___73 *rq_disk;
	struct block_device___74 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___73 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___70 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___73 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___147 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___160 *debugfs_dir;
	struct dentry___160 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___73;

struct elevator_mq_ops___73 {
	int (*init_sched)(struct request_queue___73 *, struct elevator_type___73 *);
	void (*exit_sched)(struct elevator_queue___73 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___70 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___70 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___70 *);
	bool (*allow_merge)(struct request_queue___73 *, struct request___73 *, struct bio___73 *);
	bool (*bio_merge)(struct request_queue___73 *, struct bio___73 *, unsigned int);
	int (*request_merge)(struct request_queue___73 *, struct request___73 **, struct bio___73 *);
	void (*request_merged)(struct request_queue___73 *, struct request___73 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___73 *, struct request___73 *, struct request___73 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___73 *);
	void (*finish_request)(struct request___73 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___70 *, struct list_head *, bool);
	struct request___73 * (*dispatch_request)(struct blk_mq_hw_ctx___70 *);
	bool (*has_work)(struct blk_mq_hw_ctx___70 *);
	void (*completed_request)(struct request___73 *, u64);
	void (*requeue_request)(struct request___73 *);
	struct request___73 * (*former_request)(struct request_queue___73 *, struct request___73 *);
	struct request___73 * (*next_request)(struct request_queue___73 *, struct request___73 *);
	void (*init_icq)(struct io_cq___73 *);
	void (*exit_icq)(struct io_cq___73 *);
};

struct elv_fs_entry___73;

struct elevator_type___73 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___73 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___73 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___4 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___73 {
	struct elevator_type___73 *type;
	void *elevator_data;
	struct kobject___147 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___73 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___73 *, char *);
	ssize_t (*store)(struct elevator_queue___73 *, const char *, size_t);
};

struct blk_mq_queue_data___70;

struct blk_mq_ops___70 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___70 *, const struct blk_mq_queue_data___70 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___70 *);
	int (*get_budget)(struct request_queue___73 *);
	void (*put_budget)(struct request_queue___73 *, int);
	void (*set_rq_budget_token)(struct request___73 *, int);
	int (*get_rq_budget_token)(struct request___73 *);
	enum blk_eh_timer_return (*timeout)(struct request___73 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___70 *);
	void (*complete)(struct request___73 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___70 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___70 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___70 *, struct request___73 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___70 *, struct request___73 *, unsigned int);
	void (*initialize_rq_fn)(struct request___73 *);
	void (*cleanup_rq)(struct request___73 *);
	bool (*busy)(struct request_queue___73 *);
	int (*map_queues)(struct blk_mq_tag_set___70 *);
	void (*show_rq)(struct seq_file___138 *, struct request___73 *);
};

struct blk_mq_tag_set___70 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___70 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___70 {
	struct request___73 *rq;
	bool last;
};

struct blkcg_policy_data___70;

struct blkcg___70 {
	struct cgroup_subsys_state___109 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___70 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___70 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___70 {
	struct blkcg___70 *blkcg;
	int plid;
};

struct blkg_policy_data___70 {
	struct blkcg_gq___70 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___61 {
	struct mem_cgroup___61 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___61 {
	struct lruvec___68 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___61 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___61 *memcg;
};

struct obj_cgroup___61 {
	struct percpu_ref refcnt;
	struct mem_cgroup___61 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___28 {
	spinlock_t *lock;
	struct sk_buff___2 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___28;

struct Qdisc_ops___28 {
	struct Qdisc_ops___28 *next;
	const struct Qdisc_class_ops___28 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___2 *, struct Qdisc___28 *, struct sk_buff___2 **);
	struct sk_buff___2 * (*dequeue)(struct Qdisc___28 *);
	struct sk_buff___2 * (*peek)(struct Qdisc___28 *);
	int (*init)(struct Qdisc___28 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___28 *);
	void (*destroy)(struct Qdisc___28 *);
	int (*change)(struct Qdisc___28 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___28 *);
	int (*change_tx_queue_len)(struct Qdisc___28 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___28 *, unsigned int);
	int (*dump)(struct Qdisc___28 *, struct sk_buff___2 *);
	int (*dump_stats)(struct Qdisc___28 *, struct gnet_dump___28 *);
	void (*ingress_block_set)(struct Qdisc___28 *, u32);
	void (*egress_block_set)(struct Qdisc___28 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___28 *);
	u32 (*egress_block_get)(struct Qdisc___28 *);
	struct module___4 *owner;
};

struct Qdisc_class_ops___28 {
	unsigned int flags;
	struct netdev_queue___28 * (*select_queue)(struct Qdisc___28 *, struct tcmsg *);
	int (*graft)(struct Qdisc___28 *, long unsigned int, struct Qdisc___28 *, struct Qdisc___28 **, struct netlink_ext_ack *);
	struct Qdisc___28 * (*leaf)(struct Qdisc___28 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___28 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___28 *, u32);
	int (*change)(struct Qdisc___28 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___28 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___28 *, struct qdisc_walker *);
	struct tcf_block___28 * (*tcf_block)(struct Qdisc___28 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___28 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___28 *, long unsigned int);
	int (*dump)(struct Qdisc___28 *, long unsigned int, struct sk_buff___2 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___28 *, long unsigned int, struct gnet_dump___28 *);
};

struct tcf_chain___28;

struct tcf_block___28 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___3 *net;
	struct Qdisc___28 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___28 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___28;

struct tcf_proto_ops___28;

struct tcf_proto___28 {
	struct tcf_proto___28 *next;
	void *root;
	int (*classify)(struct sk_buff___2 *, const struct tcf_proto___28 *, struct tcf_result___28 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___28 *ops;
	struct tcf_chain___28 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___28 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___28 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___28 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___2 *, const struct tcf_proto___28 *, struct tcf_result___28 *);
	int (*init)(struct tcf_proto___28 *);
	void (*destroy)(struct tcf_proto___28 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___28 *, u32);
	void (*put)(struct tcf_proto___28 *, void *);
	int (*change)(struct net___3 *, struct sk_buff___2 *, struct tcf_proto___28 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___28 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___28 *);
	void (*walk)(struct tcf_proto___28 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___28 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___28 *, void *);
	void (*hw_del)(struct tcf_proto___28 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___3 *, struct tcf_chain___28 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___3 *, struct tcf_proto___28 *, void *, struct sk_buff___2 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___3 *, struct tcf_proto___28 *, void *, struct sk_buff___2 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___2 *, struct net___3 *, void *);
	struct module___4 *owner;
	int flags;
};

struct tcf_chain___28 {
	struct mutex filter_chain_lock;
	struct tcf_proto___28 *filter_chain;
	struct list_head list;
	struct tcf_block___28 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___28 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___21 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___28 *prog;
};

struct pneigh_entry___21;

struct neigh_hash_table___21;

struct neigh_table___21 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___2 *, __u32 *);
	bool (*key_eq)(const struct neighbour___21 *, const void *);
	int (*constructor)(struct neighbour___21 *);
	int (*pconstructor)(struct pneigh_entry___21 *);
	void (*pdestructor)(struct pneigh_entry___21 *);
	void (*proxy_redo)(struct sk_buff___2 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___2 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___21 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___28 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___21 *nht;
	struct pneigh_entry___21 **phash_buckets;
};

struct neigh_ops___21 {
	int family;
	void (*solicit)(struct neighbour___21 *, struct sk_buff___2 *);
	void (*error_report)(struct neighbour___21 *, struct sk_buff___2 *);
	int (*output)(struct neighbour___21 *, struct sk_buff___2 *);
	int (*connected_output)(struct neighbour___21 *, struct sk_buff___2 *);
};

struct pneigh_entry___21 {
	struct pneigh_entry___21 *next;
	possible_net_t___28 net;
	struct net_device___2 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___21 {
	struct neighbour___21 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___8 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___3 *, struct sock___22 *, struct sk_buff___2 *);
	int (*orig_input)(struct sk_buff___2 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___21 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___21 *ctarget;
	struct net___3 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___21 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___21 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___11;

struct timewait_sock_ops___11;

struct proto___21 {
	void (*close)(struct sock___22 *, long int);
	int (*pre_connect)(struct sock___22 *, struct sockaddr *, int);
	int (*connect)(struct sock___22 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___22 *, int);
	struct sock___22 * (*accept)(struct sock___22 *, int, int *, bool);
	int (*ioctl)(struct sock___22 *, int, long unsigned int);
	int (*init)(struct sock___22 *);
	void (*destroy)(struct sock___22 *);
	void (*shutdown)(struct sock___22 *, int);
	int (*setsockopt)(struct sock___22 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___22 *, int, int, char *, int *);
	void (*keepalive)(struct sock___22 *, int);
	int (*compat_ioctl)(struct sock___22 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___22 *, struct msghdr___22 *, size_t);
	int (*recvmsg)(struct sock___22 *, struct msghdr___22 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___22 *, struct page___165 *, int, size_t, int);
	int (*bind)(struct sock___22 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___22 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___22 *, struct sk_buff___2 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___22 *);
	int (*hash)(struct sock___22 *);
	void (*unhash)(struct sock___22 *);
	void (*rehash)(struct sock___22 *);
	int (*get_port)(struct sock___22 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___22 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___22 *, int);
	bool (*sock_is_readable)(struct sock___22 *);
	void (*enter_memory_pressure)(struct sock___22 *);
	void (*leave_memory_pressure)(struct sock___22 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___11 *rsk_prot;
	struct timewait_sock_ops___11 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___4 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___22 *, int);
};

struct sock_reuseport___4 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___28 *prog;
	struct sock___22 *socks[0];
};

struct request_sock___12;

struct request_sock_ops___11 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___22 *, struct request_sock___12 *);
	void (*send_ack)(const struct sock___22 *, struct sk_buff___2 *, struct request_sock___12 *);
	void (*send_reset)(const struct sock___22 *, struct sk_buff___2 *);
	void (*destructor)(struct request_sock___12 *);
	void (*syn_ack_timeout)(const struct request_sock___12 *);
};

struct timewait_sock_ops___11 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___22 *, struct sock___22 *, void *);
	void (*twsk_destructor)(struct sock___22 *);
};

struct request_sock___12 {
	struct sock_common___21 __req_common;
	struct request_sock___12 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___11 *rsk_ops;
	struct sock___22 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___11 {
	struct in6_addr mca_addr;
	struct inet6_dev___11 *idev;
	struct ifmcaddr6___11 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct sockaddr_un {
	__kernel_sa_family_t sun_family;
	char sun_path[108];
};

struct unix_address {
	refcount_t refcnt;
	int len;
	unsigned int hash;
	struct sockaddr_un name[0];
};

struct scm_stat {
	atomic_t nr_fds;
};

struct unix_sock {
	struct sock___18 sk;
	struct unix_address *addr;
	struct path___156 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___18 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___18 peer_wq;
	wait_queue_entry_t peer_wake;
	struct scm_stat scm_stat;
	struct sk_buff___26 *oob_skb;
	long: 64;
};

typedef struct poll_table_struct___97 poll_table___29;

enum tomoyo_conditions_index {
	TOMOYO_TASK_UID = 0,
	TOMOYO_TASK_EUID = 1,
	TOMOYO_TASK_SUID = 2,
	TOMOYO_TASK_FSUID = 3,
	TOMOYO_TASK_GID = 4,
	TOMOYO_TASK_EGID = 5,
	TOMOYO_TASK_SGID = 6,
	TOMOYO_TASK_FSGID = 7,
	TOMOYO_TASK_PID = 8,
	TOMOYO_TASK_PPID = 9,
	TOMOYO_EXEC_ARGC = 10,
	TOMOYO_EXEC_ENVC = 11,
	TOMOYO_TYPE_IS_SOCKET = 12,
	TOMOYO_TYPE_IS_SYMLINK = 13,
	TOMOYO_TYPE_IS_FILE = 14,
	TOMOYO_TYPE_IS_BLOCK_DEV = 15,
	TOMOYO_TYPE_IS_DIRECTORY = 16,
	TOMOYO_TYPE_IS_CHAR_DEV = 17,
	TOMOYO_TYPE_IS_FIFO = 18,
	TOMOYO_MODE_SETUID = 19,
	TOMOYO_MODE_SETGID = 20,
	TOMOYO_MODE_STICKY = 21,
	TOMOYO_MODE_OWNER_READ = 22,
	TOMOYO_MODE_OWNER_WRITE = 23,
	TOMOYO_MODE_OWNER_EXECUTE = 24,
	TOMOYO_MODE_GROUP_READ = 25,
	TOMOYO_MODE_GROUP_WRITE = 26,
	TOMOYO_MODE_GROUP_EXECUTE = 27,
	TOMOYO_MODE_OTHERS_READ = 28,
	TOMOYO_MODE_OTHERS_WRITE = 29,
	TOMOYO_MODE_OTHERS_EXECUTE = 30,
	TOMOYO_EXEC_REALPATH = 31,
	TOMOYO_SYMLINK_TARGET = 32,
	TOMOYO_PATH1_UID = 33,
	TOMOYO_PATH1_GID = 34,
	TOMOYO_PATH1_INO = 35,
	TOMOYO_PATH1_MAJOR = 36,
	TOMOYO_PATH1_MINOR = 37,
	TOMOYO_PATH1_PERM = 38,
	TOMOYO_PATH1_TYPE = 39,
	TOMOYO_PATH1_DEV_MAJOR = 40,
	TOMOYO_PATH1_DEV_MINOR = 41,
	TOMOYO_PATH2_UID = 42,
	TOMOYO_PATH2_GID = 43,
	TOMOYO_PATH2_INO = 44,
	TOMOYO_PATH2_MAJOR = 45,
	TOMOYO_PATH2_MINOR = 46,
	TOMOYO_PATH2_PERM = 47,
	TOMOYO_PATH2_TYPE = 48,
	TOMOYO_PATH2_DEV_MAJOR = 49,
	TOMOYO_PATH2_DEV_MINOR = 50,
	TOMOYO_PATH1_PARENT_UID = 51,
	TOMOYO_PATH1_PARENT_GID = 52,
	TOMOYO_PATH1_PARENT_INO = 53,
	TOMOYO_PATH1_PARENT_PERM = 54,
	TOMOYO_PATH2_PARENT_UID = 55,
	TOMOYO_PATH2_PARENT_GID = 56,
	TOMOYO_PATH2_PARENT_INO = 57,
	TOMOYO_PATH2_PARENT_PERM = 58,
	TOMOYO_MAX_CONDITION_KEYWORD = 59,
	TOMOYO_NUMBER_UNION = 60,
	TOMOYO_NAME_UNION = 61,
	TOMOYO_ARGV_ENTRY = 62,
	TOMOYO_ENVP_ENTRY = 63,
};

enum tomoyo_path_stat_index {
	TOMOYO_PATH1 = 0,
	TOMOYO_PATH1_PARENT = 1,
	TOMOYO_PATH2 = 2,
	TOMOYO_PATH2_PARENT = 3,
	TOMOYO_MAX_PATH_STAT = 4,
};

enum tomoyo_mode_index {
	TOMOYO_CONFIG_DISABLED = 0,
	TOMOYO_CONFIG_LEARNING = 1,
	TOMOYO_CONFIG_PERMISSIVE = 2,
	TOMOYO_CONFIG_ENFORCING = 3,
	TOMOYO_CONFIG_MAX_MODE = 4,
	TOMOYO_CONFIG_WANT_REJECT_LOG = 64,
	TOMOYO_CONFIG_WANT_GRANT_LOG = 128,
	TOMOYO_CONFIG_USE_DEFAULT = 255,
};

enum tomoyo_policy_id {
	TOMOYO_ID_GROUP = 0,
	TOMOYO_ID_ADDRESS_GROUP = 1,
	TOMOYO_ID_PATH_GROUP = 2,
	TOMOYO_ID_NUMBER_GROUP = 3,
	TOMOYO_ID_TRANSITION_CONTROL = 4,
	TOMOYO_ID_AGGREGATOR = 5,
	TOMOYO_ID_MANAGER = 6,
	TOMOYO_ID_CONDITION = 7,
	TOMOYO_ID_NAME = 8,
	TOMOYO_ID_ACL = 9,
	TOMOYO_ID_DOMAIN = 10,
	TOMOYO_MAX_POLICY = 11,
};

enum tomoyo_domain_info_flags_index {
	TOMOYO_DIF_QUOTA_WARNED = 0,
	TOMOYO_DIF_TRANSITION_FAILED = 1,
	TOMOYO_MAX_DOMAIN_INFO_FLAGS = 2,
};

enum tomoyo_grant_log {
	TOMOYO_GRANTLOG_AUTO = 0,
	TOMOYO_GRANTLOG_NO = 1,
	TOMOYO_GRANTLOG_YES = 2,
};

enum tomoyo_group_id {
	TOMOYO_PATH_GROUP = 0,
	TOMOYO_NUMBER_GROUP = 1,
	TOMOYO_ADDRESS_GROUP = 2,
	TOMOYO_MAX_GROUP = 3,
};

enum tomoyo_path_acl_index {
	TOMOYO_TYPE_EXECUTE = 0,
	TOMOYO_TYPE_READ = 1,
	TOMOYO_TYPE_WRITE = 2,
	TOMOYO_TYPE_APPEND = 3,
	TOMOYO_TYPE_UNLINK = 4,
	TOMOYO_TYPE_GETATTR = 5,
	TOMOYO_TYPE_RMDIR = 6,
	TOMOYO_TYPE_TRUNCATE = 7,
	TOMOYO_TYPE_SYMLINK = 8,
	TOMOYO_TYPE_CHROOT = 9,
	TOMOYO_TYPE_UMOUNT = 10,
	TOMOYO_MAX_PATH_OPERATION = 11,
};

enum tomoyo_memory_stat_type {
	TOMOYO_MEMORY_POLICY = 0,
	TOMOYO_MEMORY_AUDIT = 1,
	TOMOYO_MEMORY_QUERY = 2,
	TOMOYO_MAX_MEMORY_STAT = 3,
};

enum tomoyo_mkdev_acl_index {
	TOMOYO_TYPE_MKBLOCK = 0,
	TOMOYO_TYPE_MKCHAR = 1,
	TOMOYO_MAX_MKDEV_OPERATION = 2,
};

enum tomoyo_network_acl_index {
	TOMOYO_NETWORK_BIND = 0,
	TOMOYO_NETWORK_LISTEN = 1,
	TOMOYO_NETWORK_CONNECT = 2,
	TOMOYO_NETWORK_SEND = 3,
	TOMOYO_MAX_NETWORK_OPERATION = 4,
};

enum tomoyo_path2_acl_index {
	TOMOYO_TYPE_LINK = 0,
	TOMOYO_TYPE_RENAME = 1,
	TOMOYO_TYPE_PIVOT_ROOT = 2,
	TOMOYO_MAX_PATH2_OPERATION = 3,
};

enum tomoyo_path_number_acl_index {
	TOMOYO_TYPE_CREATE = 0,
	TOMOYO_TYPE_MKDIR = 1,
	TOMOYO_TYPE_MKFIFO = 2,
	TOMOYO_TYPE_MKSOCK = 3,
	TOMOYO_TYPE_IOCTL = 4,
	TOMOYO_TYPE_CHMOD = 5,
	TOMOYO_TYPE_CHOWN = 6,
	TOMOYO_TYPE_CHGRP = 7,
	TOMOYO_MAX_PATH_NUMBER_OPERATION = 8,
};

enum tomoyo_securityfs_interface_index {
	TOMOYO_DOMAINPOLICY = 0,
	TOMOYO_EXCEPTIONPOLICY = 1,
	TOMOYO_PROCESS_STATUS = 2,
	TOMOYO_STAT = 3,
	TOMOYO_AUDIT = 4,
	TOMOYO_VERSION = 5,
	TOMOYO_PROFILE = 6,
	TOMOYO_QUERY = 7,
	TOMOYO_MANAGER = 8,
};

enum tomoyo_mac_index {
	TOMOYO_MAC_FILE_EXECUTE = 0,
	TOMOYO_MAC_FILE_OPEN = 1,
	TOMOYO_MAC_FILE_CREATE = 2,
	TOMOYO_MAC_FILE_UNLINK = 3,
	TOMOYO_MAC_FILE_GETATTR = 4,
	TOMOYO_MAC_FILE_MKDIR = 5,
	TOMOYO_MAC_FILE_RMDIR = 6,
	TOMOYO_MAC_FILE_MKFIFO = 7,
	TOMOYO_MAC_FILE_MKSOCK = 8,
	TOMOYO_MAC_FILE_TRUNCATE = 9,
	TOMOYO_MAC_FILE_SYMLINK = 10,
	TOMOYO_MAC_FILE_MKBLOCK = 11,
	TOMOYO_MAC_FILE_MKCHAR = 12,
	TOMOYO_MAC_FILE_LINK = 13,
	TOMOYO_MAC_FILE_RENAME = 14,
	TOMOYO_MAC_FILE_CHMOD = 15,
	TOMOYO_MAC_FILE_CHOWN = 16,
	TOMOYO_MAC_FILE_CHGRP = 17,
	TOMOYO_MAC_FILE_IOCTL = 18,
	TOMOYO_MAC_FILE_CHROOT = 19,
	TOMOYO_MAC_FILE_MOUNT = 20,
	TOMOYO_MAC_FILE_UMOUNT = 21,
	TOMOYO_MAC_FILE_PIVOT_ROOT = 22,
	TOMOYO_MAC_NETWORK_INET_STREAM_BIND = 23,
	TOMOYO_MAC_NETWORK_INET_STREAM_LISTEN = 24,
	TOMOYO_MAC_NETWORK_INET_STREAM_CONNECT = 25,
	TOMOYO_MAC_NETWORK_INET_DGRAM_BIND = 26,
	TOMOYO_MAC_NETWORK_INET_DGRAM_SEND = 27,
	TOMOYO_MAC_NETWORK_INET_RAW_BIND = 28,
	TOMOYO_MAC_NETWORK_INET_RAW_SEND = 29,
	TOMOYO_MAC_NETWORK_UNIX_STREAM_BIND = 30,
	TOMOYO_MAC_NETWORK_UNIX_STREAM_LISTEN = 31,
	TOMOYO_MAC_NETWORK_UNIX_STREAM_CONNECT = 32,
	TOMOYO_MAC_NETWORK_UNIX_DGRAM_BIND = 33,
	TOMOYO_MAC_NETWORK_UNIX_DGRAM_SEND = 34,
	TOMOYO_MAC_NETWORK_UNIX_SEQPACKET_BIND = 35,
	TOMOYO_MAC_NETWORK_UNIX_SEQPACKET_LISTEN = 36,
	TOMOYO_MAC_NETWORK_UNIX_SEQPACKET_CONNECT = 37,
	TOMOYO_MAC_ENVIRON = 38,
	TOMOYO_MAX_MAC_INDEX = 39,
};

enum tomoyo_mac_category_index {
	TOMOYO_MAC_CATEGORY_FILE = 0,
	TOMOYO_MAC_CATEGORY_NETWORK = 1,
	TOMOYO_MAC_CATEGORY_MISC = 2,
	TOMOYO_MAX_MAC_CATEGORY_INDEX = 3,
};

enum tomoyo_pref_index {
	TOMOYO_PREF_MAX_AUDIT_LOG = 0,
	TOMOYO_PREF_MAX_LEARNING_ENTRY = 1,
	TOMOYO_MAX_PREF = 2,
};

struct tomoyo_shared_acl_head {
	struct list_head list;
	atomic_t users;
} __attribute__((packed));

struct tomoyo_path_info {
	const char *name;
	u32 hash;
	u16 const_len;
	bool is_dir;
	bool is_patterned;
};

struct tomoyo_obj_info;

struct tomoyo_execve;

struct tomoyo_domain_info;

struct tomoyo_acl_info;

struct tomoyo_request_info {
	struct tomoyo_obj_info *obj;
	struct tomoyo_execve *ee;
	struct tomoyo_domain_info *domain;
	union {
		struct {
			const struct tomoyo_path_info *filename;
			const struct tomoyo_path_info *matched_path;
			u8 operation;
		} path;
		struct {
			const struct tomoyo_path_info *filename1;
			const struct tomoyo_path_info *filename2;
			u8 operation;
		} path2;
		struct {
			const struct tomoyo_path_info *filename;
			unsigned int mode;
			unsigned int major;
			unsigned int minor;
			u8 operation;
		} mkdev;
		struct {
			const struct tomoyo_path_info *filename;
			long unsigned int number;
			u8 operation;
		} path_number;
		struct {
			const struct tomoyo_path_info *name;
		} environ;
		struct {
			const __be32 *address;
			u16 port;
			u8 protocol;
			u8 operation;
			bool is_ipv6;
		} inet_network;
		struct {
			const struct tomoyo_path_info *address;
			u8 protocol;
			u8 operation;
		} unix_network;
		struct {
			const struct tomoyo_path_info *type;
			const struct tomoyo_path_info *dir;
			const struct tomoyo_path_info *dev;
			long unsigned int flags;
			int need_dev;
		} mount;
		struct {
			const struct tomoyo_path_info *domainname;
		} task;
	} param;
	struct tomoyo_acl_info *matched_acl;
	u8 param_type;
	bool granted;
	u8 retry;
	u8 profile;
	u8 mode;
	u8 type;
};

struct tomoyo_mini_stat {
	kuid_t uid;
	kgid_t gid;
	ino_t ino;
	umode_t mode;
	dev_t dev;
	dev_t rdev;
};

struct tomoyo_obj_info {
	bool validate_done;
	bool stat_valid[4];
	struct path___156 path1;
	struct path___156 path2;
	struct tomoyo_mini_stat stat[4];
	struct tomoyo_path_info *symlink_target;
};

struct tomoyo_page_dump {
	struct page___161 *page;
	char *data;
};

struct tomoyo_execve {
	struct tomoyo_request_info r;
	struct tomoyo_obj_info obj;
	struct linux_binprm___29 *bprm;
	const struct tomoyo_path_info *transition;
	struct tomoyo_page_dump dump;
	char *tmp;
};

struct tomoyo_policy_namespace;

struct tomoyo_domain_info {
	struct list_head list;
	struct list_head acl_info_list;
	const struct tomoyo_path_info *domainname;
	struct tomoyo_policy_namespace *ns;
	long unsigned int group[4];
	u8 profile;
	bool is_deleted;
	bool flags[2];
	atomic_t users;
};

struct tomoyo_condition;

struct tomoyo_acl_info {
	struct list_head list;
	struct tomoyo_condition *cond;
	s8 is_deleted;
	u8 type;
} __attribute__((packed));

struct tomoyo_condition {
	struct tomoyo_shared_acl_head head;
	u32 size;
	u16 condc;
	u16 numbers_count;
	u16 names_count;
	u16 argc;
	u16 envc;
	u8 grant_log;
	const struct tomoyo_path_info *transit;
};

struct tomoyo_profile;

struct tomoyo_policy_namespace {
	struct tomoyo_profile *profile_ptr[256];
	struct list_head group_list[3];
	struct list_head policy_list[11];
	struct list_head acl_group[256];
	struct list_head namespace_list;
	unsigned int profile_version;
	const char *name;
};

struct tomoyo_io_buffer {
	void (*read)(struct tomoyo_io_buffer *);
	int (*write)(struct tomoyo_io_buffer *);
	__poll_t (*poll)(struct file___156 *, poll_table___29 *);
	struct mutex io_sem;
	char *read_user_buf;
	size_t read_user_buf_avail;
	struct {
		struct list_head *ns;
		struct list_head *domain;
		struct list_head *group;
		struct list_head *acl;
		size_t avail;
		unsigned int step;
		unsigned int query_index;
		u16 index;
		u16 cond_index;
		u8 acl_group_index;
		u8 cond_step;
		u8 bit;
		u8 w_pos;
		bool eof;
		bool print_this_domain_only;
		bool print_transition_related_only;
		bool print_cond_part;
		const char *w[64];
	} r;
	struct {
		struct tomoyo_policy_namespace *ns;
		struct tomoyo_domain_info *domain;
		size_t avail;
		bool is_delete;
	} w;
	char *read_buf;
	size_t readbuf_size;
	char *write_buf;
	size_t writebuf_size;
	enum tomoyo_securityfs_interface_index type;
	u8 users;
	struct list_head list;
};

struct tomoyo_preference {
	unsigned int learning_max_entry;
	bool enforcing_verbose;
	bool learning_verbose;
	bool permissive_verbose;
};

struct tomoyo_profile {
	const struct tomoyo_path_info *comment;
	struct tomoyo_preference *learning;
	struct tomoyo_preference *permissive;
	struct tomoyo_preference *enforcing;
	struct tomoyo_preference preference;
	u8 default_config;
	u8 config[42];
	unsigned int pref[2];
};

struct tomoyo_time {
	u16 year;
	u8 month;
	u8 day;
	u8 hour;
	u8 min;
	u8 sec;
};

struct tomoyo_log {
	struct list_head list;
	char *log;
	int size;
};

enum tomoyo_value_type {
	TOMOYO_VALUE_TYPE_INVALID = 0,
	TOMOYO_VALUE_TYPE_DECIMAL = 1,
	TOMOYO_VALUE_TYPE_OCTAL = 2,
	TOMOYO_VALUE_TYPE_HEXADECIMAL = 3,
};

enum tomoyo_transition_type {
	TOMOYO_TRANSITION_CONTROL_NO_RESET = 0,
	TOMOYO_TRANSITION_CONTROL_RESET = 1,
	TOMOYO_TRANSITION_CONTROL_NO_INITIALIZE = 2,
	TOMOYO_TRANSITION_CONTROL_INITIALIZE = 3,
	TOMOYO_TRANSITION_CONTROL_NO_KEEP = 4,
	TOMOYO_TRANSITION_CONTROL_KEEP = 5,
	TOMOYO_MAX_TRANSITION_TYPE = 6,
};

enum tomoyo_acl_entry_type_index {
	TOMOYO_TYPE_PATH_ACL = 0,
	TOMOYO_TYPE_PATH2_ACL = 1,
	TOMOYO_TYPE_PATH_NUMBER_ACL = 2,
	TOMOYO_TYPE_MKDEV_ACL = 3,
	TOMOYO_TYPE_MOUNT_ACL = 4,
	TOMOYO_TYPE_INET_ACL = 5,
	TOMOYO_TYPE_UNIX_ACL = 6,
	TOMOYO_TYPE_ENV_ACL = 7,
	TOMOYO_TYPE_MANUAL_TASK_ACL = 8,
};

enum tomoyo_policy_stat_type {
	TOMOYO_STAT_POLICY_UPDATES = 0,
	TOMOYO_STAT_POLICY_LEARNING = 1,
	TOMOYO_STAT_POLICY_PERMISSIVE = 2,
	TOMOYO_STAT_POLICY_ENFORCING = 3,
	TOMOYO_MAX_POLICY_STAT = 4,
};

struct tomoyo_acl_head {
	struct list_head list;
	s8 is_deleted;
} __attribute__((packed));

struct tomoyo_name {
	struct tomoyo_shared_acl_head head;
	struct tomoyo_path_info entry;
};

struct tomoyo_group;

struct tomoyo_name_union {
	const struct tomoyo_path_info *filename;
	struct tomoyo_group *group;
};

struct tomoyo_group {
	struct tomoyo_shared_acl_head head;
	const struct tomoyo_path_info *group_name;
	struct list_head member_list;
};

struct tomoyo_number_union {
	long unsigned int values[2];
	struct tomoyo_group *group;
	u8 value_type[2];
};

struct tomoyo_ipaddr_union {
	struct in6_addr ip[2];
	struct tomoyo_group *group;
	bool is_ipv6;
};

struct tomoyo_path_group {
	struct tomoyo_acl_head head;
	const struct tomoyo_path_info *member_name;
};

struct tomoyo_number_group {
	struct tomoyo_acl_head head;
	struct tomoyo_number_union number;
};

struct tomoyo_address_group {
	struct tomoyo_acl_head head;
	struct tomoyo_ipaddr_union address;
};

struct tomoyo_argv {
	long unsigned int index;
	const struct tomoyo_path_info *value;
	bool is_not;
};

struct tomoyo_envp {
	const struct tomoyo_path_info *name;
	const struct tomoyo_path_info *value;
	bool is_not;
};

struct tomoyo_condition_element {
	u8 left;
	u8 right;
	bool equals;
};

struct tomoyo_task_acl {
	struct tomoyo_acl_info head;
	const struct tomoyo_path_info *domainname;
};

struct tomoyo_path_acl {
	struct tomoyo_acl_info head;
	u16 perm;
	struct tomoyo_name_union name;
};

struct tomoyo_path_number_acl {
	struct tomoyo_acl_info head;
	u8 perm;
	struct tomoyo_name_union name;
	struct tomoyo_number_union number;
};

struct tomoyo_mkdev_acl {
	struct tomoyo_acl_info head;
	u8 perm;
	struct tomoyo_name_union name;
	struct tomoyo_number_union mode;
	struct tomoyo_number_union major;
	struct tomoyo_number_union minor;
};

struct tomoyo_path2_acl {
	struct tomoyo_acl_info head;
	u8 perm;
	struct tomoyo_name_union name1;
	struct tomoyo_name_union name2;
};

struct tomoyo_mount_acl {
	struct tomoyo_acl_info head;
	struct tomoyo_name_union dev_name;
	struct tomoyo_name_union dir_name;
	struct tomoyo_name_union fs_type;
	struct tomoyo_number_union flags;
};

struct tomoyo_env_acl {
	struct tomoyo_acl_info head;
	const struct tomoyo_path_info *env;
};

struct tomoyo_inet_acl {
	struct tomoyo_acl_info head;
	u8 protocol;
	u8 perm;
	struct tomoyo_ipaddr_union address;
	struct tomoyo_number_union port;
};

struct tomoyo_unix_acl {
	struct tomoyo_acl_info head;
	u8 protocol;
	u8 perm;
	struct tomoyo_name_union name;
};

struct tomoyo_acl_param {
	char *data;
	struct list_head *list;
	struct tomoyo_policy_namespace *ns;
	bool is_delete;
};

struct tomoyo_transition_control {
	struct tomoyo_acl_head head;
	u8 type;
	bool is_last_name;
	const struct tomoyo_path_info *domainname;
	const struct tomoyo_path_info *program;
};

struct tomoyo_aggregator {
	struct tomoyo_acl_head head;
	const struct tomoyo_path_info *original_name;
	const struct tomoyo_path_info *aggregated_name;
};

struct tomoyo_manager {
	struct tomoyo_acl_head head;
	const struct tomoyo_path_info *manager;
};

struct tomoyo_task {
	struct tomoyo_domain_info *domain_info;
	struct tomoyo_domain_info *old_domain_info;
};

struct tomoyo_query {
	struct list_head list;
	struct tomoyo_domain_info *domain;
	char *query;
	size_t query_len;
	unsigned int serial;
	u8 timer;
	u8 answer;
	u8 retry;
};

struct list_head___2 {
	struct list_head___2 *next;
	struct list_head___2 *prev;
};

struct in6_addr___2 {
	union {
		__u8 u6_addr8[16];
		__be16 u6_addr16[8];
		__be32 u6_addr32[4];
	} in6_u;
};

struct tomoyo_acl_head___2 {
	struct list_head___2 list;
	long: 64;
	long: 64;
	s8 is_deleted;
} __attribute__((packed));

struct tomoyo_shared_acl_head___2 {
	struct list_head___2 list;
	long: 64;
	long: 64;
	atomic_t users;
} __attribute__((packed));

struct tomoyo_name___2 {
	struct tomoyo_shared_acl_head___2 head;
	struct tomoyo_path_info entry;
};

struct tomoyo_group___2 {
	struct tomoyo_shared_acl_head___2 head;
	const struct tomoyo_path_info *group_name;
	struct list_head___2 member_list;
	long: 64;
	long: 64;
};

struct tomoyo_number_union___2 {
	long unsigned int values[2];
	struct tomoyo_group___2 *group;
	u8 value_type[2];
};

struct tomoyo_ipaddr_union___2 {
	struct in6_addr___2 ip[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct tomoyo_group___2 *group;
	bool is_ipv6;
};

struct tomoyo_path_group___2 {
	struct tomoyo_acl_head___2 head;
	const struct tomoyo_path_info *member_name;
};

struct tomoyo_number_group___2 {
	struct tomoyo_acl_head___2 head;
	struct tomoyo_number_union___2 number;
};

struct tomoyo_address_group___2 {
	struct tomoyo_acl_head___2 head;
	struct tomoyo_ipaddr_union___2 address;
};

struct tomoyo_policy_namespace___2 {
	struct tomoyo_profile *profile_ptr[256];
	struct list_head___2 group_list[3];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head___2 policy_list[11];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head___2 acl_group[256];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head___2 namespace_list;
	long: 64;
	long: 64;
	unsigned int profile_version;
	const char *name;
};

struct tomoyo_acl_param___2 {
	char *data;
	struct list_head___2 *list;
	struct tomoyo_policy_namespace___2 *ns;
	bool is_delete;
};

enum tomoyo_special_mount {
	TOMOYO_MOUNT_BIND = 0,
	TOMOYO_MOUNT_MOVE = 1,
	TOMOYO_MOUNT_REMOUNT = 2,
	TOMOYO_MOUNT_MAKE_UNBINDABLE = 3,
	TOMOYO_MOUNT_MAKE_PRIVATE = 4,
	TOMOYO_MOUNT_MAKE_SLAVE = 5,
	TOMOYO_MOUNT_MAKE_SHARED = 6,
	TOMOYO_MAX_SPECIAL_MOUNT = 7,
};

struct tomoyo_inet_addr_info {
	__be16 port;
	const __be32 *address;
	bool is_ipv6;
};

struct tomoyo_unix_addr_info {
	u8 *addr;
	unsigned int addr_len;
};

struct tomoyo_addr_info {
	u8 protocol;
	u8 operation;
	struct tomoyo_inet_addr_info inet;
	struct tomoyo_unix_addr_info unix0;
};

struct proc_fs_info___7 {
	struct pid_namespace___137 *pid_ns;
	struct dentry___156 *proc_self;
	struct dentry___156 *proc_thread_self;
	kgid_t pid_gid;
	enum proc_hidepid hide_pid;
	enum proc_pidonly pidonly;
};

struct vfsmount___161;

struct dentry___161;

struct path___161 {
	struct vfsmount___161 *mnt;
	struct dentry___161 *dentry;
};

struct pid___142;

struct fown_struct___142 {
	rwlock_t lock;
	struct pid___142 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___161;

struct file_operations___161;

struct address_space___161;

struct file___161 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___161 f_path;
	struct inode___161 *f_inode;
	const struct file_operations___161 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___142 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___161 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct fs_context___30;

struct super_block___161;

struct module___145;

struct file_system_type___161 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___30 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___161 * (*mount)(struct file_system_type___161 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___161 *);
	struct module___145 *owner;
	struct file_system_type___161 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___161;

struct iov_iter___90;

struct poll_table_struct___102;

struct vm_area_struct___166;

struct file_lock___161;

struct page___166;

struct pipe_inode_info___54;

struct seq_file___139;

struct file_operations___161 {
	struct module___145 *owner;
	loff_t (*llseek)(struct file___161 *, loff_t, int);
	ssize_t (*read)(struct file___161 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___161 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___161 *, struct iov_iter___90 *);
	ssize_t (*write_iter)(struct kiocb___161 *, struct iov_iter___90 *);
	int (*iopoll)(struct kiocb___161 *, bool);
	int (*iterate)(struct file___161 *, struct dir_context *);
	int (*iterate_shared)(struct file___161 *, struct dir_context *);
	__poll_t (*poll)(struct file___161 *, struct poll_table_struct___102 *);
	long int (*unlocked_ioctl)(struct file___161 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___161 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___161 *, struct vm_area_struct___166 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___161 *, struct file___161 *);
	int (*flush)(struct file___161 *, fl_owner_t);
	int (*release)(struct inode___161 *, struct file___161 *);
	int (*fsync)(struct file___161 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___161 *, int);
	int (*lock)(struct file___161 *, int, struct file_lock___161 *);
	ssize_t (*sendpage)(struct file___161 *, struct page___166 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___161 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___161 *, long unsigned int);
	int (*flock)(struct file___161 *, int, struct file_lock___161 *);
	ssize_t (*splice_write)(struct pipe_inode_info___54 *, struct file___161 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___161 *, loff_t *, struct pipe_inode_info___54 *, size_t, unsigned int);
	int (*setlease)(struct file___161 *, long int, struct file_lock___161 **, void **);
	long int (*fallocate)(struct file___161 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___139 *, struct file___161 *);
	ssize_t (*copy_file_range)(struct file___161 *, loff_t, struct file___161 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___161 *, loff_t, struct file___161 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___161 *, loff_t, loff_t, int);
};

struct vmacache___166 {
	u64 seqnum;
	struct vm_area_struct___166 *vmas[4];
};

struct page_frag___166 {
	struct page___166 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___167;

struct nsproxy___151;

struct signal_struct___162;

struct bio_list___74;

struct backing_dev_info___71;

struct io_context___74;

struct css_set___110;

struct mem_cgroup___62;

struct request_queue___74;

struct vm_struct___145;

struct task_struct___168 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___168 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___167 *mm;
	struct mm_struct___167 *active_mm;
	struct vmacache___166 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___168 *real_parent;
	struct task_struct___168 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___168 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___142 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___151 *nsproxy;
	struct signal_struct___162 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___168 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___74 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___71 *backing_dev_info;
	struct io_context___74 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___110 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___54 *splice_pipe;
	struct page_frag___166 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___62 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___62 *active_memcg;
	struct request_queue___74 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___168 *oom_reaper_list;
	struct vm_struct___145 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___148;

struct kobj_type___148;

struct kernfs_node___148;

struct kobject___148 {
	const char *name;
	struct list_head entry;
	struct kobject___148 *parent;
	struct kset___148 *kset;
	struct kobj_type___148 *ktype;
	struct kernfs_node___148 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___145 {
	struct kobject___148 kobj;
	struct module___145 *mod;
	struct kobject___148 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___145 {
	struct module___145 *mod;
	struct latch_tree_node node;
};

struct module_layout___145 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___145 mtn;
};

struct module_attribute___145;

struct kernel_param___145;

struct module___145 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___145 mkobj;
	struct module_attribute___145 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___148 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___145 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___145 core_layout;
	struct module_layout___145 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___161;

struct dentry___161 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___161 *d_parent;
	struct qstr d_name;
	struct inode___161 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___161 *d_op;
	struct super_block___161 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___161;

struct address_space___161 {
	struct inode___161 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___161 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___161;

struct bdi_writeback___71;

struct inode___161 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___161 *i_op;
	struct super_block___161 *i_sb;
	struct address_space___161 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___71 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___161 *i_fop;
		void (*free_inode)(struct inode___161 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___161 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___54 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___161 {
	int (*d_revalidate)(struct dentry___161 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___161 *, unsigned int);
	int (*d_hash)(const struct dentry___161 *, struct qstr *);
	int (*d_compare)(const struct dentry___161 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___161 *);
	int (*d_init)(struct dentry___161 *);
	void (*d_release)(struct dentry___161 *);
	void (*d_prune)(struct dentry___161 *);
	void (*d_iput)(struct dentry___161 *, struct inode___161 *);
	char * (*d_dname)(struct dentry___161 *, char *, int);
	struct vfsmount___161 * (*d_automount)(struct path___161 *);
	int (*d_manage)(const struct path___161 *, bool);
	struct dentry___161 * (*d_real)(struct dentry___161 *, const struct inode___161 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___161;

struct mem_dqinfo___161 {
	struct quota_format_type___161 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___161;

struct quota_info___161 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___161 *files[3];
	struct mem_dqinfo___161 info[3];
	const struct quota_format_ops___161 *ops[3];
};

struct rcuwait___162 {
	struct task_struct___168 *task;
};

struct percpu_rw_semaphore___162 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___162 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___161 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___162 rw_sem[3];
};

struct shrink_control___62;

struct shrinker___62 {
	long unsigned int (*count_objects)(struct shrinker___62 *, struct shrink_control___62 *);
	long unsigned int (*scan_objects)(struct shrinker___62 *, struct shrink_control___62 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___161;

struct dquot_operations___161;

struct quotactl_ops___161;

struct block_device___75;

struct super_block___161 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___161 *s_type;
	const struct super_operations___161 *s_op;
	const struct dquot_operations___161 *dq_op;
	const struct quotactl_ops___161 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___161 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___75 *s_bdev;
	struct backing_dev_info___71 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___161 s_dquot;
	struct sb_writers___161 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___161 *s_d_op;
	int cleancache_poolid;
	struct shrinker___62 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___161 {
	struct dentry___161 *mnt_root;
	struct super_block___161 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct pid_namespace___142;

struct upid___142 {
	int nr;
	struct pid_namespace___142 *ns;
};

struct pid_namespace___142 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___168 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___142 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___142 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___142 numbers[1];
};

typedef struct page___166 *pgtable_t___166;

struct page_pool___45;

struct dev_pagemap___157;

struct page___166 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___161 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___45 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___166 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___166 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___167 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___157 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___157;

struct vm_area_struct___166 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___166 *vm_next;
	struct vm_area_struct___166 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___167 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___157 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___161 *vm_file;
	struct file___161 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___162 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___168 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___168 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___142 *pids[4];
	struct pid___142 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___167 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___31;

struct core_state___166;

struct mm_struct___167 {
	struct {
		struct vm_area_struct___166 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___161 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___31 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___166 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___168 *owner;
		struct user_namespace___24 *user_ns;
		struct file___161 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___34;

struct cgroup_namespace___110;

struct nsproxy___151 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___142 *pid_ns_for_children;
	struct net___34 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___110 *cgroup_ns;
};

struct bio___74;

struct bio_list___74 {
	struct bio___74 *head;
	struct bio___74 *tail;
};

struct cgroup_subsys_state___110;

struct bdi_writeback___71 {
	struct backing_dev_info___71 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___110 *memcg_css;
	struct cgroup_subsys_state___110 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___117;

struct backing_dev_info___71 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___71 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___117 *dev;
	char dev_name[64];
	struct device___117 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___161 *debug_dir;
};

struct io_cq___74;

struct io_context___74 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___74 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___110;

struct css_set___110 {
	struct cgroup_subsys_state___110 *subsys[14];
	refcount_t refcount;
	struct css_set___110 *dom_cset;
	struct cgroup___110 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___110 *mg_src_cgrp;
	struct cgroup___110 *mg_dst_cgrp;
	struct css_set___110 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___161;

struct pipe_buffer___54;

struct pipe_inode_info___54 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___166 *tmp_page;
	struct fasync_struct___161 *fasync_readers;
	struct fasync_struct___161 *fasync_writers;
	struct pipe_buffer___54 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___110;

struct cgroup_subsys_state___110 {
	struct cgroup___110 *cgroup;
	struct cgroup_subsys___110 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___110 *parent;
};

struct cgroup_file___110 {
	struct kernfs_node___148 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___62;

struct mem_cgroup_per_node___62;

struct mem_cgroup___62 {
	struct cgroup_subsys_state___110 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___110 events_file;
	struct cgroup_file___110 events_local_file;
	struct cgroup_file___110 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___62 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___168 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___62 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___74;

struct blk_integrity___74 {
	const struct blk_integrity_profile___74 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___74 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___74 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___74;

struct elevator_queue___74;

struct blk_mq_ops___71;

struct blk_mq_hw_ctx___71;

struct gendisk___74;

struct blkcg_gq___71;

struct blk_mq_tag_set___71;

struct request_queue___74 {
	struct request___74 *last_merge;
	struct elevator_queue___74 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___71 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___71 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___74 *disk;
	struct kobject___148 kobj;
	struct kobject___148 *mq_kobj;
	struct blk_integrity___74 integrity;
	struct device___117 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___71 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___71 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___74 bio_split;
	struct dentry___161 *debugfs_dir;
	struct dentry___161 *sched_debugfs_dir;
	struct dentry___161 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___145 {
	struct vm_struct___145 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___166 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___62 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___62 *memcg;
};

struct page_pool_params___45 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___117 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___45 {
	u32 count;
	struct page___166 *cache[128];
};

struct page_pool___45 {
	struct page_pool_params___45 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___166 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___45 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___157;

struct dev_pagemap___157 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___157 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___157;

struct vm_operations_struct___157 {
	void (*open)(struct vm_area_struct___166 *);
	void (*close)(struct vm_area_struct___166 *);
	int (*may_split)(struct vm_area_struct___166 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___166 *);
	int (*mprotect)(struct vm_area_struct___166 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___157 *);
	vm_fault_t (*huge_fault)(struct vm_fault___157 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___157 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___166 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___157 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___157 *);
	int (*access)(struct vm_area_struct___166 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___166 *);
	int (*set_policy)(struct vm_area_struct___166 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___166 *, long unsigned int);
	struct page___166 * (*find_special_page)(struct vm_area_struct___166 *, long unsigned int);
};

struct core_thread___166 {
	struct task_struct___168 *task;
	struct core_thread___166 *next;
};

struct core_state___166 {
	atomic_t nr_threads;
	struct core_thread___166 dumper;
	struct completion startup;
};

struct linux_binprm___32;

struct coredump_params___31;

struct linux_binfmt___31 {
	struct list_head lh;
	struct module___145 *module;
	int (*load_binary)(struct linux_binprm___32 *);
	int (*load_shlib)(struct file___161 *);
	int (*core_dump)(struct coredump_params___31 *);
	long unsigned int min_coredump;
};

struct vm_fault___157 {
	const struct {
		struct vm_area_struct___166 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___166 *cow_page;
	struct page___166 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___166 prealloc_pte;
};

struct pglist_data___69;

struct lruvec___69 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___69 *pgdat;
};

struct zone___69 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___69 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___69 {
	struct zone___69 *zone;
	int zone_idx;
};

struct zonelist___69 {
	struct zoneref___69 _zonerefs[321];
};

struct pglist_data___69 {
	struct zone___69 node_zones[5];
	struct zonelist___69 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___168 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___168 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___69 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___110 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___168 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___29;

struct cgroup_bpf___29 {
	struct bpf_prog_array___29 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___29 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___110;

struct cgroup_rstat_cpu___110;

struct cgroup___110 {
	struct cgroup_subsys_state___110 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___148 *kn;
	struct cgroup_file___110 procs_file;
	struct cgroup_file___110 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___110 *subsys[14];
	struct cgroup_root___110 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___110 *dom_cgrp;
	struct cgroup___110 *old_dom_cgrp;
	struct cgroup_rstat_cpu___110 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___110 psi;
	struct cgroup_bpf___29 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___74 {
	struct request_queue___74 *q;
	struct io_context___74 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___161 {
	struct file___161 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___161 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___161 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___161 *ia_file;
};

struct dquot___161 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___161 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___161 {
	int qf_fmt_id;
	const struct quota_format_ops___161 *qf_ops;
	struct module___145 *qf_owner;
	struct quota_format_type___161 *qf_next;
};

struct quota_format_ops___161 {
	int (*check_quota_file)(struct super_block___161 *, int);
	int (*read_file_info)(struct super_block___161 *, int);
	int (*write_file_info)(struct super_block___161 *, int);
	int (*free_file_info)(struct super_block___161 *, int);
	int (*read_dqblk)(struct dquot___161 *);
	int (*commit_dqblk)(struct dquot___161 *);
	int (*release_dqblk)(struct dquot___161 *);
	int (*get_next_id)(struct super_block___161 *, struct kqid *);
};

struct dquot_operations___161 {
	int (*write_dquot)(struct dquot___161 *);
	struct dquot___161 * (*alloc_dquot)(struct super_block___161 *, int);
	void (*destroy_dquot)(struct dquot___161 *);
	int (*acquire_dquot)(struct dquot___161 *);
	int (*release_dquot)(struct dquot___161 *);
	int (*mark_dirty)(struct dquot___161 *);
	int (*write_info)(struct super_block___161 *, int);
	qsize_t * (*get_reserved_space)(struct inode___161 *);
	int (*get_projid)(struct inode___161 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___161 *, qsize_t *);
	int (*get_next_id)(struct super_block___161 *, struct kqid *);
};

struct quotactl_ops___161 {
	int (*quota_on)(struct super_block___161 *, int, int, const struct path___161 *);
	int (*quota_off)(struct super_block___161 *, int);
	int (*quota_enable)(struct super_block___161 *, unsigned int);
	int (*quota_disable)(struct super_block___161 *, unsigned int);
	int (*quota_sync)(struct super_block___161 *, int);
	int (*set_info)(struct super_block___161 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___161 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___161 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___161 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___161 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___161 *, unsigned int);
};

struct writeback_control___71;

struct address_space_operations___161 {
	int (*writepage)(struct page___166 *, struct writeback_control___71 *);
	int (*readpage)(struct file___161 *, struct page___166 *);
	int (*writepages)(struct address_space___161 *, struct writeback_control___71 *);
	int (*set_page_dirty)(struct page___166 *);
	int (*readpages)(struct file___161 *, struct address_space___161 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___161 *, struct address_space___161 *, loff_t, unsigned int, unsigned int, struct page___166 **, void **);
	int (*write_end)(struct file___161 *, struct address_space___161 *, loff_t, unsigned int, unsigned int, struct page___166 *, void *);
	sector_t (*bmap)(struct address_space___161 *, sector_t);
	void (*invalidatepage)(struct page___166 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___166 *, gfp_t);
	void (*freepage)(struct page___166 *);
	ssize_t (*direct_IO)(struct kiocb___161 *, struct iov_iter___90 *);
	int (*migratepage)(struct address_space___161 *, struct page___166 *, struct page___166 *, enum migrate_mode);
	bool (*isolate_page)(struct page___166 *, isolate_mode_t);
	void (*putback_page)(struct page___166 *);
	int (*launder_page)(struct page___166 *);
	int (*is_partially_uptodate)(struct page___166 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___166 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___161 *, struct page___166 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___161 *, sector_t *);
	void (*swap_deactivate)(struct file___161 *);
};

struct writeback_control___71 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___71 *wb;
	struct inode___161 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___88;

struct iov_iter___90 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___88 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___54 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___161 {
	struct dentry___161 * (*lookup)(struct inode___161 *, struct dentry___161 *, unsigned int);
	const char * (*get_link)(struct dentry___161 *, struct inode___161 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___161 *, int);
	struct posix_acl * (*get_acl)(struct inode___161 *, int, bool);
	int (*readlink)(struct dentry___161 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___161 *, struct dentry___161 *, umode_t, bool);
	int (*link)(struct dentry___161 *, struct inode___161 *, struct dentry___161 *);
	int (*unlink)(struct inode___161 *, struct dentry___161 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___161 *, struct dentry___161 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___161 *, struct dentry___161 *, umode_t);
	int (*rmdir)(struct inode___161 *, struct dentry___161 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___161 *, struct dentry___161 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___161 *, struct dentry___161 *, struct inode___161 *, struct dentry___161 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___161 *, struct iattr___161 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___161 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___161 *, char *, size_t);
	int (*fiemap)(struct inode___161 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___161 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___161 *, struct dentry___161 *, struct file___161 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___161 *, struct dentry___161 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___161 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___161 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___161 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___161 {
	void (*fl_copy_lock)(struct file_lock___161 *, struct file_lock___161 *);
	void (*fl_release_private)(struct file_lock___161 *);
};

struct lock_manager_operations___161;

struct file_lock___161 {
	struct file_lock___161 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___161 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___161 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___161 *fl_ops;
	const struct lock_manager_operations___161 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___161 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___161 *);
	int (*lm_grant)(struct file_lock___161 *, int);
	bool (*lm_break)(struct file_lock___161 *);
	int (*lm_change)(struct file_lock___161 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___161 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___161 *);
};

struct fasync_struct___161 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___161 *fa_next;
	struct file___161 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___161 {
	struct inode___161 * (*alloc_inode)(struct super_block___161 *);
	void (*destroy_inode)(struct inode___161 *);
	void (*free_inode)(struct inode___161 *);
	void (*dirty_inode)(struct inode___161 *, int);
	int (*write_inode)(struct inode___161 *, struct writeback_control___71 *);
	int (*drop_inode)(struct inode___161 *);
	void (*evict_inode)(struct inode___161 *);
	void (*put_super)(struct super_block___161 *);
	int (*sync_fs)(struct super_block___161 *, int);
	int (*freeze_super)(struct super_block___161 *);
	int (*freeze_fs)(struct super_block___161 *);
	int (*thaw_super)(struct super_block___161 *);
	int (*unfreeze_fs)(struct super_block___161 *);
	int (*statfs)(struct dentry___161 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___161 *, int *, char *);
	void (*umount_begin)(struct super_block___161 *);
	int (*show_options)(struct seq_file___139 *, struct dentry___161 *);
	int (*show_devname)(struct seq_file___139 *, struct dentry___161 *);
	int (*show_path)(struct seq_file___139 *, struct dentry___161 *);
	int (*show_stats)(struct seq_file___139 *, struct dentry___161 *);
	ssize_t (*quota_read)(struct super_block___161 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___161 *, int, const char *, size_t, loff_t);
	struct dquot___161 ** (*get_dquots)(struct inode___161 *);
	long int (*nr_cached_objects)(struct super_block___161 *, struct shrink_control___62 *);
	long int (*free_cached_objects)(struct super_block___161 *, struct shrink_control___62 *);
	struct file___161 * (*real_loop)(struct file___161 *);
};

struct wakeup_source___117;

struct dev_pm_info___117 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___117 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___117 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___117;

struct bus_type___117;

struct device_driver___117;

struct dev_pm_domain___117;

struct fwnode_handle___117;

struct class___117;

struct attribute_group___148;

struct device___117 {
	struct kobject___148 kobj;
	struct device___117 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___117 *type;
	struct bus_type___117 *bus;
	struct device_driver___117 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___117 power;
	struct dev_pm_domain___117 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___117 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___117 *class;
	const struct attribute_group___148 **groups;
	void (*release)(struct device___117 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___75 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___161 *bd_inode;
	struct super_block___161 *bd_super;
	void *bd_claiming;
	struct device___117 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___148 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___74 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___161 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___104)(struct file___161 *, wait_queue_head_t *, struct poll_table_struct___102 *);

struct poll_table_struct___102 {
	poll_queue_proc___104 _qproc;
	__poll_t _key;
};

struct seq_operations___139;

struct seq_file___139 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___139 *op;
	int poll_event;
	const struct file___161 *file;
	void *private;
};

struct fc_log___30;

struct p_log___30 {
	const char *prefix;
	struct fc_log___30 *log;
};

struct fs_context_operations___30;

struct fs_context___30 {
	const struct fs_context_operations___30 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___161 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___161 *root;
	struct user_namespace___24 *user_ns;
	struct net___34 *net_ns;
	const struct cred___27 *cred;
	struct p_log___30 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___74(struct bio___74 *);

struct bio_vec___88 {
	struct page___166 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___74;

struct bio___74 {
	struct bio___74 *bi_next;
	struct block_device___75 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___74 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___71 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___74 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___88 *bi_io_vec;
	struct bio_set___74 *bi_pool;
	struct bio_vec___88 bi_inline_vecs[0];
};

struct tree_descr___7 {
	const char *name;
	const struct file_operations___161 *ops;
	int mode;
};

struct dev_pagemap_ops___157 {
	void (*page_free)(struct page___166 *);
	void (*kill)(struct dev_pagemap___157 *);
	void (*cleanup)(struct dev_pagemap___157 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___157 *);
};

struct seq_operations___139 {
	void * (*start)(struct seq_file___139 *, loff_t *);
	void (*stop)(struct seq_file___139 *, void *);
	void * (*next)(struct seq_file___139 *, void *, loff_t *);
	int (*show)(struct seq_file___139 *, void *);
};

struct fs_parameter___30 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___161 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___30 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___145 *owner;
	char *buffer[8];
};

struct fs_context_operations___30 {
	void (*free)(struct fs_context___30 *);
	int (*dup)(struct fs_context___30 *, struct fs_context___30 *);
	int (*parse_param)(struct fs_context___30 *, struct fs_parameter___30 *);
	int (*parse_monolithic)(struct fs_context___30 *, void *);
	int (*get_tree)(struct fs_context___30 *);
	int (*reconfigure)(struct fs_context___30 *);
};

struct ip_ra_chain___9;

struct fib_rules_ops___22;

struct sock___23;

struct fqdir___34;

struct fib_notifier_ops___22;

struct netns_ipv4___34 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___9 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___22 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___23 *fibnl;
	struct sock___23 **icmp_sk;
	struct sock___23 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___23 **tcp_sk;
	struct fqdir___34 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___22 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___22 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___22 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___22;

struct net_device___31;

struct sk_buff___30;

struct neighbour___22;

struct dst_ops___34 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___34 *);
	struct dst_entry___22 * (*check)(struct dst_entry___22 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___22 *);
	unsigned int (*mtu)(const struct dst_entry___22 *);
	u32 * (*cow_metrics)(struct dst_entry___22 *, long unsigned int);
	void (*destroy)(struct dst_entry___22 *);
	void (*ifdown)(struct dst_entry___22 *, struct net_device___31 *, int);
	struct dst_entry___22 * (*negative_advice)(struct dst_entry___22 *);
	void (*link_failure)(struct sk_buff___30 *);
	void (*update_pmtu)(struct dst_entry___22 *, struct sock___23 *, struct sk_buff___30 *, u32, bool);
	void (*redirect)(struct dst_entry___22 *, struct sock___23 *, struct sk_buff___30 *);
	int (*local_out)(struct net___34 *, struct sock___23 *, struct sk_buff___30 *);
	struct neighbour___22 * (*neigh_lookup)(const struct dst_entry___22 *, struct sk_buff___30 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___22 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___34 {
	struct dst_ops___34 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___34 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___22 *fib6_rules_ops;
	struct sock___23 **icmp_sk;
	struct sock___23 *ndisc_sk;
	struct sock___23 *tcp_sk;
	struct sock___23 *igmp_sk;
	struct sock___23 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___22 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___22 *notifier_ops;
	struct fib_notifier_ops___22 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___34 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___34 *fqdir;
};

struct netns_sctp___22 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___23 *ctl_sock;
	struct sock___23 *udp4_sock;
	struct sock___23 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___29 {
	struct sk_buff___30 *next;
	struct sk_buff___30 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___29;

struct netns_bpf___29 {
	struct bpf_prog_array___29 *run_array[2];
	struct bpf_prog___29 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___34 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___23 *nlsk;
	struct sock___23 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___34 xfrm4_dst_ops;
	struct dst_ops___34 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___34 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___23 *rtnl;
	struct sock___23 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___31 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___34 ipv4;
	struct netns_ipv6___34 ipv6;
	struct netns_ieee802154_lowpan___34 ieee802154_lowpan;
	struct netns_sctp___22 sctp;
	struct netns_nf___2 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___29 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___29 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___34 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___23 *crypto_nlsk;
	struct sock___23 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

typedef struct poll_table_struct___102 poll_table___30;

enum audit_mode {
	AUDIT_NORMAL = 0,
	AUDIT_QUIET_DENIED = 1,
	AUDIT_QUIET = 2,
	AUDIT_NOQUIET = 3,
	AUDIT_ALL = 4,
};

enum aa_sfs_type {
	AA_SFS_TYPE_BOOLEAN = 0,
	AA_SFS_TYPE_STRING = 1,
	AA_SFS_TYPE_U64 = 2,
	AA_SFS_TYPE_FOPS = 3,
	AA_SFS_TYPE_DIR = 4,
};

struct aa_sfs_entry {
	const char *name;
	struct dentry___161 *dentry;
	umode_t mode;
	enum aa_sfs_type v_type;
	union {
		bool boolean;
		char *string;
		long unsigned int u64;
		struct aa_sfs_entry *files;
	} v;
	const struct file_operations___161 *file_ops;
};

enum aafs_ns_type {
	AAFS_NS_DIR = 0,
	AAFS_NS_PROFS = 1,
	AAFS_NS_NS = 2,
	AAFS_NS_RAW_DATA = 3,
	AAFS_NS_LOAD = 4,
	AAFS_NS_REPLACE = 5,
	AAFS_NS_REMOVE = 6,
	AAFS_NS_REVISION = 7,
	AAFS_NS_COUNT = 8,
	AAFS_NS_MAX_COUNT = 9,
	AAFS_NS_SIZE = 10,
	AAFS_NS_MAX_SIZE = 11,
	AAFS_NS_OWNER = 12,
	AAFS_NS_SIZEOF = 13,
};

enum aafs_prof_type {
	AAFS_PROF_DIR = 0,
	AAFS_PROF_PROFS = 1,
	AAFS_PROF_NAME = 2,
	AAFS_PROF_MODE = 3,
	AAFS_PROF_ATTACH = 4,
	AAFS_PROF_HASH = 5,
	AAFS_PROF_RAW_DATA = 6,
	AAFS_PROF_RAW_HASH = 7,
	AAFS_PROF_RAW_ABI = 8,
	AAFS_PROF_SIZEOF = 9,
};

struct cgroup_namespace___110 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___110 *root_cset;
};

struct msghdr___23 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___90 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___161 *msg_iocb;
};

struct fwnode_operations___117;

struct fwnode_handle___117 {
	struct fwnode_handle___117 *secondary;
	const struct fwnode_operations___117 *ops;
	struct device___117 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___117;

struct fwnode_endpoint___117;

struct fwnode_operations___117 {
	struct fwnode_handle___117 * (*get)(struct fwnode_handle___117 *);
	void (*put)(struct fwnode_handle___117 *);
	bool (*device_is_available)(const struct fwnode_handle___117 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___117 *, const struct device___117 *);
	bool (*property_present)(const struct fwnode_handle___117 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___117 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___117 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___117 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*get_parent)(const struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*get_next_child_node)(const struct fwnode_handle___117 *, struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*get_named_child_node)(const struct fwnode_handle___117 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___117 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___117 *);
	struct fwnode_handle___117 * (*graph_get_next_endpoint)(const struct fwnode_handle___117 *, struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*graph_get_remote_endpoint)(const struct fwnode_handle___117 *);
	struct fwnode_handle___117 * (*graph_get_port_parent)(struct fwnode_handle___117 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___117 *, struct fwnode_endpoint___117 *);
	int (*add_links)(struct fwnode_handle___117 *);
};

struct fwnode_endpoint___117 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___117 *local_fwnode;
};

struct fwnode_reference_args___117 {
	struct fwnode_handle___117 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___148;

struct kernfs_elem_dir___148 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___148 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___148;

struct kernfs_root___148 {
	struct kernfs_node___148 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___148 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___148 {
	struct kernfs_node___148 *target_kn;
};

struct kernfs_ops___148;

struct kernfs_elem_attr___148 {
	const struct kernfs_ops___148 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___148 *notify_next;
};

struct kernfs_node___148 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___148 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___148 dir;
		struct kernfs_elem_symlink___148 symlink;
		struct kernfs_elem_attr___148 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___148;

struct kernfs_ops___148 {
	int (*open)(struct kernfs_open_file___148 *);
	void (*release)(struct kernfs_open_file___148 *);
	int (*seq_show)(struct seq_file___139 *, void *);
	void * (*seq_start)(struct seq_file___139 *, loff_t *);
	void * (*seq_next)(struct seq_file___139 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___139 *, void *);
	ssize_t (*read)(struct kernfs_open_file___148 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___148 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___148 *, struct poll_table_struct___102 *);
	int (*mmap)(struct kernfs_open_file___148 *, struct vm_area_struct___166 *);
};

struct kernfs_syscall_ops___148 {
	int (*show_options)(struct seq_file___139 *, struct kernfs_root___148 *);
	int (*mkdir)(struct kernfs_node___148 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___148 *);
	int (*rename)(struct kernfs_node___148 *, struct kernfs_node___148 *, const char *);
	int (*show_path)(struct seq_file___139 *, struct kernfs_node___148 *, struct kernfs_root___148 *);
};

struct kernfs_open_file___148 {
	struct kernfs_node___148 *kn;
	struct file___161 *file;
	struct seq_file___139 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___157 *vm_ops;
};

struct kobj_ns_type_operations___22 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___23 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___34 *net;
} possible_net_t___29;

struct proto___22;

struct sock_common___22 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___22 *skc_prot;
	possible_net_t___29 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___23 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___22 {
	struct cgroup___110 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___22;

struct socket_wq___23;

struct socket___23;

struct sock___23 {
	struct sock_common___22 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___29 sk_error_queue;
	struct sk_buff___30 *sk_rx_skb_cache;
	struct sk_buff_head___29 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___30 *head;
		struct sk_buff___30 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___22 *sk_filter;
	union {
		struct socket_wq___23 *sk_wq;
		struct socket_wq___23 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___22 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___22 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___30 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___30 *sk_tx_skb_cache;
	struct sk_buff_head___29 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___166 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___22 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___142 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___23 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___22 sk_cgrp_data;
	struct mem_cgroup___62 *sk_memcg;
	void (*sk_state_change)(struct sock___23 *);
	void (*sk_data_ready)(struct sock___23 *);
	void (*sk_write_space)(struct sock___23 *);
	void (*sk_error_report)(struct sock___23 *);
	int (*sk_backlog_rcv)(struct sock___23 *, struct sk_buff___30 *);
	struct sk_buff___30 * (*sk_validate_xmit_skb)(struct sock___23 *, struct net_device___31 *, struct sk_buff___30 *);
	void (*sk_destruct)(struct sock___23 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___148;

struct attribute_group___148 {
	const char *name;
	umode_t (*is_visible)(struct kobject___148 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___148 *, struct bin_attribute___148 *, int);
	struct attribute **attrs;
	struct bin_attribute___148 **bin_attrs;
};

struct bin_attribute___148 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___161 * (*f_mapping)();
	ssize_t (*read)(struct file___161 *, struct kobject___148 *, struct bin_attribute___148 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___161 *, struct kobject___148 *, struct bin_attribute___148 *, char *, loff_t, size_t);
	int (*mmap)(struct file___161 *, struct kobject___148 *, struct bin_attribute___148 *, struct vm_area_struct___166 *);
};

struct sysfs_ops___148 {
	ssize_t (*show)(struct kobject___148 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___148 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___148;

struct kset___148 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___148 kobj;
	const struct kset_uevent_ops___148 *uevent_ops;
};

struct kobj_type___148 {
	void (*release)(struct kobject___148 *);
	const struct sysfs_ops___148 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___148 **default_groups;
	const struct kobj_ns_type_operations___22 * (*child_ns_type)(struct kobject___148 *);
	const void * (*namespace)(struct kobject___148 *);
	void (*get_ownership)(struct kobject___148 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___148 {
	int (* const filter)(struct kset___148 *, struct kobject___148 *);
	const char * (* const name)(struct kset___148 *, struct kobject___148 *);
	int (* const uevent)(struct kset___148 *, struct kobject___148 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___145 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___145 *);
	int (*get)(char *, const struct kernel_param___145 *);
	void (*free)(void *);
};

struct kparam_array___145;

struct kernel_param___145 {
	const char *name;
	struct module___145 *mod;
	const struct kernel_param_ops___145 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___145 *arr;
	};
};

struct kparam_array___145 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___145 *ops;
	void *elem;
};

struct module_attribute___145 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___145 *, struct module_kobject___145 *, char *);
	ssize_t (*store)(struct module_attribute___145 *, struct module_kobject___145 *, const char *, size_t);
	void (*setup)(struct module___145 *, const char *);
	int (*test)(struct module___145 *);
	void (*free)(struct module___145 *);
};

struct socket_wq___23 {
	wait_queue_head_t wait;
	struct fasync_struct___161 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___23;

struct socket___23 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___161 *file;
	struct sock___23 *sk;
	const struct proto_ops___23 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___23 wq;
};

typedef int (*sk_read_actor_t___22)(read_descriptor_t *, struct sk_buff___30 *, unsigned int, size_t);

struct proto_ops___23 {
	int family;
	struct module___145 *owner;
	int (*release)(struct socket___23 *);
	int (*bind)(struct socket___23 *, struct sockaddr *, int);
	int (*connect)(struct socket___23 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___23 *, struct socket___23 *);
	int (*accept)(struct socket___23 *, struct socket___23 *, int, bool);
	int (*getname)(struct socket___23 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___161 *, struct socket___23 *, struct poll_table_struct___102 *);
	int (*ioctl)(struct socket___23 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___23 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___23 *, void *, bool, bool);
	int (*listen)(struct socket___23 *, int);
	int (*shutdown)(struct socket___23 *, int);
	int (*setsockopt)(struct socket___23 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___23 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___139 *, struct socket___23 *);
	int (*sendmsg)(struct socket___23 *, struct msghdr___23 *, size_t);
	int (*recvmsg)(struct socket___23 *, struct msghdr___23 *, size_t, int);
	int (*mmap)(struct file___161 *, struct socket___23 *, struct vm_area_struct___166 *);
	ssize_t (*sendpage)(struct socket___23 *, struct page___166 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___23 *, loff_t *, struct pipe_inode_info___54 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___23 *, int);
	int (*peek_len)(struct socket___23 *);
	int (*read_sock)(struct sock___23 *, read_descriptor_t *, sk_read_actor_t___22);
	int (*sendpage_locked)(struct sock___23 *, struct page___166 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___23 *, struct msghdr___23 *, size_t);
	int (*set_rcvlowat)(struct sock___23 *, int);
};

struct sk_buff___30 {
	union {
		struct {
			struct sk_buff___30 *next;
			struct sk_buff___30 *prev;
			union {
				struct net_device___31 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___23 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___30 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___117 {
	int (*prepare)(struct device___117 *);
	void (*complete)(struct device___117 *);
	int (*suspend)(struct device___117 *);
	int (*resume)(struct device___117 *);
	int (*freeze)(struct device___117 *);
	int (*thaw)(struct device___117 *);
	int (*poweroff)(struct device___117 *);
	int (*restore)(struct device___117 *);
	int (*suspend_late)(struct device___117 *);
	int (*resume_early)(struct device___117 *);
	int (*freeze_late)(struct device___117 *);
	int (*thaw_early)(struct device___117 *);
	int (*poweroff_late)(struct device___117 *);
	int (*restore_early)(struct device___117 *);
	int (*suspend_noirq)(struct device___117 *);
	int (*resume_noirq)(struct device___117 *);
	int (*freeze_noirq)(struct device___117 *);
	int (*thaw_noirq)(struct device___117 *);
	int (*poweroff_noirq)(struct device___117 *);
	int (*restore_noirq)(struct device___117 *);
	int (*runtime_suspend)(struct device___117 *);
	int (*runtime_resume)(struct device___117 *);
	int (*runtime_idle)(struct device___117 *);
};

struct wakeup_source___117 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___117 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___117 {
	struct dev_pm_ops___117 ops;
	int (*start)(struct device___117 *);
	void (*detach)(struct device___117 *, bool);
	int (*activate)(struct device___117 *);
	void (*sync)(struct device___117 *);
	void (*dismiss)(struct device___117 *);
};

struct bus_type___117 {
	const char *name;
	const char *dev_name;
	struct device___117 *dev_root;
	const struct attribute_group___148 **bus_groups;
	const struct attribute_group___148 **dev_groups;
	const struct attribute_group___148 **drv_groups;
	int (*match)(struct device___117 *, struct device_driver___117 *);
	int (*uevent)(struct device___117 *, struct kobj_uevent_env *);
	int (*probe)(struct device___117 *);
	void (*sync_state)(struct device___117 *);
	void (*remove)(struct device___117 *);
	void (*shutdown)(struct device___117 *);
	int (*online)(struct device___117 *);
	int (*offline)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	int (*num_vf)(struct device___117 *);
	int (*dma_configure)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___117 {
	const char *name;
	struct bus_type___117 *bus;
	struct module___145 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___117 *);
	void (*sync_state)(struct device___117 *);
	int (*remove)(struct device___117 *);
	void (*shutdown)(struct device___117 *);
	int (*suspend)(struct device___117 *, pm_message_t);
	int (*resume)(struct device___117 *);
	const struct attribute_group___148 **groups;
	const struct attribute_group___148 **dev_groups;
	const struct dev_pm_ops___117 *pm;
	void (*coredump)(struct device___117 *);
	struct driver_private *p;
};

struct device_type___117 {
	const char *name;
	const struct attribute_group___148 **groups;
	int (*uevent)(struct device___117 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___117 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___117 *);
	const struct dev_pm_ops___117 *pm;
};

struct class___117 {
	const char *name;
	struct module___145 *owner;
	const struct attribute_group___148 **class_groups;
	const struct attribute_group___148 **dev_groups;
	struct kobject___148 *dev_kobj;
	int (*dev_uevent)(struct device___117 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___117 *, umode_t *);
	void (*class_release)(struct class___117 *);
	void (*dev_release)(struct device___117 *);
	int (*shutdown_pre)(struct device___117 *);
	const struct kobj_ns_type_operations___22 *ns_type;
	const void * (*namespace)(struct device___117 *);
	void (*get_ownership)(struct device___117 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___117 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___54;

struct pipe_buffer___54 {
	struct page___166 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___54 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___54 {
	int (*confirm)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
	void (*release)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
	bool (*try_steal)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
	bool (*get)(struct pipe_inode_info___54 *, struct pipe_buffer___54 *);
};

typedef rx_handler_result_t rx_handler_func_t___29(struct sk_buff___30 **);

struct bpf_xdp_entity___29 {
	struct bpf_prog___29 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___29;

struct net_device_ops___29;

struct ethtool_ops___7;

struct l3mdev_ops___22;

struct ndisc_ops___12;

struct xfrmdev_ops___29;

struct header_ops___29;

struct inet6_dev___12;

struct netdev_rx_queue___29;

struct mini_Qdisc___29;

struct netdev_queue___29;

struct Qdisc___29;

struct rtnl_link_ops___29;

struct dcbnl_rtnl_ops___29;

struct net_device___31 {
	char name[16];
	struct netdev_name_node___29 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___29 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___7 *ethtool_ops;
	const struct l3mdev_ops___22 *l3mdev_ops;
	const struct ndisc_ops___12 *ndisc_ops;
	const struct xfrmdev_ops___29 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___29 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___148 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___12 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___29 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___29 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___29 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___29 *miniq_ingress;
	struct netdev_queue___29 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___29 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___29 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___29 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___29 = 0,
		NETREG_REGISTERED___29 = 1,
		NETREG_UNREGISTERING___29 = 2,
		NETREG_UNREGISTERED___29 = 3,
		NETREG_RELEASED___29 = 4,
		NETREG_DUMMY___29 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___29 = 0,
		RTNL_LINK_INITIALIZING___29 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___31 *);
	struct netpoll_info *npinfo;
	possible_net_t___29 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___117 dev;
	const struct attribute_group___148 *sysfs_groups[4];
	const struct attribute_group___148 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___29 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___29 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___29 xdp_state[3];
	long: 64;
};

struct netlink_callback___29 {
	struct sk_buff___30 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___30 *, struct netlink_callback___29 *);
	int (*done)(struct netlink_callback___29 *);
	void *data;
	struct module___145 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_ops___7 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___31 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___31 *);
	void (*get_regs)(struct net_device___31 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___31 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___31 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___31 *);
	void (*set_msglevel)(struct net_device___31 *, u32);
	int (*nway_reset)(struct net_device___31 *);
	u32 (*get_link)(struct net_device___31 *);
	int (*get_link_ext_state)(struct net_device___31 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___31 *);
	int (*get_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___31 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___31 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___31 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___31 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___31 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___31 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___31 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___31 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___31 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___31 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___31 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___31 *);
	void (*complete)(struct net_device___31 *);
	u32 (*get_priv_flags)(struct net_device___31 *);
	int (*set_priv_flags)(struct net_device___31 *, u32);
	int (*get_sset_count)(struct net_device___31 *, int);
	int (*get_rxnfc)(struct net_device___31 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___31 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___31 *, struct ethtool_flash *);
	int (*reset)(struct net_device___31 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___31 *);
	u32 (*get_rxfh_indir_size)(struct net_device___31 *);
	int (*get_rxfh)(struct net_device___31 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___31 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___31 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___31 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___31 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___31 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___31 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___31 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___31 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___31 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___31 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___31 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___31 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___31 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___31 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___31 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___31 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___31 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___31 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___31 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___31 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___31 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___31 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___31 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___31 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___31 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___31 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___31 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___31 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___31 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___31 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct inet_frags___34;

struct fqdir___34 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___34 *f;
	struct net___34 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___34;

struct inet_frags___34 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___34 *, const void *);
	void (*destructor)(struct inet_frag_queue___34 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___34 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___30 *fragments_tail;
	struct sk_buff___30 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___34 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___9 {
	struct ip_ra_chain___9 *next;
	struct sock___23 *sk;
	union {
		void (*destructor)(struct sock___23 *);
		struct sock___23 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___22;

struct fib_lookup_arg___22;

struct fib_rules_ops___22 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___22 *, struct flowi *, int, struct fib_lookup_arg___22 *);
	bool (*suppress)(struct fib_rule___22 *, int, struct fib_lookup_arg___22 *);
	int (*match)(struct fib_rule___22 *, struct flowi *, int);
	int (*configure)(struct fib_rule___22 *, struct sk_buff___30 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___22 *);
	int (*compare)(struct fib_rule___22 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___22 *, struct sk_buff___30 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___22 *);
	void (*flush_cache)(struct fib_rules_ops___22 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___145 *owner;
	struct net___34 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___22 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___34 *);
	int (*fib_dump)(struct net___34 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___145 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___9;

struct dst_entry___22 {
	struct net_device___31 *dev;
	struct dst_ops___34 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___30 *);
	int (*output)(struct net___34 *, struct sock___23 *, struct sk_buff___30 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___9 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___22;

struct neigh_parms___22;

struct neigh_ops___22;

struct neighbour___22 {
	struct neighbour___22 *next;
	struct neigh_table___22 *tbl;
	struct neigh_parms___22 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___29 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___22 *, struct sk_buff___30 *);
	const struct neigh_ops___22 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___31 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___29 {
	struct bpf_prog___29 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___29 {
	struct callback_head rcu;
	struct bpf_prog_array_item___29 items[0];
};

struct bpf_prog_aux___31;

struct bpf_prog___29 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___31 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dcbnl_rtnl_ops___29 {
	int (*ieee_getets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___31 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___31 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___31 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___31 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___31 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___31 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___31 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___31 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___31 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___31 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___31 *);
	u8 (*setstate)(struct net_device___31 *, u8);
	void (*getpermhwaddr)(struct net_device___31 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___31 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___31 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___31 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___31 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___31 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___31 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___31 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___31 *, int, u8 *);
	void (*setpfccfg)(struct net_device___31 *, int, u8);
	void (*getpfccfg)(struct net_device___31 *, int, u8 *);
	u8 (*setall)(struct net_device___31 *);
	u8 (*getcap)(struct net_device___31 *, int, u8 *);
	int (*getnumtcs)(struct net_device___31 *, int, u8 *);
	int (*setnumtcs)(struct net_device___31 *, int, u8);
	u8 (*getpfcstate)(struct net_device___31 *);
	void (*setpfcstate)(struct net_device___31 *, u8);
	void (*getbcncfg)(struct net_device___31 *, int, u32 *);
	void (*setbcncfg)(struct net_device___31 *, int, u32);
	void (*getbcnrp)(struct net_device___31 *, int, u8 *);
	void (*setbcnrp)(struct net_device___31 *, int, u8);
	int (*setapp)(struct net_device___31 *, u8, u16, u8);
	int (*getapp)(struct net_device___31 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___31 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___31 *, int, u8);
	u8 (*getdcbx)(struct net_device___31 *);
	u8 (*setdcbx)(struct net_device___31 *, u8);
	int (*peer_getappinfo)(struct net_device___31 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___31 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___31 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___31 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___31 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___31 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___32;

typedef int (*bpf_iter_init_seq_priv_t___31)(void *, struct bpf_iter_aux_info___32 *);

struct bpf_map___31;

struct bpf_iter_aux_info___32 {
	struct bpf_map___31 *map;
};

struct bpf_iter_seq_info___31 {
	const struct seq_operations___139 *seq_ops;
	bpf_iter_init_seq_priv_t___31 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___31 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___31 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___31 *, struct file___161 *);
	void (*map_free)(struct bpf_map___31 *);
	int (*map_get_next_key)(struct bpf_map___31 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___31 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___31 *, void *);
	int (*map_lookup_batch)(struct bpf_map___31 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___31 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___31 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___31 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___31 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___31 *, void *);
	int (*map_update_elem)(struct bpf_map___31 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___31 *, void *);
	int (*map_push_elem)(struct bpf_map___31 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___31 *, void *);
	int (*map_peek_elem)(struct bpf_map___31 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___31 *, struct file___161 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___31 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___31 *, void *, struct seq_file___139 *);
	int (*map_check_btf)(const struct bpf_map___31 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___31 *, struct bpf_prog_aux___31 *);
	void (*map_poke_untrack)(struct bpf_map___31 *, struct bpf_prog_aux___31 *);
	void (*map_poke_run)(struct bpf_map___31 *, u32, struct bpf_prog___29 *, struct bpf_prog___29 *);
	int (*map_direct_value_addr)(const struct bpf_map___31 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___31 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___31 *, struct vm_area_struct___166 *);
	__poll_t (*map_poll)(struct bpf_map___31 *, struct file___161 *, struct poll_table_struct___102 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___31 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___31 *, const struct bpf_map___31 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___31 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___31 *iter_seq_info;
};

struct bpf_map___31 {
	const struct bpf_map_ops___31 *ops;
	struct bpf_map___31 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___62 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___31;

struct bpf_jit_poke_descriptor___31;

struct bpf_prog_ops___29;

struct btf_mod_pair___31;

struct bpf_prog_offload___29;

struct bpf_prog_aux___31 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___29 *dst_prog;
	struct bpf_trampoline___31 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___29 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___31 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___29 *ops;
	struct bpf_map___31 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___31 *used_btfs;
	struct bpf_prog___29 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___31 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___29 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___29;

struct bpf_map_dev_ops___29 {
	int (*map_get_next_key)(struct bpf_offloaded_map___29 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___29 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___29 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___29 *, void *);
};

struct bpf_offloaded_map___29 {
	struct bpf_map___31 map;
	struct net_device___31 *netdev;
	const struct bpf_map_dev_ops___29 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___29 {
	int (*test_run)(struct bpf_prog___29 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___29 {
	struct bpf_prog___29 *prog;
	struct net_device___31 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___31 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___29 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___145 *mod;
};

struct bpf_jit_poke_descriptor___31 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___31 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___31 {
	struct btf *btf;
	struct module___145 *module;
};

struct cftype___110;

struct cgroup_subsys___110 {
	struct cgroup_subsys_state___110 * (*css_alloc)(struct cgroup_subsys_state___110 *);
	int (*css_online)(struct cgroup_subsys_state___110 *);
	void (*css_offline)(struct cgroup_subsys_state___110 *);
	void (*css_released)(struct cgroup_subsys_state___110 *);
	void (*css_free)(struct cgroup_subsys_state___110 *);
	void (*css_reset)(struct cgroup_subsys_state___110 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___110 *, int);
	int (*css_extra_stat_show)(struct seq_file___139 *, struct cgroup_subsys_state___110 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___168 *, struct css_set___110 *);
	void (*cancel_fork)(struct task_struct___168 *, struct css_set___110 *);
	void (*fork)(struct task_struct___168 *);
	void (*exit)(struct task_struct___168 *);
	void (*release)(struct task_struct___168 *);
	void (*bind)(struct cgroup_subsys_state___110 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___110 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___110 *dfl_cftypes;
	struct cftype___110 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___110 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___110 *updated_children;
	struct cgroup___110 *updated_next;
};

struct cgroup_root___110 {
	struct kernfs_root___148 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___110 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___110 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___110 *ss;
	struct list_head node;
	struct kernfs_ops___148 *kf_ops;
	int (*open)(struct kernfs_open_file___148 *);
	void (*release)(struct kernfs_open_file___148 *);
	u64 (*read_u64)(struct cgroup_subsys_state___110 *, struct cftype___110 *);
	s64 (*read_s64)(struct cgroup_subsys_state___110 *, struct cftype___110 *);
	int (*seq_show)(struct seq_file___139 *, void *);
	void * (*seq_start)(struct seq_file___139 *, loff_t *);
	void * (*seq_next)(struct seq_file___139 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___139 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___110 *, struct cftype___110 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___110 *, struct cftype___110 *, s64);
	ssize_t (*write)(struct kernfs_open_file___148 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___148 *, struct poll_table_struct___102 *);
};

struct xdp_rxq_info___29 {
	struct net_device___31 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___29 {
	struct net_device___31 *dev;
};

struct xdp_buff___29 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___29 *rxq;
	struct xdp_txq_info___29 *txq;
	u32 frame_sz;
};

struct xdp_frame___29 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___31 *dev_rx;
};

struct header_ops___29 {
	int (*create)(struct sk_buff___30 *, struct net_device___31 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___30 *, unsigned char *);
	int (*cache)(const struct neighbour___22 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___31 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___30 *);
};

struct netdev_queue___29 {
	struct net_device___31 *dev;
	struct Qdisc___29 *qdisc;
	struct Qdisc___29 *qdisc_sleeping;
	struct kobject___148 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___31 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___29 {
	struct sk_buff___30 *head;
	struct sk_buff___30 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___29;

struct Qdisc___29 {
	int (*enqueue)(struct sk_buff___30 *, struct Qdisc___29 *, struct sk_buff___30 **);
	struct sk_buff___30 * (*dequeue)(struct Qdisc___29 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___29 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___29 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___29 gso_skb;
	struct qdisc_skb_head___29 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___29 *next_sched;
	struct sk_buff_head___29 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___29 {
	struct xdp_rxq_info___29 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___148 kobj;
	struct net_device___31 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___29 {
	enum net_device_path_type type;
	const struct net_device___31 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___29 = 0,
				DEV_PATH_BR_VLAN_TAG___29 = 1,
				DEV_PATH_BR_VLAN_UNTAG___29 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___29 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___29 {
	const struct net_device___31 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___29 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___29 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___29 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___29 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___30 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___29 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___31 *dev;
	const char *name;
};

struct net_device_ops___29 {
	int (*ndo_init)(struct net_device___31 *);
	void (*ndo_uninit)(struct net_device___31 *);
	int (*ndo_open)(struct net_device___31 *);
	int (*ndo_stop)(struct net_device___31 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___30 *, struct net_device___31 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___30 *, struct net_device___31 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___31 *, struct sk_buff___30 *, struct net_device___31 *);
	void (*ndo_change_rx_flags)(struct net_device___31 *, int);
	void (*ndo_set_rx_mode)(struct net_device___31 *);
	int (*ndo_set_mac_address)(struct net_device___31 *, void *);
	int (*ndo_validate_addr)(struct net_device___31 *);
	int (*ndo_do_ioctl)(struct net_device___31 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___31 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___31 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___31 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___31 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___31 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___31 *, int);
	int (*ndo_neigh_setup)(struct net_device___31 *, struct neigh_parms___22 *);
	void (*ndo_tx_timeout)(struct net_device___31 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___31 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___31 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___31 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___31 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___31 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___31 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___31 *);
	int (*ndo_netpoll_setup)(struct net_device___31 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___31 *);
	int (*ndo_set_vf_mac)(struct net_device___31 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___31 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___31 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___31 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___31 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___31 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___31 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___31 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___31 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___31 *, int, struct sk_buff___30 *);
	int (*ndo_get_vf_guid)(struct net_device___31 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___31 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___31 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___31 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___31 *);
	int (*ndo_fcoe_disable)(struct net_device___31 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___31 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___31 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___31 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___31 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___31 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___31 *, const struct sk_buff___30 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___31 *, struct net_device___31 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___31 *, struct net_device___31 *);
	struct net_device___31 * (*ndo_get_xmit_slave)(struct net_device___31 *, struct sk_buff___30 *, bool);
	struct net_device___31 * (*ndo_sk_get_lower_dev)(struct net_device___31 *, struct sock___23 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___31 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___31 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___31 *, struct neighbour___22 *);
	void (*ndo_neigh_destroy)(struct net_device___31 *, struct neighbour___22 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___30 *, struct netlink_callback___29 *, struct net_device___31 *, struct net_device___31 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___30 *, struct nlattr **, struct net_device___31 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___31 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___30 *, u32, u32, struct net_device___31 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___31 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___31 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___31 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___31 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___31 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___31 *, struct net_device___31 *);
	void (*ndo_dfwd_del_station)(struct net_device___31 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___31 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___31 *);
	int (*ndo_change_proto_down)(struct net_device___31 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___31 *, struct sk_buff___30 *);
	void (*ndo_set_rx_headroom)(struct net_device___31 *, int);
	int (*ndo_bpf)(struct net_device___31 *, struct netdev_bpf___29 *);
	int (*ndo_xdp_xmit)(struct net_device___31 *, int, struct xdp_frame___29 **, u32);
	struct net_device___31 * (*ndo_xdp_get_xmit_slave)(struct net_device___31 *, struct xdp_buff___29 *);
	int (*ndo_xsk_wakeup)(struct net_device___31 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___31 *);
	int (*ndo_tunnel_ctl)(struct net_device___31 *, struct ip_tunnel_parm *, int);
	struct net_device___31 * (*ndo_get_peer_dev)(struct net_device___31 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___29 *, struct net_device_path___29 *);
};

struct neigh_parms___22 {
	possible_net_t___29 net;
	struct net_device___31 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___22 *);
	struct neigh_table___22 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___22 {
	u32 (*l3mdev_fib_table)(const struct net_device___31 *);
	struct sk_buff___30 * (*l3mdev_l3_rcv)(struct net_device___31 *, struct sk_buff___30 *, u16);
	struct sk_buff___30 * (*l3mdev_l3_out)(struct net_device___31 *, struct sock___23 *, struct sk_buff___30 *, u16);
	struct dst_entry___22 * (*l3mdev_link_scope_lookup)(const struct net_device___31 *, struct flowi6 *);
};

struct ndisc_ops___12 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___31 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___31 *, struct neighbour___22 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___31 *, u8, struct neighbour___22 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___31 *, struct sk_buff___30 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___34 *, struct net_device___31 *, const struct prefix_info *, struct inet6_dev___12 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___12;

struct inet6_dev___12 {
	struct net_device___31 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___12 *mc_list;
	struct ifmcaddr6___12 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___29 mc_query_queue;
	struct sk_buff_head___29 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___22 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___29;

struct tcf_block___29;

struct mini_Qdisc___29 {
	struct tcf_proto___29 *filter_list;
	struct tcf_block___29 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___29 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___31 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___31 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___34 *, struct net_device___31 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___31 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___31 *, struct list_head *);
	size_t (*get_size)(const struct net_device___31 *);
	int (*fill_info)(struct sk_buff___30 *, const struct net_device___31 *);
	size_t (*get_xstats_size)(const struct net_device___31 *);
	int (*fill_xstats)(struct sk_buff___30 *, const struct net_device___31 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___31 *, struct net_device___31 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___31 *, const struct net_device___31 *);
	int (*fill_slave_info)(struct sk_buff___30 *, const struct net_device___31 *, const struct net_device___31 *);
	struct net___34 * (*get_link_net)(const struct net_device___31 *);
	size_t (*get_linkxstats_size)(const struct net_device___31 *, int);
	int (*fill_linkxstats)(struct sk_buff___30 *, const struct net_device___31 *, int *, int);
};

struct block_device_operations___74;

struct gendisk___74 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___75 *part0;
	const struct block_device_operations___74 *fops;
	struct request_queue___74 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___71 *bdi;
	struct kobject___148 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___148 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___74 {
	struct bio___74 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___88 *bip_vec;
	struct bio_vec___88 bip_inline_vecs[0];
};

struct blkcg___71;

struct blkg_policy_data___71;

struct blkcg_gq___71 {
	struct request_queue___74 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___71 *blkcg;
	struct blkcg_gq___71 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___71 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___74 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___74(struct request___74 *);

typedef void integrity_complete_fn___74(struct request___74 *, unsigned int);

struct blk_integrity_profile___74 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___74 *prepare_fn;
	integrity_complete_fn___74 *complete_fn;
	const char *name;
};

struct block_device_operations___74 {
	blk_qc_t (*submit_bio)(struct bio___74 *);
	int (*open)(struct block_device___75 *, fmode_t);
	void (*release)(struct gendisk___74 *, fmode_t);
	int (*rw_page)(struct block_device___75 *, sector_t, struct page___166 *, unsigned int);
	int (*ioctl)(struct block_device___75 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___75 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___74 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___74 *);
	int (*getgeo)(struct block_device___75 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___75 *, bool);
	void (*swap_slot_free_notify)(struct block_device___75 *, long unsigned int);
	int (*report_zones)(struct gendisk___74 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___74 *, umode_t *);
	struct module___145 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___74 *, sector_t *);
};

typedef void rq_end_io_fn___74(struct request___74 *, blk_status_t);

struct request___74 {
	struct request_queue___74 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___71 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___74 *bio;
	struct bio___74 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___88 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___74 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___74 *saved_end_io;
		} flush;
	};
	struct gendisk___74 *rq_disk;
	struct block_device___75 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___74 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___71 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___74 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___148 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___161 *debugfs_dir;
	struct dentry___161 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___74;

struct elevator_mq_ops___74 {
	int (*init_sched)(struct request_queue___74 *, struct elevator_type___74 *);
	void (*exit_sched)(struct elevator_queue___74 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___71 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___71 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___71 *);
	bool (*allow_merge)(struct request_queue___74 *, struct request___74 *, struct bio___74 *);
	bool (*bio_merge)(struct request_queue___74 *, struct bio___74 *, unsigned int);
	int (*request_merge)(struct request_queue___74 *, struct request___74 **, struct bio___74 *);
	void (*request_merged)(struct request_queue___74 *, struct request___74 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___74 *, struct request___74 *, struct request___74 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___74 *);
	void (*finish_request)(struct request___74 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___71 *, struct list_head *, bool);
	struct request___74 * (*dispatch_request)(struct blk_mq_hw_ctx___71 *);
	bool (*has_work)(struct blk_mq_hw_ctx___71 *);
	void (*completed_request)(struct request___74 *, u64);
	void (*requeue_request)(struct request___74 *);
	struct request___74 * (*former_request)(struct request_queue___74 *, struct request___74 *);
	struct request___74 * (*next_request)(struct request_queue___74 *, struct request___74 *);
	void (*init_icq)(struct io_cq___74 *);
	void (*exit_icq)(struct io_cq___74 *);
};

struct elv_fs_entry___74;

struct elevator_type___74 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___74 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___74 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___145 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___74 {
	struct elevator_type___74 *type;
	void *elevator_data;
	struct kobject___148 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___74 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___74 *, char *);
	ssize_t (*store)(struct elevator_queue___74 *, const char *, size_t);
};

struct blk_mq_queue_data___71;

struct blk_mq_ops___71 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___71 *, const struct blk_mq_queue_data___71 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___71 *);
	int (*get_budget)(struct request_queue___74 *);
	void (*put_budget)(struct request_queue___74 *, int);
	void (*set_rq_budget_token)(struct request___74 *, int);
	int (*get_rq_budget_token)(struct request___74 *);
	enum blk_eh_timer_return (*timeout)(struct request___74 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___71 *);
	void (*complete)(struct request___74 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___71 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___71 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___71 *, struct request___74 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___71 *, struct request___74 *, unsigned int);
	void (*initialize_rq_fn)(struct request___74 *);
	void (*cleanup_rq)(struct request___74 *);
	bool (*busy)(struct request_queue___74 *);
	int (*map_queues)(struct blk_mq_tag_set___71 *);
	void (*show_rq)(struct seq_file___139 *, struct request___74 *);
};

struct blk_mq_tag_set___71 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___71 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___71 {
	struct request___74 *rq;
	bool last;
};

struct blkcg_policy_data___71;

struct blkcg___71 {
	struct cgroup_subsys_state___110 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___71 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___71 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___71 {
	struct blkcg___71 *blkcg;
	int plid;
};

struct blkg_policy_data___71 {
	struct blkcg_gq___71 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___62 {
	struct mem_cgroup___62 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___62 {
	struct lruvec___69 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___62 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___62 *memcg;
};

struct obj_cgroup___62 {
	struct percpu_ref refcnt;
	struct mem_cgroup___62 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___29 {
	spinlock_t *lock;
	struct sk_buff___30 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___29;

struct Qdisc_ops___29 {
	struct Qdisc_ops___29 *next;
	const struct Qdisc_class_ops___29 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___30 *, struct Qdisc___29 *, struct sk_buff___30 **);
	struct sk_buff___30 * (*dequeue)(struct Qdisc___29 *);
	struct sk_buff___30 * (*peek)(struct Qdisc___29 *);
	int (*init)(struct Qdisc___29 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___29 *);
	void (*destroy)(struct Qdisc___29 *);
	int (*change)(struct Qdisc___29 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___29 *);
	int (*change_tx_queue_len)(struct Qdisc___29 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___29 *, unsigned int);
	int (*dump)(struct Qdisc___29 *, struct sk_buff___30 *);
	int (*dump_stats)(struct Qdisc___29 *, struct gnet_dump___29 *);
	void (*ingress_block_set)(struct Qdisc___29 *, u32);
	void (*egress_block_set)(struct Qdisc___29 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___29 *);
	u32 (*egress_block_get)(struct Qdisc___29 *);
	struct module___145 *owner;
};

struct Qdisc_class_ops___29 {
	unsigned int flags;
	struct netdev_queue___29 * (*select_queue)(struct Qdisc___29 *, struct tcmsg *);
	int (*graft)(struct Qdisc___29 *, long unsigned int, struct Qdisc___29 *, struct Qdisc___29 **, struct netlink_ext_ack *);
	struct Qdisc___29 * (*leaf)(struct Qdisc___29 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___29 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___29 *, u32);
	int (*change)(struct Qdisc___29 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___29 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___29 *, struct qdisc_walker *);
	struct tcf_block___29 * (*tcf_block)(struct Qdisc___29 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___29 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___29 *, long unsigned int);
	int (*dump)(struct Qdisc___29 *, long unsigned int, struct sk_buff___30 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___29 *, long unsigned int, struct gnet_dump___29 *);
};

struct tcf_chain___29;

struct tcf_block___29 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___34 *net;
	struct Qdisc___29 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___29 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___29;

struct tcf_proto_ops___29;

struct tcf_proto___29 {
	struct tcf_proto___29 *next;
	void *root;
	int (*classify)(struct sk_buff___30 *, const struct tcf_proto___29 *, struct tcf_result___29 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___29 *ops;
	struct tcf_chain___29 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___29 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___29 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___29 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___30 *, const struct tcf_proto___29 *, struct tcf_result___29 *);
	int (*init)(struct tcf_proto___29 *);
	void (*destroy)(struct tcf_proto___29 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___29 *, u32);
	void (*put)(struct tcf_proto___29 *, void *);
	int (*change)(struct net___34 *, struct sk_buff___30 *, struct tcf_proto___29 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___29 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___29 *);
	void (*walk)(struct tcf_proto___29 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___29 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___29 *, void *);
	void (*hw_del)(struct tcf_proto___29 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___34 *, struct tcf_chain___29 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___34 *, struct tcf_proto___29 *, void *, struct sk_buff___30 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___34 *, struct tcf_proto___29 *, void *, struct sk_buff___30 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___30 *, struct net___34 *, void *);
	struct module___145 *owner;
	int flags;
};

struct tcf_chain___29 {
	struct mutex filter_chain_lock;
	struct tcf_proto___29 *filter_chain;
	struct list_head list;
	struct tcf_block___29 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___29 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___22 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___29 *prog;
};

struct pneigh_entry___22;

struct neigh_hash_table___22;

struct neigh_table___22 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___31 *, __u32 *);
	bool (*key_eq)(const struct neighbour___22 *, const void *);
	int (*constructor)(struct neighbour___22 *);
	int (*pconstructor)(struct pneigh_entry___22 *);
	void (*pdestructor)(struct pneigh_entry___22 *);
	void (*proxy_redo)(struct sk_buff___30 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___31 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___22 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___29 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___22 *nht;
	struct pneigh_entry___22 **phash_buckets;
};

struct neigh_ops___22 {
	int family;
	void (*solicit)(struct neighbour___22 *, struct sk_buff___30 *);
	void (*error_report)(struct neighbour___22 *, struct sk_buff___30 *);
	int (*output)(struct neighbour___22 *, struct sk_buff___30 *);
	int (*connected_output)(struct neighbour___22 *, struct sk_buff___30 *);
};

struct pneigh_entry___22 {
	struct pneigh_entry___22 *next;
	possible_net_t___29 net;
	struct net_device___31 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___22 {
	struct neighbour___22 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___9 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___34 *, struct sock___23 *, struct sk_buff___30 *);
	int (*orig_input)(struct sk_buff___30 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___22 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___22 *ctarget;
	struct net___34 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___22 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___22 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___12;

struct timewait_sock_ops___12;

struct proto___22 {
	void (*close)(struct sock___23 *, long int);
	int (*pre_connect)(struct sock___23 *, struct sockaddr *, int);
	int (*connect)(struct sock___23 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___23 *, int);
	struct sock___23 * (*accept)(struct sock___23 *, int, int *, bool);
	int (*ioctl)(struct sock___23 *, int, long unsigned int);
	int (*init)(struct sock___23 *);
	void (*destroy)(struct sock___23 *);
	void (*shutdown)(struct sock___23 *, int);
	int (*setsockopt)(struct sock___23 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___23 *, int, int, char *, int *);
	void (*keepalive)(struct sock___23 *, int);
	int (*compat_ioctl)(struct sock___23 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___23 *, struct msghdr___23 *, size_t);
	int (*recvmsg)(struct sock___23 *, struct msghdr___23 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___23 *, struct page___166 *, int, size_t, int);
	int (*bind)(struct sock___23 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___23 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___23 *, struct sk_buff___30 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___23 *);
	int (*hash)(struct sock___23 *);
	void (*unhash)(struct sock___23 *);
	void (*rehash)(struct sock___23 *);
	int (*get_port)(struct sock___23 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___23 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___23 *, int);
	bool (*sock_is_readable)(struct sock___23 *);
	void (*enter_memory_pressure)(struct sock___23 *);
	void (*leave_memory_pressure)(struct sock___23 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___12 *rsk_prot;
	struct timewait_sock_ops___12 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___145 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___23 *, int);
};

struct request_sock___13;

struct request_sock_ops___12 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___23 *, struct request_sock___13 *);
	void (*send_ack)(const struct sock___23 *, struct sk_buff___30 *, struct request_sock___13 *);
	void (*send_reset)(const struct sock___23 *, struct sk_buff___30 *);
	void (*destructor)(struct request_sock___13 *);
	void (*syn_ack_timeout)(const struct request_sock___13 *);
};

struct timewait_sock_ops___12 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___23 *, struct sock___23 *, void *);
	void (*twsk_destructor)(struct sock___23 *);
};

struct request_sock___13 {
	struct sock_common___22 __req_common;
	struct request_sock___13 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___12 *rsk_ops;
	struct sock___23 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___12 {
	struct in6_addr mca_addr;
	struct inet6_dev___12 *idev;
	struct ifmcaddr6___12 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct linux_binprm___32 {
	struct vm_area_struct___166 *vma;
	long unsigned int vma_pages;
	struct mm_struct___167 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___161 *executable;
	struct file___161 *interpreter;
	struct file___161 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___31 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___161 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct table_header {
	u16 td_id;
	u16 td_flags;
	u32 td_hilen;
	u32 td_lolen;
	char td_data[0];
};

struct aa_dfa {
	struct kref count;
	u16 flags;
	u32 max_oob;
	struct table_header *tables[8];
};

struct aa_policy {
	const char *name;
	char *hname;
	struct list_head list;
	struct list_head profiles;
};

struct aa_labelset {
	rwlock_t lock;
	struct rb_root root;
};

enum label_flags {
	FLAG_HAT = 1,
	FLAG_UNCONFINED = 2,
	FLAG_NULL = 4,
	FLAG_IX_ON_NAME_ERROR = 8,
	FLAG_IMMUTIBLE = 16,
	FLAG_USER_DEFINED = 32,
	FLAG_NO_LIST_REF = 64,
	FLAG_NS_COUNT = 128,
	FLAG_IN_TREE = 256,
	FLAG_PROFILE = 512,
	FLAG_EXPLICIT = 1024,
	FLAG_STALE = 2048,
	FLAG_RENAMED = 4096,
	FLAG_REVOKED = 8192,
};

struct aa_label;

struct aa_proxy {
	struct kref count;
	struct aa_label *label;
};

struct aa_profile;

struct aa_label {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	struct aa_proxy *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile *vec[0];
};

struct label_it {
	int i;
	int j;
};

struct aa_policydb {
	struct aa_dfa *dfa;
	unsigned int start[18];
};

struct aa_domain {
	int size;
	char **table;
};

struct aa_file_rules {
	unsigned int start;
	struct aa_dfa *dfa;
	struct aa_domain trans;
};

struct aa_caps {
	kernel_cap_t allow;
	kernel_cap_t audit;
	kernel_cap_t denied;
	kernel_cap_t quiet;
	kernel_cap_t kill;
	kernel_cap_t extended;
};

struct aa_rlimit {
	unsigned int mask;
	struct rlimit limits[16];
};

struct aa_ns;

struct aa_net_compat;

struct aa_secmark;

struct aa_loaddata;

struct aa_profile {
	struct aa_policy base;
	struct aa_profile *parent;
	struct aa_ns *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___161 *dents[9];
	struct rhashtable *data;
	struct aa_label label;
};

struct aa_perms {
	u32 allow;
	u32 audit;
	u32 deny;
	u32 quiet;
	u32 kill;
	u32 stop;
	u32 complain;
	u32 cond;
	u32 hide;
	u32 prompt;
	u16 xindex;
};

struct path_cond {
	kuid_t uid;
	umode_t mode;
};

struct aa_net_compat {
	u16 allow[46];
	u16 audit[46];
	u16 quiet[46];
};

struct aa_secmark {
	u8 audit;
	u8 deny;
	u32 secid;
	char *label;
};

enum profile_mode {
	APPARMOR_ENFORCE = 0,
	APPARMOR_COMPLAIN = 1,
	APPARMOR_KILL = 2,
	APPARMOR_UNCONFINED = 3,
};

struct aa_data {
	char *key;
	u32 size;
	char *data;
	struct rhash_head head;
};

struct aa_ns_acct {
	int max_size;
	int max_count;
	int size;
	int count;
};

struct aa_ns {
	struct aa_policy base;
	struct aa_ns *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___161 *dents[13];
};

struct aa_loaddata {
	struct kref count;
	struct list_head list;
	struct work_struct work;
	struct dentry___161 *dents[6];
	struct aa_ns *ns;
	char *name;
	size_t size;
	size_t compressed_size;
	long int revision;
	int abi;
	unsigned char *hash;
	char *data;
};

enum {
	AAFS_LOADDATA_ABI = 0,
	AAFS_LOADDATA_REVISION = 1,
	AAFS_LOADDATA_HASH = 2,
	AAFS_LOADDATA_DATA = 3,
	AAFS_LOADDATA_COMPRESSED_SIZE = 4,
	AAFS_LOADDATA_DIR = 5,
	AAFS_LOADDATA_NDENTS = 6,
};

struct rawdata_f_data {
	struct aa_loaddata *loaddata;
};

struct aa_revision {
	struct aa_ns *ns;
	long int last_read;
};

struct multi_transaction {
	struct kref count;
	ssize_t size;
	char data[0];
};

struct lsm_network_audit___4 {
	int netif;
	const struct sock___19 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___4 {
	struct path___157 path;
	u16 cmd;
};

struct aa_label___2;

struct aa_profile___2;

struct apparmor_audit_data {
	int error;
	int type;
	const char *op;
	struct aa_label___2 *label;
	const char *name;
	const char *info;
	u32 request;
	u32 denied;
	union {
		struct {
			struct aa_label___2 *peer;
			union {
				struct {
					const char *target;
					kuid_t ouid;
				} fs;
				struct {
					int rlim;
					long unsigned int max;
				} rlim;
				struct {
					int signal;
					int unmappedsig;
				};
				struct {
					int type;
					int protocol;
					struct sock___19 *peer_sk;
					void *addr;
					int addrlen;
				} net;
			};
		};
		struct {
			struct aa_profile___2 *profile;
			const char *ns;
			long int pos;
		} iface;
		struct {
			const char *src_name;
			const char *type;
			const char *trans;
			const char *data;
			long unsigned int flags;
		} mnt;
	};
};

struct common_audit_data___4 {
	char type;
	union {
		struct path___157 path;
		struct dentry___157 *dentry;
		struct inode___157 *inode;
		struct lsm_network_audit___4 *net;
		int cap;
		int ipc_id;
		struct task_struct___164 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___4 *op;
		struct file___157 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data *apparmor_audit_data;
	};
};

struct aa_proxy___2 {
	struct kref count;
	struct aa_label___2 *label;
};

struct aa_label___2 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	struct aa_proxy___2 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___2 *vec[0];
};

struct aa_ns___2;

struct aa_loaddata___2;

struct aa_profile___2 {
	struct aa_policy base;
	struct aa_profile___2 *parent;
	struct aa_ns___2 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___2 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___157 *dents[9];
	struct rhashtable *data;
	struct aa_label___2 label;
};

enum audit_type {
	AUDIT_APPARMOR_AUDIT = 0,
	AUDIT_APPARMOR_ALLOWED = 1,
	AUDIT_APPARMOR_DENIED = 2,
	AUDIT_APPARMOR_HINT = 3,
	AUDIT_APPARMOR_STATUS = 4,
	AUDIT_APPARMOR_ERROR = 5,
	AUDIT_APPARMOR_KILL = 6,
	AUDIT_APPARMOR_AUTO = 7,
};

struct aa_ns___2 {
	struct aa_policy base;
	struct aa_ns___2 *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile___2 *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___157 *dents[13];
};

struct aa_audit_rule {
	struct aa_label___2 *label;
};

struct aa_sfs_entry___2 {
	const char *name;
	struct dentry___156 *dentry;
	umode_t mode;
	enum aa_sfs_type v_type;
	union {
		bool boolean;
		char *string;
		long unsigned int u64;
		struct aa_sfs_entry___2 *files;
	} v;
	const struct file_operations___156 *file_ops;
};

struct aa_label___3;

struct aa_proxy___3 {
	struct kref count;
	struct aa_label___3 *label;
};

struct aa_profile___3;

struct aa_label___3 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	struct aa_proxy___3 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___3 *vec[0];
};

struct aa_ns___3;

struct aa_profile___3 {
	struct aa_policy base;
	struct aa_profile___3 *parent;
	struct aa_ns___3 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___2 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___156 *dents[9];
	struct rhashtable *data;
	struct aa_label___3 label;
};

struct apparmor_audit_data___2 {
	int error;
	int type;
	const char *op;
	struct aa_label___3 *label;
	const char *name;
	const char *info;
	u32 request;
	u32 denied;
	union {
		struct {
			struct aa_label___3 *peer;
			union {
				struct {
					const char *target;
					kuid_t ouid;
				} fs;
				struct {
					int rlim;
					long unsigned int max;
				} rlim;
				struct {
					int signal;
					int unmappedsig;
				};
				struct {
					int type;
					int protocol;
					struct sock___18 *peer_sk;
					void *addr;
					int addrlen;
				} net;
			};
		};
		struct {
			struct aa_profile___3 *profile;
			const char *ns;
			long int pos;
		} iface;
		struct {
			const char *src_name;
			const char *type;
			const char *trans;
			const char *data;
			long unsigned int flags;
		} mnt;
	};
};

struct common_audit_data___5 {
	char type;
	union {
		struct path___156 path;
		struct dentry___156 *dentry;
		struct inode___156 *inode;
		struct lsm_network_audit___2 *net;
		int cap;
		int ipc_id;
		struct task_struct___163 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___2 *op;
		struct file___156 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data___2 *apparmor_audit_data;
	};
};

struct aa_ns___3 {
	struct aa_policy base;
	struct aa_ns___3 *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile___3 *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___156 *dents[13];
};

struct audit_cache {
	struct aa_profile___3 *profile;
	kernel_cap_t caps;
};

struct aa_task_ctx {
	struct aa_label___3 *nnp;
	struct aa_label___3 *onexec;
	struct aa_label___3 *previous;
	u64 token;
};

struct dentry___162;

struct super_block___162;

struct module___146;

struct file_system_type___162 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___162 * (*mount)(struct file_system_type___162 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___162 *);
	struct module___146 *owner;
	struct file_system_type___162 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___162;

struct kiocb___162;

struct iov_iter___91;

struct poll_table_struct___103;

struct vm_area_struct___167;

struct inode___162;

struct file_lock___162;

struct page___167;

struct pipe_inode_info___55;

struct seq_file___140;

struct file_operations___162 {
	struct module___146 *owner;
	loff_t (*llseek)(struct file___162 *, loff_t, int);
	ssize_t (*read)(struct file___162 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___162 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___162 *, struct iov_iter___91 *);
	ssize_t (*write_iter)(struct kiocb___162 *, struct iov_iter___91 *);
	int (*iopoll)(struct kiocb___162 *, bool);
	int (*iterate)(struct file___162 *, struct dir_context *);
	int (*iterate_shared)(struct file___162 *, struct dir_context *);
	__poll_t (*poll)(struct file___162 *, struct poll_table_struct___103 *);
	long int (*unlocked_ioctl)(struct file___162 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___162 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___162 *, struct vm_area_struct___167 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___162 *, struct file___162 *);
	int (*flush)(struct file___162 *, fl_owner_t);
	int (*release)(struct inode___162 *, struct file___162 *);
	int (*fsync)(struct file___162 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___162 *, int);
	int (*lock)(struct file___162 *, int, struct file_lock___162 *);
	ssize_t (*sendpage)(struct file___162 *, struct page___167 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___162 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___162 *, long unsigned int);
	int (*flock)(struct file___162 *, int, struct file_lock___162 *);
	ssize_t (*splice_write)(struct pipe_inode_info___55 *, struct file___162 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___162 *, loff_t *, struct pipe_inode_info___55 *, size_t, unsigned int);
	int (*setlease)(struct file___162 *, long int, struct file_lock___162 **, void **);
	long int (*fallocate)(struct file___162 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___140 *, struct file___162 *);
	ssize_t (*copy_file_range)(struct file___162 *, loff_t, struct file___162 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___162 *, loff_t, struct file___162 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___162 *, loff_t, loff_t, int);
};

struct vmacache___167 {
	u64 seqnum;
	struct vm_area_struct___167 *vmas[4];
};

struct page_frag___167 {
	struct page___167 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___168;

struct pid___143;

struct nsproxy___152;

struct signal_struct___163;

struct bio_list___75;

struct backing_dev_info___72;

struct io_context___75;

struct css_set___111;

struct mem_cgroup___63;

struct request_queue___75;

struct vm_struct___146;

struct task_struct___169 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___169 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___168 *mm;
	struct mm_struct___168 *active_mm;
	struct vmacache___167 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___169 *real_parent;
	struct task_struct___169 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___169 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___143 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___152 *nsproxy;
	struct signal_struct___163 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___169 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___75 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___72 *backing_dev_info;
	struct io_context___75 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___111 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___55 *splice_pipe;
	struct page_frag___167 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___63 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___63 *active_memcg;
	struct request_queue___75 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___169 *oom_reaper_list;
	struct vm_struct___146 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___149;

struct kobj_type___149;

struct kernfs_node___149;

struct kobject___149 {
	const char *name;
	struct list_head entry;
	struct kobject___149 *parent;
	struct kset___149 *kset;
	struct kobj_type___149 *ktype;
	struct kernfs_node___149 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___146 {
	struct kobject___149 kobj;
	struct module___146 *mod;
	struct kobject___149 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___146 {
	struct module___146 *mod;
	struct latch_tree_node node;
};

struct module_layout___146 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___146 mtn;
};

struct module_attribute___146;

struct kernel_param___146;

struct module___146 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___146 mkobj;
	struct module_attribute___146 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___149 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___146 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___146 core_layout;
	struct module_layout___146 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___167 *pgtable_t___167;

struct address_space___162;

struct page_pool___46;

struct dev_pagemap___158;

struct page___167 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___162 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___46 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___167 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___167 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___168 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___158 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___158;

struct vm_area_struct___167 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___167 *vm_next;
	struct vm_area_struct___167 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___168 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___158 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___162 *vm_file;
	struct file___162 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___32;

struct core_state___167;

struct mm_struct___168 {
	struct {
		struct vm_area_struct___167 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___162 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___32 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___167 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___169 *owner;
		struct user_namespace___24 *user_ns;
		struct file___162 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___162;

struct address_space___162 {
	struct inode___162 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___162 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___118;

struct page_pool_params___46 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___118 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___46 {
	u32 count;
	struct page___167 *cache[128];
};

struct page_pool___46 {
	struct page_pool_params___46 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___167 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___46 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___158;

struct dev_pagemap___158 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___158 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___162;

struct path___162 {
	struct vfsmount___162 *mnt;
	struct dentry___162 *dentry;
};

struct fown_struct___143 {
	rwlock_t lock;
	struct pid___143 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___162 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___162 f_path;
	struct inode___162 *f_inode;
	const struct file_operations___162 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___143 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___162 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___158;

struct vm_operations_struct___158 {
	void (*open)(struct vm_area_struct___167 *);
	void (*close)(struct vm_area_struct___167 *);
	int (*may_split)(struct vm_area_struct___167 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___167 *);
	int (*mprotect)(struct vm_area_struct___167 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___158 *);
	vm_fault_t (*huge_fault)(struct vm_fault___158 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___158 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___167 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___158 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___158 *);
	int (*access)(struct vm_area_struct___167 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___167 *);
	int (*set_policy)(struct vm_area_struct___167 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___167 *, long unsigned int);
	struct page___167 * (*find_special_page)(struct vm_area_struct___167 *, long unsigned int);
};

struct core_thread___167 {
	struct task_struct___169 *task;
	struct core_thread___167 *next;
};

struct core_state___167 {
	atomic_t nr_threads;
	struct core_thread___167 dumper;
	struct completion startup;
};

struct linux_binprm___33;

struct coredump_params___32;

struct linux_binfmt___32 {
	struct list_head lh;
	struct module___146 *module;
	int (*load_binary)(struct linux_binprm___33 *);
	int (*load_shlib)(struct file___162 *);
	int (*core_dump)(struct coredump_params___32 *);
	long unsigned int min_coredump;
};

struct vm_fault___158 {
	const struct {
		struct vm_area_struct___167 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___167 *cow_page;
	struct page___167 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___167 prealloc_pte;
};

struct pglist_data___70;

struct lruvec___70 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___70 *pgdat;
};

struct zone___70 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___70 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___70 {
	struct zone___70 *zone;
	int zone_idx;
};

struct zonelist___70 {
	struct zoneref___70 _zonerefs[321];
};

struct pglist_data___70 {
	struct zone___70 node_zones[5];
	struct zonelist___70 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___169 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___169 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___70 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___143;

struct upid___143 {
	int nr;
	struct pid_namespace___143 *ns;
};

struct pid_namespace___143 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___169 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___143 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___143 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___143 numbers[1];
};

struct signal_struct___163 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___169 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___169 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___143 *pids[4];
	struct pid___143 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___168 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___35;

struct cgroup_namespace___111;

struct nsproxy___152 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___143 *pid_ns_for_children;
	struct net___35 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___111 *cgroup_ns;
};

struct bio___75;

struct bio_list___75 {
	struct bio___75 *head;
	struct bio___75 *tail;
};

struct cgroup_subsys_state___111;

struct bdi_writeback___72 {
	struct backing_dev_info___72 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___111 *memcg_css;
	struct cgroup_subsys_state___111 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___72 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___72 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___118 *dev;
	char dev_name[64];
	struct device___118 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___162 *debug_dir;
};

struct io_cq___75;

struct io_context___75 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___75 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___111;

struct css_set___111 {
	struct cgroup_subsys_state___111 *subsys[14];
	refcount_t refcount;
	struct css_set___111 *dom_cset;
	struct cgroup___111 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___111 *mg_src_cgrp;
	struct cgroup___111 *mg_dst_cgrp;
	struct css_set___111 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___162;

struct pipe_buffer___55;

struct pipe_inode_info___55 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___167 *tmp_page;
	struct fasync_struct___162 *fasync_readers;
	struct fasync_struct___162 *fasync_writers;
	struct pipe_buffer___55 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___111;

struct cgroup_subsys_state___111 {
	struct cgroup___111 *cgroup;
	struct cgroup_subsys___111 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___111 *parent;
};

struct cgroup_file___111 {
	struct kernfs_node___149 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___63;

struct mem_cgroup_per_node___63;

struct mem_cgroup___63 {
	struct cgroup_subsys_state___111 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___111 events_file;
	struct cgroup_file___111 events_local_file;
	struct cgroup_file___111 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___63 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___169 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___63 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___75;

struct blk_integrity___75 {
	const struct blk_integrity_profile___75 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___75 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___75 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___75;

struct elevator_queue___75;

struct blk_mq_ops___72;

struct blk_mq_hw_ctx___72;

struct gendisk___75;

struct blkcg_gq___72;

struct blk_mq_tag_set___72;

struct request_queue___75 {
	struct request___75 *last_merge;
	struct elevator_queue___75 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___72 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___72 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___75 *disk;
	struct kobject___149 kobj;
	struct kobject___149 *mq_kobj;
	struct blk_integrity___75 integrity;
	struct device___118 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___72 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___72 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___75 bio_split;
	struct dentry___162 *debugfs_dir;
	struct dentry___162 *sched_debugfs_dir;
	struct dentry___162 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___146 {
	struct vm_struct___146 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___167 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct psi_group___111 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___169 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___30;

struct cgroup_bpf___30 {
	struct bpf_prog_array___30 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___30 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___111;

struct cgroup_rstat_cpu___111;

struct cgroup___111 {
	struct cgroup_subsys_state___111 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___149 *kn;
	struct cgroup_file___111 procs_file;
	struct cgroup_file___111 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___111 *subsys[14];
	struct cgroup_root___111 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___111 *dom_cgrp;
	struct cgroup___111 *old_dom_cgrp;
	struct cgroup_rstat_cpu___111 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___111 psi;
	struct cgroup_bpf___30 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct shrink_control___63 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___63 *memcg;
};

struct shrinker___63 {
	long unsigned int (*count_objects)(struct shrinker___63 *, struct shrink_control___63 *);
	long unsigned int (*scan_objects)(struct shrinker___63 *, struct shrink_control___63 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___158 {
	void (*page_free)(struct page___167 *);
	void (*kill)(struct dev_pagemap___158 *);
	void (*cleanup)(struct dev_pagemap___158 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___158 *);
};

struct dentry_operations___162;

struct dentry___162 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___162 *d_parent;
	struct qstr d_name;
	struct inode___162 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___162 *d_op;
	struct super_block___162 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___162;

struct inode___162 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___162 *i_op;
	struct super_block___162 *i_sb;
	struct address_space___162 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___72 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___162 *i_fop;
		void (*free_inode)(struct inode___162 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___162 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___55 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___162 {
	int (*d_revalidate)(struct dentry___162 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___162 *, unsigned int);
	int (*d_hash)(const struct dentry___162 *, struct qstr *);
	int (*d_compare)(const struct dentry___162 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___162 *);
	int (*d_init)(struct dentry___162 *);
	void (*d_release)(struct dentry___162 *);
	void (*d_prune)(struct dentry___162 *);
	void (*d_iput)(struct dentry___162 *, struct inode___162 *);
	char * (*d_dname)(struct dentry___162 *, char *, int);
	struct vfsmount___162 * (*d_automount)(struct path___162 *);
	int (*d_manage)(const struct path___162 *, bool);
	struct dentry___162 * (*d_real)(struct dentry___162 *, const struct inode___162 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___162;

struct mem_dqinfo___162 {
	struct quota_format_type___162 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___162;

struct quota_info___162 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___162 *files[3];
	struct mem_dqinfo___162 info[3];
	const struct quota_format_ops___162 *ops[3];
};

struct rcuwait___163 {
	struct task_struct___169 *task;
};

struct percpu_rw_semaphore___163 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___163 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___162 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___163 rw_sem[3];
};

struct super_operations___162;

struct dquot_operations___162;

struct quotactl_ops___162;

struct block_device___76;

struct super_block___162 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___162 *s_type;
	const struct super_operations___162 *s_op;
	const struct dquot_operations___162 *dq_op;
	const struct quotactl_ops___162 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___162 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___76 *s_bdev;
	struct backing_dev_info___72 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___162 s_dquot;
	struct sb_writers___162 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___162 *s_d_op;
	int cleancache_poolid;
	struct shrinker___63 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___162 {
	struct dentry___162 *mnt_root;
	struct super_block___162 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct io_cq___75 {
	struct request_queue___75 *q;
	struct io_context___75 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___162 {
	struct file___162 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___162 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___162 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___162 *ia_file;
};

struct dquot___162 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___162 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___162 {
	int qf_fmt_id;
	const struct quota_format_ops___162 *qf_ops;
	struct module___146 *qf_owner;
	struct quota_format_type___162 *qf_next;
};

struct quota_format_ops___162 {
	int (*check_quota_file)(struct super_block___162 *, int);
	int (*read_file_info)(struct super_block___162 *, int);
	int (*write_file_info)(struct super_block___162 *, int);
	int (*free_file_info)(struct super_block___162 *, int);
	int (*read_dqblk)(struct dquot___162 *);
	int (*commit_dqblk)(struct dquot___162 *);
	int (*release_dqblk)(struct dquot___162 *);
	int (*get_next_id)(struct super_block___162 *, struct kqid *);
};

struct dquot_operations___162 {
	int (*write_dquot)(struct dquot___162 *);
	struct dquot___162 * (*alloc_dquot)(struct super_block___162 *, int);
	void (*destroy_dquot)(struct dquot___162 *);
	int (*acquire_dquot)(struct dquot___162 *);
	int (*release_dquot)(struct dquot___162 *);
	int (*mark_dirty)(struct dquot___162 *);
	int (*write_info)(struct super_block___162 *, int);
	qsize_t * (*get_reserved_space)(struct inode___162 *);
	int (*get_projid)(struct inode___162 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___162 *, qsize_t *);
	int (*get_next_id)(struct super_block___162 *, struct kqid *);
};

struct quotactl_ops___162 {
	int (*quota_on)(struct super_block___162 *, int, int, const struct path___162 *);
	int (*quota_off)(struct super_block___162 *, int);
	int (*quota_enable)(struct super_block___162 *, unsigned int);
	int (*quota_disable)(struct super_block___162 *, unsigned int);
	int (*quota_sync)(struct super_block___162 *, int);
	int (*set_info)(struct super_block___162 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___162 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___162 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___162 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___162 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___162 *, unsigned int);
};

struct writeback_control___72;

struct address_space_operations___162 {
	int (*writepage)(struct page___167 *, struct writeback_control___72 *);
	int (*readpage)(struct file___162 *, struct page___167 *);
	int (*writepages)(struct address_space___162 *, struct writeback_control___72 *);
	int (*set_page_dirty)(struct page___167 *);
	int (*readpages)(struct file___162 *, struct address_space___162 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___162 *, struct address_space___162 *, loff_t, unsigned int, unsigned int, struct page___167 **, void **);
	int (*write_end)(struct file___162 *, struct address_space___162 *, loff_t, unsigned int, unsigned int, struct page___167 *, void *);
	sector_t (*bmap)(struct address_space___162 *, sector_t);
	void (*invalidatepage)(struct page___167 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___167 *, gfp_t);
	void (*freepage)(struct page___167 *);
	ssize_t (*direct_IO)(struct kiocb___162 *, struct iov_iter___91 *);
	int (*migratepage)(struct address_space___162 *, struct page___167 *, struct page___167 *, enum migrate_mode);
	bool (*isolate_page)(struct page___167 *, isolate_mode_t);
	void (*putback_page)(struct page___167 *);
	int (*launder_page)(struct page___167 *);
	int (*is_partially_uptodate)(struct page___167 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___167 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___162 *, struct page___167 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___162 *, sector_t *);
	void (*swap_deactivate)(struct file___162 *);
};

struct writeback_control___72 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___72 *wb;
	struct inode___162 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___89;

struct iov_iter___91 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___89 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___55 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___162 {
	struct dentry___162 * (*lookup)(struct inode___162 *, struct dentry___162 *, unsigned int);
	const char * (*get_link)(struct dentry___162 *, struct inode___162 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___162 *, int);
	struct posix_acl * (*get_acl)(struct inode___162 *, int, bool);
	int (*readlink)(struct dentry___162 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___162 *, struct dentry___162 *, umode_t, bool);
	int (*link)(struct dentry___162 *, struct inode___162 *, struct dentry___162 *);
	int (*unlink)(struct inode___162 *, struct dentry___162 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___162 *, struct dentry___162 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___162 *, struct dentry___162 *, umode_t);
	int (*rmdir)(struct inode___162 *, struct dentry___162 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___162 *, struct dentry___162 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___162 *, struct dentry___162 *, struct inode___162 *, struct dentry___162 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___162 *, struct iattr___162 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___162 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___162 *, char *, size_t);
	int (*fiemap)(struct inode___162 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___162 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___162 *, struct dentry___162 *, struct file___162 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___162 *, struct dentry___162 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___162 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___162 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___162 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___162 {
	void (*fl_copy_lock)(struct file_lock___162 *, struct file_lock___162 *);
	void (*fl_release_private)(struct file_lock___162 *);
};

struct lock_manager_operations___162;

struct file_lock___162 {
	struct file_lock___162 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___162 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___162 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___162 *fl_ops;
	const struct lock_manager_operations___162 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___162 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___162 *);
	int (*lm_grant)(struct file_lock___162 *, int);
	bool (*lm_break)(struct file_lock___162 *);
	int (*lm_change)(struct file_lock___162 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___162 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___162 *);
};

struct fasync_struct___162 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___162 *fa_next;
	struct file___162 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___162 {
	struct inode___162 * (*alloc_inode)(struct super_block___162 *);
	void (*destroy_inode)(struct inode___162 *);
	void (*free_inode)(struct inode___162 *);
	void (*dirty_inode)(struct inode___162 *, int);
	int (*write_inode)(struct inode___162 *, struct writeback_control___72 *);
	int (*drop_inode)(struct inode___162 *);
	void (*evict_inode)(struct inode___162 *);
	void (*put_super)(struct super_block___162 *);
	int (*sync_fs)(struct super_block___162 *, int);
	int (*freeze_super)(struct super_block___162 *);
	int (*freeze_fs)(struct super_block___162 *);
	int (*thaw_super)(struct super_block___162 *);
	int (*unfreeze_fs)(struct super_block___162 *);
	int (*statfs)(struct dentry___162 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___162 *, int *, char *);
	void (*umount_begin)(struct super_block___162 *);
	int (*show_options)(struct seq_file___140 *, struct dentry___162 *);
	int (*show_devname)(struct seq_file___140 *, struct dentry___162 *);
	int (*show_path)(struct seq_file___140 *, struct dentry___162 *);
	int (*show_stats)(struct seq_file___140 *, struct dentry___162 *);
	ssize_t (*quota_read)(struct super_block___162 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___162 *, int, const char *, size_t, loff_t);
	struct dquot___162 ** (*get_dquots)(struct inode___162 *);
	long int (*nr_cached_objects)(struct super_block___162 *, struct shrink_control___63 *);
	long int (*free_cached_objects)(struct super_block___162 *, struct shrink_control___63 *);
	struct file___162 * (*real_loop)(struct file___162 *);
};

struct wakeup_source___118;

struct dev_pm_info___118 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___118 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___118 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___118;

struct bus_type___118;

struct device_driver___118;

struct dev_pm_domain___118;

struct fwnode_handle___118;

struct class___118;

struct attribute_group___149;

struct device___118 {
	struct kobject___149 kobj;
	struct device___118 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___118 *type;
	struct bus_type___118 *bus;
	struct device_driver___118 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___118 power;
	struct dev_pm_domain___118 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___118 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___118 *class;
	const struct attribute_group___149 **groups;
	void (*release)(struct device___118 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___76 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___162 *bd_inode;
	struct super_block___162 *bd_super;
	void *bd_claiming;
	struct device___118 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___149 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___75 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___162 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___105)(struct file___162 *, wait_queue_head_t *, struct poll_table_struct___103 *);

struct poll_table_struct___103 {
	poll_queue_proc___105 _qproc;
	__poll_t _key;
};

struct seq_operations___140;

struct seq_file___140 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___140 *op;
	int poll_event;
	const struct file___162 *file;
	void *private;
};

typedef void bio_end_io_t___75(struct bio___75 *);

struct bio_vec___89 {
	struct page___167 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___75;

struct bio___75 {
	struct bio___75 *bi_next;
	struct block_device___76 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___75 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___72 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___75 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___89 *bi_io_vec;
	struct bio_set___75 *bi_pool;
	struct bio_vec___89 bi_inline_vecs[0];
};

struct ip_ra_chain___10;

struct fib_rules_ops___23;

struct sock___24;

struct fqdir___35;

struct fib_notifier_ops___23;

struct netns_ipv4___35 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___10 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___23 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___24 *fibnl;
	struct sock___24 **icmp_sk;
	struct sock___24 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___24 **tcp_sk;
	struct fqdir___35 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___23 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___23 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___23 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___23;

struct net_device___32;

struct sk_buff___31;

struct neighbour___23;

struct dst_ops___35 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___35 *);
	struct dst_entry___23 * (*check)(struct dst_entry___23 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___23 *);
	unsigned int (*mtu)(const struct dst_entry___23 *);
	u32 * (*cow_metrics)(struct dst_entry___23 *, long unsigned int);
	void (*destroy)(struct dst_entry___23 *);
	void (*ifdown)(struct dst_entry___23 *, struct net_device___32 *, int);
	struct dst_entry___23 * (*negative_advice)(struct dst_entry___23 *);
	void (*link_failure)(struct sk_buff___31 *);
	void (*update_pmtu)(struct dst_entry___23 *, struct sock___24 *, struct sk_buff___31 *, u32, bool);
	void (*redirect)(struct dst_entry___23 *, struct sock___24 *, struct sk_buff___31 *);
	int (*local_out)(struct net___35 *, struct sock___24 *, struct sk_buff___31 *);
	struct neighbour___23 * (*neigh_lookup)(const struct dst_entry___23 *, struct sk_buff___31 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___23 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___35 {
	struct dst_ops___35 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___35 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___23 *fib6_rules_ops;
	struct sock___24 **icmp_sk;
	struct sock___24 *ndisc_sk;
	struct sock___24 *tcp_sk;
	struct sock___24 *igmp_sk;
	struct sock___24 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___23 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___23 *notifier_ops;
	struct fib_notifier_ops___23 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___35 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___35 *fqdir;
};

struct netns_sctp___23 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___24 *ctl_sock;
	struct sock___24 *udp4_sock;
	struct sock___24 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___30 {
	struct sk_buff___31 *next;
	struct sk_buff___31 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___30;

struct netns_bpf___30 {
	struct bpf_prog_array___30 *run_array[2];
	struct bpf_prog___30 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___35 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___24 *nlsk;
	struct sock___24 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___35 xfrm4_dst_ops;
	struct dst_ops___35 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___35 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___24 *rtnl;
	struct sock___24 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___32 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___35 ipv4;
	struct netns_ipv6___35 ipv6;
	struct netns_ieee802154_lowpan___35 ieee802154_lowpan;
	struct netns_sctp___23 sctp;
	struct netns_nf___2 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___30 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___30 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___35 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___24 *crypto_nlsk;
	struct sock___24 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___111 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___111 *root_cset;
};

struct msghdr___24 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___91 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___162 *msg_iocb;
};

struct fwnode_operations___118;

struct fwnode_handle___118 {
	struct fwnode_handle___118 *secondary;
	const struct fwnode_operations___118 *ops;
	struct device___118 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___118;

struct fwnode_endpoint___118;

struct fwnode_operations___118 {
	struct fwnode_handle___118 * (*get)(struct fwnode_handle___118 *);
	void (*put)(struct fwnode_handle___118 *);
	bool (*device_is_available)(const struct fwnode_handle___118 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___118 *, const struct device___118 *);
	bool (*property_present)(const struct fwnode_handle___118 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___118 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___118 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___118 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*get_parent)(const struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*get_next_child_node)(const struct fwnode_handle___118 *, struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*get_named_child_node)(const struct fwnode_handle___118 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___118 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___118 *);
	struct fwnode_handle___118 * (*graph_get_next_endpoint)(const struct fwnode_handle___118 *, struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*graph_get_remote_endpoint)(const struct fwnode_handle___118 *);
	struct fwnode_handle___118 * (*graph_get_port_parent)(struct fwnode_handle___118 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___118 *, struct fwnode_endpoint___118 *);
	int (*add_links)(struct fwnode_handle___118 *);
};

struct fwnode_endpoint___118 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___118 *local_fwnode;
};

struct fwnode_reference_args___118 {
	struct fwnode_handle___118 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___149;

struct kernfs_elem_dir___149 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___149 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___149;

struct kernfs_root___149 {
	struct kernfs_node___149 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___149 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___149 {
	struct kernfs_node___149 *target_kn;
};

struct kernfs_ops___149;

struct kernfs_elem_attr___149 {
	const struct kernfs_ops___149 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___149 *notify_next;
};

struct kernfs_node___149 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___149 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___149 dir;
		struct kernfs_elem_symlink___149 symlink;
		struct kernfs_elem_attr___149 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___149;

struct kernfs_ops___149 {
	int (*open)(struct kernfs_open_file___149 *);
	void (*release)(struct kernfs_open_file___149 *);
	int (*seq_show)(struct seq_file___140 *, void *);
	void * (*seq_start)(struct seq_file___140 *, loff_t *);
	void * (*seq_next)(struct seq_file___140 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___140 *, void *);
	ssize_t (*read)(struct kernfs_open_file___149 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___149 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___149 *, struct poll_table_struct___103 *);
	int (*mmap)(struct kernfs_open_file___149 *, struct vm_area_struct___167 *);
};

struct kernfs_syscall_ops___149 {
	int (*show_options)(struct seq_file___140 *, struct kernfs_root___149 *);
	int (*mkdir)(struct kernfs_node___149 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___149 *);
	int (*rename)(struct kernfs_node___149 *, struct kernfs_node___149 *, const char *);
	int (*show_path)(struct seq_file___140 *, struct kernfs_node___149 *, struct kernfs_root___149 *);
};

struct kernfs_open_file___149 {
	struct kernfs_node___149 *kn;
	struct file___162 *file;
	struct seq_file___140 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___158 *vm_ops;
};

struct kobj_ns_type_operations___23 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___24 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___35 *net;
} possible_net_t___30;

struct proto___23;

struct sock_common___23 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___23 *skc_prot;
	possible_net_t___30 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___24 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___23 {
	struct cgroup___111 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___23;

struct socket_wq___24;

struct socket___24;

struct sock___24 {
	struct sock_common___23 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___30 sk_error_queue;
	struct sk_buff___31 *sk_rx_skb_cache;
	struct sk_buff_head___30 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___31 *head;
		struct sk_buff___31 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___23 *sk_filter;
	union {
		struct socket_wq___24 *sk_wq;
		struct socket_wq___24 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___23 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___23 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___31 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___31 *sk_tx_skb_cache;
	struct sk_buff_head___30 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___167 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___23 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___143 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___24 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___23 sk_cgrp_data;
	struct mem_cgroup___63 *sk_memcg;
	void (*sk_state_change)(struct sock___24 *);
	void (*sk_data_ready)(struct sock___24 *);
	void (*sk_write_space)(struct sock___24 *);
	void (*sk_error_report)(struct sock___24 *);
	int (*sk_backlog_rcv)(struct sock___24 *, struct sk_buff___31 *);
	struct sk_buff___31 * (*sk_validate_xmit_skb)(struct sock___24 *, struct net_device___32 *, struct sk_buff___31 *);
	void (*sk_destruct)(struct sock___24 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___149;

struct attribute_group___149 {
	const char *name;
	umode_t (*is_visible)(struct kobject___149 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___149 *, struct bin_attribute___149 *, int);
	struct attribute **attrs;
	struct bin_attribute___149 **bin_attrs;
};

struct bin_attribute___149 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___162 * (*f_mapping)();
	ssize_t (*read)(struct file___162 *, struct kobject___149 *, struct bin_attribute___149 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___162 *, struct kobject___149 *, struct bin_attribute___149 *, char *, loff_t, size_t);
	int (*mmap)(struct file___162 *, struct kobject___149 *, struct bin_attribute___149 *, struct vm_area_struct___167 *);
};

struct sysfs_ops___149 {
	ssize_t (*show)(struct kobject___149 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___149 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___149;

struct kset___149 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___149 kobj;
	const struct kset_uevent_ops___149 *uevent_ops;
};

struct kobj_type___149 {
	void (*release)(struct kobject___149 *);
	const struct sysfs_ops___149 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___149 **default_groups;
	const struct kobj_ns_type_operations___23 * (*child_ns_type)(struct kobject___149 *);
	const void * (*namespace)(struct kobject___149 *);
	void (*get_ownership)(struct kobject___149 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___149 {
	int (* const filter)(struct kset___149 *, struct kobject___149 *);
	const char * (* const name)(struct kset___149 *, struct kobject___149 *);
	int (* const uevent)(struct kset___149 *, struct kobject___149 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___146 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___146 *);
	int (*get)(char *, const struct kernel_param___146 *);
	void (*free)(void *);
};

struct kparam_array___146;

struct kernel_param___146 {
	const char *name;
	struct module___146 *mod;
	const struct kernel_param_ops___146 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___146 *arr;
	};
};

struct kparam_array___146 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___146 *ops;
	void *elem;
};

struct module_attribute___146 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___146 *, struct module_kobject___146 *, char *);
	ssize_t (*store)(struct module_attribute___146 *, struct module_kobject___146 *, const char *, size_t);
	void (*setup)(struct module___146 *, const char *);
	int (*test)(struct module___146 *);
	void (*free)(struct module___146 *);
};

struct socket_wq___24 {
	wait_queue_head_t wait;
	struct fasync_struct___162 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___24;

struct socket___24 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___162 *file;
	struct sock___24 *sk;
	const struct proto_ops___24 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___24 wq;
};

typedef int (*sk_read_actor_t___23)(read_descriptor_t *, struct sk_buff___31 *, unsigned int, size_t);

struct proto_ops___24 {
	int family;
	struct module___146 *owner;
	int (*release)(struct socket___24 *);
	int (*bind)(struct socket___24 *, struct sockaddr *, int);
	int (*connect)(struct socket___24 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___24 *, struct socket___24 *);
	int (*accept)(struct socket___24 *, struct socket___24 *, int, bool);
	int (*getname)(struct socket___24 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___162 *, struct socket___24 *, struct poll_table_struct___103 *);
	int (*ioctl)(struct socket___24 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___24 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___24 *, void *, bool, bool);
	int (*listen)(struct socket___24 *, int);
	int (*shutdown)(struct socket___24 *, int);
	int (*setsockopt)(struct socket___24 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___24 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___140 *, struct socket___24 *);
	int (*sendmsg)(struct socket___24 *, struct msghdr___24 *, size_t);
	int (*recvmsg)(struct socket___24 *, struct msghdr___24 *, size_t, int);
	int (*mmap)(struct file___162 *, struct socket___24 *, struct vm_area_struct___167 *);
	ssize_t (*sendpage)(struct socket___24 *, struct page___167 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___24 *, loff_t *, struct pipe_inode_info___55 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___24 *, int);
	int (*peek_len)(struct socket___24 *);
	int (*read_sock)(struct sock___24 *, read_descriptor_t *, sk_read_actor_t___23);
	int (*sendpage_locked)(struct sock___24 *, struct page___167 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___24 *, struct msghdr___24 *, size_t);
	int (*set_rcvlowat)(struct sock___24 *, int);
};

struct sk_buff___31 {
	union {
		struct {
			struct sk_buff___31 *next;
			struct sk_buff___31 *prev;
			union {
				struct net_device___32 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___24 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___31 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___118 {
	int (*prepare)(struct device___118 *);
	void (*complete)(struct device___118 *);
	int (*suspend)(struct device___118 *);
	int (*resume)(struct device___118 *);
	int (*freeze)(struct device___118 *);
	int (*thaw)(struct device___118 *);
	int (*poweroff)(struct device___118 *);
	int (*restore)(struct device___118 *);
	int (*suspend_late)(struct device___118 *);
	int (*resume_early)(struct device___118 *);
	int (*freeze_late)(struct device___118 *);
	int (*thaw_early)(struct device___118 *);
	int (*poweroff_late)(struct device___118 *);
	int (*restore_early)(struct device___118 *);
	int (*suspend_noirq)(struct device___118 *);
	int (*resume_noirq)(struct device___118 *);
	int (*freeze_noirq)(struct device___118 *);
	int (*thaw_noirq)(struct device___118 *);
	int (*poweroff_noirq)(struct device___118 *);
	int (*restore_noirq)(struct device___118 *);
	int (*runtime_suspend)(struct device___118 *);
	int (*runtime_resume)(struct device___118 *);
	int (*runtime_idle)(struct device___118 *);
};

struct wakeup_source___118 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___118 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___118 {
	struct dev_pm_ops___118 ops;
	int (*start)(struct device___118 *);
	void (*detach)(struct device___118 *, bool);
	int (*activate)(struct device___118 *);
	void (*sync)(struct device___118 *);
	void (*dismiss)(struct device___118 *);
};

struct bus_type___118 {
	const char *name;
	const char *dev_name;
	struct device___118 *dev_root;
	const struct attribute_group___149 **bus_groups;
	const struct attribute_group___149 **dev_groups;
	const struct attribute_group___149 **drv_groups;
	int (*match)(struct device___118 *, struct device_driver___118 *);
	int (*uevent)(struct device___118 *, struct kobj_uevent_env *);
	int (*probe)(struct device___118 *);
	void (*sync_state)(struct device___118 *);
	void (*remove)(struct device___118 *);
	void (*shutdown)(struct device___118 *);
	int (*online)(struct device___118 *);
	int (*offline)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	int (*num_vf)(struct device___118 *);
	int (*dma_configure)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___118 {
	const char *name;
	struct bus_type___118 *bus;
	struct module___146 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___118 *);
	void (*sync_state)(struct device___118 *);
	int (*remove)(struct device___118 *);
	void (*shutdown)(struct device___118 *);
	int (*suspend)(struct device___118 *, pm_message_t);
	int (*resume)(struct device___118 *);
	const struct attribute_group___149 **groups;
	const struct attribute_group___149 **dev_groups;
	const struct dev_pm_ops___118 *pm;
	void (*coredump)(struct device___118 *);
	struct driver_private *p;
};

struct device_type___118 {
	const char *name;
	const struct attribute_group___149 **groups;
	int (*uevent)(struct device___118 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___118 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___118 *);
	const struct dev_pm_ops___118 *pm;
};

struct class___118 {
	const char *name;
	struct module___146 *owner;
	const struct attribute_group___149 **class_groups;
	const struct attribute_group___149 **dev_groups;
	struct kobject___149 *dev_kobj;
	int (*dev_uevent)(struct device___118 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___118 *, umode_t *);
	void (*class_release)(struct class___118 *);
	void (*dev_release)(struct device___118 *);
	int (*shutdown_pre)(struct device___118 *);
	const struct kobj_ns_type_operations___23 *ns_type;
	const void * (*namespace)(struct device___118 *);
	void (*get_ownership)(struct device___118 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___118 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___55;

struct pipe_buffer___55 {
	struct page___167 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___55 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___55 {
	int (*confirm)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
	void (*release)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
	bool (*try_steal)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
	bool (*get)(struct pipe_inode_info___55 *, struct pipe_buffer___55 *);
};

typedef rx_handler_result_t rx_handler_func_t___30(struct sk_buff___31 **);

struct bpf_xdp_entity___30 {
	struct bpf_prog___30 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___30;

struct net_device_ops___30;

struct ethtool_ops___8;

struct l3mdev_ops___23;

struct ndisc_ops___13;

struct xfrmdev_ops___30;

struct header_ops___30;

struct inet6_dev___13;

struct netdev_rx_queue___30;

struct mini_Qdisc___30;

struct netdev_queue___30;

struct Qdisc___30;

struct rtnl_link_ops___30;

struct dcbnl_rtnl_ops___30;

struct net_device___32 {
	char name[16];
	struct netdev_name_node___30 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___30 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___8 *ethtool_ops;
	const struct l3mdev_ops___23 *l3mdev_ops;
	const struct ndisc_ops___13 *ndisc_ops;
	const struct xfrmdev_ops___30 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___30 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___149 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___13 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___30 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___30 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___30 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___30 *miniq_ingress;
	struct netdev_queue___30 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___30 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___30 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___30 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___30 = 0,
		NETREG_REGISTERED___30 = 1,
		NETREG_UNREGISTERING___30 = 2,
		NETREG_UNREGISTERED___30 = 3,
		NETREG_RELEASED___30 = 4,
		NETREG_DUMMY___30 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___30 = 0,
		RTNL_LINK_INITIALIZING___30 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___32 *);
	struct netpoll_info *npinfo;
	possible_net_t___30 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___118 dev;
	const struct attribute_group___149 *sysfs_groups[4];
	const struct attribute_group___149 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___30 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___30 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___30 xdp_state[3];
	long: 64;
};

struct netlink_callback___30 {
	struct sk_buff___31 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___31 *, struct netlink_callback___30 *);
	int (*done)(struct netlink_callback___30 *);
	void *data;
	struct module___146 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_ops___8 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___32 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___32 *);
	void (*get_regs)(struct net_device___32 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___32 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___32 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___32 *);
	void (*set_msglevel)(struct net_device___32 *, u32);
	int (*nway_reset)(struct net_device___32 *);
	u32 (*get_link)(struct net_device___32 *);
	int (*get_link_ext_state)(struct net_device___32 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___32 *);
	int (*get_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___32 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___32 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___32 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___32 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___32 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___32 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___32 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___32 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___32 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___32 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___32 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___32 *);
	void (*complete)(struct net_device___32 *);
	u32 (*get_priv_flags)(struct net_device___32 *);
	int (*set_priv_flags)(struct net_device___32 *, u32);
	int (*get_sset_count)(struct net_device___32 *, int);
	int (*get_rxnfc)(struct net_device___32 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___32 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___32 *, struct ethtool_flash *);
	int (*reset)(struct net_device___32 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___32 *);
	u32 (*get_rxfh_indir_size)(struct net_device___32 *);
	int (*get_rxfh)(struct net_device___32 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___32 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___32 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___32 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___32 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___32 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___32 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___32 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___32 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___32 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___32 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___32 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___32 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___32 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___32 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___32 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___32 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___32 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___32 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___32 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___32 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___32 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___32 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___32 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___32 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___32 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___32 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___32 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___32 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___32 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___32 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct inet_frags___35;

struct fqdir___35 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___35 *f;
	struct net___35 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___35;

struct inet_frags___35 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___35 *, const void *);
	void (*destructor)(struct inet_frag_queue___35 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___35 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___31 *fragments_tail;
	struct sk_buff___31 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___35 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___10 {
	struct ip_ra_chain___10 *next;
	struct sock___24 *sk;
	union {
		void (*destructor)(struct sock___24 *);
		struct sock___24 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___23;

struct fib_lookup_arg___23;

struct fib_rules_ops___23 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___23 *, struct flowi *, int, struct fib_lookup_arg___23 *);
	bool (*suppress)(struct fib_rule___23 *, int, struct fib_lookup_arg___23 *);
	int (*match)(struct fib_rule___23 *, struct flowi *, int);
	int (*configure)(struct fib_rule___23 *, struct sk_buff___31 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___23 *);
	int (*compare)(struct fib_rule___23 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___23 *, struct sk_buff___31 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___23 *);
	void (*flush_cache)(struct fib_rules_ops___23 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___146 *owner;
	struct net___35 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___23 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___35 *);
	int (*fib_dump)(struct net___35 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___146 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___10;

struct dst_entry___23 {
	struct net_device___32 *dev;
	struct dst_ops___35 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___31 *);
	int (*output)(struct net___35 *, struct sock___24 *, struct sk_buff___31 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___10 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___23;

struct neigh_parms___23;

struct neigh_ops___23;

struct neighbour___23 {
	struct neighbour___23 *next;
	struct neigh_table___23 *tbl;
	struct neigh_parms___23 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___30 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___23 *, struct sk_buff___31 *);
	const struct neigh_ops___23 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___32 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___30 {
	struct bpf_prog___30 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___30 {
	struct callback_head rcu;
	struct bpf_prog_array_item___30 items[0];
};

struct bpf_prog_aux___32;

struct bpf_prog___30 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___32 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___140 {
	void * (*start)(struct seq_file___140 *, loff_t *);
	void (*stop)(struct seq_file___140 *, void *);
	void * (*next)(struct seq_file___140 *, void *, loff_t *);
	int (*show)(struct seq_file___140 *, void *);
};

struct dcbnl_rtnl_ops___30 {
	int (*ieee_getets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___32 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___32 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___32 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___32 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___32 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___32 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___32 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___32 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___32 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___32 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___32 *);
	u8 (*setstate)(struct net_device___32 *, u8);
	void (*getpermhwaddr)(struct net_device___32 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___32 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___32 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___32 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___32 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___32 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___32 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___32 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___32 *, int, u8 *);
	void (*setpfccfg)(struct net_device___32 *, int, u8);
	void (*getpfccfg)(struct net_device___32 *, int, u8 *);
	u8 (*setall)(struct net_device___32 *);
	u8 (*getcap)(struct net_device___32 *, int, u8 *);
	int (*getnumtcs)(struct net_device___32 *, int, u8 *);
	int (*setnumtcs)(struct net_device___32 *, int, u8);
	u8 (*getpfcstate)(struct net_device___32 *);
	void (*setpfcstate)(struct net_device___32 *, u8);
	void (*getbcncfg)(struct net_device___32 *, int, u32 *);
	void (*setbcncfg)(struct net_device___32 *, int, u32);
	void (*getbcnrp)(struct net_device___32 *, int, u8 *);
	void (*setbcnrp)(struct net_device___32 *, int, u8);
	int (*setapp)(struct net_device___32 *, u8, u16, u8);
	int (*getapp)(struct net_device___32 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___32 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___32 *, int, u8);
	u8 (*getdcbx)(struct net_device___32 *);
	u8 (*setdcbx)(struct net_device___32 *, u8);
	int (*peer_getappinfo)(struct net_device___32 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___32 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___32 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___32 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___32 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___32 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___33;

typedef int (*bpf_iter_init_seq_priv_t___32)(void *, struct bpf_iter_aux_info___33 *);

struct bpf_map___32;

struct bpf_iter_aux_info___33 {
	struct bpf_map___32 *map;
};

struct bpf_iter_seq_info___32 {
	const struct seq_operations___140 *seq_ops;
	bpf_iter_init_seq_priv_t___32 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___32 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___32 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___32 *, struct file___162 *);
	void (*map_free)(struct bpf_map___32 *);
	int (*map_get_next_key)(struct bpf_map___32 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___32 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___32 *, void *);
	int (*map_lookup_batch)(struct bpf_map___32 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___32 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___32 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___32 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___32 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___32 *, void *);
	int (*map_update_elem)(struct bpf_map___32 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___32 *, void *);
	int (*map_push_elem)(struct bpf_map___32 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___32 *, void *);
	int (*map_peek_elem)(struct bpf_map___32 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___32 *, struct file___162 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___32 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___32 *, void *, struct seq_file___140 *);
	int (*map_check_btf)(const struct bpf_map___32 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___32 *, struct bpf_prog_aux___32 *);
	void (*map_poke_untrack)(struct bpf_map___32 *, struct bpf_prog_aux___32 *);
	void (*map_poke_run)(struct bpf_map___32 *, u32, struct bpf_prog___30 *, struct bpf_prog___30 *);
	int (*map_direct_value_addr)(const struct bpf_map___32 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___32 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___32 *, struct vm_area_struct___167 *);
	__poll_t (*map_poll)(struct bpf_map___32 *, struct file___162 *, struct poll_table_struct___103 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___32 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___32 *, const struct bpf_map___32 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___32 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___32 *iter_seq_info;
};

struct bpf_map___32 {
	const struct bpf_map_ops___32 *ops;
	struct bpf_map___32 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___63 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___32;

struct bpf_jit_poke_descriptor___32;

struct bpf_prog_ops___30;

struct btf_mod_pair___32;

struct bpf_prog_offload___30;

struct bpf_prog_aux___32 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___30 *dst_prog;
	struct bpf_trampoline___32 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___30 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___32 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___30 *ops;
	struct bpf_map___32 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___32 *used_btfs;
	struct bpf_prog___30 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___32 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___30 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___30;

struct bpf_map_dev_ops___30 {
	int (*map_get_next_key)(struct bpf_offloaded_map___30 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___30 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___30 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___30 *, void *);
};

struct bpf_offloaded_map___30 {
	struct bpf_map___32 map;
	struct net_device___32 *netdev;
	const struct bpf_map_dev_ops___30 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___30 {
	int (*test_run)(struct bpf_prog___30 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___30 {
	struct bpf_prog___30 *prog;
	struct net_device___32 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___32 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___30 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___146 *mod;
};

struct bpf_jit_poke_descriptor___32 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___32 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___32 {
	struct btf *btf;
	struct module___146 *module;
};

struct cftype___111;

struct cgroup_subsys___111 {
	struct cgroup_subsys_state___111 * (*css_alloc)(struct cgroup_subsys_state___111 *);
	int (*css_online)(struct cgroup_subsys_state___111 *);
	void (*css_offline)(struct cgroup_subsys_state___111 *);
	void (*css_released)(struct cgroup_subsys_state___111 *);
	void (*css_free)(struct cgroup_subsys_state___111 *);
	void (*css_reset)(struct cgroup_subsys_state___111 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___111 *, int);
	int (*css_extra_stat_show)(struct seq_file___140 *, struct cgroup_subsys_state___111 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___169 *, struct css_set___111 *);
	void (*cancel_fork)(struct task_struct___169 *, struct css_set___111 *);
	void (*fork)(struct task_struct___169 *);
	void (*exit)(struct task_struct___169 *);
	void (*release)(struct task_struct___169 *);
	void (*bind)(struct cgroup_subsys_state___111 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___111 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___111 *dfl_cftypes;
	struct cftype___111 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___111 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___111 *updated_children;
	struct cgroup___111 *updated_next;
};

struct cgroup_root___111 {
	struct kernfs_root___149 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___111 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___111 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___111 *ss;
	struct list_head node;
	struct kernfs_ops___149 *kf_ops;
	int (*open)(struct kernfs_open_file___149 *);
	void (*release)(struct kernfs_open_file___149 *);
	u64 (*read_u64)(struct cgroup_subsys_state___111 *, struct cftype___111 *);
	s64 (*read_s64)(struct cgroup_subsys_state___111 *, struct cftype___111 *);
	int (*seq_show)(struct seq_file___140 *, void *);
	void * (*seq_start)(struct seq_file___140 *, loff_t *);
	void * (*seq_next)(struct seq_file___140 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___140 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___111 *, struct cftype___111 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___111 *, struct cftype___111 *, s64);
	ssize_t (*write)(struct kernfs_open_file___149 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___149 *, struct poll_table_struct___103 *);
};

struct xdp_rxq_info___30 {
	struct net_device___32 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___30 {
	struct net_device___32 *dev;
};

struct xdp_buff___30 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___30 *rxq;
	struct xdp_txq_info___30 *txq;
	u32 frame_sz;
};

struct xdp_frame___30 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___32 *dev_rx;
};

struct header_ops___30 {
	int (*create)(struct sk_buff___31 *, struct net_device___32 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___31 *, unsigned char *);
	int (*cache)(const struct neighbour___23 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___32 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___31 *);
};

struct netdev_queue___30 {
	struct net_device___32 *dev;
	struct Qdisc___30 *qdisc;
	struct Qdisc___30 *qdisc_sleeping;
	struct kobject___149 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___32 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___30 {
	struct sk_buff___31 *head;
	struct sk_buff___31 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___30;

struct Qdisc___30 {
	int (*enqueue)(struct sk_buff___31 *, struct Qdisc___30 *, struct sk_buff___31 **);
	struct sk_buff___31 * (*dequeue)(struct Qdisc___30 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___30 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___30 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___30 gso_skb;
	struct qdisc_skb_head___30 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___30 *next_sched;
	struct sk_buff_head___30 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___30 {
	struct xdp_rxq_info___30 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___149 kobj;
	struct net_device___32 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___30 {
	enum net_device_path_type type;
	const struct net_device___32 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___30 = 0,
				DEV_PATH_BR_VLAN_TAG___30 = 1,
				DEV_PATH_BR_VLAN_UNTAG___30 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___30 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___30 {
	const struct net_device___32 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___30 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___30 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___30 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___30 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___31 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___30 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___32 *dev;
	const char *name;
};

struct net_device_ops___30 {
	int (*ndo_init)(struct net_device___32 *);
	void (*ndo_uninit)(struct net_device___32 *);
	int (*ndo_open)(struct net_device___32 *);
	int (*ndo_stop)(struct net_device___32 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___31 *, struct net_device___32 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___31 *, struct net_device___32 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___32 *, struct sk_buff___31 *, struct net_device___32 *);
	void (*ndo_change_rx_flags)(struct net_device___32 *, int);
	void (*ndo_set_rx_mode)(struct net_device___32 *);
	int (*ndo_set_mac_address)(struct net_device___32 *, void *);
	int (*ndo_validate_addr)(struct net_device___32 *);
	int (*ndo_do_ioctl)(struct net_device___32 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___32 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___32 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___32 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___32 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___32 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___32 *, int);
	int (*ndo_neigh_setup)(struct net_device___32 *, struct neigh_parms___23 *);
	void (*ndo_tx_timeout)(struct net_device___32 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___32 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___32 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___32 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___32 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___32 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___32 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___32 *);
	int (*ndo_netpoll_setup)(struct net_device___32 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___32 *);
	int (*ndo_set_vf_mac)(struct net_device___32 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___32 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___32 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___32 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___32 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___32 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___32 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___32 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___32 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___32 *, int, struct sk_buff___31 *);
	int (*ndo_get_vf_guid)(struct net_device___32 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___32 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___32 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___32 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___32 *);
	int (*ndo_fcoe_disable)(struct net_device___32 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___32 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___32 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___32 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___32 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___32 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___32 *, const struct sk_buff___31 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___32 *, struct net_device___32 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___32 *, struct net_device___32 *);
	struct net_device___32 * (*ndo_get_xmit_slave)(struct net_device___32 *, struct sk_buff___31 *, bool);
	struct net_device___32 * (*ndo_sk_get_lower_dev)(struct net_device___32 *, struct sock___24 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___32 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___32 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___32 *, struct neighbour___23 *);
	void (*ndo_neigh_destroy)(struct net_device___32 *, struct neighbour___23 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___31 *, struct netlink_callback___30 *, struct net_device___32 *, struct net_device___32 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___31 *, struct nlattr **, struct net_device___32 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___32 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___31 *, u32, u32, struct net_device___32 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___32 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___32 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___32 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___32 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___32 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___32 *, struct net_device___32 *);
	void (*ndo_dfwd_del_station)(struct net_device___32 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___32 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___32 *);
	int (*ndo_change_proto_down)(struct net_device___32 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___32 *, struct sk_buff___31 *);
	void (*ndo_set_rx_headroom)(struct net_device___32 *, int);
	int (*ndo_bpf)(struct net_device___32 *, struct netdev_bpf___30 *);
	int (*ndo_xdp_xmit)(struct net_device___32 *, int, struct xdp_frame___30 **, u32);
	struct net_device___32 * (*ndo_xdp_get_xmit_slave)(struct net_device___32 *, struct xdp_buff___30 *);
	int (*ndo_xsk_wakeup)(struct net_device___32 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___32 *);
	int (*ndo_tunnel_ctl)(struct net_device___32 *, struct ip_tunnel_parm *, int);
	struct net_device___32 * (*ndo_get_peer_dev)(struct net_device___32 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___30 *, struct net_device_path___30 *);
};

struct neigh_parms___23 {
	possible_net_t___30 net;
	struct net_device___32 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___23 *);
	struct neigh_table___23 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___23 {
	u32 (*l3mdev_fib_table)(const struct net_device___32 *);
	struct sk_buff___31 * (*l3mdev_l3_rcv)(struct net_device___32 *, struct sk_buff___31 *, u16);
	struct sk_buff___31 * (*l3mdev_l3_out)(struct net_device___32 *, struct sock___24 *, struct sk_buff___31 *, u16);
	struct dst_entry___23 * (*l3mdev_link_scope_lookup)(const struct net_device___32 *, struct flowi6 *);
};

struct ndisc_ops___13 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___32 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___32 *, struct neighbour___23 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___32 *, u8, struct neighbour___23 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___32 *, struct sk_buff___31 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___35 *, struct net_device___32 *, const struct prefix_info *, struct inet6_dev___13 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___13;

struct inet6_dev___13 {
	struct net_device___32 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___13 *mc_list;
	struct ifmcaddr6___13 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___30 mc_query_queue;
	struct sk_buff_head___30 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___23 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___30;

struct tcf_block___30;

struct mini_Qdisc___30 {
	struct tcf_proto___30 *filter_list;
	struct tcf_block___30 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___30 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___32 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___32 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___35 *, struct net_device___32 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___32 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___32 *, struct list_head *);
	size_t (*get_size)(const struct net_device___32 *);
	int (*fill_info)(struct sk_buff___31 *, const struct net_device___32 *);
	size_t (*get_xstats_size)(const struct net_device___32 *);
	int (*fill_xstats)(struct sk_buff___31 *, const struct net_device___32 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___32 *, struct net_device___32 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___32 *, const struct net_device___32 *);
	int (*fill_slave_info)(struct sk_buff___31 *, const struct net_device___32 *, const struct net_device___32 *);
	struct net___35 * (*get_link_net)(const struct net_device___32 *);
	size_t (*get_linkxstats_size)(const struct net_device___32 *, int);
	int (*fill_linkxstats)(struct sk_buff___31 *, const struct net_device___32 *, int *, int);
};

struct block_device_operations___75;

struct gendisk___75 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___76 *part0;
	const struct block_device_operations___75 *fops;
	struct request_queue___75 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___72 *bdi;
	struct kobject___149 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___149 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___75 {
	struct bio___75 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___89 *bip_vec;
	struct bio_vec___89 bip_inline_vecs[0];
};

struct blkcg___72;

struct blkg_policy_data___72;

struct blkcg_gq___72 {
	struct request_queue___75 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___72 *blkcg;
	struct blkcg_gq___72 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___72 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___75 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___75(struct request___75 *);

typedef void integrity_complete_fn___75(struct request___75 *, unsigned int);

struct blk_integrity_profile___75 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___75 *prepare_fn;
	integrity_complete_fn___75 *complete_fn;
	const char *name;
};

struct block_device_operations___75 {
	blk_qc_t (*submit_bio)(struct bio___75 *);
	int (*open)(struct block_device___76 *, fmode_t);
	void (*release)(struct gendisk___75 *, fmode_t);
	int (*rw_page)(struct block_device___76 *, sector_t, struct page___167 *, unsigned int);
	int (*ioctl)(struct block_device___76 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___76 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___75 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___75 *);
	int (*getgeo)(struct block_device___76 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___76 *, bool);
	void (*swap_slot_free_notify)(struct block_device___76 *, long unsigned int);
	int (*report_zones)(struct gendisk___75 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___75 *, umode_t *);
	struct module___146 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___75 *, sector_t *);
};

typedef void rq_end_io_fn___75(struct request___75 *, blk_status_t);

struct request___75 {
	struct request_queue___75 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___72 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___75 *bio;
	struct bio___75 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___89 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___75 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___75 *saved_end_io;
		} flush;
	};
	struct gendisk___75 *rq_disk;
	struct block_device___76 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___75 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___72 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___75 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___149 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___162 *debugfs_dir;
	struct dentry___162 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___75;

struct elevator_mq_ops___75 {
	int (*init_sched)(struct request_queue___75 *, struct elevator_type___75 *);
	void (*exit_sched)(struct elevator_queue___75 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___72 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___72 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___72 *);
	bool (*allow_merge)(struct request_queue___75 *, struct request___75 *, struct bio___75 *);
	bool (*bio_merge)(struct request_queue___75 *, struct bio___75 *, unsigned int);
	int (*request_merge)(struct request_queue___75 *, struct request___75 **, struct bio___75 *);
	void (*request_merged)(struct request_queue___75 *, struct request___75 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___75 *, struct request___75 *, struct request___75 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___75 *);
	void (*finish_request)(struct request___75 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___72 *, struct list_head *, bool);
	struct request___75 * (*dispatch_request)(struct blk_mq_hw_ctx___72 *);
	bool (*has_work)(struct blk_mq_hw_ctx___72 *);
	void (*completed_request)(struct request___75 *, u64);
	void (*requeue_request)(struct request___75 *);
	struct request___75 * (*former_request)(struct request_queue___75 *, struct request___75 *);
	struct request___75 * (*next_request)(struct request_queue___75 *, struct request___75 *);
	void (*init_icq)(struct io_cq___75 *);
	void (*exit_icq)(struct io_cq___75 *);
};

struct elv_fs_entry___75;

struct elevator_type___75 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___75 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___75 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___146 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___75 {
	struct elevator_type___75 *type;
	void *elevator_data;
	struct kobject___149 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___75 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___75 *, char *);
	ssize_t (*store)(struct elevator_queue___75 *, const char *, size_t);
};

struct blk_mq_queue_data___72;

struct blk_mq_ops___72 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___72 *, const struct blk_mq_queue_data___72 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___72 *);
	int (*get_budget)(struct request_queue___75 *);
	void (*put_budget)(struct request_queue___75 *, int);
	void (*set_rq_budget_token)(struct request___75 *, int);
	int (*get_rq_budget_token)(struct request___75 *);
	enum blk_eh_timer_return (*timeout)(struct request___75 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___72 *);
	void (*complete)(struct request___75 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___72 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___72 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___72 *, struct request___75 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___72 *, struct request___75 *, unsigned int);
	void (*initialize_rq_fn)(struct request___75 *);
	void (*cleanup_rq)(struct request___75 *);
	bool (*busy)(struct request_queue___75 *);
	int (*map_queues)(struct blk_mq_tag_set___72 *);
	void (*show_rq)(struct seq_file___140 *, struct request___75 *);
};

struct blk_mq_tag_set___72 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___72 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___72 {
	struct request___75 *rq;
	bool last;
};

struct blkcg_policy_data___72;

struct blkcg___72 {
	struct cgroup_subsys_state___111 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___72 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___72 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___72 {
	struct blkcg___72 *blkcg;
	int plid;
};

struct blkg_policy_data___72 {
	struct blkcg_gq___72 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___63 {
	struct mem_cgroup___63 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___63 {
	struct lruvec___70 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___63 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___63 *memcg;
};

struct obj_cgroup___63 {
	struct percpu_ref refcnt;
	struct mem_cgroup___63 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___30 {
	spinlock_t *lock;
	struct sk_buff___31 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___30;

struct Qdisc_ops___30 {
	struct Qdisc_ops___30 *next;
	const struct Qdisc_class_ops___30 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___31 *, struct Qdisc___30 *, struct sk_buff___31 **);
	struct sk_buff___31 * (*dequeue)(struct Qdisc___30 *);
	struct sk_buff___31 * (*peek)(struct Qdisc___30 *);
	int (*init)(struct Qdisc___30 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___30 *);
	void (*destroy)(struct Qdisc___30 *);
	int (*change)(struct Qdisc___30 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___30 *);
	int (*change_tx_queue_len)(struct Qdisc___30 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___30 *, unsigned int);
	int (*dump)(struct Qdisc___30 *, struct sk_buff___31 *);
	int (*dump_stats)(struct Qdisc___30 *, struct gnet_dump___30 *);
	void (*ingress_block_set)(struct Qdisc___30 *, u32);
	void (*egress_block_set)(struct Qdisc___30 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___30 *);
	u32 (*egress_block_get)(struct Qdisc___30 *);
	struct module___146 *owner;
};

struct Qdisc_class_ops___30 {
	unsigned int flags;
	struct netdev_queue___30 * (*select_queue)(struct Qdisc___30 *, struct tcmsg *);
	int (*graft)(struct Qdisc___30 *, long unsigned int, struct Qdisc___30 *, struct Qdisc___30 **, struct netlink_ext_ack *);
	struct Qdisc___30 * (*leaf)(struct Qdisc___30 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___30 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___30 *, u32);
	int (*change)(struct Qdisc___30 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___30 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___30 *, struct qdisc_walker *);
	struct tcf_block___30 * (*tcf_block)(struct Qdisc___30 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___30 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___30 *, long unsigned int);
	int (*dump)(struct Qdisc___30 *, long unsigned int, struct sk_buff___31 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___30 *, long unsigned int, struct gnet_dump___30 *);
};

struct tcf_chain___30;

struct tcf_block___30 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___35 *net;
	struct Qdisc___30 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___30 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___30;

struct tcf_proto_ops___30;

struct tcf_proto___30 {
	struct tcf_proto___30 *next;
	void *root;
	int (*classify)(struct sk_buff___31 *, const struct tcf_proto___30 *, struct tcf_result___30 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___30 *ops;
	struct tcf_chain___30 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___30 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___30 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___30 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___31 *, const struct tcf_proto___30 *, struct tcf_result___30 *);
	int (*init)(struct tcf_proto___30 *);
	void (*destroy)(struct tcf_proto___30 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___30 *, u32);
	void (*put)(struct tcf_proto___30 *, void *);
	int (*change)(struct net___35 *, struct sk_buff___31 *, struct tcf_proto___30 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___30 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___30 *);
	void (*walk)(struct tcf_proto___30 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___30 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___30 *, void *);
	void (*hw_del)(struct tcf_proto___30 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___35 *, struct tcf_chain___30 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___35 *, struct tcf_proto___30 *, void *, struct sk_buff___31 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___35 *, struct tcf_proto___30 *, void *, struct sk_buff___31 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___31 *, struct net___35 *, void *);
	struct module___146 *owner;
	int flags;
};

struct tcf_chain___30 {
	struct mutex filter_chain_lock;
	struct tcf_proto___30 *filter_chain;
	struct list_head list;
	struct tcf_block___30 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___30 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___23 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___30 *prog;
};

struct pneigh_entry___23;

struct neigh_hash_table___23;

struct neigh_table___23 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___32 *, __u32 *);
	bool (*key_eq)(const struct neighbour___23 *, const void *);
	int (*constructor)(struct neighbour___23 *);
	int (*pconstructor)(struct pneigh_entry___23 *);
	void (*pdestructor)(struct pneigh_entry___23 *);
	void (*proxy_redo)(struct sk_buff___31 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___32 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___23 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___30 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___23 *nht;
	struct pneigh_entry___23 **phash_buckets;
};

struct neigh_ops___23 {
	int family;
	void (*solicit)(struct neighbour___23 *, struct sk_buff___31 *);
	void (*error_report)(struct neighbour___23 *, struct sk_buff___31 *);
	int (*output)(struct neighbour___23 *, struct sk_buff___31 *);
	int (*connected_output)(struct neighbour___23 *, struct sk_buff___31 *);
};

struct pneigh_entry___23 {
	struct pneigh_entry___23 *next;
	possible_net_t___30 net;
	struct net_device___32 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___23 {
	struct neighbour___23 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___10 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___35 *, struct sock___24 *, struct sk_buff___31 *);
	int (*orig_input)(struct sk_buff___31 *);
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 data[0];
};

struct fib_rule___23 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___23 *ctarget;
	struct net___35 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___23 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___23 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___13;

struct timewait_sock_ops___13;

struct proto___23 {
	void (*close)(struct sock___24 *, long int);
	int (*pre_connect)(struct sock___24 *, struct sockaddr *, int);
	int (*connect)(struct sock___24 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___24 *, int);
	struct sock___24 * (*accept)(struct sock___24 *, int, int *, bool);
	int (*ioctl)(struct sock___24 *, int, long unsigned int);
	int (*init)(struct sock___24 *);
	void (*destroy)(struct sock___24 *);
	void (*shutdown)(struct sock___24 *, int);
	int (*setsockopt)(struct sock___24 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___24 *, int, int, char *, int *);
	void (*keepalive)(struct sock___24 *, int);
	int (*compat_ioctl)(struct sock___24 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___24 *, struct msghdr___24 *, size_t);
	int (*recvmsg)(struct sock___24 *, struct msghdr___24 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___24 *, struct page___167 *, int, size_t, int);
	int (*bind)(struct sock___24 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___24 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___24 *, struct sk_buff___31 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___24 *);
	int (*hash)(struct sock___24 *);
	void (*unhash)(struct sock___24 *);
	void (*rehash)(struct sock___24 *);
	int (*get_port)(struct sock___24 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___24 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___24 *, int);
	bool (*sock_is_readable)(struct sock___24 *);
	void (*enter_memory_pressure)(struct sock___24 *);
	void (*leave_memory_pressure)(struct sock___24 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___13 *rsk_prot;
	struct timewait_sock_ops___13 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___146 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___24 *, int);
};

struct request_sock___14;

struct request_sock_ops___13 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___24 *, struct request_sock___14 *);
	void (*send_ack)(const struct sock___24 *, struct sk_buff___31 *, struct request_sock___14 *);
	void (*send_reset)(const struct sock___24 *, struct sk_buff___31 *);
	void (*destructor)(struct request_sock___14 *);
	void (*syn_ack_timeout)(const struct request_sock___14 *);
};

struct timewait_sock_ops___13 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___24 *, struct sock___24 *, void *);
	void (*twsk_destructor)(struct sock___24 *);
};

struct request_sock___14 {
	struct sock_common___23 __req_common;
	struct request_sock___14 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___13 *rsk_ops;
	struct sock___24 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___13 {
	struct in6_addr mca_addr;
	struct inet6_dev___13 *idev;
	struct ifmcaddr6___13 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct lsm_network_audit___5 {
	int netif;
	const struct sock___24 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___5 {
	struct path___162 path;
	u16 cmd;
};

struct aa_label___4;

struct aa_profile___4;

struct apparmor_audit_data___3 {
	int error;
	int type;
	const char *op;
	struct aa_label___4 *label;
	const char *name;
	const char *info;
	u32 request;
	u32 denied;
	union {
		struct {
			struct aa_label___4 *peer;
			union {
				struct {
					const char *target;
					kuid_t ouid;
				} fs;
				struct {
					int rlim;
					long unsigned int max;
				} rlim;
				struct {
					int signal;
					int unmappedsig;
				};
				struct {
					int type;
					int protocol;
					struct sock___24 *peer_sk;
					void *addr;
					int addrlen;
				} net;
			};
		};
		struct {
			struct aa_profile___4 *profile;
			const char *ns;
			long int pos;
		} iface;
		struct {
			const char *src_name;
			const char *type;
			const char *trans;
			const char *data;
			long unsigned int flags;
		} mnt;
	};
};

struct common_audit_data___6 {
	char type;
	union {
		struct path___162 path;
		struct dentry___162 *dentry;
		struct inode___162 *inode;
		struct lsm_network_audit___5 *net;
		int cap;
		int ipc_id;
		struct task_struct___169 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___5 *op;
		struct file___162 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data___3 *apparmor_audit_data;
	};
};

struct linux_binprm___33 {
	struct vm_area_struct___167 *vma;
	long unsigned int vma_pages;
	struct mm_struct___168 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___162 *executable;
	struct file___162 *interpreter;
	struct file___162 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___32 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___162 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct aa_proxy___4 {
	struct kref count;
	struct aa_label___4 *label;
};

struct aa_label___4 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct aa_proxy___4 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___4 *vec[0];
};

struct aa_ns___4;

struct aa_profile___4 {
	struct aa_policy base;
	struct aa_profile___4 *parent;
	struct aa_ns___4 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___2 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___162 *dents[9];
	struct rhashtable *data;
	struct aa_label___4 label;
};

struct aa_ns___4 {
	struct aa_policy base;
	struct aa_ns___4 *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile___4 *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___162 *dents[13];
};

struct counted_str {
	struct kref count;
	char name[0];
};

struct match_workbuf {
	unsigned int count;
	unsigned int pos;
	unsigned int len;
	unsigned int size;
	unsigned int history[24];
};

struct dentry___163;

struct super_block___163;

struct module___147;

struct file_system_type___163 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___163 * (*mount)(struct file_system_type___163 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___163 *);
	struct module___147 *owner;
	struct file_system_type___163 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___163;

struct kiocb___163;

struct iov_iter___92;

struct poll_table_struct___104;

struct vm_area_struct___168;

struct inode___163;

struct file_lock___163;

struct page___168;

struct pipe_inode_info___56;

struct seq_file___141;

struct file_operations___163 {
	struct module___147 *owner;
	loff_t (*llseek)(struct file___163 *, loff_t, int);
	ssize_t (*read)(struct file___163 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___163 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___163 *, struct iov_iter___92 *);
	ssize_t (*write_iter)(struct kiocb___163 *, struct iov_iter___92 *);
	int (*iopoll)(struct kiocb___163 *, bool);
	int (*iterate)(struct file___163 *, struct dir_context *);
	int (*iterate_shared)(struct file___163 *, struct dir_context *);
	__poll_t (*poll)(struct file___163 *, struct poll_table_struct___104 *);
	long int (*unlocked_ioctl)(struct file___163 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___163 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___163 *, struct vm_area_struct___168 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___163 *, struct file___163 *);
	int (*flush)(struct file___163 *, fl_owner_t);
	int (*release)(struct inode___163 *, struct file___163 *);
	int (*fsync)(struct file___163 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___163 *, int);
	int (*lock)(struct file___163 *, int, struct file_lock___163 *);
	ssize_t (*sendpage)(struct file___163 *, struct page___168 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___163 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___163 *, long unsigned int);
	int (*flock)(struct file___163 *, int, struct file_lock___163 *);
	ssize_t (*splice_write)(struct pipe_inode_info___56 *, struct file___163 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___163 *, loff_t *, struct pipe_inode_info___56 *, size_t, unsigned int);
	int (*setlease)(struct file___163 *, long int, struct file_lock___163 **, void **);
	long int (*fallocate)(struct file___163 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___141 *, struct file___163 *);
	ssize_t (*copy_file_range)(struct file___163 *, loff_t, struct file___163 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___163 *, loff_t, struct file___163 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___163 *, loff_t, loff_t, int);
};

struct vmacache___168 {
	u64 seqnum;
	struct vm_area_struct___168 *vmas[4];
};

struct page_frag___168 {
	struct page___168 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___169;

struct pid___144;

struct fs_struct___21;

struct nsproxy___153;

struct signal_struct___164;

struct bio_list___76;

struct backing_dev_info___73;

struct io_context___76;

struct css_set___112;

struct mem_cgroup___64;

struct request_queue___76;

struct vm_struct___147;

struct task_struct___170 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___170 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___169 *mm;
	struct mm_struct___169 *active_mm;
	struct vmacache___168 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___170 *real_parent;
	struct task_struct___170 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___170 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___144 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct___21 *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___153 *nsproxy;
	struct signal_struct___164 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___170 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___76 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___73 *backing_dev_info;
	struct io_context___76 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___112 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___56 *splice_pipe;
	struct page_frag___168 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___64 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___64 *active_memcg;
	struct request_queue___76 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___170 *oom_reaper_list;
	struct vm_struct___147 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___150;

struct kobj_type___150;

struct kernfs_node___150;

struct kobject___150 {
	const char *name;
	struct list_head entry;
	struct kobject___150 *parent;
	struct kset___150 *kset;
	struct kobj_type___150 *ktype;
	struct kernfs_node___150 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___147 {
	struct kobject___150 kobj;
	struct module___147 *mod;
	struct kobject___150 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___147 {
	struct module___147 *mod;
	struct latch_tree_node node;
};

struct module_layout___147 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___147 mtn;
};

struct module_attribute___147;

struct kernel_param___147;

struct module___147 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___147 mkobj;
	struct module_attribute___147 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___150 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___147 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___147 core_layout;
	struct module_layout___147 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___163 {
	struct dentry___163 *mnt_root;
	struct super_block___163 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct dentry_operations___163;

struct dentry___163 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___163 *d_parent;
	struct qstr d_name;
	struct inode___163 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___163 *d_op;
	struct super_block___163 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct quota_format_type___163;

struct mem_dqinfo___163 {
	struct quota_format_type___163 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___163;

struct quota_info___163 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___163 *files[3];
	struct mem_dqinfo___163 info[3];
	const struct quota_format_ops___163 *ops[3];
};

struct rcuwait___164 {
	struct task_struct___170 *task;
};

struct percpu_rw_semaphore___164 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___164 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___163 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___164 rw_sem[3];
};

struct shrink_control___64;

struct shrinker___64 {
	long unsigned int (*count_objects)(struct shrinker___64 *, struct shrink_control___64 *);
	long unsigned int (*scan_objects)(struct shrinker___64 *, struct shrink_control___64 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___163;

struct dquot_operations___163;

struct quotactl_ops___163;

struct block_device___77;

struct super_block___163 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___163 *s_type;
	const struct super_operations___163 *s_op;
	const struct dquot_operations___163 *dq_op;
	const struct quotactl_ops___163 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___163 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___77 *s_bdev;
	struct backing_dev_info___73 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___163 s_dquot;
	struct sb_writers___163 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___163 *s_d_op;
	int cleancache_poolid;
	struct shrinker___64 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct address_space_operations___163;

struct address_space___163 {
	struct inode___163 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___163 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___163;

struct bdi_writeback___73;

struct inode___163 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___163 *i_op;
	struct super_block___163 *i_sb;
	struct address_space___163 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___73 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___163 *i_fop;
		void (*free_inode)(struct inode___163 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___163 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___56 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct path___163;

struct dentry_operations___163 {
	int (*d_revalidate)(struct dentry___163 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___163 *, unsigned int);
	int (*d_hash)(const struct dentry___163 *, struct qstr *);
	int (*d_compare)(const struct dentry___163 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___163 *);
	int (*d_init)(struct dentry___163 *);
	void (*d_release)(struct dentry___163 *);
	void (*d_prune)(struct dentry___163 *);
	void (*d_iput)(struct dentry___163 *, struct inode___163 *);
	char * (*d_dname)(struct dentry___163 *, char *, int);
	struct vfsmount___163 * (*d_automount)(struct path___163 *);
	int (*d_manage)(const struct path___163 *, bool);
	struct dentry___163 * (*d_real)(struct dentry___163 *, const struct inode___163 *);
	long: 64;
	long: 64;
	long: 64;
};

struct path___163 {
	struct vfsmount___163 *mnt;
	struct dentry___163 *dentry;
};

struct pid_namespace___144;

struct upid___144 {
	int nr;
	struct pid_namespace___144 *ns;
};

struct pid_namespace___144 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___170 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___144 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___144 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___144 numbers[1];
};

typedef struct page___168 *pgtable_t___168;

struct page_pool___47;

struct dev_pagemap___159;

struct page___168 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___163 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___47 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___168 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___168 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___169 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___159 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___159;

struct vm_area_struct___168 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___168 *vm_next;
	struct vm_area_struct___168 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___169 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___159 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___163 *vm_file;
	struct file___163 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___164 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___170 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___170 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___144 *pids[4];
	struct pid___144 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___169 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___33;

struct core_state___168;

struct mm_struct___169 {
	struct {
		struct vm_area_struct___168 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___163 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___33 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___168 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___170 *owner;
		struct user_namespace___24 *user_ns;
		struct file___163 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fs_struct___21 {
	int users;
	spinlock_t lock;
	seqcount_spinlock_t seq;
	int umask;
	int in_exec;
	struct path___163 root;
	struct path___163 pwd;
};

struct net___36;

struct cgroup_namespace___112;

struct nsproxy___153 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___144 *pid_ns_for_children;
	struct net___36 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___112 *cgroup_ns;
};

struct bio___76;

struct bio_list___76 {
	struct bio___76 *head;
	struct bio___76 *tail;
};

struct cgroup_subsys_state___112;

struct bdi_writeback___73 {
	struct backing_dev_info___73 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___112 *memcg_css;
	struct cgroup_subsys_state___112 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___119;

struct backing_dev_info___73 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___73 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___119 *dev;
	char dev_name[64];
	struct device___119 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___163 *debug_dir;
};

struct io_cq___76;

struct io_context___76 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___76 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___112;

struct css_set___112 {
	struct cgroup_subsys_state___112 *subsys[14];
	refcount_t refcount;
	struct css_set___112 *dom_cset;
	struct cgroup___112 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___112 *mg_src_cgrp;
	struct cgroup___112 *mg_dst_cgrp;
	struct css_set___112 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___163;

struct pipe_buffer___56;

struct pipe_inode_info___56 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___168 *tmp_page;
	struct fasync_struct___163 *fasync_readers;
	struct fasync_struct___163 *fasync_writers;
	struct pipe_buffer___56 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___112;

struct cgroup_subsys_state___112 {
	struct cgroup___112 *cgroup;
	struct cgroup_subsys___112 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___112 *parent;
};

struct cgroup_file___112 {
	struct kernfs_node___150 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___64;

struct mem_cgroup_per_node___64;

struct mem_cgroup___64 {
	struct cgroup_subsys_state___112 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___112 events_file;
	struct cgroup_file___112 events_local_file;
	struct cgroup_file___112 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___64 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___170 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___64 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___76;

struct blk_integrity___76 {
	const struct blk_integrity_profile___76 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___76 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___76 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___76;

struct elevator_queue___76;

struct blk_mq_ops___73;

struct blk_mq_hw_ctx___73;

struct gendisk___76;

struct blkcg_gq___73;

struct blk_mq_tag_set___73;

struct request_queue___76 {
	struct request___76 *last_merge;
	struct elevator_queue___76 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___73 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___73 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___76 *disk;
	struct kobject___150 kobj;
	struct kobject___150 *mq_kobj;
	struct blk_integrity___76 integrity;
	struct device___119 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___73 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___73 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___76 bio_split;
	struct dentry___163 *debugfs_dir;
	struct dentry___163 *sched_debugfs_dir;
	struct dentry___163 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___147 {
	struct vm_struct___147 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___168 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___64 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___64 *memcg;
};

struct page_pool_params___47 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___119 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___47 {
	u32 count;
	struct page___168 *cache[128];
};

struct page_pool___47 {
	struct page_pool_params___47 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___168 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___47 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___159;

struct dev_pagemap___159 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___159 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___144 {
	rwlock_t lock;
	struct pid___144 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___163 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___163 f_path;
	struct inode___163 *f_inode;
	const struct file_operations___163 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___144 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___163 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___159;

struct vm_operations_struct___159 {
	void (*open)(struct vm_area_struct___168 *);
	void (*close)(struct vm_area_struct___168 *);
	int (*may_split)(struct vm_area_struct___168 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___168 *);
	int (*mprotect)(struct vm_area_struct___168 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___159 *);
	vm_fault_t (*huge_fault)(struct vm_fault___159 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___159 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___168 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___159 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___159 *);
	int (*access)(struct vm_area_struct___168 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___168 *);
	int (*set_policy)(struct vm_area_struct___168 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___168 *, long unsigned int);
	struct page___168 * (*find_special_page)(struct vm_area_struct___168 *, long unsigned int);
};

struct core_thread___168 {
	struct task_struct___170 *task;
	struct core_thread___168 *next;
};

struct core_state___168 {
	atomic_t nr_threads;
	struct core_thread___168 dumper;
	struct completion startup;
};

struct linux_binprm___34;

struct coredump_params___33;

struct linux_binfmt___33 {
	struct list_head lh;
	struct module___147 *module;
	int (*load_binary)(struct linux_binprm___34 *);
	int (*load_shlib)(struct file___163 *);
	int (*core_dump)(struct coredump_params___33 *);
	long unsigned int min_coredump;
};

struct vm_fault___159 {
	const struct {
		struct vm_area_struct___168 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___168 *cow_page;
	struct page___168 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___168 prealloc_pte;
};

struct pglist_data___71;

struct lruvec___71 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___71 *pgdat;
};

struct zone___71 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___71 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___71 {
	struct zone___71 *zone;
	int zone_idx;
};

struct zonelist___71 {
	struct zoneref___71 _zonerefs[321];
};

struct pglist_data___71 {
	struct zone___71 node_zones[5];
	struct zonelist___71 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___170 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___170 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___71 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___112 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___170 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___31;

struct cgroup_bpf___31 {
	struct bpf_prog_array___31 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___31 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___112;

struct cgroup_rstat_cpu___112;

struct cgroup___112 {
	struct cgroup_subsys_state___112 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___150 *kn;
	struct cgroup_file___112 procs_file;
	struct cgroup_file___112 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___112 *subsys[14];
	struct cgroup_root___112 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___112 *dom_cgrp;
	struct cgroup___112 *old_dom_cgrp;
	struct cgroup_rstat_cpu___112 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___112 psi;
	struct cgroup_bpf___31 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___76 {
	struct request_queue___76 *q;
	struct io_context___76 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___163 {
	struct file___163 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___163 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___163 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___163 *ia_file;
};

struct dquot___163 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___163 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___163 {
	int qf_fmt_id;
	const struct quota_format_ops___163 *qf_ops;
	struct module___147 *qf_owner;
	struct quota_format_type___163 *qf_next;
};

struct quota_format_ops___163 {
	int (*check_quota_file)(struct super_block___163 *, int);
	int (*read_file_info)(struct super_block___163 *, int);
	int (*write_file_info)(struct super_block___163 *, int);
	int (*free_file_info)(struct super_block___163 *, int);
	int (*read_dqblk)(struct dquot___163 *);
	int (*commit_dqblk)(struct dquot___163 *);
	int (*release_dqblk)(struct dquot___163 *);
	int (*get_next_id)(struct super_block___163 *, struct kqid *);
};

struct dquot_operations___163 {
	int (*write_dquot)(struct dquot___163 *);
	struct dquot___163 * (*alloc_dquot)(struct super_block___163 *, int);
	void (*destroy_dquot)(struct dquot___163 *);
	int (*acquire_dquot)(struct dquot___163 *);
	int (*release_dquot)(struct dquot___163 *);
	int (*mark_dirty)(struct dquot___163 *);
	int (*write_info)(struct super_block___163 *, int);
	qsize_t * (*get_reserved_space)(struct inode___163 *);
	int (*get_projid)(struct inode___163 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___163 *, qsize_t *);
	int (*get_next_id)(struct super_block___163 *, struct kqid *);
};

struct quotactl_ops___163 {
	int (*quota_on)(struct super_block___163 *, int, int, const struct path___163 *);
	int (*quota_off)(struct super_block___163 *, int);
	int (*quota_enable)(struct super_block___163 *, unsigned int);
	int (*quota_disable)(struct super_block___163 *, unsigned int);
	int (*quota_sync)(struct super_block___163 *, int);
	int (*set_info)(struct super_block___163 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___163 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___163 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___163 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___163 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___163 *, unsigned int);
};

struct writeback_control___73;

struct address_space_operations___163 {
	int (*writepage)(struct page___168 *, struct writeback_control___73 *);
	int (*readpage)(struct file___163 *, struct page___168 *);
	int (*writepages)(struct address_space___163 *, struct writeback_control___73 *);
	int (*set_page_dirty)(struct page___168 *);
	int (*readpages)(struct file___163 *, struct address_space___163 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___163 *, struct address_space___163 *, loff_t, unsigned int, unsigned int, struct page___168 **, void **);
	int (*write_end)(struct file___163 *, struct address_space___163 *, loff_t, unsigned int, unsigned int, struct page___168 *, void *);
	sector_t (*bmap)(struct address_space___163 *, sector_t);
	void (*invalidatepage)(struct page___168 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___168 *, gfp_t);
	void (*freepage)(struct page___168 *);
	ssize_t (*direct_IO)(struct kiocb___163 *, struct iov_iter___92 *);
	int (*migratepage)(struct address_space___163 *, struct page___168 *, struct page___168 *, enum migrate_mode);
	bool (*isolate_page)(struct page___168 *, isolate_mode_t);
	void (*putback_page)(struct page___168 *);
	int (*launder_page)(struct page___168 *);
	int (*is_partially_uptodate)(struct page___168 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___168 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___163 *, struct page___168 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___163 *, sector_t *);
	void (*swap_deactivate)(struct file___163 *);
};

struct writeback_control___73 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___73 *wb;
	struct inode___163 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___90;

struct iov_iter___92 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___90 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___56 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___163 {
	struct dentry___163 * (*lookup)(struct inode___163 *, struct dentry___163 *, unsigned int);
	const char * (*get_link)(struct dentry___163 *, struct inode___163 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___163 *, int);
	struct posix_acl * (*get_acl)(struct inode___163 *, int, bool);
	int (*readlink)(struct dentry___163 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___163 *, struct dentry___163 *, umode_t, bool);
	int (*link)(struct dentry___163 *, struct inode___163 *, struct dentry___163 *);
	int (*unlink)(struct inode___163 *, struct dentry___163 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___163 *, struct dentry___163 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___163 *, struct dentry___163 *, umode_t);
	int (*rmdir)(struct inode___163 *, struct dentry___163 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___163 *, struct dentry___163 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___163 *, struct dentry___163 *, struct inode___163 *, struct dentry___163 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___163 *, struct iattr___163 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___163 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___163 *, char *, size_t);
	int (*fiemap)(struct inode___163 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___163 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___163 *, struct dentry___163 *, struct file___163 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___163 *, struct dentry___163 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___163 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___163 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___163 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___163 {
	void (*fl_copy_lock)(struct file_lock___163 *, struct file_lock___163 *);
	void (*fl_release_private)(struct file_lock___163 *);
};

struct lock_manager_operations___163;

struct file_lock___163 {
	struct file_lock___163 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___163 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___163 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___163 *fl_ops;
	const struct lock_manager_operations___163 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___163 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___163 *);
	int (*lm_grant)(struct file_lock___163 *, int);
	bool (*lm_break)(struct file_lock___163 *);
	int (*lm_change)(struct file_lock___163 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___163 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___163 *);
};

struct fasync_struct___163 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___163 *fa_next;
	struct file___163 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___163 {
	struct inode___163 * (*alloc_inode)(struct super_block___163 *);
	void (*destroy_inode)(struct inode___163 *);
	void (*free_inode)(struct inode___163 *);
	void (*dirty_inode)(struct inode___163 *, int);
	int (*write_inode)(struct inode___163 *, struct writeback_control___73 *);
	int (*drop_inode)(struct inode___163 *);
	void (*evict_inode)(struct inode___163 *);
	void (*put_super)(struct super_block___163 *);
	int (*sync_fs)(struct super_block___163 *, int);
	int (*freeze_super)(struct super_block___163 *);
	int (*freeze_fs)(struct super_block___163 *);
	int (*thaw_super)(struct super_block___163 *);
	int (*unfreeze_fs)(struct super_block___163 *);
	int (*statfs)(struct dentry___163 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___163 *, int *, char *);
	void (*umount_begin)(struct super_block___163 *);
	int (*show_options)(struct seq_file___141 *, struct dentry___163 *);
	int (*show_devname)(struct seq_file___141 *, struct dentry___163 *);
	int (*show_path)(struct seq_file___141 *, struct dentry___163 *);
	int (*show_stats)(struct seq_file___141 *, struct dentry___163 *);
	ssize_t (*quota_read)(struct super_block___163 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___163 *, int, const char *, size_t, loff_t);
	struct dquot___163 ** (*get_dquots)(struct inode___163 *);
	long int (*nr_cached_objects)(struct super_block___163 *, struct shrink_control___64 *);
	long int (*free_cached_objects)(struct super_block___163 *, struct shrink_control___64 *);
	struct file___163 * (*real_loop)(struct file___163 *);
};

struct wakeup_source___119;

struct dev_pm_info___119 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___119 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___119 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___119;

struct bus_type___119;

struct device_driver___119;

struct dev_pm_domain___119;

struct fwnode_handle___119;

struct class___119;

struct attribute_group___150;

struct device___119 {
	struct kobject___150 kobj;
	struct device___119 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___119 *type;
	struct bus_type___119 *bus;
	struct device_driver___119 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___119 power;
	struct dev_pm_domain___119 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___119 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___119 *class;
	const struct attribute_group___150 **groups;
	void (*release)(struct device___119 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___77 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___163 *bd_inode;
	struct super_block___163 *bd_super;
	void *bd_claiming;
	struct device___119 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___150 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___76 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___163 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___106)(struct file___163 *, wait_queue_head_t *, struct poll_table_struct___104 *);

struct poll_table_struct___104 {
	poll_queue_proc___106 _qproc;
	__poll_t _key;
};

struct seq_operations___141;

struct seq_file___141 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___141 *op;
	int poll_event;
	const struct file___163 *file;
	void *private;
};

typedef void bio_end_io_t___76(struct bio___76 *);

struct bio_vec___90 {
	struct page___168 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___76;

struct bio___76 {
	struct bio___76 *bi_next;
	struct block_device___77 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___76 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___73 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___76 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___90 *bi_io_vec;
	struct bio_set___76 *bi_pool;
	struct bio_vec___90 bi_inline_vecs[0];
};

struct ip_ra_chain___11;

struct fib_rules_ops___24;

struct sock___25;

struct fqdir___36;

struct fib_notifier_ops___24;

struct netns_ipv4___36 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___11 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___24 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___25 *fibnl;
	struct sock___25 **icmp_sk;
	struct sock___25 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___25 **tcp_sk;
	struct fqdir___36 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___24 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___24 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___24 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___24;

struct net_device___33;

struct sk_buff___32;

struct neighbour___24;

struct dst_ops___36 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___36 *);
	struct dst_entry___24 * (*check)(struct dst_entry___24 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___24 *);
	unsigned int (*mtu)(const struct dst_entry___24 *);
	u32 * (*cow_metrics)(struct dst_entry___24 *, long unsigned int);
	void (*destroy)(struct dst_entry___24 *);
	void (*ifdown)(struct dst_entry___24 *, struct net_device___33 *, int);
	struct dst_entry___24 * (*negative_advice)(struct dst_entry___24 *);
	void (*link_failure)(struct sk_buff___32 *);
	void (*update_pmtu)(struct dst_entry___24 *, struct sock___25 *, struct sk_buff___32 *, u32, bool);
	void (*redirect)(struct dst_entry___24 *, struct sock___25 *, struct sk_buff___32 *);
	int (*local_out)(struct net___36 *, struct sock___25 *, struct sk_buff___32 *);
	struct neighbour___24 * (*neigh_lookup)(const struct dst_entry___24 *, struct sk_buff___32 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___24 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___36 {
	struct dst_ops___36 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___36 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___24 *fib6_rules_ops;
	struct sock___25 **icmp_sk;
	struct sock___25 *ndisc_sk;
	struct sock___25 *tcp_sk;
	struct sock___25 *igmp_sk;
	struct sock___25 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___24 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___24 *notifier_ops;
	struct fib_notifier_ops___24 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___36 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___36 *fqdir;
};

struct netns_sctp___24 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___25 *ctl_sock;
	struct sock___25 *udp4_sock;
	struct sock___25 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___31 {
	struct sk_buff___32 *next;
	struct sk_buff___32 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___31;

struct netns_bpf___31 {
	struct bpf_prog_array___31 *run_array[2];
	struct bpf_prog___31 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___36 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___25 *nlsk;
	struct sock___25 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___36 xfrm4_dst_ops;
	struct dst_ops___36 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___36 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___25 *rtnl;
	struct sock___25 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___33 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___36 ipv4;
	struct netns_ipv6___36 ipv6;
	struct netns_ieee802154_lowpan___36 ieee802154_lowpan;
	struct netns_sctp___24 sctp;
	struct netns_nf___2 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___31 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___31 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___36 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___25 *crypto_nlsk;
	struct sock___25 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___112 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___112 *root_cset;
};

enum path_flags {
	PATH_IS_DIR = 1,
	PATH_SOCK_COND = 2,
	PATH_CONNECT_PATH = 4,
	PATH_CHROOT_REL = 8,
	PATH_CHROOT_NSCONNECT = 16,
	PATH_DELEGATE_DELETED = 32768,
	PATH_MEDIATE_DELETED = 65536,
};

struct msghdr___25 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___92 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___163 *msg_iocb;
};

struct dev_pagemap_ops___159 {
	void (*page_free)(struct page___168 *);
	void (*kill)(struct dev_pagemap___159 *);
	void (*cleanup)(struct dev_pagemap___159 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___159 *);
};

struct fwnode_operations___119;

struct fwnode_handle___119 {
	struct fwnode_handle___119 *secondary;
	const struct fwnode_operations___119 *ops;
	struct device___119 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___119;

struct fwnode_endpoint___119;

struct fwnode_operations___119 {
	struct fwnode_handle___119 * (*get)(struct fwnode_handle___119 *);
	void (*put)(struct fwnode_handle___119 *);
	bool (*device_is_available)(const struct fwnode_handle___119 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___119 *, const struct device___119 *);
	bool (*property_present)(const struct fwnode_handle___119 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___119 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___119 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___119 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*get_parent)(const struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*get_next_child_node)(const struct fwnode_handle___119 *, struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*get_named_child_node)(const struct fwnode_handle___119 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___119 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___119 *);
	struct fwnode_handle___119 * (*graph_get_next_endpoint)(const struct fwnode_handle___119 *, struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*graph_get_remote_endpoint)(const struct fwnode_handle___119 *);
	struct fwnode_handle___119 * (*graph_get_port_parent)(struct fwnode_handle___119 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___119 *, struct fwnode_endpoint___119 *);
	int (*add_links)(struct fwnode_handle___119 *);
};

struct fwnode_endpoint___119 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___119 *local_fwnode;
};

struct fwnode_reference_args___119 {
	struct fwnode_handle___119 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___150;

struct kernfs_elem_dir___150 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___150 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___150;

struct kernfs_root___150 {
	struct kernfs_node___150 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___150 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___150 {
	struct kernfs_node___150 *target_kn;
};

struct kernfs_ops___150;

struct kernfs_elem_attr___150 {
	const struct kernfs_ops___150 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___150 *notify_next;
};

struct kernfs_node___150 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___150 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___150 dir;
		struct kernfs_elem_symlink___150 symlink;
		struct kernfs_elem_attr___150 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___150;

struct kernfs_ops___150 {
	int (*open)(struct kernfs_open_file___150 *);
	void (*release)(struct kernfs_open_file___150 *);
	int (*seq_show)(struct seq_file___141 *, void *);
	void * (*seq_start)(struct seq_file___141 *, loff_t *);
	void * (*seq_next)(struct seq_file___141 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___141 *, void *);
	ssize_t (*read)(struct kernfs_open_file___150 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___150 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___150 *, struct poll_table_struct___104 *);
	int (*mmap)(struct kernfs_open_file___150 *, struct vm_area_struct___168 *);
};

struct kernfs_syscall_ops___150 {
	int (*show_options)(struct seq_file___141 *, struct kernfs_root___150 *);
	int (*mkdir)(struct kernfs_node___150 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___150 *);
	int (*rename)(struct kernfs_node___150 *, struct kernfs_node___150 *, const char *);
	int (*show_path)(struct seq_file___141 *, struct kernfs_node___150 *, struct kernfs_root___150 *);
};

struct kernfs_open_file___150 {
	struct kernfs_node___150 *kn;
	struct file___163 *file;
	struct seq_file___141 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___159 *vm_ops;
};

struct kobj_ns_type_operations___24 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___25 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___36 *net;
} possible_net_t___31;

struct proto___24;

struct sock_common___24 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___24 *skc_prot;
	possible_net_t___31 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___25 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___24 {
	struct cgroup___112 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___24;

struct socket_wq___25;

struct socket___25;

struct sock___25 {
	struct sock_common___24 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___31 sk_error_queue;
	struct sk_buff___32 *sk_rx_skb_cache;
	struct sk_buff_head___31 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___32 *head;
		struct sk_buff___32 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___24 *sk_filter;
	union {
		struct socket_wq___25 *sk_wq;
		struct socket_wq___25 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___24 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___24 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___32 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___32 *sk_tx_skb_cache;
	struct sk_buff_head___31 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___168 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___24 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___144 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___25 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___24 sk_cgrp_data;
	struct mem_cgroup___64 *sk_memcg;
	void (*sk_state_change)(struct sock___25 *);
	void (*sk_data_ready)(struct sock___25 *);
	void (*sk_write_space)(struct sock___25 *);
	void (*sk_error_report)(struct sock___25 *);
	int (*sk_backlog_rcv)(struct sock___25 *, struct sk_buff___32 *);
	struct sk_buff___32 * (*sk_validate_xmit_skb)(struct sock___25 *, struct net_device___33 *, struct sk_buff___32 *);
	void (*sk_destruct)(struct sock___25 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___150;

struct attribute_group___150 {
	const char *name;
	umode_t (*is_visible)(struct kobject___150 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___150 *, struct bin_attribute___150 *, int);
	struct attribute **attrs;
	struct bin_attribute___150 **bin_attrs;
};

struct bin_attribute___150 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___163 * (*f_mapping)();
	ssize_t (*read)(struct file___163 *, struct kobject___150 *, struct bin_attribute___150 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___163 *, struct kobject___150 *, struct bin_attribute___150 *, char *, loff_t, size_t);
	int (*mmap)(struct file___163 *, struct kobject___150 *, struct bin_attribute___150 *, struct vm_area_struct___168 *);
};

struct sysfs_ops___150 {
	ssize_t (*show)(struct kobject___150 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___150 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___150;

struct kset___150 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___150 kobj;
	const struct kset_uevent_ops___150 *uevent_ops;
};

struct kobj_type___150 {
	void (*release)(struct kobject___150 *);
	const struct sysfs_ops___150 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___150 **default_groups;
	const struct kobj_ns_type_operations___24 * (*child_ns_type)(struct kobject___150 *);
	const void * (*namespace)(struct kobject___150 *);
	void (*get_ownership)(struct kobject___150 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___150 {
	int (* const filter)(struct kset___150 *, struct kobject___150 *);
	const char * (* const name)(struct kset___150 *, struct kobject___150 *);
	int (* const uevent)(struct kset___150 *, struct kobject___150 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___147 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___147 *);
	int (*get)(char *, const struct kernel_param___147 *);
	void (*free)(void *);
};

struct kparam_array___147;

struct kernel_param___147 {
	const char *name;
	struct module___147 *mod;
	const struct kernel_param_ops___147 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___147 *arr;
	};
};

struct kparam_array___147 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___147 *ops;
	void *elem;
};

struct module_attribute___147 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___147 *, struct module_kobject___147 *, char *);
	ssize_t (*store)(struct module_attribute___147 *, struct module_kobject___147 *, const char *, size_t);
	void (*setup)(struct module___147 *, const char *);
	int (*test)(struct module___147 *);
	void (*free)(struct module___147 *);
};

struct socket_wq___25 {
	wait_queue_head_t wait;
	struct fasync_struct___163 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___25;

struct socket___25 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___163 *file;
	struct sock___25 *sk;
	const struct proto_ops___25 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___25 wq;
};

typedef int (*sk_read_actor_t___24)(read_descriptor_t *, struct sk_buff___32 *, unsigned int, size_t);

struct proto_ops___25 {
	int family;
	struct module___147 *owner;
	int (*release)(struct socket___25 *);
	int (*bind)(struct socket___25 *, struct sockaddr *, int);
	int (*connect)(struct socket___25 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___25 *, struct socket___25 *);
	int (*accept)(struct socket___25 *, struct socket___25 *, int, bool);
	int (*getname)(struct socket___25 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___163 *, struct socket___25 *, struct poll_table_struct___104 *);
	int (*ioctl)(struct socket___25 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___25 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___25 *, void *, bool, bool);
	int (*listen)(struct socket___25 *, int);
	int (*shutdown)(struct socket___25 *, int);
	int (*setsockopt)(struct socket___25 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___25 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___141 *, struct socket___25 *);
	int (*sendmsg)(struct socket___25 *, struct msghdr___25 *, size_t);
	int (*recvmsg)(struct socket___25 *, struct msghdr___25 *, size_t, int);
	int (*mmap)(struct file___163 *, struct socket___25 *, struct vm_area_struct___168 *);
	ssize_t (*sendpage)(struct socket___25 *, struct page___168 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___25 *, loff_t *, struct pipe_inode_info___56 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___25 *, int);
	int (*peek_len)(struct socket___25 *);
	int (*read_sock)(struct sock___25 *, read_descriptor_t *, sk_read_actor_t___24);
	int (*sendpage_locked)(struct sock___25 *, struct page___168 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___25 *, struct msghdr___25 *, size_t);
	int (*set_rcvlowat)(struct sock___25 *, int);
};

struct sk_buff___32 {
	union {
		struct {
			struct sk_buff___32 *next;
			struct sk_buff___32 *prev;
			union {
				struct net_device___33 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___25 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___32 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___119 {
	int (*prepare)(struct device___119 *);
	void (*complete)(struct device___119 *);
	int (*suspend)(struct device___119 *);
	int (*resume)(struct device___119 *);
	int (*freeze)(struct device___119 *);
	int (*thaw)(struct device___119 *);
	int (*poweroff)(struct device___119 *);
	int (*restore)(struct device___119 *);
	int (*suspend_late)(struct device___119 *);
	int (*resume_early)(struct device___119 *);
	int (*freeze_late)(struct device___119 *);
	int (*thaw_early)(struct device___119 *);
	int (*poweroff_late)(struct device___119 *);
	int (*restore_early)(struct device___119 *);
	int (*suspend_noirq)(struct device___119 *);
	int (*resume_noirq)(struct device___119 *);
	int (*freeze_noirq)(struct device___119 *);
	int (*thaw_noirq)(struct device___119 *);
	int (*poweroff_noirq)(struct device___119 *);
	int (*restore_noirq)(struct device___119 *);
	int (*runtime_suspend)(struct device___119 *);
	int (*runtime_resume)(struct device___119 *);
	int (*runtime_idle)(struct device___119 *);
};

struct wakeup_source___119 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___119 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___119 {
	struct dev_pm_ops___119 ops;
	int (*start)(struct device___119 *);
	void (*detach)(struct device___119 *, bool);
	int (*activate)(struct device___119 *);
	void (*sync)(struct device___119 *);
	void (*dismiss)(struct device___119 *);
};

struct bus_type___119 {
	const char *name;
	const char *dev_name;
	struct device___119 *dev_root;
	const struct attribute_group___150 **bus_groups;
	const struct attribute_group___150 **dev_groups;
	const struct attribute_group___150 **drv_groups;
	int (*match)(struct device___119 *, struct device_driver___119 *);
	int (*uevent)(struct device___119 *, struct kobj_uevent_env *);
	int (*probe)(struct device___119 *);
	void (*sync_state)(struct device___119 *);
	void (*remove)(struct device___119 *);
	void (*shutdown)(struct device___119 *);
	int (*online)(struct device___119 *);
	int (*offline)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	int (*num_vf)(struct device___119 *);
	int (*dma_configure)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___119 {
	const char *name;
	struct bus_type___119 *bus;
	struct module___147 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___119 *);
	void (*sync_state)(struct device___119 *);
	int (*remove)(struct device___119 *);
	void (*shutdown)(struct device___119 *);
	int (*suspend)(struct device___119 *, pm_message_t);
	int (*resume)(struct device___119 *);
	const struct attribute_group___150 **groups;
	const struct attribute_group___150 **dev_groups;
	const struct dev_pm_ops___119 *pm;
	void (*coredump)(struct device___119 *);
	struct driver_private *p;
};

struct device_type___119 {
	const char *name;
	const struct attribute_group___150 **groups;
	int (*uevent)(struct device___119 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___119 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___119 *);
	const struct dev_pm_ops___119 *pm;
};

struct class___119 {
	const char *name;
	struct module___147 *owner;
	const struct attribute_group___150 **class_groups;
	const struct attribute_group___150 **dev_groups;
	struct kobject___150 *dev_kobj;
	int (*dev_uevent)(struct device___119 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___119 *, umode_t *);
	void (*class_release)(struct class___119 *);
	void (*dev_release)(struct device___119 *);
	int (*shutdown_pre)(struct device___119 *);
	const struct kobj_ns_type_operations___24 *ns_type;
	const void * (*namespace)(struct device___119 *);
	void (*get_ownership)(struct device___119 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___119 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___56;

struct pipe_buffer___56 {
	struct page___168 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___56 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___56 {
	int (*confirm)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
	void (*release)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
	bool (*try_steal)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
	bool (*get)(struct pipe_inode_info___56 *, struct pipe_buffer___56 *);
};

typedef rx_handler_result_t rx_handler_func_t___31(struct sk_buff___32 **);

struct bpf_xdp_entity___31 {
	struct bpf_prog___31 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___31;

struct net_device_ops___31;

struct ethtool_ops___9;

struct l3mdev_ops___24;

struct ndisc_ops___14;

struct xfrmdev_ops___31;

struct header_ops___31;

struct inet6_dev___14;

struct netdev_rx_queue___31;

struct mini_Qdisc___31;

struct netdev_queue___31;

struct Qdisc___31;

struct rtnl_link_ops___31;

struct dcbnl_rtnl_ops___31;

struct net_device___33 {
	char name[16];
	struct netdev_name_node___31 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___31 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___9 *ethtool_ops;
	const struct l3mdev_ops___24 *l3mdev_ops;
	const struct ndisc_ops___14 *ndisc_ops;
	const struct xfrmdev_ops___31 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___31 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___150 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___14 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___31 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___31 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___31 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___31 *miniq_ingress;
	struct netdev_queue___31 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___31 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___31 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___31 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___31 = 0,
		NETREG_REGISTERED___31 = 1,
		NETREG_UNREGISTERING___31 = 2,
		NETREG_UNREGISTERED___31 = 3,
		NETREG_RELEASED___31 = 4,
		NETREG_DUMMY___31 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___31 = 0,
		RTNL_LINK_INITIALIZING___31 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___33 *);
	struct netpoll_info *npinfo;
	possible_net_t___31 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___119 dev;
	const struct attribute_group___150 *sysfs_groups[4];
	const struct attribute_group___150 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___31 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___31 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___31 xdp_state[3];
	long: 64;
};

struct netlink_callback___31 {
	struct sk_buff___32 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___32 *, struct netlink_callback___31 *);
	int (*done)(struct netlink_callback___31 *);
	void *data;
	struct module___147 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_ops___9 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___33 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___33 *);
	void (*get_regs)(struct net_device___33 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___33 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___33 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___33 *);
	void (*set_msglevel)(struct net_device___33 *, u32);
	int (*nway_reset)(struct net_device___33 *);
	u32 (*get_link)(struct net_device___33 *);
	int (*get_link_ext_state)(struct net_device___33 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___33 *);
	int (*get_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___33 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___33 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___33 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___33 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___33 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___33 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___33 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___33 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___33 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___33 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___33 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___33 *);
	void (*complete)(struct net_device___33 *);
	u32 (*get_priv_flags)(struct net_device___33 *);
	int (*set_priv_flags)(struct net_device___33 *, u32);
	int (*get_sset_count)(struct net_device___33 *, int);
	int (*get_rxnfc)(struct net_device___33 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___33 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___33 *, struct ethtool_flash *);
	int (*reset)(struct net_device___33 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___33 *);
	u32 (*get_rxfh_indir_size)(struct net_device___33 *);
	int (*get_rxfh)(struct net_device___33 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___33 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___33 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___33 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___33 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___33 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___33 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___33 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___33 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___33 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___33 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___33 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___33 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___33 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___33 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___33 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___33 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___33 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___33 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___33 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___33 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___33 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___33 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___33 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___33 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___33 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___33 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___33 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___33 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___33 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___33 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct inet_frags___36;

struct fqdir___36 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___36 *f;
	struct net___36 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___36;

struct inet_frags___36 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___36 *, const void *);
	void (*destructor)(struct inet_frag_queue___36 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___36 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___32 *fragments_tail;
	struct sk_buff___32 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___36 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___11 {
	struct ip_ra_chain___11 *next;
	struct sock___25 *sk;
	union {
		void (*destructor)(struct sock___25 *);
		struct sock___25 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___24;

struct fib_lookup_arg___24;

struct fib_rules_ops___24 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___24 *, struct flowi *, int, struct fib_lookup_arg___24 *);
	bool (*suppress)(struct fib_rule___24 *, int, struct fib_lookup_arg___24 *);
	int (*match)(struct fib_rule___24 *, struct flowi *, int);
	int (*configure)(struct fib_rule___24 *, struct sk_buff___32 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___24 *);
	int (*compare)(struct fib_rule___24 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___24 *, struct sk_buff___32 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___24 *);
	void (*flush_cache)(struct fib_rules_ops___24 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___147 *owner;
	struct net___36 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___24 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___36 *);
	int (*fib_dump)(struct net___36 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___147 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___11;

struct dst_entry___24 {
	struct net_device___33 *dev;
	struct dst_ops___36 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___32 *);
	int (*output)(struct net___36 *, struct sock___25 *, struct sk_buff___32 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___11 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___24;

struct neigh_parms___24;

struct neigh_ops___24;

struct neighbour___24 {
	struct neighbour___24 *next;
	struct neigh_table___24 *tbl;
	struct neigh_parms___24 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___31 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___24 *, struct sk_buff___32 *);
	const struct neigh_ops___24 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___33 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___31 {
	struct bpf_prog___31 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___31 {
	struct callback_head rcu;
	struct bpf_prog_array_item___31 items[0];
};

struct bpf_prog_aux___33;

struct bpf_prog___31 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___33 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___141 {
	void * (*start)(struct seq_file___141 *, loff_t *);
	void (*stop)(struct seq_file___141 *, void *);
	void * (*next)(struct seq_file___141 *, void *, loff_t *);
	int (*show)(struct seq_file___141 *, void *);
};

struct dcbnl_rtnl_ops___31 {
	int (*ieee_getets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___33 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___33 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___33 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___33 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___33 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___33 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___33 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___33 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___33 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___33 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___33 *);
	u8 (*setstate)(struct net_device___33 *, u8);
	void (*getpermhwaddr)(struct net_device___33 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___33 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___33 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___33 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___33 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___33 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___33 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___33 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___33 *, int, u8 *);
	void (*setpfccfg)(struct net_device___33 *, int, u8);
	void (*getpfccfg)(struct net_device___33 *, int, u8 *);
	u8 (*setall)(struct net_device___33 *);
	u8 (*getcap)(struct net_device___33 *, int, u8 *);
	int (*getnumtcs)(struct net_device___33 *, int, u8 *);
	int (*setnumtcs)(struct net_device___33 *, int, u8);
	u8 (*getpfcstate)(struct net_device___33 *);
	void (*setpfcstate)(struct net_device___33 *, u8);
	void (*getbcncfg)(struct net_device___33 *, int, u32 *);
	void (*setbcncfg)(struct net_device___33 *, int, u32);
	void (*getbcnrp)(struct net_device___33 *, int, u8 *);
	void (*setbcnrp)(struct net_device___33 *, int, u8);
	int (*setapp)(struct net_device___33 *, u8, u16, u8);
	int (*getapp)(struct net_device___33 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___33 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___33 *, int, u8);
	u8 (*getdcbx)(struct net_device___33 *);
	u8 (*setdcbx)(struct net_device___33 *, u8);
	int (*peer_getappinfo)(struct net_device___33 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___33 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___33 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___33 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___33 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___33 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___34;

typedef int (*bpf_iter_init_seq_priv_t___33)(void *, struct bpf_iter_aux_info___34 *);

struct bpf_map___33;

struct bpf_iter_aux_info___34 {
	struct bpf_map___33 *map;
};

struct bpf_iter_seq_info___33 {
	const struct seq_operations___141 *seq_ops;
	bpf_iter_init_seq_priv_t___33 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___33 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___33 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___33 *, struct file___163 *);
	void (*map_free)(struct bpf_map___33 *);
	int (*map_get_next_key)(struct bpf_map___33 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___33 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___33 *, void *);
	int (*map_lookup_batch)(struct bpf_map___33 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___33 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___33 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___33 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___33 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___33 *, void *);
	int (*map_update_elem)(struct bpf_map___33 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___33 *, void *);
	int (*map_push_elem)(struct bpf_map___33 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___33 *, void *);
	int (*map_peek_elem)(struct bpf_map___33 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___33 *, struct file___163 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___33 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___33 *, void *, struct seq_file___141 *);
	int (*map_check_btf)(const struct bpf_map___33 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___33 *, struct bpf_prog_aux___33 *);
	void (*map_poke_untrack)(struct bpf_map___33 *, struct bpf_prog_aux___33 *);
	void (*map_poke_run)(struct bpf_map___33 *, u32, struct bpf_prog___31 *, struct bpf_prog___31 *);
	int (*map_direct_value_addr)(const struct bpf_map___33 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___33 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___33 *, struct vm_area_struct___168 *);
	__poll_t (*map_poll)(struct bpf_map___33 *, struct file___163 *, struct poll_table_struct___104 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___33 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___33 *, const struct bpf_map___33 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___33 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___33 *iter_seq_info;
};

struct bpf_map___33 {
	const struct bpf_map_ops___33 *ops;
	struct bpf_map___33 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___64 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___33;

struct bpf_jit_poke_descriptor___33;

struct bpf_prog_ops___31;

struct btf_mod_pair___33;

struct bpf_prog_offload___31;

struct bpf_prog_aux___33 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___31 *dst_prog;
	struct bpf_trampoline___33 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___31 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___33 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___31 *ops;
	struct bpf_map___33 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___33 *used_btfs;
	struct bpf_prog___31 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___33 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___31 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___31;

struct bpf_map_dev_ops___31 {
	int (*map_get_next_key)(struct bpf_offloaded_map___31 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___31 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___31 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___31 *, void *);
};

struct bpf_offloaded_map___31 {
	struct bpf_map___33 map;
	struct net_device___33 *netdev;
	const struct bpf_map_dev_ops___31 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___31 {
	int (*test_run)(struct bpf_prog___31 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___31 {
	struct bpf_prog___31 *prog;
	struct net_device___33 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___33 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___31 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___147 *mod;
};

struct bpf_jit_poke_descriptor___33 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___33 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___33 {
	struct btf *btf;
	struct module___147 *module;
};

struct cftype___112;

struct cgroup_subsys___112 {
	struct cgroup_subsys_state___112 * (*css_alloc)(struct cgroup_subsys_state___112 *);
	int (*css_online)(struct cgroup_subsys_state___112 *);
	void (*css_offline)(struct cgroup_subsys_state___112 *);
	void (*css_released)(struct cgroup_subsys_state___112 *);
	void (*css_free)(struct cgroup_subsys_state___112 *);
	void (*css_reset)(struct cgroup_subsys_state___112 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___112 *, int);
	int (*css_extra_stat_show)(struct seq_file___141 *, struct cgroup_subsys_state___112 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___170 *, struct css_set___112 *);
	void (*cancel_fork)(struct task_struct___170 *, struct css_set___112 *);
	void (*fork)(struct task_struct___170 *);
	void (*exit)(struct task_struct___170 *);
	void (*release)(struct task_struct___170 *);
	void (*bind)(struct cgroup_subsys_state___112 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___112 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___112 *dfl_cftypes;
	struct cftype___112 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___112 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___112 *updated_children;
	struct cgroup___112 *updated_next;
};

struct cgroup_root___112 {
	struct kernfs_root___150 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___112 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___112 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___112 *ss;
	struct list_head node;
	struct kernfs_ops___150 *kf_ops;
	int (*open)(struct kernfs_open_file___150 *);
	void (*release)(struct kernfs_open_file___150 *);
	u64 (*read_u64)(struct cgroup_subsys_state___112 *, struct cftype___112 *);
	s64 (*read_s64)(struct cgroup_subsys_state___112 *, struct cftype___112 *);
	int (*seq_show)(struct seq_file___141 *, void *);
	void * (*seq_start)(struct seq_file___141 *, loff_t *);
	void * (*seq_next)(struct seq_file___141 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___141 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___112 *, struct cftype___112 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___112 *, struct cftype___112 *, s64);
	ssize_t (*write)(struct kernfs_open_file___150 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___150 *, struct poll_table_struct___104 *);
};

struct xdp_rxq_info___31 {
	struct net_device___33 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___31 {
	struct net_device___33 *dev;
};

struct xdp_buff___31 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___31 *rxq;
	struct xdp_txq_info___31 *txq;
	u32 frame_sz;
};

struct xdp_frame___31 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___33 *dev_rx;
};

struct header_ops___31 {
	int (*create)(struct sk_buff___32 *, struct net_device___33 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___32 *, unsigned char *);
	int (*cache)(const struct neighbour___24 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___33 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___32 *);
};

struct netdev_queue___31 {
	struct net_device___33 *dev;
	struct Qdisc___31 *qdisc;
	struct Qdisc___31 *qdisc_sleeping;
	struct kobject___150 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___33 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___31 {
	struct sk_buff___32 *head;
	struct sk_buff___32 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___31;

struct Qdisc___31 {
	int (*enqueue)(struct sk_buff___32 *, struct Qdisc___31 *, struct sk_buff___32 **);
	struct sk_buff___32 * (*dequeue)(struct Qdisc___31 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___31 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___31 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___31 gso_skb;
	struct qdisc_skb_head___31 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___31 *next_sched;
	struct sk_buff_head___31 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___31 {
	struct xdp_rxq_info___31 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___150 kobj;
	struct net_device___33 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___31 {
	enum net_device_path_type type;
	const struct net_device___33 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___31 = 0,
				DEV_PATH_BR_VLAN_TAG___31 = 1,
				DEV_PATH_BR_VLAN_UNTAG___31 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___31 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___31 {
	const struct net_device___33 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___31 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___31 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___31 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___31 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___32 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___31 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___33 *dev;
	const char *name;
};

struct net_device_ops___31 {
	int (*ndo_init)(struct net_device___33 *);
	void (*ndo_uninit)(struct net_device___33 *);
	int (*ndo_open)(struct net_device___33 *);
	int (*ndo_stop)(struct net_device___33 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___32 *, struct net_device___33 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___32 *, struct net_device___33 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___33 *, struct sk_buff___32 *, struct net_device___33 *);
	void (*ndo_change_rx_flags)(struct net_device___33 *, int);
	void (*ndo_set_rx_mode)(struct net_device___33 *);
	int (*ndo_set_mac_address)(struct net_device___33 *, void *);
	int (*ndo_validate_addr)(struct net_device___33 *);
	int (*ndo_do_ioctl)(struct net_device___33 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___33 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___33 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___33 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___33 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___33 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___33 *, int);
	int (*ndo_neigh_setup)(struct net_device___33 *, struct neigh_parms___24 *);
	void (*ndo_tx_timeout)(struct net_device___33 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___33 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___33 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___33 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___33 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___33 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___33 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___33 *);
	int (*ndo_netpoll_setup)(struct net_device___33 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___33 *);
	int (*ndo_set_vf_mac)(struct net_device___33 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___33 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___33 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___33 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___33 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___33 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___33 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___33 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___33 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___33 *, int, struct sk_buff___32 *);
	int (*ndo_get_vf_guid)(struct net_device___33 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___33 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___33 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___33 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___33 *);
	int (*ndo_fcoe_disable)(struct net_device___33 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___33 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___33 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___33 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___33 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___33 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___33 *, const struct sk_buff___32 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___33 *, struct net_device___33 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___33 *, struct net_device___33 *);
	struct net_device___33 * (*ndo_get_xmit_slave)(struct net_device___33 *, struct sk_buff___32 *, bool);
	struct net_device___33 * (*ndo_sk_get_lower_dev)(struct net_device___33 *, struct sock___25 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___33 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___33 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___33 *, struct neighbour___24 *);
	void (*ndo_neigh_destroy)(struct net_device___33 *, struct neighbour___24 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___32 *, struct netlink_callback___31 *, struct net_device___33 *, struct net_device___33 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___32 *, struct nlattr **, struct net_device___33 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___33 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___32 *, u32, u32, struct net_device___33 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___33 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___33 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___33 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___33 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___33 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___33 *, struct net_device___33 *);
	void (*ndo_dfwd_del_station)(struct net_device___33 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___33 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___33 *);
	int (*ndo_change_proto_down)(struct net_device___33 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___33 *, struct sk_buff___32 *);
	void (*ndo_set_rx_headroom)(struct net_device___33 *, int);
	int (*ndo_bpf)(struct net_device___33 *, struct netdev_bpf___31 *);
	int (*ndo_xdp_xmit)(struct net_device___33 *, int, struct xdp_frame___31 **, u32);
	struct net_device___33 * (*ndo_xdp_get_xmit_slave)(struct net_device___33 *, struct xdp_buff___31 *);
	int (*ndo_xsk_wakeup)(struct net_device___33 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___33 *);
	int (*ndo_tunnel_ctl)(struct net_device___33 *, struct ip_tunnel_parm *, int);
	struct net_device___33 * (*ndo_get_peer_dev)(struct net_device___33 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___31 *, struct net_device_path___31 *);
};

struct neigh_parms___24 {
	possible_net_t___31 net;
	struct net_device___33 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___24 *);
	struct neigh_table___24 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___24 {
	u32 (*l3mdev_fib_table)(const struct net_device___33 *);
	struct sk_buff___32 * (*l3mdev_l3_rcv)(struct net_device___33 *, struct sk_buff___32 *, u16);
	struct sk_buff___32 * (*l3mdev_l3_out)(struct net_device___33 *, struct sock___25 *, struct sk_buff___32 *, u16);
	struct dst_entry___24 * (*l3mdev_link_scope_lookup)(const struct net_device___33 *, struct flowi6 *);
};

struct ndisc_ops___14 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___33 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___33 *, struct neighbour___24 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___33 *, u8, struct neighbour___24 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___33 *, struct sk_buff___32 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___36 *, struct net_device___33 *, const struct prefix_info *, struct inet6_dev___14 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___14;

struct inet6_dev___14 {
	struct net_device___33 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___14 *mc_list;
	struct ifmcaddr6___14 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___31 mc_query_queue;
	struct sk_buff_head___31 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___24 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___31;

struct tcf_block___31;

struct mini_Qdisc___31 {
	struct tcf_proto___31 *filter_list;
	struct tcf_block___31 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___31 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___33 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___33 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___36 *, struct net_device___33 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___33 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___33 *, struct list_head *);
	size_t (*get_size)(const struct net_device___33 *);
	int (*fill_info)(struct sk_buff___32 *, const struct net_device___33 *);
	size_t (*get_xstats_size)(const struct net_device___33 *);
	int (*fill_xstats)(struct sk_buff___32 *, const struct net_device___33 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___33 *, struct net_device___33 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___33 *, const struct net_device___33 *);
	int (*fill_slave_info)(struct sk_buff___32 *, const struct net_device___33 *, const struct net_device___33 *);
	struct net___36 * (*get_link_net)(const struct net_device___33 *);
	size_t (*get_linkxstats_size)(const struct net_device___33 *, int);
	int (*fill_linkxstats)(struct sk_buff___32 *, const struct net_device___33 *, int *, int);
};

struct block_device_operations___76;

struct gendisk___76 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___77 *part0;
	const struct block_device_operations___76 *fops;
	struct request_queue___76 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___73 *bdi;
	struct kobject___150 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___150 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___76 {
	struct bio___76 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___90 *bip_vec;
	struct bio_vec___90 bip_inline_vecs[0];
};

struct blkcg___73;

struct blkg_policy_data___73;

struct blkcg_gq___73 {
	struct request_queue___76 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___73 *blkcg;
	struct blkcg_gq___73 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___73 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___76 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___76(struct request___76 *);

typedef void integrity_complete_fn___76(struct request___76 *, unsigned int);

struct blk_integrity_profile___76 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___76 *prepare_fn;
	integrity_complete_fn___76 *complete_fn;
	const char *name;
};

struct block_device_operations___76 {
	blk_qc_t (*submit_bio)(struct bio___76 *);
	int (*open)(struct block_device___77 *, fmode_t);
	void (*release)(struct gendisk___76 *, fmode_t);
	int (*rw_page)(struct block_device___77 *, sector_t, struct page___168 *, unsigned int);
	int (*ioctl)(struct block_device___77 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___77 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___76 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___76 *);
	int (*getgeo)(struct block_device___77 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___77 *, bool);
	void (*swap_slot_free_notify)(struct block_device___77 *, long unsigned int);
	int (*report_zones)(struct gendisk___76 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___76 *, umode_t *);
	struct module___147 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___76 *, sector_t *);
};

typedef void rq_end_io_fn___76(struct request___76 *, blk_status_t);

struct request___76 {
	struct request_queue___76 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___73 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___76 *bio;
	struct bio___76 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___90 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___76 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___76 *saved_end_io;
		} flush;
	};
	struct gendisk___76 *rq_disk;
	struct block_device___77 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___76 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___73 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___76 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___150 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___163 *debugfs_dir;
	struct dentry___163 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___76;

struct elevator_mq_ops___76 {
	int (*init_sched)(struct request_queue___76 *, struct elevator_type___76 *);
	void (*exit_sched)(struct elevator_queue___76 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___73 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___73 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___73 *);
	bool (*allow_merge)(struct request_queue___76 *, struct request___76 *, struct bio___76 *);
	bool (*bio_merge)(struct request_queue___76 *, struct bio___76 *, unsigned int);
	int (*request_merge)(struct request_queue___76 *, struct request___76 **, struct bio___76 *);
	void (*request_merged)(struct request_queue___76 *, struct request___76 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___76 *, struct request___76 *, struct request___76 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___76 *);
	void (*finish_request)(struct request___76 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___73 *, struct list_head *, bool);
	struct request___76 * (*dispatch_request)(struct blk_mq_hw_ctx___73 *);
	bool (*has_work)(struct blk_mq_hw_ctx___73 *);
	void (*completed_request)(struct request___76 *, u64);
	void (*requeue_request)(struct request___76 *);
	struct request___76 * (*former_request)(struct request_queue___76 *, struct request___76 *);
	struct request___76 * (*next_request)(struct request_queue___76 *, struct request___76 *);
	void (*init_icq)(struct io_cq___76 *);
	void (*exit_icq)(struct io_cq___76 *);
};

struct elv_fs_entry___76;

struct elevator_type___76 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___76 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___76 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___147 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___76 {
	struct elevator_type___76 *type;
	void *elevator_data;
	struct kobject___150 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___76 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___76 *, char *);
	ssize_t (*store)(struct elevator_queue___76 *, const char *, size_t);
};

struct blk_mq_queue_data___73;

struct blk_mq_ops___73 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___73 *, const struct blk_mq_queue_data___73 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___73 *);
	int (*get_budget)(struct request_queue___76 *);
	void (*put_budget)(struct request_queue___76 *, int);
	void (*set_rq_budget_token)(struct request___76 *, int);
	int (*get_rq_budget_token)(struct request___76 *);
	enum blk_eh_timer_return (*timeout)(struct request___76 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___73 *);
	void (*complete)(struct request___76 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___73 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___73 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___73 *, struct request___76 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___73 *, struct request___76 *, unsigned int);
	void (*initialize_rq_fn)(struct request___76 *);
	void (*cleanup_rq)(struct request___76 *);
	bool (*busy)(struct request_queue___76 *);
	int (*map_queues)(struct blk_mq_tag_set___73 *);
	void (*show_rq)(struct seq_file___141 *, struct request___76 *);
};

struct blk_mq_tag_set___73 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___73 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___73 {
	struct request___76 *rq;
	bool last;
};

struct blkcg_policy_data___73;

struct blkcg___73 {
	struct cgroup_subsys_state___112 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___73 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___73 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___73 {
	struct blkcg___73 *blkcg;
	int plid;
};

struct blkg_policy_data___73 {
	struct blkcg_gq___73 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___64 {
	struct mem_cgroup___64 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___64 {
	struct lruvec___71 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___64 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___64 *memcg;
};

struct obj_cgroup___64 {
	struct percpu_ref refcnt;
	struct mem_cgroup___64 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___31 {
	spinlock_t *lock;
	struct sk_buff___32 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___31;

struct Qdisc_ops___31 {
	struct Qdisc_ops___31 *next;
	const struct Qdisc_class_ops___31 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___32 *, struct Qdisc___31 *, struct sk_buff___32 **);
	struct sk_buff___32 * (*dequeue)(struct Qdisc___31 *);
	struct sk_buff___32 * (*peek)(struct Qdisc___31 *);
	int (*init)(struct Qdisc___31 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___31 *);
	void (*destroy)(struct Qdisc___31 *);
	int (*change)(struct Qdisc___31 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___31 *);
	int (*change_tx_queue_len)(struct Qdisc___31 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___31 *, unsigned int);
	int (*dump)(struct Qdisc___31 *, struct sk_buff___32 *);
	int (*dump_stats)(struct Qdisc___31 *, struct gnet_dump___31 *);
	void (*ingress_block_set)(struct Qdisc___31 *, u32);
	void (*egress_block_set)(struct Qdisc___31 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___31 *);
	u32 (*egress_block_get)(struct Qdisc___31 *);
	struct module___147 *owner;
};

struct Qdisc_class_ops___31 {
	unsigned int flags;
	struct netdev_queue___31 * (*select_queue)(struct Qdisc___31 *, struct tcmsg *);
	int (*graft)(struct Qdisc___31 *, long unsigned int, struct Qdisc___31 *, struct Qdisc___31 **, struct netlink_ext_ack *);
	struct Qdisc___31 * (*leaf)(struct Qdisc___31 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___31 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___31 *, u32);
	int (*change)(struct Qdisc___31 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___31 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___31 *, struct qdisc_walker *);
	struct tcf_block___31 * (*tcf_block)(struct Qdisc___31 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___31 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___31 *, long unsigned int);
	int (*dump)(struct Qdisc___31 *, long unsigned int, struct sk_buff___32 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___31 *, long unsigned int, struct gnet_dump___31 *);
};

struct tcf_chain___31;

struct tcf_block___31 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___36 *net;
	struct Qdisc___31 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___31 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___31;

struct tcf_proto_ops___31;

struct tcf_proto___31 {
	struct tcf_proto___31 *next;
	void *root;
	int (*classify)(struct sk_buff___32 *, const struct tcf_proto___31 *, struct tcf_result___31 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___31 *ops;
	struct tcf_chain___31 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___31 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___31 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___31 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___32 *, const struct tcf_proto___31 *, struct tcf_result___31 *);
	int (*init)(struct tcf_proto___31 *);
	void (*destroy)(struct tcf_proto___31 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___31 *, u32);
	void (*put)(struct tcf_proto___31 *, void *);
	int (*change)(struct net___36 *, struct sk_buff___32 *, struct tcf_proto___31 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___31 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___31 *);
	void (*walk)(struct tcf_proto___31 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___31 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___31 *, void *);
	void (*hw_del)(struct tcf_proto___31 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___36 *, struct tcf_chain___31 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___36 *, struct tcf_proto___31 *, void *, struct sk_buff___32 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___36 *, struct tcf_proto___31 *, void *, struct sk_buff___32 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___32 *, struct net___36 *, void *);
	struct module___147 *owner;
	int flags;
};

struct tcf_chain___31 {
	struct mutex filter_chain_lock;
	struct tcf_proto___31 *filter_chain;
	struct list_head list;
	struct tcf_block___31 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___31 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___24 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___31 *prog;
};

struct pneigh_entry___24;

struct neigh_hash_table___24;

struct neigh_table___24 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___33 *, __u32 *);
	bool (*key_eq)(const struct neighbour___24 *, const void *);
	int (*constructor)(struct neighbour___24 *);
	int (*pconstructor)(struct pneigh_entry___24 *);
	void (*pdestructor)(struct pneigh_entry___24 *);
	void (*proxy_redo)(struct sk_buff___32 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___33 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___24 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___31 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___24 *nht;
	struct pneigh_entry___24 **phash_buckets;
};

struct neigh_ops___24 {
	int family;
	void (*solicit)(struct neighbour___24 *, struct sk_buff___32 *);
	void (*error_report)(struct neighbour___24 *, struct sk_buff___32 *);
	int (*output)(struct neighbour___24 *, struct sk_buff___32 *);
	int (*connected_output)(struct neighbour___24 *, struct sk_buff___32 *);
};

struct pneigh_entry___24 {
	struct pneigh_entry___24 *next;
	possible_net_t___31 net;
	struct net_device___33 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___24 {
	struct neighbour___24 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___11 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___36 *, struct sock___25 *, struct sk_buff___32 *);
	int (*orig_input)(struct sk_buff___32 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___24 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___24 *ctarget;
	struct net___36 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___24 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___24 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___14;

struct timewait_sock_ops___14;

struct proto___24 {
	void (*close)(struct sock___25 *, long int);
	int (*pre_connect)(struct sock___25 *, struct sockaddr *, int);
	int (*connect)(struct sock___25 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___25 *, int);
	struct sock___25 * (*accept)(struct sock___25 *, int, int *, bool);
	int (*ioctl)(struct sock___25 *, int, long unsigned int);
	int (*init)(struct sock___25 *);
	void (*destroy)(struct sock___25 *);
	void (*shutdown)(struct sock___25 *, int);
	int (*setsockopt)(struct sock___25 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___25 *, int, int, char *, int *);
	void (*keepalive)(struct sock___25 *, int);
	int (*compat_ioctl)(struct sock___25 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___25 *, struct msghdr___25 *, size_t);
	int (*recvmsg)(struct sock___25 *, struct msghdr___25 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___25 *, struct page___168 *, int, size_t, int);
	int (*bind)(struct sock___25 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___25 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___25 *, struct sk_buff___32 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___25 *);
	int (*hash)(struct sock___25 *);
	void (*unhash)(struct sock___25 *);
	void (*rehash)(struct sock___25 *);
	int (*get_port)(struct sock___25 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___25 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___25 *, int);
	bool (*sock_is_readable)(struct sock___25 *);
	void (*enter_memory_pressure)(struct sock___25 *);
	void (*leave_memory_pressure)(struct sock___25 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___14 *rsk_prot;
	struct timewait_sock_ops___14 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___147 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___25 *, int);
};

struct request_sock___15;

struct request_sock_ops___14 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___25 *, struct request_sock___15 *);
	void (*send_ack)(const struct sock___25 *, struct sk_buff___32 *, struct request_sock___15 *);
	void (*send_reset)(const struct sock___25 *, struct sk_buff___32 *);
	void (*destructor)(struct request_sock___15 *);
	void (*syn_ack_timeout)(const struct request_sock___15 *);
};

struct timewait_sock_ops___14 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___25 *, struct sock___25 *, void *);
	void (*twsk_destructor)(struct sock___25 *);
};

struct request_sock___15 {
	struct sock_common___24 __req_common;
	struct request_sock___15 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___14 *rsk_ops;
	struct sock___25 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___14 {
	struct in6_addr mca_addr;
	struct inet6_dev___14 *idev;
	struct ifmcaddr6___14 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct linux_binprm___34 {
	struct vm_area_struct___168 *vma;
	long unsigned int vma_pages;
	struct mm_struct___169 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___163 *executable;
	struct file___163 *interpreter;
	struct file___163 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___33 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___163 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct aa_loaddata___2 {
	struct kref count;
	struct list_head list;
	struct work_struct work;
	struct dentry___156 *dents[6];
	struct aa_ns___3 *ns;
	char *name;
	size_t size;
	size_t compressed_size;
	long int revision;
	int abi;
	unsigned char *hash;
	char *data;
};

struct aa_load_ent {
	struct list_head list;
	struct aa_profile___3 *new;
	struct aa_profile___3 *old;
	struct aa_profile___3 *rename;
	const char *ns_name;
};

struct dentry___164;

struct super_block___164;

struct module___148;

struct file_system_type___164 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___164 * (*mount)(struct file_system_type___164 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___164 *);
	struct module___148 *owner;
	struct file_system_type___164 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___164;

struct kiocb___164;

struct iov_iter___93;

struct poll_table_struct___105;

struct vm_area_struct___169;

struct inode___164;

struct file_lock___164;

struct page___169;

struct pipe_inode_info___57;

struct seq_file___142;

struct file_operations___164 {
	struct module___148 *owner;
	loff_t (*llseek)(struct file___164 *, loff_t, int);
	ssize_t (*read)(struct file___164 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___164 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___164 *, struct iov_iter___93 *);
	ssize_t (*write_iter)(struct kiocb___164 *, struct iov_iter___93 *);
	int (*iopoll)(struct kiocb___164 *, bool);
	int (*iterate)(struct file___164 *, struct dir_context *);
	int (*iterate_shared)(struct file___164 *, struct dir_context *);
	__poll_t (*poll)(struct file___164 *, struct poll_table_struct___105 *);
	long int (*unlocked_ioctl)(struct file___164 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___164 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___164 *, struct vm_area_struct___169 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___164 *, struct file___164 *);
	int (*flush)(struct file___164 *, fl_owner_t);
	int (*release)(struct inode___164 *, struct file___164 *);
	int (*fsync)(struct file___164 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___164 *, int);
	int (*lock)(struct file___164 *, int, struct file_lock___164 *);
	ssize_t (*sendpage)(struct file___164 *, struct page___169 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___164 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___164 *, long unsigned int);
	int (*flock)(struct file___164 *, int, struct file_lock___164 *);
	ssize_t (*splice_write)(struct pipe_inode_info___57 *, struct file___164 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___164 *, loff_t *, struct pipe_inode_info___57 *, size_t, unsigned int);
	int (*setlease)(struct file___164 *, long int, struct file_lock___164 **, void **);
	long int (*fallocate)(struct file___164 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___142 *, struct file___164 *);
	ssize_t (*copy_file_range)(struct file___164 *, loff_t, struct file___164 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___164 *, loff_t, struct file___164 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___164 *, loff_t, loff_t, int);
};

struct vmacache___169 {
	u64 seqnum;
	struct vm_area_struct___169 *vmas[4];
};

struct page_frag___169 {
	struct page___169 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___170;

struct pid___145;

struct nsproxy___154;

struct signal_struct___165;

struct bio_list___77;

struct backing_dev_info___74;

struct io_context___77;

struct css_set___113;

struct mem_cgroup___65;

struct request_queue___77;

struct vm_struct___148;

struct task_struct___171 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___171 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___170 *mm;
	struct mm_struct___170 *active_mm;
	struct vmacache___169 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___171 *real_parent;
	struct task_struct___171 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___171 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___145 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___154 *nsproxy;
	struct signal_struct___165 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___171 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___77 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___74 *backing_dev_info;
	struct io_context___77 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___113 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___57 *splice_pipe;
	struct page_frag___169 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___65 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___65 *active_memcg;
	struct request_queue___77 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___171 *oom_reaper_list;
	struct vm_struct___148 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___151;

struct kobj_type___151;

struct kernfs_node___151;

struct kobject___151 {
	const char *name;
	struct list_head entry;
	struct kobject___151 *parent;
	struct kset___151 *kset;
	struct kobj_type___151 *ktype;
	struct kernfs_node___151 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___148 {
	struct kobject___151 kobj;
	struct module___148 *mod;
	struct kobject___151 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___148 {
	struct module___148 *mod;
	struct latch_tree_node node;
};

struct module_layout___148 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___148 mtn;
};

struct module_attribute___148;

struct kernel_param___148;

struct module___148 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___148 mkobj;
	struct module_attribute___148 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___151 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___148 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___148 core_layout;
	struct module_layout___148 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___145;

struct upid___145 {
	int nr;
	struct pid_namespace___145 *ns;
};

struct pid_namespace___145 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___171 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___145 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___145 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___145 numbers[1];
};

typedef struct page___169 *pgtable_t___169;

struct address_space___164;

struct page_pool___48;

struct dev_pagemap___160;

struct page___169 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___164 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___48 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___169 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___169 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___170 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___160 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___160;

struct vm_area_struct___169 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___169 *vm_next;
	struct vm_area_struct___169 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___170 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___160 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___164 *vm_file;
	struct file___164 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___165 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___171 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___171 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___145 *pids[4];
	struct pid___145 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___170 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___34;

struct core_state___169;

struct mm_struct___170 {
	struct {
		struct vm_area_struct___169 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___164 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___34 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___169 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___171 *owner;
		struct user_namespace___24 *user_ns;
		struct file___164 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___37;

struct cgroup_namespace___113;

struct nsproxy___154 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___145 *pid_ns_for_children;
	struct net___37 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___113 *cgroup_ns;
};

struct bio___77;

struct bio_list___77 {
	struct bio___77 *head;
	struct bio___77 *tail;
};

struct cgroup_subsys_state___113;

struct bdi_writeback___74 {
	struct backing_dev_info___74 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___113 *memcg_css;
	struct cgroup_subsys_state___113 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___120;

struct backing_dev_info___74 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___74 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___120 *dev;
	char dev_name[64];
	struct device___120 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___164 *debug_dir;
};

struct io_cq___77;

struct io_context___77 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___77 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___113;

struct css_set___113 {
	struct cgroup_subsys_state___113 *subsys[14];
	refcount_t refcount;
	struct css_set___113 *dom_cset;
	struct cgroup___113 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___113 *mg_src_cgrp;
	struct cgroup___113 *mg_dst_cgrp;
	struct css_set___113 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___164;

struct pipe_buffer___57;

struct pipe_inode_info___57 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___169 *tmp_page;
	struct fasync_struct___164 *fasync_readers;
	struct fasync_struct___164 *fasync_writers;
	struct pipe_buffer___57 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___113;

struct cgroup_subsys_state___113 {
	struct cgroup___113 *cgroup;
	struct cgroup_subsys___113 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___113 *parent;
};

struct cgroup_file___113 {
	struct kernfs_node___151 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___65;

struct mem_cgroup_per_node___65;

struct mem_cgroup___65 {
	struct cgroup_subsys_state___113 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___113 events_file;
	struct cgroup_file___113 events_local_file;
	struct cgroup_file___113 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___65 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___171 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___65 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___77;

struct blk_integrity___77 {
	const struct blk_integrity_profile___77 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___77 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___77 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___77;

struct elevator_queue___77;

struct blk_mq_ops___74;

struct blk_mq_hw_ctx___74;

struct gendisk___77;

struct blkcg_gq___74;

struct blk_mq_tag_set___74;

struct request_queue___77 {
	struct request___77 *last_merge;
	struct elevator_queue___77 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___74 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___74 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___77 *disk;
	struct kobject___151 kobj;
	struct kobject___151 *mq_kobj;
	struct blk_integrity___77 integrity;
	struct device___120 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___74 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___74 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___77 bio_split;
	struct dentry___164 *debugfs_dir;
	struct dentry___164 *sched_debugfs_dir;
	struct dentry___164 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___148 {
	struct vm_struct___148 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___169 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___164;

struct address_space___164 {
	struct inode___164 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___164 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___48 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___120 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___48 {
	u32 count;
	struct page___169 *cache[128];
};

struct page_pool___48 {
	struct page_pool_params___48 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___169 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___48 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___160;

struct dev_pagemap___160 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___160 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___164;

struct path___164 {
	struct vfsmount___164 *mnt;
	struct dentry___164 *dentry;
};

struct fown_struct___145 {
	rwlock_t lock;
	struct pid___145 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___164 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___164 f_path;
	struct inode___164 *f_inode;
	const struct file_operations___164 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___145 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___164 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___160;

struct vm_operations_struct___160 {
	void (*open)(struct vm_area_struct___169 *);
	void (*close)(struct vm_area_struct___169 *);
	int (*may_split)(struct vm_area_struct___169 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___169 *);
	int (*mprotect)(struct vm_area_struct___169 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___160 *);
	vm_fault_t (*huge_fault)(struct vm_fault___160 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___160 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___169 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___160 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___160 *);
	int (*access)(struct vm_area_struct___169 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___169 *);
	int (*set_policy)(struct vm_area_struct___169 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___169 *, long unsigned int);
	struct page___169 * (*find_special_page)(struct vm_area_struct___169 *, long unsigned int);
};

struct core_thread___169 {
	struct task_struct___171 *task;
	struct core_thread___169 *next;
};

struct core_state___169 {
	atomic_t nr_threads;
	struct core_thread___169 dumper;
	struct completion startup;
};

struct linux_binprm___35;

struct coredump_params___34;

struct linux_binfmt___34 {
	struct list_head lh;
	struct module___148 *module;
	int (*load_binary)(struct linux_binprm___35 *);
	int (*load_shlib)(struct file___164 *);
	int (*core_dump)(struct coredump_params___34 *);
	long unsigned int min_coredump;
};

struct vm_fault___160 {
	const struct {
		struct vm_area_struct___169 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___169 *cow_page;
	struct page___169 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___169 prealloc_pte;
};

struct psi_group___113 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___171 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___32;

struct cgroup_bpf___32 {
	struct bpf_prog_array___32 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___32 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___113;

struct cgroup_rstat_cpu___113;

struct cgroup___113 {
	struct cgroup_subsys_state___113 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___151 *kn;
	struct cgroup_file___113 procs_file;
	struct cgroup_file___113 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___113 *subsys[14];
	struct cgroup_root___113 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___113 *dom_cgrp;
	struct cgroup___113 *old_dom_cgrp;
	struct cgroup_rstat_cpu___113 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___113 psi;
	struct cgroup_bpf___32 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___72;

struct lruvec___72 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___72 *pgdat;
};

struct zone___72 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___72 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___72 {
	struct zone___72 *zone;
	int zone_idx;
};

struct zonelist___72 {
	struct zoneref___72 _zonerefs[321];
};

struct pglist_data___72 {
	struct zone___72 node_zones[5];
	struct zonelist___72 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___171 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___171 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___72 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___65 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___65 *memcg;
};

struct shrinker___65 {
	long unsigned int (*count_objects)(struct shrinker___65 *, struct shrink_control___65 *);
	long unsigned int (*scan_objects)(struct shrinker___65 *, struct shrink_control___65 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___160 {
	void (*page_free)(struct page___169 *);
	void (*kill)(struct dev_pagemap___160 *);
	void (*cleanup)(struct dev_pagemap___160 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___160 *);
};

struct dentry_operations___164;

struct dentry___164 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___164 *d_parent;
	struct qstr d_name;
	struct inode___164 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___164 *d_op;
	struct super_block___164 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___164;

struct inode___164 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___164 *i_op;
	struct super_block___164 *i_sb;
	struct address_space___164 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___74 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___164 *i_fop;
		void (*free_inode)(struct inode___164 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___164 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___57 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___164 {
	int (*d_revalidate)(struct dentry___164 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___164 *, unsigned int);
	int (*d_hash)(const struct dentry___164 *, struct qstr *);
	int (*d_compare)(const struct dentry___164 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___164 *);
	int (*d_init)(struct dentry___164 *);
	void (*d_release)(struct dentry___164 *);
	void (*d_prune)(struct dentry___164 *);
	void (*d_iput)(struct dentry___164 *, struct inode___164 *);
	char * (*d_dname)(struct dentry___164 *, char *, int);
	struct vfsmount___164 * (*d_automount)(struct path___164 *);
	int (*d_manage)(const struct path___164 *, bool);
	struct dentry___164 * (*d_real)(struct dentry___164 *, const struct inode___164 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___164;

struct mem_dqinfo___164 {
	struct quota_format_type___164 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___164;

struct quota_info___164 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___164 *files[3];
	struct mem_dqinfo___164 info[3];
	const struct quota_format_ops___164 *ops[3];
};

struct rcuwait___165 {
	struct task_struct___171 *task;
};

struct percpu_rw_semaphore___165 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___165 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___164 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___165 rw_sem[3];
};

struct super_operations___164;

struct dquot_operations___164;

struct quotactl_ops___164;

struct block_device___78;

struct super_block___164 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___164 *s_type;
	const struct super_operations___164 *s_op;
	const struct dquot_operations___164 *dq_op;
	const struct quotactl_ops___164 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___164 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___78 *s_bdev;
	struct backing_dev_info___74 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___164 s_dquot;
	struct sb_writers___164 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___164 *s_d_op;
	int cleancache_poolid;
	struct shrinker___65 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___164 {
	struct dentry___164 *mnt_root;
	struct super_block___164 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct io_cq___77 {
	struct request_queue___77 *q;
	struct io_context___77 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___164 {
	struct file___164 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___164 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___164 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___164 *ia_file;
};

struct dquot___164 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___164 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___164 {
	int qf_fmt_id;
	const struct quota_format_ops___164 *qf_ops;
	struct module___148 *qf_owner;
	struct quota_format_type___164 *qf_next;
};

struct quota_format_ops___164 {
	int (*check_quota_file)(struct super_block___164 *, int);
	int (*read_file_info)(struct super_block___164 *, int);
	int (*write_file_info)(struct super_block___164 *, int);
	int (*free_file_info)(struct super_block___164 *, int);
	int (*read_dqblk)(struct dquot___164 *);
	int (*commit_dqblk)(struct dquot___164 *);
	int (*release_dqblk)(struct dquot___164 *);
	int (*get_next_id)(struct super_block___164 *, struct kqid *);
};

struct dquot_operations___164 {
	int (*write_dquot)(struct dquot___164 *);
	struct dquot___164 * (*alloc_dquot)(struct super_block___164 *, int);
	void (*destroy_dquot)(struct dquot___164 *);
	int (*acquire_dquot)(struct dquot___164 *);
	int (*release_dquot)(struct dquot___164 *);
	int (*mark_dirty)(struct dquot___164 *);
	int (*write_info)(struct super_block___164 *, int);
	qsize_t * (*get_reserved_space)(struct inode___164 *);
	int (*get_projid)(struct inode___164 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___164 *, qsize_t *);
	int (*get_next_id)(struct super_block___164 *, struct kqid *);
};

struct quotactl_ops___164 {
	int (*quota_on)(struct super_block___164 *, int, int, const struct path___164 *);
	int (*quota_off)(struct super_block___164 *, int);
	int (*quota_enable)(struct super_block___164 *, unsigned int);
	int (*quota_disable)(struct super_block___164 *, unsigned int);
	int (*quota_sync)(struct super_block___164 *, int);
	int (*set_info)(struct super_block___164 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___164 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___164 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___164 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___164 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___164 *, unsigned int);
};

struct writeback_control___74;

struct address_space_operations___164 {
	int (*writepage)(struct page___169 *, struct writeback_control___74 *);
	int (*readpage)(struct file___164 *, struct page___169 *);
	int (*writepages)(struct address_space___164 *, struct writeback_control___74 *);
	int (*set_page_dirty)(struct page___169 *);
	int (*readpages)(struct file___164 *, struct address_space___164 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___164 *, struct address_space___164 *, loff_t, unsigned int, unsigned int, struct page___169 **, void **);
	int (*write_end)(struct file___164 *, struct address_space___164 *, loff_t, unsigned int, unsigned int, struct page___169 *, void *);
	sector_t (*bmap)(struct address_space___164 *, sector_t);
	void (*invalidatepage)(struct page___169 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___169 *, gfp_t);
	void (*freepage)(struct page___169 *);
	ssize_t (*direct_IO)(struct kiocb___164 *, struct iov_iter___93 *);
	int (*migratepage)(struct address_space___164 *, struct page___169 *, struct page___169 *, enum migrate_mode);
	bool (*isolate_page)(struct page___169 *, isolate_mode_t);
	void (*putback_page)(struct page___169 *);
	int (*launder_page)(struct page___169 *);
	int (*is_partially_uptodate)(struct page___169 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___169 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___164 *, struct page___169 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___164 *, sector_t *);
	void (*swap_deactivate)(struct file___164 *);
};

struct writeback_control___74 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___74 *wb;
	struct inode___164 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___91;

struct iov_iter___93 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___91 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___57 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___164 {
	struct dentry___164 * (*lookup)(struct inode___164 *, struct dentry___164 *, unsigned int);
	const char * (*get_link)(struct dentry___164 *, struct inode___164 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___164 *, int);
	struct posix_acl * (*get_acl)(struct inode___164 *, int, bool);
	int (*readlink)(struct dentry___164 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___164 *, struct dentry___164 *, umode_t, bool);
	int (*link)(struct dentry___164 *, struct inode___164 *, struct dentry___164 *);
	int (*unlink)(struct inode___164 *, struct dentry___164 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___164 *, struct dentry___164 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___164 *, struct dentry___164 *, umode_t);
	int (*rmdir)(struct inode___164 *, struct dentry___164 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___164 *, struct dentry___164 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___164 *, struct dentry___164 *, struct inode___164 *, struct dentry___164 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___164 *, struct iattr___164 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___164 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___164 *, char *, size_t);
	int (*fiemap)(struct inode___164 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___164 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___164 *, struct dentry___164 *, struct file___164 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___164 *, struct dentry___164 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___164 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___164 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___164 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___164 {
	void (*fl_copy_lock)(struct file_lock___164 *, struct file_lock___164 *);
	void (*fl_release_private)(struct file_lock___164 *);
};

struct lock_manager_operations___164;

struct file_lock___164 {
	struct file_lock___164 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___164 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___164 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___164 *fl_ops;
	const struct lock_manager_operations___164 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___164 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___164 *);
	int (*lm_grant)(struct file_lock___164 *, int);
	bool (*lm_break)(struct file_lock___164 *);
	int (*lm_change)(struct file_lock___164 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___164 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___164 *);
};

struct fasync_struct___164 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___164 *fa_next;
	struct file___164 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___164 {
	struct inode___164 * (*alloc_inode)(struct super_block___164 *);
	void (*destroy_inode)(struct inode___164 *);
	void (*free_inode)(struct inode___164 *);
	void (*dirty_inode)(struct inode___164 *, int);
	int (*write_inode)(struct inode___164 *, struct writeback_control___74 *);
	int (*drop_inode)(struct inode___164 *);
	void (*evict_inode)(struct inode___164 *);
	void (*put_super)(struct super_block___164 *);
	int (*sync_fs)(struct super_block___164 *, int);
	int (*freeze_super)(struct super_block___164 *);
	int (*freeze_fs)(struct super_block___164 *);
	int (*thaw_super)(struct super_block___164 *);
	int (*unfreeze_fs)(struct super_block___164 *);
	int (*statfs)(struct dentry___164 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___164 *, int *, char *);
	void (*umount_begin)(struct super_block___164 *);
	int (*show_options)(struct seq_file___142 *, struct dentry___164 *);
	int (*show_devname)(struct seq_file___142 *, struct dentry___164 *);
	int (*show_path)(struct seq_file___142 *, struct dentry___164 *);
	int (*show_stats)(struct seq_file___142 *, struct dentry___164 *);
	ssize_t (*quota_read)(struct super_block___164 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___164 *, int, const char *, size_t, loff_t);
	struct dquot___164 ** (*get_dquots)(struct inode___164 *);
	long int (*nr_cached_objects)(struct super_block___164 *, struct shrink_control___65 *);
	long int (*free_cached_objects)(struct super_block___164 *, struct shrink_control___65 *);
	struct file___164 * (*real_loop)(struct file___164 *);
};

struct wakeup_source___120;

struct dev_pm_info___120 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___120 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___120 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___120;

struct bus_type___120;

struct device_driver___120;

struct dev_pm_domain___120;

struct fwnode_handle___120;

struct class___120;

struct attribute_group___151;

struct device___120 {
	struct kobject___151 kobj;
	struct device___120 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___120 *type;
	struct bus_type___120 *bus;
	struct device_driver___120 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___120 power;
	struct dev_pm_domain___120 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___120 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___120 *class;
	const struct attribute_group___151 **groups;
	void (*release)(struct device___120 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___78 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___164 *bd_inode;
	struct super_block___164 *bd_super;
	void *bd_claiming;
	struct device___120 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___151 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___77 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___164 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___107)(struct file___164 *, wait_queue_head_t *, struct poll_table_struct___105 *);

struct poll_table_struct___105 {
	poll_queue_proc___107 _qproc;
	__poll_t _key;
};

struct seq_operations___142;

struct seq_file___142 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___142 *op;
	int poll_event;
	const struct file___164 *file;
	void *private;
};

typedef void bio_end_io_t___77(struct bio___77 *);

struct bio_vec___91 {
	struct page___169 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___77;

struct bio___77 {
	struct bio___77 *bi_next;
	struct block_device___78 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___77 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___74 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___77 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___91 *bi_io_vec;
	struct bio_set___77 *bi_pool;
	struct bio_vec___91 bi_inline_vecs[0];
};

struct ip_ra_chain___12;

struct fib_rules_ops___25;

struct sock___26;

struct fqdir___37;

struct fib_notifier_ops___25;

struct netns_ipv4___37 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___12 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___25 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___26 *fibnl;
	struct sock___26 **icmp_sk;
	struct sock___26 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___26 **tcp_sk;
	struct fqdir___37 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___25 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___25 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___25 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___25;

struct net_device___34;

struct sk_buff___33;

struct neighbour___25;

struct dst_ops___37 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___37 *);
	struct dst_entry___25 * (*check)(struct dst_entry___25 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___25 *);
	unsigned int (*mtu)(const struct dst_entry___25 *);
	u32 * (*cow_metrics)(struct dst_entry___25 *, long unsigned int);
	void (*destroy)(struct dst_entry___25 *);
	void (*ifdown)(struct dst_entry___25 *, struct net_device___34 *, int);
	struct dst_entry___25 * (*negative_advice)(struct dst_entry___25 *);
	void (*link_failure)(struct sk_buff___33 *);
	void (*update_pmtu)(struct dst_entry___25 *, struct sock___26 *, struct sk_buff___33 *, u32, bool);
	void (*redirect)(struct dst_entry___25 *, struct sock___26 *, struct sk_buff___33 *);
	int (*local_out)(struct net___37 *, struct sock___26 *, struct sk_buff___33 *);
	struct neighbour___25 * (*neigh_lookup)(const struct dst_entry___25 *, struct sk_buff___33 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___25 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___37 {
	struct dst_ops___37 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___37 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___25 *fib6_rules_ops;
	struct sock___26 **icmp_sk;
	struct sock___26 *ndisc_sk;
	struct sock___26 *tcp_sk;
	struct sock___26 *igmp_sk;
	struct sock___26 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___25 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___25 *notifier_ops;
	struct fib_notifier_ops___25 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___37 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___37 *fqdir;
};

struct netns_sctp___25 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___26 *ctl_sock;
	struct sock___26 *udp4_sock;
	struct sock___26 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___32 {
	struct sk_buff___33 *next;
	struct sk_buff___33 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___32;

struct netns_bpf___32 {
	struct bpf_prog_array___32 *run_array[2];
	struct bpf_prog___32 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___37 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___26 *nlsk;
	struct sock___26 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___37 xfrm4_dst_ops;
	struct dst_ops___37 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___37 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___26 *rtnl;
	struct sock___26 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___34 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___37 ipv4;
	struct netns_ipv6___37 ipv6;
	struct netns_ieee802154_lowpan___37 ieee802154_lowpan;
	struct netns_sctp___25 sctp;
	struct netns_nf___2 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___32 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___32 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___37 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___26 *crypto_nlsk;
	struct sock___26 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___113 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___113 *root_cset;
};

struct msghdr___26 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___93 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___164 *msg_iocb;
};

struct fwnode_operations___120;

struct fwnode_handle___120 {
	struct fwnode_handle___120 *secondary;
	const struct fwnode_operations___120 *ops;
	struct device___120 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___120;

struct fwnode_endpoint___120;

struct fwnode_operations___120 {
	struct fwnode_handle___120 * (*get)(struct fwnode_handle___120 *);
	void (*put)(struct fwnode_handle___120 *);
	bool (*device_is_available)(const struct fwnode_handle___120 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___120 *, const struct device___120 *);
	bool (*property_present)(const struct fwnode_handle___120 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___120 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___120 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___120 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*get_parent)(const struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*get_next_child_node)(const struct fwnode_handle___120 *, struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*get_named_child_node)(const struct fwnode_handle___120 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___120 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___120 *);
	struct fwnode_handle___120 * (*graph_get_next_endpoint)(const struct fwnode_handle___120 *, struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*graph_get_remote_endpoint)(const struct fwnode_handle___120 *);
	struct fwnode_handle___120 * (*graph_get_port_parent)(struct fwnode_handle___120 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___120 *, struct fwnode_endpoint___120 *);
	int (*add_links)(struct fwnode_handle___120 *);
};

struct fwnode_endpoint___120 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___120 *local_fwnode;
};

struct fwnode_reference_args___120 {
	struct fwnode_handle___120 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___151;

struct kernfs_elem_dir___151 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___151 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___151;

struct kernfs_root___151 {
	struct kernfs_node___151 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___151 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___151 {
	struct kernfs_node___151 *target_kn;
};

struct kernfs_ops___151;

struct kernfs_elem_attr___151 {
	const struct kernfs_ops___151 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___151 *notify_next;
};

struct kernfs_node___151 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___151 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___151 dir;
		struct kernfs_elem_symlink___151 symlink;
		struct kernfs_elem_attr___151 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___151;

struct kernfs_ops___151 {
	int (*open)(struct kernfs_open_file___151 *);
	void (*release)(struct kernfs_open_file___151 *);
	int (*seq_show)(struct seq_file___142 *, void *);
	void * (*seq_start)(struct seq_file___142 *, loff_t *);
	void * (*seq_next)(struct seq_file___142 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___142 *, void *);
	ssize_t (*read)(struct kernfs_open_file___151 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___151 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___151 *, struct poll_table_struct___105 *);
	int (*mmap)(struct kernfs_open_file___151 *, struct vm_area_struct___169 *);
};

struct kernfs_syscall_ops___151 {
	int (*show_options)(struct seq_file___142 *, struct kernfs_root___151 *);
	int (*mkdir)(struct kernfs_node___151 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___151 *);
	int (*rename)(struct kernfs_node___151 *, struct kernfs_node___151 *, const char *);
	int (*show_path)(struct seq_file___142 *, struct kernfs_node___151 *, struct kernfs_root___151 *);
};

struct kernfs_open_file___151 {
	struct kernfs_node___151 *kn;
	struct file___164 *file;
	struct seq_file___142 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___160 *vm_ops;
};

struct kobj_ns_type_operations___25 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___26 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___37 *net;
} possible_net_t___32;

struct proto___25;

struct sock_common___25 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___25 *skc_prot;
	possible_net_t___32 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___26 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___25 {
	struct cgroup___113 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___25;

struct socket_wq___26;

struct socket___26;

struct sock___26 {
	struct sock_common___25 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___32 sk_error_queue;
	struct sk_buff___33 *sk_rx_skb_cache;
	struct sk_buff_head___32 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___33 *head;
		struct sk_buff___33 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___25 *sk_filter;
	union {
		struct socket_wq___26 *sk_wq;
		struct socket_wq___26 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___25 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___25 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___33 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___33 *sk_tx_skb_cache;
	struct sk_buff_head___32 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___169 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___25 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___145 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___26 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___25 sk_cgrp_data;
	struct mem_cgroup___65 *sk_memcg;
	void (*sk_state_change)(struct sock___26 *);
	void (*sk_data_ready)(struct sock___26 *);
	void (*sk_write_space)(struct sock___26 *);
	void (*sk_error_report)(struct sock___26 *);
	int (*sk_backlog_rcv)(struct sock___26 *, struct sk_buff___33 *);
	struct sk_buff___33 * (*sk_validate_xmit_skb)(struct sock___26 *, struct net_device___34 *, struct sk_buff___33 *);
	void (*sk_destruct)(struct sock___26 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___151;

struct attribute_group___151 {
	const char *name;
	umode_t (*is_visible)(struct kobject___151 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___151 *, struct bin_attribute___151 *, int);
	struct attribute **attrs;
	struct bin_attribute___151 **bin_attrs;
};

struct bin_attribute___151 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___164 * (*f_mapping)();
	ssize_t (*read)(struct file___164 *, struct kobject___151 *, struct bin_attribute___151 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___164 *, struct kobject___151 *, struct bin_attribute___151 *, char *, loff_t, size_t);
	int (*mmap)(struct file___164 *, struct kobject___151 *, struct bin_attribute___151 *, struct vm_area_struct___169 *);
};

struct sysfs_ops___151 {
	ssize_t (*show)(struct kobject___151 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___151 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___151;

struct kset___151 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___151 kobj;
	const struct kset_uevent_ops___151 *uevent_ops;
};

struct kobj_type___151 {
	void (*release)(struct kobject___151 *);
	const struct sysfs_ops___151 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___151 **default_groups;
	const struct kobj_ns_type_operations___25 * (*child_ns_type)(struct kobject___151 *);
	const void * (*namespace)(struct kobject___151 *);
	void (*get_ownership)(struct kobject___151 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___151 {
	int (* const filter)(struct kset___151 *, struct kobject___151 *);
	const char * (* const name)(struct kset___151 *, struct kobject___151 *);
	int (* const uevent)(struct kset___151 *, struct kobject___151 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___148 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___148 *);
	int (*get)(char *, const struct kernel_param___148 *);
	void (*free)(void *);
};

struct kparam_array___148;

struct kernel_param___148 {
	const char *name;
	struct module___148 *mod;
	const struct kernel_param_ops___148 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___148 *arr;
	};
};

struct kparam_array___148 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___148 *ops;
	void *elem;
};

struct module_attribute___148 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___148 *, struct module_kobject___148 *, char *);
	ssize_t (*store)(struct module_attribute___148 *, struct module_kobject___148 *, const char *, size_t);
	void (*setup)(struct module___148 *, const char *);
	int (*test)(struct module___148 *);
	void (*free)(struct module___148 *);
};

struct socket_wq___26 {
	wait_queue_head_t wait;
	struct fasync_struct___164 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___26;

struct socket___26 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___164 *file;
	struct sock___26 *sk;
	const struct proto_ops___26 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___26 wq;
};

typedef int (*sk_read_actor_t___25)(read_descriptor_t *, struct sk_buff___33 *, unsigned int, size_t);

struct proto_ops___26 {
	int family;
	struct module___148 *owner;
	int (*release)(struct socket___26 *);
	int (*bind)(struct socket___26 *, struct sockaddr *, int);
	int (*connect)(struct socket___26 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___26 *, struct socket___26 *);
	int (*accept)(struct socket___26 *, struct socket___26 *, int, bool);
	int (*getname)(struct socket___26 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___164 *, struct socket___26 *, struct poll_table_struct___105 *);
	int (*ioctl)(struct socket___26 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___26 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___26 *, void *, bool, bool);
	int (*listen)(struct socket___26 *, int);
	int (*shutdown)(struct socket___26 *, int);
	int (*setsockopt)(struct socket___26 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___26 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___142 *, struct socket___26 *);
	int (*sendmsg)(struct socket___26 *, struct msghdr___26 *, size_t);
	int (*recvmsg)(struct socket___26 *, struct msghdr___26 *, size_t, int);
	int (*mmap)(struct file___164 *, struct socket___26 *, struct vm_area_struct___169 *);
	ssize_t (*sendpage)(struct socket___26 *, struct page___169 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___26 *, loff_t *, struct pipe_inode_info___57 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___26 *, int);
	int (*peek_len)(struct socket___26 *);
	int (*read_sock)(struct sock___26 *, read_descriptor_t *, sk_read_actor_t___25);
	int (*sendpage_locked)(struct sock___26 *, struct page___169 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___26 *, struct msghdr___26 *, size_t);
	int (*set_rcvlowat)(struct sock___26 *, int);
};

struct sk_buff___33 {
	union {
		struct {
			struct sk_buff___33 *next;
			struct sk_buff___33 *prev;
			union {
				struct net_device___34 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___26 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___33 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___120 {
	int (*prepare)(struct device___120 *);
	void (*complete)(struct device___120 *);
	int (*suspend)(struct device___120 *);
	int (*resume)(struct device___120 *);
	int (*freeze)(struct device___120 *);
	int (*thaw)(struct device___120 *);
	int (*poweroff)(struct device___120 *);
	int (*restore)(struct device___120 *);
	int (*suspend_late)(struct device___120 *);
	int (*resume_early)(struct device___120 *);
	int (*freeze_late)(struct device___120 *);
	int (*thaw_early)(struct device___120 *);
	int (*poweroff_late)(struct device___120 *);
	int (*restore_early)(struct device___120 *);
	int (*suspend_noirq)(struct device___120 *);
	int (*resume_noirq)(struct device___120 *);
	int (*freeze_noirq)(struct device___120 *);
	int (*thaw_noirq)(struct device___120 *);
	int (*poweroff_noirq)(struct device___120 *);
	int (*restore_noirq)(struct device___120 *);
	int (*runtime_suspend)(struct device___120 *);
	int (*runtime_resume)(struct device___120 *);
	int (*runtime_idle)(struct device___120 *);
};

struct wakeup_source___120 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___120 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___120 {
	struct dev_pm_ops___120 ops;
	int (*start)(struct device___120 *);
	void (*detach)(struct device___120 *, bool);
	int (*activate)(struct device___120 *);
	void (*sync)(struct device___120 *);
	void (*dismiss)(struct device___120 *);
};

struct bus_type___120 {
	const char *name;
	const char *dev_name;
	struct device___120 *dev_root;
	const struct attribute_group___151 **bus_groups;
	const struct attribute_group___151 **dev_groups;
	const struct attribute_group___151 **drv_groups;
	int (*match)(struct device___120 *, struct device_driver___120 *);
	int (*uevent)(struct device___120 *, struct kobj_uevent_env *);
	int (*probe)(struct device___120 *);
	void (*sync_state)(struct device___120 *);
	void (*remove)(struct device___120 *);
	void (*shutdown)(struct device___120 *);
	int (*online)(struct device___120 *);
	int (*offline)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	int (*num_vf)(struct device___120 *);
	int (*dma_configure)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___120 {
	const char *name;
	struct bus_type___120 *bus;
	struct module___148 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___120 *);
	void (*sync_state)(struct device___120 *);
	int (*remove)(struct device___120 *);
	void (*shutdown)(struct device___120 *);
	int (*suspend)(struct device___120 *, pm_message_t);
	int (*resume)(struct device___120 *);
	const struct attribute_group___151 **groups;
	const struct attribute_group___151 **dev_groups;
	const struct dev_pm_ops___120 *pm;
	void (*coredump)(struct device___120 *);
	struct driver_private *p;
};

struct device_type___120 {
	const char *name;
	const struct attribute_group___151 **groups;
	int (*uevent)(struct device___120 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___120 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___120 *);
	const struct dev_pm_ops___120 *pm;
};

struct class___120 {
	const char *name;
	struct module___148 *owner;
	const struct attribute_group___151 **class_groups;
	const struct attribute_group___151 **dev_groups;
	struct kobject___151 *dev_kobj;
	int (*dev_uevent)(struct device___120 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___120 *, umode_t *);
	void (*class_release)(struct class___120 *);
	void (*dev_release)(struct device___120 *);
	int (*shutdown_pre)(struct device___120 *);
	const struct kobj_ns_type_operations___25 *ns_type;
	const void * (*namespace)(struct device___120 *);
	void (*get_ownership)(struct device___120 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___120 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___57;

struct pipe_buffer___57 {
	struct page___169 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___57 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___57 {
	int (*confirm)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
	void (*release)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
	bool (*try_steal)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
	bool (*get)(struct pipe_inode_info___57 *, struct pipe_buffer___57 *);
};

typedef rx_handler_result_t rx_handler_func_t___32(struct sk_buff___33 **);

struct bpf_xdp_entity___32 {
	struct bpf_prog___32 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___32;

struct net_device_ops___32;

struct ethtool_ops___10;

struct l3mdev_ops___25;

struct ndisc_ops___15;

struct xfrmdev_ops___32;

struct header_ops___32;

struct inet6_dev___15;

struct netdev_rx_queue___32;

struct mini_Qdisc___32;

struct netdev_queue___32;

struct Qdisc___32;

struct rtnl_link_ops___32;

struct dcbnl_rtnl_ops___32;

struct net_device___34 {
	char name[16];
	struct netdev_name_node___32 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___32 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___10 *ethtool_ops;
	const struct l3mdev_ops___25 *l3mdev_ops;
	const struct ndisc_ops___15 *ndisc_ops;
	const struct xfrmdev_ops___32 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___32 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___151 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___15 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___32 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___32 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___32 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___32 *miniq_ingress;
	struct netdev_queue___32 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___32 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___32 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___32 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___32 = 0,
		NETREG_REGISTERED___32 = 1,
		NETREG_UNREGISTERING___32 = 2,
		NETREG_UNREGISTERED___32 = 3,
		NETREG_RELEASED___32 = 4,
		NETREG_DUMMY___32 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___32 = 0,
		RTNL_LINK_INITIALIZING___32 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___34 *);
	struct netpoll_info *npinfo;
	possible_net_t___32 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___120 dev;
	const struct attribute_group___151 *sysfs_groups[4];
	const struct attribute_group___151 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___32 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___32 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___32 xdp_state[3];
	long: 64;
};

struct netlink_callback___32 {
	struct sk_buff___33 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___33 *, struct netlink_callback___32 *);
	int (*done)(struct netlink_callback___32 *);
	void *data;
	struct module___148 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_ops___10 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___34 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___34 *);
	void (*get_regs)(struct net_device___34 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___34 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___34 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___34 *);
	void (*set_msglevel)(struct net_device___34 *, u32);
	int (*nway_reset)(struct net_device___34 *);
	u32 (*get_link)(struct net_device___34 *);
	int (*get_link_ext_state)(struct net_device___34 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___34 *);
	int (*get_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___34 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___34 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___34 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___34 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___34 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___34 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___34 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___34 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___34 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___34 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___34 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___34 *);
	void (*complete)(struct net_device___34 *);
	u32 (*get_priv_flags)(struct net_device___34 *);
	int (*set_priv_flags)(struct net_device___34 *, u32);
	int (*get_sset_count)(struct net_device___34 *, int);
	int (*get_rxnfc)(struct net_device___34 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___34 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___34 *, struct ethtool_flash *);
	int (*reset)(struct net_device___34 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___34 *);
	u32 (*get_rxfh_indir_size)(struct net_device___34 *);
	int (*get_rxfh)(struct net_device___34 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___34 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___34 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___34 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___34 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___34 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___34 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___34 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___34 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___34 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___34 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___34 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___34 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___34 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___34 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___34 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___34 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___34 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___34 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___34 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___34 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___34 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___34 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___34 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___34 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___34 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___34 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___34 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___34 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___34 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___34 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct inet_frags___37;

struct fqdir___37 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___37 *f;
	struct net___37 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___37;

struct inet_frags___37 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___37 *, const void *);
	void (*destructor)(struct inet_frag_queue___37 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___37 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___33 *fragments_tail;
	struct sk_buff___33 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___37 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___12 {
	struct ip_ra_chain___12 *next;
	struct sock___26 *sk;
	union {
		void (*destructor)(struct sock___26 *);
		struct sock___26 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___25;

struct fib_lookup_arg___25;

struct fib_rules_ops___25 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___25 *, struct flowi *, int, struct fib_lookup_arg___25 *);
	bool (*suppress)(struct fib_rule___25 *, int, struct fib_lookup_arg___25 *);
	int (*match)(struct fib_rule___25 *, struct flowi *, int);
	int (*configure)(struct fib_rule___25 *, struct sk_buff___33 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___25 *);
	int (*compare)(struct fib_rule___25 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___25 *, struct sk_buff___33 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___25 *);
	void (*flush_cache)(struct fib_rules_ops___25 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___148 *owner;
	struct net___37 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___25 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___37 *);
	int (*fib_dump)(struct net___37 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___148 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___12;

struct dst_entry___25 {
	struct net_device___34 *dev;
	struct dst_ops___37 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___33 *);
	int (*output)(struct net___37 *, struct sock___26 *, struct sk_buff___33 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___12 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___25;

struct neigh_parms___25;

struct neigh_ops___25;

struct neighbour___25 {
	struct neighbour___25 *next;
	struct neigh_table___25 *tbl;
	struct neigh_parms___25 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___32 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___25 *, struct sk_buff___33 *);
	const struct neigh_ops___25 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___34 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___32 {
	struct bpf_prog___32 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___32 {
	struct callback_head rcu;
	struct bpf_prog_array_item___32 items[0];
};

struct bpf_prog_aux___34;

struct bpf_prog___32 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___34 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___142 {
	void * (*start)(struct seq_file___142 *, loff_t *);
	void (*stop)(struct seq_file___142 *, void *);
	void * (*next)(struct seq_file___142 *, void *, loff_t *);
	int (*show)(struct seq_file___142 *, void *);
};

struct dcbnl_rtnl_ops___32 {
	int (*ieee_getets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___34 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___34 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___34 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___34 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___34 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___34 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___34 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___34 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___34 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___34 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___34 *);
	u8 (*setstate)(struct net_device___34 *, u8);
	void (*getpermhwaddr)(struct net_device___34 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___34 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___34 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___34 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___34 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___34 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___34 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___34 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___34 *, int, u8 *);
	void (*setpfccfg)(struct net_device___34 *, int, u8);
	void (*getpfccfg)(struct net_device___34 *, int, u8 *);
	u8 (*setall)(struct net_device___34 *);
	u8 (*getcap)(struct net_device___34 *, int, u8 *);
	int (*getnumtcs)(struct net_device___34 *, int, u8 *);
	int (*setnumtcs)(struct net_device___34 *, int, u8);
	u8 (*getpfcstate)(struct net_device___34 *);
	void (*setpfcstate)(struct net_device___34 *, u8);
	void (*getbcncfg)(struct net_device___34 *, int, u32 *);
	void (*setbcncfg)(struct net_device___34 *, int, u32);
	void (*getbcnrp)(struct net_device___34 *, int, u8 *);
	void (*setbcnrp)(struct net_device___34 *, int, u8);
	int (*setapp)(struct net_device___34 *, u8, u16, u8);
	int (*getapp)(struct net_device___34 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___34 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___34 *, int, u8);
	u8 (*getdcbx)(struct net_device___34 *);
	u8 (*setdcbx)(struct net_device___34 *, u8);
	int (*peer_getappinfo)(struct net_device___34 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___34 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___34 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___34 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___34 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___34 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___35;

typedef int (*bpf_iter_init_seq_priv_t___34)(void *, struct bpf_iter_aux_info___35 *);

struct bpf_map___34;

struct bpf_iter_aux_info___35 {
	struct bpf_map___34 *map;
};

struct bpf_iter_seq_info___34 {
	const struct seq_operations___142 *seq_ops;
	bpf_iter_init_seq_priv_t___34 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___34 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___34 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___34 *, struct file___164 *);
	void (*map_free)(struct bpf_map___34 *);
	int (*map_get_next_key)(struct bpf_map___34 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___34 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___34 *, void *);
	int (*map_lookup_batch)(struct bpf_map___34 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___34 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___34 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___34 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___34 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___34 *, void *);
	int (*map_update_elem)(struct bpf_map___34 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___34 *, void *);
	int (*map_push_elem)(struct bpf_map___34 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___34 *, void *);
	int (*map_peek_elem)(struct bpf_map___34 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___34 *, struct file___164 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___34 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___34 *, void *, struct seq_file___142 *);
	int (*map_check_btf)(const struct bpf_map___34 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___34 *, struct bpf_prog_aux___34 *);
	void (*map_poke_untrack)(struct bpf_map___34 *, struct bpf_prog_aux___34 *);
	void (*map_poke_run)(struct bpf_map___34 *, u32, struct bpf_prog___32 *, struct bpf_prog___32 *);
	int (*map_direct_value_addr)(const struct bpf_map___34 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___34 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___34 *, struct vm_area_struct___169 *);
	__poll_t (*map_poll)(struct bpf_map___34 *, struct file___164 *, struct poll_table_struct___105 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___34 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___34 *, const struct bpf_map___34 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___34 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___34 *iter_seq_info;
};

struct bpf_map___34 {
	const struct bpf_map_ops___34 *ops;
	struct bpf_map___34 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___65 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___34;

struct bpf_jit_poke_descriptor___34;

struct bpf_prog_ops___32;

struct btf_mod_pair___34;

struct bpf_prog_offload___32;

struct bpf_prog_aux___34 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___32 *dst_prog;
	struct bpf_trampoline___34 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___32 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___34 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___32 *ops;
	struct bpf_map___34 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___34 *used_btfs;
	struct bpf_prog___32 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___34 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___32 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___32;

struct bpf_map_dev_ops___32 {
	int (*map_get_next_key)(struct bpf_offloaded_map___32 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___32 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___32 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___32 *, void *);
};

struct bpf_offloaded_map___32 {
	struct bpf_map___34 map;
	struct net_device___34 *netdev;
	const struct bpf_map_dev_ops___32 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___32 {
	int (*test_run)(struct bpf_prog___32 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___32 {
	struct bpf_prog___32 *prog;
	struct net_device___34 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___34 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___32 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___148 *mod;
};

struct bpf_jit_poke_descriptor___34 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___34 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___34 {
	struct btf *btf;
	struct module___148 *module;
};

struct cftype___113;

struct cgroup_subsys___113 {
	struct cgroup_subsys_state___113 * (*css_alloc)(struct cgroup_subsys_state___113 *);
	int (*css_online)(struct cgroup_subsys_state___113 *);
	void (*css_offline)(struct cgroup_subsys_state___113 *);
	void (*css_released)(struct cgroup_subsys_state___113 *);
	void (*css_free)(struct cgroup_subsys_state___113 *);
	void (*css_reset)(struct cgroup_subsys_state___113 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___113 *, int);
	int (*css_extra_stat_show)(struct seq_file___142 *, struct cgroup_subsys_state___113 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___171 *, struct css_set___113 *);
	void (*cancel_fork)(struct task_struct___171 *, struct css_set___113 *);
	void (*fork)(struct task_struct___171 *);
	void (*exit)(struct task_struct___171 *);
	void (*release)(struct task_struct___171 *);
	void (*bind)(struct cgroup_subsys_state___113 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___113 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___113 *dfl_cftypes;
	struct cftype___113 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___113 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___113 *updated_children;
	struct cgroup___113 *updated_next;
};

struct cgroup_root___113 {
	struct kernfs_root___151 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___113 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___113 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___113 *ss;
	struct list_head node;
	struct kernfs_ops___151 *kf_ops;
	int (*open)(struct kernfs_open_file___151 *);
	void (*release)(struct kernfs_open_file___151 *);
	u64 (*read_u64)(struct cgroup_subsys_state___113 *, struct cftype___113 *);
	s64 (*read_s64)(struct cgroup_subsys_state___113 *, struct cftype___113 *);
	int (*seq_show)(struct seq_file___142 *, void *);
	void * (*seq_start)(struct seq_file___142 *, loff_t *);
	void * (*seq_next)(struct seq_file___142 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___142 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___113 *, struct cftype___113 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___113 *, struct cftype___113 *, s64);
	ssize_t (*write)(struct kernfs_open_file___151 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___151 *, struct poll_table_struct___105 *);
};

struct xdp_rxq_info___32 {
	struct net_device___34 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___32 {
	struct net_device___34 *dev;
};

struct xdp_buff___32 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___32 *rxq;
	struct xdp_txq_info___32 *txq;
	u32 frame_sz;
};

struct xdp_frame___32 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___34 *dev_rx;
};

struct header_ops___32 {
	int (*create)(struct sk_buff___33 *, struct net_device___34 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___33 *, unsigned char *);
	int (*cache)(const struct neighbour___25 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___34 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___33 *);
};

struct netdev_queue___32 {
	struct net_device___34 *dev;
	struct Qdisc___32 *qdisc;
	struct Qdisc___32 *qdisc_sleeping;
	struct kobject___151 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___34 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___32 {
	struct sk_buff___33 *head;
	struct sk_buff___33 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___32;

struct Qdisc___32 {
	int (*enqueue)(struct sk_buff___33 *, struct Qdisc___32 *, struct sk_buff___33 **);
	struct sk_buff___33 * (*dequeue)(struct Qdisc___32 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___32 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___32 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___32 gso_skb;
	struct qdisc_skb_head___32 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___32 *next_sched;
	struct sk_buff_head___32 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___32 {
	struct xdp_rxq_info___32 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___151 kobj;
	struct net_device___34 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___32 {
	enum net_device_path_type type;
	const struct net_device___34 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___32 = 0,
				DEV_PATH_BR_VLAN_TAG___32 = 1,
				DEV_PATH_BR_VLAN_UNTAG___32 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___32 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___32 {
	const struct net_device___34 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___32 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___32 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___32 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___32 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___33 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___32 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___34 *dev;
	const char *name;
};

struct net_device_ops___32 {
	int (*ndo_init)(struct net_device___34 *);
	void (*ndo_uninit)(struct net_device___34 *);
	int (*ndo_open)(struct net_device___34 *);
	int (*ndo_stop)(struct net_device___34 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___33 *, struct net_device___34 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___33 *, struct net_device___34 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___34 *, struct sk_buff___33 *, struct net_device___34 *);
	void (*ndo_change_rx_flags)(struct net_device___34 *, int);
	void (*ndo_set_rx_mode)(struct net_device___34 *);
	int (*ndo_set_mac_address)(struct net_device___34 *, void *);
	int (*ndo_validate_addr)(struct net_device___34 *);
	int (*ndo_do_ioctl)(struct net_device___34 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___34 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___34 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___34 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___34 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___34 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___34 *, int);
	int (*ndo_neigh_setup)(struct net_device___34 *, struct neigh_parms___25 *);
	void (*ndo_tx_timeout)(struct net_device___34 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___34 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___34 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___34 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___34 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___34 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___34 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___34 *);
	int (*ndo_netpoll_setup)(struct net_device___34 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___34 *);
	int (*ndo_set_vf_mac)(struct net_device___34 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___34 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___34 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___34 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___34 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___34 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___34 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___34 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___34 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___34 *, int, struct sk_buff___33 *);
	int (*ndo_get_vf_guid)(struct net_device___34 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___34 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___34 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___34 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___34 *);
	int (*ndo_fcoe_disable)(struct net_device___34 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___34 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___34 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___34 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___34 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___34 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___34 *, const struct sk_buff___33 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___34 *, struct net_device___34 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___34 *, struct net_device___34 *);
	struct net_device___34 * (*ndo_get_xmit_slave)(struct net_device___34 *, struct sk_buff___33 *, bool);
	struct net_device___34 * (*ndo_sk_get_lower_dev)(struct net_device___34 *, struct sock___26 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___34 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___34 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___34 *, struct neighbour___25 *);
	void (*ndo_neigh_destroy)(struct net_device___34 *, struct neighbour___25 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___33 *, struct netlink_callback___32 *, struct net_device___34 *, struct net_device___34 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___33 *, struct nlattr **, struct net_device___34 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___34 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___33 *, u32, u32, struct net_device___34 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___34 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___34 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___34 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___34 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___34 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___34 *, struct net_device___34 *);
	void (*ndo_dfwd_del_station)(struct net_device___34 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___34 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___34 *);
	int (*ndo_change_proto_down)(struct net_device___34 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___34 *, struct sk_buff___33 *);
	void (*ndo_set_rx_headroom)(struct net_device___34 *, int);
	int (*ndo_bpf)(struct net_device___34 *, struct netdev_bpf___32 *);
	int (*ndo_xdp_xmit)(struct net_device___34 *, int, struct xdp_frame___32 **, u32);
	struct net_device___34 * (*ndo_xdp_get_xmit_slave)(struct net_device___34 *, struct xdp_buff___32 *);
	int (*ndo_xsk_wakeup)(struct net_device___34 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___34 *);
	int (*ndo_tunnel_ctl)(struct net_device___34 *, struct ip_tunnel_parm *, int);
	struct net_device___34 * (*ndo_get_peer_dev)(struct net_device___34 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___32 *, struct net_device_path___32 *);
};

struct neigh_parms___25 {
	possible_net_t___32 net;
	struct net_device___34 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___25 *);
	struct neigh_table___25 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___25 {
	u32 (*l3mdev_fib_table)(const struct net_device___34 *);
	struct sk_buff___33 * (*l3mdev_l3_rcv)(struct net_device___34 *, struct sk_buff___33 *, u16);
	struct sk_buff___33 * (*l3mdev_l3_out)(struct net_device___34 *, struct sock___26 *, struct sk_buff___33 *, u16);
	struct dst_entry___25 * (*l3mdev_link_scope_lookup)(const struct net_device___34 *, struct flowi6 *);
};

struct ndisc_ops___15 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___34 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___34 *, struct neighbour___25 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___34 *, u8, struct neighbour___25 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___34 *, struct sk_buff___33 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___37 *, struct net_device___34 *, const struct prefix_info *, struct inet6_dev___15 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___15;

struct inet6_dev___15 {
	struct net_device___34 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___15 *mc_list;
	struct ifmcaddr6___15 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___32 mc_query_queue;
	struct sk_buff_head___32 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___25 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___32;

struct tcf_block___32;

struct mini_Qdisc___32 {
	struct tcf_proto___32 *filter_list;
	struct tcf_block___32 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___32 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___34 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___34 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___37 *, struct net_device___34 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___34 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___34 *, struct list_head *);
	size_t (*get_size)(const struct net_device___34 *);
	int (*fill_info)(struct sk_buff___33 *, const struct net_device___34 *);
	size_t (*get_xstats_size)(const struct net_device___34 *);
	int (*fill_xstats)(struct sk_buff___33 *, const struct net_device___34 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___34 *, struct net_device___34 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___34 *, const struct net_device___34 *);
	int (*fill_slave_info)(struct sk_buff___33 *, const struct net_device___34 *, const struct net_device___34 *);
	struct net___37 * (*get_link_net)(const struct net_device___34 *);
	size_t (*get_linkxstats_size)(const struct net_device___34 *, int);
	int (*fill_linkxstats)(struct sk_buff___33 *, const struct net_device___34 *, int *, int);
};

struct block_device_operations___77;

struct gendisk___77 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___78 *part0;
	const struct block_device_operations___77 *fops;
	struct request_queue___77 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___74 *bdi;
	struct kobject___151 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___151 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___77 {
	struct bio___77 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___91 *bip_vec;
	struct bio_vec___91 bip_inline_vecs[0];
};

struct blkcg___74;

struct blkg_policy_data___74;

struct blkcg_gq___74 {
	struct request_queue___77 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___74 *blkcg;
	struct blkcg_gq___74 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___74 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___77 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___77(struct request___77 *);

typedef void integrity_complete_fn___77(struct request___77 *, unsigned int);

struct blk_integrity_profile___77 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___77 *prepare_fn;
	integrity_complete_fn___77 *complete_fn;
	const char *name;
};

struct block_device_operations___77 {
	blk_qc_t (*submit_bio)(struct bio___77 *);
	int (*open)(struct block_device___78 *, fmode_t);
	void (*release)(struct gendisk___77 *, fmode_t);
	int (*rw_page)(struct block_device___78 *, sector_t, struct page___169 *, unsigned int);
	int (*ioctl)(struct block_device___78 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___78 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___77 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___77 *);
	int (*getgeo)(struct block_device___78 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___78 *, bool);
	void (*swap_slot_free_notify)(struct block_device___78 *, long unsigned int);
	int (*report_zones)(struct gendisk___77 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___77 *, umode_t *);
	struct module___148 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___77 *, sector_t *);
};

typedef void rq_end_io_fn___77(struct request___77 *, blk_status_t);

struct request___77 {
	struct request_queue___77 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___74 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___77 *bio;
	struct bio___77 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___91 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___77 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___77 *saved_end_io;
		} flush;
	};
	struct gendisk___77 *rq_disk;
	struct block_device___78 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___77 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___74 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___77 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___151 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___164 *debugfs_dir;
	struct dentry___164 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___77;

struct elevator_mq_ops___77 {
	int (*init_sched)(struct request_queue___77 *, struct elevator_type___77 *);
	void (*exit_sched)(struct elevator_queue___77 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___74 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___74 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___74 *);
	bool (*allow_merge)(struct request_queue___77 *, struct request___77 *, struct bio___77 *);
	bool (*bio_merge)(struct request_queue___77 *, struct bio___77 *, unsigned int);
	int (*request_merge)(struct request_queue___77 *, struct request___77 **, struct bio___77 *);
	void (*request_merged)(struct request_queue___77 *, struct request___77 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___77 *, struct request___77 *, struct request___77 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___77 *);
	void (*finish_request)(struct request___77 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___74 *, struct list_head *, bool);
	struct request___77 * (*dispatch_request)(struct blk_mq_hw_ctx___74 *);
	bool (*has_work)(struct blk_mq_hw_ctx___74 *);
	void (*completed_request)(struct request___77 *, u64);
	void (*requeue_request)(struct request___77 *);
	struct request___77 * (*former_request)(struct request_queue___77 *, struct request___77 *);
	struct request___77 * (*next_request)(struct request_queue___77 *, struct request___77 *);
	void (*init_icq)(struct io_cq___77 *);
	void (*exit_icq)(struct io_cq___77 *);
};

struct elv_fs_entry___77;

struct elevator_type___77 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___77 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___77 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___148 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___77 {
	struct elevator_type___77 *type;
	void *elevator_data;
	struct kobject___151 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___77 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___77 *, char *);
	ssize_t (*store)(struct elevator_queue___77 *, const char *, size_t);
};

struct blk_mq_queue_data___74;

struct blk_mq_ops___74 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___74 *, const struct blk_mq_queue_data___74 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___74 *);
	int (*get_budget)(struct request_queue___77 *);
	void (*put_budget)(struct request_queue___77 *, int);
	void (*set_rq_budget_token)(struct request___77 *, int);
	int (*get_rq_budget_token)(struct request___77 *);
	enum blk_eh_timer_return (*timeout)(struct request___77 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___74 *);
	void (*complete)(struct request___77 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___74 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___74 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___74 *, struct request___77 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___74 *, struct request___77 *, unsigned int);
	void (*initialize_rq_fn)(struct request___77 *);
	void (*cleanup_rq)(struct request___77 *);
	bool (*busy)(struct request_queue___77 *);
	int (*map_queues)(struct blk_mq_tag_set___74 *);
	void (*show_rq)(struct seq_file___142 *, struct request___77 *);
};

struct blk_mq_tag_set___74 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___74 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___74 {
	struct request___77 *rq;
	bool last;
};

struct blkcg_policy_data___74;

struct blkcg___74 {
	struct cgroup_subsys_state___113 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___74 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___74 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___74 {
	struct blkcg___74 *blkcg;
	int plid;
};

struct blkg_policy_data___74 {
	struct blkcg_gq___74 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___65 {
	struct mem_cgroup___65 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___65 {
	struct lruvec___72 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___65 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___65 *memcg;
};

struct obj_cgroup___65 {
	struct percpu_ref refcnt;
	struct mem_cgroup___65 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___32 {
	spinlock_t *lock;
	struct sk_buff___33 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___32;

struct Qdisc_ops___32 {
	struct Qdisc_ops___32 *next;
	const struct Qdisc_class_ops___32 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___33 *, struct Qdisc___32 *, struct sk_buff___33 **);
	struct sk_buff___33 * (*dequeue)(struct Qdisc___32 *);
	struct sk_buff___33 * (*peek)(struct Qdisc___32 *);
	int (*init)(struct Qdisc___32 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___32 *);
	void (*destroy)(struct Qdisc___32 *);
	int (*change)(struct Qdisc___32 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___32 *);
	int (*change_tx_queue_len)(struct Qdisc___32 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___32 *, unsigned int);
	int (*dump)(struct Qdisc___32 *, struct sk_buff___33 *);
	int (*dump_stats)(struct Qdisc___32 *, struct gnet_dump___32 *);
	void (*ingress_block_set)(struct Qdisc___32 *, u32);
	void (*egress_block_set)(struct Qdisc___32 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___32 *);
	u32 (*egress_block_get)(struct Qdisc___32 *);
	struct module___148 *owner;
};

struct Qdisc_class_ops___32 {
	unsigned int flags;
	struct netdev_queue___32 * (*select_queue)(struct Qdisc___32 *, struct tcmsg *);
	int (*graft)(struct Qdisc___32 *, long unsigned int, struct Qdisc___32 *, struct Qdisc___32 **, struct netlink_ext_ack *);
	struct Qdisc___32 * (*leaf)(struct Qdisc___32 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___32 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___32 *, u32);
	int (*change)(struct Qdisc___32 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___32 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___32 *, struct qdisc_walker *);
	struct tcf_block___32 * (*tcf_block)(struct Qdisc___32 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___32 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___32 *, long unsigned int);
	int (*dump)(struct Qdisc___32 *, long unsigned int, struct sk_buff___33 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___32 *, long unsigned int, struct gnet_dump___32 *);
};

struct tcf_chain___32;

struct tcf_block___32 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___37 *net;
	struct Qdisc___32 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___32 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___32;

struct tcf_proto_ops___32;

struct tcf_proto___32 {
	struct tcf_proto___32 *next;
	void *root;
	int (*classify)(struct sk_buff___33 *, const struct tcf_proto___32 *, struct tcf_result___32 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___32 *ops;
	struct tcf_chain___32 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___32 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___32 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___32 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___33 *, const struct tcf_proto___32 *, struct tcf_result___32 *);
	int (*init)(struct tcf_proto___32 *);
	void (*destroy)(struct tcf_proto___32 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___32 *, u32);
	void (*put)(struct tcf_proto___32 *, void *);
	int (*change)(struct net___37 *, struct sk_buff___33 *, struct tcf_proto___32 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___32 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___32 *);
	void (*walk)(struct tcf_proto___32 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___32 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___32 *, void *);
	void (*hw_del)(struct tcf_proto___32 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___37 *, struct tcf_chain___32 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___37 *, struct tcf_proto___32 *, void *, struct sk_buff___33 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___37 *, struct tcf_proto___32 *, void *, struct sk_buff___33 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___33 *, struct net___37 *, void *);
	struct module___148 *owner;
	int flags;
};

struct tcf_chain___32 {
	struct mutex filter_chain_lock;
	struct tcf_proto___32 *filter_chain;
	struct list_head list;
	struct tcf_block___32 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___32 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___25 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___32 *prog;
};

struct pneigh_entry___25;

struct neigh_hash_table___25;

struct neigh_table___25 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___34 *, __u32 *);
	bool (*key_eq)(const struct neighbour___25 *, const void *);
	int (*constructor)(struct neighbour___25 *);
	int (*pconstructor)(struct pneigh_entry___25 *);
	void (*pdestructor)(struct pneigh_entry___25 *);
	void (*proxy_redo)(struct sk_buff___33 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___34 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___25 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___32 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___25 *nht;
	struct pneigh_entry___25 **phash_buckets;
};

struct neigh_ops___25 {
	int family;
	void (*solicit)(struct neighbour___25 *, struct sk_buff___33 *);
	void (*error_report)(struct neighbour___25 *, struct sk_buff___33 *);
	int (*output)(struct neighbour___25 *, struct sk_buff___33 *);
	int (*connected_output)(struct neighbour___25 *, struct sk_buff___33 *);
};

struct pneigh_entry___25 {
	struct pneigh_entry___25 *next;
	possible_net_t___32 net;
	struct net_device___34 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___25 {
	struct neighbour___25 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___12 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___37 *, struct sock___26 *, struct sk_buff___33 *);
	int (*orig_input)(struct sk_buff___33 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___25 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___25 *ctarget;
	struct net___37 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___25 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___25 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___15;

struct timewait_sock_ops___15;

struct proto___25 {
	void (*close)(struct sock___26 *, long int);
	int (*pre_connect)(struct sock___26 *, struct sockaddr *, int);
	int (*connect)(struct sock___26 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___26 *, int);
	struct sock___26 * (*accept)(struct sock___26 *, int, int *, bool);
	int (*ioctl)(struct sock___26 *, int, long unsigned int);
	int (*init)(struct sock___26 *);
	void (*destroy)(struct sock___26 *);
	void (*shutdown)(struct sock___26 *, int);
	int (*setsockopt)(struct sock___26 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___26 *, int, int, char *, int *);
	void (*keepalive)(struct sock___26 *, int);
	int (*compat_ioctl)(struct sock___26 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___26 *, struct msghdr___26 *, size_t);
	int (*recvmsg)(struct sock___26 *, struct msghdr___26 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___26 *, struct page___169 *, int, size_t, int);
	int (*bind)(struct sock___26 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___26 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___26 *, struct sk_buff___33 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___26 *);
	int (*hash)(struct sock___26 *);
	void (*unhash)(struct sock___26 *);
	void (*rehash)(struct sock___26 *);
	int (*get_port)(struct sock___26 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___26 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___26 *, int);
	bool (*sock_is_readable)(struct sock___26 *);
	void (*enter_memory_pressure)(struct sock___26 *);
	void (*leave_memory_pressure)(struct sock___26 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___15 *rsk_prot;
	struct timewait_sock_ops___15 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___148 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___26 *, int);
};

struct request_sock___16;

struct request_sock_ops___15 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___26 *, struct request_sock___16 *);
	void (*send_ack)(const struct sock___26 *, struct sk_buff___33 *, struct request_sock___16 *);
	void (*send_reset)(const struct sock___26 *, struct sk_buff___33 *);
	void (*destructor)(struct request_sock___16 *);
	void (*syn_ack_timeout)(const struct request_sock___16 *);
};

struct timewait_sock_ops___15 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___26 *, struct sock___26 *, void *);
	void (*twsk_destructor)(struct sock___26 *);
};

struct request_sock___16 {
	struct sock_common___25 __req_common;
	struct request_sock___16 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___15 *rsk_ops;
	struct sock___26 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___15 {
	struct in6_addr mca_addr;
	struct inet6_dev___15 *idev;
	struct ifmcaddr6___15 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct lsm_network_audit___6 {
	int netif;
	const struct sock___26 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___6 {
	struct path___164 path;
	u16 cmd;
};

struct aa_label___5;

struct aa_profile___5;

struct apparmor_audit_data___4 {
	int error;
	int type;
	const char *op;
	struct aa_label___5 *label;
	const char *name;
	const char *info;
	u32 request;
	u32 denied;
	union {
		struct {
			struct aa_label___5 *peer;
			union {
				struct {
					const char *target;
					kuid_t ouid;
				} fs;
				struct {
					int rlim;
					long unsigned int max;
				} rlim;
				struct {
					int signal;
					int unmappedsig;
				};
				struct {
					int type;
					int protocol;
					struct sock___26 *peer_sk;
					void *addr;
					int addrlen;
				} net;
			};
		};
		struct {
			struct aa_profile___5 *profile;
			const char *ns;
			long int pos;
		} iface;
		struct {
			const char *src_name;
			const char *type;
			const char *trans;
			const char *data;
			long unsigned int flags;
		} mnt;
	};
};

struct common_audit_data___7 {
	char type;
	union {
		struct path___164 path;
		struct dentry___164 *dentry;
		struct inode___164 *inode;
		struct lsm_network_audit___6 *net;
		int cap;
		int ipc_id;
		struct task_struct___171 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___6 *op;
		struct file___164 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data___4 *apparmor_audit_data;
	};
};

struct linux_binprm___35 {
	struct vm_area_struct___169 *vma;
	long unsigned int vma_pages;
	struct mm_struct___170 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___164 *executable;
	struct file___164 *interpreter;
	struct file___164 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___34 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___164 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct aa_proxy___5 {
	struct kref count;
	struct aa_label___5 *label;
};

struct aa_label___5 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	struct aa_proxy___5 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___5 *vec[0];
};

struct aa_ns___5;

struct aa_loaddata___3;

struct aa_profile___5 {
	struct aa_policy base;
	struct aa_profile___5 *parent;
	struct aa_ns___5 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___3 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___164 *dents[9];
	struct rhashtable *data;
	struct aa_label___5 label;
};

struct aa_ns___5 {
	struct aa_policy base;
	struct aa_ns___5 *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile___5 *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___164 *dents[13];
};

struct aa_loaddata___3 {
	struct kref count;
	struct list_head list;
	struct work_struct work;
	struct dentry___164 *dents[6];
	struct aa_ns___5 *ns;
	char *name;
	size_t size;
	size_t compressed_size;
	long int revision;
	int abi;
	unsigned char *hash;
	char *data;
};

struct aa_load_ent___2 {
	struct list_head list;
	struct aa_profile___5 *new;
	struct aa_profile___5 *old;
	struct aa_profile___5 *rename;
	const char *ns_name;
};

enum aa_code {
	AA_U8 = 0,
	AA_U16 = 1,
	AA_U32 = 2,
	AA_U64 = 3,
	AA_NAME = 4,
	AA_STRING = 5,
	AA_BLOB = 6,
	AA_STRUCT = 7,
	AA_STRUCTEND = 8,
	AA_LIST = 9,
	AA_LISTEND = 10,
	AA_ARRAY = 11,
	AA_ARRAYEND = 12,
};

struct aa_ext {
	void *start;
	void *end;
	void *pos;
	u32 version;
};

struct vfsmount___165;

struct dentry___165;

struct path___165 {
	struct vfsmount___165 *mnt;
	struct dentry___165 *dentry;
};

struct pid___146;

struct fown_struct___146 {
	rwlock_t lock;
	struct pid___146 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct inode___165;

struct file_operations___165;

struct address_space___165;

struct file___165 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___165 f_path;
	struct inode___165 *f_inode;
	const struct file_operations___165 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___146 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___165 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct super_block___165;

struct module___149;

struct file_system_type___165 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___165 * (*mount)(struct file_system_type___165 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___165 *);
	struct module___149 *owner;
	struct file_system_type___165 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct kiocb___165;

struct iov_iter___94;

struct poll_table_struct___106;

struct vm_area_struct___170;

struct file_lock___165;

struct page___170;

struct pipe_inode_info___58;

struct seq_file___143;

struct file_operations___165 {
	struct module___149 *owner;
	loff_t (*llseek)(struct file___165 *, loff_t, int);
	ssize_t (*read)(struct file___165 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___165 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___165 *, struct iov_iter___94 *);
	ssize_t (*write_iter)(struct kiocb___165 *, struct iov_iter___94 *);
	int (*iopoll)(struct kiocb___165 *, bool);
	int (*iterate)(struct file___165 *, struct dir_context *);
	int (*iterate_shared)(struct file___165 *, struct dir_context *);
	__poll_t (*poll)(struct file___165 *, struct poll_table_struct___106 *);
	long int (*unlocked_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___165 *, struct vm_area_struct___170 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___165 *, struct file___165 *);
	int (*flush)(struct file___165 *, fl_owner_t);
	int (*release)(struct inode___165 *, struct file___165 *);
	int (*fsync)(struct file___165 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___165 *, int);
	int (*lock)(struct file___165 *, int, struct file_lock___165 *);
	ssize_t (*sendpage)(struct file___165 *, struct page___170 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___165 *, long unsigned int);
	int (*flock)(struct file___165 *, int, struct file_lock___165 *);
	ssize_t (*splice_write)(struct pipe_inode_info___58 *, struct file___165 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___165 *, loff_t *, struct pipe_inode_info___58 *, size_t, unsigned int);
	int (*setlease)(struct file___165 *, long int, struct file_lock___165 **, void **);
	long int (*fallocate)(struct file___165 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___143 *, struct file___165 *);
	ssize_t (*copy_file_range)(struct file___165 *, loff_t, struct file___165 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___165 *, loff_t, struct file___165 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___165 *, loff_t, loff_t, int);
};

struct vmacache___170 {
	u64 seqnum;
	struct vm_area_struct___170 *vmas[4];
};

struct page_frag___170 {
	struct page___170 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___171;

struct nsproxy___155;

struct signal_struct___166;

struct bio_list___78;

struct backing_dev_info___75;

struct io_context___78;

struct css_set___114;

struct mem_cgroup___66;

struct request_queue___78;

struct vm_struct___149;

struct task_struct___172 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___172 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___171 *mm;
	struct mm_struct___171 *active_mm;
	struct vmacache___170 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___172 *real_parent;
	struct task_struct___172 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___172 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___146 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___155 *nsproxy;
	struct signal_struct___166 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___172 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___78 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___75 *backing_dev_info;
	struct io_context___78 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___114 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___58 *splice_pipe;
	struct page_frag___170 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___66 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___66 *active_memcg;
	struct request_queue___78 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___172 *oom_reaper_list;
	struct vm_struct___149 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___152;

struct kobj_type___152;

struct kernfs_node___152;

struct kobject___152 {
	const char *name;
	struct list_head entry;
	struct kobject___152 *parent;
	struct kset___152 *kset;
	struct kobj_type___152 *ktype;
	struct kernfs_node___152 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___149 {
	struct kobject___152 kobj;
	struct module___149 *mod;
	struct kobject___152 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___149 {
	struct module___149 *mod;
	struct latch_tree_node node;
};

struct module_layout___149 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___149 mtn;
};

struct module_attribute___149;

struct kernel_param___149;

struct module___149 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___149 mkobj;
	struct module_attribute___149 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___152 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___149 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___149 core_layout;
	struct module_layout___149 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___165;

struct dentry___165 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___165 *d_parent;
	struct qstr d_name;
	struct inode___165 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___165 *d_op;
	struct super_block___165 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___165;

struct address_space___165 {
	struct inode___165 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___165 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___165;

struct bdi_writeback___75;

struct inode___165 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___165 *i_op;
	struct super_block___165 *i_sb;
	struct address_space___165 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___75 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___165 *i_fop;
		void (*free_inode)(struct inode___165 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___165 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___58 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___165 {
	int (*d_revalidate)(struct dentry___165 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___165 *, unsigned int);
	int (*d_hash)(const struct dentry___165 *, struct qstr *);
	int (*d_compare)(const struct dentry___165 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___165 *);
	int (*d_init)(struct dentry___165 *);
	void (*d_release)(struct dentry___165 *);
	void (*d_prune)(struct dentry___165 *);
	void (*d_iput)(struct dentry___165 *, struct inode___165 *);
	char * (*d_dname)(struct dentry___165 *, char *, int);
	struct vfsmount___165 * (*d_automount)(struct path___165 *);
	int (*d_manage)(const struct path___165 *, bool);
	struct dentry___165 * (*d_real)(struct dentry___165 *, const struct inode___165 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___165;

struct mem_dqinfo___165 {
	struct quota_format_type___165 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___165;

struct quota_info___165 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___165 *files[3];
	struct mem_dqinfo___165 info[3];
	const struct quota_format_ops___165 *ops[3];
};

struct rcuwait___166 {
	struct task_struct___172 *task;
};

struct percpu_rw_semaphore___166 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___166 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___165 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___166 rw_sem[3];
};

struct shrink_control___66;

struct shrinker___66 {
	long unsigned int (*count_objects)(struct shrinker___66 *, struct shrink_control___66 *);
	long unsigned int (*scan_objects)(struct shrinker___66 *, struct shrink_control___66 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___165;

struct dquot_operations___165;

struct quotactl_ops___165;

struct block_device___79;

struct super_block___165 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___165 *s_type;
	const struct super_operations___165 *s_op;
	const struct dquot_operations___165 *dq_op;
	const struct quotactl_ops___165 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___165 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___79 *s_bdev;
	struct backing_dev_info___75 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___165 s_dquot;
	struct sb_writers___165 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___165 *s_d_op;
	int cleancache_poolid;
	struct shrinker___66 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___165 {
	struct dentry___165 *mnt_root;
	struct super_block___165 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct pid_namespace___146;

struct upid___146 {
	int nr;
	struct pid_namespace___146 *ns;
};

struct pid_namespace___146 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___172 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___146 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___146 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___146 numbers[1];
};

typedef struct page___170 *pgtable_t___170;

struct page_pool___49;

struct dev_pagemap___161;

struct page___170 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___165 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___49 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___170 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___170 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___171 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___161 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___161;

struct vm_area_struct___170 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___170 *vm_next;
	struct vm_area_struct___170 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___171 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___161 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___165 *vm_file;
	struct file___165 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___166 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___172 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___172 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___146 *pids[4];
	struct pid___146 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___171 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___35;

struct core_state___170;

struct mm_struct___171 {
	struct {
		struct vm_area_struct___170 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___35 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___170 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___172 *owner;
		struct user_namespace___24 *user_ns;
		struct file___165 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___38;

struct cgroup_namespace___114;

struct nsproxy___155 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___146 *pid_ns_for_children;
	struct net___38 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___114 *cgroup_ns;
};

struct bio___78;

struct bio_list___78 {
	struct bio___78 *head;
	struct bio___78 *tail;
};

struct cgroup_subsys_state___114;

struct bdi_writeback___75 {
	struct backing_dev_info___75 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___114 *memcg_css;
	struct cgroup_subsys_state___114 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___121;

struct backing_dev_info___75 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___75 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___121 *dev;
	char dev_name[64];
	struct device___121 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___165 *debug_dir;
};

struct io_cq___78;

struct io_context___78 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___78 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___114;

struct css_set___114 {
	struct cgroup_subsys_state___114 *subsys[14];
	refcount_t refcount;
	struct css_set___114 *dom_cset;
	struct cgroup___114 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___114 *mg_src_cgrp;
	struct cgroup___114 *mg_dst_cgrp;
	struct css_set___114 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___165;

struct pipe_buffer___58;

struct pipe_inode_info___58 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___170 *tmp_page;
	struct fasync_struct___165 *fasync_readers;
	struct fasync_struct___165 *fasync_writers;
	struct pipe_buffer___58 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___114;

struct cgroup_subsys_state___114 {
	struct cgroup___114 *cgroup;
	struct cgroup_subsys___114 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___114 *parent;
};

struct cgroup_file___114 {
	struct kernfs_node___152 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___66;

struct mem_cgroup_per_node___66;

struct mem_cgroup___66 {
	struct cgroup_subsys_state___114 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___114 events_file;
	struct cgroup_file___114 events_local_file;
	struct cgroup_file___114 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___66 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___172 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___66 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___78;

struct blk_integrity___78 {
	const struct blk_integrity_profile___78 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___78 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___78 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___78;

struct elevator_queue___78;

struct blk_mq_ops___75;

struct blk_mq_hw_ctx___75;

struct gendisk___78;

struct blkcg_gq___75;

struct blk_mq_tag_set___75;

struct request_queue___78 {
	struct request___78 *last_merge;
	struct elevator_queue___78 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___75 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___75 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___78 *disk;
	struct kobject___152 kobj;
	struct kobject___152 *mq_kobj;
	struct blk_integrity___78 integrity;
	struct device___121 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___75 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___75 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___78 bio_split;
	struct dentry___165 *debugfs_dir;
	struct dentry___165 *sched_debugfs_dir;
	struct dentry___165 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___149 {
	struct vm_struct___149 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___170 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___66 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___66 *memcg;
};

struct page_pool_params___49 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___121 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___49 {
	u32 count;
	struct page___170 *cache[128];
};

struct page_pool___49 {
	struct page_pool_params___49 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___170 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___49 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___161;

struct dev_pagemap___161 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___161 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___161;

struct vm_operations_struct___161 {
	void (*open)(struct vm_area_struct___170 *);
	void (*close)(struct vm_area_struct___170 *);
	int (*may_split)(struct vm_area_struct___170 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___170 *);
	int (*mprotect)(struct vm_area_struct___170 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___161 *);
	vm_fault_t (*huge_fault)(struct vm_fault___161 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___161 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___170 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___161 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___161 *);
	int (*access)(struct vm_area_struct___170 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___170 *);
	int (*set_policy)(struct vm_area_struct___170 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___170 *, long unsigned int);
	struct page___170 * (*find_special_page)(struct vm_area_struct___170 *, long unsigned int);
};

struct core_thread___170 {
	struct task_struct___172 *task;
	struct core_thread___170 *next;
};

struct core_state___170 {
	atomic_t nr_threads;
	struct core_thread___170 dumper;
	struct completion startup;
};

struct linux_binprm___36;

struct coredump_params___35;

struct linux_binfmt___35 {
	struct list_head lh;
	struct module___149 *module;
	int (*load_binary)(struct linux_binprm___36 *);
	int (*load_shlib)(struct file___165 *);
	int (*core_dump)(struct coredump_params___35 *);
	long unsigned int min_coredump;
};

struct vm_fault___161 {
	const struct {
		struct vm_area_struct___170 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___170 *cow_page;
	struct page___170 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___170 prealloc_pte;
};

struct pglist_data___73;

struct lruvec___73 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___73 *pgdat;
};

struct zone___73 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___73 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___73 {
	struct zone___73 *zone;
	int zone_idx;
};

struct zonelist___73 {
	struct zoneref___73 _zonerefs[321];
};

struct pglist_data___73 {
	struct zone___73 node_zones[5];
	struct zonelist___73 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___172 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___172 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___73 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___114 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___172 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___33;

struct cgroup_bpf___33 {
	struct bpf_prog_array___33 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___33 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___114;

struct cgroup_rstat_cpu___114;

struct cgroup___114 {
	struct cgroup_subsys_state___114 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___152 *kn;
	struct cgroup_file___114 procs_file;
	struct cgroup_file___114 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___114 *subsys[14];
	struct cgroup_root___114 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___114 *dom_cgrp;
	struct cgroup___114 *old_dom_cgrp;
	struct cgroup_rstat_cpu___114 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___114 psi;
	struct cgroup_bpf___33 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___78 {
	struct request_queue___78 *q;
	struct io_context___78 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___165 {
	struct file___165 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___165 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___165 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___165 *ia_file;
};

struct dquot___165 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___165 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___165 {
	int qf_fmt_id;
	const struct quota_format_ops___165 *qf_ops;
	struct module___149 *qf_owner;
	struct quota_format_type___165 *qf_next;
};

struct quota_format_ops___165 {
	int (*check_quota_file)(struct super_block___165 *, int);
	int (*read_file_info)(struct super_block___165 *, int);
	int (*write_file_info)(struct super_block___165 *, int);
	int (*free_file_info)(struct super_block___165 *, int);
	int (*read_dqblk)(struct dquot___165 *);
	int (*commit_dqblk)(struct dquot___165 *);
	int (*release_dqblk)(struct dquot___165 *);
	int (*get_next_id)(struct super_block___165 *, struct kqid *);
};

struct dquot_operations___165 {
	int (*write_dquot)(struct dquot___165 *);
	struct dquot___165 * (*alloc_dquot)(struct super_block___165 *, int);
	void (*destroy_dquot)(struct dquot___165 *);
	int (*acquire_dquot)(struct dquot___165 *);
	int (*release_dquot)(struct dquot___165 *);
	int (*mark_dirty)(struct dquot___165 *);
	int (*write_info)(struct super_block___165 *, int);
	qsize_t * (*get_reserved_space)(struct inode___165 *);
	int (*get_projid)(struct inode___165 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___165 *, qsize_t *);
	int (*get_next_id)(struct super_block___165 *, struct kqid *);
};

struct quotactl_ops___165 {
	int (*quota_on)(struct super_block___165 *, int, int, const struct path___165 *);
	int (*quota_off)(struct super_block___165 *, int);
	int (*quota_enable)(struct super_block___165 *, unsigned int);
	int (*quota_disable)(struct super_block___165 *, unsigned int);
	int (*quota_sync)(struct super_block___165 *, int);
	int (*set_info)(struct super_block___165 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___165 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___165 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___165 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___165 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___165 *, unsigned int);
};

struct writeback_control___75;

struct address_space_operations___165 {
	int (*writepage)(struct page___170 *, struct writeback_control___75 *);
	int (*readpage)(struct file___165 *, struct page___170 *);
	int (*writepages)(struct address_space___165 *, struct writeback_control___75 *);
	int (*set_page_dirty)(struct page___170 *);
	int (*readpages)(struct file___165 *, struct address_space___165 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___165 *, struct address_space___165 *, loff_t, unsigned int, unsigned int, struct page___170 **, void **);
	int (*write_end)(struct file___165 *, struct address_space___165 *, loff_t, unsigned int, unsigned int, struct page___170 *, void *);
	sector_t (*bmap)(struct address_space___165 *, sector_t);
	void (*invalidatepage)(struct page___170 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___170 *, gfp_t);
	void (*freepage)(struct page___170 *);
	ssize_t (*direct_IO)(struct kiocb___165 *, struct iov_iter___94 *);
	int (*migratepage)(struct address_space___165 *, struct page___170 *, struct page___170 *, enum migrate_mode);
	bool (*isolate_page)(struct page___170 *, isolate_mode_t);
	void (*putback_page)(struct page___170 *);
	int (*launder_page)(struct page___170 *);
	int (*is_partially_uptodate)(struct page___170 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___170 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___165 *, struct page___170 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___165 *, sector_t *);
	void (*swap_deactivate)(struct file___165 *);
};

struct writeback_control___75 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___75 *wb;
	struct inode___165 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___92;

struct iov_iter___94 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___92 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___58 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___165 {
	struct dentry___165 * (*lookup)(struct inode___165 *, struct dentry___165 *, unsigned int);
	const char * (*get_link)(struct dentry___165 *, struct inode___165 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___165 *, int);
	struct posix_acl * (*get_acl)(struct inode___165 *, int, bool);
	int (*readlink)(struct dentry___165 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___165 *, struct dentry___165 *, umode_t, bool);
	int (*link)(struct dentry___165 *, struct inode___165 *, struct dentry___165 *);
	int (*unlink)(struct inode___165 *, struct dentry___165 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___165 *, struct dentry___165 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___165 *, struct dentry___165 *, umode_t);
	int (*rmdir)(struct inode___165 *, struct dentry___165 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___165 *, struct dentry___165 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___165 *, struct dentry___165 *, struct inode___165 *, struct dentry___165 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___165 *, struct iattr___165 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___165 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___165 *, char *, size_t);
	int (*fiemap)(struct inode___165 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___165 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___165 *, struct dentry___165 *, struct file___165 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___165 *, struct dentry___165 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___165 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___165 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___165 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___165 {
	void (*fl_copy_lock)(struct file_lock___165 *, struct file_lock___165 *);
	void (*fl_release_private)(struct file_lock___165 *);
};

struct lock_manager_operations___165;

struct file_lock___165 {
	struct file_lock___165 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___165 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___165 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___165 *fl_ops;
	const struct lock_manager_operations___165 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___165 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___165 *);
	int (*lm_grant)(struct file_lock___165 *, int);
	bool (*lm_break)(struct file_lock___165 *);
	int (*lm_change)(struct file_lock___165 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___165 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___165 *);
};

struct fasync_struct___165 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___165 *fa_next;
	struct file___165 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___165 {
	struct inode___165 * (*alloc_inode)(struct super_block___165 *);
	void (*destroy_inode)(struct inode___165 *);
	void (*free_inode)(struct inode___165 *);
	void (*dirty_inode)(struct inode___165 *, int);
	int (*write_inode)(struct inode___165 *, struct writeback_control___75 *);
	int (*drop_inode)(struct inode___165 *);
	void (*evict_inode)(struct inode___165 *);
	void (*put_super)(struct super_block___165 *);
	int (*sync_fs)(struct super_block___165 *, int);
	int (*freeze_super)(struct super_block___165 *);
	int (*freeze_fs)(struct super_block___165 *);
	int (*thaw_super)(struct super_block___165 *);
	int (*unfreeze_fs)(struct super_block___165 *);
	int (*statfs)(struct dentry___165 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___165 *, int *, char *);
	void (*umount_begin)(struct super_block___165 *);
	int (*show_options)(struct seq_file___143 *, struct dentry___165 *);
	int (*show_devname)(struct seq_file___143 *, struct dentry___165 *);
	int (*show_path)(struct seq_file___143 *, struct dentry___165 *);
	int (*show_stats)(struct seq_file___143 *, struct dentry___165 *);
	ssize_t (*quota_read)(struct super_block___165 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___165 *, int, const char *, size_t, loff_t);
	struct dquot___165 ** (*get_dquots)(struct inode___165 *);
	long int (*nr_cached_objects)(struct super_block___165 *, struct shrink_control___66 *);
	long int (*free_cached_objects)(struct super_block___165 *, struct shrink_control___66 *);
	struct file___165 * (*real_loop)(struct file___165 *);
};

struct wakeup_source___121;

struct dev_pm_info___121 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___121 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___121 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___121;

struct bus_type___121;

struct device_driver___121;

struct dev_pm_domain___121;

struct fwnode_handle___121;

struct class___121;

struct attribute_group___152;

struct device___121 {
	struct kobject___152 kobj;
	struct device___121 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___121 *type;
	struct bus_type___121 *bus;
	struct device_driver___121 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___121 power;
	struct dev_pm_domain___121 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___121 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___121 *class;
	const struct attribute_group___152 **groups;
	void (*release)(struct device___121 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___79 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___165 *bd_inode;
	struct super_block___165 *bd_super;
	void *bd_claiming;
	struct device___121 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___152 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___78 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___165 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___108)(struct file___165 *, wait_queue_head_t *, struct poll_table_struct___106 *);

struct poll_table_struct___106 {
	poll_queue_proc___108 _qproc;
	__poll_t _key;
};

struct seq_operations___143;

struct seq_file___143 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___143 *op;
	int poll_event;
	const struct file___165 *file;
	void *private;
};

typedef void bio_end_io_t___78(struct bio___78 *);

struct bio_vec___92 {
	struct page___170 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___78;

struct bio___78 {
	struct bio___78 *bi_next;
	struct block_device___79 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___78 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___75 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___78 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___92 *bi_io_vec;
	struct bio_set___78 *bi_pool;
	struct bio_vec___92 bi_inline_vecs[0];
};

struct dev_pagemap_ops___161 {
	void (*page_free)(struct page___170 *);
	void (*kill)(struct dev_pagemap___161 *);
	void (*cleanup)(struct dev_pagemap___161 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___161 *);
};

struct sock___27;

struct sk_buff___34;

struct socket___27;

struct msghdr___27;

struct request_sock___17;

struct bpf_map___35;

struct bpf_prog___33;

struct bpf_prog_aux___35;

union security_list_options___5 {
	int (*binder_set_context_mgr)(const struct cred___27 *);
	int (*binder_transaction)(const struct cred___27 *, const struct cred___27 *);
	int (*binder_transfer_binder)(const struct cred___27 *, const struct cred___27 *);
	int (*binder_transfer_file)(const struct cred___27 *, const struct cred___27 *, struct file___165 *);
	int (*ptrace_access_check)(struct task_struct___172 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___172 *);
	int (*capget)(struct task_struct___172 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___27 *, const struct cred___27 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___27 *, struct user_namespace___24 *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___165 *);
	int (*quota_on)(struct dentry___165 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___171 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___36 *);
	int (*bprm_creds_from_file)(struct linux_binprm___36 *, struct file___165 *);
	int (*bprm_check_security)(struct linux_binprm___36 *);
	void (*bprm_committing_creds)(struct linux_binprm___36 *);
	void (*bprm_committed_creds)(struct linux_binprm___36 *);
	int (*fs_context_dup)(struct fs_context *, struct fs_context *);
	int (*fs_context_parse_param)(struct fs_context *, struct fs_parameter___28 *);
	int (*sb_alloc_security)(struct super_block___165 *);
	void (*sb_delete)(struct super_block___165 *);
	void (*sb_free_security)(struct super_block___165 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___165 *, void *);
	int (*sb_remount)(struct super_block___165 *, void *);
	int (*sb_kern_mount)(struct super_block___165 *);
	int (*sb_show_options)(struct seq_file___143 *, struct super_block___165 *);
	int (*sb_statfs)(struct dentry___165 *);
	int (*sb_mount)(const char *, const struct path___165 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___165 *, int);
	int (*sb_pivotroot)(const struct path___165 *, const struct path___165 *);
	int (*sb_set_mnt_opts)(struct super_block___165 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___165 *, struct super_block___165 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___165 *, const struct path___165 *);
	int (*dentry_init_security)(struct dentry___165 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___165 *, int, struct qstr *, const struct cred___27 *, struct cred___27 *);
	int (*path_unlink)(const struct path___165 *, struct dentry___165 *);
	int (*path_mkdir)(const struct path___165 *, struct dentry___165 *, umode_t);
	int (*path_rmdir)(const struct path___165 *, struct dentry___165 *);
	int (*path_mknod)(const struct path___165 *, struct dentry___165 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___165 *);
	int (*path_symlink)(const struct path___165 *, struct dentry___165 *, const char *);
	int (*path_link)(struct dentry___165 *, const struct path___165 *, struct dentry___165 *);
	int (*path_rename)(const struct path___165 *, struct dentry___165 *, const struct path___165 *, struct dentry___165 *);
	int (*path_chmod)(const struct path___165 *, umode_t);
	int (*path_chown)(const struct path___165 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___165 *);
	int (*path_notify)(const struct path___165 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___165 *);
	void (*inode_free_security)(struct inode___165 *);
	int (*inode_init_security)(struct inode___165 *, struct inode___165 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___165 *, const struct qstr *, const struct inode___165 *);
	int (*inode_create)(struct inode___165 *, struct dentry___165 *, umode_t);
	int (*inode_link)(struct dentry___165 *, struct inode___165 *, struct dentry___165 *);
	int (*inode_unlink)(struct inode___165 *, struct dentry___165 *);
	int (*inode_symlink)(struct inode___165 *, struct dentry___165 *, const char *);
	int (*inode_mkdir)(struct inode___165 *, struct dentry___165 *, umode_t);
	int (*inode_rmdir)(struct inode___165 *, struct dentry___165 *);
	int (*inode_mknod)(struct inode___165 *, struct dentry___165 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___165 *, struct dentry___165 *, struct inode___165 *, struct dentry___165 *);
	int (*inode_readlink)(struct dentry___165 *);
	int (*inode_follow_link)(struct dentry___165 *, struct inode___165 *, bool);
	int (*inode_permission)(struct inode___165 *, int);
	int (*inode_setattr)(struct dentry___165 *, struct iattr___165 *);
	int (*inode_getattr)(const struct path___165 *);
	int (*inode_setxattr)(struct user_namespace___24 *, struct dentry___165 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___165 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___165 *, const char *);
	int (*inode_listxattr)(struct dentry___165 *);
	int (*inode_removexattr)(struct user_namespace___24 *, struct dentry___165 *, const char *);
	int (*inode_need_killpriv)(struct dentry___165 *);
	int (*inode_killpriv)(struct user_namespace___24 *, struct dentry___165 *);
	int (*inode_getsecurity)(struct user_namespace___24 *, struct inode___165 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___165 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___165 *, char *, size_t);
	void (*inode_getsecid)(struct inode___165 *, u32 *);
	int (*inode_copy_up)(struct dentry___165 *, struct cred___27 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___152 *, struct kernfs_node___152 *);
	int (*file_permission)(struct file___165 *, int);
	int (*file_alloc_security)(struct file___165 *);
	void (*file_free_security)(struct file___165 *);
	int (*file_ioctl)(struct file___165 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___165 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___170 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___165 *, unsigned int);
	int (*file_fcntl)(struct file___165 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___165 *);
	int (*file_send_sigiotask)(struct task_struct___172 *, struct fown_struct___146 *, int);
	int (*file_receive)(struct file___165 *);
	int (*file_open)(struct file___165 *);
	int (*task_alloc)(struct task_struct___172 *, long unsigned int);
	void (*task_free)(struct task_struct___172 *);
	int (*cred_alloc_blank)(struct cred___27 *, gfp_t);
	void (*cred_free)(struct cred___27 *);
	int (*cred_prepare)(struct cred___27 *, const struct cred___27 *, gfp_t);
	void (*cred_transfer)(struct cred___27 *, const struct cred___27 *);
	void (*cred_getsecid)(const struct cred___27 *, u32 *);
	int (*kernel_act_as)(struct cred___27 *, u32);
	int (*kernel_create_files_as)(struct cred___27 *, struct inode___165 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___165 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___165 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___27 *, const struct cred___27 *, int);
	int (*task_fix_setgid)(struct cred___27 *, const struct cred___27 *, int);
	int (*task_setpgid)(struct task_struct___172 *, pid_t);
	int (*task_getpgid)(struct task_struct___172 *);
	int (*task_getsid)(struct task_struct___172 *);
	void (*task_getsecid_subj)(struct task_struct___172 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___172 *, u32 *);
	int (*task_setnice)(struct task_struct___172 *, int);
	int (*task_setioprio)(struct task_struct___172 *, int);
	int (*task_getioprio)(struct task_struct___172 *);
	int (*task_prlimit)(const struct cred___27 *, const struct cred___27 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___172 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___172 *);
	int (*task_getscheduler)(struct task_struct___172 *);
	int (*task_movememory)(struct task_struct___172 *);
	int (*task_kill)(struct task_struct___172 *, struct kernel_siginfo *, int, const struct cred___27 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___172 *, struct inode___165 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___172 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock___27 *, struct sk_buff___34 *);
	void (*d_instantiate)(struct dentry___165 *, struct inode___165 *);
	int (*getprocattr)(struct task_struct___172 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___165 *);
	int (*inode_notifysecctx)(struct inode___165 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___165 *, void *, u32);
	int (*inode_getsecctx)(struct inode___165 *, void **, u32 *);
	int (*post_notification)(const struct cred___27 *, const struct cred___27 *, struct watch_notification *);
	int (*watch_key)(struct key___10 *);
	int (*unix_stream_connect)(struct sock___27 *, struct sock___27 *, struct sock___27 *);
	int (*unix_may_send)(struct socket___27 *, struct socket___27 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___27 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___27 *, struct socket___27 *);
	int (*socket_bind)(struct socket___27 *, struct sockaddr *, int);
	int (*socket_connect)(struct socket___27 *, struct sockaddr *, int);
	int (*socket_listen)(struct socket___27 *, int);
	int (*socket_accept)(struct socket___27 *, struct socket___27 *);
	int (*socket_sendmsg)(struct socket___27 *, struct msghdr___27 *, int);
	int (*socket_recvmsg)(struct socket___27 *, struct msghdr___27 *, int, int);
	int (*socket_getsockname)(struct socket___27 *);
	int (*socket_getpeername)(struct socket___27 *);
	int (*socket_getsockopt)(struct socket___27 *, int, int);
	int (*socket_setsockopt)(struct socket___27 *, int, int);
	int (*socket_shutdown)(struct socket___27 *, int);
	int (*socket_sock_rcv_skb)(struct sock___27 *, struct sk_buff___34 *);
	int (*socket_getpeersec_stream)(struct socket___27 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___27 *, struct sk_buff___34 *, u32 *);
	int (*sk_alloc_security)(struct sock___27 *, int, gfp_t);
	void (*sk_free_security)(struct sock___27 *);
	void (*sk_clone_security)(const struct sock___27 *, struct sock___27 *);
	void (*sk_getsecid)(struct sock___27 *, u32 *);
	void (*sock_graft)(struct sock___27 *, struct socket___27 *);
	int (*inet_conn_request)(const struct sock___27 *, struct sk_buff___34 *, struct request_sock___17 *);
	void (*inet_csk_clone)(struct sock___27 *, const struct request_sock___17 *);
	void (*inet_conn_established)(struct sock___27 *, struct sk_buff___34 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___17 *, struct flowi_common *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock___27 *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___34 *);
	int (*sctp_bind_connect)(struct sock___27 *, int, struct sockaddr *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock___27 *, struct sock___27 *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx **, struct xfrm_user_sec_ctx *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx *, struct xfrm_sec_ctx **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common *);
	int (*xfrm_decode_session)(struct sk_buff___34 *, u32 *, int);
	int (*key_alloc)(struct key___10 *, const struct cred___27 *, long unsigned int);
	void (*key_free)(struct key___10 *);
	int (*key_permission)(key_ref_t, const struct cred___27 *, enum key_need_perm);
	int (*key_getsecurity)(struct key___10 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___35 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog___33 *);
	int (*bpf_map_alloc_security)(struct bpf_map___35 *);
	void (*bpf_map_free_security)(struct bpf_map___35 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___35 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___35 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event *);
	void (*perf_event_free)(struct perf_event *);
	int (*perf_event_read)(struct perf_event *);
	int (*perf_event_write)(struct perf_event *);
};

struct linux_binprm___36 {
	struct vm_area_struct___170 *vma;
	long unsigned int vma_pages;
	struct mm_struct___171 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___165 *executable;
	struct file___165 *interpreter;
	struct file___165 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct kernfs_root___152;

struct kernfs_elem_dir___152 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___152 *root;
	long unsigned int rev;
};

struct kernfs_elem_symlink___152 {
	struct kernfs_node___152 *target_kn;
};

struct kernfs_ops___152;

struct kernfs_elem_attr___152 {
	const struct kernfs_ops___152 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___152 *notify_next;
};

struct kernfs_node___152 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___152 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___152 dir;
		struct kernfs_elem_symlink___152 symlink;
		struct kernfs_elem_attr___152 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

typedef struct {
	struct net___38 *net;
} possible_net_t___33;

struct proto___26;

struct sock_common___26 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___26 *skc_prot;
	possible_net_t___33 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___27 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff_head___33 {
	struct sk_buff___34 *next;
	struct sk_buff___34 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___26 {
	struct cgroup___114 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___26;

struct socket_wq___27;

struct dst_entry___26;

struct net_device___35;

struct sock_reuseport___5;

struct sock___27 {
	struct sock_common___26 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___33 sk_error_queue;
	struct sk_buff___34 *sk_rx_skb_cache;
	struct sk_buff_head___33 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___34 *head;
		struct sk_buff___34 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___26 *sk_filter;
	union {
		struct socket_wq___27 *sk_wq;
		struct socket_wq___27 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___26 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___26 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___34 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___34 *sk_tx_skb_cache;
	struct sk_buff_head___33 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___170 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___26 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___146 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___27 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___26 sk_cgrp_data;
	struct mem_cgroup___66 *sk_memcg;
	void (*sk_state_change)(struct sock___27 *);
	void (*sk_data_ready)(struct sock___27 *);
	void (*sk_write_space)(struct sock___27 *);
	void (*sk_error_report)(struct sock___27 *);
	int (*sk_backlog_rcv)(struct sock___27 *, struct sk_buff___34 *);
	struct sk_buff___34 * (*sk_validate_xmit_skb)(struct sock___27 *, struct net_device___35 *, struct sk_buff___34 *);
	void (*sk_destruct)(struct sock___27 *);
	struct sock_reuseport___5 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct sk_buff___34 {
	union {
		struct {
			struct sk_buff___34 *next;
			struct sk_buff___34 *prev;
			union {
				struct net_device___35 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___27 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___34 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct socket_wq___27 {
	wait_queue_head_t wait;
	struct fasync_struct___165 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___27;

struct socket___27 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___165 *file;
	struct sock___27 *sk;
	const struct proto_ops___27 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___27 wq;
};

struct msghdr___27 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___94 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___165 *msg_iocb;
};

struct request_sock_ops___16;

struct request_sock___17 {
	struct sock_common___26 __req_common;
	struct request_sock___17 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___16 *rsk_ops;
	struct sock___27 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct bpf_map_ops___35;

struct bpf_map___35 {
	const struct bpf_map_ops___35 *ops;
	struct bpf_map___35 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___66 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog___33 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___35 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_trampoline___35;

struct bpf_jit_poke_descriptor___35;

struct bpf_prog_ops___33;

struct btf_mod_pair___35;

struct bpf_prog_offload___33;

struct bpf_prog_aux___35 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___33 *dst_prog;
	struct bpf_trampoline___35 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___33 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___35 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___33 *ops;
	struct bpf_map___35 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___35 *used_btfs;
	struct bpf_prog___33 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___35 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___33 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct security_hook_list___5 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___5 hook;
	struct lsm_id *lsmid;
};

struct kernel_param_ops___149 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___149 *);
	int (*get)(char *, const struct kernel_param___149 *);
	void (*free)(void *);
};

struct kparam_array___149;

struct kernel_param___149 {
	const char *name;
	struct module___149 *mod;
	const struct kernel_param_ops___149 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___149 *arr;
	};
};

struct kparam_array___149 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___149 *ops;
	void *elem;
};

struct ip_ra_chain___13;

struct fib_rules_ops___26;

struct fqdir___38;

struct tcp_congestion_ops___4;

struct fib_notifier_ops___26;

struct netns_ipv4___38 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___13 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___26 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___27 *fibnl;
	struct sock___27 **icmp_sk;
	struct sock___27 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___27 **tcp_sk;
	struct fqdir___38 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___4 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___26 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___26 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___26 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___26;

struct dst_ops___38 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___38 *);
	struct dst_entry___26 * (*check)(struct dst_entry___26 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___26 *);
	unsigned int (*mtu)(const struct dst_entry___26 *);
	u32 * (*cow_metrics)(struct dst_entry___26 *, long unsigned int);
	void (*destroy)(struct dst_entry___26 *);
	void (*ifdown)(struct dst_entry___26 *, struct net_device___35 *, int);
	struct dst_entry___26 * (*negative_advice)(struct dst_entry___26 *);
	void (*link_failure)(struct sk_buff___34 *);
	void (*update_pmtu)(struct dst_entry___26 *, struct sock___27 *, struct sk_buff___34 *, u32, bool);
	void (*redirect)(struct dst_entry___26 *, struct sock___27 *, struct sk_buff___34 *);
	int (*local_out)(struct net___38 *, struct sock___27 *, struct sk_buff___34 *);
	struct neighbour___26 * (*neigh_lookup)(const struct dst_entry___26 *, struct sk_buff___34 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___26 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___38 {
	struct dst_ops___38 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___38 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___26 *fib6_rules_ops;
	struct sock___27 **icmp_sk;
	struct sock___27 *ndisc_sk;
	struct sock___27 *tcp_sk;
	struct sock___27 *igmp_sk;
	struct sock___27 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___26 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___26 *notifier_ops;
	struct fib_notifier_ops___26 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___38 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___38 *fqdir;
};

struct netns_sctp___26 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___27 *ctl_sock;
	struct sock___27 *udp4_sock;
	struct sock___27 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___3;

struct netns_nf___3 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___3 *hooks_ipv4[5];
	struct nf_hook_entries___3 *hooks_ipv6[5];
	struct nf_hook_entries___3 *hooks_arp[3];
	struct nf_hook_entries___3 *hooks_bridge[5];
	struct nf_hook_entries___3 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct netns_bpf___33 {
	struct bpf_prog_array___33 *run_array[2];
	struct bpf_prog___33 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___38 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___27 *nlsk;
	struct sock___27 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___38 xfrm4_dst_ops;
	struct dst_ops___38 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___38 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___27 *rtnl;
	struct sock___27 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___35 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___38 ipv4;
	struct netns_ipv6___38 ipv6;
	struct netns_ieee802154_lowpan___38 ieee802154_lowpan;
	struct netns_sctp___26 sctp;
	struct netns_nf___3 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___33 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___33 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___38 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___27 *crypto_nlsk;
	struct sock___27 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___114 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___114 *root_cset;
};

struct seq_operations___143 {
	void * (*start)(struct seq_file___143 *, loff_t *);
	void (*stop)(struct seq_file___143 *, void *);
	void * (*next)(struct seq_file___143 *, void *, loff_t *);
	int (*show)(struct seq_file___143 *, void *);
};

struct fwnode_operations___121;

struct fwnode_handle___121 {
	struct fwnode_handle___121 *secondary;
	const struct fwnode_operations___121 *ops;
	struct device___121 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___121;

struct fwnode_endpoint___121;

struct fwnode_operations___121 {
	struct fwnode_handle___121 * (*get)(struct fwnode_handle___121 *);
	void (*put)(struct fwnode_handle___121 *);
	bool (*device_is_available)(const struct fwnode_handle___121 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___121 *, const struct device___121 *);
	bool (*property_present)(const struct fwnode_handle___121 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___121 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___121 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___121 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*get_parent)(const struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*get_next_child_node)(const struct fwnode_handle___121 *, struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*get_named_child_node)(const struct fwnode_handle___121 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___121 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___121 *);
	struct fwnode_handle___121 * (*graph_get_next_endpoint)(const struct fwnode_handle___121 *, struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*graph_get_remote_endpoint)(const struct fwnode_handle___121 *);
	struct fwnode_handle___121 * (*graph_get_port_parent)(struct fwnode_handle___121 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___121 *, struct fwnode_endpoint___121 *);
	int (*add_links)(struct fwnode_handle___121 *);
};

struct fwnode_endpoint___121 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___121 *local_fwnode;
};

struct fwnode_reference_args___121 {
	struct fwnode_handle___121 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_syscall_ops___152;

struct kernfs_root___152 {
	struct kernfs_node___152 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___152 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_open_file___152;

struct kernfs_ops___152 {
	int (*open)(struct kernfs_open_file___152 *);
	void (*release)(struct kernfs_open_file___152 *);
	int (*seq_show)(struct seq_file___143 *, void *);
	void * (*seq_start)(struct seq_file___143 *, loff_t *);
	void * (*seq_next)(struct seq_file___143 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___143 *, void *);
	ssize_t (*read)(struct kernfs_open_file___152 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___152 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___152 *, struct poll_table_struct___106 *);
	int (*mmap)(struct kernfs_open_file___152 *, struct vm_area_struct___170 *);
};

struct kernfs_syscall_ops___152 {
	int (*show_options)(struct seq_file___143 *, struct kernfs_root___152 *);
	int (*mkdir)(struct kernfs_node___152 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___152 *);
	int (*rename)(struct kernfs_node___152 *, struct kernfs_node___152 *, const char *);
	int (*show_path)(struct seq_file___143 *, struct kernfs_node___152 *, struct kernfs_root___152 *);
};

struct kernfs_open_file___152 {
	struct kernfs_node___152 *kn;
	struct file___165 *file;
	struct seq_file___143 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___161 *vm_ops;
};

struct kobj_ns_type_operations___26 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___27 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___152;

struct attribute_group___152 {
	const char *name;
	umode_t (*is_visible)(struct kobject___152 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___152 *, struct bin_attribute___152 *, int);
	struct attribute **attrs;
	struct bin_attribute___152 **bin_attrs;
};

struct bin_attribute___152 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___165 * (*f_mapping)();
	ssize_t (*read)(struct file___165 *, struct kobject___152 *, struct bin_attribute___152 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___165 *, struct kobject___152 *, struct bin_attribute___152 *, char *, loff_t, size_t);
	int (*mmap)(struct file___165 *, struct kobject___152 *, struct bin_attribute___152 *, struct vm_area_struct___170 *);
};

struct sysfs_ops___152 {
	ssize_t (*show)(struct kobject___152 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___152 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___152;

struct kset___152 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___152 kobj;
	const struct kset_uevent_ops___152 *uevent_ops;
};

struct kobj_type___152 {
	void (*release)(struct kobject___152 *);
	const struct sysfs_ops___152 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___152 **default_groups;
	const struct kobj_ns_type_operations___26 * (*child_ns_type)(struct kobject___152 *);
	const void * (*namespace)(struct kobject___152 *);
	void (*get_ownership)(struct kobject___152 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___152 {
	int (* const filter)(struct kset___152 *, struct kobject___152 *);
	const char * (* const name)(struct kset___152 *, struct kobject___152 *);
	int (* const uevent)(struct kset___152 *, struct kobject___152 *, struct kobj_uevent_env *);
};

struct module_attribute___149 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___149 *, struct module_kobject___149 *, char *);
	ssize_t (*store)(struct module_attribute___149 *, struct module_kobject___149 *, const char *, size_t);
	void (*setup)(struct module___149 *, const char *);
	int (*test)(struct module___149 *);
	void (*free)(struct module___149 *);
};

typedef int (*sk_read_actor_t___26)(read_descriptor_t *, struct sk_buff___34 *, unsigned int, size_t);

struct proto_ops___27 {
	int family;
	struct module___149 *owner;
	int (*release)(struct socket___27 *);
	int (*bind)(struct socket___27 *, struct sockaddr *, int);
	int (*connect)(struct socket___27 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___27 *, struct socket___27 *);
	int (*accept)(struct socket___27 *, struct socket___27 *, int, bool);
	int (*getname)(struct socket___27 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___165 *, struct socket___27 *, struct poll_table_struct___106 *);
	int (*ioctl)(struct socket___27 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___27 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___27 *, void *, bool, bool);
	int (*listen)(struct socket___27 *, int);
	int (*shutdown)(struct socket___27 *, int);
	int (*setsockopt)(struct socket___27 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___27 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___143 *, struct socket___27 *);
	int (*sendmsg)(struct socket___27 *, struct msghdr___27 *, size_t);
	int (*recvmsg)(struct socket___27 *, struct msghdr___27 *, size_t, int);
	int (*mmap)(struct file___165 *, struct socket___27 *, struct vm_area_struct___170 *);
	ssize_t (*sendpage)(struct socket___27 *, struct page___170 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___27 *, loff_t *, struct pipe_inode_info___58 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___27 *, int);
	int (*peek_len)(struct socket___27 *);
	int (*read_sock)(struct sock___27 *, read_descriptor_t *, sk_read_actor_t___26);
	int (*sendpage_locked)(struct sock___27 *, struct page___170 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___27 *, struct msghdr___27 *, size_t);
	int (*set_rcvlowat)(struct sock___27 *, int);
};

struct dev_pm_ops___121 {
	int (*prepare)(struct device___121 *);
	void (*complete)(struct device___121 *);
	int (*suspend)(struct device___121 *);
	int (*resume)(struct device___121 *);
	int (*freeze)(struct device___121 *);
	int (*thaw)(struct device___121 *);
	int (*poweroff)(struct device___121 *);
	int (*restore)(struct device___121 *);
	int (*suspend_late)(struct device___121 *);
	int (*resume_early)(struct device___121 *);
	int (*freeze_late)(struct device___121 *);
	int (*thaw_early)(struct device___121 *);
	int (*poweroff_late)(struct device___121 *);
	int (*restore_early)(struct device___121 *);
	int (*suspend_noirq)(struct device___121 *);
	int (*resume_noirq)(struct device___121 *);
	int (*freeze_noirq)(struct device___121 *);
	int (*thaw_noirq)(struct device___121 *);
	int (*poweroff_noirq)(struct device___121 *);
	int (*restore_noirq)(struct device___121 *);
	int (*runtime_suspend)(struct device___121 *);
	int (*runtime_resume)(struct device___121 *);
	int (*runtime_idle)(struct device___121 *);
};

struct wakeup_source___121 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___121 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___121 {
	struct dev_pm_ops___121 ops;
	int (*start)(struct device___121 *);
	void (*detach)(struct device___121 *, bool);
	int (*activate)(struct device___121 *);
	void (*sync)(struct device___121 *);
	void (*dismiss)(struct device___121 *);
};

struct bus_type___121 {
	const char *name;
	const char *dev_name;
	struct device___121 *dev_root;
	const struct attribute_group___152 **bus_groups;
	const struct attribute_group___152 **dev_groups;
	const struct attribute_group___152 **drv_groups;
	int (*match)(struct device___121 *, struct device_driver___121 *);
	int (*uevent)(struct device___121 *, struct kobj_uevent_env *);
	int (*probe)(struct device___121 *);
	void (*sync_state)(struct device___121 *);
	void (*remove)(struct device___121 *);
	void (*shutdown)(struct device___121 *);
	int (*online)(struct device___121 *);
	int (*offline)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	int (*num_vf)(struct device___121 *);
	int (*dma_configure)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___121 {
	const char *name;
	struct bus_type___121 *bus;
	struct module___149 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___121 *);
	void (*sync_state)(struct device___121 *);
	int (*remove)(struct device___121 *);
	void (*shutdown)(struct device___121 *);
	int (*suspend)(struct device___121 *, pm_message_t);
	int (*resume)(struct device___121 *);
	const struct attribute_group___152 **groups;
	const struct attribute_group___152 **dev_groups;
	const struct dev_pm_ops___121 *pm;
	void (*coredump)(struct device___121 *);
	struct driver_private *p;
};

struct device_type___121 {
	const char *name;
	const struct attribute_group___152 **groups;
	int (*uevent)(struct device___121 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___121 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___121 *);
	const struct dev_pm_ops___121 *pm;
};

struct class___121 {
	const char *name;
	struct module___149 *owner;
	const struct attribute_group___152 **class_groups;
	const struct attribute_group___152 **dev_groups;
	struct kobject___152 *dev_kobj;
	int (*dev_uevent)(struct device___121 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___121 *, umode_t *);
	void (*class_release)(struct class___121 *);
	void (*dev_release)(struct device___121 *);
	int (*shutdown_pre)(struct device___121 *);
	const struct kobj_ns_type_operations___26 *ns_type;
	const void * (*namespace)(struct device___121 *);
	void (*get_ownership)(struct device___121 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___121 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___58;

struct pipe_buffer___58 {
	struct page___170 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___58 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___58 {
	int (*confirm)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
	void (*release)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
	bool (*try_steal)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
	bool (*get)(struct pipe_inode_info___58 *, struct pipe_buffer___58 *);
};

typedef rx_handler_result_t rx_handler_func_t___33(struct sk_buff___34 **);

struct bpf_xdp_entity___33 {
	struct bpf_prog___33 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___33;

struct net_device_ops___33;

struct ethtool_ops___11;

struct l3mdev_ops___26;

struct ndisc_ops___16;

struct xfrmdev_ops___33;

struct header_ops___33;

struct inet6_dev___16;

struct netdev_rx_queue___33;

struct mini_Qdisc___33;

struct netdev_queue___33;

struct Qdisc___33;

struct rtnl_link_ops___33;

struct dcbnl_rtnl_ops___33;

struct net_device___35 {
	char name[16];
	struct netdev_name_node___33 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___33 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___11 *ethtool_ops;
	const struct l3mdev_ops___26 *l3mdev_ops;
	const struct ndisc_ops___16 *ndisc_ops;
	const struct xfrmdev_ops___33 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___33 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___152 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___16 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___33 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___33 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___33 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___33 *miniq_ingress;
	struct netdev_queue___33 *ingress_queue;
	struct nf_hook_entries___3 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___33 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___33 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___33 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___33 = 0,
		NETREG_REGISTERED___33 = 1,
		NETREG_UNREGISTERING___33 = 2,
		NETREG_UNREGISTERED___33 = 3,
		NETREG_RELEASED___33 = 4,
		NETREG_DUMMY___33 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___33 = 0,
		RTNL_LINK_INITIALIZING___33 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___35 *);
	struct netpoll_info *npinfo;
	possible_net_t___33 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___121 dev;
	const struct attribute_group___152 *sysfs_groups[4];
	const struct attribute_group___152 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___33 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___33 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___33 xdp_state[3];
	long: 64;
};

struct inet_frags___38;

struct fqdir___38 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___38 *f;
	struct net___38 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___38;

struct inet_frags___38 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___38 *, const void *);
	void (*destructor)(struct inet_frag_queue___38 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___38 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___34 *fragments_tail;
	struct sk_buff___34 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___38 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___13 {
	struct ip_ra_chain___13 *next;
	struct sock___27 *sk;
	union {
		void (*destructor)(struct sock___27 *);
		struct sock___27 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___26;

struct fib_lookup_arg___26;

struct fib_rules_ops___26 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___26 *, struct flowi *, int, struct fib_lookup_arg___26 *);
	bool (*suppress)(struct fib_rule___26 *, int, struct fib_lookup_arg___26 *);
	int (*match)(struct fib_rule___26 *, struct flowi *, int);
	int (*configure)(struct fib_rule___26 *, struct sk_buff___34 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___26 *);
	int (*compare)(struct fib_rule___26 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___26 *, struct sk_buff___34 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___26 *);
	void (*flush_cache)(struct fib_rules_ops___26 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___149 *owner;
	struct net___38 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___4 {
	u32 (*ssthresh)(struct sock___27 *);
	void (*cong_avoid)(struct sock___27 *, u32, u32);
	void (*set_state)(struct sock___27 *, u8);
	void (*cwnd_event)(struct sock___27 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___27 *, u32);
	void (*pkts_acked)(struct sock___27 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___27 *);
	void (*cong_control)(struct sock___27 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___27 *);
	u32 (*sndbuf_expand)(struct sock___27 *);
	size_t (*get_info)(struct sock___27 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___149 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___27 *);
	void (*release)(struct sock___27 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___26 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___38 *);
	int (*fib_dump)(struct net___38 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___149 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___13;

struct dst_entry___26 {
	struct net_device___35 *dev;
	struct dst_ops___38 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___34 *);
	int (*output)(struct net___38 *, struct sock___27 *, struct sk_buff___34 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___13 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___26;

struct neigh_parms___26;

struct neigh_ops___26;

struct neighbour___26 {
	struct neighbour___26 *next;
	struct neigh_table___26 *tbl;
	struct neigh_parms___26 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___33 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___26 *, struct sk_buff___34 *);
	const struct neigh_ops___26 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___35 *dev;
	u8 primary_key[0];
};

struct nf_hook_state___3;

typedef unsigned int nf_hookfn___3(void *, struct sk_buff___34 *, const struct nf_hook_state___3 *);

struct nf_hook_entry___3 {
	nf_hookfn___3 *hook;
	void *priv;
};

struct nf_hook_entries___3 {
	u16 num_hook_entries;
	struct nf_hook_entry___3 hooks[0];
};

struct bpf_prog_array_item___33 {
	struct bpf_prog___33 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___33 {
	struct callback_head rcu;
	struct bpf_prog_array_item___33 items[0];
};

struct pernet_operations___5 {
	struct list_head list;
	int (*init)(struct net___38 *);
	void (*pre_exit)(struct net___38 *);
	void (*exit)(struct net___38 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___33 {
	int (*ieee_getets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___35 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___35 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___35 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___35 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___35 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___35 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___35 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___35 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___35 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___35 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___35 *);
	u8 (*setstate)(struct net_device___35 *, u8);
	void (*getpermhwaddr)(struct net_device___35 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___35 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___35 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___35 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___35 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___35 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___35 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___35 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___35 *, int, u8 *);
	void (*setpfccfg)(struct net_device___35 *, int, u8);
	void (*getpfccfg)(struct net_device___35 *, int, u8 *);
	u8 (*setall)(struct net_device___35 *);
	u8 (*getcap)(struct net_device___35 *, int, u8 *);
	int (*getnumtcs)(struct net_device___35 *, int, u8 *);
	int (*setnumtcs)(struct net_device___35 *, int, u8);
	u8 (*getpfcstate)(struct net_device___35 *);
	void (*setpfcstate)(struct net_device___35 *, u8);
	void (*getbcncfg)(struct net_device___35 *, int, u32 *);
	void (*setbcncfg)(struct net_device___35 *, int, u32);
	void (*getbcnrp)(struct net_device___35 *, int, u8 *);
	void (*setbcnrp)(struct net_device___35 *, int, u8);
	int (*setapp)(struct net_device___35 *, u8, u16, u8);
	int (*getapp)(struct net_device___35 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___35 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___35 *, int, u8);
	u8 (*getdcbx)(struct net_device___35 *);
	u8 (*setdcbx)(struct net_device___35 *, u8);
	int (*peer_getappinfo)(struct net_device___35 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___35 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___35 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___35 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___35 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___35 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___36;

typedef int (*bpf_iter_init_seq_priv_t___35)(void *, struct bpf_iter_aux_info___36 *);

struct bpf_iter_aux_info___36 {
	struct bpf_map___35 *map;
};

struct bpf_iter_seq_info___35 {
	const struct seq_operations___143 *seq_ops;
	bpf_iter_init_seq_priv_t___35 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___35 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___35 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___35 *, struct file___165 *);
	void (*map_free)(struct bpf_map___35 *);
	int (*map_get_next_key)(struct bpf_map___35 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___35 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___35 *, void *);
	int (*map_lookup_batch)(struct bpf_map___35 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___35 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___35 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___35 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___35 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___35 *, void *);
	int (*map_update_elem)(struct bpf_map___35 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___35 *, void *);
	int (*map_push_elem)(struct bpf_map___35 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___35 *, void *);
	int (*map_peek_elem)(struct bpf_map___35 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___35 *, struct file___165 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___35 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___35 *, void *, struct seq_file___143 *);
	int (*map_check_btf)(const struct bpf_map___35 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___35 *, struct bpf_prog_aux___35 *);
	void (*map_poke_untrack)(struct bpf_map___35 *, struct bpf_prog_aux___35 *);
	void (*map_poke_run)(struct bpf_map___35 *, u32, struct bpf_prog___33 *, struct bpf_prog___33 *);
	int (*map_direct_value_addr)(const struct bpf_map___35 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___35 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___35 *, struct vm_area_struct___170 *);
	__poll_t (*map_poll)(struct bpf_map___35 *, struct file___165 *, struct poll_table_struct___106 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___35 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___35 *, const struct bpf_map___35 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___35 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___35 *iter_seq_info;
};

struct bpf_offloaded_map___33;

struct bpf_map_dev_ops___33 {
	int (*map_get_next_key)(struct bpf_offloaded_map___33 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___33 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___33 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___33 *, void *);
};

struct bpf_offloaded_map___33 {
	struct bpf_map___35 map;
	struct net_device___35 *netdev;
	const struct bpf_map_dev_ops___33 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___33 {
	int (*test_run)(struct bpf_prog___33 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___33 {
	struct bpf_prog___33 *prog;
	struct net_device___35 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___35 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___33 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___149 *mod;
};

struct bpf_jit_poke_descriptor___35 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___35 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___35 {
	struct btf *btf;
	struct module___149 *module;
};

struct cftype___114;

struct cgroup_subsys___114 {
	struct cgroup_subsys_state___114 * (*css_alloc)(struct cgroup_subsys_state___114 *);
	int (*css_online)(struct cgroup_subsys_state___114 *);
	void (*css_offline)(struct cgroup_subsys_state___114 *);
	void (*css_released)(struct cgroup_subsys_state___114 *);
	void (*css_free)(struct cgroup_subsys_state___114 *);
	void (*css_reset)(struct cgroup_subsys_state___114 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___114 *, int);
	int (*css_extra_stat_show)(struct seq_file___143 *, struct cgroup_subsys_state___114 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___172 *, struct css_set___114 *);
	void (*cancel_fork)(struct task_struct___172 *, struct css_set___114 *);
	void (*fork)(struct task_struct___172 *);
	void (*exit)(struct task_struct___172 *);
	void (*release)(struct task_struct___172 *);
	void (*bind)(struct cgroup_subsys_state___114 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___114 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___114 *dfl_cftypes;
	struct cftype___114 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___114 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___114 *updated_children;
	struct cgroup___114 *updated_next;
};

struct cgroup_root___114 {
	struct kernfs_root___152 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___114 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___114 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___114 *ss;
	struct list_head node;
	struct kernfs_ops___152 *kf_ops;
	int (*open)(struct kernfs_open_file___152 *);
	void (*release)(struct kernfs_open_file___152 *);
	u64 (*read_u64)(struct cgroup_subsys_state___114 *, struct cftype___114 *);
	s64 (*read_s64)(struct cgroup_subsys_state___114 *, struct cftype___114 *);
	int (*seq_show)(struct seq_file___143 *, void *);
	void * (*seq_start)(struct seq_file___143 *, loff_t *);
	void * (*seq_next)(struct seq_file___143 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___143 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___114 *, struct cftype___114 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___114 *, struct cftype___114 *, s64);
	ssize_t (*write)(struct kernfs_open_file___152 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___152 *, struct poll_table_struct___106 *);
};

struct xdp_rxq_info___33 {
	struct net_device___35 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___33 {
	struct net_device___35 *dev;
};

struct xdp_buff___33 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___33 *rxq;
	struct xdp_txq_info___33 *txq;
	u32 frame_sz;
};

struct xdp_frame___33 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___35 *dev_rx;
};

struct netlink_callback___33 {
	struct sk_buff___34 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___34 *, struct netlink_callback___33 *);
	int (*done)(struct netlink_callback___33 *);
	void *data;
	struct module___149 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___33 {
	int (*create)(struct sk_buff___34 *, struct net_device___35 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___34 *, unsigned char *);
	int (*cache)(const struct neighbour___26 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___35 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___34 *);
};

struct netdev_queue___33 {
	struct net_device___35 *dev;
	struct Qdisc___33 *qdisc;
	struct Qdisc___33 *qdisc_sleeping;
	struct kobject___152 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___35 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___33 {
	struct sk_buff___34 *head;
	struct sk_buff___34 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___33;

struct Qdisc___33 {
	int (*enqueue)(struct sk_buff___34 *, struct Qdisc___33 *, struct sk_buff___34 **);
	struct sk_buff___34 * (*dequeue)(struct Qdisc___33 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___33 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___33 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___33 gso_skb;
	struct qdisc_skb_head___33 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___33 *next_sched;
	struct sk_buff_head___33 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___33 {
	struct xdp_rxq_info___33 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___152 kobj;
	struct net_device___35 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___33 {
	enum net_device_path_type type;
	const struct net_device___35 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___33 = 0,
				DEV_PATH_BR_VLAN_TAG___33 = 1,
				DEV_PATH_BR_VLAN_UNTAG___33 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___33 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___33 {
	const struct net_device___35 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___33 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___33 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___33 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___33 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___34 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___33 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___35 *dev;
	const char *name;
};

struct net_device_ops___33 {
	int (*ndo_init)(struct net_device___35 *);
	void (*ndo_uninit)(struct net_device___35 *);
	int (*ndo_open)(struct net_device___35 *);
	int (*ndo_stop)(struct net_device___35 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___34 *, struct net_device___35 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___34 *, struct net_device___35 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___35 *, struct sk_buff___34 *, struct net_device___35 *);
	void (*ndo_change_rx_flags)(struct net_device___35 *, int);
	void (*ndo_set_rx_mode)(struct net_device___35 *);
	int (*ndo_set_mac_address)(struct net_device___35 *, void *);
	int (*ndo_validate_addr)(struct net_device___35 *);
	int (*ndo_do_ioctl)(struct net_device___35 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___35 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___35 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___35 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___35 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___35 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___35 *, int);
	int (*ndo_neigh_setup)(struct net_device___35 *, struct neigh_parms___26 *);
	void (*ndo_tx_timeout)(struct net_device___35 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___35 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___35 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___35 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___35 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___35 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___35 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___35 *);
	int (*ndo_netpoll_setup)(struct net_device___35 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___35 *);
	int (*ndo_set_vf_mac)(struct net_device___35 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___35 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___35 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___35 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___35 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___35 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___35 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___35 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___35 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___35 *, int, struct sk_buff___34 *);
	int (*ndo_get_vf_guid)(struct net_device___35 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___35 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___35 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___35 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___35 *);
	int (*ndo_fcoe_disable)(struct net_device___35 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___35 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___35 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___35 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___35 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___35 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___35 *, const struct sk_buff___34 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___35 *, struct net_device___35 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___35 *, struct net_device___35 *);
	struct net_device___35 * (*ndo_get_xmit_slave)(struct net_device___35 *, struct sk_buff___34 *, bool);
	struct net_device___35 * (*ndo_sk_get_lower_dev)(struct net_device___35 *, struct sock___27 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___35 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___35 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___35 *, struct neighbour___26 *);
	void (*ndo_neigh_destroy)(struct net_device___35 *, struct neighbour___26 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___34 *, struct netlink_callback___33 *, struct net_device___35 *, struct net_device___35 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___34 *, struct nlattr **, struct net_device___35 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___35 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___34 *, u32, u32, struct net_device___35 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___35 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___35 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___35 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___35 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___35 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___35 *, struct net_device___35 *);
	void (*ndo_dfwd_del_station)(struct net_device___35 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___35 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___35 *);
	int (*ndo_change_proto_down)(struct net_device___35 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___35 *, struct sk_buff___34 *);
	void (*ndo_set_rx_headroom)(struct net_device___35 *, int);
	int (*ndo_bpf)(struct net_device___35 *, struct netdev_bpf___33 *);
	int (*ndo_xdp_xmit)(struct net_device___35 *, int, struct xdp_frame___33 **, u32);
	struct net_device___35 * (*ndo_xdp_get_xmit_slave)(struct net_device___35 *, struct xdp_buff___33 *);
	int (*ndo_xsk_wakeup)(struct net_device___35 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___35 *);
	int (*ndo_tunnel_ctl)(struct net_device___35 *, struct ip_tunnel_parm *, int);
	struct net_device___35 * (*ndo_get_peer_dev)(struct net_device___35 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___33 *, struct net_device_path___33 *);
};

struct neigh_parms___26 {
	possible_net_t___33 net;
	struct net_device___35 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___26 *);
	struct neigh_table___26 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___11 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___35 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___35 *);
	void (*get_regs)(struct net_device___35 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___35 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___35 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___35 *);
	void (*set_msglevel)(struct net_device___35 *, u32);
	int (*nway_reset)(struct net_device___35 *);
	u32 (*get_link)(struct net_device___35 *);
	int (*get_link_ext_state)(struct net_device___35 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___35 *);
	int (*get_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___35 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___35 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___35 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___35 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___35 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___35 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___35 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___35 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___35 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___35 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___35 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___35 *);
	void (*complete)(struct net_device___35 *);
	u32 (*get_priv_flags)(struct net_device___35 *);
	int (*set_priv_flags)(struct net_device___35 *, u32);
	int (*get_sset_count)(struct net_device___35 *, int);
	int (*get_rxnfc)(struct net_device___35 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___35 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___35 *, struct ethtool_flash *);
	int (*reset)(struct net_device___35 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___35 *);
	u32 (*get_rxfh_indir_size)(struct net_device___35 *);
	int (*get_rxfh)(struct net_device___35 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___35 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___35 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___35 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___35 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___35 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___35 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___35 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___35 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___35 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___35 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___35 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___35 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___35 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___35 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___35 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___35 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___35 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___35 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___35 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___35 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___35 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___35 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___35 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___35 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___35 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___35 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___35 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___35 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___35 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___35 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___26 {
	u32 (*l3mdev_fib_table)(const struct net_device___35 *);
	struct sk_buff___34 * (*l3mdev_l3_rcv)(struct net_device___35 *, struct sk_buff___34 *, u16);
	struct sk_buff___34 * (*l3mdev_l3_out)(struct net_device___35 *, struct sock___27 *, struct sk_buff___34 *, u16);
	struct dst_entry___26 * (*l3mdev_link_scope_lookup)(const struct net_device___35 *, struct flowi6 *);
};

struct ndisc_ops___16 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___35 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___35 *, struct neighbour___26 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___35 *, u8, struct neighbour___26 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___35 *, struct sk_buff___34 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___38 *, struct net_device___35 *, const struct prefix_info *, struct inet6_dev___16 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___16;

struct inet6_dev___16 {
	struct net_device___35 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___16 *mc_list;
	struct ifmcaddr6___16 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___33 mc_query_queue;
	struct sk_buff_head___33 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___26 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___33;

struct tcf_block___33;

struct mini_Qdisc___33 {
	struct tcf_proto___33 *filter_list;
	struct tcf_block___33 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___33 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___35 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___35 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___38 *, struct net_device___35 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___35 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___35 *, struct list_head *);
	size_t (*get_size)(const struct net_device___35 *);
	int (*fill_info)(struct sk_buff___34 *, const struct net_device___35 *);
	size_t (*get_xstats_size)(const struct net_device___35 *);
	int (*fill_xstats)(struct sk_buff___34 *, const struct net_device___35 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___35 *, struct net_device___35 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___35 *, const struct net_device___35 *);
	int (*fill_slave_info)(struct sk_buff___34 *, const struct net_device___35 *, const struct net_device___35 *);
	struct net___38 * (*get_link_net)(const struct net_device___35 *);
	size_t (*get_linkxstats_size)(const struct net_device___35 *, int);
	int (*fill_linkxstats)(struct sk_buff___34 *, const struct net_device___35 *, int *, int);
};

struct nf_hook_state___3 {
	u8 hook;
	u8 pf;
	struct net_device___35 *in;
	struct net_device___35 *out;
	struct sock___27 *sk;
	struct net___38 *net;
	int (*okfn)(struct net___38 *, struct sock___27 *, struct sk_buff___34 *);
};

struct nf_hook_ops___3 {
	nf_hookfn___3 *hook;
	struct net_device___35 *dev;
	void *priv;
	u8 pf;
	enum nf_hook_ops_type hook_ops_type: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	unsigned int hooknum;
	int priority;
};

struct block_device_operations___78;

struct gendisk___78 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___79 *part0;
	const struct block_device_operations___78 *fops;
	struct request_queue___78 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___75 *bdi;
	struct kobject___152 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___152 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___78 {
	struct bio___78 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___92 *bip_vec;
	struct bio_vec___92 bip_inline_vecs[0];
};

struct blkcg___75;

struct blkg_policy_data___75;

struct blkcg_gq___75 {
	struct request_queue___78 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___75 *blkcg;
	struct blkcg_gq___75 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___75 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___78 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___78(struct request___78 *);

typedef void integrity_complete_fn___78(struct request___78 *, unsigned int);

struct blk_integrity_profile___78 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___78 *prepare_fn;
	integrity_complete_fn___78 *complete_fn;
	const char *name;
};

struct block_device_operations___78 {
	blk_qc_t (*submit_bio)(struct bio___78 *);
	int (*open)(struct block_device___79 *, fmode_t);
	void (*release)(struct gendisk___78 *, fmode_t);
	int (*rw_page)(struct block_device___79 *, sector_t, struct page___170 *, unsigned int);
	int (*ioctl)(struct block_device___79 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___79 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___78 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___78 *);
	int (*getgeo)(struct block_device___79 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___79 *, bool);
	void (*swap_slot_free_notify)(struct block_device___79 *, long unsigned int);
	int (*report_zones)(struct gendisk___78 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___78 *, umode_t *);
	struct module___149 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___78 *, sector_t *);
};

typedef void rq_end_io_fn___78(struct request___78 *, blk_status_t);

struct request___78 {
	struct request_queue___78 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___75 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___78 *bio;
	struct bio___78 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___92 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___78 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___78 *saved_end_io;
		} flush;
	};
	struct gendisk___78 *rq_disk;
	struct block_device___79 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___78 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___75 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___78 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___152 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___165 *debugfs_dir;
	struct dentry___165 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___78;

struct elevator_mq_ops___78 {
	int (*init_sched)(struct request_queue___78 *, struct elevator_type___78 *);
	void (*exit_sched)(struct elevator_queue___78 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___75 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___75 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___75 *);
	bool (*allow_merge)(struct request_queue___78 *, struct request___78 *, struct bio___78 *);
	bool (*bio_merge)(struct request_queue___78 *, struct bio___78 *, unsigned int);
	int (*request_merge)(struct request_queue___78 *, struct request___78 **, struct bio___78 *);
	void (*request_merged)(struct request_queue___78 *, struct request___78 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___78 *, struct request___78 *, struct request___78 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___78 *);
	void (*finish_request)(struct request___78 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___75 *, struct list_head *, bool);
	struct request___78 * (*dispatch_request)(struct blk_mq_hw_ctx___75 *);
	bool (*has_work)(struct blk_mq_hw_ctx___75 *);
	void (*completed_request)(struct request___78 *, u64);
	void (*requeue_request)(struct request___78 *);
	struct request___78 * (*former_request)(struct request_queue___78 *, struct request___78 *);
	struct request___78 * (*next_request)(struct request_queue___78 *, struct request___78 *);
	void (*init_icq)(struct io_cq___78 *);
	void (*exit_icq)(struct io_cq___78 *);
};

struct elv_fs_entry___78;

struct elevator_type___78 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___78 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___78 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___149 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___78 {
	struct elevator_type___78 *type;
	void *elevator_data;
	struct kobject___152 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___78 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___78 *, char *);
	ssize_t (*store)(struct elevator_queue___78 *, const char *, size_t);
};

struct blk_mq_queue_data___75;

struct blk_mq_ops___75 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___75 *, const struct blk_mq_queue_data___75 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___75 *);
	int (*get_budget)(struct request_queue___78 *);
	void (*put_budget)(struct request_queue___78 *, int);
	void (*set_rq_budget_token)(struct request___78 *, int);
	int (*get_rq_budget_token)(struct request___78 *);
	enum blk_eh_timer_return (*timeout)(struct request___78 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___75 *);
	void (*complete)(struct request___78 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___75 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___75 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___75 *, struct request___78 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___75 *, struct request___78 *, unsigned int);
	void (*initialize_rq_fn)(struct request___78 *);
	void (*cleanup_rq)(struct request___78 *);
	bool (*busy)(struct request_queue___78 *);
	int (*map_queues)(struct blk_mq_tag_set___75 *);
	void (*show_rq)(struct seq_file___143 *, struct request___78 *);
};

struct blk_mq_tag_set___75 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___75 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___75 {
	struct request___78 *rq;
	bool last;
};

struct blkcg_policy_data___75;

struct blkcg___75 {
	struct cgroup_subsys_state___114 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___75 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___75 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___75 {
	struct blkcg___75 *blkcg;
	int plid;
};

struct blkg_policy_data___75 {
	struct blkcg_gq___75 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___66 {
	struct mem_cgroup___66 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___66 {
	struct lruvec___73 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___66 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___66 *memcg;
};

struct obj_cgroup___66 {
	struct percpu_ref refcnt;
	struct mem_cgroup___66 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___33 {
	spinlock_t *lock;
	struct sk_buff___34 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___33;

struct Qdisc_ops___33 {
	struct Qdisc_ops___33 *next;
	const struct Qdisc_class_ops___33 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___34 *, struct Qdisc___33 *, struct sk_buff___34 **);
	struct sk_buff___34 * (*dequeue)(struct Qdisc___33 *);
	struct sk_buff___34 * (*peek)(struct Qdisc___33 *);
	int (*init)(struct Qdisc___33 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___33 *);
	void (*destroy)(struct Qdisc___33 *);
	int (*change)(struct Qdisc___33 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___33 *);
	int (*change_tx_queue_len)(struct Qdisc___33 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___33 *, unsigned int);
	int (*dump)(struct Qdisc___33 *, struct sk_buff___34 *);
	int (*dump_stats)(struct Qdisc___33 *, struct gnet_dump___33 *);
	void (*ingress_block_set)(struct Qdisc___33 *, u32);
	void (*egress_block_set)(struct Qdisc___33 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___33 *);
	u32 (*egress_block_get)(struct Qdisc___33 *);
	struct module___149 *owner;
};

struct Qdisc_class_ops___33 {
	unsigned int flags;
	struct netdev_queue___33 * (*select_queue)(struct Qdisc___33 *, struct tcmsg *);
	int (*graft)(struct Qdisc___33 *, long unsigned int, struct Qdisc___33 *, struct Qdisc___33 **, struct netlink_ext_ack *);
	struct Qdisc___33 * (*leaf)(struct Qdisc___33 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___33 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___33 *, u32);
	int (*change)(struct Qdisc___33 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___33 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___33 *, struct qdisc_walker *);
	struct tcf_block___33 * (*tcf_block)(struct Qdisc___33 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___33 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___33 *, long unsigned int);
	int (*dump)(struct Qdisc___33 *, long unsigned int, struct sk_buff___34 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___33 *, long unsigned int, struct gnet_dump___33 *);
};

struct tcf_chain___33;

struct tcf_block___33 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___38 *net;
	struct Qdisc___33 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___33 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___33;

struct tcf_proto_ops___33;

struct tcf_proto___33 {
	struct tcf_proto___33 *next;
	void *root;
	int (*classify)(struct sk_buff___34 *, const struct tcf_proto___33 *, struct tcf_result___33 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___33 *ops;
	struct tcf_chain___33 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___33 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___33 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___33 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___34 *, const struct tcf_proto___33 *, struct tcf_result___33 *);
	int (*init)(struct tcf_proto___33 *);
	void (*destroy)(struct tcf_proto___33 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___33 *, u32);
	void (*put)(struct tcf_proto___33 *, void *);
	int (*change)(struct net___38 *, struct sk_buff___34 *, struct tcf_proto___33 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___33 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___33 *);
	void (*walk)(struct tcf_proto___33 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___33 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___33 *, void *);
	void (*hw_del)(struct tcf_proto___33 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___38 *, struct tcf_chain___33 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___38 *, struct tcf_proto___33 *, void *, struct sk_buff___34 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___38 *, struct tcf_proto___33 *, void *, struct sk_buff___34 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___34 *, struct net___38 *, void *);
	struct module___149 *owner;
	int flags;
};

struct tcf_chain___33 {
	struct mutex filter_chain_lock;
	struct tcf_proto___33 *filter_chain;
	struct list_head list;
	struct tcf_block___33 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___33 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___26 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___33 *prog;
};

struct pneigh_entry___26;

struct neigh_hash_table___26;

struct neigh_table___26 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___35 *, __u32 *);
	bool (*key_eq)(const struct neighbour___26 *, const void *);
	int (*constructor)(struct neighbour___26 *);
	int (*pconstructor)(struct pneigh_entry___26 *);
	void (*pdestructor)(struct pneigh_entry___26 *);
	void (*proxy_redo)(struct sk_buff___34 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___35 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___26 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___33 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___26 *nht;
	struct pneigh_entry___26 **phash_buckets;
};

struct neigh_ops___26 {
	int family;
	void (*solicit)(struct neighbour___26 *, struct sk_buff___34 *);
	void (*error_report)(struct neighbour___26 *, struct sk_buff___34 *);
	int (*output)(struct neighbour___26 *, struct sk_buff___34 *);
	int (*connected_output)(struct neighbour___26 *, struct sk_buff___34 *);
};

struct pneigh_entry___26 {
	struct pneigh_entry___26 *next;
	possible_net_t___33 net;
	struct net_device___35 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___26 {
	struct neighbour___26 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___13 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___38 *, struct sock___27 *, struct sk_buff___34 *);
	int (*orig_input)(struct sk_buff___34 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___26 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___26 *ctarget;
	struct net___38 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___26 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___26 *rule;
	u32 table;
	int flags;
};

struct timewait_sock_ops___16;

struct proto___26 {
	void (*close)(struct sock___27 *, long int);
	int (*pre_connect)(struct sock___27 *, struct sockaddr *, int);
	int (*connect)(struct sock___27 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___27 *, int);
	struct sock___27 * (*accept)(struct sock___27 *, int, int *, bool);
	int (*ioctl)(struct sock___27 *, int, long unsigned int);
	int (*init)(struct sock___27 *);
	void (*destroy)(struct sock___27 *);
	void (*shutdown)(struct sock___27 *, int);
	int (*setsockopt)(struct sock___27 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___27 *, int, int, char *, int *);
	void (*keepalive)(struct sock___27 *, int);
	int (*compat_ioctl)(struct sock___27 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___27 *, struct msghdr___27 *, size_t);
	int (*recvmsg)(struct sock___27 *, struct msghdr___27 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___27 *, struct page___170 *, int, size_t, int);
	int (*bind)(struct sock___27 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___27 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___27 *, struct sk_buff___34 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___27 *);
	int (*hash)(struct sock___27 *);
	void (*unhash)(struct sock___27 *);
	void (*rehash)(struct sock___27 *);
	int (*get_port)(struct sock___27 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___27 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___27 *, int);
	bool (*sock_is_readable)(struct sock___27 *);
	void (*enter_memory_pressure)(struct sock___27 *);
	void (*leave_memory_pressure)(struct sock___27 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___16 *rsk_prot;
	struct timewait_sock_ops___16 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___149 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___27 *, int);
};

struct sock_reuseport___5 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany;
	unsigned int has_conns;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___33 *prog;
	struct sock___27 *socks[0];
};

struct request_sock_ops___16 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___27 *, struct request_sock___17 *);
	void (*send_ack)(const struct sock___27 *, struct sk_buff___34 *, struct request_sock___17 *);
	void (*send_reset)(const struct sock___27 *, struct sk_buff___34 *);
	void (*destructor)(struct request_sock___17 *);
	void (*syn_ack_timeout)(const struct request_sock___17 *);
};

struct timewait_sock_ops___16 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___27 *, struct sock___27 *, void *);
	void (*twsk_destructor)(struct sock___27 *);
};

struct ifmcaddr6___16 {
	struct in6_addr mca_addr;
	struct inet6_dev___16 *idev;
	struct ifmcaddr6___16 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct unix_sock___2 {
	struct sock___27 sk;
	struct unix_address *addr;
	struct path___165 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___27 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___27 peer_wq;
	wait_queue_entry_t peer_wake;
	struct scm_stat scm_stat;
	struct sk_buff___34 *oob_skb;
	long: 64;
};

struct aa_label___6;

struct aa_proxy___6 {
	struct kref count;
	struct aa_label___6 *label;
};

struct aa_profile___6;

struct aa_label___6 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	struct aa_proxy___6 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___6 *vec[0];
};

struct aa_ns___6;

struct aa_profile___6 {
	struct aa_policy base;
	struct aa_profile___6 *parent;
	struct aa_ns___6 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___2 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___165 *dents[9];
	struct rhashtable *data;
	struct aa_label___6 label;
};

struct lsm_network_audit___7 {
	int netif;
	const struct sock___27 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___7 {
	struct path___165 path;
	u16 cmd;
};

struct apparmor_audit_data___5 {
	int error;
	int type;
	const char *op;
	struct aa_label___6 *label;
	const char *name;
	const char *info;
	u32 request;
	u32 denied;
	union {
		struct {
			struct aa_label___6 *peer;
			union {
				struct {
					const char *target;
					kuid_t ouid;
				} fs;
				struct {
					int rlim;
					long unsigned int max;
				} rlim;
				struct {
					int signal;
					int unmappedsig;
				};
				struct {
					int type;
					int protocol;
					struct sock___27 *peer_sk;
					void *addr;
					int addrlen;
				} net;
			};
		};
		struct {
			struct aa_profile___6 *profile;
			const char *ns;
			long int pos;
		} iface;
		struct {
			const char *src_name;
			const char *type;
			const char *trans;
			const char *data;
			long unsigned int flags;
		} mnt;
	};
};

struct common_audit_data___8 {
	char type;
	union {
		struct path___165 path;
		struct dentry___165 *dentry;
		struct inode___165 *inode;
		struct lsm_network_audit___7 *net;
		int cap;
		int ipc_id;
		struct task_struct___172 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___7 *op;
		struct file___165 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data___5 *apparmor_audit_data;
	};
};

struct coredump_params___35 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___165 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct aa_file_ctx {
	spinlock_t lock;
	struct aa_label___6 *label;
	u32 allow;
};

struct aa_sk_ctx {
	struct aa_label___6 *label;
	struct aa_label___6 *peer;
	struct path___165 path;
};

struct aa_ns___6 {
	struct aa_policy base;
	struct aa_ns___6 *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile___6 *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___165 *dents[13];
};

struct aa_task_ctx___2 {
	struct aa_label___6 *nnp;
	struct aa_label___6 *onexec;
	struct aa_label___6 *previous;
	u64 token;
};

union aa_buffer {
	struct list_head list;
	char buffer[1];
};

struct aa_sfs_entry___3 {
	const char *name;
	struct dentry___163 *dentry;
	umode_t mode;
	enum aa_sfs_type v_type;
	union {
		bool boolean;
		char *string;
		long unsigned int u64;
		struct aa_sfs_entry___3 *files;
	} v;
	const struct file_operations___163 *file_ops;
};

struct dentry___166;

struct super_block___166;

struct module___150;

struct file_system_type___166 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___166 * (*mount)(struct file_system_type___166 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___166 *);
	struct module___150 *owner;
	struct file_system_type___166 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___166;

struct kiocb___166;

struct iov_iter___95;

struct poll_table_struct___107;

struct vm_area_struct___171;

struct inode___166;

struct file_lock___166;

struct page___171;

struct pipe_inode_info___59;

struct seq_file___144;

struct file_operations___166 {
	struct module___150 *owner;
	loff_t (*llseek)(struct file___166 *, loff_t, int);
	ssize_t (*read)(struct file___166 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___166 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___166 *, struct iov_iter___95 *);
	ssize_t (*write_iter)(struct kiocb___166 *, struct iov_iter___95 *);
	int (*iopoll)(struct kiocb___166 *, bool);
	int (*iterate)(struct file___166 *, struct dir_context *);
	int (*iterate_shared)(struct file___166 *, struct dir_context *);
	__poll_t (*poll)(struct file___166 *, struct poll_table_struct___107 *);
	long int (*unlocked_ioctl)(struct file___166 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___166 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___166 *, struct vm_area_struct___171 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___166 *, struct file___166 *);
	int (*flush)(struct file___166 *, fl_owner_t);
	int (*release)(struct inode___166 *, struct file___166 *);
	int (*fsync)(struct file___166 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___166 *, int);
	int (*lock)(struct file___166 *, int, struct file_lock___166 *);
	ssize_t (*sendpage)(struct file___166 *, struct page___171 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___166 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___166 *, long unsigned int);
	int (*flock)(struct file___166 *, int, struct file_lock___166 *);
	ssize_t (*splice_write)(struct pipe_inode_info___59 *, struct file___166 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___166 *, loff_t *, struct pipe_inode_info___59 *, size_t, unsigned int);
	int (*setlease)(struct file___166 *, long int, struct file_lock___166 **, void **);
	long int (*fallocate)(struct file___166 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___144 *, struct file___166 *);
	ssize_t (*copy_file_range)(struct file___166 *, loff_t, struct file___166 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___166 *, loff_t, struct file___166 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___166 *, loff_t, loff_t, int);
};

struct vmacache___171 {
	u64 seqnum;
	struct vm_area_struct___171 *vmas[4];
};

struct page_frag___171 {
	struct page___171 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___172;

struct pid___147;

struct files_struct___20;

struct nsproxy___156;

struct signal_struct___167;

struct bio_list___79;

struct backing_dev_info___76;

struct io_context___79;

struct css_set___115;

struct mem_cgroup___67;

struct request_queue___79;

struct vm_struct___150;

struct task_struct___173 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___173 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___172 *mm;
	struct mm_struct___172 *active_mm;
	struct vmacache___171 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___173 *real_parent;
	struct task_struct___173 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___173 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___147 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___20 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___156 *nsproxy;
	struct signal_struct___167 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___173 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___79 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___76 *backing_dev_info;
	struct io_context___79 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___115 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___59 *splice_pipe;
	struct page_frag___171 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___67 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___67 *active_memcg;
	struct request_queue___79 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___173 *oom_reaper_list;
	struct vm_struct___150 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___153;

struct kobj_type___153;

struct kernfs_node___153;

struct kobject___153 {
	const char *name;
	struct list_head entry;
	struct kobject___153 *parent;
	struct kset___153 *kset;
	struct kobj_type___153 *ktype;
	struct kernfs_node___153 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___150 {
	struct kobject___153 kobj;
	struct module___150 *mod;
	struct kobject___153 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___150 {
	struct module___150 *mod;
	struct latch_tree_node node;
};

struct module_layout___150 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___150 mtn;
};

struct module_attribute___150;

struct kernel_param___150;

struct module___150 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___150 mkobj;
	struct module_attribute___150 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___153 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___150 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___150 core_layout;
	struct module_layout___150 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___166;

struct dentry___166 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___166 *d_parent;
	struct qstr d_name;
	struct inode___166 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___166 *d_op;
	struct super_block___166 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___166;

struct address_space___166 {
	struct inode___166 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___166 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___166;

struct bdi_writeback___76;

struct cdev___27;

struct inode___166 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___166 *i_op;
	struct super_block___166 *i_sb;
	struct address_space___166 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___76 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___166 *i_fop;
		void (*free_inode)(struct inode___166 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___166 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___59 *i_pipe;
		struct cdev___27 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___166;

struct path___166;

struct dentry_operations___166 {
	int (*d_revalidate)(struct dentry___166 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___166 *, unsigned int);
	int (*d_hash)(const struct dentry___166 *, struct qstr *);
	int (*d_compare)(const struct dentry___166 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___166 *);
	int (*d_init)(struct dentry___166 *);
	void (*d_release)(struct dentry___166 *);
	void (*d_prune)(struct dentry___166 *);
	void (*d_iput)(struct dentry___166 *, struct inode___166 *);
	char * (*d_dname)(struct dentry___166 *, char *, int);
	struct vfsmount___166 * (*d_automount)(struct path___166 *);
	int (*d_manage)(const struct path___166 *, bool);
	struct dentry___166 * (*d_real)(struct dentry___166 *, const struct inode___166 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___166;

struct mem_dqinfo___166 {
	struct quota_format_type___166 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___166;

struct quota_info___166 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___166 *files[3];
	struct mem_dqinfo___166 info[3];
	const struct quota_format_ops___166 *ops[3];
};

struct rcuwait___167 {
	struct task_struct___173 *task;
};

struct percpu_rw_semaphore___167 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___167 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___166 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___167 rw_sem[3];
};

struct shrink_control___67;

struct shrinker___67 {
	long unsigned int (*count_objects)(struct shrinker___67 *, struct shrink_control___67 *);
	long unsigned int (*scan_objects)(struct shrinker___67 *, struct shrink_control___67 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___166;

struct dquot_operations___166;

struct quotactl_ops___166;

struct block_device___80;

struct super_block___166 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___166 *s_type;
	const struct super_operations___166 *s_op;
	const struct dquot_operations___166 *dq_op;
	const struct quotactl_ops___166 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___166 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___80 *s_bdev;
	struct backing_dev_info___76 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___166 s_dquot;
	struct sb_writers___166 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___166 *s_d_op;
	int cleancache_poolid;
	struct shrinker___67 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___166 {
	struct dentry___166 *mnt_root;
	struct super_block___166 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct path___166 {
	struct vfsmount___166 *mnt;
	struct dentry___166 *dentry;
};

struct pid_namespace___147;

struct upid___147 {
	int nr;
	struct pid_namespace___147 *ns;
};

struct pid_namespace___147 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___173 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___147 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___147 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___147 numbers[1];
};

typedef struct page___171 *pgtable_t___171;

struct page_pool___50;

struct dev_pagemap___162;

struct page___171 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___166 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___50 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___171 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___171 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___172 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___162 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___162;

struct vm_area_struct___171 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___171 *vm_next;
	struct vm_area_struct___171 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___172 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___162 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___166 *vm_file;
	struct file___166 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___13;

struct signal_struct___167 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___173 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___173 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___147 *pids[4];
	struct pid___147 *tty_old_pgrp;
	int leader;
	struct tty_struct___13 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___172 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___36;

struct core_state___171;

struct mm_struct___172 {
	struct {
		struct vm_area_struct___171 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___166 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___36 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___171 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___173 *owner;
		struct user_namespace___24 *user_ns;
		struct file___166 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___20 {
	unsigned int max_fds;
	struct file___166 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___20 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___20 *fdt;
	struct fdtable___20 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___166 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___39;

struct cgroup_namespace___115;

struct nsproxy___156 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___147 *pid_ns_for_children;
	struct net___39 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___115 *cgroup_ns;
};

struct bio___79;

struct bio_list___79 {
	struct bio___79 *head;
	struct bio___79 *tail;
};

struct cgroup_subsys_state___115;

struct bdi_writeback___76 {
	struct backing_dev_info___76 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___115 *memcg_css;
	struct cgroup_subsys_state___115 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___122;

struct backing_dev_info___76 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___76 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___122 *dev;
	char dev_name[64];
	struct device___122 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___166 *debug_dir;
};

struct io_cq___79;

struct io_context___79 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___79 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___115;

struct css_set___115 {
	struct cgroup_subsys_state___115 *subsys[14];
	refcount_t refcount;
	struct css_set___115 *dom_cset;
	struct cgroup___115 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___115 *mg_src_cgrp;
	struct cgroup___115 *mg_dst_cgrp;
	struct css_set___115 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___166;

struct pipe_buffer___59;

struct pipe_inode_info___59 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___171 *tmp_page;
	struct fasync_struct___166 *fasync_readers;
	struct fasync_struct___166 *fasync_writers;
	struct pipe_buffer___59 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___115;

struct cgroup_subsys_state___115 {
	struct cgroup___115 *cgroup;
	struct cgroup_subsys___115 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___115 *parent;
};

struct cgroup_file___115 {
	struct kernfs_node___153 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___67;

struct mem_cgroup_per_node___67;

struct mem_cgroup___67 {
	struct cgroup_subsys_state___115 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___115 events_file;
	struct cgroup_file___115 events_local_file;
	struct cgroup_file___115 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___67 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___173 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___67 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___79;

struct blk_integrity___79 {
	const struct blk_integrity_profile___79 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___79 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___79 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___79;

struct elevator_queue___79;

struct blk_mq_ops___76;

struct blk_mq_hw_ctx___76;

struct gendisk___79;

struct blkcg_gq___76;

struct blk_mq_tag_set___76;

struct request_queue___79 {
	struct request___79 *last_merge;
	struct elevator_queue___79 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___76 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___76 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___79 *disk;
	struct kobject___153 kobj;
	struct kobject___153 *mq_kobj;
	struct blk_integrity___79 integrity;
	struct device___122 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___76 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___76 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___79 bio_split;
	struct dentry___166 *debugfs_dir;
	struct dentry___166 *sched_debugfs_dir;
	struct dentry___166 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___150 {
	struct vm_struct___150 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___171 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___67 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___67 *memcg;
};

struct page_pool_params___50 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___122 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___50 {
	u32 count;
	struct page___171 *cache[128];
};

struct page_pool___50 {
	struct page_pool_params___50 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___171 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___50 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___162;

struct dev_pagemap___162 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___162 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___147 {
	rwlock_t lock;
	struct pid___147 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___166 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___166 f_path;
	struct inode___166 *f_inode;
	const struct file_operations___166 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___147 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___166 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___162;

struct vm_operations_struct___162 {
	void (*open)(struct vm_area_struct___171 *);
	void (*close)(struct vm_area_struct___171 *);
	int (*may_split)(struct vm_area_struct___171 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___171 *);
	int (*mprotect)(struct vm_area_struct___171 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___162 *);
	vm_fault_t (*huge_fault)(struct vm_fault___162 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___162 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___171 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___162 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___162 *);
	int (*access)(struct vm_area_struct___171 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___171 *);
	int (*set_policy)(struct vm_area_struct___171 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___171 *, long unsigned int);
	struct page___171 * (*find_special_page)(struct vm_area_struct___171 *, long unsigned int);
};

struct core_thread___171 {
	struct task_struct___173 *task;
	struct core_thread___171 *next;
};

struct core_state___171 {
	atomic_t nr_threads;
	struct core_thread___171 dumper;
	struct completion startup;
};

struct linux_binprm___37;

struct coredump_params___36;

struct linux_binfmt___36 {
	struct list_head lh;
	struct module___150 *module;
	int (*load_binary)(struct linux_binprm___37 *);
	int (*load_shlib)(struct file___166 *);
	int (*core_dump)(struct coredump_params___36 *);
	long unsigned int min_coredump;
};

struct vm_fault___162 {
	const struct {
		struct vm_area_struct___171 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___171 *cow_page;
	struct page___171 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___171 prealloc_pte;
};

struct pglist_data___74;

struct lruvec___74 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___74 *pgdat;
};

struct zone___74 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___74 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___74 {
	struct zone___74 *zone;
	int zone_idx;
};

struct zonelist___74 {
	struct zoneref___74 _zonerefs[321];
};

struct pglist_data___74 {
	struct zone___74 node_zones[5];
	struct zonelist___74 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___173 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___173 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___74 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___115 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___173 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___34;

struct cgroup_bpf___34 {
	struct bpf_prog_array___34 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___34 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___115;

struct cgroup_rstat_cpu___115;

struct cgroup___115 {
	struct cgroup_subsys_state___115 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___153 *kn;
	struct cgroup_file___115 procs_file;
	struct cgroup_file___115 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___115 *subsys[14];
	struct cgroup_root___115 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___115 *dom_cgrp;
	struct cgroup___115 *old_dom_cgrp;
	struct cgroup_rstat_cpu___115 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___115 psi;
	struct cgroup_bpf___34 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___14;

struct tty_operations___14;

struct tty_ldisc___13;

struct tty_port___14;

struct tty_struct___13 {
	int magic;
	struct kref kref;
	struct device___122 *dev;
	struct tty_driver___14 *driver;
	const struct tty_operations___14 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___13 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___147 *pgrp;
		struct pid___147 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___13 *link;
	struct fasync_struct___166 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___14 *port;
};

struct io_cq___79 {
	struct request_queue___79 *q;
	struct io_context___79 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___166 {
	struct file___166 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___166 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___166 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___166 *ia_file;
};

struct dquot___166 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___166 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___166 {
	int qf_fmt_id;
	const struct quota_format_ops___166 *qf_ops;
	struct module___150 *qf_owner;
	struct quota_format_type___166 *qf_next;
};

struct quota_format_ops___166 {
	int (*check_quota_file)(struct super_block___166 *, int);
	int (*read_file_info)(struct super_block___166 *, int);
	int (*write_file_info)(struct super_block___166 *, int);
	int (*free_file_info)(struct super_block___166 *, int);
	int (*read_dqblk)(struct dquot___166 *);
	int (*commit_dqblk)(struct dquot___166 *);
	int (*release_dqblk)(struct dquot___166 *);
	int (*get_next_id)(struct super_block___166 *, struct kqid *);
};

struct dquot_operations___166 {
	int (*write_dquot)(struct dquot___166 *);
	struct dquot___166 * (*alloc_dquot)(struct super_block___166 *, int);
	void (*destroy_dquot)(struct dquot___166 *);
	int (*acquire_dquot)(struct dquot___166 *);
	int (*release_dquot)(struct dquot___166 *);
	int (*mark_dirty)(struct dquot___166 *);
	int (*write_info)(struct super_block___166 *, int);
	qsize_t * (*get_reserved_space)(struct inode___166 *);
	int (*get_projid)(struct inode___166 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___166 *, qsize_t *);
	int (*get_next_id)(struct super_block___166 *, struct kqid *);
};

struct quotactl_ops___166 {
	int (*quota_on)(struct super_block___166 *, int, int, const struct path___166 *);
	int (*quota_off)(struct super_block___166 *, int);
	int (*quota_enable)(struct super_block___166 *, unsigned int);
	int (*quota_disable)(struct super_block___166 *, unsigned int);
	int (*quota_sync)(struct super_block___166 *, int);
	int (*set_info)(struct super_block___166 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___166 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___166 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___166 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___166 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___166 *, unsigned int);
};

struct writeback_control___76;

struct address_space_operations___166 {
	int (*writepage)(struct page___171 *, struct writeback_control___76 *);
	int (*readpage)(struct file___166 *, struct page___171 *);
	int (*writepages)(struct address_space___166 *, struct writeback_control___76 *);
	int (*set_page_dirty)(struct page___171 *);
	int (*readpages)(struct file___166 *, struct address_space___166 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___166 *, struct address_space___166 *, loff_t, unsigned int, unsigned int, struct page___171 **, void **);
	int (*write_end)(struct file___166 *, struct address_space___166 *, loff_t, unsigned int, unsigned int, struct page___171 *, void *);
	sector_t (*bmap)(struct address_space___166 *, sector_t);
	void (*invalidatepage)(struct page___171 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___171 *, gfp_t);
	void (*freepage)(struct page___171 *);
	ssize_t (*direct_IO)(struct kiocb___166 *, struct iov_iter___95 *);
	int (*migratepage)(struct address_space___166 *, struct page___171 *, struct page___171 *, enum migrate_mode);
	bool (*isolate_page)(struct page___171 *, isolate_mode_t);
	void (*putback_page)(struct page___171 *);
	int (*launder_page)(struct page___171 *);
	int (*is_partially_uptodate)(struct page___171 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___171 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___166 *, struct page___171 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___166 *, sector_t *);
	void (*swap_deactivate)(struct file___166 *);
};

struct writeback_control___76 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___76 *wb;
	struct inode___166 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___93;

struct iov_iter___95 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___93 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___59 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___27 {
	struct kobject___153 kobj;
	struct module___150 *owner;
	const struct file_operations___166 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___166 {
	struct dentry___166 * (*lookup)(struct inode___166 *, struct dentry___166 *, unsigned int);
	const char * (*get_link)(struct dentry___166 *, struct inode___166 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___166 *, int);
	struct posix_acl * (*get_acl)(struct inode___166 *, int, bool);
	int (*readlink)(struct dentry___166 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___166 *, struct dentry___166 *, umode_t, bool);
	int (*link)(struct dentry___166 *, struct inode___166 *, struct dentry___166 *);
	int (*unlink)(struct inode___166 *, struct dentry___166 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___166 *, struct dentry___166 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___166 *, struct dentry___166 *, umode_t);
	int (*rmdir)(struct inode___166 *, struct dentry___166 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___166 *, struct dentry___166 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___166 *, struct dentry___166 *, struct inode___166 *, struct dentry___166 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___166 *, struct iattr___166 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___166 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___166 *, char *, size_t);
	int (*fiemap)(struct inode___166 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___166 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___166 *, struct dentry___166 *, struct file___166 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___166 *, struct dentry___166 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___166 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___166 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___166 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___166 {
	void (*fl_copy_lock)(struct file_lock___166 *, struct file_lock___166 *);
	void (*fl_release_private)(struct file_lock___166 *);
};

struct lock_manager_operations___166;

struct file_lock___166 {
	struct file_lock___166 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___166 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___166 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___166 *fl_ops;
	const struct lock_manager_operations___166 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___166 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___166 *);
	int (*lm_grant)(struct file_lock___166 *, int);
	bool (*lm_break)(struct file_lock___166 *);
	int (*lm_change)(struct file_lock___166 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___166 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___166 *);
};

struct fasync_struct___166 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___166 *fa_next;
	struct file___166 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___166 {
	struct inode___166 * (*alloc_inode)(struct super_block___166 *);
	void (*destroy_inode)(struct inode___166 *);
	void (*free_inode)(struct inode___166 *);
	void (*dirty_inode)(struct inode___166 *, int);
	int (*write_inode)(struct inode___166 *, struct writeback_control___76 *);
	int (*drop_inode)(struct inode___166 *);
	void (*evict_inode)(struct inode___166 *);
	void (*put_super)(struct super_block___166 *);
	int (*sync_fs)(struct super_block___166 *, int);
	int (*freeze_super)(struct super_block___166 *);
	int (*freeze_fs)(struct super_block___166 *);
	int (*thaw_super)(struct super_block___166 *);
	int (*unfreeze_fs)(struct super_block___166 *);
	int (*statfs)(struct dentry___166 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___166 *, int *, char *);
	void (*umount_begin)(struct super_block___166 *);
	int (*show_options)(struct seq_file___144 *, struct dentry___166 *);
	int (*show_devname)(struct seq_file___144 *, struct dentry___166 *);
	int (*show_path)(struct seq_file___144 *, struct dentry___166 *);
	int (*show_stats)(struct seq_file___144 *, struct dentry___166 *);
	ssize_t (*quota_read)(struct super_block___166 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___166 *, int, const char *, size_t, loff_t);
	struct dquot___166 ** (*get_dquots)(struct inode___166 *);
	long int (*nr_cached_objects)(struct super_block___166 *, struct shrink_control___67 *);
	long int (*free_cached_objects)(struct super_block___166 *, struct shrink_control___67 *);
	struct file___166 * (*real_loop)(struct file___166 *);
};

struct wakeup_source___122;

struct dev_pm_info___122 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___122 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___122 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___122;

struct bus_type___122;

struct device_driver___122;

struct dev_pm_domain___122;

struct fwnode_handle___122;

struct class___122;

struct attribute_group___153;

struct device___122 {
	struct kobject___153 kobj;
	struct device___122 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___122 *type;
	struct bus_type___122 *bus;
	struct device_driver___122 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___122 power;
	struct dev_pm_domain___122 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___122 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___122 *class;
	const struct attribute_group___153 **groups;
	void (*release)(struct device___122 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___80 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___166 *bd_inode;
	struct super_block___166 *bd_super;
	void *bd_claiming;
	struct device___122 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___153 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___79 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___166 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___109)(struct file___166 *, wait_queue_head_t *, struct poll_table_struct___107 *);

struct poll_table_struct___107 {
	poll_queue_proc___109 _qproc;
	__poll_t _key;
};

struct seq_operations___144;

struct seq_file___144 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___144 *op;
	int poll_event;
	const struct file___166 *file;
	void *private;
};

typedef void bio_end_io_t___79(struct bio___79 *);

struct bio_vec___93 {
	struct page___171 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___79;

struct bio___79 {
	struct bio___79 *bi_next;
	struct block_device___80 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___79 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___76 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___79 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___93 *bi_io_vec;
	struct bio_set___79 *bi_pool;
	struct bio_vec___93 bi_inline_vecs[0];
};

struct kernfs_root___153;

struct kernfs_elem_dir___153 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___153 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___153;

struct kernfs_root___153 {
	struct kernfs_node___153 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___153 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___153 {
	struct kernfs_node___153 *target_kn;
};

struct kernfs_ops___153;

struct kernfs_elem_attr___153 {
	const struct kernfs_ops___153 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___153 *notify_next;
};

struct kernfs_node___153 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___153 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___153 dir;
		struct kernfs_elem_symlink___153 symlink;
		struct kernfs_elem_attr___153 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___153;

struct kernfs_ops___153 {
	int (*open)(struct kernfs_open_file___153 *);
	void (*release)(struct kernfs_open_file___153 *);
	int (*seq_show)(struct seq_file___144 *, void *);
	void * (*seq_start)(struct seq_file___144 *, loff_t *);
	void * (*seq_next)(struct seq_file___144 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___144 *, void *);
	ssize_t (*read)(struct kernfs_open_file___153 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___153 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___153 *, struct poll_table_struct___107 *);
	int (*mmap)(struct kernfs_open_file___153 *, struct vm_area_struct___171 *);
};

struct kernfs_syscall_ops___153 {
	int (*show_options)(struct seq_file___144 *, struct kernfs_root___153 *);
	int (*mkdir)(struct kernfs_node___153 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___153 *);
	int (*rename)(struct kernfs_node___153 *, struct kernfs_node___153 *, const char *);
	int (*show_path)(struct seq_file___144 *, struct kernfs_node___153 *, struct kernfs_root___153 *);
};

struct kernfs_open_file___153 {
	struct kernfs_node___153 *kn;
	struct file___166 *file;
	struct seq_file___144 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___162 *vm_ops;
};

struct sock___28;

struct kobj_ns_type_operations___27 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___28 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___39 *net;
} possible_net_t___34;

struct proto___27;

struct sock_common___27 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___27 *skc_prot;
	possible_net_t___34 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___28 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___35;

struct sk_buff_head___34 {
	struct sk_buff___35 *next;
	struct sk_buff___35 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___27 {
	struct cgroup___115 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___27;

struct socket_wq___28;

struct dst_entry___27;

struct socket___28;

struct net_device___36;

struct sock___28 {
	struct sock_common___27 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___34 sk_error_queue;
	struct sk_buff___35 *sk_rx_skb_cache;
	struct sk_buff_head___34 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___35 *head;
		struct sk_buff___35 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___27 *sk_filter;
	union {
		struct socket_wq___28 *sk_wq;
		struct socket_wq___28 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___27 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___27 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___35 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___35 *sk_tx_skb_cache;
	struct sk_buff_head___34 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___171 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___27 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___147 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___28 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___27 sk_cgrp_data;
	struct mem_cgroup___67 *sk_memcg;
	void (*sk_state_change)(struct sock___28 *);
	void (*sk_data_ready)(struct sock___28 *);
	void (*sk_write_space)(struct sock___28 *);
	void (*sk_error_report)(struct sock___28 *);
	int (*sk_backlog_rcv)(struct sock___28 *, struct sk_buff___35 *);
	struct sk_buff___35 * (*sk_validate_xmit_skb)(struct sock___28 *, struct net_device___36 *, struct sk_buff___35 *);
	void (*sk_destruct)(struct sock___28 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___153;

struct attribute_group___153 {
	const char *name;
	umode_t (*is_visible)(struct kobject___153 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___153 *, struct bin_attribute___153 *, int);
	struct attribute **attrs;
	struct bin_attribute___153 **bin_attrs;
};

struct bin_attribute___153 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___166 * (*f_mapping)();
	ssize_t (*read)(struct file___166 *, struct kobject___153 *, struct bin_attribute___153 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___166 *, struct kobject___153 *, struct bin_attribute___153 *, char *, loff_t, size_t);
	int (*mmap)(struct file___166 *, struct kobject___153 *, struct bin_attribute___153 *, struct vm_area_struct___171 *);
};

struct sysfs_ops___153 {
	ssize_t (*show)(struct kobject___153 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___153 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___153;

struct kset___153 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___153 kobj;
	const struct kset_uevent_ops___153 *uevent_ops;
};

struct kobj_type___153 {
	void (*release)(struct kobject___153 *);
	const struct sysfs_ops___153 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___153 **default_groups;
	const struct kobj_ns_type_operations___27 * (*child_ns_type)(struct kobject___153 *);
	const void * (*namespace)(struct kobject___153 *);
	void (*get_ownership)(struct kobject___153 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___153 {
	int (* const filter)(struct kset___153 *, struct kobject___153 *);
	const char * (* const name)(struct kset___153 *, struct kobject___153 *);
	int (* const uevent)(struct kset___153 *, struct kobject___153 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___122 {
	int (*prepare)(struct device___122 *);
	void (*complete)(struct device___122 *);
	int (*suspend)(struct device___122 *);
	int (*resume)(struct device___122 *);
	int (*freeze)(struct device___122 *);
	int (*thaw)(struct device___122 *);
	int (*poweroff)(struct device___122 *);
	int (*restore)(struct device___122 *);
	int (*suspend_late)(struct device___122 *);
	int (*resume_early)(struct device___122 *);
	int (*freeze_late)(struct device___122 *);
	int (*thaw_early)(struct device___122 *);
	int (*poweroff_late)(struct device___122 *);
	int (*restore_early)(struct device___122 *);
	int (*suspend_noirq)(struct device___122 *);
	int (*resume_noirq)(struct device___122 *);
	int (*freeze_noirq)(struct device___122 *);
	int (*thaw_noirq)(struct device___122 *);
	int (*poweroff_noirq)(struct device___122 *);
	int (*restore_noirq)(struct device___122 *);
	int (*runtime_suspend)(struct device___122 *);
	int (*runtime_resume)(struct device___122 *);
	int (*runtime_idle)(struct device___122 *);
};

struct wakeup_source___122 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___122 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___122 {
	struct dev_pm_ops___122 ops;
	int (*start)(struct device___122 *);
	void (*detach)(struct device___122 *, bool);
	int (*activate)(struct device___122 *);
	void (*sync)(struct device___122 *);
	void (*dismiss)(struct device___122 *);
};

struct bus_type___122 {
	const char *name;
	const char *dev_name;
	struct device___122 *dev_root;
	const struct attribute_group___153 **bus_groups;
	const struct attribute_group___153 **dev_groups;
	const struct attribute_group___153 **drv_groups;
	int (*match)(struct device___122 *, struct device_driver___122 *);
	int (*uevent)(struct device___122 *, struct kobj_uevent_env *);
	int (*probe)(struct device___122 *);
	void (*sync_state)(struct device___122 *);
	void (*remove)(struct device___122 *);
	void (*shutdown)(struct device___122 *);
	int (*online)(struct device___122 *);
	int (*offline)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	int (*num_vf)(struct device___122 *);
	int (*dma_configure)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___122 {
	const char *name;
	struct bus_type___122 *bus;
	struct module___150 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___122 *);
	void (*sync_state)(struct device___122 *);
	int (*remove)(struct device___122 *);
	void (*shutdown)(struct device___122 *);
	int (*suspend)(struct device___122 *, pm_message_t);
	int (*resume)(struct device___122 *);
	const struct attribute_group___153 **groups;
	const struct attribute_group___153 **dev_groups;
	const struct dev_pm_ops___122 *pm;
	void (*coredump)(struct device___122 *);
	struct driver_private *p;
};

struct device_type___122 {
	const char *name;
	const struct attribute_group___153 **groups;
	int (*uevent)(struct device___122 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___122 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___122 *);
	const struct dev_pm_ops___122 *pm;
};

struct class___122 {
	const char *name;
	struct module___150 *owner;
	const struct attribute_group___153 **class_groups;
	const struct attribute_group___153 **dev_groups;
	struct kobject___153 *dev_kobj;
	int (*dev_uevent)(struct device___122 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___122 *, umode_t *);
	void (*class_release)(struct class___122 *);
	void (*dev_release)(struct device___122 *);
	int (*shutdown_pre)(struct device___122 *);
	const struct kobj_ns_type_operations___27 *ns_type;
	const void * (*namespace)(struct device___122 *);
	void (*get_ownership)(struct device___122 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___122 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___122;

struct fwnode_handle___122 {
	struct fwnode_handle___122 *secondary;
	const struct fwnode_operations___122 *ops;
	struct device___122 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___144 {
	void * (*start)(struct seq_file___144 *, loff_t *);
	void (*stop)(struct seq_file___144 *, void *);
	void * (*next)(struct seq_file___144 *, void *, loff_t *);
	int (*show)(struct seq_file___144 *, void *);
};

struct tty_operations___14 {
	struct tty_struct___13 * (*lookup)(struct tty_driver___14 *, struct file___166 *, int);
	int (*install)(struct tty_driver___14 *, struct tty_struct___13 *);
	void (*remove)(struct tty_driver___14 *, struct tty_struct___13 *);
	int (*open)(struct tty_struct___13 *, struct file___166 *);
	void (*close)(struct tty_struct___13 *, struct file___166 *);
	void (*shutdown)(struct tty_struct___13 *);
	void (*cleanup)(struct tty_struct___13 *);
	int (*write)(struct tty_struct___13 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___13 *, unsigned char);
	void (*flush_chars)(struct tty_struct___13 *);
	unsigned int (*write_room)(struct tty_struct___13 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___13 *);
	int (*ioctl)(struct tty_struct___13 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___13 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___13 *, struct ktermios *);
	void (*throttle)(struct tty_struct___13 *);
	void (*unthrottle)(struct tty_struct___13 *);
	void (*stop)(struct tty_struct___13 *);
	void (*start)(struct tty_struct___13 *);
	void (*hangup)(struct tty_struct___13 *);
	int (*break_ctl)(struct tty_struct___13 *, int);
	void (*flush_buffer)(struct tty_struct___13 *);
	void (*set_ldisc)(struct tty_struct___13 *);
	void (*wait_until_sent)(struct tty_struct___13 *, int);
	void (*send_xchar)(struct tty_struct___13 *, char);
	int (*tiocmget)(struct tty_struct___13 *);
	int (*tiocmset)(struct tty_struct___13 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___13 *, struct winsize *);
	int (*get_icount)(struct tty_struct___13 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___13 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___13 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___13 *, struct seq_file___144 *);
	int (*poll_init)(struct tty_driver___14 *, int, char *);
	int (*poll_get_char)(struct tty_driver___14 *, int);
	void (*poll_put_char)(struct tty_driver___14 *, int, char);
	int (*proc_show)(struct seq_file___144 *, void *);
};

struct tty_driver___14 {
	int magic;
	struct kref kref;
	struct cdev___27 **cdevs;
	struct module___150 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___14 *other;
	struct tty_struct___13 **ttys;
	struct tty_port___14 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___14 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___13;

struct tty_port_client_operations___13;

struct tty_port___14 {
	struct tty_bufhead buf;
	struct tty_struct___13 *tty;
	struct tty_struct___13 *itty;
	const struct tty_port_operations___13 *ops;
	const struct tty_port_client_operations___13 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___13 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___13 *);
	void (*close)(struct tty_struct___13 *);
	void (*flush_buffer)(struct tty_struct___13 *);
	ssize_t (*read)(struct tty_struct___13 *, struct file___166 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___13 *, struct file___166 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___13 *, struct file___166 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___13 *, struct file___166 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___13 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___13 *, struct file___166 *, struct poll_table_struct___107 *);
	int (*hangup)(struct tty_struct___13 *);
	void (*receive_buf)(struct tty_struct___13 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___13 *);
	void (*dcd_change)(struct tty_struct___13 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___13 *, const unsigned char *, const char *, int);
	struct module___150 *owner;
};

struct tty_ldisc___13 {
	struct tty_ldisc_ops___13 *ops;
	struct tty_struct___13 *tty;
};

struct tty_port_operations___13 {
	int (*carrier_raised)(struct tty_port___14 *);
	void (*dtr_rts)(struct tty_port___14 *, int);
	void (*shutdown)(struct tty_port___14 *);
	int (*activate)(struct tty_port___14 *, struct tty_struct___13 *);
	void (*destruct)(struct tty_port___14 *);
};

struct tty_port_client_operations___13 {
	int (*receive_buf)(struct tty_port___14 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___14 *);
};

struct tty_file_private___2 {
	struct tty_struct___13 *tty;
	struct file___166 *file;
	struct list_head list;
};

struct msghdr___28 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___95 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___166 *msg_iocb;
};

struct fwnode_reference_args___122;

struct fwnode_endpoint___122;

struct fwnode_operations___122 {
	struct fwnode_handle___122 * (*get)(struct fwnode_handle___122 *);
	void (*put)(struct fwnode_handle___122 *);
	bool (*device_is_available)(const struct fwnode_handle___122 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___122 *, const struct device___122 *);
	bool (*property_present)(const struct fwnode_handle___122 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___122 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___122 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___122 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*get_parent)(const struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*get_next_child_node)(const struct fwnode_handle___122 *, struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*get_named_child_node)(const struct fwnode_handle___122 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___122 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___122 *);
	struct fwnode_handle___122 * (*graph_get_next_endpoint)(const struct fwnode_handle___122 *, struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*graph_get_remote_endpoint)(const struct fwnode_handle___122 *);
	struct fwnode_handle___122 * (*graph_get_port_parent)(struct fwnode_handle___122 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___122 *, struct fwnode_endpoint___122 *);
	int (*add_links)(struct fwnode_handle___122 *);
};

struct fwnode_endpoint___122 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___122 *local_fwnode;
};

struct fwnode_reference_args___122 {
	struct fwnode_handle___122 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct sk_buff___35 {
	union {
		struct {
			struct sk_buff___35 *next;
			struct sk_buff___35 *prev;
			union {
				struct net_device___36 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___28 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___35 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___39;

struct fqdir___39 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___39 *f;
	struct net___39 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___39;

struct inet_frags___39 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___39 *, const void *);
	void (*destructor)(struct inet_frag_queue___39 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___14;

struct fib_rules_ops___27;

struct fib_notifier_ops___27;

struct netns_ipv4___39 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___14 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___27 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___28 *fibnl;
	struct sock___28 **icmp_sk;
	struct sock___28 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___28 **tcp_sk;
	struct fqdir___39 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___27 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___27 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___27 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___27;

struct dst_ops___39 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___39 *);
	struct dst_entry___27 * (*check)(struct dst_entry___27 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___27 *);
	unsigned int (*mtu)(const struct dst_entry___27 *);
	u32 * (*cow_metrics)(struct dst_entry___27 *, long unsigned int);
	void (*destroy)(struct dst_entry___27 *);
	void (*ifdown)(struct dst_entry___27 *, struct net_device___36 *, int);
	struct dst_entry___27 * (*negative_advice)(struct dst_entry___27 *);
	void (*link_failure)(struct sk_buff___35 *);
	void (*update_pmtu)(struct dst_entry___27 *, struct sock___28 *, struct sk_buff___35 *, u32, bool);
	void (*redirect)(struct dst_entry___27 *, struct sock___28 *, struct sk_buff___35 *);
	int (*local_out)(struct net___39 *, struct sock___28 *, struct sk_buff___35 *);
	struct neighbour___27 * (*neigh_lookup)(const struct dst_entry___27 *, struct sk_buff___35 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___27 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___39 {
	struct dst_ops___39 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___39 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___27 *fib6_rules_ops;
	struct sock___28 **icmp_sk;
	struct sock___28 *ndisc_sk;
	struct sock___28 *tcp_sk;
	struct sock___28 *igmp_sk;
	struct sock___28 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___27 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___27 *notifier_ops;
	struct fib_notifier_ops___27 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___39 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___39 *fqdir;
};

struct netns_sctp___27 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___28 *ctl_sock;
	struct sock___28 *udp4_sock;
	struct sock___28 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___34;

struct netns_bpf___34 {
	struct bpf_prog_array___34 *run_array[2];
	struct bpf_prog___34 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___39 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___28 *nlsk;
	struct sock___28 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___39 xfrm4_dst_ops;
	struct dst_ops___39 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___39 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___28 *rtnl;
	struct sock___28 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___36 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___39 ipv4;
	struct netns_ipv6___39 ipv6;
	struct netns_ieee802154_lowpan___39 ieee802154_lowpan;
	struct netns_sctp___27 sctp;
	struct netns_nf___3 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___34 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___34 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___39 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___28 *crypto_nlsk;
	struct sock___28 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___39 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___35 *fragments_tail;
	struct sk_buff___35 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___39 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___14 {
	struct ip_ra_chain___14 *next;
	struct sock___28 *sk;
	union {
		void (*destructor)(struct sock___28 *);
		struct sock___28 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___27;

struct fib_lookup_arg___27;

struct fib_rules_ops___27 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___27 *, struct flowi *, int, struct fib_lookup_arg___27 *);
	bool (*suppress)(struct fib_rule___27 *, int, struct fib_lookup_arg___27 *);
	int (*match)(struct fib_rule___27 *, struct flowi *, int);
	int (*configure)(struct fib_rule___27 *, struct sk_buff___35 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___27 *);
	int (*compare)(struct fib_rule___27 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___27 *, struct sk_buff___35 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___27 *);
	void (*flush_cache)(struct fib_rules_ops___27 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___150 *owner;
	struct net___39 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___27 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___39 *);
	int (*fib_dump)(struct net___39 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___150 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___14;

struct dst_entry___27 {
	struct net_device___36 *dev;
	struct dst_ops___39 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___35 *);
	int (*output)(struct net___39 *, struct sock___28 *, struct sk_buff___35 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___14 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___34(struct sk_buff___35 **);

struct bpf_xdp_entity___34 {
	struct bpf_prog___34 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___34;

struct net_device_ops___34;

struct ethtool_ops___12;

struct l3mdev_ops___27;

struct ndisc_ops___17;

struct xfrmdev_ops___34;

struct header_ops___34;

struct inet6_dev___17;

struct netdev_rx_queue___34;

struct mini_Qdisc___34;

struct netdev_queue___34;

struct Qdisc___34;

struct rtnl_link_ops___34;

struct dcbnl_rtnl_ops___34;

struct net_device___36 {
	char name[16];
	struct netdev_name_node___34 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___34 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___12 *ethtool_ops;
	const struct l3mdev_ops___27 *l3mdev_ops;
	const struct ndisc_ops___17 *ndisc_ops;
	const struct xfrmdev_ops___34 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___34 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___153 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___17 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___34 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___34 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___34 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___34 *miniq_ingress;
	struct netdev_queue___34 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___34 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___34 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___34 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___34 = 0,
		NETREG_REGISTERED___34 = 1,
		NETREG_UNREGISTERING___34 = 2,
		NETREG_UNREGISTERED___34 = 3,
		NETREG_RELEASED___34 = 4,
		NETREG_DUMMY___34 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___34 = 0,
		RTNL_LINK_INITIALIZING___34 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___36 *);
	struct netpoll_info *npinfo;
	possible_net_t___34 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___122 dev;
	const struct attribute_group___153 *sysfs_groups[4];
	const struct attribute_group___153 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___34 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___34 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___34 xdp_state[3];
	long: 64;
};

struct neigh_table___27;

struct neigh_parms___27;

struct neigh_ops___27;

struct neighbour___27 {
	struct neighbour___27 *next;
	struct neigh_table___27 *tbl;
	struct neigh_parms___27 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___34 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___27 *, struct sk_buff___35 *);
	const struct neigh_ops___27 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___36 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___34 {
	struct bpf_prog___34 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___34 {
	struct callback_head rcu;
	struct bpf_prog_array_item___34 items[0];
};

struct bpf_prog_aux___36;

struct bpf_prog___34 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___36 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___162 {
	void (*page_free)(struct page___171 *);
	void (*kill)(struct dev_pagemap___162 *);
	void (*cleanup)(struct dev_pagemap___162 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___162 *);
};

struct kernel_param_ops___150 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___150 *);
	int (*get)(char *, const struct kernel_param___150 *);
	void (*free)(void *);
};

struct kparam_array___150;

struct kernel_param___150 {
	const char *name;
	struct module___150 *mod;
	const struct kernel_param_ops___150 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___150 *arr;
	};
};

struct kparam_array___150 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___150 *ops;
	void *elem;
};

struct module_attribute___150 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___150 *, struct module_kobject___150 *, char *);
	ssize_t (*store)(struct module_attribute___150 *, struct module_kobject___150 *, const char *, size_t);
	void (*setup)(struct module___150 *, const char *);
	int (*test)(struct module___150 *);
	void (*free)(struct module___150 *);
};

struct cgroup_namespace___115 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___115 *root_cset;
};

struct socket_wq___28 {
	wait_queue_head_t wait;
	struct fasync_struct___166 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___28;

struct socket___28 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___166 *file;
	struct sock___28 *sk;
	const struct proto_ops___28 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___28 wq;
};

typedef int (*sk_read_actor_t___27)(read_descriptor_t *, struct sk_buff___35 *, unsigned int, size_t);

struct proto_ops___28 {
	int family;
	struct module___150 *owner;
	int (*release)(struct socket___28 *);
	int (*bind)(struct socket___28 *, struct sockaddr *, int);
	int (*connect)(struct socket___28 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___28 *, struct socket___28 *);
	int (*accept)(struct socket___28 *, struct socket___28 *, int, bool);
	int (*getname)(struct socket___28 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___166 *, struct socket___28 *, struct poll_table_struct___107 *);
	int (*ioctl)(struct socket___28 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___28 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___28 *, void *, bool, bool);
	int (*listen)(struct socket___28 *, int);
	int (*shutdown)(struct socket___28 *, int);
	int (*setsockopt)(struct socket___28 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___28 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___144 *, struct socket___28 *);
	int (*sendmsg)(struct socket___28 *, struct msghdr___28 *, size_t);
	int (*recvmsg)(struct socket___28 *, struct msghdr___28 *, size_t, int);
	int (*mmap)(struct file___166 *, struct socket___28 *, struct vm_area_struct___171 *);
	ssize_t (*sendpage)(struct socket___28 *, struct page___171 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___28 *, loff_t *, struct pipe_inode_info___59 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___28 *, int);
	int (*peek_len)(struct socket___28 *);
	int (*read_sock)(struct sock___28 *, read_descriptor_t *, sk_read_actor_t___27);
	int (*sendpage_locked)(struct sock___28 *, struct page___171 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___28 *, struct msghdr___28 *, size_t);
	int (*set_rcvlowat)(struct sock___28 *, int);
};

struct pipe_buf_operations___59;

struct pipe_buffer___59 {
	struct page___171 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___59 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___59 {
	int (*confirm)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
	void (*release)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
	bool (*try_steal)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
	bool (*get)(struct pipe_inode_info___59 *, struct pipe_buffer___59 *);
};

struct dcbnl_rtnl_ops___34 {
	int (*ieee_getets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___36 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___36 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___36 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___36 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___36 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___36 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___36 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___36 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___36 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___36 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___36 *);
	u8 (*setstate)(struct net_device___36 *, u8);
	void (*getpermhwaddr)(struct net_device___36 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___36 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___36 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___36 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___36 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___36 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___36 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___36 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___36 *, int, u8 *);
	void (*setpfccfg)(struct net_device___36 *, int, u8);
	void (*getpfccfg)(struct net_device___36 *, int, u8 *);
	u8 (*setall)(struct net_device___36 *);
	u8 (*getcap)(struct net_device___36 *, int, u8 *);
	int (*getnumtcs)(struct net_device___36 *, int, u8 *);
	int (*setnumtcs)(struct net_device___36 *, int, u8);
	u8 (*getpfcstate)(struct net_device___36 *);
	void (*setpfcstate)(struct net_device___36 *, u8);
	void (*getbcncfg)(struct net_device___36 *, int, u32 *);
	void (*setbcncfg)(struct net_device___36 *, int, u32);
	void (*getbcnrp)(struct net_device___36 *, int, u8 *);
	void (*setbcnrp)(struct net_device___36 *, int, u8);
	int (*setapp)(struct net_device___36 *, u8, u16, u8);
	int (*getapp)(struct net_device___36 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___36 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___36 *, int, u8);
	u8 (*getdcbx)(struct net_device___36 *);
	u8 (*setdcbx)(struct net_device___36 *, u8);
	int (*peer_getappinfo)(struct net_device___36 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___36 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___36 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___36 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___36 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___36 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___37;

typedef int (*bpf_iter_init_seq_priv_t___36)(void *, struct bpf_iter_aux_info___37 *);

struct bpf_map___36;

struct bpf_iter_aux_info___37 {
	struct bpf_map___36 *map;
};

struct bpf_iter_seq_info___36 {
	const struct seq_operations___144 *seq_ops;
	bpf_iter_init_seq_priv_t___36 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___36 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___36 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___36 *, struct file___166 *);
	void (*map_free)(struct bpf_map___36 *);
	int (*map_get_next_key)(struct bpf_map___36 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___36 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___36 *, void *);
	int (*map_lookup_batch)(struct bpf_map___36 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___36 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___36 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___36 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___36 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___36 *, void *);
	int (*map_update_elem)(struct bpf_map___36 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___36 *, void *);
	int (*map_push_elem)(struct bpf_map___36 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___36 *, void *);
	int (*map_peek_elem)(struct bpf_map___36 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___36 *, struct file___166 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___36 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___36 *, void *, struct seq_file___144 *);
	int (*map_check_btf)(const struct bpf_map___36 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___36 *, struct bpf_prog_aux___36 *);
	void (*map_poke_untrack)(struct bpf_map___36 *, struct bpf_prog_aux___36 *);
	void (*map_poke_run)(struct bpf_map___36 *, u32, struct bpf_prog___34 *, struct bpf_prog___34 *);
	int (*map_direct_value_addr)(const struct bpf_map___36 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___36 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___36 *, struct vm_area_struct___171 *);
	__poll_t (*map_poll)(struct bpf_map___36 *, struct file___166 *, struct poll_table_struct___107 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___36 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___36 *, const struct bpf_map___36 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___36 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___36 *iter_seq_info;
};

struct bpf_map___36 {
	const struct bpf_map_ops___36 *ops;
	struct bpf_map___36 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___67 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___36;

struct bpf_jit_poke_descriptor___36;

struct bpf_prog_ops___34;

struct btf_mod_pair___36;

struct bpf_prog_offload___34;

struct bpf_prog_aux___36 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___34 *dst_prog;
	struct bpf_trampoline___36 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___34 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___36 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___34 *ops;
	struct bpf_map___36 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___36 *used_btfs;
	struct bpf_prog___34 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___36 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___34 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___34;

struct bpf_map_dev_ops___34 {
	int (*map_get_next_key)(struct bpf_offloaded_map___34 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___34 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___34 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___34 *, void *);
};

struct bpf_offloaded_map___34 {
	struct bpf_map___36 map;
	struct net_device___36 *netdev;
	const struct bpf_map_dev_ops___34 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___34 {
	int (*test_run)(struct bpf_prog___34 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___34 {
	struct bpf_prog___34 *prog;
	struct net_device___36 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___36 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___34 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___150 *mod;
};

struct bpf_jit_poke_descriptor___36 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___36 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___36 {
	struct btf *btf;
	struct module___150 *module;
};

struct cftype___115;

struct cgroup_subsys___115 {
	struct cgroup_subsys_state___115 * (*css_alloc)(struct cgroup_subsys_state___115 *);
	int (*css_online)(struct cgroup_subsys_state___115 *);
	void (*css_offline)(struct cgroup_subsys_state___115 *);
	void (*css_released)(struct cgroup_subsys_state___115 *);
	void (*css_free)(struct cgroup_subsys_state___115 *);
	void (*css_reset)(struct cgroup_subsys_state___115 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___115 *, int);
	int (*css_extra_stat_show)(struct seq_file___144 *, struct cgroup_subsys_state___115 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___173 *, struct css_set___115 *);
	void (*cancel_fork)(struct task_struct___173 *, struct css_set___115 *);
	void (*fork)(struct task_struct___173 *);
	void (*exit)(struct task_struct___173 *);
	void (*release)(struct task_struct___173 *);
	void (*bind)(struct cgroup_subsys_state___115 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___115 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___115 *dfl_cftypes;
	struct cftype___115 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___115 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___115 *updated_children;
	struct cgroup___115 *updated_next;
};

struct cgroup_root___115 {
	struct kernfs_root___153 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___115 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___115 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___115 *ss;
	struct list_head node;
	struct kernfs_ops___153 *kf_ops;
	int (*open)(struct kernfs_open_file___153 *);
	void (*release)(struct kernfs_open_file___153 *);
	u64 (*read_u64)(struct cgroup_subsys_state___115 *, struct cftype___115 *);
	s64 (*read_s64)(struct cgroup_subsys_state___115 *, struct cftype___115 *);
	int (*seq_show)(struct seq_file___144 *, void *);
	void * (*seq_start)(struct seq_file___144 *, loff_t *);
	void * (*seq_next)(struct seq_file___144 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___144 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___115 *, struct cftype___115 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___115 *, struct cftype___115 *, s64);
	ssize_t (*write)(struct kernfs_open_file___153 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___153 *, struct poll_table_struct___107 *);
};

struct xdp_rxq_info___34 {
	struct net_device___36 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___34 {
	struct net_device___36 *dev;
};

struct xdp_buff___34 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___34 *rxq;
	struct xdp_txq_info___34 *txq;
	u32 frame_sz;
};

struct xdp_frame___34 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___36 *dev_rx;
};

struct netlink_callback___34 {
	struct sk_buff___35 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___35 *, struct netlink_callback___34 *);
	int (*done)(struct netlink_callback___34 *);
	void *data;
	struct module___150 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___34 {
	int (*create)(struct sk_buff___35 *, struct net_device___36 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___35 *, unsigned char *);
	int (*cache)(const struct neighbour___27 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___36 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___35 *);
};

struct netdev_queue___34 {
	struct net_device___36 *dev;
	struct Qdisc___34 *qdisc;
	struct Qdisc___34 *qdisc_sleeping;
	struct kobject___153 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___36 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___34 {
	struct sk_buff___35 *head;
	struct sk_buff___35 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___34;

struct Qdisc___34 {
	int (*enqueue)(struct sk_buff___35 *, struct Qdisc___34 *, struct sk_buff___35 **);
	struct sk_buff___35 * (*dequeue)(struct Qdisc___34 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___34 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___34 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___34 gso_skb;
	struct qdisc_skb_head___34 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___34 *next_sched;
	struct sk_buff_head___34 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___34 {
	struct xdp_rxq_info___34 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___153 kobj;
	struct net_device___36 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___34 {
	enum net_device_path_type type;
	const struct net_device___36 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___34 = 0,
				DEV_PATH_BR_VLAN_TAG___34 = 1,
				DEV_PATH_BR_VLAN_UNTAG___34 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___34 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___34 {
	const struct net_device___36 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___34 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___34 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___34 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___34 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___35 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___34 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___36 *dev;
	const char *name;
};

struct net_device_ops___34 {
	int (*ndo_init)(struct net_device___36 *);
	void (*ndo_uninit)(struct net_device___36 *);
	int (*ndo_open)(struct net_device___36 *);
	int (*ndo_stop)(struct net_device___36 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___35 *, struct net_device___36 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___35 *, struct net_device___36 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___36 *, struct sk_buff___35 *, struct net_device___36 *);
	void (*ndo_change_rx_flags)(struct net_device___36 *, int);
	void (*ndo_set_rx_mode)(struct net_device___36 *);
	int (*ndo_set_mac_address)(struct net_device___36 *, void *);
	int (*ndo_validate_addr)(struct net_device___36 *);
	int (*ndo_do_ioctl)(struct net_device___36 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___36 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___36 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___36 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___36 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___36 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___36 *, int);
	int (*ndo_neigh_setup)(struct net_device___36 *, struct neigh_parms___27 *);
	void (*ndo_tx_timeout)(struct net_device___36 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___36 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___36 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___36 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___36 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___36 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___36 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___36 *);
	int (*ndo_netpoll_setup)(struct net_device___36 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___36 *);
	int (*ndo_set_vf_mac)(struct net_device___36 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___36 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___36 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___36 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___36 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___36 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___36 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___36 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___36 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___36 *, int, struct sk_buff___35 *);
	int (*ndo_get_vf_guid)(struct net_device___36 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___36 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___36 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___36 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___36 *);
	int (*ndo_fcoe_disable)(struct net_device___36 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___36 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___36 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___36 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___36 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___36 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___36 *, const struct sk_buff___35 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___36 *, struct net_device___36 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___36 *, struct net_device___36 *);
	struct net_device___36 * (*ndo_get_xmit_slave)(struct net_device___36 *, struct sk_buff___35 *, bool);
	struct net_device___36 * (*ndo_sk_get_lower_dev)(struct net_device___36 *, struct sock___28 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___36 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___36 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___36 *, struct neighbour___27 *);
	void (*ndo_neigh_destroy)(struct net_device___36 *, struct neighbour___27 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___35 *, struct netlink_callback___34 *, struct net_device___36 *, struct net_device___36 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___35 *, struct nlattr **, struct net_device___36 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___36 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___35 *, u32, u32, struct net_device___36 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___36 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___36 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___36 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___36 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___36 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___36 *, struct net_device___36 *);
	void (*ndo_dfwd_del_station)(struct net_device___36 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___36 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___36 *);
	int (*ndo_change_proto_down)(struct net_device___36 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___36 *, struct sk_buff___35 *);
	void (*ndo_set_rx_headroom)(struct net_device___36 *, int);
	int (*ndo_bpf)(struct net_device___36 *, struct netdev_bpf___34 *);
	int (*ndo_xdp_xmit)(struct net_device___36 *, int, struct xdp_frame___34 **, u32);
	struct net_device___36 * (*ndo_xdp_get_xmit_slave)(struct net_device___36 *, struct xdp_buff___34 *);
	int (*ndo_xsk_wakeup)(struct net_device___36 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___36 *);
	int (*ndo_tunnel_ctl)(struct net_device___36 *, struct ip_tunnel_parm *, int);
	struct net_device___36 * (*ndo_get_peer_dev)(struct net_device___36 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___34 *, struct net_device_path___34 *);
};

struct neigh_parms___27 {
	possible_net_t___34 net;
	struct net_device___36 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___27 *);
	struct neigh_table___27 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___12 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___36 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___36 *);
	void (*get_regs)(struct net_device___36 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___36 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___36 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___36 *);
	void (*set_msglevel)(struct net_device___36 *, u32);
	int (*nway_reset)(struct net_device___36 *);
	u32 (*get_link)(struct net_device___36 *);
	int (*get_link_ext_state)(struct net_device___36 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___36 *);
	int (*get_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___36 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___36 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___36 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___36 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___36 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___36 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___36 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___36 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___36 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___36 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___36 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___36 *);
	void (*complete)(struct net_device___36 *);
	u32 (*get_priv_flags)(struct net_device___36 *);
	int (*set_priv_flags)(struct net_device___36 *, u32);
	int (*get_sset_count)(struct net_device___36 *, int);
	int (*get_rxnfc)(struct net_device___36 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___36 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___36 *, struct ethtool_flash *);
	int (*reset)(struct net_device___36 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___36 *);
	u32 (*get_rxfh_indir_size)(struct net_device___36 *);
	int (*get_rxfh)(struct net_device___36 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___36 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___36 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___36 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___36 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___36 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___36 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___36 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___36 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___36 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___36 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___36 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___36 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___36 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___36 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___36 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___36 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___36 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___36 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___36 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___36 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___36 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___36 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___36 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___36 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___36 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___36 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___36 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___36 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___36 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___36 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___27 {
	u32 (*l3mdev_fib_table)(const struct net_device___36 *);
	struct sk_buff___35 * (*l3mdev_l3_rcv)(struct net_device___36 *, struct sk_buff___35 *, u16);
	struct sk_buff___35 * (*l3mdev_l3_out)(struct net_device___36 *, struct sock___28 *, struct sk_buff___35 *, u16);
	struct dst_entry___27 * (*l3mdev_link_scope_lookup)(const struct net_device___36 *, struct flowi6 *);
};

struct ndisc_ops___17 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___36 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___36 *, struct neighbour___27 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___36 *, u8, struct neighbour___27 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___36 *, struct sk_buff___35 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___39 *, struct net_device___36 *, const struct prefix_info *, struct inet6_dev___17 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___17;

struct inet6_dev___17 {
	struct net_device___36 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___17 *mc_list;
	struct ifmcaddr6___17 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___34 mc_query_queue;
	struct sk_buff_head___34 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___27 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___34;

struct tcf_block___34;

struct mini_Qdisc___34 {
	struct tcf_proto___34 *filter_list;
	struct tcf_block___34 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___34 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___36 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___36 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___39 *, struct net_device___36 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___36 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___36 *, struct list_head *);
	size_t (*get_size)(const struct net_device___36 *);
	int (*fill_info)(struct sk_buff___35 *, const struct net_device___36 *);
	size_t (*get_xstats_size)(const struct net_device___36 *);
	int (*fill_xstats)(struct sk_buff___35 *, const struct net_device___36 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___36 *, struct net_device___36 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___36 *, const struct net_device___36 *);
	int (*fill_slave_info)(struct sk_buff___35 *, const struct net_device___36 *, const struct net_device___36 *);
	struct net___39 * (*get_link_net)(const struct net_device___36 *);
	size_t (*get_linkxstats_size)(const struct net_device___36 *, int);
	int (*fill_linkxstats)(struct sk_buff___35 *, const struct net_device___36 *, int *, int);
};

struct block_device_operations___79;

struct gendisk___79 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___80 *part0;
	const struct block_device_operations___79 *fops;
	struct request_queue___79 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___76 *bdi;
	struct kobject___153 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___153 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___79 {
	struct bio___79 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___93 *bip_vec;
	struct bio_vec___93 bip_inline_vecs[0];
};

struct blkcg___76;

struct blkg_policy_data___76;

struct blkcg_gq___76 {
	struct request_queue___79 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___76 *blkcg;
	struct blkcg_gq___76 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___76 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___79 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___79(struct request___79 *);

typedef void integrity_complete_fn___79(struct request___79 *, unsigned int);

struct blk_integrity_profile___79 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___79 *prepare_fn;
	integrity_complete_fn___79 *complete_fn;
	const char *name;
};

struct block_device_operations___79 {
	blk_qc_t (*submit_bio)(struct bio___79 *);
	int (*open)(struct block_device___80 *, fmode_t);
	void (*release)(struct gendisk___79 *, fmode_t);
	int (*rw_page)(struct block_device___80 *, sector_t, struct page___171 *, unsigned int);
	int (*ioctl)(struct block_device___80 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___80 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___79 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___79 *);
	int (*getgeo)(struct block_device___80 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___80 *, bool);
	void (*swap_slot_free_notify)(struct block_device___80 *, long unsigned int);
	int (*report_zones)(struct gendisk___79 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___79 *, umode_t *);
	struct module___150 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___79 *, sector_t *);
};

typedef void rq_end_io_fn___79(struct request___79 *, blk_status_t);

struct request___79 {
	struct request_queue___79 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___76 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___79 *bio;
	struct bio___79 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___93 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___79 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___79 *saved_end_io;
		} flush;
	};
	struct gendisk___79 *rq_disk;
	struct block_device___80 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___79 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___76 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___79 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___153 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___166 *debugfs_dir;
	struct dentry___166 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___79;

struct elevator_mq_ops___79 {
	int (*init_sched)(struct request_queue___79 *, struct elevator_type___79 *);
	void (*exit_sched)(struct elevator_queue___79 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___76 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___76 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___76 *);
	bool (*allow_merge)(struct request_queue___79 *, struct request___79 *, struct bio___79 *);
	bool (*bio_merge)(struct request_queue___79 *, struct bio___79 *, unsigned int);
	int (*request_merge)(struct request_queue___79 *, struct request___79 **, struct bio___79 *);
	void (*request_merged)(struct request_queue___79 *, struct request___79 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___79 *, struct request___79 *, struct request___79 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___79 *);
	void (*finish_request)(struct request___79 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___76 *, struct list_head *, bool);
	struct request___79 * (*dispatch_request)(struct blk_mq_hw_ctx___76 *);
	bool (*has_work)(struct blk_mq_hw_ctx___76 *);
	void (*completed_request)(struct request___79 *, u64);
	void (*requeue_request)(struct request___79 *);
	struct request___79 * (*former_request)(struct request_queue___79 *, struct request___79 *);
	struct request___79 * (*next_request)(struct request_queue___79 *, struct request___79 *);
	void (*init_icq)(struct io_cq___79 *);
	void (*exit_icq)(struct io_cq___79 *);
};

struct elv_fs_entry___79;

struct elevator_type___79 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___79 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___79 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___150 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___79 {
	struct elevator_type___79 *type;
	void *elevator_data;
	struct kobject___153 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___79 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___79 *, char *);
	ssize_t (*store)(struct elevator_queue___79 *, const char *, size_t);
};

struct blk_mq_queue_data___76;

struct blk_mq_ops___76 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___76 *, const struct blk_mq_queue_data___76 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___76 *);
	int (*get_budget)(struct request_queue___79 *);
	void (*put_budget)(struct request_queue___79 *, int);
	void (*set_rq_budget_token)(struct request___79 *, int);
	int (*get_rq_budget_token)(struct request___79 *);
	enum blk_eh_timer_return (*timeout)(struct request___79 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___76 *);
	void (*complete)(struct request___79 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___76 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___76 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___76 *, struct request___79 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___76 *, struct request___79 *, unsigned int);
	void (*initialize_rq_fn)(struct request___79 *);
	void (*cleanup_rq)(struct request___79 *);
	bool (*busy)(struct request_queue___79 *);
	int (*map_queues)(struct blk_mq_tag_set___76 *);
	void (*show_rq)(struct seq_file___144 *, struct request___79 *);
};

struct blk_mq_tag_set___76 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___76 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___76 {
	struct request___79 *rq;
	bool last;
};

struct blkcg_policy_data___76;

struct blkcg___76 {
	struct cgroup_subsys_state___115 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___76 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___76 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___76 {
	struct blkcg___76 *blkcg;
	int plid;
};

struct blkg_policy_data___76 {
	struct blkcg_gq___76 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___67 {
	struct mem_cgroup___67 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___67 {
	struct lruvec___74 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___67 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___67 *memcg;
};

struct obj_cgroup___67 {
	struct percpu_ref refcnt;
	struct mem_cgroup___67 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___34 {
	spinlock_t *lock;
	struct sk_buff___35 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___34;

struct Qdisc_ops___34 {
	struct Qdisc_ops___34 *next;
	const struct Qdisc_class_ops___34 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___35 *, struct Qdisc___34 *, struct sk_buff___35 **);
	struct sk_buff___35 * (*dequeue)(struct Qdisc___34 *);
	struct sk_buff___35 * (*peek)(struct Qdisc___34 *);
	int (*init)(struct Qdisc___34 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___34 *);
	void (*destroy)(struct Qdisc___34 *);
	int (*change)(struct Qdisc___34 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___34 *);
	int (*change_tx_queue_len)(struct Qdisc___34 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___34 *, unsigned int);
	int (*dump)(struct Qdisc___34 *, struct sk_buff___35 *);
	int (*dump_stats)(struct Qdisc___34 *, struct gnet_dump___34 *);
	void (*ingress_block_set)(struct Qdisc___34 *, u32);
	void (*egress_block_set)(struct Qdisc___34 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___34 *);
	u32 (*egress_block_get)(struct Qdisc___34 *);
	struct module___150 *owner;
};

struct Qdisc_class_ops___34 {
	unsigned int flags;
	struct netdev_queue___34 * (*select_queue)(struct Qdisc___34 *, struct tcmsg *);
	int (*graft)(struct Qdisc___34 *, long unsigned int, struct Qdisc___34 *, struct Qdisc___34 **, struct netlink_ext_ack *);
	struct Qdisc___34 * (*leaf)(struct Qdisc___34 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___34 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___34 *, u32);
	int (*change)(struct Qdisc___34 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___34 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___34 *, struct qdisc_walker *);
	struct tcf_block___34 * (*tcf_block)(struct Qdisc___34 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___34 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___34 *, long unsigned int);
	int (*dump)(struct Qdisc___34 *, long unsigned int, struct sk_buff___35 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___34 *, long unsigned int, struct gnet_dump___34 *);
};

struct tcf_chain___34;

struct tcf_block___34 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___39 *net;
	struct Qdisc___34 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___34 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___34;

struct tcf_proto_ops___34;

struct tcf_proto___34 {
	struct tcf_proto___34 *next;
	void *root;
	int (*classify)(struct sk_buff___35 *, const struct tcf_proto___34 *, struct tcf_result___34 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___34 *ops;
	struct tcf_chain___34 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___34 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___34 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___34 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___35 *, const struct tcf_proto___34 *, struct tcf_result___34 *);
	int (*init)(struct tcf_proto___34 *);
	void (*destroy)(struct tcf_proto___34 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___34 *, u32);
	void (*put)(struct tcf_proto___34 *, void *);
	int (*change)(struct net___39 *, struct sk_buff___35 *, struct tcf_proto___34 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___34 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___34 *);
	void (*walk)(struct tcf_proto___34 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___34 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___34 *, void *);
	void (*hw_del)(struct tcf_proto___34 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___39 *, struct tcf_chain___34 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___39 *, struct tcf_proto___34 *, void *, struct sk_buff___35 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___39 *, struct tcf_proto___34 *, void *, struct sk_buff___35 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___35 *, struct net___39 *, void *);
	struct module___150 *owner;
	int flags;
};

struct tcf_chain___34 {
	struct mutex filter_chain_lock;
	struct tcf_proto___34 *filter_chain;
	struct list_head list;
	struct tcf_block___34 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___34 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___27 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___34 *prog;
};

struct pneigh_entry___27;

struct neigh_hash_table___27;

struct neigh_table___27 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___36 *, __u32 *);
	bool (*key_eq)(const struct neighbour___27 *, const void *);
	int (*constructor)(struct neighbour___27 *);
	int (*pconstructor)(struct pneigh_entry___27 *);
	void (*pdestructor)(struct pneigh_entry___27 *);
	void (*proxy_redo)(struct sk_buff___35 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___36 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___27 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___34 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___27 *nht;
	struct pneigh_entry___27 **phash_buckets;
};

struct neigh_ops___27 {
	int family;
	void (*solicit)(struct neighbour___27 *, struct sk_buff___35 *);
	void (*error_report)(struct neighbour___27 *, struct sk_buff___35 *);
	int (*output)(struct neighbour___27 *, struct sk_buff___35 *);
	int (*connected_output)(struct neighbour___27 *, struct sk_buff___35 *);
};

struct pneigh_entry___27 {
	struct pneigh_entry___27 *next;
	possible_net_t___34 net;
	struct net_device___36 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___27 {
	struct neighbour___27 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___14 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___39 *, struct sock___28 *, struct sk_buff___35 *);
	int (*orig_input)(struct sk_buff___35 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___27 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___27 *ctarget;
	struct net___39 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___27 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___27 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___17;

struct timewait_sock_ops___17;

struct proto___27 {
	void (*close)(struct sock___28 *, long int);
	int (*pre_connect)(struct sock___28 *, struct sockaddr *, int);
	int (*connect)(struct sock___28 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___28 *, int);
	struct sock___28 * (*accept)(struct sock___28 *, int, int *, bool);
	int (*ioctl)(struct sock___28 *, int, long unsigned int);
	int (*init)(struct sock___28 *);
	void (*destroy)(struct sock___28 *);
	void (*shutdown)(struct sock___28 *, int);
	int (*setsockopt)(struct sock___28 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___28 *, int, int, char *, int *);
	void (*keepalive)(struct sock___28 *, int);
	int (*compat_ioctl)(struct sock___28 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___28 *, struct msghdr___28 *, size_t);
	int (*recvmsg)(struct sock___28 *, struct msghdr___28 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___28 *, struct page___171 *, int, size_t, int);
	int (*bind)(struct sock___28 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___28 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___28 *, struct sk_buff___35 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___28 *);
	int (*hash)(struct sock___28 *);
	void (*unhash)(struct sock___28 *);
	void (*rehash)(struct sock___28 *);
	int (*get_port)(struct sock___28 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___28 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___28 *, int);
	bool (*sock_is_readable)(struct sock___28 *);
	void (*enter_memory_pressure)(struct sock___28 *);
	void (*leave_memory_pressure)(struct sock___28 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___17 *rsk_prot;
	struct timewait_sock_ops___17 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___150 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___28 *, int);
};

struct request_sock___18;

struct request_sock_ops___17 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___28 *, struct request_sock___18 *);
	void (*send_ack)(const struct sock___28 *, struct sk_buff___35 *, struct request_sock___18 *);
	void (*send_reset)(const struct sock___28 *, struct sk_buff___35 *);
	void (*destructor)(struct request_sock___18 *);
	void (*syn_ack_timeout)(const struct request_sock___18 *);
};

struct timewait_sock_ops___17 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___28 *, struct sock___28 *, void *);
	void (*twsk_destructor)(struct sock___28 *);
};

struct linux_binprm___37 {
	struct vm_area_struct___171 *vma;
	long unsigned int vma_pages;
	struct mm_struct___172 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___166 *executable;
	struct file___166 *interpreter;
	struct file___166 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct request_sock___18 {
	struct sock_common___27 __req_common;
	struct request_sock___18 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___17 *rsk_ops;
	struct sock___28 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct aa_label___7;

struct aa_proxy___7 {
	struct kref count;
	struct aa_label___7 *label;
};

struct aa_profile___7;

struct aa_label___7 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	struct aa_proxy___7 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___7 *vec[0];
};

struct aa_ns___7;

struct aa_profile___7 {
	struct aa_policy base;
	struct aa_profile___7 *parent;
	struct aa_ns___7 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___2 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___166 *dents[9];
	struct rhashtable *data;
	struct aa_label___7 label;
};

struct ifmcaddr6___17 {
	struct in6_addr mca_addr;
	struct inet6_dev___17 *idev;
	struct ifmcaddr6___17 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct lsm_network_audit___8 {
	int netif;
	const struct sock___28 *sk;
	u16 family;
	__be16 dport;
	__be16 sport;
	union {
		struct {
			__be32 daddr;
			__be32 saddr;
		} v4;
		struct {
			struct in6_addr daddr;
			struct in6_addr saddr;
		} v6;
	} fam;
};

struct lsm_ioctlop_audit___8 {
	struct path___166 path;
	u16 cmd;
};

struct apparmor_audit_data___6 {
	int error;
	int type;
	const char *op;
	struct aa_label___7 *label;
	const char *name;
	const char *info;
	u32 request;
	u32 denied;
	union {
		struct {
			struct aa_label___7 *peer;
			union {
				struct {
					const char *target;
					kuid_t ouid;
				} fs;
				struct {
					int rlim;
					long unsigned int max;
				} rlim;
				struct {
					int signal;
					int unmappedsig;
				};
				struct {
					int type;
					int protocol;
					struct sock___28 *peer_sk;
					void *addr;
					int addrlen;
				} net;
			};
		};
		struct {
			struct aa_profile___7 *profile;
			const char *ns;
			long int pos;
		} iface;
		struct {
			const char *src_name;
			const char *type;
			const char *trans;
			const char *data;
			long unsigned int flags;
		} mnt;
	};
};

struct common_audit_data___9 {
	char type;
	union {
		struct path___166 path;
		struct dentry___166 *dentry;
		struct inode___166 *inode;
		struct lsm_network_audit___8 *net;
		int cap;
		int ipc_id;
		struct task_struct___173 *tsk;
		struct {
			key_serial_t key;
			char *key_desc;
		} key_struct;
		char *kmod_name;
		struct lsm_ioctlop_audit___8 *op;
		struct file___166 *file;
		struct lsm_ibpkey_audit *ibpkey;
		struct lsm_ibendport_audit *ibendport;
		int reason;
	} u;
	union {
		struct smack_audit_data *smack_audit_data;
		struct selinux_audit_data___2 *selinux_audit_data;
		struct apparmor_audit_data___6 *apparmor_audit_data;
	};
};

struct coredump_params___36 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___166 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct aa_file_ctx___2 {
	spinlock_t lock;
	struct aa_label___7 *label;
	u32 allow;
};

struct aa_ns___7 {
	struct aa_policy base;
	struct aa_ns___7 *parent;
	struct mutex lock;
	struct aa_ns_acct acct;
	struct aa_profile___7 *unconfined;
	struct list_head sub_ns;
	atomic_t uniq_null;
	long int uniq_id;
	int level;
	long int revision;
	wait_queue_head_t wait;
	struct aa_labelset labels;
	struct list_head rawdata_list;
	struct dentry___166 *dents[13];
};

struct unix_sock___3 {
	struct sock___28 sk;
	struct unix_address *addr;
	struct path___166 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___28 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___28 peer_wq;
	wait_queue_entry_t peer_wake;
	struct scm_stat scm_stat;
	struct sk_buff___35 *oob_skb;
	long: 64;
};

struct aa_sk_ctx___2 {
	struct aa_label___7 *label;
	struct aa_label___7 *peer;
	struct path___166 path;
};

struct dentry___167;

struct super_block___167;

struct module___151;

struct file_system_type___167 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___167 * (*mount)(struct file_system_type___167 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___167 *);
	struct module___151 *owner;
	struct file_system_type___167 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___167;

struct kiocb___167;

struct iov_iter___96;

struct poll_table_struct___108;

struct vm_area_struct___172;

struct inode___167;

struct file_lock___167;

struct page___172;

struct pipe_inode_info___60;

struct seq_file___145;

struct file_operations___167 {
	struct module___151 *owner;
	loff_t (*llseek)(struct file___167 *, loff_t, int);
	ssize_t (*read)(struct file___167 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___167 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___167 *, struct iov_iter___96 *);
	ssize_t (*write_iter)(struct kiocb___167 *, struct iov_iter___96 *);
	int (*iopoll)(struct kiocb___167 *, bool);
	int (*iterate)(struct file___167 *, struct dir_context *);
	int (*iterate_shared)(struct file___167 *, struct dir_context *);
	__poll_t (*poll)(struct file___167 *, struct poll_table_struct___108 *);
	long int (*unlocked_ioctl)(struct file___167 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___167 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___167 *, struct vm_area_struct___172 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___167 *, struct file___167 *);
	int (*flush)(struct file___167 *, fl_owner_t);
	int (*release)(struct inode___167 *, struct file___167 *);
	int (*fsync)(struct file___167 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___167 *, int);
	int (*lock)(struct file___167 *, int, struct file_lock___167 *);
	ssize_t (*sendpage)(struct file___167 *, struct page___172 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___167 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___167 *, long unsigned int);
	int (*flock)(struct file___167 *, int, struct file_lock___167 *);
	ssize_t (*splice_write)(struct pipe_inode_info___60 *, struct file___167 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___167 *, loff_t *, struct pipe_inode_info___60 *, size_t, unsigned int);
	int (*setlease)(struct file___167 *, long int, struct file_lock___167 **, void **);
	long int (*fallocate)(struct file___167 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___145 *, struct file___167 *);
	ssize_t (*copy_file_range)(struct file___167 *, loff_t, struct file___167 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___167 *, loff_t, struct file___167 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___167 *, loff_t, loff_t, int);
};

struct vmacache___172 {
	u64 seqnum;
	struct vm_area_struct___172 *vmas[4];
};

struct page_frag___172 {
	struct page___172 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___173;

struct pid___148;

struct nsproxy___157;

struct signal_struct___168;

struct bio_list___80;

struct backing_dev_info___77;

struct io_context___80;

struct css_set___116;

struct mem_cgroup___68;

struct request_queue___80;

struct vm_struct___151;

struct task_struct___174 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___174 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___173 *mm;
	struct mm_struct___173 *active_mm;
	struct vmacache___172 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___174 *real_parent;
	struct task_struct___174 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___174 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___148 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___157 *nsproxy;
	struct signal_struct___168 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___174 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___80 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___77 *backing_dev_info;
	struct io_context___80 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___116 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___60 *splice_pipe;
	struct page_frag___172 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___68 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___68 *active_memcg;
	struct request_queue___80 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___174 *oom_reaper_list;
	struct vm_struct___151 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___154;

struct kobj_type___154;

struct kernfs_node___154;

struct kobject___154 {
	const char *name;
	struct list_head entry;
	struct kobject___154 *parent;
	struct kset___154 *kset;
	struct kobj_type___154 *ktype;
	struct kernfs_node___154 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___151 {
	struct kobject___154 kobj;
	struct module___151 *mod;
	struct kobject___154 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___151 {
	struct module___151 *mod;
	struct latch_tree_node node;
};

struct module_layout___151 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___151 mtn;
};

struct module_attribute___151;

struct kernel_param___151;

struct module___151 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___151 mkobj;
	struct module_attribute___151 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___154 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___151 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___151 core_layout;
	struct module_layout___151 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___172 *pgtable_t___172;

struct address_space___167;

struct page_pool___51;

struct dev_pagemap___163;

struct page___172 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___167 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___172 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___172 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___173 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___163 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___163;

struct vm_area_struct___172 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___172 *vm_next;
	struct vm_area_struct___172 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___173 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___163 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___167 *vm_file;
	struct file___167 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct linux_binfmt___37;

struct core_state___172;

struct mm_struct___173 {
	struct {
		struct vm_area_struct___172 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___167 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___37 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___172 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___174 *owner;
		struct user_namespace___24 *user_ns;
		struct file___167 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___167;

struct address_space___167 {
	struct inode___167 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___167 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___123;

struct page_pool_params___51 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___123 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___51 {
	u32 count;
	struct page___172 *cache[128];
};

struct page_pool___51 {
	struct page_pool_params___51 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___172 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___51 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___163;

struct dev_pagemap___163 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___163 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___167;

struct path___167 {
	struct vfsmount___167 *mnt;
	struct dentry___167 *dentry;
};

struct fown_struct___148 {
	rwlock_t lock;
	struct pid___148 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___167 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___167 f_path;
	struct inode___167 *f_inode;
	const struct file_operations___167 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___148 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___167 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___163;

struct vm_operations_struct___163 {
	void (*open)(struct vm_area_struct___172 *);
	void (*close)(struct vm_area_struct___172 *);
	int (*may_split)(struct vm_area_struct___172 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___172 *);
	int (*mprotect)(struct vm_area_struct___172 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___163 *);
	vm_fault_t (*huge_fault)(struct vm_fault___163 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___163 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___172 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___163 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___163 *);
	int (*access)(struct vm_area_struct___172 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___172 *);
	int (*set_policy)(struct vm_area_struct___172 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___172 *, long unsigned int);
	struct page___172 * (*find_special_page)(struct vm_area_struct___172 *, long unsigned int);
};

struct core_thread___172 {
	struct task_struct___174 *task;
	struct core_thread___172 *next;
};

struct core_state___172 {
	atomic_t nr_threads;
	struct core_thread___172 dumper;
	struct completion startup;
};

struct linux_binprm___38;

struct coredump_params___37;

struct linux_binfmt___37 {
	struct list_head lh;
	struct module___151 *module;
	int (*load_binary)(struct linux_binprm___38 *);
	int (*load_shlib)(struct file___167 *);
	int (*core_dump)(struct coredump_params___37 *);
	long unsigned int min_coredump;
};

struct vm_fault___163 {
	const struct {
		struct vm_area_struct___172 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___172 *cow_page;
	struct page___172 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___172 prealloc_pte;
};

struct pglist_data___75;

struct lruvec___75 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___75 *pgdat;
};

struct zone___75 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___75 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___75 {
	struct zone___75 *zone;
	int zone_idx;
};

struct zonelist___75 {
	struct zoneref___75 _zonerefs[321];
};

struct pglist_data___75 {
	struct zone___75 node_zones[5];
	struct zonelist___75 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___174 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___174 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___75 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct crypto_alg___16;

struct crypto_tfm___16 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___16 *);
	struct crypto_alg___16 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___16 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___16 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___16 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___16 *, u8 *, const u8 *);
};

struct compress_alg___16 {
	int (*coa_compress)(struct crypto_tfm___16 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___16 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___16 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___16 cipher;
		struct compress_alg___16 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___16 *);
	void (*cra_exit)(struct crypto_tfm___16 *);
	void (*cra_destroy)(struct crypto_alg___16 *);
	struct module___151 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___12;

struct shash_desc___8 {
	struct crypto_shash___12 *tfm;
	void *__ctx[0];
};

struct crypto_shash___12 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___16 base;
};

struct shash_alg___3 {
	int (*init)(struct shash_desc___8 *);
	int (*update)(struct shash_desc___8 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___8 *, u8 *);
	int (*finup)(struct shash_desc___8 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___8 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___8 *, void *);
	int (*import)(struct shash_desc___8 *, const void *);
	int (*setkey)(struct crypto_shash___12 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___12 *);
	void (*exit_tfm)(struct crypto_shash___12 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___16 base;
};

struct pid_namespace___148;

struct upid___148 {
	int nr;
	struct pid_namespace___148 *ns;
};

struct pid_namespace___148 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___174 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___148 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___148 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___148 numbers[1];
};

struct signal_struct___168 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___174 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___174 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___148 *pids[4];
	struct pid___148 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___173 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___40;

struct cgroup_namespace___116;

struct nsproxy___157 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___148 *pid_ns_for_children;
	struct net___40 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___116 *cgroup_ns;
};

struct bio___80;

struct bio_list___80 {
	struct bio___80 *head;
	struct bio___80 *tail;
};

struct cgroup_subsys_state___116;

struct bdi_writeback___77 {
	struct backing_dev_info___77 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___116 *memcg_css;
	struct cgroup_subsys_state___116 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___77 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___77 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___123 *dev;
	char dev_name[64];
	struct device___123 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___167 *debug_dir;
};

struct io_cq___80;

struct io_context___80 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___80 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___116;

struct css_set___116 {
	struct cgroup_subsys_state___116 *subsys[14];
	refcount_t refcount;
	struct css_set___116 *dom_cset;
	struct cgroup___116 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___116 *mg_src_cgrp;
	struct cgroup___116 *mg_dst_cgrp;
	struct css_set___116 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___167;

struct pipe_buffer___60;

struct pipe_inode_info___60 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___172 *tmp_page;
	struct fasync_struct___167 *fasync_readers;
	struct fasync_struct___167 *fasync_writers;
	struct pipe_buffer___60 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___116;

struct cgroup_subsys_state___116 {
	struct cgroup___116 *cgroup;
	struct cgroup_subsys___116 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___116 *parent;
};

struct cgroup_file___116 {
	struct kernfs_node___154 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___68;

struct mem_cgroup_per_node___68;

struct mem_cgroup___68 {
	struct cgroup_subsys_state___116 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___116 events_file;
	struct cgroup_file___116 events_local_file;
	struct cgroup_file___116 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___68 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___174 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___68 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___80;

struct blk_integrity___80 {
	const struct blk_integrity_profile___80 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___80 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___80 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___80;

struct elevator_queue___80;

struct blk_mq_ops___77;

struct blk_mq_hw_ctx___77;

struct gendisk___80;

struct blkcg_gq___77;

struct blk_mq_tag_set___77;

struct request_queue___80 {
	struct request___80 *last_merge;
	struct elevator_queue___80 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___77 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___77 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___80 *disk;
	struct kobject___154 kobj;
	struct kobject___154 *mq_kobj;
	struct blk_integrity___80 integrity;
	struct device___123 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___77 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___77 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___80 bio_split;
	struct dentry___167 *debugfs_dir;
	struct dentry___167 *sched_debugfs_dir;
	struct dentry___167 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___151 {
	struct vm_struct___151 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___172 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___94 {
	struct page___172 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___96 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___94 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___60 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___29 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___96 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___167 *msg_iocb;
};

struct kiocb___167 {
	struct file___167 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___167 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct psi_group___116 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___174 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___35;

struct cgroup_bpf___35 {
	struct bpf_prog_array___35 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___35 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___116;

struct cgroup_rstat_cpu___116;

struct cgroup___116 {
	struct cgroup_subsys_state___116 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___154 *kn;
	struct cgroup_file___116 procs_file;
	struct cgroup_file___116 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___116 *subsys[14];
	struct cgroup_root___116 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___116 *dom_cgrp;
	struct cgroup___116 *old_dom_cgrp;
	struct cgroup_rstat_cpu___116 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___116 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct shrink_control___68 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___68 *memcg;
};

struct shrinker___68 {
	long unsigned int (*count_objects)(struct shrinker___68 *, struct shrink_control___68 *);
	long unsigned int (*scan_objects)(struct shrinker___68 *, struct shrink_control___68 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___163 {
	void (*page_free)(struct page___172 *);
	void (*kill)(struct dev_pagemap___163 *);
	void (*cleanup)(struct dev_pagemap___163 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___163 *);
};

struct dentry_operations___167;

struct dentry___167 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___167 *d_parent;
	struct qstr d_name;
	struct inode___167 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___167 *d_op;
	struct super_block___167 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___167;

struct inode___167 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___167 *i_op;
	struct super_block___167 *i_sb;
	struct address_space___167 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___77 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___167 *i_fop;
		void (*free_inode)(struct inode___167 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___167 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___60 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___167 {
	int (*d_revalidate)(struct dentry___167 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___167 *, unsigned int);
	int (*d_hash)(const struct dentry___167 *, struct qstr *);
	int (*d_compare)(const struct dentry___167 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___167 *);
	int (*d_init)(struct dentry___167 *);
	void (*d_release)(struct dentry___167 *);
	void (*d_prune)(struct dentry___167 *);
	void (*d_iput)(struct dentry___167 *, struct inode___167 *);
	char * (*d_dname)(struct dentry___167 *, char *, int);
	struct vfsmount___167 * (*d_automount)(struct path___167 *);
	int (*d_manage)(const struct path___167 *, bool);
	struct dentry___167 * (*d_real)(struct dentry___167 *, const struct inode___167 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___167;

struct mem_dqinfo___167 {
	struct quota_format_type___167 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___167;

struct quota_info___167 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___167 *files[3];
	struct mem_dqinfo___167 info[3];
	const struct quota_format_ops___167 *ops[3];
};

struct rcuwait___168 {
	struct task_struct___174 *task;
};

struct percpu_rw_semaphore___168 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___168 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___167 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___168 rw_sem[3];
};

struct super_operations___167;

struct dquot_operations___167;

struct quotactl_ops___167;

struct block_device___81;

struct super_block___167 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___167 *s_type;
	const struct super_operations___167 *s_op;
	const struct dquot_operations___167 *dq_op;
	const struct quotactl_ops___167 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___167 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___81 *s_bdev;
	struct backing_dev_info___77 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___167 s_dquot;
	struct sb_writers___167 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___167 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___167 {
	struct dentry___167 *mnt_root;
	struct super_block___167 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct io_cq___80 {
	struct request_queue___80 *q;
	struct io_context___80 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___167 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___167 *ia_file;
};

struct dquot___167 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___167 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___167 {
	int qf_fmt_id;
	const struct quota_format_ops___167 *qf_ops;
	struct module___151 *qf_owner;
	struct quota_format_type___167 *qf_next;
};

struct quota_format_ops___167 {
	int (*check_quota_file)(struct super_block___167 *, int);
	int (*read_file_info)(struct super_block___167 *, int);
	int (*write_file_info)(struct super_block___167 *, int);
	int (*free_file_info)(struct super_block___167 *, int);
	int (*read_dqblk)(struct dquot___167 *);
	int (*commit_dqblk)(struct dquot___167 *);
	int (*release_dqblk)(struct dquot___167 *);
	int (*get_next_id)(struct super_block___167 *, struct kqid *);
};

struct dquot_operations___167 {
	int (*write_dquot)(struct dquot___167 *);
	struct dquot___167 * (*alloc_dquot)(struct super_block___167 *, int);
	void (*destroy_dquot)(struct dquot___167 *);
	int (*acquire_dquot)(struct dquot___167 *);
	int (*release_dquot)(struct dquot___167 *);
	int (*mark_dirty)(struct dquot___167 *);
	int (*write_info)(struct super_block___167 *, int);
	qsize_t * (*get_reserved_space)(struct inode___167 *);
	int (*get_projid)(struct inode___167 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___167 *, qsize_t *);
	int (*get_next_id)(struct super_block___167 *, struct kqid *);
};

struct quotactl_ops___167 {
	int (*quota_on)(struct super_block___167 *, int, int, const struct path___167 *);
	int (*quota_off)(struct super_block___167 *, int);
	int (*quota_enable)(struct super_block___167 *, unsigned int);
	int (*quota_disable)(struct super_block___167 *, unsigned int);
	int (*quota_sync)(struct super_block___167 *, int);
	int (*set_info)(struct super_block___167 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___167 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___167 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___167 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___167 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___167 *, unsigned int);
};

struct writeback_control___77;

struct address_space_operations___167 {
	int (*writepage)(struct page___172 *, struct writeback_control___77 *);
	int (*readpage)(struct file___167 *, struct page___172 *);
	int (*writepages)(struct address_space___167 *, struct writeback_control___77 *);
	int (*set_page_dirty)(struct page___172 *);
	int (*readpages)(struct file___167 *, struct address_space___167 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___167 *, struct address_space___167 *, loff_t, unsigned int, unsigned int, struct page___172 **, void **);
	int (*write_end)(struct file___167 *, struct address_space___167 *, loff_t, unsigned int, unsigned int, struct page___172 *, void *);
	sector_t (*bmap)(struct address_space___167 *, sector_t);
	void (*invalidatepage)(struct page___172 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___172 *, gfp_t);
	void (*freepage)(struct page___172 *);
	ssize_t (*direct_IO)(struct kiocb___167 *, struct iov_iter___96 *);
	int (*migratepage)(struct address_space___167 *, struct page___172 *, struct page___172 *, enum migrate_mode);
	bool (*isolate_page)(struct page___172 *, isolate_mode_t);
	void (*putback_page)(struct page___172 *);
	int (*launder_page)(struct page___172 *);
	int (*is_partially_uptodate)(struct page___172 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___172 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___167 *, struct page___172 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___167 *, sector_t *);
	void (*swap_deactivate)(struct file___167 *);
};

struct writeback_control___77 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___77 *wb;
	struct inode___167 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___167 {
	struct dentry___167 * (*lookup)(struct inode___167 *, struct dentry___167 *, unsigned int);
	const char * (*get_link)(struct dentry___167 *, struct inode___167 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___167 *, int);
	struct posix_acl * (*get_acl)(struct inode___167 *, int, bool);
	int (*readlink)(struct dentry___167 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___167 *, struct dentry___167 *, umode_t, bool);
	int (*link)(struct dentry___167 *, struct inode___167 *, struct dentry___167 *);
	int (*unlink)(struct inode___167 *, struct dentry___167 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___167 *, struct dentry___167 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___167 *, struct dentry___167 *, umode_t);
	int (*rmdir)(struct inode___167 *, struct dentry___167 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___167 *, struct dentry___167 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___167 *, struct dentry___167 *, struct inode___167 *, struct dentry___167 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___167 *, struct iattr___167 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___167 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___167 *, char *, size_t);
	int (*fiemap)(struct inode___167 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___167 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___167 *, struct dentry___167 *, struct file___167 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___167 *, struct dentry___167 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___167 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___167 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___167 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___167 {
	void (*fl_copy_lock)(struct file_lock___167 *, struct file_lock___167 *);
	void (*fl_release_private)(struct file_lock___167 *);
};

struct lock_manager_operations___167;

struct file_lock___167 {
	struct file_lock___167 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___167 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___167 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___167 *fl_ops;
	const struct lock_manager_operations___167 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___167 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___167 *);
	int (*lm_grant)(struct file_lock___167 *, int);
	bool (*lm_break)(struct file_lock___167 *);
	int (*lm_change)(struct file_lock___167 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___167 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___167 *);
};

struct fasync_struct___167 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___167 *fa_next;
	struct file___167 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___167 {
	struct inode___167 * (*alloc_inode)(struct super_block___167 *);
	void (*destroy_inode)(struct inode___167 *);
	void (*free_inode)(struct inode___167 *);
	void (*dirty_inode)(struct inode___167 *, int);
	int (*write_inode)(struct inode___167 *, struct writeback_control___77 *);
	int (*drop_inode)(struct inode___167 *);
	void (*evict_inode)(struct inode___167 *);
	void (*put_super)(struct super_block___167 *);
	int (*sync_fs)(struct super_block___167 *, int);
	int (*freeze_super)(struct super_block___167 *);
	int (*freeze_fs)(struct super_block___167 *);
	int (*thaw_super)(struct super_block___167 *);
	int (*unfreeze_fs)(struct super_block___167 *);
	int (*statfs)(struct dentry___167 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___167 *, int *, char *);
	void (*umount_begin)(struct super_block___167 *);
	int (*show_options)(struct seq_file___145 *, struct dentry___167 *);
	int (*show_devname)(struct seq_file___145 *, struct dentry___167 *);
	int (*show_path)(struct seq_file___145 *, struct dentry___167 *);
	int (*show_stats)(struct seq_file___145 *, struct dentry___167 *);
	ssize_t (*quota_read)(struct super_block___167 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___167 *, int, const char *, size_t, loff_t);
	struct dquot___167 ** (*get_dquots)(struct inode___167 *);
	long int (*nr_cached_objects)(struct super_block___167 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___167 *, struct shrink_control___68 *);
	struct file___167 * (*real_loop)(struct file___167 *);
};

struct wakeup_source___123;

struct dev_pm_info___123 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___123 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___123 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___123;

struct bus_type___123;

struct device_driver___123;

struct dev_pm_domain___123;

struct fwnode_handle___123;

struct class___123;

struct attribute_group___154;

struct device___123 {
	struct kobject___154 kobj;
	struct device___123 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___123 *type;
	struct bus_type___123 *bus;
	struct device_driver___123 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___123 power;
	struct dev_pm_domain___123 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___123 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___123 *class;
	const struct attribute_group___154 **groups;
	void (*release)(struct device___123 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___81 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___167 *bd_inode;
	struct super_block___167 *bd_super;
	void *bd_claiming;
	struct device___123 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___154 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___80 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___167 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___110)(struct file___167 *, wait_queue_head_t *, struct poll_table_struct___108 *);

struct poll_table_struct___108 {
	poll_queue_proc___110 _qproc;
	__poll_t _key;
};

struct seq_operations___145;

struct seq_file___145 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___145 *op;
	int poll_event;
	const struct file___167 *file;
	void *private;
};

typedef void bio_end_io_t___80(struct bio___80 *);

struct bio_integrity_payload___80;

struct bio___80 {
	struct bio___80 *bi_next;
	struct block_device___81 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___80 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___77 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___80 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___94 *bi_io_vec;
	struct bio_set___80 *bi_pool;
	struct bio_vec___94 bi_inline_vecs[0];
};

struct ip_ra_chain___15;

struct fib_rules_ops___28;

struct sock___29;

struct fqdir___40;

struct fib_notifier_ops___28;

struct netns_ipv4___40 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___15 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___28 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___29 *fibnl;
	struct sock___29 **icmp_sk;
	struct sock___29 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___29 **tcp_sk;
	struct fqdir___40 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___28 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___28 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___28 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___28;

struct net_device___37;

struct sk_buff___36;

struct neighbour___28;

struct dst_ops___40 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___40 *);
	struct dst_entry___28 * (*check)(struct dst_entry___28 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___28 *);
	unsigned int (*mtu)(const struct dst_entry___28 *);
	u32 * (*cow_metrics)(struct dst_entry___28 *, long unsigned int);
	void (*destroy)(struct dst_entry___28 *);
	void (*ifdown)(struct dst_entry___28 *, struct net_device___37 *, int);
	struct dst_entry___28 * (*negative_advice)(struct dst_entry___28 *);
	void (*link_failure)(struct sk_buff___36 *);
	void (*update_pmtu)(struct dst_entry___28 *, struct sock___29 *, struct sk_buff___36 *, u32, bool);
	void (*redirect)(struct dst_entry___28 *, struct sock___29 *, struct sk_buff___36 *);
	int (*local_out)(struct net___40 *, struct sock___29 *, struct sk_buff___36 *);
	struct neighbour___28 * (*neigh_lookup)(const struct dst_entry___28 *, struct sk_buff___36 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___28 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___40 {
	struct dst_ops___40 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___40 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___28 *fib6_rules_ops;
	struct sock___29 **icmp_sk;
	struct sock___29 *ndisc_sk;
	struct sock___29 *tcp_sk;
	struct sock___29 *igmp_sk;
	struct sock___29 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___28 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___28 *notifier_ops;
	struct fib_notifier_ops___28 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___40 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___40 *fqdir;
};

struct netns_sctp___28 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___29 *ctl_sock;
	struct sock___29 *udp4_sock;
	struct sock___29 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___35 {
	struct sk_buff___36 *next;
	struct sk_buff___36 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___35;

struct netns_bpf___35 {
	struct bpf_prog_array___35 *run_array[2];
	struct bpf_prog___35 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___40 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___29 *nlsk;
	struct sock___29 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___40 xfrm4_dst_ops;
	struct dst_ops___40 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___40 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___29 *rtnl;
	struct sock___29 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___37 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___40 ipv4;
	struct netns_ipv6___40 ipv6;
	struct netns_ieee802154_lowpan___40 ieee802154_lowpan;
	struct netns_sctp___28 sctp;
	struct netns_nf___3 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___35 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___35 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___40 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___29 *crypto_nlsk;
	struct sock___29 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___116 {
	struct ns_common___26 ns;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	struct css_set___116 *root_cset;
};

struct fwnode_operations___123;

struct fwnode_handle___123 {
	struct fwnode_handle___123 *secondary;
	const struct fwnode_operations___123 *ops;
	struct device___123 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___123;

struct fwnode_endpoint___123;

struct fwnode_operations___123 {
	struct fwnode_handle___123 * (*get)(struct fwnode_handle___123 *);
	void (*put)(struct fwnode_handle___123 *);
	bool (*device_is_available)(const struct fwnode_handle___123 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___123 *, const struct device___123 *);
	bool (*property_present)(const struct fwnode_handle___123 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___123 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___123 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___123 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*get_parent)(const struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*get_next_child_node)(const struct fwnode_handle___123 *, struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*get_named_child_node)(const struct fwnode_handle___123 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___123 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___123 *);
	struct fwnode_handle___123 * (*graph_get_next_endpoint)(const struct fwnode_handle___123 *, struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*graph_get_remote_endpoint)(const struct fwnode_handle___123 *);
	struct fwnode_handle___123 * (*graph_get_port_parent)(struct fwnode_handle___123 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___123 *, struct fwnode_endpoint___123 *);
	int (*add_links)(struct fwnode_handle___123 *);
};

struct fwnode_endpoint___123 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___123 *local_fwnode;
};

struct fwnode_reference_args___123 {
	struct fwnode_handle___123 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___154;

struct kernfs_elem_dir___154 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___154 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___154;

struct kernfs_root___154 {
	struct kernfs_node___154 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___154 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___154 {
	struct kernfs_node___154 *target_kn;
};

struct kernfs_ops___154;

struct kernfs_elem_attr___154 {
	const struct kernfs_ops___154 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___154 *notify_next;
};

struct kernfs_node___154 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___154 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___154 dir;
		struct kernfs_elem_symlink___154 symlink;
		struct kernfs_elem_attr___154 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___154;

struct kernfs_ops___154 {
	int (*open)(struct kernfs_open_file___154 *);
	void (*release)(struct kernfs_open_file___154 *);
	int (*seq_show)(struct seq_file___145 *, void *);
	void * (*seq_start)(struct seq_file___145 *, loff_t *);
	void * (*seq_next)(struct seq_file___145 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___145 *, void *);
	ssize_t (*read)(struct kernfs_open_file___154 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___154 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___154 *, struct poll_table_struct___108 *);
	int (*mmap)(struct kernfs_open_file___154 *, struct vm_area_struct___172 *);
};

struct kernfs_syscall_ops___154 {
	int (*show_options)(struct seq_file___145 *, struct kernfs_root___154 *);
	int (*mkdir)(struct kernfs_node___154 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___154 *);
	int (*rename)(struct kernfs_node___154 *, struct kernfs_node___154 *, const char *);
	int (*show_path)(struct seq_file___145 *, struct kernfs_node___154 *, struct kernfs_root___154 *);
};

struct kernfs_open_file___154 {
	struct kernfs_node___154 *kn;
	struct file___167 *file;
	struct seq_file___145 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___163 *vm_ops;
};

struct kobj_ns_type_operations___28 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___29 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___40 *net;
} possible_net_t___35;

struct proto___28;

struct sock_common___28 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___28 *skc_prot;
	possible_net_t___35 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___29 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___28 {
	struct cgroup___116 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___28;

struct socket_wq___29;

struct socket___29;

struct sock___29 {
	struct sock_common___28 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___35 sk_error_queue;
	struct sk_buff___36 *sk_rx_skb_cache;
	struct sk_buff_head___35 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___36 *head;
		struct sk_buff___36 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___28 *sk_filter;
	union {
		struct socket_wq___29 *sk_wq;
		struct socket_wq___29 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___28 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___28 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___36 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___36 *sk_tx_skb_cache;
	struct sk_buff_head___35 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___172 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___28 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___148 *sk_peer_pid;
	const struct cred___27 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___29 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___28 sk_cgrp_data;
	struct mem_cgroup___68 *sk_memcg;
	void (*sk_state_change)(struct sock___29 *);
	void (*sk_data_ready)(struct sock___29 *);
	void (*sk_write_space)(struct sock___29 *);
	void (*sk_error_report)(struct sock___29 *);
	int (*sk_backlog_rcv)(struct sock___29 *, struct sk_buff___36 *);
	struct sk_buff___36 * (*sk_validate_xmit_skb)(struct sock___29 *, struct net_device___37 *, struct sk_buff___36 *);
	void (*sk_destruct)(struct sock___29 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___154;

struct attribute_group___154 {
	const char *name;
	umode_t (*is_visible)(struct kobject___154 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___154 *, struct bin_attribute___154 *, int);
	struct attribute **attrs;
	struct bin_attribute___154 **bin_attrs;
};

struct bin_attribute___154 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___167 * (*f_mapping)();
	ssize_t (*read)(struct file___167 *, struct kobject___154 *, struct bin_attribute___154 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___167 *, struct kobject___154 *, struct bin_attribute___154 *, char *, loff_t, size_t);
	int (*mmap)(struct file___167 *, struct kobject___154 *, struct bin_attribute___154 *, struct vm_area_struct___172 *);
};

struct sysfs_ops___154 {
	ssize_t (*show)(struct kobject___154 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___154 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___154;

struct kset___154 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___154 kobj;
	const struct kset_uevent_ops___154 *uevent_ops;
};

struct kobj_type___154 {
	void (*release)(struct kobject___154 *);
	const struct sysfs_ops___154 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___154 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___154 *);
	const void * (*namespace)(struct kobject___154 *);
	void (*get_ownership)(struct kobject___154 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___154 {
	int (* const filter)(struct kset___154 *, struct kobject___154 *);
	const char * (* const name)(struct kset___154 *, struct kobject___154 *);
	int (* const uevent)(struct kset___154 *, struct kobject___154 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___151 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___151 *);
	int (*get)(char *, const struct kernel_param___151 *);
	void (*free)(void *);
};

struct kparam_array___151;

struct kernel_param___151 {
	const char *name;
	struct module___151 *mod;
	const struct kernel_param_ops___151 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___151 *arr;
	};
};

struct kparam_array___151 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___151 *ops;
	void *elem;
};

struct module_attribute___151 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___151 *, struct module_kobject___151 *, char *);
	ssize_t (*store)(struct module_attribute___151 *, struct module_kobject___151 *, const char *, size_t);
	void (*setup)(struct module___151 *, const char *);
	int (*test)(struct module___151 *);
	void (*free)(struct module___151 *);
};

struct socket_wq___29 {
	wait_queue_head_t wait;
	struct fasync_struct___167 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___29;

struct socket___29 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___167 *file;
	struct sock___29 *sk;
	const struct proto_ops___29 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___29 wq;
};

typedef int (*sk_read_actor_t___28)(read_descriptor_t *, struct sk_buff___36 *, unsigned int, size_t);

struct proto_ops___29 {
	int family;
	struct module___151 *owner;
	int (*release)(struct socket___29 *);
	int (*bind)(struct socket___29 *, struct sockaddr *, int);
	int (*connect)(struct socket___29 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___29 *, struct socket___29 *);
	int (*accept)(struct socket___29 *, struct socket___29 *, int, bool);
	int (*getname)(struct socket___29 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___167 *, struct socket___29 *, struct poll_table_struct___108 *);
	int (*ioctl)(struct socket___29 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___29 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___29 *, void *, bool, bool);
	int (*listen)(struct socket___29 *, int);
	int (*shutdown)(struct socket___29 *, int);
	int (*setsockopt)(struct socket___29 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___29 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___145 *, struct socket___29 *);
	int (*sendmsg)(struct socket___29 *, struct msghdr___29 *, size_t);
	int (*recvmsg)(struct socket___29 *, struct msghdr___29 *, size_t, int);
	int (*mmap)(struct file___167 *, struct socket___29 *, struct vm_area_struct___172 *);
	ssize_t (*sendpage)(struct socket___29 *, struct page___172 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___29 *, loff_t *, struct pipe_inode_info___60 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___29 *, int);
	int (*peek_len)(struct socket___29 *);
	int (*read_sock)(struct sock___29 *, read_descriptor_t *, sk_read_actor_t___28);
	int (*sendpage_locked)(struct sock___29 *, struct page___172 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___29 *, struct msghdr___29 *, size_t);
	int (*set_rcvlowat)(struct sock___29 *, int);
};

struct sk_buff___36 {
	union {
		struct {
			struct sk_buff___36 *next;
			struct sk_buff___36 *prev;
			union {
				struct net_device___37 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___29 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___36 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___123 {
	int (*prepare)(struct device___123 *);
	void (*complete)(struct device___123 *);
	int (*suspend)(struct device___123 *);
	int (*resume)(struct device___123 *);
	int (*freeze)(struct device___123 *);
	int (*thaw)(struct device___123 *);
	int (*poweroff)(struct device___123 *);
	int (*restore)(struct device___123 *);
	int (*suspend_late)(struct device___123 *);
	int (*resume_early)(struct device___123 *);
	int (*freeze_late)(struct device___123 *);
	int (*thaw_early)(struct device___123 *);
	int (*poweroff_late)(struct device___123 *);
	int (*restore_early)(struct device___123 *);
	int (*suspend_noirq)(struct device___123 *);
	int (*resume_noirq)(struct device___123 *);
	int (*freeze_noirq)(struct device___123 *);
	int (*thaw_noirq)(struct device___123 *);
	int (*poweroff_noirq)(struct device___123 *);
	int (*restore_noirq)(struct device___123 *);
	int (*runtime_suspend)(struct device___123 *);
	int (*runtime_resume)(struct device___123 *);
	int (*runtime_idle)(struct device___123 *);
};

struct wakeup_source___123 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___123 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___123 {
	struct dev_pm_ops___123 ops;
	int (*start)(struct device___123 *);
	void (*detach)(struct device___123 *, bool);
	int (*activate)(struct device___123 *);
	void (*sync)(struct device___123 *);
	void (*dismiss)(struct device___123 *);
};

struct bus_type___123 {
	const char *name;
	const char *dev_name;
	struct device___123 *dev_root;
	const struct attribute_group___154 **bus_groups;
	const struct attribute_group___154 **dev_groups;
	const struct attribute_group___154 **drv_groups;
	int (*match)(struct device___123 *, struct device_driver___123 *);
	int (*uevent)(struct device___123 *, struct kobj_uevent_env *);
	int (*probe)(struct device___123 *);
	void (*sync_state)(struct device___123 *);
	void (*remove)(struct device___123 *);
	void (*shutdown)(struct device___123 *);
	int (*online)(struct device___123 *);
	int (*offline)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	int (*num_vf)(struct device___123 *);
	int (*dma_configure)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___123 {
	const char *name;
	struct bus_type___123 *bus;
	struct module___151 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___123 *);
	void (*sync_state)(struct device___123 *);
	int (*remove)(struct device___123 *);
	void (*shutdown)(struct device___123 *);
	int (*suspend)(struct device___123 *, pm_message_t);
	int (*resume)(struct device___123 *);
	const struct attribute_group___154 **groups;
	const struct attribute_group___154 **dev_groups;
	const struct dev_pm_ops___123 *pm;
	void (*coredump)(struct device___123 *);
	struct driver_private *p;
};

struct device_type___123 {
	const char *name;
	const struct attribute_group___154 **groups;
	int (*uevent)(struct device___123 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___123 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___123 *);
	const struct dev_pm_ops___123 *pm;
};

struct class___123 {
	const char *name;
	struct module___151 *owner;
	const struct attribute_group___154 **class_groups;
	const struct attribute_group___154 **dev_groups;
	struct kobject___154 *dev_kobj;
	int (*dev_uevent)(struct device___123 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___123 *, umode_t *);
	void (*class_release)(struct class___123 *);
	void (*dev_release)(struct device___123 *);
	int (*shutdown_pre)(struct device___123 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___123 *);
	void (*get_ownership)(struct device___123 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___123 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___60;

struct pipe_buffer___60 {
	struct page___172 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___60 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___60 {
	int (*confirm)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
	void (*release)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
	bool (*try_steal)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
	bool (*get)(struct pipe_inode_info___60 *, struct pipe_buffer___60 *);
};

typedef rx_handler_result_t rx_handler_func_t___35(struct sk_buff___36 **);

struct bpf_xdp_entity___35 {
	struct bpf_prog___35 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___35;

struct net_device_ops___35;

struct ethtool_ops___13;

struct l3mdev_ops___28;

struct ndisc_ops___18;

struct xfrmdev_ops___35;

struct header_ops___35;

struct inet6_dev___18;

struct netdev_rx_queue___35;

struct mini_Qdisc___35;

struct netdev_queue___35;

struct Qdisc___35;

struct rtnl_link_ops___35;

struct dcbnl_rtnl_ops___35;

struct net_device___37 {
	char name[16];
	struct netdev_name_node___35 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___35 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___13 *ethtool_ops;
	const struct l3mdev_ops___28 *l3mdev_ops;
	const struct ndisc_ops___18 *ndisc_ops;
	const struct xfrmdev_ops___35 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___35 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___154 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___18 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___35 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___35 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___35 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___35 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___35 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___35 = 0,
		NETREG_REGISTERED___35 = 1,
		NETREG_UNREGISTERING___35 = 2,
		NETREG_UNREGISTERED___35 = 3,
		NETREG_RELEASED___35 = 4,
		NETREG_DUMMY___35 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___35 = 0,
		RTNL_LINK_INITIALIZING___35 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___37 *);
	struct netpoll_info *npinfo;
	possible_net_t___35 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___123 dev;
	const struct attribute_group___154 *sysfs_groups[4];
	const struct attribute_group___154 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___35 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___35 xdp_state[3];
	long: 64;
};

struct netlink_callback___35 {
	struct sk_buff___36 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___36 *, struct netlink_callback___35 *);
	int (*done)(struct netlink_callback___35 *);
	void *data;
	struct module___151 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_ops___13 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___37 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___37 *);
	void (*get_regs)(struct net_device___37 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___37 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___37 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___37 *);
	void (*set_msglevel)(struct net_device___37 *, u32);
	int (*nway_reset)(struct net_device___37 *);
	u32 (*get_link)(struct net_device___37 *);
	int (*get_link_ext_state)(struct net_device___37 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___37 *);
	int (*get_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___37 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___37 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___37 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___37 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___37 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___37 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___37 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___37 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___37 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___37 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___37 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___37 *);
	void (*complete)(struct net_device___37 *);
	u32 (*get_priv_flags)(struct net_device___37 *);
	int (*set_priv_flags)(struct net_device___37 *, u32);
	int (*get_sset_count)(struct net_device___37 *, int);
	int (*get_rxnfc)(struct net_device___37 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___37 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___37 *, struct ethtool_flash *);
	int (*reset)(struct net_device___37 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___37 *);
	u32 (*get_rxfh_indir_size)(struct net_device___37 *);
	int (*get_rxfh)(struct net_device___37 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___37 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___37 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___37 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___37 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___37 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___37 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___37 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___37 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___37 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___37 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___37 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___37 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___37 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___37 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___37 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___37 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___37 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___37 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___37 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___37 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___37 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___37 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___37 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___37 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___37 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___37 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___37 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___37 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___37 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___37 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct inet_frags___40;

struct fqdir___40 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___40 *f;
	struct net___40 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___40;

struct inet_frags___40 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___40 *, const void *);
	void (*destructor)(struct inet_frag_queue___40 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___40 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___36 *fragments_tail;
	struct sk_buff___36 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___40 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___15 {
	struct ip_ra_chain___15 *next;
	struct sock___29 *sk;
	union {
		void (*destructor)(struct sock___29 *);
		struct sock___29 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___28;

struct fib_lookup_arg___28;

struct fib_rules_ops___28 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___28 *, struct flowi *, int, struct fib_lookup_arg___28 *);
	bool (*suppress)(struct fib_rule___28 *, int, struct fib_lookup_arg___28 *);
	int (*match)(struct fib_rule___28 *, struct flowi *, int);
	int (*configure)(struct fib_rule___28 *, struct sk_buff___36 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___28 *);
	int (*compare)(struct fib_rule___28 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___28 *, struct sk_buff___36 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___28 *);
	void (*flush_cache)(struct fib_rules_ops___28 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___151 *owner;
	struct net___40 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___28 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___40 *);
	int (*fib_dump)(struct net___40 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___151 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___15;

struct dst_entry___28 {
	struct net_device___37 *dev;
	struct dst_ops___40 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___36 *);
	int (*output)(struct net___40 *, struct sock___29 *, struct sk_buff___36 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___15 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___28;

struct neigh_parms___28;

struct neigh_ops___28;

struct neighbour___28 {
	struct neighbour___28 *next;
	struct neigh_table___28 *tbl;
	struct neigh_parms___28 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___35 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___28 *, struct sk_buff___36 *);
	const struct neigh_ops___28 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___37 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___35 {
	struct bpf_prog___35 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___35 {
	struct callback_head rcu;
	struct bpf_prog_array_item___35 items[0];
};

struct bpf_prog_aux___37;

struct bpf_prog___35 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___37 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___145 {
	void * (*start)(struct seq_file___145 *, loff_t *);
	void (*stop)(struct seq_file___145 *, void *);
	void * (*next)(struct seq_file___145 *, void *, loff_t *);
	int (*show)(struct seq_file___145 *, void *);
};

struct dcbnl_rtnl_ops___35 {
	int (*ieee_getets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___37 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___37 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___37 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___37 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___37 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___37 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___37 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___37 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___37 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___37 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___37 *);
	u8 (*setstate)(struct net_device___37 *, u8);
	void (*getpermhwaddr)(struct net_device___37 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___37 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___37 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___37 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___37 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___37 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___37 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___37 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___37 *, int, u8 *);
	void (*setpfccfg)(struct net_device___37 *, int, u8);
	void (*getpfccfg)(struct net_device___37 *, int, u8 *);
	u8 (*setall)(struct net_device___37 *);
	u8 (*getcap)(struct net_device___37 *, int, u8 *);
	int (*getnumtcs)(struct net_device___37 *, int, u8 *);
	int (*setnumtcs)(struct net_device___37 *, int, u8);
	u8 (*getpfcstate)(struct net_device___37 *);
	void (*setpfcstate)(struct net_device___37 *, u8);
	void (*getbcncfg)(struct net_device___37 *, int, u32 *);
	void (*setbcncfg)(struct net_device___37 *, int, u32);
	void (*getbcnrp)(struct net_device___37 *, int, u8 *);
	void (*setbcnrp)(struct net_device___37 *, int, u8);
	int (*setapp)(struct net_device___37 *, u8, u16, u8);
	int (*getapp)(struct net_device___37 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___37 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___37 *, int, u8);
	u8 (*getdcbx)(struct net_device___37 *);
	u8 (*setdcbx)(struct net_device___37 *, u8);
	int (*peer_getappinfo)(struct net_device___37 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___37 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___37 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___37 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___37 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___37 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___38;

typedef int (*bpf_iter_init_seq_priv_t___37)(void *, struct bpf_iter_aux_info___38 *);

struct bpf_map___37;

struct bpf_iter_aux_info___38 {
	struct bpf_map___37 *map;
};

struct bpf_iter_seq_info___37 {
	const struct seq_operations___145 *seq_ops;
	bpf_iter_init_seq_priv_t___37 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___37 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___37 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___37 *, struct file___167 *);
	void (*map_free)(struct bpf_map___37 *);
	int (*map_get_next_key)(struct bpf_map___37 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___37 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___37 *, void *);
	int (*map_lookup_batch)(struct bpf_map___37 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___37 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___37 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___37 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___37 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___37 *, void *);
	int (*map_update_elem)(struct bpf_map___37 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___37 *, void *);
	int (*map_push_elem)(struct bpf_map___37 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___37 *, void *);
	int (*map_peek_elem)(struct bpf_map___37 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___37 *, struct file___167 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___37 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___37 *, void *, struct seq_file___145 *);
	int (*map_check_btf)(const struct bpf_map___37 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___37 *, struct bpf_prog_aux___37 *);
	void (*map_poke_untrack)(struct bpf_map___37 *, struct bpf_prog_aux___37 *);
	void (*map_poke_run)(struct bpf_map___37 *, u32, struct bpf_prog___35 *, struct bpf_prog___35 *);
	int (*map_direct_value_addr)(const struct bpf_map___37 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___37 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___37 *, struct vm_area_struct___172 *);
	__poll_t (*map_poll)(struct bpf_map___37 *, struct file___167 *, struct poll_table_struct___108 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___37 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___37 *, const struct bpf_map___37 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___37 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___37 *iter_seq_info;
};

struct bpf_map___37 {
	const struct bpf_map_ops___37 *ops;
	struct bpf_map___37 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___68 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___37;

struct bpf_jit_poke_descriptor___37;

struct bpf_prog_ops___35;

struct btf_mod_pair___37;

struct bpf_prog_offload___35;

struct bpf_prog_aux___37 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___35 *dst_prog;
	struct bpf_trampoline___37 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___35 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___37 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___35 *ops;
	struct bpf_map___37 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___37 *used_btfs;
	struct bpf_prog___35 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___37 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___35 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___35;

struct bpf_map_dev_ops___35 {
	int (*map_get_next_key)(struct bpf_offloaded_map___35 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___35 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___35 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___35 *, void *);
};

struct bpf_offloaded_map___35 {
	struct bpf_map___37 map;
	struct net_device___37 *netdev;
	const struct bpf_map_dev_ops___35 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___35 {
	int (*test_run)(struct bpf_prog___35 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___35 {
	struct bpf_prog___35 *prog;
	struct net_device___37 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___37 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___35 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___151 *mod;
};

struct bpf_jit_poke_descriptor___37 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___37 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___37 {
	struct btf *btf;
	struct module___151 *module;
};

struct cftype___116;

struct cgroup_subsys___116 {
	struct cgroup_subsys_state___116 * (*css_alloc)(struct cgroup_subsys_state___116 *);
	int (*css_online)(struct cgroup_subsys_state___116 *);
	void (*css_offline)(struct cgroup_subsys_state___116 *);
	void (*css_released)(struct cgroup_subsys_state___116 *);
	void (*css_free)(struct cgroup_subsys_state___116 *);
	void (*css_reset)(struct cgroup_subsys_state___116 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___116 *, int);
	int (*css_extra_stat_show)(struct seq_file___145 *, struct cgroup_subsys_state___116 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___174 *, struct css_set___116 *);
	void (*cancel_fork)(struct task_struct___174 *, struct css_set___116 *);
	void (*fork)(struct task_struct___174 *);
	void (*exit)(struct task_struct___174 *);
	void (*release)(struct task_struct___174 *);
	void (*bind)(struct cgroup_subsys_state___116 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___116 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___116 *dfl_cftypes;
	struct cftype___116 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___116 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___116 *updated_children;
	struct cgroup___116 *updated_next;
};

struct cgroup_root___116 {
	struct kernfs_root___154 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___116 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___116 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___116 *ss;
	struct list_head node;
	struct kernfs_ops___154 *kf_ops;
	int (*open)(struct kernfs_open_file___154 *);
	void (*release)(struct kernfs_open_file___154 *);
	u64 (*read_u64)(struct cgroup_subsys_state___116 *, struct cftype___116 *);
	s64 (*read_s64)(struct cgroup_subsys_state___116 *, struct cftype___116 *);
	int (*seq_show)(struct seq_file___145 *, void *);
	void * (*seq_start)(struct seq_file___145 *, loff_t *);
	void * (*seq_next)(struct seq_file___145 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___145 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___116 *, struct cftype___116 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___116 *, struct cftype___116 *, s64);
	ssize_t (*write)(struct kernfs_open_file___154 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___154 *, struct poll_table_struct___108 *);
};

struct xdp_rxq_info___35 {
	struct net_device___37 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___35 {
	struct net_device___37 *dev;
};

struct xdp_buff___35 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___35 *rxq;
	struct xdp_txq_info___35 *txq;
	u32 frame_sz;
};

struct xdp_frame___35 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___37 *dev_rx;
};

struct header_ops___35 {
	int (*create)(struct sk_buff___36 *, struct net_device___37 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___36 *, unsigned char *);
	int (*cache)(const struct neighbour___28 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___37 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___36 *);
};

struct netdev_queue___35 {
	struct net_device___37 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___154 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___37 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___35 {
	struct sk_buff___36 *head;
	struct sk_buff___36 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___35;

struct Qdisc___35 {
	int (*enqueue)(struct sk_buff___36 *, struct Qdisc___35 *, struct sk_buff___36 **);
	struct sk_buff___36 * (*dequeue)(struct Qdisc___35 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___35 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___35 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___35 gso_skb;
	struct qdisc_skb_head___35 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___35 *next_sched;
	struct sk_buff_head___35 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___35 {
	struct xdp_rxq_info___35 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___154 kobj;
	struct net_device___37 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___35 {
	enum net_device_path_type type;
	const struct net_device___37 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___35 = 0,
				DEV_PATH_BR_VLAN_TAG___35 = 1,
				DEV_PATH_BR_VLAN_UNTAG___35 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___35 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___35 {
	const struct net_device___37 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___35 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___35 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___35 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___35 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___36 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___35 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___37 *dev;
	const char *name;
};

struct net_device_ops___35 {
	int (*ndo_init)(struct net_device___37 *);
	void (*ndo_uninit)(struct net_device___37 *);
	int (*ndo_open)(struct net_device___37 *);
	int (*ndo_stop)(struct net_device___37 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___36 *, struct net_device___37 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___36 *, struct net_device___37 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___37 *, struct sk_buff___36 *, struct net_device___37 *);
	void (*ndo_change_rx_flags)(struct net_device___37 *, int);
	void (*ndo_set_rx_mode)(struct net_device___37 *);
	int (*ndo_set_mac_address)(struct net_device___37 *, void *);
	int (*ndo_validate_addr)(struct net_device___37 *);
	int (*ndo_do_ioctl)(struct net_device___37 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___37 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___37 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___37 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___37 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___37 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___37 *, int);
	int (*ndo_neigh_setup)(struct net_device___37 *, struct neigh_parms___28 *);
	void (*ndo_tx_timeout)(struct net_device___37 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___37 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___37 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___37 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___37 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___37 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___37 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___37 *);
	int (*ndo_netpoll_setup)(struct net_device___37 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___37 *);
	int (*ndo_set_vf_mac)(struct net_device___37 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___37 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___37 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___37 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___37 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___37 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___37 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___37 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___37 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___37 *, int, struct sk_buff___36 *);
	int (*ndo_get_vf_guid)(struct net_device___37 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___37 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___37 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___37 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___37 *);
	int (*ndo_fcoe_disable)(struct net_device___37 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___37 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___37 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___37 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___37 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___37 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___37 *, const struct sk_buff___36 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___37 *, struct net_device___37 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___37 *, struct net_device___37 *);
	struct net_device___37 * (*ndo_get_xmit_slave)(struct net_device___37 *, struct sk_buff___36 *, bool);
	struct net_device___37 * (*ndo_sk_get_lower_dev)(struct net_device___37 *, struct sock___29 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___37 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___37 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___37 *, struct neighbour___28 *);
	void (*ndo_neigh_destroy)(struct net_device___37 *, struct neighbour___28 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___36 *, struct netlink_callback___35 *, struct net_device___37 *, struct net_device___37 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___36 *, struct nlattr **, struct net_device___37 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___37 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___36 *, u32, u32, struct net_device___37 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___37 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___37 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___37 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___37 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___37 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___37 *, struct net_device___37 *);
	void (*ndo_dfwd_del_station)(struct net_device___37 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___37 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___37 *);
	int (*ndo_change_proto_down)(struct net_device___37 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___37 *, struct sk_buff___36 *);
	void (*ndo_set_rx_headroom)(struct net_device___37 *, int);
	int (*ndo_bpf)(struct net_device___37 *, struct netdev_bpf___35 *);
	int (*ndo_xdp_xmit)(struct net_device___37 *, int, struct xdp_frame___35 **, u32);
	struct net_device___37 * (*ndo_xdp_get_xmit_slave)(struct net_device___37 *, struct xdp_buff___35 *);
	int (*ndo_xsk_wakeup)(struct net_device___37 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___37 *);
	int (*ndo_tunnel_ctl)(struct net_device___37 *, struct ip_tunnel_parm *, int);
	struct net_device___37 * (*ndo_get_peer_dev)(struct net_device___37 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___35 *, struct net_device_path___35 *);
};

struct neigh_parms___28 {
	possible_net_t___35 net;
	struct net_device___37 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___28 *);
	struct neigh_table___28 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___28 {
	u32 (*l3mdev_fib_table)(const struct net_device___37 *);
	struct sk_buff___36 * (*l3mdev_l3_rcv)(struct net_device___37 *, struct sk_buff___36 *, u16);
	struct sk_buff___36 * (*l3mdev_l3_out)(struct net_device___37 *, struct sock___29 *, struct sk_buff___36 *, u16);
	struct dst_entry___28 * (*l3mdev_link_scope_lookup)(const struct net_device___37 *, struct flowi6 *);
};

struct ndisc_ops___18 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___37 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___37 *, struct neighbour___28 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___37 *, u8, struct neighbour___28 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___37 *, struct sk_buff___36 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___40 *, struct net_device___37 *, const struct prefix_info *, struct inet6_dev___18 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___18;

struct inet6_dev___18 {
	struct net_device___37 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___18 *mc_list;
	struct ifmcaddr6___18 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___35 mc_query_queue;
	struct sk_buff_head___35 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___28 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___35;

struct tcf_block___35;

struct mini_Qdisc___35 {
	struct tcf_proto___35 *filter_list;
	struct tcf_block___35 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___35 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___37 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___37 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___40 *, struct net_device___37 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___37 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___37 *, struct list_head *);
	size_t (*get_size)(const struct net_device___37 *);
	int (*fill_info)(struct sk_buff___36 *, const struct net_device___37 *);
	size_t (*get_xstats_size)(const struct net_device___37 *);
	int (*fill_xstats)(struct sk_buff___36 *, const struct net_device___37 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___37 *, struct net_device___37 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___37 *, const struct net_device___37 *);
	int (*fill_slave_info)(struct sk_buff___36 *, const struct net_device___37 *, const struct net_device___37 *);
	struct net___40 * (*get_link_net)(const struct net_device___37 *);
	size_t (*get_linkxstats_size)(const struct net_device___37 *, int);
	int (*fill_linkxstats)(struct sk_buff___36 *, const struct net_device___37 *, int *, int);
};

struct block_device_operations___80;

struct gendisk___80 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___81 *part0;
	const struct block_device_operations___80 *fops;
	struct request_queue___80 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___77 *bdi;
	struct kobject___154 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___154 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___80 {
	struct bio___80 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___94 *bip_vec;
	struct bio_vec___94 bip_inline_vecs[0];
};

struct blkcg___77;

struct blkg_policy_data___77;

struct blkcg_gq___77 {
	struct request_queue___80 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___77 *blkcg;
	struct blkcg_gq___77 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___77 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___80 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___80(struct request___80 *);

typedef void integrity_complete_fn___80(struct request___80 *, unsigned int);

struct blk_integrity_profile___80 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___80 *prepare_fn;
	integrity_complete_fn___80 *complete_fn;
	const char *name;
};

struct block_device_operations___80 {
	blk_qc_t (*submit_bio)(struct bio___80 *);
	int (*open)(struct block_device___81 *, fmode_t);
	void (*release)(struct gendisk___80 *, fmode_t);
	int (*rw_page)(struct block_device___81 *, sector_t, struct page___172 *, unsigned int);
	int (*ioctl)(struct block_device___81 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___81 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___80 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___80 *);
	int (*getgeo)(struct block_device___81 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___81 *, bool);
	void (*swap_slot_free_notify)(struct block_device___81 *, long unsigned int);
	int (*report_zones)(struct gendisk___80 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___80 *, umode_t *);
	struct module___151 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___80 *, sector_t *);
};

typedef void rq_end_io_fn___80(struct request___80 *, blk_status_t);

struct request___80 {
	struct request_queue___80 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___77 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___80 *bio;
	struct bio___80 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___94 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___80 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___80 *saved_end_io;
		} flush;
	};
	struct gendisk___80 *rq_disk;
	struct block_device___81 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___80 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___77 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___80 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___154 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___167 *debugfs_dir;
	struct dentry___167 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___80;

struct elevator_mq_ops___80 {
	int (*init_sched)(struct request_queue___80 *, struct elevator_type___80 *);
	void (*exit_sched)(struct elevator_queue___80 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___77 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___77 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___77 *);
	bool (*allow_merge)(struct request_queue___80 *, struct request___80 *, struct bio___80 *);
	bool (*bio_merge)(struct request_queue___80 *, struct bio___80 *, unsigned int);
	int (*request_merge)(struct request_queue___80 *, struct request___80 **, struct bio___80 *);
	void (*request_merged)(struct request_queue___80 *, struct request___80 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___80 *, struct request___80 *, struct request___80 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___80 *);
	void (*finish_request)(struct request___80 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___77 *, struct list_head *, bool);
	struct request___80 * (*dispatch_request)(struct blk_mq_hw_ctx___77 *);
	bool (*has_work)(struct blk_mq_hw_ctx___77 *);
	void (*completed_request)(struct request___80 *, u64);
	void (*requeue_request)(struct request___80 *);
	struct request___80 * (*former_request)(struct request_queue___80 *, struct request___80 *);
	struct request___80 * (*next_request)(struct request_queue___80 *, struct request___80 *);
	void (*init_icq)(struct io_cq___80 *);
	void (*exit_icq)(struct io_cq___80 *);
};

struct elv_fs_entry___80;

struct elevator_type___80 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___80 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___80 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___151 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___80 {
	struct elevator_type___80 *type;
	void *elevator_data;
	struct kobject___154 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___80 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___80 *, char *);
	ssize_t (*store)(struct elevator_queue___80 *, const char *, size_t);
};

struct blk_mq_queue_data___77;

struct blk_mq_ops___77 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___77 *, const struct blk_mq_queue_data___77 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___77 *);
	int (*get_budget)(struct request_queue___80 *);
	void (*put_budget)(struct request_queue___80 *, int);
	void (*set_rq_budget_token)(struct request___80 *, int);
	int (*get_rq_budget_token)(struct request___80 *);
	enum blk_eh_timer_return (*timeout)(struct request___80 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___77 *);
	void (*complete)(struct request___80 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___77 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___77 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___77 *, struct request___80 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___77 *, struct request___80 *, unsigned int);
	void (*initialize_rq_fn)(struct request___80 *);
	void (*cleanup_rq)(struct request___80 *);
	bool (*busy)(struct request_queue___80 *);
	int (*map_queues)(struct blk_mq_tag_set___77 *);
	void (*show_rq)(struct seq_file___145 *, struct request___80 *);
};

struct blk_mq_tag_set___77 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___77 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___77 {
	struct request___80 *rq;
	bool last;
};

struct blkcg_policy_data___77;

struct blkcg___77 {
	struct cgroup_subsys_state___116 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___77 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___77 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___77 {
	struct blkcg___77 *blkcg;
	int plid;
};

struct blkg_policy_data___77 {
	struct blkcg_gq___77 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___68 {
	struct mem_cgroup___68 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___68 {
	struct lruvec___75 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___68 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___68 *memcg;
};

struct obj_cgroup___68 {
	struct percpu_ref refcnt;
	struct mem_cgroup___68 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___35 {
	spinlock_t *lock;
	struct sk_buff___36 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___35;

struct Qdisc_ops___35 {
	struct Qdisc_ops___35 *next;
	const struct Qdisc_class_ops___35 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___36 *, struct Qdisc___35 *, struct sk_buff___36 **);
	struct sk_buff___36 * (*dequeue)(struct Qdisc___35 *);
	struct sk_buff___36 * (*peek)(struct Qdisc___35 *);
	int (*init)(struct Qdisc___35 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___35 *);
	void (*destroy)(struct Qdisc___35 *);
	int (*change)(struct Qdisc___35 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___35 *);
	int (*change_tx_queue_len)(struct Qdisc___35 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___35 *, unsigned int);
	int (*dump)(struct Qdisc___35 *, struct sk_buff___36 *);
	int (*dump_stats)(struct Qdisc___35 *, struct gnet_dump___35 *);
	void (*ingress_block_set)(struct Qdisc___35 *, u32);
	void (*egress_block_set)(struct Qdisc___35 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___35 *);
	u32 (*egress_block_get)(struct Qdisc___35 *);
	struct module___151 *owner;
};

struct Qdisc_class_ops___35 {
	unsigned int flags;
	struct netdev_queue___35 * (*select_queue)(struct Qdisc___35 *, struct tcmsg *);
	int (*graft)(struct Qdisc___35 *, long unsigned int, struct Qdisc___35 *, struct Qdisc___35 **, struct netlink_ext_ack *);
	struct Qdisc___35 * (*leaf)(struct Qdisc___35 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___35 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___35 *, u32);
	int (*change)(struct Qdisc___35 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___35 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___35 *, struct qdisc_walker *);
	struct tcf_block___35 * (*tcf_block)(struct Qdisc___35 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___35 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___35 *, long unsigned int);
	int (*dump)(struct Qdisc___35 *, long unsigned int, struct sk_buff___36 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___35 *, long unsigned int, struct gnet_dump___35 *);
};

struct tcf_chain___35;

struct tcf_block___35 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___40 *net;
	struct Qdisc___35 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___35 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___35;

struct tcf_proto_ops___35;

struct tcf_proto___35 {
	struct tcf_proto___35 *next;
	void *root;
	int (*classify)(struct sk_buff___36 *, const struct tcf_proto___35 *, struct tcf_result___35 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___35 *ops;
	struct tcf_chain___35 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___35 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___35 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___35 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___36 *, const struct tcf_proto___35 *, struct tcf_result___35 *);
	int (*init)(struct tcf_proto___35 *);
	void (*destroy)(struct tcf_proto___35 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___35 *, u32);
	void (*put)(struct tcf_proto___35 *, void *);
	int (*change)(struct net___40 *, struct sk_buff___36 *, struct tcf_proto___35 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___35 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___35 *);
	void (*walk)(struct tcf_proto___35 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___35 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___35 *, void *);
	void (*hw_del)(struct tcf_proto___35 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___40 *, struct tcf_chain___35 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___40 *, struct tcf_proto___35 *, void *, struct sk_buff___36 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___40 *, struct tcf_proto___35 *, void *, struct sk_buff___36 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___36 *, struct net___40 *, void *);
	struct module___151 *owner;
	int flags;
};

struct tcf_chain___35 {
	struct mutex filter_chain_lock;
	struct tcf_proto___35 *filter_chain;
	struct list_head list;
	struct tcf_block___35 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___35 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___28 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___35 *prog;
};

struct pneigh_entry___28;

struct neigh_hash_table___28;

struct neigh_table___28 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___37 *, __u32 *);
	bool (*key_eq)(const struct neighbour___28 *, const void *);
	int (*constructor)(struct neighbour___28 *);
	int (*pconstructor)(struct pneigh_entry___28 *);
	void (*pdestructor)(struct pneigh_entry___28 *);
	void (*proxy_redo)(struct sk_buff___36 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___37 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___28 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___35 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___28 *nht;
	struct pneigh_entry___28 **phash_buckets;
};

struct neigh_ops___28 {
	int family;
	void (*solicit)(struct neighbour___28 *, struct sk_buff___36 *);
	void (*error_report)(struct neighbour___28 *, struct sk_buff___36 *);
	int (*output)(struct neighbour___28 *, struct sk_buff___36 *);
	int (*connected_output)(struct neighbour___28 *, struct sk_buff___36 *);
};

struct pneigh_entry___28 {
	struct pneigh_entry___28 *next;
	possible_net_t___35 net;
	struct net_device___37 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___28 {
	struct neighbour___28 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___15 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___40 *, struct sock___29 *, struct sk_buff___36 *);
	int (*orig_input)(struct sk_buff___36 *);
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 data[0];
};

struct fib_rule___28 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___28 *ctarget;
	struct net___40 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___28 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___28 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___18;

struct timewait_sock_ops___18;

struct proto___28 {
	void (*close)(struct sock___29 *, long int);
	int (*pre_connect)(struct sock___29 *, struct sockaddr *, int);
	int (*connect)(struct sock___29 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___29 *, int);
	struct sock___29 * (*accept)(struct sock___29 *, int, int *, bool);
	int (*ioctl)(struct sock___29 *, int, long unsigned int);
	int (*init)(struct sock___29 *);
	void (*destroy)(struct sock___29 *);
	void (*shutdown)(struct sock___29 *, int);
	int (*setsockopt)(struct sock___29 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___29 *, int, int, char *, int *);
	void (*keepalive)(struct sock___29 *, int);
	int (*compat_ioctl)(struct sock___29 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___29 *, struct msghdr___29 *, size_t);
	int (*recvmsg)(struct sock___29 *, struct msghdr___29 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___29 *, struct page___172 *, int, size_t, int);
	int (*bind)(struct sock___29 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___29 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___29 *, struct sk_buff___36 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___29 *);
	int (*hash)(struct sock___29 *);
	void (*unhash)(struct sock___29 *);
	void (*rehash)(struct sock___29 *);
	int (*get_port)(struct sock___29 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___29 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___29 *, int);
	bool (*sock_is_readable)(struct sock___29 *);
	void (*enter_memory_pressure)(struct sock___29 *);
	void (*leave_memory_pressure)(struct sock___29 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___18 *rsk_prot;
	struct timewait_sock_ops___18 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___151 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___29 *, int);
};

struct request_sock___19;

struct request_sock_ops___18 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___29 *, struct request_sock___19 *);
	void (*send_ack)(const struct sock___29 *, struct sk_buff___36 *, struct request_sock___19 *);
	void (*send_reset)(const struct sock___29 *, struct sk_buff___36 *);
	void (*destructor)(struct request_sock___19 *);
	void (*syn_ack_timeout)(const struct request_sock___19 *);
};

struct timewait_sock_ops___18 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___29 *, struct sock___29 *, void *);
	void (*twsk_destructor)(struct sock___29 *);
};

struct request_sock___19 {
	struct sock_common___28 __req_common;
	struct request_sock___19 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___18 *rsk_ops;
	struct sock___29 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___18 {
	struct in6_addr mca_addr;
	struct inet6_dev___18 *idev;
	struct ifmcaddr6___18 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct linux_binprm___38 {
	struct vm_area_struct___172 *vma;
	long unsigned int vma_pages;
	struct mm_struct___173 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd;
	unsigned int execfd_creds;
	unsigned int secureexec;
	unsigned int point_of_no_return;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___167 *executable;
	struct file___167 *interpreter;
	struct file___167 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___37 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___167 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct aa_label___8;

struct aa_proxy___8 {
	struct kref count;
	struct aa_label___8 *label;
};

struct aa_profile___8;

struct aa_label___8 {
	struct kref count;
	struct rb_node node;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct aa_proxy___8 *proxy;
	char *hname;
	long int flags;
	u32 secid;
	int size;
	struct aa_profile___8 *vec[0];
};

struct aa_profile___8 {
	struct aa_policy base;
	struct aa_profile___8 *parent;
	struct aa_ns___2 *ns;
	const char *rename;
	const char *attach;
	struct aa_dfa *xmatch;
	int xmatch_len;
	enum audit_mode audit;
	long int mode;
	u32 path_flags;
	const char *disconnected;
	int size;
	struct aa_policydb policy;
	struct aa_file_rules file;
	struct aa_caps caps;
	struct aa_net_compat *net_compat;
	int xattr_count;
	char **xattrs;
	struct aa_rlimit rlimits;
	int secmark_count;
	struct aa_secmark *secmark;
	struct aa_loaddata___2 *rawdata;
	unsigned char *hash;
	char *dirname;
	struct dentry___167 *dents[9];
	struct rhashtable *data;
	struct aa_label___8 label;
};

struct socket___30;

struct sockaddr___2;

struct msghdr___30;

struct flowi_common___2;

union bpf_attr___2;

struct bpf_map___38;

struct bpf_prog_aux___38;

union security_list_options___6 {
	int (*binder_set_context_mgr)(const struct cred___25 *);
	int (*binder_transaction)(const struct cred___25 *, const struct cred___25 *);
	int (*binder_transfer_binder)(const struct cred___25 *, const struct cred___25 *);
	int (*binder_transfer_file)(const struct cred___25 *, const struct cred___25 *, struct file___152 *);
	int (*ptrace_access_check)(struct task_struct___159 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___159 *);
	int (*capget)(struct task_struct___159 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___25 *, const struct cred___25 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___25 *, struct user_namespace *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___152 *);
	int (*quota_on)(struct dentry___152 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___158 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___2 *);
	int (*bprm_creds_from_file)(struct linux_binprm___2 *, struct file___152 *);
	int (*bprm_check_security)(struct linux_binprm___2 *);
	void (*bprm_committing_creds)(struct linux_binprm___2 *);
	void (*bprm_committed_creds)(struct linux_binprm___2 *);
	int (*fs_context_dup)(struct fs_context *, struct fs_context *);
	int (*fs_context_parse_param)(struct fs_context *, struct fs_parameter___28 *);
	int (*sb_alloc_security)(struct super_block___152 *);
	void (*sb_delete)(struct super_block___152 *);
	void (*sb_free_security)(struct super_block___152 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___152 *, void *);
	int (*sb_remount)(struct super_block___152 *, void *);
	int (*sb_kern_mount)(struct super_block___152 *);
	int (*sb_show_options)(struct seq_file___9 *, struct super_block___152 *);
	int (*sb_statfs)(struct dentry___152 *);
	int (*sb_mount)(const char *, const struct path___152 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___152 *, int);
	int (*sb_pivotroot)(const struct path___152 *, const struct path___152 *);
	int (*sb_set_mnt_opts)(struct super_block___152 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___152 *, struct super_block___152 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___152 *, const struct path___152 *);
	int (*dentry_init_security)(struct dentry___152 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___152 *, int, struct qstr *, const struct cred___25 *, struct cred___25 *);
	int (*path_unlink)(const struct path___152 *, struct dentry___152 *);
	int (*path_mkdir)(const struct path___152 *, struct dentry___152 *, umode_t);
	int (*path_rmdir)(const struct path___152 *, struct dentry___152 *);
	int (*path_mknod)(const struct path___152 *, struct dentry___152 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___152 *);
	int (*path_symlink)(const struct path___152 *, struct dentry___152 *, const char *);
	int (*path_link)(struct dentry___152 *, const struct path___152 *, struct dentry___152 *);
	int (*path_rename)(const struct path___152 *, struct dentry___152 *, const struct path___152 *, struct dentry___152 *);
	int (*path_chmod)(const struct path___152 *, umode_t);
	int (*path_chown)(const struct path___152 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___152 *);
	int (*path_notify)(const struct path___152 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___152 *);
	void (*inode_free_security)(struct inode___152 *);
	int (*inode_init_security)(struct inode___152 *, struct inode___152 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___152 *, const struct qstr *, const struct inode___152 *);
	int (*inode_create)(struct inode___152 *, struct dentry___152 *, umode_t);
	int (*inode_link)(struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*inode_unlink)(struct inode___152 *, struct dentry___152 *);
	int (*inode_symlink)(struct inode___152 *, struct dentry___152 *, const char *);
	int (*inode_mkdir)(struct inode___152 *, struct dentry___152 *, umode_t);
	int (*inode_rmdir)(struct inode___152 *, struct dentry___152 *);
	int (*inode_mknod)(struct inode___152 *, struct dentry___152 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___152 *, struct dentry___152 *, struct inode___152 *, struct dentry___152 *);
	int (*inode_readlink)(struct dentry___152 *);
	int (*inode_follow_link)(struct dentry___152 *, struct inode___152 *, bool);
	int (*inode_permission)(struct inode___152 *, int);
	int (*inode_setattr)(struct dentry___152 *, struct iattr___152 *);
	int (*inode_getattr)(const struct path___152 *);
	int (*inode_setxattr)(struct user_namespace *, struct dentry___152 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___152 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___152 *, const char *);
	int (*inode_listxattr)(struct dentry___152 *);
	int (*inode_removexattr)(struct user_namespace *, struct dentry___152 *, const char *);
	int (*inode_need_killpriv)(struct dentry___152 *);
	int (*inode_killpriv)(struct user_namespace *, struct dentry___152 *);
	int (*inode_getsecurity)(struct user_namespace *, struct inode___152 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___152 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___152 *, char *, size_t);
	void (*inode_getsecid)(struct inode___152 *, u32 *);
	int (*inode_copy_up)(struct dentry___152 *, struct cred___25 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___139 *, struct kernfs_node___139 *);
	int (*file_permission)(struct file___152 *, int);
	int (*file_alloc_security)(struct file___152 *);
	void (*file_free_security)(struct file___152 *);
	int (*file_ioctl)(struct file___152 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___152 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___157 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___152 *, unsigned int);
	int (*file_fcntl)(struct file___152 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___152 *);
	int (*file_send_sigiotask)(struct task_struct___159 *, struct fown_struct___133 *, int);
	int (*file_receive)(struct file___152 *);
	int (*file_open)(struct file___152 *);
	int (*task_alloc)(struct task_struct___159 *, long unsigned int);
	void (*task_free)(struct task_struct___159 *);
	int (*cred_alloc_blank)(struct cred___25 *, gfp_t);
	void (*cred_free)(struct cred___25 *);
	int (*cred_prepare)(struct cred___25 *, const struct cred___25 *, gfp_t);
	void (*cred_transfer)(struct cred___25 *, const struct cred___25 *);
	void (*cred_getsecid)(const struct cred___25 *, u32 *);
	int (*kernel_act_as)(struct cred___25 *, u32);
	int (*kernel_create_files_as)(struct cred___25 *, struct inode___152 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___152 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___152 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___25 *, const struct cred___25 *, int);
	int (*task_fix_setgid)(struct cred___25 *, const struct cred___25 *, int);
	int (*task_setpgid)(struct task_struct___159 *, pid_t);
	int (*task_getpgid)(struct task_struct___159 *);
	int (*task_getsid)(struct task_struct___159 *);
	void (*task_getsecid_subj)(struct task_struct___159 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___159 *, u32 *);
	int (*task_setnice)(struct task_struct___159 *, int);
	int (*task_setioprio)(struct task_struct___159 *, int);
	int (*task_getioprio)(struct task_struct___159 *);
	int (*task_prlimit)(const struct cred___25 *, const struct cred___25 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___159 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___159 *);
	int (*task_getscheduler)(struct task_struct___159 *);
	int (*task_movememory)(struct task_struct___159 *);
	int (*task_kill)(struct task_struct___159 *, struct kernel_siginfo *, int, const struct cred___25 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___159 *, struct inode___152 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___159 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___6 *);
	void (*d_instantiate)(struct dentry___152 *, struct inode___152 *);
	int (*getprocattr)(struct task_struct___159 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___152 *);
	int (*inode_notifysecctx)(struct inode___152 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___152 *, void *, u32);
	int (*inode_getsecctx)(struct inode___152 *, void **, u32 *);
	int (*post_notification)(const struct cred___25 *, const struct cred___25 *, struct watch_notification *);
	int (*watch_key)(struct key___8 *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___30 *, struct socket___30 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___30 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___30 *, struct socket___30 *);
	int (*socket_bind)(struct socket___30 *, struct sockaddr___2 *, int);
	int (*socket_connect)(struct socket___30 *, struct sockaddr___2 *, int);
	int (*socket_listen)(struct socket___30 *, int);
	int (*socket_accept)(struct socket___30 *, struct socket___30 *);
	int (*socket_sendmsg)(struct socket___30 *, struct msghdr___30 *, int);
	int (*socket_recvmsg)(struct socket___30 *, struct msghdr___30 *, int, int);
	int (*socket_getsockname)(struct socket___30 *);
	int (*socket_getpeername)(struct socket___30 *);
	int (*socket_getsockopt)(struct socket___30 *, int, int);
	int (*socket_setsockopt)(struct socket___30 *, int, int);
	int (*socket_shutdown)(struct socket___30 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___6 *);
	int (*socket_getpeersec_stream)(struct socket___30 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___30 *, struct sk_buff___6 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___30 *);
	int (*inet_conn_request)(const struct sock *, struct sk_buff___6 *, struct request_sock___5 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___5 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___6 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___5 *, struct flowi_common___2 *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___6 *);
	int (*sctp_bind_connect)(struct sock *, int, struct sockaddr___2 *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock *, struct sock *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx___2 **, struct xfrm_user_sec_ctx___2 *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx___2 *, struct xfrm_sec_ctx___2 **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx___2 *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx___2 *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx___2 *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common___2 *);
	int (*xfrm_decode_session)(struct sk_buff___6 *, u32 *, int);
	int (*key_alloc)(struct key___8 *, const struct cred___25 *, long unsigned int);
	void (*key_free)(struct key___8 *);
	int (*key_permission)(key_ref_t, const struct cred___25 *, enum key_need_perm);
	int (*key_getsecurity)(struct key___8 *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr___2 *, unsigned int);
	int (*bpf_map)(struct bpf_map___38 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog *);
	int (*bpf_map_alloc_security)(struct bpf_map___38 *);
	void (*bpf_map_free_security)(struct bpf_map___38 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___38 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___38 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event *);
	void (*perf_event_free)(struct perf_event *);
	int (*perf_event_read)(struct perf_event *);
	int (*perf_event_write)(struct perf_event *);
};

struct security_hook_list___6 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___6 hook;
	struct lsm_id *lsmid;
};

struct ptrace_relation {
	struct task_struct___159 *tracer;
	struct task_struct___159 *tracee;
	bool invalid;
	struct list_head node;
	struct callback_head rcu;
};

struct access_report_info {
	struct callback_head work;
	const char *access;
	struct task_struct___159 *target;
	struct task_struct___159 *agent;
};

enum sid_policy_type {
	SIDPOL_DEFAULT = 0,
	SIDPOL_CONSTRAINED = 1,
	SIDPOL_ALLOWED = 2,
};

typedef union {
	kuid_t uid;
	kgid_t gid;
} kid_t;

enum setid_type {
	UID = 0,
	GID = 1,
};

struct setid_rule {
	struct hlist_node next;
	kid_t src_id;
	kid_t dst_id;
	enum setid_type type;
};

struct setid_ruleset {
	struct hlist_head rules[256];
	char *policy_str;
	struct callback_head rcu;
	enum setid_type type;
};

enum devcg_behavior {
	DEVCG_DEFAULT_NONE = 0,
	DEVCG_DEFAULT_ALLOW = 1,
	DEVCG_DEFAULT_DENY = 2,
};

struct dev_exception_item {
	u32 major;
	u32 minor;
	short int type;
	short int access;
	struct list_head list;
	struct callback_head rcu;
};

struct dev_cgroup {
	struct cgroup_subsys_state___87 css;
	struct list_head exceptions;
	enum devcg_behavior behavior;
};

union security_list_options___7 {
	int (*binder_set_context_mgr)(const struct cred___9 *);
	int (*binder_transaction)(const struct cred___9 *, const struct cred___9 *);
	int (*binder_transfer_binder)(const struct cred___9 *, const struct cred___9 *);
	int (*binder_transfer_file)(const struct cred___9 *, const struct cred___9 *, struct file___29 *);
	int (*ptrace_access_check)(struct task_struct___69 *, unsigned int);
	int (*ptrace_traceme)(struct task_struct___69 *);
	int (*capget)(struct task_struct___69 *, kernel_cap_t *, kernel_cap_t *, kernel_cap_t *);
	int (*capset)(struct cred___9 *, const struct cred___9 *, const kernel_cap_t *, const kernel_cap_t *, const kernel_cap_t *);
	int (*capable)(const struct cred___9 *, struct user_namespace *, int, unsigned int);
	int (*quotactl)(int, int, int, struct super_block___63 *);
	int (*quota_on)(struct dentry___63 *);
	int (*syslog)(int);
	int (*settime)(const struct timespec64 *, const struct timezone *);
	int (*vm_enough_memory)(struct mm_struct___68 *, long int);
	int (*bprm_creds_for_exec)(struct linux_binprm___2 *);
	int (*bprm_creds_from_file)(struct linux_binprm___2 *, struct file___29 *);
	int (*bprm_check_security)(struct linux_binprm___2 *);
	void (*bprm_committing_creds)(struct linux_binprm___2 *);
	void (*bprm_committed_creds)(struct linux_binprm___2 *);
	int (*fs_context_dup)(struct fs_context *, struct fs_context *);
	int (*fs_context_parse_param)(struct fs_context *, struct fs_parameter___28 *);
	int (*sb_alloc_security)(struct super_block___63 *);
	void (*sb_delete)(struct super_block___63 *);
	void (*sb_free_security)(struct super_block___63 *);
	void (*sb_free_mnt_opts)(void *);
	int (*sb_eat_lsm_opts)(char *, void **);
	int (*sb_mnt_opts_compat)(struct super_block___63 *, void *);
	int (*sb_remount)(struct super_block___63 *, void *);
	int (*sb_kern_mount)(struct super_block___63 *);
	int (*sb_show_options)(struct seq_file___9 *, struct super_block___63 *);
	int (*sb_statfs)(struct dentry___63 *);
	int (*sb_mount)(const char *, const struct path___62 *, const char *, long unsigned int, void *);
	int (*sb_umount)(struct vfsmount___62 *, int);
	int (*sb_pivotroot)(const struct path___62 *, const struct path___62 *);
	int (*sb_set_mnt_opts)(struct super_block___63 *, void *, long unsigned int, long unsigned int *);
	int (*sb_clone_mnt_opts)(const struct super_block___63 *, struct super_block___63 *, long unsigned int, long unsigned int *);
	int (*sb_add_mnt_opt)(const char *, const char *, int, void **);
	int (*move_mount)(const struct path___62 *, const struct path___62 *);
	int (*dentry_init_security)(struct dentry___63 *, int, const struct qstr *, void **, u32 *);
	int (*dentry_create_files_as)(struct dentry___63 *, int, struct qstr *, const struct cred___9 *, struct cred___9 *);
	int (*path_unlink)(const struct path___62 *, struct dentry___63 *);
	int (*path_mkdir)(const struct path___62 *, struct dentry___63 *, umode_t);
	int (*path_rmdir)(const struct path___62 *, struct dentry___63 *);
	int (*path_mknod)(const struct path___62 *, struct dentry___63 *, umode_t, unsigned int);
	int (*path_truncate)(const struct path___62 *);
	int (*path_symlink)(const struct path___62 *, struct dentry___63 *, const char *);
	int (*path_link)(struct dentry___63 *, const struct path___62 *, struct dentry___63 *);
	int (*path_rename)(const struct path___62 *, struct dentry___63 *, const struct path___62 *, struct dentry___63 *);
	int (*path_chmod)(const struct path___62 *, umode_t);
	int (*path_chown)(const struct path___62 *, kuid_t, kgid_t);
	int (*path_chroot)(const struct path___62 *);
	int (*path_notify)(const struct path___62 *, u64, unsigned int);
	int (*inode_alloc_security)(struct inode___63 *);
	void (*inode_free_security)(struct inode___63 *);
	int (*inode_init_security)(struct inode___63 *, struct inode___63 *, const struct qstr *, const char **, void **, size_t *);
	int (*inode_init_security_anon)(struct inode___63 *, const struct qstr *, const struct inode___63 *);
	int (*inode_create)(struct inode___63 *, struct dentry___63 *, umode_t);
	int (*inode_link)(struct dentry___63 *, struct inode___63 *, struct dentry___63 *);
	int (*inode_unlink)(struct inode___63 *, struct dentry___63 *);
	int (*inode_symlink)(struct inode___63 *, struct dentry___63 *, const char *);
	int (*inode_mkdir)(struct inode___63 *, struct dentry___63 *, umode_t);
	int (*inode_rmdir)(struct inode___63 *, struct dentry___63 *);
	int (*inode_mknod)(struct inode___63 *, struct dentry___63 *, umode_t, dev_t);
	int (*inode_rename)(struct inode___63 *, struct dentry___63 *, struct inode___63 *, struct dentry___63 *);
	int (*inode_readlink)(struct dentry___63 *);
	int (*inode_follow_link)(struct dentry___63 *, struct inode___63 *, bool);
	int (*inode_permission)(struct inode___63 *, int);
	int (*inode_setattr)(struct dentry___63 *, struct iattr___63 *);
	int (*inode_getattr)(const struct path___62 *);
	int (*inode_setxattr)(struct user_namespace *, struct dentry___63 *, const char *, const void *, size_t, int);
	void (*inode_post_setxattr)(struct dentry___63 *, const char *, const void *, size_t, int);
	int (*inode_getxattr)(struct dentry___63 *, const char *);
	int (*inode_listxattr)(struct dentry___63 *);
	int (*inode_removexattr)(struct user_namespace *, struct dentry___63 *, const char *);
	int (*inode_need_killpriv)(struct dentry___63 *);
	int (*inode_killpriv)(struct user_namespace *, struct dentry___63 *);
	int (*inode_getsecurity)(struct user_namespace *, struct inode___63 *, const char *, void **, bool);
	int (*inode_setsecurity)(struct inode___63 *, const char *, const void *, size_t, int);
	int (*inode_listsecurity)(struct inode___63 *, char *, size_t);
	void (*inode_getsecid)(struct inode___63 *, u32 *);
	int (*inode_copy_up)(struct dentry___63 *, struct cred___9 **);
	int (*inode_copy_up_xattr)(const char *);
	int (*kernfs_init_security)(struct kernfs_node___62 *, struct kernfs_node___62 *);
	int (*file_permission)(struct file___29 *, int);
	int (*file_alloc_security)(struct file___29 *);
	void (*file_free_security)(struct file___29 *);
	int (*file_ioctl)(struct file___29 *, unsigned int, long unsigned int);
	int (*mmap_addr)(long unsigned int);
	int (*mmap_file)(struct file___29 *, long unsigned int, long unsigned int, long unsigned int);
	int (*file_mprotect)(struct vm_area_struct___67 *, long unsigned int, long unsigned int);
	int (*file_lock)(struct file___29 *, unsigned int);
	int (*file_fcntl)(struct file___29 *, unsigned int, long unsigned int);
	void (*file_set_fowner)(struct file___29 *);
	int (*file_send_sigiotask)(struct task_struct___69 *, struct fown_struct___55 *, int);
	int (*file_receive)(struct file___29 *);
	int (*file_open)(struct file___29 *);
	int (*task_alloc)(struct task_struct___69 *, long unsigned int);
	void (*task_free)(struct task_struct___69 *);
	int (*cred_alloc_blank)(struct cred___9 *, gfp_t);
	void (*cred_free)(struct cred___9 *);
	int (*cred_prepare)(struct cred___9 *, const struct cred___9 *, gfp_t);
	void (*cred_transfer)(struct cred___9 *, const struct cred___9 *);
	void (*cred_getsecid)(const struct cred___9 *, u32 *);
	int (*kernel_act_as)(struct cred___9 *, u32);
	int (*kernel_create_files_as)(struct cred___9 *, struct inode___63 *);
	int (*kernel_module_request)(char *);
	int (*kernel_load_data)(enum kernel_load_data_id, bool);
	int (*kernel_post_load_data)(char *, loff_t, enum kernel_load_data_id, char *);
	int (*kernel_read_file)(struct file___29 *, enum kernel_read_file_id, bool);
	int (*kernel_post_read_file)(struct file___29 *, char *, loff_t, enum kernel_read_file_id);
	int (*task_fix_setuid)(struct cred___9 *, const struct cred___9 *, int);
	int (*task_fix_setgid)(struct cred___9 *, const struct cred___9 *, int);
	int (*task_setpgid)(struct task_struct___69 *, pid_t);
	int (*task_getpgid)(struct task_struct___69 *);
	int (*task_getsid)(struct task_struct___69 *);
	void (*task_getsecid_subj)(struct task_struct___69 *, u32 *);
	void (*task_getsecid_obj)(struct task_struct___69 *, u32 *);
	int (*task_setnice)(struct task_struct___69 *, int);
	int (*task_setioprio)(struct task_struct___69 *, int);
	int (*task_getioprio)(struct task_struct___69 *);
	int (*task_prlimit)(const struct cred___9 *, const struct cred___9 *, unsigned int);
	int (*task_setrlimit)(struct task_struct___69 *, unsigned int, struct rlimit *);
	int (*task_setscheduler)(struct task_struct___69 *);
	int (*task_getscheduler)(struct task_struct___69 *);
	int (*task_movememory)(struct task_struct___69 *);
	int (*task_kill)(struct task_struct___69 *, struct kernel_siginfo *, int, const struct cred___9 *);
	int (*task_prctl)(int, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	void (*task_to_inode)(struct task_struct___69 *, struct inode___63 *);
	int (*ipc_permission)(struct kern_ipc_perm *, short int);
	void (*ipc_getsecid)(struct kern_ipc_perm *, u32 *);
	int (*msg_msg_alloc_security)(struct msg_msg *);
	void (*msg_msg_free_security)(struct msg_msg *);
	int (*msg_queue_alloc_security)(struct kern_ipc_perm *);
	void (*msg_queue_free_security)(struct kern_ipc_perm *);
	int (*msg_queue_associate)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgctl)(struct kern_ipc_perm *, int);
	int (*msg_queue_msgsnd)(struct kern_ipc_perm *, struct msg_msg *, int);
	int (*msg_queue_msgrcv)(struct kern_ipc_perm *, struct msg_msg *, struct task_struct___69 *, long int, int);
	int (*shm_alloc_security)(struct kern_ipc_perm *);
	void (*shm_free_security)(struct kern_ipc_perm *);
	int (*shm_associate)(struct kern_ipc_perm *, int);
	int (*shm_shmctl)(struct kern_ipc_perm *, int);
	int (*shm_shmat)(struct kern_ipc_perm *, char *, int);
	int (*sem_alloc_security)(struct kern_ipc_perm *);
	void (*sem_free_security)(struct kern_ipc_perm *);
	int (*sem_associate)(struct kern_ipc_perm *, int);
	int (*sem_semctl)(struct kern_ipc_perm *, int);
	int (*sem_semop)(struct kern_ipc_perm *, struct sembuf *, unsigned int, int);
	int (*netlink_send)(struct sock *, struct sk_buff___6 *);
	void (*d_instantiate)(struct dentry___63 *, struct inode___63 *);
	int (*getprocattr)(struct task_struct___69 *, char *, char **);
	int (*setprocattr)(const char *, void *, size_t);
	int (*ismaclabel)(const char *);
	int (*secid_to_secctx)(u32, char **, u32 *);
	int (*secctx_to_secid)(const char *, u32, u32 *);
	void (*release_secctx)(char *, u32);
	void (*inode_invalidate_secctx)(struct inode___63 *);
	int (*inode_notifysecctx)(struct inode___63 *, void *, u32);
	int (*inode_setsecctx)(struct dentry___63 *, void *, u32);
	int (*inode_getsecctx)(struct inode___63 *, void **, u32 *);
	int (*post_notification)(const struct cred___9 *, const struct cred___9 *, struct watch_notification *);
	int (*watch_key)(struct key *);
	int (*unix_stream_connect)(struct sock *, struct sock *, struct sock *);
	int (*unix_may_send)(struct socket___30 *, struct socket___30 *);
	int (*socket_create)(int, int, int, int);
	int (*socket_post_create)(struct socket___30 *, int, int, int, int);
	int (*socket_socketpair)(struct socket___30 *, struct socket___30 *);
	int (*socket_bind)(struct socket___30 *, struct sockaddr___2 *, int);
	int (*socket_connect)(struct socket___30 *, struct sockaddr___2 *, int);
	int (*socket_listen)(struct socket___30 *, int);
	int (*socket_accept)(struct socket___30 *, struct socket___30 *);
	int (*socket_sendmsg)(struct socket___30 *, struct msghdr___30 *, int);
	int (*socket_recvmsg)(struct socket___30 *, struct msghdr___30 *, int, int);
	int (*socket_getsockname)(struct socket___30 *);
	int (*socket_getpeername)(struct socket___30 *);
	int (*socket_getsockopt)(struct socket___30 *, int, int);
	int (*socket_setsockopt)(struct socket___30 *, int, int);
	int (*socket_shutdown)(struct socket___30 *, int);
	int (*socket_sock_rcv_skb)(struct sock *, struct sk_buff___6 *);
	int (*socket_getpeersec_stream)(struct socket___30 *, char *, int *, unsigned int);
	int (*socket_getpeersec_dgram)(struct socket___30 *, struct sk_buff___6 *, u32 *);
	int (*sk_alloc_security)(struct sock *, int, gfp_t);
	void (*sk_free_security)(struct sock *);
	void (*sk_clone_security)(const struct sock *, struct sock *);
	void (*sk_getsecid)(struct sock *, u32 *);
	void (*sock_graft)(struct sock *, struct socket___30 *);
	int (*inet_conn_request)(const struct sock *, struct sk_buff___6 *, struct request_sock___5 *);
	void (*inet_csk_clone)(struct sock *, const struct request_sock___5 *);
	void (*inet_conn_established)(struct sock *, struct sk_buff___6 *);
	int (*secmark_relabel_packet)(u32);
	void (*secmark_refcount_inc)();
	void (*secmark_refcount_dec)();
	void (*req_classify_flow)(const struct request_sock___5 *, struct flowi_common___2 *);
	int (*tun_dev_alloc_security)(void **);
	void (*tun_dev_free_security)(void *);
	int (*tun_dev_create)();
	int (*tun_dev_attach_queue)(void *);
	int (*tun_dev_attach)(struct sock *, void *);
	int (*tun_dev_open)(void *);
	int (*sctp_assoc_request)(struct sctp_endpoint *, struct sk_buff___6 *);
	int (*sctp_bind_connect)(struct sock *, int, struct sockaddr___2 *, int);
	void (*sctp_sk_clone)(struct sctp_endpoint *, struct sock *, struct sock *);
	int (*ib_pkey_access)(void *, u64, u16);
	int (*ib_endport_manage_subnet)(void *, const char *, u8);
	int (*ib_alloc_security)(void **);
	void (*ib_free_security)(void *);
	int (*xfrm_policy_alloc_security)(struct xfrm_sec_ctx___2 **, struct xfrm_user_sec_ctx___2 *, gfp_t);
	int (*xfrm_policy_clone_security)(struct xfrm_sec_ctx___2 *, struct xfrm_sec_ctx___2 **);
	void (*xfrm_policy_free_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_policy_delete_security)(struct xfrm_sec_ctx___2 *);
	int (*xfrm_state_alloc)(struct xfrm_state *, struct xfrm_user_sec_ctx___2 *);
	int (*xfrm_state_alloc_acquire)(struct xfrm_state *, struct xfrm_sec_ctx___2 *, u32);
	void (*xfrm_state_free_security)(struct xfrm_state *);
	int (*xfrm_state_delete_security)(struct xfrm_state *);
	int (*xfrm_policy_lookup)(struct xfrm_sec_ctx___2 *, u32);
	int (*xfrm_state_pol_flow_match)(struct xfrm_state *, struct xfrm_policy *, const struct flowi_common___2 *);
	int (*xfrm_decode_session)(struct sk_buff___6 *, u32 *, int);
	int (*key_alloc)(struct key *, const struct cred___9 *, long unsigned int);
	void (*key_free)(struct key *);
	int (*key_permission)(key_ref_t, const struct cred___9 *, enum key_need_perm);
	int (*key_getsecurity)(struct key *, char **);
	int (*audit_rule_init)(u32, u32, char *, void **);
	int (*audit_rule_known)(struct audit_krule *);
	int (*audit_rule_match)(u32, u32, u32, void *);
	void (*audit_rule_free)(void *);
	int (*bpf)(int, union bpf_attr *, unsigned int);
	int (*bpf_map)(struct bpf_map___11 *, fmode_t);
	int (*bpf_prog)(struct bpf_prog *);
	int (*bpf_map_alloc_security)(struct bpf_map___11 *);
	void (*bpf_map_free_security)(struct bpf_map___11 *);
	int (*bpf_prog_alloc_security)(struct bpf_prog_aux___11 *);
	void (*bpf_prog_free_security)(struct bpf_prog_aux___11 *);
	int (*locked_down)(enum lockdown_reason);
	int (*lock_kernel_down)(const char *, enum lockdown_reason);
	int (*perf_event_open)(struct perf_event_attr *, int);
	int (*perf_event_alloc)(struct perf_event *);
	void (*perf_event_free)(struct perf_event *);
	int (*perf_event_read)(struct perf_event *);
	int (*perf_event_write)(struct perf_event *);
};

struct security_hook_list___7 {
	struct hlist_node list;
	struct hlist_head *head;
	union security_list_options___7 hook;
	struct lsm_id *lsmid;
};

struct landlock_ruleset_attr {
	__u64 handled_access_fs;
};

enum landlock_rule_type {
	LANDLOCK_RULE_PATH_BENEATH = 1,
};

struct landlock_path_beneath_attr {
	__u64 allowed_access;
	__s32 parent_fd;
} __attribute__((packed));

struct landlock_hierarchy {
	struct landlock_hierarchy *parent;
	refcount_t usage;
};

struct landlock_ruleset {
	struct rb_root root;
	struct landlock_hierarchy *hierarchy;
	union {
		struct work_struct work_free;
		struct {
			struct mutex lock;
			refcount_t usage;
			u32 num_rules;
			u32 num_layers;
			u16 fs_access_masks[0];
		};
	};
};

struct landlock_cred_security {
	struct landlock_ruleset *domain;
};

typedef struct raw_spinlock___2 raw_spinlock_t___2;

struct landlock_object;

struct landlock_object_underops {
	void (*release)(struct landlock_object * const);
};

struct landlock_object {
	refcount_t usage;
	spinlock_t___2 lock;
	void *underobj;
	union {
		struct callback_head rcu_free;
		const struct landlock_object_underops *underops;
	};
};

struct landlock_object___2;

struct landlock_object_underops___2 {
	void (*release)(struct landlock_object___2 * const);
};

struct landlock_object___2 {
	refcount_t usage;
	spinlock_t lock;
	void *underobj;
	union {
		struct callback_head rcu_free;
		const struct landlock_object_underops___2 *underops;
	};
};

struct landlock_layer {
	u16 level;
	u16 access;
};

struct landlock_rule {
	struct rb_node node;
	struct landlock_object___2 *object;
	u32 num_layers;
	struct landlock_layer layers[0];
};

struct landlock_inode_security {
	struct landlock_object___2 *object;
};

struct landlock_superblock_security {
	atomic_long_t inode_refs;
};

enum integrity_status {
	INTEGRITY_PASS = 0,
	INTEGRITY_PASS_IMMUTABLE = 1,
	INTEGRITY_FAIL = 2,
	INTEGRITY_FAIL_IMMUTABLE = 3,
	INTEGRITY_NOLABEL = 4,
	INTEGRITY_NOXATTRS = 5,
	INTEGRITY_UNKNOWN = 6,
};

struct ima_digest_data {
	u8 algo;
	u8 length;
	union {
		struct {
			u8 unused;
			u8 type;
		} sha1;
		struct {
			u8 type;
			u8 algo;
		} ng;
		u8 data[2];
	} xattr;
	u8 digest[0];
};

struct integrity_iint_cache {
	struct rb_node rb_node;
	struct mutex mutex;
	struct inode___140 *inode;
	u64 version;
	long unsigned int flags;
	long unsigned int measured_pcrs;
	long unsigned int atomic_flags;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_read_status: 4;
	enum integrity_status ima_creds_status: 4;
	enum integrity_status evm_status: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ima_digest_data *ima_hash;
};

struct modsig;

struct static_key_true___2 {
	struct static_key key;
};

struct static_key_false___5 {
	struct static_key key;
};

struct _ddebug___2 {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct static_key_true___2 dd_key_true;
		struct static_key_false___5 dd_key_false;
	} key;
};

typedef int (*request_key_actor_t___9)(struct key___10 *, void *);

struct public_key {
	void *key;
	u32 keylen;
	enum OID algo;
	void *params;
	u32 paramlen;
	bool key_is_private;
	const char *id_type;
	const char *pkey_algo;
};

struct asymmetric_key_id;

struct public_key_signature {
	struct asymmetric_key_id *auth_ids[2];
	u8 *s;
	u8 *digest;
	u32 s_size;
	u32 digest_size;
	const char *pkey_algo;
	const char *hash_algo;
	const char *encoding;
	const void *data;
	unsigned int data_size;
};

struct asymmetric_key_id {
	short unsigned int len;
	unsigned char data[0];
};

enum asymmetric_payload_bits {
	asym_crypto = 0,
	asym_subtype = 1,
	asym_key_ids = 2,
	asym_auth = 3,
};

struct signature_v2_hdr {
	uint8_t type;
	uint8_t version;
	uint8_t hash_algo;
	__be32 keyid;
	__be16 sig_size;
	uint8_t sig[0];
} __attribute__((packed));

typedef struct {
	efi_guid_t signature_owner;
	u8 signature_data[0];
} efi_signature_data_t;

typedef struct {
	efi_guid_t signature_type;
	u32 signature_list_size;
	u32 signature_header_size;
	u32 signature_size;
	u8 signature_header[0];
} efi_signature_list_t;

typedef void (*efi_element_handler_t)(const char *, const void *, size_t);

struct static_key_true___3 {
	struct static_key___3 key;
	long: 64;
	long: 64;
};

struct _ddebug___3 {
	const char *modname;
	const char *function;
	const char *filename;
	const char *format;
	unsigned int lineno: 18;
	unsigned int flags: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct static_key_true___3 dd_key_true;
		struct static_key_false___3 dd_key_false;
	} key;
};

struct efi_mokvar_table_entry {
	char name[256];
	u64 data_size;
	u8 data[0];
};

struct evm_ima_xattr_data {
	u8 type;
	u8 data[0];
};

enum ima_show_type {
	IMA_SHOW_BINARY = 0,
	IMA_SHOW_BINARY_NO_FIELD_LEN = 1,
	IMA_SHOW_BINARY_OLD_STRING_FMT = 2,
	IMA_SHOW_ASCII = 3,
};

struct ima_event_data {
	struct integrity_iint_cache *iint;
	struct file___140 *file;
	const unsigned char *filename;
	struct evm_ima_xattr_data *xattr_value;
	int xattr_len;
	const struct modsig *modsig;
	const char *violation;
	const void *buf;
	int buf_len;
};

struct ima_field_data {
	u8 *data;
	u32 len;
};

struct ima_template_field {
	const char field_id[16];
	int (*field_init)(struct ima_event_data *, struct ima_field_data *);
	void (*field_show)(struct seq_file___121 *, enum ima_show_type, struct ima_field_data *);
};

struct ima_template_desc {
	struct list_head list;
	char *name;
	char *fmt;
	int num_fields;
	const struct ima_template_field **fields;
};

struct ima_template_entry {
	int pcr;
	struct tpm_digest *digests;
	struct ima_template_desc *template_desc;
	u32 template_data_len;
	struct ima_field_data template_data[0];
};

struct ima_queue_entry {
	struct hlist_node hnext;
	struct list_head later;
	struct ima_template_entry *entry;
};

struct ima_h_table {
	atomic_long_t len;
	atomic_long_t violations;
	struct hlist_head queue[1024];
};

enum ima_fs_flags {
	IMA_FS_BUSY = 0,
};

struct integrity_iint_cache___2 {
	struct rb_node rb_node;
	struct mutex mutex;
	struct inode___41 *inode;
	u64 version;
	long unsigned int flags;
	long unsigned int measured_pcrs;
	long unsigned int atomic_flags;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_read_status: 4;
	enum integrity_status ima_creds_status: 4;
	enum integrity_status evm_status: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ima_digest_data *ima_hash;
};

struct ima_event_data___2 {
	struct integrity_iint_cache___2 *iint;
	struct file___41 *file;
	const unsigned char *filename;
	struct evm_ima_xattr_data *xattr_value;
	int xattr_len;
	const struct modsig *modsig;
	const char *violation;
	const void *buf;
	int buf_len;
};

struct ima_template_field___2 {
	const char field_id[16];
	int (*field_init)(struct ima_event_data___2 *, struct ima_field_data *);
	void (*field_show)(struct seq_file___40 *, enum ima_show_type, struct ima_field_data *);
};

struct ima_template_desc___2 {
	struct list_head list;
	char *name;
	char *fmt;
	int num_fields;
	const struct ima_template_field___2 **fields;
};

struct ima_template_entry___2 {
	int pcr;
	struct tpm_digest *digests;
	struct ima_template_desc___2 *template_desc;
	u32 template_data_len;
	struct ima_field_data template_data[0];
};

struct ima_queue_entry___2 {
	struct hlist_node hnext;
	struct list_head later;
	struct ima_template_entry___2 *entry;
};

struct dentry___168;

struct super_block___168;

struct module___152;

struct file_system_type___168 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___168 * (*mount)(struct file_system_type___168 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___168 *);
	struct module___152 *owner;
	struct file_system_type___168 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___168;

struct kiocb___168;

struct poll_table_struct___109;

struct vm_area_struct___173;

struct inode___168;

struct file_lock___168;

struct page___173;

struct seq_file___146;

struct file_operations___168 {
	struct module___152 *owner;
	loff_t (*llseek)(struct file___168 *, loff_t, int);
	ssize_t (*read)(struct file___168 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___168 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___168 *, struct iov_iter___96 *);
	ssize_t (*write_iter)(struct kiocb___168 *, struct iov_iter___96 *);
	int (*iopoll)(struct kiocb___168 *, bool);
	int (*iterate)(struct file___168 *, struct dir_context *);
	int (*iterate_shared)(struct file___168 *, struct dir_context *);
	__poll_t (*poll)(struct file___168 *, struct poll_table_struct___109 *);
	long int (*unlocked_ioctl)(struct file___168 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___168 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___168 *, struct vm_area_struct___173 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___168 *, struct file___168 *);
	int (*flush)(struct file___168 *, fl_owner_t);
	int (*release)(struct inode___168 *, struct file___168 *);
	int (*fsync)(struct file___168 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___168 *, int);
	int (*lock)(struct file___168 *, int, struct file_lock___168 *);
	ssize_t (*sendpage)(struct file___168 *, struct page___173 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___168 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___168 *, long unsigned int);
	int (*flock)(struct file___168 *, int, struct file_lock___168 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___168 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___168 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___168 *, long int, struct file_lock___168 **, void **);
	long int (*fallocate)(struct file___168 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___146 *, struct file___168 *);
	ssize_t (*copy_file_range)(struct file___168 *, loff_t, struct file___168 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___168 *, loff_t, struct file___168 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___168 *, loff_t, loff_t, int);
};

struct vmacache___173 {
	u64 seqnum;
	struct vm_area_struct___173 *vmas[4];
};

struct page_frag___173 {
	struct page___173 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___174;

struct pid___149;

struct nsproxy___158;

struct signal_struct___169;

struct vm_struct___152;

struct task_struct___175 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___175 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___174 *mm;
	struct mm_struct___174 *active_mm;
	struct vmacache___173 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___175 *real_parent;
	struct task_struct___175 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___175 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___149 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___158 *nsproxy;
	struct signal_struct___169 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___175 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___80 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___173 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___175 *oom_reaper_list;
	struct vm_struct___152 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___155;

struct kobj_type___155;

struct kernfs_node___155;

struct kobject___155 {
	const char *name;
	struct list_head entry;
	struct kobject___155 *parent;
	struct kset___155 *kset;
	struct kobj_type___155 *ktype;
	struct kernfs_node___155 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___152 {
	struct kobject___155 kobj;
	struct module___152 *mod;
	struct kobject___155 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___152 {
	struct module___152 *mod;
	struct latch_tree_node node;
};

struct module_layout___152 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___152 mtn;
};

struct module_attribute___152;

struct kernel_param___152;

struct module___152 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___152 mkobj;
	struct module_attribute___152 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___155 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___152 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___152 core_layout;
	struct module_layout___152 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___149;

struct upid___149 {
	int nr;
	struct pid_namespace___149 *ns;
};

struct pid_namespace___149 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___175 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___149 *parent;
	struct fs_pin *bacct;
	struct user_namespace___24 *user_ns;
	struct ucounts___24 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___149 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___149 numbers[1];
};

typedef struct page___173 *pgtable_t___173;

struct address_space___168;

struct dev_pagemap___164;

struct page___173 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___168 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___173 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___173 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___174 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___164 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___164;

struct vm_area_struct___173 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___173 *vm_next;
	struct vm_area_struct___173 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___174 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___164 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___168 *vm_file;
	struct file___168 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___169 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___175 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___175 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___149 *pids[4];
	struct pid___149 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___174 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct linux_binfmt___38;

struct core_state___173;

struct mm_struct___174 {
	struct {
		struct vm_area_struct___173 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___168 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt___38 *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___173 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___175 *owner;
		struct user_namespace___24 *user_ns;
		struct file___168 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___158 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___149 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___152 {
	struct vm_struct___152 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___173 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___168;

struct address_space___168 {
	struct inode___168 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___168 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___164;

struct dev_pagemap___164 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___164 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___168;

struct path___168 {
	struct vfsmount___168 *mnt;
	struct dentry___168 *dentry;
};

struct fown_struct___149 {
	rwlock_t lock;
	struct pid___149 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___168 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___168 f_path;
	struct inode___168 *f_inode;
	const struct file_operations___168 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___149 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___168 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___164;

struct vm_operations_struct___164 {
	void (*open)(struct vm_area_struct___173 *);
	void (*close)(struct vm_area_struct___173 *);
	int (*may_split)(struct vm_area_struct___173 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___173 *);
	int (*mprotect)(struct vm_area_struct___173 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___164 *);
	vm_fault_t (*huge_fault)(struct vm_fault___164 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___164 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___173 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___164 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___164 *);
	int (*access)(struct vm_area_struct___173 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___173 *);
	int (*set_policy)(struct vm_area_struct___173 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___173 *, long unsigned int);
	struct page___173 * (*find_special_page)(struct vm_area_struct___173 *, long unsigned int);
};

struct core_thread___173 {
	struct task_struct___175 *task;
	struct core_thread___173 *next;
};

struct core_state___173 {
	atomic_t nr_threads;
	struct core_thread___173 dumper;
	struct completion startup;
};

struct linux_binprm___39;

struct coredump_params___38;

struct linux_binfmt___38 {
	struct list_head lh;
	struct module___152 *module;
	int (*load_binary)(struct linux_binprm___39 *);
	int (*load_shlib)(struct file___168 *);
	int (*core_dump)(struct coredump_params___38 *);
	long unsigned int min_coredump;
};

struct vm_fault___164 {
	const struct {
		struct vm_area_struct___173 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___173 *cow_page;
	struct page___173 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___173 prealloc_pte;
};

struct dentry_operations___168;

struct dentry___168 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___168 *d_parent;
	struct qstr d_name;
	struct inode___168 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___168 *d_op;
	struct super_block___168 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___168;

struct cdev___28;

struct inode___168 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___168 *i_op;
	struct super_block___168 *i_sb;
	struct address_space___168 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___168 *i_fop;
		void (*free_inode)(struct inode___168 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___168 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___28 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___168 {
	int (*d_revalidate)(struct dentry___168 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___168 *, unsigned int);
	int (*d_hash)(const struct dentry___168 *, struct qstr *);
	int (*d_compare)(const struct dentry___168 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___168 *);
	int (*d_init)(struct dentry___168 *);
	void (*d_release)(struct dentry___168 *);
	void (*d_prune)(struct dentry___168 *);
	void (*d_iput)(struct dentry___168 *, struct inode___168 *);
	char * (*d_dname)(struct dentry___168 *, char *, int);
	struct vfsmount___168 * (*d_automount)(struct path___168 *);
	int (*d_manage)(const struct path___168 *, bool);
	struct dentry___168 * (*d_real)(struct dentry___168 *, const struct inode___168 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___168;

struct mem_dqinfo___168 {
	struct quota_format_type___168 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___168;

struct quota_info___168 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___168 *files[3];
	struct mem_dqinfo___168 info[3];
	const struct quota_format_ops___168 *ops[3];
};

struct rcuwait___169 {
	struct task_struct___175 *task;
};

struct percpu_rw_semaphore___169 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___169 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___168 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___169 rw_sem[3];
};

struct super_operations___168;

struct dquot_operations___168;

struct quotactl_ops___168;

struct xattr_handler___23;

struct super_block___168 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___168 *s_type;
	const struct super_operations___168 *s_op;
	const struct dquot_operations___168 *dq_op;
	const struct quotactl_ops___168 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___168 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___23 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___168 s_dquot;
	struct sb_writers___168 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___168 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___24 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___168 {
	struct dentry___168 *mnt_root;
	struct super_block___168 *mnt_sb;
	int mnt_flags;
	struct user_namespace___24 *mnt_userns;
};

struct kiocb___168 {
	struct file___168 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___168 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___168 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___168 *ia_file;
};

struct dquot___168 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___168 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___168 {
	int qf_fmt_id;
	const struct quota_format_ops___168 *qf_ops;
	struct module___152 *qf_owner;
	struct quota_format_type___168 *qf_next;
};

struct quota_format_ops___168 {
	int (*check_quota_file)(struct super_block___168 *, int);
	int (*read_file_info)(struct super_block___168 *, int);
	int (*write_file_info)(struct super_block___168 *, int);
	int (*free_file_info)(struct super_block___168 *, int);
	int (*read_dqblk)(struct dquot___168 *);
	int (*commit_dqblk)(struct dquot___168 *);
	int (*release_dqblk)(struct dquot___168 *);
	int (*get_next_id)(struct super_block___168 *, struct kqid *);
};

struct dquot_operations___168 {
	int (*write_dquot)(struct dquot___168 *);
	struct dquot___168 * (*alloc_dquot)(struct super_block___168 *, int);
	void (*destroy_dquot)(struct dquot___168 *);
	int (*acquire_dquot)(struct dquot___168 *);
	int (*release_dquot)(struct dquot___168 *);
	int (*mark_dirty)(struct dquot___168 *);
	int (*write_info)(struct super_block___168 *, int);
	qsize_t * (*get_reserved_space)(struct inode___168 *);
	int (*get_projid)(struct inode___168 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___168 *, qsize_t *);
	int (*get_next_id)(struct super_block___168 *, struct kqid *);
};

struct quotactl_ops___168 {
	int (*quota_on)(struct super_block___168 *, int, int, const struct path___168 *);
	int (*quota_off)(struct super_block___168 *, int);
	int (*quota_enable)(struct super_block___168 *, unsigned int);
	int (*quota_disable)(struct super_block___168 *, unsigned int);
	int (*quota_sync)(struct super_block___168 *, int);
	int (*set_info)(struct super_block___168 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___168 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___168 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___168 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___168 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___168 *, unsigned int);
};

struct address_space_operations___168 {
	int (*writepage)(struct page___173 *, struct writeback_control___3 *);
	int (*readpage)(struct file___168 *, struct page___173 *);
	int (*writepages)(struct address_space___168 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___173 *);
	int (*readpages)(struct file___168 *, struct address_space___168 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___168 *, struct address_space___168 *, loff_t, unsigned int, unsigned int, struct page___173 **, void **);
	int (*write_end)(struct file___168 *, struct address_space___168 *, loff_t, unsigned int, unsigned int, struct page___173 *, void *);
	sector_t (*bmap)(struct address_space___168 *, sector_t);
	void (*invalidatepage)(struct page___173 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___173 *, gfp_t);
	void (*freepage)(struct page___173 *);
	ssize_t (*direct_IO)(struct kiocb___168 *, struct iov_iter___96 *);
	int (*migratepage)(struct address_space___168 *, struct page___173 *, struct page___173 *, enum migrate_mode);
	bool (*isolate_page)(struct page___173 *, isolate_mode_t);
	void (*putback_page)(struct page___173 *);
	int (*launder_page)(struct page___173 *);
	int (*is_partially_uptodate)(struct page___173 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___173 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___168 *, struct page___173 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___168 *, sector_t *);
	void (*swap_deactivate)(struct file___168 *);
};

struct cdev___28 {
	struct kobject___155 kobj;
	struct module___152 *owner;
	const struct file_operations___168 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___168 {
	struct dentry___168 * (*lookup)(struct inode___168 *, struct dentry___168 *, unsigned int);
	const char * (*get_link)(struct dentry___168 *, struct inode___168 *, struct delayed_call *);
	int (*permission)(struct user_namespace___24 *, struct inode___168 *, int);
	struct posix_acl * (*get_acl)(struct inode___168 *, int, bool);
	int (*readlink)(struct dentry___168 *, char *, int);
	int (*create)(struct user_namespace___24 *, struct inode___168 *, struct dentry___168 *, umode_t, bool);
	int (*link)(struct dentry___168 *, struct inode___168 *, struct dentry___168 *);
	int (*unlink)(struct inode___168 *, struct dentry___168 *);
	int (*symlink)(struct user_namespace___24 *, struct inode___168 *, struct dentry___168 *, const char *);
	int (*mkdir)(struct user_namespace___24 *, struct inode___168 *, struct dentry___168 *, umode_t);
	int (*rmdir)(struct inode___168 *, struct dentry___168 *);
	int (*mknod)(struct user_namespace___24 *, struct inode___168 *, struct dentry___168 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___24 *, struct inode___168 *, struct dentry___168 *, struct inode___168 *, struct dentry___168 *, unsigned int);
	int (*setattr)(struct user_namespace___24 *, struct dentry___168 *, struct iattr___168 *);
	int (*getattr)(struct user_namespace___24 *, const struct path___168 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___168 *, char *, size_t);
	int (*fiemap)(struct inode___168 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___168 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___168 *, struct dentry___168 *, struct file___168 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___24 *, struct inode___168 *, struct dentry___168 *, umode_t);
	int (*set_acl)(struct user_namespace___24 *, struct inode___168 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___24 *, struct dentry___168 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___168 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___168 {
	void (*fl_copy_lock)(struct file_lock___168 *, struct file_lock___168 *);
	void (*fl_release_private)(struct file_lock___168 *);
};

struct fasync_struct___168;

struct lock_manager_operations___168;

struct file_lock___168 {
	struct file_lock___168 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___168 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___168 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___168 *fl_ops;
	const struct lock_manager_operations___168 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___168 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___168 *);
	int (*lm_grant)(struct file_lock___168 *, int);
	bool (*lm_break)(struct file_lock___168 *);
	int (*lm_change)(struct file_lock___168 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___168 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___168 *);
};

struct fasync_struct___168 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___168 *fa_next;
	struct file___168 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___168 {
	struct inode___168 * (*alloc_inode)(struct super_block___168 *);
	void (*destroy_inode)(struct inode___168 *);
	void (*free_inode)(struct inode___168 *);
	void (*dirty_inode)(struct inode___168 *, int);
	int (*write_inode)(struct inode___168 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___168 *);
	void (*evict_inode)(struct inode___168 *);
	void (*put_super)(struct super_block___168 *);
	int (*sync_fs)(struct super_block___168 *, int);
	int (*freeze_super)(struct super_block___168 *);
	int (*freeze_fs)(struct super_block___168 *);
	int (*thaw_super)(struct super_block___168 *);
	int (*unfreeze_fs)(struct super_block___168 *);
	int (*statfs)(struct dentry___168 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___168 *, int *, char *);
	void (*umount_begin)(struct super_block___168 *);
	int (*show_options)(struct seq_file___146 *, struct dentry___168 *);
	int (*show_devname)(struct seq_file___146 *, struct dentry___168 *);
	int (*show_path)(struct seq_file___146 *, struct dentry___168 *);
	int (*show_stats)(struct seq_file___146 *, struct dentry___168 *);
	ssize_t (*quota_read)(struct super_block___168 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___168 *, int, const char *, size_t, loff_t);
	struct dquot___168 ** (*get_dquots)(struct inode___168 *);
	long int (*nr_cached_objects)(struct super_block___168 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___168 *, struct shrink_control___68 *);
	struct file___168 * (*real_loop)(struct file___168 *);
};

struct xattr_handler___23 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___168 *);
	int (*get)(const struct xattr_handler___23 *, struct dentry___168 *, struct inode___168 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___23 *, struct user_namespace___24 *, struct dentry___168 *, struct inode___168 *, const char *, const void *, size_t, int);
};

typedef void (*poll_queue_proc___111)(struct file___168 *, wait_queue_head_t *, struct poll_table_struct___109 *);

struct poll_table_struct___109 {
	poll_queue_proc___111 _qproc;
	__poll_t _key;
};

struct seq_operations___146;

struct seq_file___146 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___146 *op;
	int poll_event;
	const struct file___168 *file;
	void *private;
};

struct kernfs_root___155;

struct kernfs_elem_dir___155 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___155 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___155;

struct kernfs_root___155 {
	struct kernfs_node___155 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___155 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___155 {
	struct kernfs_node___155 *target_kn;
};

struct kernfs_ops___155;

struct kernfs_elem_attr___155 {
	const struct kernfs_ops___155 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___155 *notify_next;
};

struct kernfs_node___155 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___155 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___155 dir;
		struct kernfs_elem_symlink___155 symlink;
		struct kernfs_elem_attr___155 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___155;

struct kernfs_ops___155 {
	int (*open)(struct kernfs_open_file___155 *);
	void (*release)(struct kernfs_open_file___155 *);
	int (*seq_show)(struct seq_file___146 *, void *);
	void * (*seq_start)(struct seq_file___146 *, loff_t *);
	void * (*seq_next)(struct seq_file___146 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___146 *, void *);
	ssize_t (*read)(struct kernfs_open_file___155 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___155 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___155 *, struct poll_table_struct___109 *);
	int (*mmap)(struct kernfs_open_file___155 *, struct vm_area_struct___173 *);
};

struct kernfs_syscall_ops___155 {
	int (*show_options)(struct seq_file___146 *, struct kernfs_root___155 *);
	int (*mkdir)(struct kernfs_node___155 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___155 *);
	int (*rename)(struct kernfs_node___155 *, struct kernfs_node___155 *, const char *);
	int (*show_path)(struct seq_file___146 *, struct kernfs_node___155 *, struct kernfs_root___155 *);
};

struct kernfs_open_file___155 {
	struct kernfs_node___155 *kn;
	struct file___168 *file;
	struct seq_file___146 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___164 *vm_ops;
};

struct bin_attribute___155;

struct attribute_group___155 {
	const char *name;
	umode_t (*is_visible)(struct kobject___155 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___155 *, struct bin_attribute___155 *, int);
	struct attribute **attrs;
	struct bin_attribute___155 **bin_attrs;
};

struct bin_attribute___155 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___168 * (*f_mapping)();
	ssize_t (*read)(struct file___168 *, struct kobject___155 *, struct bin_attribute___155 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___168 *, struct kobject___155 *, struct bin_attribute___155 *, char *, loff_t, size_t);
	int (*mmap)(struct file___168 *, struct kobject___155 *, struct bin_attribute___155 *, struct vm_area_struct___173 *);
};

struct sysfs_ops___155 {
	ssize_t (*show)(struct kobject___155 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___155 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___155;

struct kset___155 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___155 kobj;
	const struct kset_uevent_ops___155 *uevent_ops;
};

struct kobj_type___155 {
	void (*release)(struct kobject___155 *);
	const struct sysfs_ops___155 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___155 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___155 *);
	const void * (*namespace)(struct kobject___155 *);
	void (*get_ownership)(struct kobject___155 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___155 {
	int (* const filter)(struct kset___155 *, struct kobject___155 *);
	const char * (* const name)(struct kset___155 *, struct kobject___155 *);
	int (* const uevent)(struct kset___155 *, struct kobject___155 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___152 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___152 *);
	int (*get)(char *, const struct kernel_param___152 *);
	void (*free)(void *);
};

struct kparam_array___152;

struct kernel_param___152 {
	const char *name;
	struct module___152 *mod;
	const struct kernel_param_ops___152 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___152 *arr;
	};
};

struct kparam_array___152 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___152 *ops;
	void *elem;
};

struct module_attribute___152 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___152 *, struct module_kobject___152 *, char *);
	ssize_t (*store)(struct module_attribute___152 *, struct module_kobject___152 *, const char *, size_t);
	void (*setup)(struct module___152 *, const char *);
	int (*test)(struct module___152 *);
	void (*free)(struct module___152 *);
};

struct fd___28 {
	struct file___168 *file;
	unsigned int flags;
};

struct linux_binprm___39 {
	struct vm_area_struct___173 *vma;
	long unsigned int vma_pages;
	struct mm_struct___174 *mm;
	long unsigned int p;
	long unsigned int argmin;
	unsigned int have_execfd: 1;
	unsigned int execfd_creds: 1;
	unsigned int secureexec: 1;
	unsigned int point_of_no_return: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct file___168 *executable;
	struct file___168 *interpreter;
	struct file___168 *file;
	struct cred___27 *cred;
	int unsafe;
	unsigned int per_clear;
	int argc;
	int envc;
	const char *filename;
	const char *interp;
	const char *fdpath;
	unsigned int interp_flags;
	int execfd;
	long unsigned int loader;
	long unsigned int exec;
	struct rlimit rlim_stack;
	char buf[256];
};

struct coredump_params___38 {
	const kernel_siginfo_t *siginfo;
	struct pt_regs *regs;
	struct file___168 *file;
	long unsigned int limit;
	long unsigned int mm_flags;
	loff_t written;
	loff_t pos;
	loff_t to_skip;
	int vma_count;
	size_t vma_data_size;
	struct core_vma_metadata *vma_meta;
};

struct dev_pagemap_ops___164 {
	void (*page_free)(struct page___173 *);
	void (*kill)(struct dev_pagemap___164 *);
	void (*cleanup)(struct dev_pagemap___164 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___164 *);
};

struct seq_operations___146 {
	void * (*start)(struct seq_file___146 *, loff_t *);
	void (*stop)(struct seq_file___146 *, void *);
	void * (*next)(struct seq_file___146 *, void *, loff_t *);
	int (*show)(struct seq_file___146 *, void *);
};

enum evm_ima_xattr_type {
	IMA_XATTR_DIGEST = 1,
	EVM_XATTR_HMAC = 2,
	EVM_IMA_XATTR_DIGSIG = 3,
	IMA_XATTR_DIGEST_NG = 4,
	EVM_XATTR_PORTABLE_DIGSIG = 5,
	IMA_XATTR_LAST = 6,
};

struct integrity_iint_cache___3 {
	struct rb_node rb_node;
	struct mutex mutex;
	struct inode___168 *inode;
	u64 version;
	long unsigned int flags;
	long unsigned int measured_pcrs;
	long unsigned int atomic_flags;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_read_status: 4;
	enum integrity_status ima_creds_status: 4;
	enum integrity_status evm_status: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ima_digest_data *ima_hash;
};

struct ima_event_data___3 {
	struct integrity_iint_cache___3 *iint;
	struct file___168 *file;
	const unsigned char *filename;
	struct evm_ima_xattr_data *xattr_value;
	int xattr_len;
	const struct modsig *modsig;
	const char *violation;
	const void *buf;
	int buf_len;
};

struct ima_template_field___3 {
	const char field_id[16];
	int (*field_init)(struct ima_event_data___3 *, struct ima_field_data *);
	void (*field_show)(struct seq_file___146 *, enum ima_show_type, struct ima_field_data *);
};

struct ima_template_desc___3 {
	struct list_head list;
	char *name;
	char *fmt;
	int num_fields;
	const struct ima_template_field___3 **fields;
};

struct ima_template_entry___3 {
	int pcr;
	struct tpm_digest *digests;
	struct ima_template_desc___3 *template_desc;
	u32 template_data_len;
	struct ima_field_data template_data[0];
};

enum ima_hooks {
	NONE = 0,
	FILE_CHECK = 1,
	MMAP_CHECK = 2,
	BPRM_CHECK = 3,
	CREDS_CHECK = 4,
	POST_SETATTR = 5,
	MODULE_CHECK = 6,
	FIRMWARE_CHECK = 7,
	KEXEC_KERNEL_CHECK = 8,
	KEXEC_INITRAMFS_CHECK = 9,
	POLICY_CHECK = 10,
	KEXEC_CMDLINE = 11,
	KEY_CHECK = 12,
	CRITICAL_DATA = 13,
	SETXATTR_CHECK = 14,
	MAX_CHECK = 15,
};

struct crypto_async_request___5;

typedef void (*crypto_completion_t___5)(struct crypto_async_request___5 *, int);

struct crypto_tfm___17;

struct crypto_async_request___5 {
	struct list_head list;
	crypto_completion_t___5 complete;
	void *data;
	struct crypto_tfm___17 *tfm;
	u32 flags;
};

struct crypto_alg___17;

struct crypto_tfm___17 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___17 *);
	struct crypto_alg___17 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___17 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___17 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___17 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___17 *, u8 *, const u8 *);
};

struct compress_alg___17 {
	int (*coa_compress)(struct crypto_tfm___17 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___17 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___17 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___17 cipher;
		struct compress_alg___17 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___17 *);
	void (*cra_exit)(struct crypto_tfm___17 *);
	void (*cra_destroy)(struct crypto_alg___17 *);
	struct module___42 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hash_alg_common___2 {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___17 base;
};

struct ahash_request___2 {
	struct crypto_async_request___5 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___2 {
	int (*init)(struct ahash_request___2 *);
	int (*update)(struct ahash_request___2 *);
	int (*final)(struct ahash_request___2 *);
	int (*finup)(struct ahash_request___2 *);
	int (*digest)(struct ahash_request___2 *);
	int (*export)(struct ahash_request___2 *, void *);
	int (*import)(struct ahash_request___2 *, const void *);
	int (*setkey)(struct crypto_ahash___2 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___17 base;
};

struct crypto_shash___13;

struct shash_desc___9 {
	struct crypto_shash___13 *tfm;
	void *__ctx[0];
};

struct crypto_shash___13 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___17 base;
};

struct shash_alg___4 {
	int (*init)(struct shash_desc___9 *);
	int (*update)(struct shash_desc___9 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___9 *, u8 *);
	int (*finup)(struct shash_desc___9 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___9 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___9 *, void *);
	int (*import)(struct shash_desc___9 *, const void *);
	int (*setkey)(struct crypto_shash___13 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___13 *);
	void (*exit_tfm)(struct crypto_shash___13 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___17 base;
};

enum tpm_pcrs {
	TPM_PCR0 = 0,
	TPM_PCR8 = 8,
	TPM_PCR10 = 10,
};

struct ima_algo_desc {
	struct crypto_shash___13 *tfm;
	enum hash_algo algo;
};

struct irq_desc___18;

typedef void (*irq_flow_handler_t___18)(struct irq_desc___18 *);

struct irq_chip___17;

struct irq_domain___16;

struct irq_data___17 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___17 *chip;
	struct irq_domain___16 *domain;
	struct irq_data___17 *parent_data;
	void *chip_data;
};

struct irqaction___13;

struct irq_desc___18 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___17 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___18 handle_irq;
	struct irqaction___13 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___23 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___25 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___124;

struct device___124;

struct fwnode_handle___124 {
	struct fwnode_handle___124 *secondary;
	const struct fwnode_operations___124 *ops;
	struct device___124 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___124;

struct fwnode_endpoint___124;

struct fwnode_operations___124 {
	struct fwnode_handle___124 * (*get)(struct fwnode_handle___124 *);
	void (*put)(struct fwnode_handle___124 *);
	bool (*device_is_available)(const struct fwnode_handle___124 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___124 *, const struct device___124 *);
	bool (*property_present)(const struct fwnode_handle___124 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___124 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___124 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___124 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*get_parent)(const struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*get_next_child_node)(const struct fwnode_handle___124 *, struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*get_named_child_node)(const struct fwnode_handle___124 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___124 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___124 *);
	struct fwnode_handle___124 * (*graph_get_next_endpoint)(const struct fwnode_handle___124 *, struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*graph_get_remote_endpoint)(const struct fwnode_handle___124 *);
	struct fwnode_handle___124 * (*graph_get_port_parent)(struct fwnode_handle___124 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___124 *, struct fwnode_endpoint___124 *);
	int (*add_links)(struct fwnode_handle___124 *);
};

struct wakeup_source___124;

struct dev_pm_info___124 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___124 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___124 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___124;

struct bus_type___124;

struct device_driver___124;

struct dev_pm_domain___124;

struct device_node___35;

struct class___124;

struct device___124 {
	struct kobject___23 kobj;
	struct device___124 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___124 *type;
	struct bus_type___124 *bus;
	struct device_driver___124 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___124 power;
	struct dev_pm_domain___124 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___16 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___35 *of_node;
	struct fwnode_handle___124 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___124 *class;
	const struct attribute_group___23 **groups;
	void (*release)(struct device___124 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___124 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___124 *local_fwnode;
};

struct fwnode_reference_args___124 {
	struct fwnode_handle___124 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___31 {
	char *name;
	int length;
	void *value;
	struct property___31 *next;
	long unsigned int _flags;
	struct bin_attribute___23 attr;
};

struct device_node___35 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___124 fwnode;
	struct property___31 *properties;
	struct property___31 *deadprops;
	struct device_node___35 *parent;
	struct device_node___35 *child;
	struct device_node___35 *sibling;
	struct kobject___23 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___15 {
	struct fwnode_handle___124 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___16 {
	int (*match)(struct irq_domain___16 *, struct device_node___35 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___16 *, struct irq_fwspec___15 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___16 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___16 *, unsigned int);
	int (*xlate)(struct irq_domain___16 *, struct device_node___35 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___16 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___16 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___16 *, struct irq_data___17 *, bool);
	void (*deactivate)(struct irq_domain___16 *, struct irq_data___17 *);
	int (*translate)(struct irq_domain___16 *, struct irq_fwspec___15 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___16;

struct irq_domain___16 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___16 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___124 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___16 *gc;
	struct irq_domain___16 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___17 *revmap[0];
};

struct irq_chip_generic___16;

struct irq_domain_chip_generic___16 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___16 *gc[0];
};

struct dev_pm_ops___124 {
	int (*prepare)(struct device___124 *);
	void (*complete)(struct device___124 *);
	int (*suspend)(struct device___124 *);
	int (*resume)(struct device___124 *);
	int (*freeze)(struct device___124 *);
	int (*thaw)(struct device___124 *);
	int (*poweroff)(struct device___124 *);
	int (*restore)(struct device___124 *);
	int (*suspend_late)(struct device___124 *);
	int (*resume_early)(struct device___124 *);
	int (*freeze_late)(struct device___124 *);
	int (*thaw_early)(struct device___124 *);
	int (*poweroff_late)(struct device___124 *);
	int (*restore_early)(struct device___124 *);
	int (*suspend_noirq)(struct device___124 *);
	int (*resume_noirq)(struct device___124 *);
	int (*freeze_noirq)(struct device___124 *);
	int (*thaw_noirq)(struct device___124 *);
	int (*poweroff_noirq)(struct device___124 *);
	int (*restore_noirq)(struct device___124 *);
	int (*runtime_suspend)(struct device___124 *);
	int (*runtime_resume)(struct device___124 *);
	int (*runtime_idle)(struct device___124 *);
};

struct wakeup_source___124 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___124 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___124 {
	struct dev_pm_ops___124 ops;
	int (*start)(struct device___124 *);
	void (*detach)(struct device___124 *, bool);
	int (*activate)(struct device___124 *);
	void (*sync)(struct device___124 *);
	void (*dismiss)(struct device___124 *);
};

struct bus_type___124 {
	const char *name;
	const char *dev_name;
	struct device___124 *dev_root;
	const struct attribute_group___23 **bus_groups;
	const struct attribute_group___23 **dev_groups;
	const struct attribute_group___23 **drv_groups;
	int (*match)(struct device___124 *, struct device_driver___124 *);
	int (*uevent)(struct device___124 *, struct kobj_uevent_env *);
	int (*probe)(struct device___124 *);
	void (*sync_state)(struct device___124 *);
	void (*remove)(struct device___124 *);
	void (*shutdown)(struct device___124 *);
	int (*online)(struct device___124 *);
	int (*offline)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	int (*num_vf)(struct device___124 *);
	int (*dma_configure)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___124 {
	const char *name;
	struct bus_type___124 *bus;
	struct module___25 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___124 *);
	void (*sync_state)(struct device___124 *);
	int (*remove)(struct device___124 *);
	void (*shutdown)(struct device___124 *);
	int (*suspend)(struct device___124 *, pm_message_t);
	int (*resume)(struct device___124 *);
	const struct attribute_group___23 **groups;
	const struct attribute_group___23 **dev_groups;
	const struct dev_pm_ops___124 *pm;
	void (*coredump)(struct device___124 *);
	struct driver_private *p;
};

struct device_type___124 {
	const char *name;
	const struct attribute_group___23 **groups;
	int (*uevent)(struct device___124 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___124 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___124 *);
	const struct dev_pm_ops___124 *pm;
};

struct class___124 {
	const char *name;
	struct module___25 *owner;
	const struct attribute_group___23 **class_groups;
	const struct attribute_group___23 **dev_groups;
	struct kobject___23 *dev_kobj;
	int (*dev_uevent)(struct device___124 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___124 *, umode_t *);
	void (*class_release)(struct class___124 *);
	void (*dev_release)(struct device___124 *);
	int (*shutdown_pre)(struct device___124 *);
	const struct kobj_ns_type_operations *ns_type;
	const void * (*namespace)(struct device___124 *);
	void (*get_ownership)(struct device___124 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___124 *pm;
	struct subsys_private *p;
};

struct irq_chip___17 {
	struct device___124 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___17 *);
	void (*irq_shutdown)(struct irq_data___17 *);
	void (*irq_enable)(struct irq_data___17 *);
	void (*irq_disable)(struct irq_data___17 *);
	void (*irq_ack)(struct irq_data___17 *);
	void (*irq_mask)(struct irq_data___17 *);
	void (*irq_mask_ack)(struct irq_data___17 *);
	void (*irq_unmask)(struct irq_data___17 *);
	void (*irq_eoi)(struct irq_data___17 *);
	int (*irq_set_affinity)(struct irq_data___17 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___17 *);
	int (*irq_set_type)(struct irq_data___17 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___17 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___17 *);
	void (*irq_bus_sync_unlock)(struct irq_data___17 *);
	void (*irq_cpu_online)(struct irq_data___17 *);
	void (*irq_cpu_offline)(struct irq_data___17 *);
	void (*irq_suspend)(struct irq_data___17 *);
	void (*irq_resume)(struct irq_data___17 *);
	void (*irq_pm_shutdown)(struct irq_data___17 *);
	void (*irq_calc_mask)(struct irq_data___17 *);
	void (*irq_print_chip)(struct irq_data___17 *, struct seq_file___24 *);
	int (*irq_request_resources)(struct irq_data___17 *);
	void (*irq_release_resources)(struct irq_data___17 *);
	void (*irq_compose_msi_msg)(struct irq_data___17 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___17 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___17 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___17 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___17 *, void *);
	void (*ipi_send_single)(struct irq_data___17 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___17 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___17 *);
	void (*irq_nmi_teardown)(struct irq_data___17 *);
	long unsigned int flags;
};

struct irqaction___13 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___13 *next;
	irq_handler_t thread_fn;
	struct task_struct___25 *thread;
	struct irqaction___13 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___16 {
	struct irq_chip___17 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___18 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___16 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___16 *);
	void (*resume)(struct irq_chip_generic___16 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___16 *domain;
	struct list_head list;
	struct irq_chip_type___16 chip_types[0];
};

struct tpm_chip___3;

struct tpm_class_ops___3 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___3 *, u8);
	int (*recv)(struct tpm_chip___3 *, u8 *, size_t);
	int (*send)(struct tpm_chip___3 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___3 *);
	u8 (*status)(struct tpm_chip___3 *);
	void (*update_timeouts)(struct tpm_chip___3 *, long unsigned int *);
	void (*update_durations)(struct tpm_chip___3 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___3 *);
	int (*cmd_ready)(struct tpm_chip___3 *);
	int (*request_locality)(struct tpm_chip___3 *, int);
	int (*relinquish_locality)(struct tpm_chip___3 *, int);
	void (*clk_enable)(struct tpm_chip___3 *, bool);
};

struct tpm_chip_seqops___3 {
	struct tpm_chip___3 *chip;
	const struct seq_operations___22 *seqops;
};

struct tpm_chip___3 {
	struct device___124 dev;
	struct device___124 devs;
	struct cdev___12 cdev;
	struct cdev___12 cdevs;
	struct rw_semaphore ops_sem;
	const struct tpm_class_ops___3 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___3 bin_log_seqops;
	struct tpm_chip_seqops___3 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___24 *bios_dir[3];
	const struct attribute_group___23 *groups[8];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

struct integrity_iint_cache___4 {
	struct rb_node rb_node;
	struct mutex mutex;
	struct inode___25 *inode;
	u64 version;
	long unsigned int flags;
	long unsigned int measured_pcrs;
	long unsigned int atomic_flags;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_read_status: 4;
	enum integrity_status ima_creds_status: 4;
	enum integrity_status evm_status: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ima_digest_data *ima_hash;
};

struct ima_event_data___4 {
	struct integrity_iint_cache___4 *iint;
	struct file___24 *file;
	const unsigned char *filename;
	struct evm_ima_xattr_data *xattr_value;
	int xattr_len;
	const struct modsig *modsig;
	const char *violation;
	const void *buf;
	int buf_len;
};

struct ima_template_field___4 {
	const char field_id[16];
	int (*field_init)(struct ima_event_data___4 *, struct ima_field_data *);
	void (*field_show)(struct seq_file___24 *, enum ima_show_type, struct ima_field_data *);
};

struct ima_template_desc___4 {
	struct list_head list;
	char *name;
	char *fmt;
	int num_fields;
	const struct ima_template_field___4 **fields;
};

struct ima_template_entry___4 {
	int pcr;
	struct tpm_digest *digests;
	struct ima_template_desc___4 *template_desc;
	u32 template_data_len;
	struct ima_field_data template_data[0];
};

struct dentry___169;

struct super_block___169;

struct module___153;

struct file_system_type___169 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___169 * (*mount)(struct file_system_type___169 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___169 *);
	struct module___153 *owner;
	struct file_system_type___169 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___169;

struct kiocb___169;

struct iov_iter___97;

struct poll_table_struct___110;

struct vm_area_struct___174;

struct inode___169;

struct file_lock___169;

struct page___174;

struct seq_file___147;

struct file_operations___169 {
	struct module___153 *owner;
	loff_t (*llseek)(struct file___169 *, loff_t, int);
	ssize_t (*read)(struct file___169 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___169 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___169 *, struct iov_iter___97 *);
	ssize_t (*write_iter)(struct kiocb___169 *, struct iov_iter___97 *);
	int (*iopoll)(struct kiocb___169 *, bool);
	int (*iterate)(struct file___169 *, struct dir_context *);
	int (*iterate_shared)(struct file___169 *, struct dir_context *);
	__poll_t (*poll)(struct file___169 *, struct poll_table_struct___110 *);
	long int (*unlocked_ioctl)(struct file___169 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___169 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___169 *, struct vm_area_struct___174 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___169 *, struct file___169 *);
	int (*flush)(struct file___169 *, fl_owner_t);
	int (*release)(struct inode___169 *, struct file___169 *);
	int (*fsync)(struct file___169 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___169 *, int);
	int (*lock)(struct file___169 *, int, struct file_lock___169 *);
	ssize_t (*sendpage)(struct file___169 *, struct page___174 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___169 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___169 *, long unsigned int);
	int (*flock)(struct file___169 *, int, struct file_lock___169 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___169 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___169 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___169 *, long int, struct file_lock___169 **, void **);
	long int (*fallocate)(struct file___169 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___147 *, struct file___169 *);
	ssize_t (*copy_file_range)(struct file___169 *, loff_t, struct file___169 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___169 *, loff_t, struct file___169 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___169 *, loff_t, loff_t, int);
};

struct vfsmount___169;

struct path___169 {
	struct vfsmount___169 *mnt;
	struct dentry___169 *dentry;
};

struct pid___150;

struct fown_struct___150 {
	rwlock_t lock;
	struct pid___150 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___169;

struct file___169 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___169 f_path;
	struct inode___169 *f_inode;
	const struct file_operations___169 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___150 f_owner;
	const struct cred___27 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___169 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vmacache___174 {
	u64 seqnum;
	struct vm_area_struct___174 *vmas[4];
};

struct page_frag___174 {
	struct page___174 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___175;

struct nsproxy___159;

struct signal_struct___170;

struct vm_struct___153;

struct task_struct___176 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___176 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___175 *mm;
	struct mm_struct___175 *active_mm;
	struct vmacache___174 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___176 *real_parent;
	struct task_struct___176 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___176 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___150 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___27 *ptracer_cred;
	const struct cred___27 *real_cred;
	const struct cred___27 *cred;
	struct key___10 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___159 *nsproxy;
	struct signal_struct___170 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___176 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___80 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___174 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___176 *oom_reaper_list;
	struct vm_struct___153 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___156;

struct kobj_type___156;

struct kernfs_node___156;

struct kobject___156 {
	const char *name;
	struct list_head entry;
	struct kobject___156 *parent;
	struct kset___156 *kset;
	struct kobj_type___156 *ktype;
	struct kernfs_node___156 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___153 {
	struct kobject___156 kobj;
	struct module___153 *mod;
	struct kobject___156 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___153 {
	struct module___153 *mod;
	struct latch_tree_node node;
};

struct module_layout___153 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___153 mtn;
};

struct module_attribute___153;

struct kernel_param___153;

struct module___153 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___153 mkobj;
	struct module_attribute___153 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___156 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___153 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___153 core_layout;
	struct module_layout___153 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___169;

struct dentry___169 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___169 *d_parent;
	struct qstr d_name;
	struct inode___169 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___169 *d_op;
	struct super_block___169 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___169;

struct address_space___169 {
	struct inode___169 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___169 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___169;

struct cdev___29;

struct inode___169 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___169 *i_op;
	struct super_block___169 *i_sb;
	struct address_space___169 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___169 *i_fop;
		void (*free_inode)(struct inode___169 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___169 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___29 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___169 {
	int (*d_revalidate)(struct dentry___169 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___169 *, unsigned int);
	int (*d_hash)(const struct dentry___169 *, struct qstr *);
	int (*d_compare)(const struct dentry___169 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___169 *);
	int (*d_init)(struct dentry___169 *);
	void (*d_release)(struct dentry___169 *);
	void (*d_prune)(struct dentry___169 *);
	void (*d_iput)(struct dentry___169 *, struct inode___169 *);
	char * (*d_dname)(struct dentry___169 *, char *, int);
	struct vfsmount___169 * (*d_automount)(struct path___169 *);
	int (*d_manage)(const struct path___169 *, bool);
	struct dentry___169 * (*d_real)(struct dentry___169 *, const struct inode___169 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___169;

struct mem_dqinfo___169 {
	struct quota_format_type___169 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___169;

struct quota_info___169 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___169 *files[3];
	struct mem_dqinfo___169 info[3];
	const struct quota_format_ops___169 *ops[3];
};

struct rcuwait___170 {
	struct task_struct___176 *task;
};

struct percpu_rw_semaphore___170 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___170 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___169 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___170 rw_sem[3];
};

struct super_operations___169;

struct dquot_operations___169;

struct quotactl_ops___169;

struct block_device___82;

struct super_block___169 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___169 *s_type;
	const struct super_operations___169 *s_op;
	const struct dquot_operations___169 *dq_op;
	const struct quotactl_ops___169 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___169 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___10 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___82 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___169 s_dquot;
	struct sb_writers___169 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___169 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___169 {
	struct dentry___169 *mnt_root;
	struct super_block___169 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct pid_namespace___150;

struct upid___150 {
	int nr;
	struct pid_namespace___150 *ns;
};

struct pid_namespace___150 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___176 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___150 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___150 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___150 numbers[1];
};

typedef struct page___174 *pgtable_t___174;

struct dev_pagemap___165;

struct page___174 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___169 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___174 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___174 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___175 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___165 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___165;

struct vm_area_struct___174 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___174 *vm_next;
	struct vm_area_struct___174 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___175 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___165 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___169 *vm_file;
	struct file___169 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___170 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___176 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___176 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___150 *pids[4];
	struct pid___150 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___175 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___174;

struct mm_struct___175 {
	struct {
		struct vm_area_struct___174 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___169 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___174 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___176 *owner;
		struct user_namespace *user_ns;
		struct file___169 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___159 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___150 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___153 {
	struct vm_struct___153 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___174 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dev_pagemap_ops___165;

struct dev_pagemap___165 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___165 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___165;

struct vm_operations_struct___165 {
	void (*open)(struct vm_area_struct___174 *);
	void (*close)(struct vm_area_struct___174 *);
	int (*may_split)(struct vm_area_struct___174 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___174 *);
	int (*mprotect)(struct vm_area_struct___174 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___165 *);
	vm_fault_t (*huge_fault)(struct vm_fault___165 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___165 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___174 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___165 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___165 *);
	int (*access)(struct vm_area_struct___174 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___174 *);
	int (*set_policy)(struct vm_area_struct___174 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___174 *, long unsigned int);
	struct page___174 * (*find_special_page)(struct vm_area_struct___174 *, long unsigned int);
};

struct core_thread___174 {
	struct task_struct___176 *task;
	struct core_thread___174 *next;
};

struct core_state___174 {
	atomic_t nr_threads;
	struct core_thread___174 dumper;
	struct completion startup;
};

struct vm_fault___165 {
	const struct {
		struct vm_area_struct___174 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___174 *cow_page;
	struct page___174 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___174 prealloc_pte;
};

struct kiocb___169 {
	struct file___169 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___169 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___169 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___169 *ia_file;
};

struct dquot___169 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___169 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___169 {
	int qf_fmt_id;
	const struct quota_format_ops___169 *qf_ops;
	struct module___153 *qf_owner;
	struct quota_format_type___169 *qf_next;
};

struct quota_format_ops___169 {
	int (*check_quota_file)(struct super_block___169 *, int);
	int (*read_file_info)(struct super_block___169 *, int);
	int (*write_file_info)(struct super_block___169 *, int);
	int (*free_file_info)(struct super_block___169 *, int);
	int (*read_dqblk)(struct dquot___169 *);
	int (*commit_dqblk)(struct dquot___169 *);
	int (*release_dqblk)(struct dquot___169 *);
	int (*get_next_id)(struct super_block___169 *, struct kqid *);
};

struct dquot_operations___169 {
	int (*write_dquot)(struct dquot___169 *);
	struct dquot___169 * (*alloc_dquot)(struct super_block___169 *, int);
	void (*destroy_dquot)(struct dquot___169 *);
	int (*acquire_dquot)(struct dquot___169 *);
	int (*release_dquot)(struct dquot___169 *);
	int (*mark_dirty)(struct dquot___169 *);
	int (*write_info)(struct super_block___169 *, int);
	qsize_t * (*get_reserved_space)(struct inode___169 *);
	int (*get_projid)(struct inode___169 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___169 *, qsize_t *);
	int (*get_next_id)(struct super_block___169 *, struct kqid *);
};

struct quotactl_ops___169 {
	int (*quota_on)(struct super_block___169 *, int, int, const struct path___169 *);
	int (*quota_off)(struct super_block___169 *, int);
	int (*quota_enable)(struct super_block___169 *, unsigned int);
	int (*quota_disable)(struct super_block___169 *, unsigned int);
	int (*quota_sync)(struct super_block___169 *, int);
	int (*set_info)(struct super_block___169 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___169 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___169 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___169 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___169 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___169 *, unsigned int);
};

struct address_space_operations___169 {
	int (*writepage)(struct page___174 *, struct writeback_control___3 *);
	int (*readpage)(struct file___169 *, struct page___174 *);
	int (*writepages)(struct address_space___169 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___174 *);
	int (*readpages)(struct file___169 *, struct address_space___169 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___169 *, struct address_space___169 *, loff_t, unsigned int, unsigned int, struct page___174 **, void **);
	int (*write_end)(struct file___169 *, struct address_space___169 *, loff_t, unsigned int, unsigned int, struct page___174 *, void *);
	sector_t (*bmap)(struct address_space___169 *, sector_t);
	void (*invalidatepage)(struct page___174 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___174 *, gfp_t);
	void (*freepage)(struct page___174 *);
	ssize_t (*direct_IO)(struct kiocb___169 *, struct iov_iter___97 *);
	int (*migratepage)(struct address_space___169 *, struct page___174 *, struct page___174 *, enum migrate_mode);
	bool (*isolate_page)(struct page___174 *, isolate_mode_t);
	void (*putback_page)(struct page___174 *);
	int (*launder_page)(struct page___174 *);
	int (*is_partially_uptodate)(struct page___174 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___174 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___169 *, struct page___174 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___169 *, sector_t *);
	void (*swap_deactivate)(struct file___169 *);
};

struct bio_vec___95;

struct iov_iter___97 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___95 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___29 {
	struct kobject___156 kobj;
	struct module___153 *owner;
	const struct file_operations___169 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___169 {
	struct dentry___169 * (*lookup)(struct inode___169 *, struct dentry___169 *, unsigned int);
	const char * (*get_link)(struct dentry___169 *, struct inode___169 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___169 *, int);
	struct posix_acl * (*get_acl)(struct inode___169 *, int, bool);
	int (*readlink)(struct dentry___169 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___169 *, struct dentry___169 *, umode_t, bool);
	int (*link)(struct dentry___169 *, struct inode___169 *, struct dentry___169 *);
	int (*unlink)(struct inode___169 *, struct dentry___169 *);
	int (*symlink)(struct user_namespace *, struct inode___169 *, struct dentry___169 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___169 *, struct dentry___169 *, umode_t);
	int (*rmdir)(struct inode___169 *, struct dentry___169 *);
	int (*mknod)(struct user_namespace *, struct inode___169 *, struct dentry___169 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___169 *, struct dentry___169 *, struct inode___169 *, struct dentry___169 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___169 *, struct iattr___169 *);
	int (*getattr)(struct user_namespace *, const struct path___169 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___169 *, char *, size_t);
	int (*fiemap)(struct inode___169 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___169 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___169 *, struct dentry___169 *, struct file___169 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___169 *, struct dentry___169 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___169 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___169 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___169 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___169 {
	void (*fl_copy_lock)(struct file_lock___169 *, struct file_lock___169 *);
	void (*fl_release_private)(struct file_lock___169 *);
};

struct fasync_struct___169;

struct lock_manager_operations___169;

struct file_lock___169 {
	struct file_lock___169 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___169 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___169 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___169 *fl_ops;
	const struct lock_manager_operations___169 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___169 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___169 *);
	int (*lm_grant)(struct file_lock___169 *, int);
	bool (*lm_break)(struct file_lock___169 *);
	int (*lm_change)(struct file_lock___169 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___169 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___169 *);
};

struct fasync_struct___169 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___169 *fa_next;
	struct file___169 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___169 {
	struct inode___169 * (*alloc_inode)(struct super_block___169 *);
	void (*destroy_inode)(struct inode___169 *);
	void (*free_inode)(struct inode___169 *);
	void (*dirty_inode)(struct inode___169 *, int);
	int (*write_inode)(struct inode___169 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___169 *);
	void (*evict_inode)(struct inode___169 *);
	void (*put_super)(struct super_block___169 *);
	int (*sync_fs)(struct super_block___169 *, int);
	int (*freeze_super)(struct super_block___169 *);
	int (*freeze_fs)(struct super_block___169 *);
	int (*thaw_super)(struct super_block___169 *);
	int (*unfreeze_fs)(struct super_block___169 *);
	int (*statfs)(struct dentry___169 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___169 *, int *, char *);
	void (*umount_begin)(struct super_block___169 *);
	int (*show_options)(struct seq_file___147 *, struct dentry___169 *);
	int (*show_devname)(struct seq_file___147 *, struct dentry___169 *);
	int (*show_path)(struct seq_file___147 *, struct dentry___169 *);
	int (*show_stats)(struct seq_file___147 *, struct dentry___169 *);
	ssize_t (*quota_read)(struct super_block___169 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___169 *, int, const char *, size_t, loff_t);
	struct dquot___169 ** (*get_dquots)(struct inode___169 *);
	long int (*nr_cached_objects)(struct super_block___169 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___169 *, struct shrink_control___68 *);
	struct file___169 * (*real_loop)(struct file___169 *);
};

struct wakeup_source___125;

struct device___125;

struct dev_pm_info___125 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___125 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___125 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___125;

struct bus_type___125;

struct device_driver___125;

struct dev_pm_domain___125;

struct irq_domain___17;

struct device_node___36;

struct fwnode_handle___125;

struct class___125;

struct attribute_group___156;

struct device___125 {
	struct kobject___156 kobj;
	struct device___125 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___125 *type;
	struct bus_type___125 *bus;
	struct device_driver___125 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___125 power;
	struct dev_pm_domain___125 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___17 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___36 *of_node;
	struct fwnode_handle___125 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___125 *class;
	const struct attribute_group___156 **groups;
	void (*release)(struct device___125 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gendisk___81;

struct block_device___82 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___169 *bd_inode;
	struct super_block___169 *bd_super;
	void *bd_claiming;
	struct device___125 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___156 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___81 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___169 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___112)(struct file___169 *, wait_queue_head_t *, struct poll_table_struct___110 *);

struct poll_table_struct___110 {
	poll_queue_proc___112 _qproc;
	__poll_t _key;
};

struct seq_operations___147;

struct seq_file___147 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___147 *op;
	int poll_event;
	const struct file___169 *file;
	void *private;
};

struct dev_pagemap_ops___165 {
	void (*page_free)(struct page___174 *);
	void (*kill)(struct dev_pagemap___165 *);
	void (*cleanup)(struct dev_pagemap___165 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___165 *);
};

struct irq_desc___19;

typedef void (*irq_flow_handler_t___19)(struct irq_desc___19 *);

struct irq_chip___18;

struct irq_data___18 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___4 *common;
	struct irq_chip___18 *chip;
	struct irq_domain___17 *domain;
	struct irq_data___18 *parent_data;
	void *chip_data;
};

struct irqaction___14;

struct irq_desc___19 {
	struct irq_common_data___4 irq_common_data;
	struct irq_data___18 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___19 handle_irq;
	struct irqaction___14 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___156 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___153 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___125;

struct fwnode_handle___125 {
	struct fwnode_handle___125 *secondary;
	const struct fwnode_operations___125 *ops;
	struct device___125 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___125;

struct fwnode_endpoint___125;

struct fwnode_operations___125 {
	struct fwnode_handle___125 * (*get)(struct fwnode_handle___125 *);
	void (*put)(struct fwnode_handle___125 *);
	bool (*device_is_available)(const struct fwnode_handle___125 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___125 *, const struct device___125 *);
	bool (*property_present)(const struct fwnode_handle___125 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___125 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___125 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___125 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*get_parent)(const struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*get_next_child_node)(const struct fwnode_handle___125 *, struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*get_named_child_node)(const struct fwnode_handle___125 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___125 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___125 *);
	struct fwnode_handle___125 * (*graph_get_next_endpoint)(const struct fwnode_handle___125 *, struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*graph_get_remote_endpoint)(const struct fwnode_handle___125 *);
	struct fwnode_handle___125 * (*graph_get_port_parent)(struct fwnode_handle___125 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___125 *, struct fwnode_endpoint___125 *);
	int (*add_links)(struct fwnode_handle___125 *);
};

struct fwnode_endpoint___125 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___125 *local_fwnode;
};

struct fwnode_reference_args___125 {
	struct fwnode_handle___125 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___18 {
	struct device___125 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___18 *);
	void (*irq_shutdown)(struct irq_data___18 *);
	void (*irq_enable)(struct irq_data___18 *);
	void (*irq_disable)(struct irq_data___18 *);
	void (*irq_ack)(struct irq_data___18 *);
	void (*irq_mask)(struct irq_data___18 *);
	void (*irq_mask_ack)(struct irq_data___18 *);
	void (*irq_unmask)(struct irq_data___18 *);
	void (*irq_eoi)(struct irq_data___18 *);
	int (*irq_set_affinity)(struct irq_data___18 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___18 *);
	int (*irq_set_type)(struct irq_data___18 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___18 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___18 *);
	void (*irq_bus_sync_unlock)(struct irq_data___18 *);
	void (*irq_cpu_online)(struct irq_data___18 *);
	void (*irq_cpu_offline)(struct irq_data___18 *);
	void (*irq_suspend)(struct irq_data___18 *);
	void (*irq_resume)(struct irq_data___18 *);
	void (*irq_pm_shutdown)(struct irq_data___18 *);
	void (*irq_calc_mask)(struct irq_data___18 *);
	void (*irq_print_chip)(struct irq_data___18 *, struct seq_file___147 *);
	int (*irq_request_resources)(struct irq_data___18 *);
	void (*irq_release_resources)(struct irq_data___18 *);
	void (*irq_compose_msi_msg)(struct irq_data___18 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___18 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___18 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___18 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___18 *, void *);
	void (*ipi_send_single)(struct irq_data___18 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___18 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___18 *);
	void (*irq_nmi_teardown)(struct irq_data___18 *);
	long unsigned int flags;
};

struct irq_domain_ops___17;

struct irq_domain_chip_generic___17;

struct irq_domain___17 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___17 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___125 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___17 *gc;
	struct irq_domain___17 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___18 *revmap[0];
};

struct kernfs_root___156;

struct kernfs_elem_dir___156 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___156 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___156;

struct kernfs_root___156 {
	struct kernfs_node___156 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___156 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___156 {
	struct kernfs_node___156 *target_kn;
};

struct kernfs_ops___156;

struct kernfs_elem_attr___156 {
	const struct kernfs_ops___156 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___156 *notify_next;
};

struct kernfs_node___156 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___156 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___156 dir;
		struct kernfs_elem_symlink___156 symlink;
		struct kernfs_elem_attr___156 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___156;

struct kernfs_ops___156 {
	int (*open)(struct kernfs_open_file___156 *);
	void (*release)(struct kernfs_open_file___156 *);
	int (*seq_show)(struct seq_file___147 *, void *);
	void * (*seq_start)(struct seq_file___147 *, loff_t *);
	void * (*seq_next)(struct seq_file___147 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___147 *, void *);
	ssize_t (*read)(struct kernfs_open_file___156 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___156 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___156 *, struct poll_table_struct___110 *);
	int (*mmap)(struct kernfs_open_file___156 *, struct vm_area_struct___174 *);
};

struct kernfs_syscall_ops___156 {
	int (*show_options)(struct seq_file___147 *, struct kernfs_root___156 *);
	int (*mkdir)(struct kernfs_node___156 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___156 *);
	int (*rename)(struct kernfs_node___156 *, struct kernfs_node___156 *, const char *);
	int (*show_path)(struct seq_file___147 *, struct kernfs_node___156 *, struct kernfs_root___156 *);
};

struct kernfs_open_file___156 {
	struct kernfs_node___156 *kn;
	struct file___169 *file;
	struct seq_file___147 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___165 *vm_ops;
};

struct bin_attribute___156;

struct attribute_group___156 {
	const char *name;
	umode_t (*is_visible)(struct kobject___156 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___156 *, struct bin_attribute___156 *, int);
	struct attribute **attrs;
	struct bin_attribute___156 **bin_attrs;
};

struct bin_attribute___156 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___169 * (*f_mapping)();
	ssize_t (*read)(struct file___169 *, struct kobject___156 *, struct bin_attribute___156 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___169 *, struct kobject___156 *, struct bin_attribute___156 *, char *, loff_t, size_t);
	int (*mmap)(struct file___169 *, struct kobject___156 *, struct bin_attribute___156 *, struct vm_area_struct___174 *);
};

struct sysfs_ops___156 {
	ssize_t (*show)(struct kobject___156 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___156 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___156;

struct kset___156 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___156 kobj;
	const struct kset_uevent_ops___156 *uevent_ops;
};

struct kobj_type___156 {
	void (*release)(struct kobject___156 *);
	const struct sysfs_ops___156 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___156 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___156 *);
	const void * (*namespace)(struct kobject___156 *);
	void (*get_ownership)(struct kobject___156 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___156 {
	int (* const filter)(struct kset___156 *, struct kobject___156 *);
	const char * (* const name)(struct kset___156 *, struct kobject___156 *);
	int (* const uevent)(struct kset___156 *, struct kobject___156 *, struct kobj_uevent_env *);
};

struct irqaction___14 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___14 *next;
	irq_handler_t thread_fn;
	struct task_struct___176 *thread;
	struct irqaction___14 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___17 {
	struct irq_chip___18 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___19 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___17 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___17 *);
	void (*resume)(struct irq_chip_generic___17 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___17 *domain;
	struct list_head list;
	struct irq_chip_type___17 chip_types[0];
};

struct irq_domain_chip_generic___17 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___17 *gc[0];
};

struct kernel_param_ops___153 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___153 *);
	int (*get)(char *, const struct kernel_param___153 *);
	void (*free)(void *);
};

struct kparam_array___153;

struct kernel_param___153 {
	const char *name;
	struct module___153 *mod;
	const struct kernel_param_ops___153 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___153 *arr;
	};
};

struct kparam_array___153 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___153 *ops;
	void *elem;
};

struct module_attribute___153 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___153 *, struct module_kobject___153 *, char *);
	ssize_t (*store)(struct module_attribute___153 *, struct module_kobject___153 *, const char *, size_t);
	void (*setup)(struct module___153 *, const char *);
	int (*test)(struct module___153 *);
	void (*free)(struct module___153 *);
};

struct bio_vec___95 {
	struct page___174 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct dev_pm_ops___125 {
	int (*prepare)(struct device___125 *);
	void (*complete)(struct device___125 *);
	int (*suspend)(struct device___125 *);
	int (*resume)(struct device___125 *);
	int (*freeze)(struct device___125 *);
	int (*thaw)(struct device___125 *);
	int (*poweroff)(struct device___125 *);
	int (*restore)(struct device___125 *);
	int (*suspend_late)(struct device___125 *);
	int (*resume_early)(struct device___125 *);
	int (*freeze_late)(struct device___125 *);
	int (*thaw_early)(struct device___125 *);
	int (*poweroff_late)(struct device___125 *);
	int (*restore_early)(struct device___125 *);
	int (*suspend_noirq)(struct device___125 *);
	int (*resume_noirq)(struct device___125 *);
	int (*freeze_noirq)(struct device___125 *);
	int (*thaw_noirq)(struct device___125 *);
	int (*poweroff_noirq)(struct device___125 *);
	int (*restore_noirq)(struct device___125 *);
	int (*runtime_suspend)(struct device___125 *);
	int (*runtime_resume)(struct device___125 *);
	int (*runtime_idle)(struct device___125 *);
};

struct wakeup_source___125 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___125 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___125 {
	struct dev_pm_ops___125 ops;
	int (*start)(struct device___125 *);
	void (*detach)(struct device___125 *, bool);
	int (*activate)(struct device___125 *);
	void (*sync)(struct device___125 *);
	void (*dismiss)(struct device___125 *);
};

struct bus_type___125 {
	const char *name;
	const char *dev_name;
	struct device___125 *dev_root;
	const struct attribute_group___156 **bus_groups;
	const struct attribute_group___156 **dev_groups;
	const struct attribute_group___156 **drv_groups;
	int (*match)(struct device___125 *, struct device_driver___125 *);
	int (*uevent)(struct device___125 *, struct kobj_uevent_env *);
	int (*probe)(struct device___125 *);
	void (*sync_state)(struct device___125 *);
	void (*remove)(struct device___125 *);
	void (*shutdown)(struct device___125 *);
	int (*online)(struct device___125 *);
	int (*offline)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	int (*num_vf)(struct device___125 *);
	int (*dma_configure)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___125 {
	const char *name;
	struct bus_type___125 *bus;
	struct module___153 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___125 *);
	void (*sync_state)(struct device___125 *);
	int (*remove)(struct device___125 *);
	void (*shutdown)(struct device___125 *);
	int (*suspend)(struct device___125 *, pm_message_t);
	int (*resume)(struct device___125 *);
	const struct attribute_group___156 **groups;
	const struct attribute_group___156 **dev_groups;
	const struct dev_pm_ops___125 *pm;
	void (*coredump)(struct device___125 *);
	struct driver_private *p;
};

struct device_type___125 {
	const char *name;
	const struct attribute_group___156 **groups;
	int (*uevent)(struct device___125 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___125 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___125 *);
	const struct dev_pm_ops___125 *pm;
};

struct class___125 {
	const char *name;
	struct module___153 *owner;
	const struct attribute_group___156 **class_groups;
	const struct attribute_group___156 **dev_groups;
	struct kobject___156 *dev_kobj;
	int (*dev_uevent)(struct device___125 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___125 *, umode_t *);
	void (*class_release)(struct class___125 *);
	void (*dev_release)(struct device___125 *);
	int (*shutdown_pre)(struct device___125 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___125 *);
	void (*get_ownership)(struct device___125 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___125 *pm;
	struct subsys_private *p;
};

struct property___32;

struct device_node___36 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___125 fwnode;
	struct property___32 *properties;
	struct property___32 *deadprops;
	struct device_node___36 *parent;
	struct device_node___36 *child;
	struct device_node___36 *sibling;
	struct kobject___156 kobj;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___81;

struct gendisk___81 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___82 *part0;
	const struct block_device_operations___81 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___156 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___156 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio___81;

struct block_device___83;

struct gendisk___82;

struct page___175;

struct module___154;

struct block_device_operations___81 {
	blk_qc_t (*submit_bio)(struct bio___81 *);
	int (*open)(struct block_device___83 *, fmode_t);
	void (*release)(struct gendisk___82 *, fmode_t);
	int (*rw_page)(struct block_device___83 *, sector_t, struct page___175 *, unsigned int);
	int (*ioctl)(struct block_device___83 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___83 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___82 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___82 *);
	int (*getgeo)(struct block_device___83 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___83 *, bool);
	void (*swap_slot_free_notify)(struct block_device___83 *, long unsigned int);
	int (*report_zones)(struct gendisk___82 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___82 *, umode_t *);
	struct module___154 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___82 *, sector_t *);
};

struct seq_operations___147 {
	void * (*start)(struct seq_file___147 *, loff_t *);
	void (*stop)(struct seq_file___147 *, void *);
	void * (*next)(struct seq_file___147 *, void *, loff_t *);
	int (*show)(struct seq_file___147 *, void *);
};

struct property___32 {
	char *name;
	int length;
	void *value;
	struct property___32 *next;
	long unsigned int _flags;
	struct bin_attribute___156 attr;
};

struct irq_fwspec___16 {
	struct fwnode_handle___125 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___17 {
	int (*match)(struct irq_domain___17 *, struct device_node___36 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___17 *, struct irq_fwspec___16 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___17 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___17 *, unsigned int);
	int (*xlate)(struct irq_domain___17 *, struct device_node___36 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___17 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___17 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___17 *, struct irq_data___18 *, bool);
	void (*deactivate)(struct irq_domain___17 *, struct irq_data___18 *);
	int (*translate)(struct irq_domain___17 *, struct irq_fwspec___16 *, long unsigned int *, unsigned int *);
};

struct integrity_iint_cache___5 {
	struct rb_node rb_node;
	struct mutex mutex;
	struct inode___169 *inode;
	u64 version;
	long unsigned int flags;
	long unsigned int measured_pcrs;
	long unsigned int atomic_flags;
	enum integrity_status ima_file_status: 4;
	enum integrity_status ima_mmap_status: 4;
	enum integrity_status ima_bprm_status: 4;
	enum integrity_status ima_read_status: 4;
	enum integrity_status ima_creds_status: 4;
	enum integrity_status evm_status: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ima_digest_data *ima_hash;
};

struct ima_event_data___5 {
	struct integrity_iint_cache___5 *iint;
	struct file___169 *file;
	const unsigned char *filename;
	struct evm_ima_xattr_data *xattr_value;
	int xattr_len;
	const struct modsig *modsig;
	const char *violation;
	const void *buf;
	int buf_len;
};

struct ima_template_field___5 {
	const char field_id[16];
	int (*field_init)(struct ima_event_data___5 *, struct ima_field_data *);
	void (*field_show)(struct seq_file___147 *, enum ima_show_type, struct ima_field_data *);
};

struct ima_template_desc___5 {
	struct list_head list;
	char *name;
	char *fmt;
	int num_fields;
	const struct ima_template_field___5 **fields;
};

enum lsm_rule_types {
	LSM_OBJ_USER = 0,
	LSM_OBJ_ROLE = 1,
	LSM_OBJ_TYPE = 2,
	LSM_SUBJ_USER = 3,
	LSM_SUBJ_ROLE = 4,
	LSM_SUBJ_TYPE = 5,
};

enum policy_types {
	ORIGINAL_TCB = 1,
	DEFAULT_TCB = 2,
};

enum policy_rule_list {
	IMA_DEFAULT_POLICY = 1,
	IMA_CUSTOM_POLICY = 2,
};

struct ima_rule_opt_list {
	size_t count;
	char *items[0];
};

struct ima_rule_entry {
	struct list_head list;
	int action;
	unsigned int flags;
	enum ima_hooks func;
	int mask;
	long unsigned int fsmagic;
	uuid_t fsuuid;
	kuid_t uid;
	kuid_t fowner;
	bool (*uid_op)(kuid_t, kuid_t);
	bool (*fowner_op)(kuid_t, kuid_t);
	int pcr;
	unsigned int allowed_algos;
	struct {
		void *rules[4];
		char *args_p;
		int type;
	} lsm[6];
	char *fsname;
	struct ima_rule_opt_list *keyrings;
	struct ima_rule_opt_list *label;
	struct ima_template_desc___5 *template;
};

enum {
	Opt_measure = 0,
	Opt_dont_measure = 1,
	Opt_appraise = 2,
	Opt_dont_appraise = 3,
	Opt_audit = 4,
	Opt_hash___3 = 5,
	Opt_dont_hash = 6,
	Opt_obj_user = 7,
	Opt_obj_role = 8,
	Opt_obj_type = 9,
	Opt_subj_user = 10,
	Opt_subj_role = 11,
	Opt_subj_type = 12,
	Opt_func = 13,
	Opt_mask = 14,
	Opt_fsmagic = 15,
	Opt_fsname = 16,
	Opt_fsuuid = 17,
	Opt_uid_eq = 18,
	Opt_euid_eq = 19,
	Opt_fowner_eq = 20,
	Opt_uid_gt = 21,
	Opt_euid_gt = 22,
	Opt_fowner_gt = 23,
	Opt_uid_lt = 24,
	Opt_euid_lt = 25,
	Opt_fowner_lt = 26,
	Opt_appraise_type = 27,
	Opt_appraise_flag = 28,
	Opt_appraise_algos = 29,
	Opt_permit_directio = 30,
	Opt_pcr = 31,
	Opt_template = 32,
	Opt_keyrings = 33,
	Opt_label = 34,
	Opt_err___10 = 35,
};

struct ima_kexec_hdr {
	u16 version;
	u16 _reserved0;
	u32 _reserved1;
	u64 buffer_size;
	u64 count;
};

enum header_fields {
	HDR_PCR = 0,
	HDR_DIGEST = 1,
	HDR_TEMPLATE_NAME = 2,
	HDR_TEMPLATE_DATA = 3,
	HDR__LAST = 4,
};

enum data_formats {
	DATA_FMT_DIGEST = 0,
	DATA_FMT_DIGEST_WITH_ALGO = 1,
	DATA_FMT_STRING = 2,
	DATA_FMT_HEX = 3,
	DATA_FMT_UINT = 4,
};

struct dentry___170;

struct super_block___170;

struct module___155;

struct file_system_type___170 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___170 * (*mount)(struct file_system_type___170 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___170 *);
	struct module___155 *owner;
	struct file_system_type___170 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___170;

struct kiocb___170;

struct poll_table_struct___111;

struct vm_area_struct___175;

struct inode___170;

struct file_lock___170;

struct page___176;

struct seq_file___148;

struct file_operations___170 {
	struct module___155 *owner;
	loff_t (*llseek)(struct file___170 *, loff_t, int);
	ssize_t (*read)(struct file___170 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___170 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___170 *, struct iov_iter___97 *);
	ssize_t (*write_iter)(struct kiocb___170 *, struct iov_iter___97 *);
	int (*iopoll)(struct kiocb___170 *, bool);
	int (*iterate)(struct file___170 *, struct dir_context *);
	int (*iterate_shared)(struct file___170 *, struct dir_context *);
	__poll_t (*poll)(struct file___170 *, struct poll_table_struct___111 *);
	long int (*unlocked_ioctl)(struct file___170 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___170 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___170 *, struct vm_area_struct___175 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___170 *, struct file___170 *);
	int (*flush)(struct file___170 *, fl_owner_t);
	int (*release)(struct inode___170 *, struct file___170 *);
	int (*fsync)(struct file___170 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___170 *, int);
	int (*lock)(struct file___170 *, int, struct file_lock___170 *);
	ssize_t (*sendpage)(struct file___170 *, struct page___176 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___170 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___170 *, long unsigned int);
	int (*flock)(struct file___170 *, int, struct file_lock___170 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___170 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___170 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___170 *, long int, struct file_lock___170 **, void **);
	long int (*fallocate)(struct file___170 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___148 *, struct file___170 *);
	ssize_t (*copy_file_range)(struct file___170 *, loff_t, struct file___170 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___170 *, loff_t, struct file___170 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___170 *, loff_t, loff_t, int);
};

struct vmacache___175 {
	u64 seqnum;
	struct vm_area_struct___175 *vmas[4];
};

struct page_frag___175 {
	struct page___176 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___176;

struct pid___151;

struct cred___28;

struct key___11;

struct nsproxy___160;

struct signal_struct___171;

struct vm_struct___154;

struct task_struct___177 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___177 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___176 *mm;
	struct mm_struct___176 *active_mm;
	struct vmacache___175 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___177 *real_parent;
	struct task_struct___177 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___177 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___151 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___28 *ptracer_cred;
	const struct cred___28 *real_cred;
	const struct cred___28 *cred;
	struct key___11 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___160 *nsproxy;
	struct signal_struct___171 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___177 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___80 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___175 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___177 *oom_reaper_list;
	struct vm_struct___154 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___157;

struct kobj_type___157;

struct kernfs_node___157;

struct kobject___157 {
	const char *name;
	struct list_head entry;
	struct kobject___157 *parent;
	struct kset___157 *kset;
	struct kobj_type___157 *ktype;
	struct kernfs_node___157 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___154 {
	struct kobject___157 kobj;
	struct module___155 *mod;
	struct kobject___157 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___154 {
	struct module___155 *mod;
	struct latch_tree_node node;
};

struct module_layout___154 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___154 mtn;
};

struct module_attribute___154;

struct kernel_param___154;

struct module___155 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___154 mkobj;
	struct module_attribute___154 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___157 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___154 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___154 core_layout;
	struct module_layout___154 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct key_type___9;

struct keyring_index_key___9 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___9 *type;
	struct key_tag *domain_tag;
	const char *description;
};

typedef int (*request_key_actor_t___10)(struct key___11 *, void *);

struct key_match_data___9;

struct key_restriction___11;

struct kernel_pkey_params___6;

struct key_type___9 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___11 *, struct key_preparsed_payload *);
	int (*update)(struct key___11 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___9 *);
	void (*match_free)(struct key_match_data___9 *);
	void (*revoke)(struct key___11 *);
	void (*destroy)(struct key___11 *);
	void (*describe)(const struct key___11 *, struct seq_file___148 *);
	long int (*read)(const struct key___11 *, char *, size_t);
	request_key_actor_t___10 request_key;
	struct key_restriction___11 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___6 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___6 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___6 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___15)(struct key___11 *, const struct key_type___9 *, const union key_payload *, struct key___11 *);

struct key___11 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___9 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___9 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___11 *restrict_link;
};

struct key_restriction___11 {
	key_restrict_link_func_t___15 check;
	struct key___11 *key;
	struct key_type___9 *keytype;
};

struct key_match_data___9 {
	bool (*cmp)(const struct key___11 *, const struct key_match_data___9 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct seq_operations___148;

struct seq_file___148 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___148 *op;
	int poll_event;
	const struct file___170 *file;
	void *private;
};

struct kernel_pkey_params___6 {
	struct key___11 *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___176 *pgtable_t___175;

struct address_space___170;

struct dev_pagemap___166;

struct page___176 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___170 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___176 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___175 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___176 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___166 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___166;

struct vm_area_struct___175 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___175 *vm_next;
	struct vm_area_struct___175 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___176 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___166 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___170 *vm_file;
	struct file___170 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___175;

struct mm_struct___176 {
	struct {
		struct vm_area_struct___175 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___170 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___175 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___177 *owner;
		struct user_namespace *user_ns;
		struct file___170 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___170;

struct address_space___170 {
	struct inode___170 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___170 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___166;

struct dev_pagemap___166 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___166 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___170;

struct path___170 {
	struct vfsmount___170 *mnt;
	struct dentry___170 *dentry;
};

struct fown_struct___151 {
	rwlock_t lock;
	struct pid___151 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___170 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___170 f_path;
	struct inode___170 *f_inode;
	const struct file_operations___170 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___151 f_owner;
	const struct cred___28 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___170 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___166;

struct vm_operations_struct___166 {
	void (*open)(struct vm_area_struct___175 *);
	void (*close)(struct vm_area_struct___175 *);
	int (*may_split)(struct vm_area_struct___175 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___175 *);
	int (*mprotect)(struct vm_area_struct___175 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___166 *);
	vm_fault_t (*huge_fault)(struct vm_fault___166 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___166 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___175 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___166 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___166 *);
	int (*access)(struct vm_area_struct___175 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___175 *);
	int (*set_policy)(struct vm_area_struct___175 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___175 *, long unsigned int);
	struct page___176 * (*find_special_page)(struct vm_area_struct___175 *, long unsigned int);
};

struct core_thread___175 {
	struct task_struct___177 *task;
	struct core_thread___175 *next;
};

struct core_state___175 {
	atomic_t nr_threads;
	struct core_thread___175 dumper;
	struct completion startup;
};

struct vm_fault___166 {
	const struct {
		struct vm_area_struct___175 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___176 *cow_page;
	struct page___176 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___175 prealloc_pte;
};

struct dentry_operations___170;

struct dentry___170 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___170 *d_parent;
	struct qstr d_name;
	struct inode___170 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___170 *d_op;
	struct super_block___170 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___170;

struct cdev___30;

struct inode___170 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___170 *i_op;
	struct super_block___170 *i_sb;
	struct address_space___170 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___170 *i_fop;
		void (*free_inode)(struct inode___170 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___170 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___30 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___170 {
	int (*d_revalidate)(struct dentry___170 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___170 *, unsigned int);
	int (*d_hash)(const struct dentry___170 *, struct qstr *);
	int (*d_compare)(const struct dentry___170 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___170 *);
	int (*d_init)(struct dentry___170 *);
	void (*d_release)(struct dentry___170 *);
	void (*d_prune)(struct dentry___170 *);
	void (*d_iput)(struct dentry___170 *, struct inode___170 *);
	char * (*d_dname)(struct dentry___170 *, char *, int);
	struct vfsmount___170 * (*d_automount)(struct path___170 *);
	int (*d_manage)(const struct path___170 *, bool);
	struct dentry___170 * (*d_real)(struct dentry___170 *, const struct inode___170 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___170;

struct mem_dqinfo___170 {
	struct quota_format_type___170 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___170;

struct quota_info___170 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___170 *files[3];
	struct mem_dqinfo___170 info[3];
	const struct quota_format_ops___170 *ops[3];
};

struct rcuwait___171 {
	struct task_struct___177 *task;
};

struct percpu_rw_semaphore___171 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___171 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___170 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___171 rw_sem[3];
};

struct super_operations___170;

struct dquot_operations___170;

struct quotactl_ops___170;

struct super_block___170 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___170 *s_type;
	const struct super_operations___170 *s_op;
	const struct dquot_operations___170 *dq_op;
	const struct quotactl_ops___170 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___170 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___11 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___170 s_dquot;
	struct sb_writers___170 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___170 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___170 {
	struct dentry___170 *mnt_root;
	struct super_block___170 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct pid_namespace___151;

struct upid___151 {
	int nr;
	struct pid_namespace___151 *ns;
};

struct pid_namespace___151 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___177 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___151 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___151 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___151 numbers[1];
};

struct signal_struct___171 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___177 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___177 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___151 *pids[4];
	struct pid___151 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___176 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cred___28 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___11 *session_keyring;
	struct key___11 *process_keyring;
	struct key___11 *thread_keyring;
	struct key___11 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct nsproxy___160 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___151 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___154 {
	struct vm_struct___154 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___176 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct kiocb___170 {
	struct file___170 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___170 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___170 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___170 *ia_file;
};

struct dquot___170 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___170 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___170 {
	int qf_fmt_id;
	const struct quota_format_ops___170 *qf_ops;
	struct module___155 *qf_owner;
	struct quota_format_type___170 *qf_next;
};

struct quota_format_ops___170 {
	int (*check_quota_file)(struct super_block___170 *, int);
	int (*read_file_info)(struct super_block___170 *, int);
	int (*write_file_info)(struct super_block___170 *, int);
	int (*free_file_info)(struct super_block___170 *, int);
	int (*read_dqblk)(struct dquot___170 *);
	int (*commit_dqblk)(struct dquot___170 *);
	int (*release_dqblk)(struct dquot___170 *);
	int (*get_next_id)(struct super_block___170 *, struct kqid *);
};

struct dquot_operations___170 {
	int (*write_dquot)(struct dquot___170 *);
	struct dquot___170 * (*alloc_dquot)(struct super_block___170 *, int);
	void (*destroy_dquot)(struct dquot___170 *);
	int (*acquire_dquot)(struct dquot___170 *);
	int (*release_dquot)(struct dquot___170 *);
	int (*mark_dirty)(struct dquot___170 *);
	int (*write_info)(struct super_block___170 *, int);
	qsize_t * (*get_reserved_space)(struct inode___170 *);
	int (*get_projid)(struct inode___170 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___170 *, qsize_t *);
	int (*get_next_id)(struct super_block___170 *, struct kqid *);
};

struct quotactl_ops___170 {
	int (*quota_on)(struct super_block___170 *, int, int, const struct path___170 *);
	int (*quota_off)(struct super_block___170 *, int);
	int (*quota_enable)(struct super_block___170 *, unsigned int);
	int (*quota_disable)(struct super_block___170 *, unsigned int);
	int (*quota_sync)(struct super_block___170 *, int);
	int (*set_info)(struct super_block___170 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___170 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___170 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___170 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___170 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___170 *, unsigned int);
};

struct address_space_operations___170 {
	int (*writepage)(struct page___176 *, struct writeback_control___3 *);
	int (*readpage)(struct file___170 *, struct page___176 *);
	int (*writepages)(struct address_space___170 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___176 *);
	int (*readpages)(struct file___170 *, struct address_space___170 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___170 *, struct address_space___170 *, loff_t, unsigned int, unsigned int, struct page___176 **, void **);
	int (*write_end)(struct file___170 *, struct address_space___170 *, loff_t, unsigned int, unsigned int, struct page___176 *, void *);
	sector_t (*bmap)(struct address_space___170 *, sector_t);
	void (*invalidatepage)(struct page___176 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___176 *, gfp_t);
	void (*freepage)(struct page___176 *);
	ssize_t (*direct_IO)(struct kiocb___170 *, struct iov_iter___97 *);
	int (*migratepage)(struct address_space___170 *, struct page___176 *, struct page___176 *, enum migrate_mode);
	bool (*isolate_page)(struct page___176 *, isolate_mode_t);
	void (*putback_page)(struct page___176 *);
	int (*launder_page)(struct page___176 *);
	int (*is_partially_uptodate)(struct page___176 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___176 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___170 *, struct page___176 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___170 *, sector_t *);
	void (*swap_deactivate)(struct file___170 *);
};

struct cdev___30 {
	struct kobject___157 kobj;
	struct module___155 *owner;
	const struct file_operations___170 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___170 {
	struct dentry___170 * (*lookup)(struct inode___170 *, struct dentry___170 *, unsigned int);
	const char * (*get_link)(struct dentry___170 *, struct inode___170 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___170 *, int);
	struct posix_acl * (*get_acl)(struct inode___170 *, int, bool);
	int (*readlink)(struct dentry___170 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___170 *, struct dentry___170 *, umode_t, bool);
	int (*link)(struct dentry___170 *, struct inode___170 *, struct dentry___170 *);
	int (*unlink)(struct inode___170 *, struct dentry___170 *);
	int (*symlink)(struct user_namespace *, struct inode___170 *, struct dentry___170 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___170 *, struct dentry___170 *, umode_t);
	int (*rmdir)(struct inode___170 *, struct dentry___170 *);
	int (*mknod)(struct user_namespace *, struct inode___170 *, struct dentry___170 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___170 *, struct dentry___170 *, struct inode___170 *, struct dentry___170 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___170 *, struct iattr___170 *);
	int (*getattr)(struct user_namespace *, const struct path___170 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___170 *, char *, size_t);
	int (*fiemap)(struct inode___170 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___170 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___170 *, struct dentry___170 *, struct file___170 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___170 *, struct dentry___170 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___170 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___170 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___170 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___170 {
	void (*fl_copy_lock)(struct file_lock___170 *, struct file_lock___170 *);
	void (*fl_release_private)(struct file_lock___170 *);
};

struct fasync_struct___170;

struct lock_manager_operations___170;

struct file_lock___170 {
	struct file_lock___170 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___170 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___170 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___170 *fl_ops;
	const struct lock_manager_operations___170 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___170 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___170 *);
	int (*lm_grant)(struct file_lock___170 *, int);
	bool (*lm_break)(struct file_lock___170 *);
	int (*lm_change)(struct file_lock___170 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___170 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___170 *);
};

struct fasync_struct___170 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___170 *fa_next;
	struct file___170 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___170 {
	struct inode___170 * (*alloc_inode)(struct super_block___170 *);
	void (*destroy_inode)(struct inode___170 *);
	void (*free_inode)(struct inode___170 *);
	void (*dirty_inode)(struct inode___170 *, int);
	int (*write_inode)(struct inode___170 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___170 *);
	void (*evict_inode)(struct inode___170 *);
	void (*put_super)(struct super_block___170 *);
	int (*sync_fs)(struct super_block___170 *, int);
	int (*freeze_super)(struct super_block___170 *);
	int (*freeze_fs)(struct super_block___170 *);
	int (*thaw_super)(struct super_block___170 *);
	int (*unfreeze_fs)(struct super_block___170 *);
	int (*statfs)(struct dentry___170 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___170 *, int *, char *);
	void (*umount_begin)(struct super_block___170 *);
	int (*show_options)(struct seq_file___148 *, struct dentry___170 *);
	int (*show_devname)(struct seq_file___148 *, struct dentry___170 *);
	int (*show_path)(struct seq_file___148 *, struct dentry___170 *);
	int (*show_stats)(struct seq_file___148 *, struct dentry___170 *);
	ssize_t (*quota_read)(struct super_block___170 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___170 *, int, const char *, size_t, loff_t);
	struct dquot___170 ** (*get_dquots)(struct inode___170 *);
	long int (*nr_cached_objects)(struct super_block___170 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___170 *, struct shrink_control___68 *);
	struct file___170 * (*real_loop)(struct file___170 *);
};

typedef void (*poll_queue_proc___113)(struct file___170 *, wait_queue_head_t *, struct poll_table_struct___111 *);

struct poll_table_struct___111 {
	poll_queue_proc___113 _qproc;
	__poll_t _key;
};

struct dev_pagemap_ops___166 {
	void (*page_free)(struct page___176 *);
	void (*kill)(struct dev_pagemap___166 *);
	void (*cleanup)(struct dev_pagemap___166 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___166 *);
};

struct kernfs_root___157;

struct kernfs_elem_dir___157 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___157 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___157;

struct kernfs_root___157 {
	struct kernfs_node___157 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___157 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___157 {
	struct kernfs_node___157 *target_kn;
};

struct kernfs_ops___157;

struct kernfs_elem_attr___157 {
	const struct kernfs_ops___157 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___157 *notify_next;
};

struct kernfs_node___157 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___157 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___157 dir;
		struct kernfs_elem_symlink___157 symlink;
		struct kernfs_elem_attr___157 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___157;

struct kernfs_ops___157 {
	int (*open)(struct kernfs_open_file___157 *);
	void (*release)(struct kernfs_open_file___157 *);
	int (*seq_show)(struct seq_file___148 *, void *);
	void * (*seq_start)(struct seq_file___148 *, loff_t *);
	void * (*seq_next)(struct seq_file___148 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___148 *, void *);
	ssize_t (*read)(struct kernfs_open_file___157 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___157 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___157 *, struct poll_table_struct___111 *);
	int (*mmap)(struct kernfs_open_file___157 *, struct vm_area_struct___175 *);
};

struct kernfs_syscall_ops___157 {
	int (*show_options)(struct seq_file___148 *, struct kernfs_root___157 *);
	int (*mkdir)(struct kernfs_node___157 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___157 *);
	int (*rename)(struct kernfs_node___157 *, struct kernfs_node___157 *, const char *);
	int (*show_path)(struct seq_file___148 *, struct kernfs_node___157 *, struct kernfs_root___157 *);
};

struct kernfs_open_file___157 {
	struct kernfs_node___157 *kn;
	struct file___170 *file;
	struct seq_file___148 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___166 *vm_ops;
};

struct bin_attribute___157;

struct attribute_group___157 {
	const char *name;
	umode_t (*is_visible)(struct kobject___157 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___157 *, struct bin_attribute___157 *, int);
	struct attribute **attrs;
	struct bin_attribute___157 **bin_attrs;
};

struct bin_attribute___157 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___170 * (*f_mapping)();
	ssize_t (*read)(struct file___170 *, struct kobject___157 *, struct bin_attribute___157 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___170 *, struct kobject___157 *, struct bin_attribute___157 *, char *, loff_t, size_t);
	int (*mmap)(struct file___170 *, struct kobject___157 *, struct bin_attribute___157 *, struct vm_area_struct___175 *);
};

struct sysfs_ops___157 {
	ssize_t (*show)(struct kobject___157 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___157 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___157;

struct kset___157 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___157 kobj;
	const struct kset_uevent_ops___157 *uevent_ops;
};

struct kobj_type___157 {
	void (*release)(struct kobject___157 *);
	const struct sysfs_ops___157 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___157 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___157 *);
	const void * (*namespace)(struct kobject___157 *);
	void (*get_ownership)(struct kobject___157 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___157 {
	int (* const filter)(struct kset___157 *, struct kobject___157 *);
	const char * (* const name)(struct kset___157 *, struct kobject___157 *);
	int (* const uevent)(struct kset___157 *, struct kobject___157 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___154 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___154 *);
	int (*get)(char *, const struct kernel_param___154 *);
	void (*free)(void *);
};

struct kparam_array___154;

struct kernel_param___154 {
	const char *name;
	struct module___155 *mod;
	const struct kernel_param_ops___154 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___154 *arr;
	};
};

struct kparam_array___154 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___154 *ops;
	void *elem;
};

struct module_attribute___154 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___154 *, struct module_kobject___154 *, char *);
	ssize_t (*store)(struct module_attribute___154 *, struct module_kobject___154 *, const char *, size_t);
	void (*setup)(struct module___155 *, const char *);
	int (*test)(struct module___155 *);
	void (*free)(struct module___155 *);
};

struct seq_operations___148 {
	void * (*start)(struct seq_file___148 *, loff_t *);
	void (*stop)(struct seq_file___148 *, void *);
	void * (*next)(struct seq_file___148 *, void *, loff_t *);
	int (*show)(struct seq_file___148 *, void *);
};

struct modsig___2 {
	struct pkcs7_message *pkcs7_msg;
	enum hash_algo hash_algo;
	const u8 *digest;
	u32 digest_size;
	int raw_pkcs7_len;
	u8 raw_pkcs7[0];
};

struct kimage___5;

typedef void *kexec_load_t___5(struct kimage___5 *, char *, long unsigned int, char *, long unsigned int, char *, long unsigned int);

struct kexec_file_ops___5 {
	kexec_probe_t *probe;
	kexec_load_t___5 *load;
	kexec_cleanup_t *cleanup;
	kexec_verify_sig_t *verify_sig;
};

struct kimage___5 {
	kimage_entry_t head;
	kimage_entry_t *entry;
	kimage_entry_t *last_entry;
	long unsigned int start;
	struct page___173 *control_code_page;
	struct page___173 *swap_page;
	void *vmcoreinfo_data_copy;
	long unsigned int nr_segments;
	struct kexec_segment segment[16];
	struct list_head control_pages;
	struct list_head dest_pages;
	struct list_head unusable_pages;
	long unsigned int control_page;
	unsigned int type;
	unsigned int preserve_context;
	unsigned int file_mode;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct kimage_arch arch;
	void *kernel_buf;
	long unsigned int kernel_buf_len;
	void *initrd_buf;
	long unsigned int initrd_buf_len;
	char *cmdline_buf;
	long unsigned int cmdline_buf_len;
	const struct kexec_file_ops___5 *fops;
	void *image_loader_data;
	struct purgatory_info purgatory_info;
	void *ima_buffer;
	phys_addr_t ima_buffer_addr;
	size_t ima_buffer_size;
	void *elf_headers;
	long unsigned int elf_headers_sz;
	long unsigned int elf_load_addr;
};

struct kexec_buf___3 {
	struct kimage___5 *image;
	void *buffer;
	long unsigned int bufsz;
	long unsigned int mem;
	long unsigned int memsz;
	long unsigned int buf_align;
	long unsigned int buf_min;
	long unsigned int buf_max;
	bool top_down;
};

struct dentry___171;

struct super_block___171;

struct module___156;

struct file_system_type___171 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___171 * (*mount)(struct file_system_type___171 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___171 *);
	struct module___156 *owner;
	struct file_system_type___171 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___171;

struct kiocb___171;

struct poll_table_struct___112;

struct vm_area_struct___176;

struct inode___171;

struct file_lock___171;

struct page___177;

struct seq_file___149;

struct file_operations___171 {
	struct module___156 *owner;
	loff_t (*llseek)(struct file___171 *, loff_t, int);
	ssize_t (*read)(struct file___171 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___171 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___171 *, struct iov_iter___97 *);
	ssize_t (*write_iter)(struct kiocb___171 *, struct iov_iter___97 *);
	int (*iopoll)(struct kiocb___171 *, bool);
	int (*iterate)(struct file___171 *, struct dir_context *);
	int (*iterate_shared)(struct file___171 *, struct dir_context *);
	__poll_t (*poll)(struct file___171 *, struct poll_table_struct___112 *);
	long int (*unlocked_ioctl)(struct file___171 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___171 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___171 *, struct vm_area_struct___176 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___171 *, struct file___171 *);
	int (*flush)(struct file___171 *, fl_owner_t);
	int (*release)(struct inode___171 *, struct file___171 *);
	int (*fsync)(struct file___171 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___171 *, int);
	int (*lock)(struct file___171 *, int, struct file_lock___171 *);
	ssize_t (*sendpage)(struct file___171 *, struct page___177 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___171 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___171 *, long unsigned int);
	int (*flock)(struct file___171 *, int, struct file_lock___171 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___171 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___171 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___171 *, long int, struct file_lock___171 **, void **);
	long int (*fallocate)(struct file___171 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___149 *, struct file___171 *);
	ssize_t (*copy_file_range)(struct file___171 *, loff_t, struct file___171 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___171 *, loff_t, struct file___171 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___171 *, loff_t, loff_t, int);
};

struct vmacache___176 {
	u64 seqnum;
	struct vm_area_struct___176 *vmas[4];
};

struct page_frag___176 {
	struct page___177 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___177;

struct pid___152;

struct cred___29;

struct key___12;

struct nsproxy___161;

struct signal_struct___172;

struct vm_struct___155;

struct task_struct___178 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___178 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___177 *mm;
	struct mm_struct___177 *active_mm;
	struct vmacache___176 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___178 *real_parent;
	struct task_struct___178 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___178 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___152 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___29 *ptracer_cred;
	const struct cred___29 *real_cred;
	const struct cred___29 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___161 *nsproxy;
	struct signal_struct___172 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___178 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___80 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___176 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___178 *oom_reaper_list;
	struct vm_struct___155 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___158;

struct kobj_type___158;

struct kernfs_node___158;

struct kobject___158 {
	const char *name;
	struct list_head entry;
	struct kobject___158 *parent;
	struct kset___158 *kset;
	struct kobj_type___158 *ktype;
	struct kernfs_node___158 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___155 {
	struct kobject___158 kobj;
	struct module___156 *mod;
	struct kobject___158 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___155 {
	struct module___156 *mod;
	struct latch_tree_node node;
};

struct module_layout___155 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___155 mtn;
};

struct module_attribute___155;

struct kernel_param___155;

struct module___156 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___155 mkobj;
	struct module_attribute___155 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___158 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___155 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___155 core_layout;
	struct module_layout___155 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ucounts___25;

struct user_namespace___25 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___25 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___26 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___12 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___12 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___25 *ucounts;
	long int ucount_max[16];
};

struct key_type___10;

struct keyring_index_key___10 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___10 *type;
	struct key_tag *domain_tag;
	const char *description;
};

typedef int (*request_key_actor_t___11)(struct key___12 *, void *);

struct key_match_data___10;

struct key_restriction___12;

struct key_type___10 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___12 *, struct key_preparsed_payload *);
	int (*update)(struct key___12 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___10 *);
	void (*match_free)(struct key_match_data___10 *);
	void (*revoke)(struct key___12 *);
	void (*destroy)(struct key___12 *);
	void (*describe)(const struct key___12 *, struct seq_file___149 *);
	long int (*read)(const struct key___12 *, char *, size_t);
	request_key_actor_t___11 request_key;
	struct key_restriction___12 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___2 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___2 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___2 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___16)(struct key___12 *, const struct key_type___10 *, const union key_payload *, struct key___12 *);

struct key___12 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___10 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___10 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___12 *restrict_link;
};

struct key_restriction___12 {
	key_restrict_link_func_t___16 check;
	struct key___12 *key;
	struct key_type___10 *keytype;
};

struct key_match_data___10 {
	bool (*cmp)(const struct key___12 *, const struct key_match_data___10 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct seq_operations___149;

struct seq_file___149 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___149 *op;
	int poll_event;
	const struct file___171 *file;
	void *private;
};

struct pid_namespace___152;

struct upid___152 {
	int nr;
	struct pid_namespace___152 *ns;
};

struct pid_namespace___152 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___178 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___152 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___152 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___152 numbers[1];
};

typedef struct page___177 *pgtable_t___176;

struct address_space___171;

struct dev_pagemap___167;

struct page___177 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___171 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___177 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___176 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___177 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___167 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___25 {
	struct hlist_node node;
	struct user_namespace___25 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___167;

struct vm_area_struct___176 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___176 *vm_next;
	struct vm_area_struct___176 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___177 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___167 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___171 *vm_file;
	struct file___171 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___172 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___178 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___178 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___152 *pids[4];
	struct pid___152 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___177 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___176;

struct mm_struct___177 {
	struct {
		struct vm_area_struct___176 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___171 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___176 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___178 *owner;
		struct user_namespace___25 *user_ns;
		struct file___171 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___29 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___12 *session_keyring;
	struct key___12 *process_keyring;
	struct key___12 *thread_keyring;
	struct key___12 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct nsproxy___161 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___152 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___155 {
	struct vm_struct___155 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___177 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct seq_operations___149 {
	void * (*start)(struct seq_file___149 *, loff_t *);
	void (*stop)(struct seq_file___149 *, void *);
	void * (*next)(struct seq_file___149 *, void *, loff_t *);
	int (*show)(struct seq_file___149 *, void *);
};

struct vfsmount___171;

struct path___171 {
	struct vfsmount___171 *mnt;
	struct dentry___171 *dentry;
};

struct fown_struct___152 {
	rwlock_t lock;
	struct pid___152 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___171 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___171 f_path;
	struct inode___171 *f_inode;
	const struct file_operations___171 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___152 f_owner;
	const struct cred___29 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___171 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct dentry_operations___171;

struct dentry___171 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___171 *d_parent;
	struct qstr d_name;
	struct inode___171 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___171 *d_op;
	struct super_block___171 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___171;

struct address_space___171 {
	struct inode___171 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___171 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___171;

struct cdev___31;

struct inode___171 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___171 *i_op;
	struct super_block___171 *i_sb;
	struct address_space___171 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___171 *i_fop;
		void (*free_inode)(struct inode___171 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___171 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___171 {
	int (*d_revalidate)(struct dentry___171 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___171 *, unsigned int);
	int (*d_hash)(const struct dentry___171 *, struct qstr *);
	int (*d_compare)(const struct dentry___171 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___171 *);
	int (*d_init)(struct dentry___171 *);
	void (*d_release)(struct dentry___171 *);
	void (*d_prune)(struct dentry___171 *);
	void (*d_iput)(struct dentry___171 *, struct inode___171 *);
	char * (*d_dname)(struct dentry___171 *, char *, int);
	struct vfsmount___171 * (*d_automount)(struct path___171 *);
	int (*d_manage)(const struct path___171 *, bool);
	struct dentry___171 * (*d_real)(struct dentry___171 *, const struct inode___171 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___171;

struct mem_dqinfo___171 {
	struct quota_format_type___171 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___171;

struct quota_info___171 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___171 *files[3];
	struct mem_dqinfo___171 info[3];
	const struct quota_format_ops___171 *ops[3];
};

struct rcuwait___172 {
	struct task_struct___178 *task;
};

struct percpu_rw_semaphore___172 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___172 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___171 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___172 rw_sem[3];
};

struct super_operations___171;

struct dquot_operations___171;

struct quotactl_ops___171;

struct super_block___171 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___171 *s_type;
	const struct super_operations___171 *s_op;
	const struct dquot_operations___171 *dq_op;
	const struct quotactl_ops___171 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___171 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___171 s_dquot;
	struct sb_writers___171 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___171 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___171 {
	struct dentry___171 *mnt_root;
	struct super_block___171 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct dev_pagemap_ops___167;

struct dev_pagemap___167 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___167 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___167;

struct vm_operations_struct___167 {
	void (*open)(struct vm_area_struct___176 *);
	void (*close)(struct vm_area_struct___176 *);
	int (*may_split)(struct vm_area_struct___176 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___176 *);
	int (*mprotect)(struct vm_area_struct___176 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___167 *);
	vm_fault_t (*huge_fault)(struct vm_fault___167 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___167 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___176 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___167 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___167 *);
	int (*access)(struct vm_area_struct___176 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___176 *);
	int (*set_policy)(struct vm_area_struct___176 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___176 *, long unsigned int);
	struct page___177 * (*find_special_page)(struct vm_area_struct___176 *, long unsigned int);
};

struct core_thread___176 {
	struct task_struct___178 *task;
	struct core_thread___176 *next;
};

struct core_state___176 {
	atomic_t nr_threads;
	struct core_thread___176 dumper;
	struct completion startup;
};

struct vm_fault___167 {
	const struct {
		struct vm_area_struct___176 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___177 *cow_page;
	struct page___177 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___176 prealloc_pte;
};

struct kiocb___171 {
	struct file___171 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___171 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___171 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___171 *ia_file;
};

struct dquot___171 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___171 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___171 {
	int qf_fmt_id;
	const struct quota_format_ops___171 *qf_ops;
	struct module___156 *qf_owner;
	struct quota_format_type___171 *qf_next;
};

struct quota_format_ops___171 {
	int (*check_quota_file)(struct super_block___171 *, int);
	int (*read_file_info)(struct super_block___171 *, int);
	int (*write_file_info)(struct super_block___171 *, int);
	int (*free_file_info)(struct super_block___171 *, int);
	int (*read_dqblk)(struct dquot___171 *);
	int (*commit_dqblk)(struct dquot___171 *);
	int (*release_dqblk)(struct dquot___171 *);
	int (*get_next_id)(struct super_block___171 *, struct kqid *);
};

struct dquot_operations___171 {
	int (*write_dquot)(struct dquot___171 *);
	struct dquot___171 * (*alloc_dquot)(struct super_block___171 *, int);
	void (*destroy_dquot)(struct dquot___171 *);
	int (*acquire_dquot)(struct dquot___171 *);
	int (*release_dquot)(struct dquot___171 *);
	int (*mark_dirty)(struct dquot___171 *);
	int (*write_info)(struct super_block___171 *, int);
	qsize_t * (*get_reserved_space)(struct inode___171 *);
	int (*get_projid)(struct inode___171 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___171 *, qsize_t *);
	int (*get_next_id)(struct super_block___171 *, struct kqid *);
};

struct quotactl_ops___171 {
	int (*quota_on)(struct super_block___171 *, int, int, const struct path___171 *);
	int (*quota_off)(struct super_block___171 *, int);
	int (*quota_enable)(struct super_block___171 *, unsigned int);
	int (*quota_disable)(struct super_block___171 *, unsigned int);
	int (*quota_sync)(struct super_block___171 *, int);
	int (*set_info)(struct super_block___171 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___171 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___171 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___171 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___171 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___171 *, unsigned int);
};

struct address_space_operations___171 {
	int (*writepage)(struct page___177 *, struct writeback_control___3 *);
	int (*readpage)(struct file___171 *, struct page___177 *);
	int (*writepages)(struct address_space___171 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___177 *);
	int (*readpages)(struct file___171 *, struct address_space___171 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___171 *, struct address_space___171 *, loff_t, unsigned int, unsigned int, struct page___177 **, void **);
	int (*write_end)(struct file___171 *, struct address_space___171 *, loff_t, unsigned int, unsigned int, struct page___177 *, void *);
	sector_t (*bmap)(struct address_space___171 *, sector_t);
	void (*invalidatepage)(struct page___177 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___177 *, gfp_t);
	void (*freepage)(struct page___177 *);
	ssize_t (*direct_IO)(struct kiocb___171 *, struct iov_iter___97 *);
	int (*migratepage)(struct address_space___171 *, struct page___177 *, struct page___177 *, enum migrate_mode);
	bool (*isolate_page)(struct page___177 *, isolate_mode_t);
	void (*putback_page)(struct page___177 *);
	int (*launder_page)(struct page___177 *);
	int (*is_partially_uptodate)(struct page___177 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___177 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___171 *, struct page___177 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___171 *, sector_t *);
	void (*swap_deactivate)(struct file___171 *);
};

struct cdev___31 {
	struct kobject___158 kobj;
	struct module___156 *owner;
	const struct file_operations___171 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___171 {
	struct dentry___171 * (*lookup)(struct inode___171 *, struct dentry___171 *, unsigned int);
	const char * (*get_link)(struct dentry___171 *, struct inode___171 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___171 *, int);
	struct posix_acl * (*get_acl)(struct inode___171 *, int, bool);
	int (*readlink)(struct dentry___171 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___171 *, struct dentry___171 *, umode_t, bool);
	int (*link)(struct dentry___171 *, struct inode___171 *, struct dentry___171 *);
	int (*unlink)(struct inode___171 *, struct dentry___171 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___171 *, struct dentry___171 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___171 *, struct dentry___171 *, umode_t);
	int (*rmdir)(struct inode___171 *, struct dentry___171 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___171 *, struct dentry___171 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___171 *, struct dentry___171 *, struct inode___171 *, struct dentry___171 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___171 *, struct iattr___171 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___171 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___171 *, char *, size_t);
	int (*fiemap)(struct inode___171 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___171 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___171 *, struct dentry___171 *, struct file___171 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___171 *, struct dentry___171 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___171 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___171 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___171 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___171 {
	void (*fl_copy_lock)(struct file_lock___171 *, struct file_lock___171 *);
	void (*fl_release_private)(struct file_lock___171 *);
};

struct fasync_struct___171;

struct lock_manager_operations___171;

struct file_lock___171 {
	struct file_lock___171 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___171 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___171 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___171 *fl_ops;
	const struct lock_manager_operations___171 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___171 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___171 *);
	int (*lm_grant)(struct file_lock___171 *, int);
	bool (*lm_break)(struct file_lock___171 *);
	int (*lm_change)(struct file_lock___171 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___171 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___171 *);
};

struct fasync_struct___171 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___171 *fa_next;
	struct file___171 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___171 {
	struct inode___171 * (*alloc_inode)(struct super_block___171 *);
	void (*destroy_inode)(struct inode___171 *);
	void (*free_inode)(struct inode___171 *);
	void (*dirty_inode)(struct inode___171 *, int);
	int (*write_inode)(struct inode___171 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___171 *);
	void (*evict_inode)(struct inode___171 *);
	void (*put_super)(struct super_block___171 *);
	int (*sync_fs)(struct super_block___171 *, int);
	int (*freeze_super)(struct super_block___171 *);
	int (*freeze_fs)(struct super_block___171 *);
	int (*thaw_super)(struct super_block___171 *);
	int (*unfreeze_fs)(struct super_block___171 *);
	int (*statfs)(struct dentry___171 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___171 *, int *, char *);
	void (*umount_begin)(struct super_block___171 *);
	int (*show_options)(struct seq_file___149 *, struct dentry___171 *);
	int (*show_devname)(struct seq_file___149 *, struct dentry___171 *);
	int (*show_path)(struct seq_file___149 *, struct dentry___171 *);
	int (*show_stats)(struct seq_file___149 *, struct dentry___171 *);
	ssize_t (*quota_read)(struct super_block___171 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___171 *, int, const char *, size_t, loff_t);
	struct dquot___171 ** (*get_dquots)(struct inode___171 *);
	long int (*nr_cached_objects)(struct super_block___171 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___171 *, struct shrink_control___68 *);
	struct file___171 * (*real_loop)(struct file___171 *);
};

typedef void (*poll_queue_proc___114)(struct file___171 *, wait_queue_head_t *, struct poll_table_struct___112 *);

struct poll_table_struct___112 {
	poll_queue_proc___114 _qproc;
	__poll_t _key;
};

struct dev_pagemap_ops___167 {
	void (*page_free)(struct page___177 *);
	void (*kill)(struct dev_pagemap___167 *);
	void (*cleanup)(struct dev_pagemap___167 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___167 *);
};

struct kernfs_root___158;

struct kernfs_elem_dir___158 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___158 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___158;

struct kernfs_root___158 {
	struct kernfs_node___158 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___158 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___158 {
	struct kernfs_node___158 *target_kn;
};

struct kernfs_ops___158;

struct kernfs_elem_attr___158 {
	const struct kernfs_ops___158 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___158 *notify_next;
};

struct kernfs_node___158 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___158 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___158 dir;
		struct kernfs_elem_symlink___158 symlink;
		struct kernfs_elem_attr___158 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___158;

struct kernfs_ops___158 {
	int (*open)(struct kernfs_open_file___158 *);
	void (*release)(struct kernfs_open_file___158 *);
	int (*seq_show)(struct seq_file___149 *, void *);
	void * (*seq_start)(struct seq_file___149 *, loff_t *);
	void * (*seq_next)(struct seq_file___149 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___149 *, void *);
	ssize_t (*read)(struct kernfs_open_file___158 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___158 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___158 *, struct poll_table_struct___112 *);
	int (*mmap)(struct kernfs_open_file___158 *, struct vm_area_struct___176 *);
};

struct kernfs_syscall_ops___158 {
	int (*show_options)(struct seq_file___149 *, struct kernfs_root___158 *);
	int (*mkdir)(struct kernfs_node___158 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___158 *);
	int (*rename)(struct kernfs_node___158 *, struct kernfs_node___158 *, const char *);
	int (*show_path)(struct seq_file___149 *, struct kernfs_node___158 *, struct kernfs_root___158 *);
};

struct kernfs_open_file___158 {
	struct kernfs_node___158 *kn;
	struct file___171 *file;
	struct seq_file___149 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___167 *vm_ops;
};

struct bin_attribute___158;

struct attribute_group___158 {
	const char *name;
	umode_t (*is_visible)(struct kobject___158 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___158 *, struct bin_attribute___158 *, int);
	struct attribute **attrs;
	struct bin_attribute___158 **bin_attrs;
};

struct bin_attribute___158 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___171 * (*f_mapping)();
	ssize_t (*read)(struct file___171 *, struct kobject___158 *, struct bin_attribute___158 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___171 *, struct kobject___158 *, struct bin_attribute___158 *, char *, loff_t, size_t);
	int (*mmap)(struct file___171 *, struct kobject___158 *, struct bin_attribute___158 *, struct vm_area_struct___176 *);
};

struct sysfs_ops___158 {
	ssize_t (*show)(struct kobject___158 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___158 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___158;

struct kset___158 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___158 kobj;
	const struct kset_uevent_ops___158 *uevent_ops;
};

struct kobj_type___158 {
	void (*release)(struct kobject___158 *);
	const struct sysfs_ops___158 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___158 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___158 *);
	const void * (*namespace)(struct kobject___158 *);
	void (*get_ownership)(struct kobject___158 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___158 {
	int (* const filter)(struct kset___158 *, struct kobject___158 *);
	const char * (* const name)(struct kset___158 *, struct kobject___158 *);
	int (* const uevent)(struct kset___158 *, struct kobject___158 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___155 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___155 *);
	int (*get)(char *, const struct kernel_param___155 *);
	void (*free)(void *);
};

struct kparam_array___155;

struct kernel_param___155 {
	const char *name;
	struct module___156 *mod;
	const struct kernel_param_ops___155 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___155 *arr;
	};
};

struct kparam_array___155 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___155 *ops;
	void *elem;
};

struct module_attribute___155 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___155 *, struct module_kobject___155 *, char *);
	ssize_t (*store)(struct module_attribute___155 *, struct module_kobject___155 *, const char *, size_t);
	void (*setup)(struct module___156 *, const char *);
	int (*test)(struct module___156 *);
	void (*free)(struct module___156 *);
};

struct ima_key_entry {
	struct list_head list;
	void *payload;
	size_t payload_len;
	char *keyring_name;
};

struct evm_xattr {
	struct evm_ima_xattr_data data;
	u8 digest[20];
};

struct xattr_list {
	struct list_head list;
	char *name;
	bool enabled;
};

struct evm_digest {
	struct ima_digest_data hdr;
	char digest[64];
};

struct h_misc {
	long unsigned int ino;
	__u32 generation;
	uid_t uid;
	gid_t gid;
	umode_t mode;
};

typedef int (*key_restrict_link_func_t___17)(struct key___12 *, const struct key_type *, const union key_payload *, struct key___12 *);

enum {
	CRYPTO_MSG_ALG_REQUEST = 0,
	CRYPTO_MSG_ALG_REGISTER = 1,
	CRYPTO_MSG_ALG_LOADED = 2,
};

struct crypto_larval {
	struct crypto_alg___15 alg;
	struct crypto_alg___15 *adult;
	struct completion completion;
	u32 mask;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_cipher {
	struct crypto_tfm___15 base;
};

struct crypto_comp___2 {
	struct crypto_tfm___15 base;
};

struct crypto_async_request___6;

typedef void (*crypto_completion_t___6)(struct crypto_async_request___6 *, int);

struct crypto_tfm___18;

struct crypto_async_request___6 {
	struct list_head list;
	crypto_completion_t___6 complete;
	void *data;
	struct crypto_tfm___18 *tfm;
	u32 flags;
};

struct crypto_alg___18;

struct crypto_tfm___18 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___18 *);
	struct crypto_alg___18 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___18 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___18 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___18 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___18 *, u8 *, const u8 *);
};

struct compress_alg___18 {
	int (*coa_compress)(struct crypto_tfm___18 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___18 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___3;

struct crypto_alg___18 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___3 *cra_type;
	union {
		struct cipher_alg___18 cipher;
		struct compress_alg___18 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___18 *);
	void (*cra_exit)(struct crypto_tfm___18 *);
	void (*cra_destroy)(struct crypto_alg___18 *);
	struct module___151 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___3;

struct crypto_type___3 {
	unsigned int (*ctxsize)(struct crypto_alg___18 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___18 *);
	int (*init)(struct crypto_tfm___18 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___18 *);
	void (*show)(struct seq_file___145 *, struct crypto_alg___18 *);
	int (*report)(struct sk_buff___36 *, struct crypto_alg___18 *);
	void (*free)(struct crypto_instance___3 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct crypto_template___3;

struct crypto_spawn___3;

struct crypto_instance___3 {
	struct crypto_alg___18 alg;
	struct crypto_template___3 *tmpl;
	union {
		struct hlist_node list;
		struct crypto_spawn___3 *spawns;
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_spawn___3 {
	struct list_head list;
	struct crypto_alg___18 *alg;
	union {
		struct crypto_instance___3 *inst;
		struct crypto_spawn___3 *next;
	};
	const struct crypto_type___3 *frontend;
	u32 mask;
	bool dead;
	bool registered;
};

struct crypto_template___3 {
	struct list_head list;
	struct hlist_head instances;
	struct module___151 *module;
	int (*create)(struct crypto_template___3 *, struct rtattr **);
	char name[128];
};

struct rtattr {
	short unsigned int rta_len;
	short unsigned int rta_type;
};

struct crypto_queue {
	struct list_head list;
	struct list_head *backlog;
	unsigned int qlen;
	unsigned int max_qlen;
};

struct crypto_attr_alg {
	char name[128];
};

struct crypto_attr_type {
	u32 type;
	u32 mask;
};

enum {
	NAPI_STATE_SCHED = 0,
	NAPI_STATE_MISSED = 1,
	NAPI_STATE_DISABLE = 2,
	NAPI_STATE_NPSVC = 3,
	NAPI_STATE_LISTED = 4,
	NAPI_STATE_NO_BUSY_POLL = 5,
	NAPI_STATE_IN_BUSY_POLL = 6,
	NAPI_STATE_PREFER_BUSY_POLL = 7,
	NAPI_STATE_THREADED = 8,
	NAPI_STATE_SCHED_THREADED = 9,
};

enum xps_map_type {
	XPS_CPUS = 0,
	XPS_RXQS = 1,
	XPS_MAPS_MAX = 2,
};

enum bpf_xdp_mode {
	XDP_MODE_SKB = 0,
	XDP_MODE_DRV = 1,
	XDP_MODE_HW = 2,
	__MAX_XDP_MODE = 3,
};

enum {
	NETIF_MSG_DRV_BIT = 0,
	NETIF_MSG_PROBE_BIT = 1,
	NETIF_MSG_LINK_BIT = 2,
	NETIF_MSG_TIMER_BIT = 3,
	NETIF_MSG_IFDOWN_BIT = 4,
	NETIF_MSG_IFUP_BIT = 5,
	NETIF_MSG_RX_ERR_BIT = 6,
	NETIF_MSG_TX_ERR_BIT = 7,
	NETIF_MSG_TX_QUEUED_BIT = 8,
	NETIF_MSG_INTR_BIT = 9,
	NETIF_MSG_TX_DONE_BIT = 10,
	NETIF_MSG_RX_STATUS_BIT = 11,
	NETIF_MSG_PKTDATA_BIT = 12,
	NETIF_MSG_HW_BIT = 13,
	NETIF_MSG_WOL_BIT = 14,
	NETIF_MSG_CLASS_COUNT = 15,
};

struct crypto_larval___2 {
	struct crypto_alg___18 alg;
	struct crypto_alg___18 *adult;
	struct completion completion;
	u32 mask;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	CRYPTOA_UNSPEC = 0,
	CRYPTOA_ALG = 1,
	CRYPTOA_TYPE = 2,
	__CRYPTOA_MAX = 3,
};

struct scatter_walk {
	struct scatterlist *sg;
	unsigned int offset;
};

struct aead_request {
	struct crypto_async_request___6 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead;

struct aead_alg {
	int (*setkey)(struct crypto_aead *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead *, unsigned int);
	int (*encrypt)(struct aead_request *);
	int (*decrypt)(struct aead_request *);
	int (*init)(struct crypto_aead *);
	void (*exit)(struct crypto_aead *);
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct crypto_aead {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct aead_instance {
	void (*free)(struct aead_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___3 base;
		} s;
		struct aead_alg alg;
	};
};

struct crypto_aead_spawn {
	struct crypto_spawn___3 base;
};

enum crypto_attr_type_t {
	CRYPTOCFGA_UNSPEC = 0,
	CRYPTOCFGA_PRIORITY_VAL = 1,
	CRYPTOCFGA_REPORT_LARVAL = 2,
	CRYPTOCFGA_REPORT_HASH = 3,
	CRYPTOCFGA_REPORT_BLKCIPHER = 4,
	CRYPTOCFGA_REPORT_AEAD = 5,
	CRYPTOCFGA_REPORT_COMPRESS = 6,
	CRYPTOCFGA_REPORT_RNG = 7,
	CRYPTOCFGA_REPORT_CIPHER = 8,
	CRYPTOCFGA_REPORT_AKCIPHER = 9,
	CRYPTOCFGA_REPORT_KPP = 10,
	CRYPTOCFGA_REPORT_ACOMP = 11,
	CRYPTOCFGA_STAT_LARVAL = 12,
	CRYPTOCFGA_STAT_HASH = 13,
	CRYPTOCFGA_STAT_BLKCIPHER = 14,
	CRYPTOCFGA_STAT_AEAD = 15,
	CRYPTOCFGA_STAT_COMPRESS = 16,
	CRYPTOCFGA_STAT_RNG = 17,
	CRYPTOCFGA_STAT_CIPHER = 18,
	CRYPTOCFGA_STAT_AKCIPHER = 19,
	CRYPTOCFGA_STAT_KPP = 20,
	CRYPTOCFGA_STAT_ACOMP = 21,
	__CRYPTOCFGA_MAX = 22,
};

struct crypto_report_aead {
	char type[64];
	char geniv[64];
	unsigned int blocksize;
	unsigned int maxauthsize;
	unsigned int ivsize;
};

struct crypto_sync_skcipher;

struct aead_geniv_ctx {
	spinlock_t lock;
	struct crypto_aead *child;
	struct crypto_sync_skcipher *sknull;
	u8 salt[0];
};

struct crypto_rng;

struct rng_alg {
	int (*generate)(struct crypto_rng *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct crypto_rng {
	struct crypto_tfm___18 base;
};

struct crypto_cipher___2 {
	struct crypto_tfm___18 base;
};

struct crypto_cipher_spawn {
	struct crypto_spawn___3 base;
};

struct skcipher_request___4 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___6 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___7 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct crypto_sync_skcipher___2 {
	struct crypto_skcipher___7 base;
};

struct skcipher_alg___4 {
	int (*setkey)(struct crypto_skcipher___7 *, const u8 *, unsigned int);
	int (*encrypt)(struct skcipher_request___4 *);
	int (*decrypt)(struct skcipher_request___4 *);
	int (*init)(struct crypto_skcipher___7 *);
	void (*exit)(struct crypto_skcipher___7 *);
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
	unsigned int chunksize;
	unsigned int walksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct skcipher_instance {
	void (*free)(struct skcipher_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___3 base;
		} s;
		struct skcipher_alg___4 alg;
	};
};

struct crypto_skcipher_spawn {
	struct crypto_spawn___3 base;
};

struct skcipher_walk {
	union {
		struct {
			struct page___172 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			void *addr;
		} virt;
	} src;
	union {
		struct {
			struct page___172 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			void *addr;
		} virt;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	struct list_head buffers;
	u8 *page;
	u8 *buffer;
	u8 *oiv;
	void *iv;
	unsigned int ivsize;
	int flags;
	unsigned int blocksize;
	unsigned int stride;
	unsigned int alignmask;
};

struct skcipher_ctx_simple {
	struct crypto_cipher___2 *cipher;
};

struct crypto_report_blkcipher {
	char type[64];
	char geniv[64];
	unsigned int blocksize;
	unsigned int min_keysize;
	unsigned int max_keysize;
	unsigned int ivsize;
};

enum {
	SKCIPHER_WALK_PHYS = 1,
	SKCIPHER_WALK_SLOW = 2,
	SKCIPHER_WALK_COPY = 4,
	SKCIPHER_WALK_DIFF = 8,
	SKCIPHER_WALK_SLEEP = 16,
};

struct skcipher_walk_buffer {
	struct list_head entry;
	struct scatter_walk dst;
	unsigned int len;
	u8 *data;
	u8 buffer[0];
};

struct aead_request___2 {
	struct crypto_async_request___4 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___2;

struct aead_alg___2 {
	int (*setkey)(struct crypto_aead___2 *, const u8 *, unsigned int);
	int (*setauthsize)(struct crypto_aead___2 *, unsigned int);
	int (*encrypt)(struct aead_request___2 *);
	int (*decrypt)(struct aead_request___2 *);
	int (*init)(struct crypto_aead___2 *);
	void (*exit)(struct crypto_aead___2 *);
	unsigned int ivsize;
	unsigned int maxauthsize;
	unsigned int chunksize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct crypto_aead___2 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct aead_instance___2 {
	void (*free)(struct aead_instance___2 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___2 base;
		} s;
		struct aead_alg___2 alg;
	};
};

struct crypto_sync_skcipher___3;

struct aead_geniv_ctx___2 {
	spinlock_t lock;
	struct crypto_aead___2 *child;
	struct crypto_sync_skcipher___3 *sknull;
	u8 salt[0];
};

struct crypto_sync_skcipher___3 {
	struct crypto_skcipher___6 base;
};

struct hash_alg_common___3 {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct ahash_request___3 {
	struct crypto_async_request___6 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___3;

struct ahash_alg {
	int (*init)(struct ahash_request___3 *);
	int (*update)(struct ahash_request___3 *);
	int (*final)(struct ahash_request___3 *);
	int (*finup)(struct ahash_request___3 *);
	int (*digest)(struct ahash_request___3 *);
	int (*export)(struct ahash_request___3 *, void *);
	int (*import)(struct ahash_request___3 *, const void *);
	int (*setkey)(struct crypto_ahash___3 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_ahash___3 *);
	void (*exit_tfm)(struct crypto_ahash___3 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hash_alg_common___3 halg;
};

struct crypto_ahash___3 {
	int (*init)(struct ahash_request___3 *);
	int (*update)(struct ahash_request___3 *);
	int (*final)(struct ahash_request___3 *);
	int (*finup)(struct ahash_request___3 *);
	int (*digest)(struct ahash_request___3 *);
	int (*export)(struct ahash_request___3 *, void *);
	int (*import)(struct ahash_request___3 *, const void *);
	int (*setkey)(struct crypto_ahash___3 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct crypto_shash___14;

struct shash_desc___10 {
	struct crypto_shash___14 *tfm;
	void *__ctx[0];
};

struct crypto_shash___14 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct shash_alg___5 {
	int (*init)(struct shash_desc___10 *);
	int (*update)(struct shash_desc___10 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___10 *, u8 *);
	int (*finup)(struct shash_desc___10 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___10 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___10 *, void *);
	int (*import)(struct shash_desc___10 *, const void *);
	int (*setkey)(struct crypto_shash___14 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___14 *);
	void (*exit_tfm)(struct crypto_shash___14 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct crypto_hash_walk {
	char *data;
	unsigned int offset;
	unsigned int alignmask;
	struct page___172 *pg;
	unsigned int entrylen;
	unsigned int total;
	struct scatterlist *sg;
	unsigned int flags;
};

struct ahash_instance {
	void (*free)(struct ahash_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[256];
			struct crypto_instance___3 base;
		} s;
		struct ahash_alg alg;
	};
};

struct crypto_ahash_spawn {
	struct crypto_spawn___3 base;
};

struct crypto_report_hash {
	char type[64];
	unsigned int blocksize;
	unsigned int digestsize;
};

struct ahash_request_priv {
	crypto_completion_t___6 complete;
	void *data;
	u8 *result;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *ubuf[0];
};

struct shash_instance {
	void (*free)(struct shash_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[256];
			struct crypto_instance___3 base;
		} s;
		struct shash_alg___5 alg;
	};
};

struct crypto_shash_spawn {
	struct crypto_spawn___3 base;
};

struct crypto_report_akcipher {
	char type[64];
};

struct akcipher_request {
	struct crypto_async_request___6 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher {
	struct crypto_tfm___18 base;
};

struct akcipher_alg {
	int (*sign)(struct akcipher_request *);
	int (*verify)(struct akcipher_request *);
	int (*encrypt)(struct akcipher_request *);
	int (*decrypt)(struct akcipher_request *);
	int (*set_pub_key)(struct crypto_akcipher *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher *);
	int (*init)(struct crypto_akcipher *);
	void (*exit)(struct crypto_akcipher *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct akcipher_instance {
	void (*free)(struct akcipher_instance *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___3 base;
		} s;
		struct akcipher_alg alg;
	};
};

struct crypto_akcipher_spawn {
	struct crypto_spawn___3 base;
};

struct crypto_report_kpp {
	char type[64];
};

struct kpp_request___2 {
	struct crypto_async_request___6 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_kpp___2 {
	struct crypto_tfm___18 base;
};

struct kpp_alg___2 {
	int (*set_secret)(struct crypto_kpp___2 *, const void *, unsigned int);
	int (*generate_public_key)(struct kpp_request___2 *);
	int (*compute_shared_secret)(struct kpp_request___2 *);
	unsigned int (*max_size)(struct crypto_kpp___2 *);
	int (*init)(struct crypto_kpp___2 *);
	void (*exit)(struct crypto_kpp___2 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct kpp_request___3 {
	struct crypto_async_request___4 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_kpp___3 {
	struct crypto_tfm___15 base;
};

struct kpp_alg___3 {
	int (*set_secret)(struct crypto_kpp___3 *, const void *, unsigned int);
	int (*generate_public_key)(struct kpp_request___3 *);
	int (*compute_shared_secret)(struct kpp_request___3 *);
	unsigned int (*max_size)(struct crypto_kpp___3 *);
	int (*init)(struct crypto_kpp___3 *);
	void (*exit)(struct crypto_kpp___3 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

typedef long unsigned int mpi_limb_t;

struct gcry_mpi {
	int alloced;
	int nlimbs;
	int nbits;
	int sign;
	unsigned int flags;
	mpi_limb_t *d;
};

typedef struct gcry_mpi *MPI;

struct dh_ctx {
	MPI p;
	MPI q;
	MPI g;
	MPI xa;
};

enum {
	CRYPTO_KPP_SECRET_TYPE_UNKNOWN = 0,
	CRYPTO_KPP_SECRET_TYPE_DH = 1,
	CRYPTO_KPP_SECRET_TYPE_ECDH = 2,
};

struct kpp_secret {
	short unsigned int type;
	short unsigned int len;
};

enum rsapubkey_actions {
	ACT_rsa_get_e = 0,
	ACT_rsa_get_n = 1,
	NR__rsapubkey_actions = 2,
};

enum rsaprivkey_actions {
	ACT_rsa_get_d = 0,
	ACT_rsa_get_dp = 1,
	ACT_rsa_get_dq = 2,
	ACT_rsa_get_e___2 = 3,
	ACT_rsa_get_n___2 = 4,
	ACT_rsa_get_p = 5,
	ACT_rsa_get_q = 6,
	ACT_rsa_get_qinv = 7,
	NR__rsaprivkey_actions = 8,
};

struct rsa_key {
	const u8 *n;
	const u8 *e;
	const u8 *d;
	const u8 *p;
	const u8 *q;
	const u8 *dp;
	const u8 *dq;
	const u8 *qinv;
	size_t n_sz;
	size_t e_sz;
	size_t d_sz;
	size_t p_sz;
	size_t q_sz;
	size_t dp_sz;
	size_t dq_sz;
	size_t qinv_sz;
};

struct akcipher_request___2 {
	struct crypto_async_request___4 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher___2 {
	struct crypto_tfm___15 base;
};

struct akcipher_alg___2 {
	int (*sign)(struct akcipher_request___2 *);
	int (*verify)(struct akcipher_request___2 *);
	int (*encrypt)(struct akcipher_request___2 *);
	int (*decrypt)(struct akcipher_request___2 *);
	int (*set_pub_key)(struct crypto_akcipher___2 *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher___2 *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher___2 *);
	int (*init)(struct crypto_akcipher___2 *);
	void (*exit)(struct crypto_akcipher___2 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct rsa_mpi_key {
	MPI n;
	MPI e;
	MPI d;
};

struct asn1_decoder___2;

struct akcipher_instance___2 {
	void (*free)(struct akcipher_instance___2 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___2 base;
		} s;
		struct akcipher_alg___2 alg;
	};
};

struct crypto_akcipher_spawn___2 {
	struct crypto_spawn___2 base;
};

struct rsa_asn1_template {
	const char *name;
	const u8 *data;
	size_t size;
};

struct pkcs1pad_ctx {
	struct crypto_akcipher___2 *child;
	unsigned int key_size;
};

struct pkcs1pad_inst_ctx {
	struct crypto_akcipher_spawn___2 spawn;
	const struct rsa_asn1_template *digest_info;
};

struct pkcs1pad_request {
	struct scatterlist in_sg[2];
	struct scatterlist out_sg[1];
	uint8_t *in_buf;
	uint8_t *out_buf;
	long: 64;
	long: 64;
	struct akcipher_request___2 child_req;
};

struct crypto_report_acomp {
	char type[64];
};

struct acomp_req___2 {
	struct crypto_async_request___6 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int slen;
	unsigned int dlen;
	u32 flags;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_acomp___2 {
	int (*compress)(struct acomp_req___2 *);
	int (*decompress)(struct acomp_req___2 *);
	void (*dst_free)(struct scatterlist *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___18 base;
};

struct acomp_alg {
	int (*compress)(struct acomp_req___2 *);
	int (*decompress)(struct acomp_req___2 *);
	void (*dst_free)(struct scatterlist *);
	int (*init)(struct crypto_acomp___2 *);
	void (*exit)(struct crypto_acomp___2 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct crypto_report_comp {
	char type[64];
};

struct crypto_scomp {
	struct crypto_tfm___18 base;
};

struct scomp_alg {
	void * (*alloc_ctx)(struct crypto_scomp *);
	void (*free_ctx)(struct crypto_scomp *, void *);
	int (*compress)(struct crypto_scomp *, const u8 *, unsigned int, u8 *, unsigned int *, void *);
	int (*decompress)(struct crypto_scomp *, const u8 *, unsigned int, u8 *, unsigned int *, void *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___18 base;
};

struct scomp_scratch {
	spinlock_t lock;
	void *src;
	void *dst;
};

struct cryptomgr_param {
	struct rtattr *tb[34];
	struct {
		struct rtattr attr;
		struct crypto_attr_type data;
	} type;
	struct {
		struct rtattr attr;
		struct crypto_attr_alg data;
	} attrs[32];
	char template[128];
	struct crypto_larval___2 *larval;
	u32 otype;
	u32 omask;
};

struct crypto_test_param {
	char driver[128];
	char alg[128];
	u32 type;
};

struct shash_desc___11 {
	struct crypto_shash___11 *tfm;
	void *__ctx[0];
};

struct shash_alg___6 {
	int (*init)(struct shash_desc___11 *);
	int (*update)(struct shash_desc___11 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___11 *, u8 *);
	int (*finup)(struct shash_desc___11 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___11 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___11 *, void *);
	int (*import)(struct shash_desc___11 *, const void *);
	int (*setkey)(struct crypto_shash___11 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___11 *);
	void (*exit_tfm)(struct crypto_shash___11 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct shash_instance___2 {
	void (*free)(struct shash_instance___2 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[256];
			struct crypto_instance___2 base;
		} s;
		struct shash_alg___6 alg;
	};
};

struct crypto_shash_spawn___2 {
	struct crypto_spawn___2 base;
};

struct hmac_ctx {
	struct crypto_shash___11 *hash;
};

struct skcipher_walk___2 {
	union {
		struct {
			struct page___177 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			void *addr;
		} virt;
	} src;
	union {
		struct {
			struct page___177 *page;
			long unsigned int offset;
		} phys;
		struct {
			u8 *page;
			void *addr;
		} virt;
	} dst;
	struct scatter_walk in;
	unsigned int nbytes;
	struct scatter_walk out;
	unsigned int total;
	struct list_head buffers;
	u8 *page;
	u8 *buffer;
	u8 *oiv;
	void *iv;
	unsigned int ivsize;
	int flags;
	unsigned int blocksize;
	unsigned int stride;
	unsigned int alignmask;
};

struct md5_state {
	u32 hash[4];
	u32 block[16];
	u64 byte_count;
};

struct sha1_state {
	u32 state[5];
	u64 count;
	u8 buffer[64];
};

typedef void sha1_block_fn(struct sha1_state *, const u8 *, int);

struct sha256_state {
	u32 state[8];
	u64 count;
	u8 buf[64];
};

struct sha512_state {
	u64 state[8];
	u64 count[2];
	u8 buf[128];
};

typedef void sha512_block_fn(struct sha512_state *, const u8 *, int);

typedef struct {
	u64 a;
	u64 b;
} u128;

typedef struct {
	__be64 a;
	__be64 b;
} be128;

typedef struct {
	__le64 b;
	__le64 a;
} le128;

struct gf128mul_4k {
	be128 t[256];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct gf128mul_64k {
	struct gf128mul_4k *t[16];
};

struct skcipher_instance___2 {
	void (*free)(struct skcipher_instance___2 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct {
			char head[128];
			struct crypto_instance___2 base;
		} s;
		struct skcipher_alg___3 alg;
	};
};

struct skcipher_ctx_simple___2 {
	struct crypto_cipher *cipher;
};

struct crypto_cipher_spawn___2 {
	struct crypto_spawn___2 base;
};

struct crypto_skcipher_spawn___2 {
	struct crypto_spawn___2 base;
};

struct crypto_cts_ctx {
	struct crypto_skcipher___6 *child;
};

struct crypto_cts_reqctx {
	struct scatterlist sg[2];
	unsigned int offset;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct skcipher_request___3 subreq;
};

typedef struct {
	u64 a;
	u64 b;
} u128___2;

typedef struct {
	__le64 b;
	__le64 a;
} le128___2;

struct xts_tfm_ctx {
	struct crypto_skcipher___6 *child;
	struct crypto_cipher *tweak;
};

struct xts_instance_ctx {
	struct crypto_skcipher_spawn___2 spawn;
	char name[128];
};

struct xts_request_ctx {
	le128___2 t;
	struct scatterlist *tail;
	struct scatterlist sg[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct skcipher_request___3 subreq;
};

struct crypto_rfc3686_ctx {
	struct crypto_skcipher___6 *child;
	u8 nonce[4];
};

struct crypto_rfc3686_req_ctx {
	u8 iv[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct skcipher_request___3 subreq;
};

typedef struct {
	__be64 a;
	__be64 b;
} be128___2;

struct crypto_aead_spawn___2 {
	struct crypto_spawn___2 base;
};

struct hash_alg_common___4 {
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct ahash_request___4 {
	struct crypto_async_request___4 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___4 {
	int (*init)(struct ahash_request___4 *);
	int (*update)(struct ahash_request___4 *);
	int (*final)(struct ahash_request___4 *);
	int (*finup)(struct ahash_request___4 *);
	int (*digest)(struct ahash_request___4 *);
	int (*export)(struct ahash_request___4 *, void *);
	int (*import)(struct ahash_request___4 *, const void *);
	int (*setkey)(struct crypto_ahash___4 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___15 base;
};

struct crypto_ahash_spawn___2 {
	struct crypto_spawn___2 base;
};

struct gcm_instance_ctx {
	struct crypto_skcipher_spawn___2 ctr;
	struct crypto_ahash_spawn___2 ghash;
};

struct crypto_gcm_ctx {
	struct crypto_skcipher___6 *ctr;
	struct crypto_ahash___4 *ghash;
};

struct crypto_rfc4106_ctx {
	struct crypto_aead___2 *child;
	u8 nonce[4];
};

struct crypto_rfc4106_req_ctx {
	struct scatterlist src[3];
	struct scatterlist dst[3];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct aead_request___2 subreq;
};

struct crypto_rfc4543_instance_ctx {
	struct crypto_aead_spawn___2 aead;
};

struct crypto_rfc4543_ctx {
	struct crypto_aead___2 *child;
	struct crypto_sync_skcipher___3 *null;
	u8 nonce[4];
};

struct crypto_rfc4543_req_ctx {
	struct aead_request___2 subreq;
};

struct crypto_gcm_ghash_ctx {
	unsigned int cryptlen;
	struct scatterlist *src;
	int (*complete)(struct aead_request___2 *, u32);
};

struct crypto_gcm_req_priv_ctx {
	u8 iv[16];
	u8 auth_tag[16];
	u8 iauth_tag[16];
	struct scatterlist src[3];
	struct scatterlist dst[3];
	struct scatterlist sg;
	struct crypto_gcm_ghash_ctx ghash_ctx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		struct ahash_request___4 ahreq;
		struct skcipher_request___3 skreq;
	} u;
};

struct crypto_aes_ctx {
	u32 key_enc[60];
	u32 key_dec[60];
	u32 key_length;
};

struct crypto_scomp___2 {
	struct crypto_tfm___15 base;
};

struct scomp_alg___2 {
	void * (*alloc_ctx)(struct crypto_scomp___2 *);
	void (*free_ctx)(struct crypto_scomp___2 *, void *);
	int (*compress)(struct crypto_scomp___2 *, const u8 *, unsigned int, u8 *, unsigned int *, void *);
	int (*decompress)(struct crypto_scomp___2 *, const u8 *, unsigned int, u8 *, unsigned int *, void *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct deflate_ctx {
	struct z_stream_s comp_stream;
	struct z_stream_s decomp_stream;
};

struct chksum_ctx {
	u32 key;
};

struct chksum_desc_ctx {
	u32 crc;
};

struct chksum_desc_ctx___2 {
	__u16 crc;
};

struct lzo_ctx {
	void *lzo_comp_mem;
};

struct lzorle_ctx {
	void *lzorle_comp_mem;
};

struct crypto_report_rng {
	char type[64];
	unsigned int seedsize;
};

struct random_ready_callback {
	struct list_head list;
	void (*func)(struct random_ready_callback *);
	struct module___156 *owner;
};

struct crypto_rng___2;

struct rng_alg___2 {
	int (*generate)(struct crypto_rng___2 *, const u8 *, unsigned int, u8 *, unsigned int);
	int (*seed)(struct crypto_rng___2 *, const u8 *, unsigned int);
	void (*set_ent)(struct crypto_rng___2 *, const u8 *, unsigned int);
	unsigned int seedsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___15 base;
};

struct crypto_rng___2 {
	struct crypto_tfm___15 base;
};

struct drbg_string {
	const unsigned char *buf;
	size_t len;
	struct list_head list;
};

typedef uint32_t drbg_flag_t;

struct drbg_core {
	drbg_flag_t flags;
	__u8 statelen;
	__u8 blocklen_bytes;
	char cra_name[128];
	char backend_cra_name[128];
};

struct drbg_state;

struct drbg_state_ops {
	int (*update)(struct drbg_state *, struct list_head *, int);
	int (*generate)(struct drbg_state *, unsigned char *, unsigned int, struct list_head *);
	int (*crypto_init)(struct drbg_state *);
	int (*crypto_fini)(struct drbg_state *);
};

struct drbg_state {
	struct mutex drbg_mutex;
	unsigned char *V;
	unsigned char *Vbuf;
	unsigned char *C;
	unsigned char *Cbuf;
	size_t reseed_ctr;
	size_t reseed_threshold;
	unsigned char *scratchpad;
	unsigned char *scratchpadbuf;
	void *priv_data;
	struct crypto_skcipher___6 *ctr_handle;
	struct skcipher_request___3 *ctr_req;
	__u8 *outscratchpadbuf;
	__u8 *outscratchpad;
	struct crypto_wait ctr_wait;
	struct scatterlist sg_in;
	struct scatterlist sg_out;
	bool seeded;
	bool pr;
	bool fips_primed;
	unsigned char *prev;
	struct work_struct seed_work;
	struct crypto_rng___2 *jent;
	const struct drbg_state_ops *d_ops;
	const struct drbg_core *core;
	struct drbg_string test_data;
	struct random_ready_callback random_ready;
};

enum drbg_prefixes {
	DRBG_PREFIX0 = 0,
	DRBG_PREFIX1 = 1,
	DRBG_PREFIX2 = 2,
	DRBG_PREFIX3 = 3,
};

struct sdesc___2 {
	struct shash_desc___11 shash;
	char ctx[0];
};

struct s {
	__be32 conv;
};

struct rand_data {
	__u64 data;
	__u64 old_data;
	__u64 prev_time;
	__u64 last_delta;
	__s64 last_delta2;
	unsigned int osr;
	unsigned char *mem;
	unsigned int memlocation;
	unsigned int memblocks;
	unsigned int memblocksize;
	unsigned int memaccessloops;
	int rct_count;
	unsigned int apt_observations;
	unsigned int apt_count;
	unsigned int apt_base;
	unsigned int apt_base_set;
	unsigned int health_failure;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rand_data___2;

struct jitterentropy {
	spinlock_t jent_lock;
	struct rand_data___2 *entropy_collector;
	unsigned int reset_cnt;
};

struct gf128mul_4k___2 {
	be128___2 t[256];
};

struct ghash_ctx {
	struct gf128mul_4k___2 *gf128;
};

struct ghash_desc_ctx {
	u8 buffer[16];
	u32 bytes;
};

struct dentry___172;

struct super_block___172;

struct module___157;

struct file_system_type___172 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___172 * (*mount)(struct file_system_type___172 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___172 *);
	struct module___157 *owner;
	struct file_system_type___172 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___172;

struct kiocb___172;

struct vm_area_struct___177;

struct inode___172;

struct file_lock___172;

struct page___178;

struct seq_file___150;

struct file_operations___172 {
	struct module___157 *owner;
	loff_t (*llseek)(struct file___172 *, loff_t, int);
	ssize_t (*read)(struct file___172 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___172 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___172 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___172 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___172 *, bool);
	int (*iterate)(struct file___172 *, struct dir_context *);
	int (*iterate_shared)(struct file___172 *, struct dir_context *);
	__poll_t (*poll)(struct file___172 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___172 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___172 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___172 *, struct vm_area_struct___177 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___172 *, struct file___172 *);
	int (*flush)(struct file___172 *, fl_owner_t);
	int (*release)(struct inode___172 *, struct file___172 *);
	int (*fsync)(struct file___172 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___172 *, int);
	int (*lock)(struct file___172 *, int, struct file_lock___172 *);
	ssize_t (*sendpage)(struct file___172 *, struct page___178 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___172 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___172 *, long unsigned int);
	int (*flock)(struct file___172 *, int, struct file_lock___172 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___172 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___172 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___172 *, long int, struct file_lock___172 **, void **);
	long int (*fallocate)(struct file___172 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___150 *, struct file___172 *);
	ssize_t (*copy_file_range)(struct file___172 *, loff_t, struct file___172 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___172 *, loff_t, struct file___172 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___172 *, loff_t, loff_t, int);
};

struct vmacache___177 {
	u64 seqnum;
	struct vm_area_struct___177 *vmas[4];
};

struct page_frag___177 {
	struct page___178 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___178;

struct cred___30;

struct key___13;

struct signal_struct___173;

struct task_struct___179 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___179 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___178 *mm;
	struct mm_struct___178 *active_mm;
	struct vmacache___177 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___179 *real_parent;
	struct task_struct___179 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___179 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___152 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___173 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___179 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___80 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___177 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___179 *oom_reaper_list;
	struct vm_struct___2 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___159;

struct kobj_type___159;

struct kernfs_node___159;

struct kobject___159 {
	const char *name;
	struct list_head entry;
	struct kobject___159 *parent;
	struct kset___159 *kset;
	struct kobj_type___159 *ktype;
	struct kernfs_node___159 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___156 {
	struct kobject___159 kobj;
	struct module___157 *mod;
	struct kobject___159 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___156 {
	struct module___157 *mod;
	struct latch_tree_node node;
};

struct module_layout___156 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___156 mtn;
};

struct module_attribute___156;

struct kernel_param___156;

struct module___157 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___156 mkobj;
	struct module_attribute___156 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___159 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___156 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___156 core_layout;
	struct module_layout___156 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___172;

struct dentry___172 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___172 *d_parent;
	struct qstr d_name;
	struct inode___172 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___172 *d_op;
	struct super_block___172 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___172;

struct address_space___172 {
	struct inode___172 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___172 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___172;

struct inode___172 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___172 *i_op;
	struct super_block___172 *i_sb;
	struct address_space___172 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___172 *i_fop;
		void (*free_inode)(struct inode___172 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___172 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___172;

struct path___172;

struct dentry_operations___172 {
	int (*d_revalidate)(struct dentry___172 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___172 *, unsigned int);
	int (*d_hash)(const struct dentry___172 *, struct qstr *);
	int (*d_compare)(const struct dentry___172 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___172 *);
	int (*d_init)(struct dentry___172 *);
	void (*d_release)(struct dentry___172 *);
	void (*d_prune)(struct dentry___172 *);
	void (*d_iput)(struct dentry___172 *, struct inode___172 *);
	char * (*d_dname)(struct dentry___172 *, char *, int);
	struct vfsmount___172 * (*d_automount)(struct path___172 *);
	int (*d_manage)(const struct path___172 *, bool);
	struct dentry___172 * (*d_real)(struct dentry___172 *, const struct inode___172 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___172;

struct mem_dqinfo___172 {
	struct quota_format_type___172 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___172;

struct quota_info___172 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___172 *files[3];
	struct mem_dqinfo___172 info[3];
	const struct quota_format_ops___172 *ops[3];
};

struct rcuwait___173 {
	struct task_struct___179 *task;
};

struct percpu_rw_semaphore___173 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___173 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___172 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___173 rw_sem[3];
};

struct super_operations___172;

struct dquot_operations___172;

struct quotactl_ops___172;

struct super_block___172 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___172 *s_type;
	const struct super_operations___172 *s_op;
	const struct dquot_operations___172 *dq_op;
	const struct quotactl_ops___172 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___172 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___172 s_dquot;
	struct sb_writers___172 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___172 *s_d_op;
	int cleancache_poolid;
	struct shrinker___68 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___172 {
	struct dentry___172 *mnt_root;
	struct super_block___172 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct path___172 {
	struct vfsmount___172 *mnt;
	struct dentry___172 *dentry;
};

typedef struct page___178 *pgtable_t___177;

struct page___178 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___172 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___178 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___177 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___178 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___167 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_area_struct___177 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___177 *vm_next;
	struct vm_area_struct___177 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___178 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___8 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___172 *vm_file;
	struct file___172 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___173 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___179 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___179 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___152 *pids[4];
	struct pid___152 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___178 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___177;

struct mm_struct___178 {
	struct {
		struct vm_area_struct___177 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___172 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___177 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___179 *owner;
		struct user_namespace *user_ns;
		struct file___172 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___30 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___13 *session_keyring;
	struct key___13 *process_keyring;
	struct key___13 *thread_keyring;
	struct key___13 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct key_type___11;

struct keyring_index_key___11 {
	long unsigned int hash;
	union {
		struct {
			u16 desc_len;
			char desc[6];
		};
		long unsigned int x;
	};
	struct key_type___11 *type;
	struct key_tag *domain_tag;
	const char *description;
};

struct key_restriction___13;

struct key___13 {
	refcount_t usage;
	key_serial_t serial;
	union {
		struct list_head graveyard_link;
		struct rb_node serial_node;
	};
	struct watch_list *watchers;
	struct rw_semaphore sem;
	struct key_user *user;
	void *security;
	union {
		time64_t expiry;
		time64_t revoked_at;
	};
	time64_t last_used_at;
	kuid_t uid;
	kgid_t gid;
	key_perm_t perm;
	short unsigned int quotalen;
	short unsigned int datalen;
	short int state;
	long unsigned int flags;
	union {
		struct keyring_index_key___11 index_key;
		struct {
			long unsigned int hash;
			long unsigned int len_desc;
			struct key_type___11 *type;
			struct key_tag *domain_tag;
			char *description;
		};
	};
	union {
		union key_payload payload;
		struct {
			struct list_head name_link;
			struct assoc_array keys;
		};
	};
	struct key_restriction___13 *restrict_link;
};

struct file___172 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___172 f_path;
	struct inode___172 *f_inode;
	const struct file_operations___172 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___152 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___172 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct core_thread___177 {
	struct task_struct___179 *task;
	struct core_thread___177 *next;
};

struct core_state___177 {
	atomic_t nr_threads;
	struct core_thread___177 dumper;
	struct completion startup;
};

typedef int (*request_key_actor_t___12)(struct key___13 *, void *);

struct key_match_data___11;

struct kernel_pkey_params___7;

struct key_type___11 {
	const char *name;
	size_t def_datalen;
	unsigned int flags;
	int (*vet_description)(const char *);
	int (*preparse)(struct key_preparsed_payload *);
	void (*free_preparse)(struct key_preparsed_payload *);
	int (*instantiate)(struct key___13 *, struct key_preparsed_payload *);
	int (*update)(struct key___13 *, struct key_preparsed_payload *);
	int (*match_preparse)(struct key_match_data___11 *);
	void (*match_free)(struct key_match_data___11 *);
	void (*revoke)(struct key___13 *);
	void (*destroy)(struct key___13 *);
	void (*describe)(const struct key___13 *, struct seq_file___150 *);
	long int (*read)(const struct key___13 *, char *, size_t);
	request_key_actor_t___12 request_key;
	struct key_restriction___13 * (*lookup_restriction)(const char *);
	int (*asym_query)(const struct kernel_pkey_params___7 *, struct kernel_pkey_query *);
	int (*asym_eds_op)(struct kernel_pkey_params___7 *, const void *, void *);
	int (*asym_verify_signature)(struct kernel_pkey_params___7 *, const void *, const void *);
	struct list_head link;
	struct lock_class_key lock_class;
};

typedef int (*key_restrict_link_func_t___18)(struct key___13 *, const struct key_type___11 *, const union key_payload *, struct key___13 *);

struct key_restriction___13 {
	key_restrict_link_func_t___18 check;
	struct key___13 *key;
	struct key_type___11 *keytype;
};

struct kiocb___172 {
	struct file___172 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___172 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___74 *ki_waitq;
	};
};

struct iattr___172 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___172 *ia_file;
};

struct dquot___172 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___172 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___172 {
	int qf_fmt_id;
	const struct quota_format_ops___172 *qf_ops;
	struct module___157 *qf_owner;
	struct quota_format_type___172 *qf_next;
};

struct quota_format_ops___172 {
	int (*check_quota_file)(struct super_block___172 *, int);
	int (*read_file_info)(struct super_block___172 *, int);
	int (*write_file_info)(struct super_block___172 *, int);
	int (*free_file_info)(struct super_block___172 *, int);
	int (*read_dqblk)(struct dquot___172 *);
	int (*commit_dqblk)(struct dquot___172 *);
	int (*release_dqblk)(struct dquot___172 *);
	int (*get_next_id)(struct super_block___172 *, struct kqid *);
};

struct dquot_operations___172 {
	int (*write_dquot)(struct dquot___172 *);
	struct dquot___172 * (*alloc_dquot)(struct super_block___172 *, int);
	void (*destroy_dquot)(struct dquot___172 *);
	int (*acquire_dquot)(struct dquot___172 *);
	int (*release_dquot)(struct dquot___172 *);
	int (*mark_dirty)(struct dquot___172 *);
	int (*write_info)(struct super_block___172 *, int);
	qsize_t * (*get_reserved_space)(struct inode___172 *);
	int (*get_projid)(struct inode___172 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___172 *, qsize_t *);
	int (*get_next_id)(struct super_block___172 *, struct kqid *);
};

struct quotactl_ops___172 {
	int (*quota_on)(struct super_block___172 *, int, int, const struct path___172 *);
	int (*quota_off)(struct super_block___172 *, int);
	int (*quota_enable)(struct super_block___172 *, unsigned int);
	int (*quota_disable)(struct super_block___172 *, unsigned int);
	int (*quota_sync)(struct super_block___172 *, int);
	int (*set_info)(struct super_block___172 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___172 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___172 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___172 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___172 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___172 *, unsigned int);
};

struct address_space_operations___172 {
	int (*writepage)(struct page___178 *, struct writeback_control___3 *);
	int (*readpage)(struct file___172 *, struct page___178 *);
	int (*writepages)(struct address_space___172 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___178 *);
	int (*readpages)(struct file___172 *, struct address_space___172 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___172 *, struct address_space___172 *, loff_t, unsigned int, unsigned int, struct page___178 **, void **);
	int (*write_end)(struct file___172 *, struct address_space___172 *, loff_t, unsigned int, unsigned int, struct page___178 *, void *);
	sector_t (*bmap)(struct address_space___172 *, sector_t);
	void (*invalidatepage)(struct page___178 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___178 *, gfp_t);
	void (*freepage)(struct page___178 *);
	ssize_t (*direct_IO)(struct kiocb___172 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___172 *, struct page___178 *, struct page___178 *, enum migrate_mode);
	bool (*isolate_page)(struct page___178 *, isolate_mode_t);
	void (*putback_page)(struct page___178 *);
	int (*launder_page)(struct page___178 *);
	int (*is_partially_uptodate)(struct page___178 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___178 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___172 *, struct page___178 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___172 *, sector_t *);
	void (*swap_deactivate)(struct file___172 *);
};

struct inode_operations___172 {
	struct dentry___172 * (*lookup)(struct inode___172 *, struct dentry___172 *, unsigned int);
	const char * (*get_link)(struct dentry___172 *, struct inode___172 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___172 *, int);
	struct posix_acl * (*get_acl)(struct inode___172 *, int, bool);
	int (*readlink)(struct dentry___172 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___172 *, struct dentry___172 *, umode_t, bool);
	int (*link)(struct dentry___172 *, struct inode___172 *, struct dentry___172 *);
	int (*unlink)(struct inode___172 *, struct dentry___172 *);
	int (*symlink)(struct user_namespace *, struct inode___172 *, struct dentry___172 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___172 *, struct dentry___172 *, umode_t);
	int (*rmdir)(struct inode___172 *, struct dentry___172 *);
	int (*mknod)(struct user_namespace *, struct inode___172 *, struct dentry___172 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___172 *, struct dentry___172 *, struct inode___172 *, struct dentry___172 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___172 *, struct iattr___172 *);
	int (*getattr)(struct user_namespace *, const struct path___172 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___172 *, char *, size_t);
	int (*fiemap)(struct inode___172 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___172 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___172 *, struct dentry___172 *, struct file___172 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___172 *, struct dentry___172 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___172 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___172 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___172 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___172 {
	void (*fl_copy_lock)(struct file_lock___172 *, struct file_lock___172 *);
	void (*fl_release_private)(struct file_lock___172 *);
};

struct fasync_struct___172;

struct lock_manager_operations___172;

struct file_lock___172 {
	struct file_lock___172 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___172 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___172 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___172 *fl_ops;
	const struct lock_manager_operations___172 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___172 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___172 *);
	int (*lm_grant)(struct file_lock___172 *, int);
	bool (*lm_break)(struct file_lock___172 *);
	int (*lm_change)(struct file_lock___172 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___172 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___172 *);
};

struct fasync_struct___172 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___172 *fa_next;
	struct file___172 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___172 {
	struct inode___172 * (*alloc_inode)(struct super_block___172 *);
	void (*destroy_inode)(struct inode___172 *);
	void (*free_inode)(struct inode___172 *);
	void (*dirty_inode)(struct inode___172 *, int);
	int (*write_inode)(struct inode___172 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___172 *);
	void (*evict_inode)(struct inode___172 *);
	void (*put_super)(struct super_block___172 *);
	int (*sync_fs)(struct super_block___172 *, int);
	int (*freeze_super)(struct super_block___172 *);
	int (*freeze_fs)(struct super_block___172 *);
	int (*thaw_super)(struct super_block___172 *);
	int (*unfreeze_fs)(struct super_block___172 *);
	int (*statfs)(struct dentry___172 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___172 *, int *, char *);
	void (*umount_begin)(struct super_block___172 *);
	int (*show_options)(struct seq_file___150 *, struct dentry___172 *);
	int (*show_devname)(struct seq_file___150 *, struct dentry___172 *);
	int (*show_path)(struct seq_file___150 *, struct dentry___172 *);
	int (*show_stats)(struct seq_file___150 *, struct dentry___172 *);
	ssize_t (*quota_read)(struct super_block___172 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___172 *, int, const char *, size_t, loff_t);
	struct dquot___172 ** (*get_dquots)(struct inode___172 *);
	long int (*nr_cached_objects)(struct super_block___172 *, struct shrink_control___68 *);
	long int (*free_cached_objects)(struct super_block___172 *, struct shrink_control___68 *);
	struct file___172 * (*real_loop)(struct file___172 *);
};

struct seq_operations___150;

struct seq_file___150 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___150 *op;
	int poll_event;
	const struct file___172 *file;
	void *private;
};

struct seq_operations___150 {
	void * (*start)(struct seq_file___150 *, loff_t *);
	void (*stop)(struct seq_file___150 *, void *);
	void * (*next)(struct seq_file___150 *, void *, loff_t *);
	int (*show)(struct seq_file___150 *, void *);
};

struct key_match_data___11 {
	bool (*cmp)(const struct key___13 *, const struct key_match_data___11 *);
	const void *raw_data;
	void *preparsed;
	unsigned int lookup_type;
};

struct kernel_pkey_params___7 {
	struct key___13 *key;
	const char *encoding;
	const char *hash_algo;
	char *info;
	__u32 in_len;
	union {
		__u32 out_len;
		__u32 in2_len;
	};
	enum kernel_pkey_operation op: 8;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct asymmetric_key_ids {
	void *id[2];
};

struct asymmetric_key_subtype {
	struct module___157 *owner;
	const char *name;
	short unsigned int name_len;
	void (*describe)(const struct key___13 *, struct seq_file___150 *);
	void (*destroy)(void *, void *);
	int (*query)(const struct kernel_pkey_params___7 *, struct kernel_pkey_query *);
	int (*eds_op)(struct kernel_pkey_params___7 *, const void *, void *);
	int (*verify_signature)(const struct key___13 *, const struct public_key_signature *);
};

struct asymmetric_key_parser {
	struct list_head link;
	struct module___157 *owner;
	const char *name;
	int (*parse)(struct key_preparsed_payload *);
};

struct kernfs_root___159;

struct kernfs_elem_dir___159 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___159 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___159;

struct kernfs_root___159 {
	struct kernfs_node___159 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___159 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___159 {
	struct kernfs_node___159 *target_kn;
};

struct kernfs_ops___159;

struct kernfs_elem_attr___159 {
	const struct kernfs_ops___159 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___159 *notify_next;
};

struct kernfs_node___159 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___159 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___159 dir;
		struct kernfs_elem_symlink___159 symlink;
		struct kernfs_elem_attr___159 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___159;

struct kernfs_ops___159 {
	int (*open)(struct kernfs_open_file___159 *);
	void (*release)(struct kernfs_open_file___159 *);
	int (*seq_show)(struct seq_file___150 *, void *);
	void * (*seq_start)(struct seq_file___150 *, loff_t *);
	void * (*seq_next)(struct seq_file___150 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___150 *, void *);
	ssize_t (*read)(struct kernfs_open_file___159 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___159 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___159 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___159 *, struct vm_area_struct___177 *);
};

struct kernfs_syscall_ops___159 {
	int (*show_options)(struct seq_file___150 *, struct kernfs_root___159 *);
	int (*mkdir)(struct kernfs_node___159 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___159 *);
	int (*rename)(struct kernfs_node___159 *, struct kernfs_node___159 *, const char *);
	int (*show_path)(struct seq_file___150 *, struct kernfs_node___159 *, struct kernfs_root___159 *);
};

struct kernfs_open_file___159 {
	struct kernfs_node___159 *kn;
	struct file___172 *file;
	struct seq_file___150 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct bin_attribute___159;

struct attribute_group___159 {
	const char *name;
	umode_t (*is_visible)(struct kobject___159 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___159 *, struct bin_attribute___159 *, int);
	struct attribute **attrs;
	struct bin_attribute___159 **bin_attrs;
};

struct bin_attribute___159 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___172 * (*f_mapping)();
	ssize_t (*read)(struct file___172 *, struct kobject___159 *, struct bin_attribute___159 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___172 *, struct kobject___159 *, struct bin_attribute___159 *, char *, loff_t, size_t);
	int (*mmap)(struct file___172 *, struct kobject___159 *, struct bin_attribute___159 *, struct vm_area_struct___177 *);
};

struct sysfs_ops___159 {
	ssize_t (*show)(struct kobject___159 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___159 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___159;

struct kset___159 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___159 kobj;
	const struct kset_uevent_ops___159 *uevent_ops;
};

struct kobj_type___159 {
	void (*release)(struct kobject___159 *);
	const struct sysfs_ops___159 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___159 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___159 *);
	const void * (*namespace)(struct kobject___159 *);
	void (*get_ownership)(struct kobject___159 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___159 {
	int (* const filter)(struct kset___159 *, struct kobject___159 *);
	const char * (* const name)(struct kset___159 *, struct kobject___159 *);
	int (* const uevent)(struct kset___159 *, struct kobject___159 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___156 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___156 *);
	int (*get)(char *, const struct kernel_param___156 *);
	void (*free)(void *);
};

struct kparam_array___156;

struct kernel_param___156 {
	const char *name;
	struct module___157 *mod;
	const struct kernel_param_ops___156 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___156 *arr;
	};
};

struct kparam_array___156 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___156 *ops;
	void *elem;
};

struct module_attribute___156 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___156 *, struct module_kobject___156 *, char *);
	ssize_t (*store)(struct module_attribute___156 *, struct module_kobject___156 *, const char *, size_t);
	void (*setup)(struct module___157 *, const char *);
	int (*test)(struct module___157 *);
	void (*free)(struct module___157 *);
};

struct asymmetric_key_subtype___2 {
	struct module___8 *owner;
	const char *name;
	short unsigned int name_len;
	void (*describe)(const struct key___12 *, struct seq_file___149 *);
	void (*destroy)(void *, void *);
	int (*query)(const struct kernel_pkey_params___2 *, struct kernel_pkey_query *);
	int (*eds_op)(struct kernel_pkey_params___2 *, const void *, void *);
	int (*verify_signature)(const struct key___12 *, const struct public_key_signature *);
};

struct asymmetric_key_subtype___3 {
	struct module___155 *owner;
	const char *name;
	short unsigned int name_len;
	void (*describe)(const struct key___11 *, struct seq_file___148 *);
	void (*destroy)(void *, void *);
	int (*query)(const struct kernel_pkey_params___6 *, struct kernel_pkey_query *);
	int (*eds_op)(struct kernel_pkey_params___6 *, const void *, void *);
	int (*verify_signature)(const struct key___11 *, const struct public_key_signature *);
};

struct crypto_async_request___7;

typedef void (*crypto_completion_t___7)(struct crypto_async_request___7 *, int);

struct crypto_tfm___19;

struct crypto_async_request___7 {
	struct list_head list;
	crypto_completion_t___7 complete;
	void *data;
	struct crypto_tfm___19 *tfm;
	u32 flags;
};

struct crypto_alg___19;

struct crypto_tfm___19 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___19 *);
	struct crypto_alg___19 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___19 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___19 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___19 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___19 *, u8 *, const u8 *);
};

struct compress_alg___19 {
	int (*coa_compress)(struct crypto_tfm___19 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___19 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_type___4;

struct crypto_alg___19 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type___4 *cra_type;
	union {
		struct cipher_alg___19 cipher;
		struct compress_alg___19 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___19 *);
	void (*cra_exit)(struct crypto_tfm___19 *);
	void (*cra_destroy)(struct crypto_alg___19 *);
	struct module___155 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_instance___4;

struct crypto_type___4 {
	unsigned int (*ctxsize)(struct crypto_alg___19 *, u32, u32);
	unsigned int (*extsize)(struct crypto_alg___19 *);
	int (*init)(struct crypto_tfm___19 *, u32, u32);
	int (*init_tfm)(struct crypto_tfm___19 *);
	void (*show)(struct seq_file___148 *, struct crypto_alg___19 *);
	int (*report)(struct sk_buff___6 *, struct crypto_alg___19 *);
	void (*free)(struct crypto_instance___4 *);
	unsigned int type;
	unsigned int maskclear;
	unsigned int maskset;
	unsigned int tfmsize;
};

struct akcipher_request___3 {
	struct crypto_async_request___7 base;
	struct scatterlist *src;
	struct scatterlist *dst;
	unsigned int src_len;
	unsigned int dst_len;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_akcipher___3 {
	struct crypto_tfm___19 base;
};

struct akcipher_alg___3 {
	int (*sign)(struct akcipher_request___3 *);
	int (*verify)(struct akcipher_request___3 *);
	int (*encrypt)(struct akcipher_request___3 *);
	int (*decrypt)(struct akcipher_request___3 *);
	int (*set_pub_key)(struct crypto_akcipher___3 *, const void *, unsigned int);
	int (*set_priv_key)(struct crypto_akcipher___3 *, const void *, unsigned int);
	unsigned int (*max_size)(struct crypto_akcipher___3 *);
	int (*init)(struct crypto_akcipher___3 *);
	void (*exit)(struct crypto_akcipher___3 *);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___19 base;
};

struct crypto_template___4;

struct crypto_spawn___4;

struct crypto_instance___4 {
	struct crypto_alg___19 alg;
	struct crypto_template___4 *tmpl;
	union {
		struct hlist_node list;
		struct crypto_spawn___4 *spawns;
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_spawn___4 {
	struct list_head list;
	struct crypto_alg___19 *alg;
	union {
		struct crypto_instance___4 *inst;
		struct crypto_spawn___4 *next;
	};
	const struct crypto_type___4 *frontend;
	u32 mask;
	bool dead;
	bool registered;
};

struct crypto_template___4 {
	struct list_head list;
	struct hlist_head instances;
	struct module___155 *module;
	int (*create)(struct crypto_template___4 *, struct rtattr **);
	char name[128];
};

enum x509_actions {
	ACT_x509_extract_key_data = 0,
	ACT_x509_extract_name_segment = 1,
	ACT_x509_note_OID = 2,
	ACT_x509_note_issuer = 3,
	ACT_x509_note_not_after = 4,
	ACT_x509_note_not_before = 5,
	ACT_x509_note_params = 6,
	ACT_x509_note_pkey_algo = 7,
	ACT_x509_note_serial = 8,
	ACT_x509_note_signature = 9,
	ACT_x509_note_subject = 10,
	ACT_x509_note_tbs_certificate = 11,
	ACT_x509_process_extension = 12,
	NR__x509_actions = 13,
};

enum x509_akid_actions {
	ACT_x509_akid_note_kid = 0,
	ACT_x509_akid_note_name = 1,
	ACT_x509_akid_note_serial = 2,
	ACT_x509_extract_name_segment___2 = 3,
	ACT_x509_note_OID___2 = 4,
	NR__x509_akid_actions = 5,
};

struct x509_certificate {
	struct x509_certificate *next;
	struct x509_certificate *signer;
	struct public_key *pub;
	struct public_key_signature *sig;
	char *issuer;
	char *subject;
	struct asymmetric_key_id *id;
	struct asymmetric_key_id *skid;
	time64_t valid_from;
	time64_t valid_to;
	const void *tbs;
	unsigned int tbs_size;
	unsigned int raw_sig_size;
	const void *raw_sig;
	const void *raw_serial;
	unsigned int raw_serial_size;
	unsigned int raw_issuer_size;
	const void *raw_issuer;
	const void *raw_subject;
	unsigned int raw_subject_size;
	unsigned int raw_skid_size;
	const void *raw_skid;
	unsigned int index;
	bool seen;
	bool verified;
	bool self_signed;
	bool unsupported_key;
	bool unsupported_sig;
	bool blacklisted;
};

struct x509_parse_context {
	struct x509_certificate *cert;
	long unsigned int data;
	const void *cert_start;
	const void *key;
	size_t key_size;
	const void *params;
	size_t params_size;
	enum OID key_algo;
	enum OID last_oid;
	enum OID algo_oid;
	unsigned char nr_mpi;
	u8 o_size;
	u8 cn_size;
	u8 email_size;
	u16 o_offset;
	u16 cn_offset;
	u16 email_offset;
	unsigned int raw_akid_size;
	const void *raw_akid;
	const void *akid_raw_issuer;
	unsigned int akid_raw_issuer_size;
};

struct asymmetric_key_parser___2 {
	struct list_head link;
	struct module___8 *owner;
	const char *name;
	int (*parse)(struct key_preparsed_payload *);
};

enum pkcs7_actions {
	ACT_pkcs7_check_content_type = 0,
	ACT_pkcs7_extract_cert = 1,
	ACT_pkcs7_note_OID = 2,
	ACT_pkcs7_note_certificate_list = 3,
	ACT_pkcs7_note_content = 4,
	ACT_pkcs7_note_data = 5,
	ACT_pkcs7_note_signed_info = 6,
	ACT_pkcs7_note_signeddata_version = 7,
	ACT_pkcs7_note_signerinfo_version = 8,
	ACT_pkcs7_sig_note_authenticated_attr = 9,
	ACT_pkcs7_sig_note_digest_algo = 10,
	ACT_pkcs7_sig_note_issuer = 11,
	ACT_pkcs7_sig_note_pkey_algo = 12,
	ACT_pkcs7_sig_note_serial = 13,
	ACT_pkcs7_sig_note_set_of_authattrs = 14,
	ACT_pkcs7_sig_note_signature = 15,
	ACT_pkcs7_sig_note_skid = 16,
	NR__pkcs7_actions = 17,
};

struct pkcs7_signed_info {
	struct pkcs7_signed_info *next;
	struct x509_certificate *signer;
	unsigned int index;
	bool unsupported_crypto;
	bool blacklisted;
	const void *msgdigest;
	unsigned int msgdigest_len;
	unsigned int authattrs_len;
	const void *authattrs;
	long unsigned int aa_set;
	time64_t signing_time;
	struct public_key_signature *sig;
};

struct pkcs7_message___2 {
	struct x509_certificate *certs;
	struct x509_certificate *crl;
	struct pkcs7_signed_info *signed_infos;
	u8 version;
	bool have_authattrs;
	enum OID data_type;
	size_t data_len;
	size_t data_hdrlen;
	const void *data;
};

struct pkcs7_parse_context {
	struct pkcs7_message___2 *msg;
	struct pkcs7_signed_info *sinfo;
	struct pkcs7_signed_info **ppsinfo;
	struct x509_certificate *certs;
	struct x509_certificate **ppcerts;
	long unsigned int data;
	enum OID last_oid;
	unsigned int x509_index;
	unsigned int sinfo_index;
	const void *raw_serial;
	unsigned int raw_serial_size;
	unsigned int raw_issuer_size;
	const void *raw_issuer;
	const void *raw_skid;
	unsigned int raw_skid_size;
	bool expect_skid;
};

typedef int (*key_restrict_link_func_t___19)(struct key___13 *, const struct key_type *, const union key_payload *, struct key___13 *);

struct mz_hdr {
	uint16_t magic;
	uint16_t lbsize;
	uint16_t blocks;
	uint16_t relocs;
	uint16_t hdrsize;
	uint16_t min_extra_pps;
	uint16_t max_extra_pps;
	uint16_t ss;
	uint16_t sp;
	uint16_t checksum;
	uint16_t ip;
	uint16_t cs;
	uint16_t reloc_table_offset;
	uint16_t overlay_num;
	uint16_t reserved0[4];
	uint16_t oem_id;
	uint16_t oem_info;
	uint16_t reserved1[10];
	uint32_t peaddr;
	char message[0];
};

struct pe_hdr {
	uint32_t magic;
	uint16_t machine;
	uint16_t sections;
	uint32_t timestamp;
	uint32_t symbol_table;
	uint32_t symbols;
	uint16_t opt_hdr_size;
	uint16_t flags;
};

struct pe32_opt_hdr {
	uint16_t magic;
	uint8_t ld_major;
	uint8_t ld_minor;
	uint32_t text_size;
	uint32_t data_size;
	uint32_t bss_size;
	uint32_t entry_point;
	uint32_t code_base;
	uint32_t data_base;
	uint32_t image_base;
	uint32_t section_align;
	uint32_t file_align;
	uint16_t os_major;
	uint16_t os_minor;
	uint16_t image_major;
	uint16_t image_minor;
	uint16_t subsys_major;
	uint16_t subsys_minor;
	uint32_t win32_version;
	uint32_t image_size;
	uint32_t header_size;
	uint32_t csum;
	uint16_t subsys;
	uint16_t dll_flags;
	uint32_t stack_size_req;
	uint32_t stack_size;
	uint32_t heap_size_req;
	uint32_t heap_size;
	uint32_t loader_flags;
	uint32_t data_dirs;
};

struct pe32plus_opt_hdr {
	uint16_t magic;
	uint8_t ld_major;
	uint8_t ld_minor;
	uint32_t text_size;
	uint32_t data_size;
	uint32_t bss_size;
	uint32_t entry_point;
	uint32_t code_base;
	uint64_t image_base;
	uint32_t section_align;
	uint32_t file_align;
	uint16_t os_major;
	uint16_t os_minor;
	uint16_t image_major;
	uint16_t image_minor;
	uint16_t subsys_major;
	uint16_t subsys_minor;
	uint32_t win32_version;
	uint32_t image_size;
	uint32_t header_size;
	uint32_t csum;
	uint16_t subsys;
	uint16_t dll_flags;
	uint64_t stack_size_req;
	uint64_t stack_size;
	uint64_t heap_size_req;
	uint64_t heap_size;
	uint32_t loader_flags;
	uint32_t data_dirs;
};

struct data_dirent {
	uint32_t virtual_address;
	uint32_t size;
};

struct data_directory {
	struct data_dirent exports;
	struct data_dirent imports;
	struct data_dirent resources;
	struct data_dirent exceptions;
	struct data_dirent certs;
	struct data_dirent base_relocations;
	struct data_dirent debug;
	struct data_dirent arch;
	struct data_dirent global_ptr;
	struct data_dirent tls;
	struct data_dirent load_config;
	struct data_dirent bound_imports;
	struct data_dirent import_addrs;
	struct data_dirent delay_imports;
	struct data_dirent clr_runtime_hdr;
	struct data_dirent reserved;
};

struct section_header {
	char name[8];
	uint32_t virtual_size;
	uint32_t virtual_address;
	uint32_t raw_data_size;
	uint32_t data_addr;
	uint32_t relocs;
	uint32_t line_numbers;
	uint16_t num_relocs;
	uint16_t num_lin_numbers;
	uint32_t flags;
};

struct win_certificate {
	uint32_t length;
	uint16_t revision;
	uint16_t cert_type;
};

struct crypto_alg___20;

struct crypto_tfm___20 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___20 *);
	struct crypto_alg___20 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___20 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___20 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___20 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___20 *, u8 *, const u8 *);
};

struct compress_alg___20 {
	int (*coa_compress)(struct crypto_tfm___20 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___20 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___20 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___20 cipher;
		struct compress_alg___20 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___20 *);
	void (*cra_exit)(struct crypto_tfm___20 *);
	void (*cra_destroy)(struct crypto_alg___20 *);
	struct module___157 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___15;

struct shash_desc___12 {
	struct crypto_shash___15 *tfm;
	void *__ctx[0];
};

struct crypto_shash___15 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___20 base;
};

struct shash_alg___7 {
	int (*init)(struct shash_desc___12 *);
	int (*update)(struct shash_desc___12 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___12 *, u8 *);
	int (*finup)(struct shash_desc___12 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___12 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___12 *, void *);
	int (*import)(struct shash_desc___12 *, const void *);
	int (*setkey)(struct crypto_shash___15 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___15 *);
	void (*exit_tfm)(struct crypto_shash___15 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___20 base;
};

struct pefile_context {
	unsigned int header_size;
	unsigned int image_checksum_offset;
	unsigned int cert_dirent_offset;
	unsigned int n_data_dirents;
	unsigned int n_sections;
	unsigned int certs_size;
	unsigned int sig_offset;
	unsigned int sig_len;
	const struct section_header *secs;
	const void *digest;
	unsigned int digest_len;
	const char *digest_algo;
};

enum mscode_actions {
	ACT_mscode_note_content_type = 0,
	ACT_mscode_note_digest = 1,
	ACT_mscode_note_digest_algo = 2,
	NR__mscode_actions = 3,
};

struct fs_context___31;

struct dentry___173;

struct super_block___173;

struct module___158;

struct file_system_type___173 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___31 *);
	const struct fs_parameter_spec *parameters;
	struct dentry___173 * (*mount)(struct file_system_type___173 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___173 *);
	struct module___158 *owner;
	struct file_system_type___173 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___173;

struct kiocb___173;

struct iov_iter___98;

struct vm_area_struct___178;

struct inode___173;

struct file_lock___173;

struct page___179;

struct seq_file___151;

struct file_operations___173 {
	struct module___158 *owner;
	loff_t (*llseek)(struct file___173 *, loff_t, int);
	ssize_t (*read)(struct file___173 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___173 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___173 *, struct iov_iter___98 *);
	ssize_t (*write_iter)(struct kiocb___173 *, struct iov_iter___98 *);
	int (*iopoll)(struct kiocb___173 *, bool);
	int (*iterate)(struct file___173 *, struct dir_context *);
	int (*iterate_shared)(struct file___173 *, struct dir_context *);
	__poll_t (*poll)(struct file___173 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___173 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___173 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___173 *, struct vm_area_struct___178 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___173 *, struct file___173 *);
	int (*flush)(struct file___173 *, fl_owner_t);
	int (*release)(struct inode___173 *, struct file___173 *);
	int (*fsync)(struct file___173 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___173 *, int);
	int (*lock)(struct file___173 *, int, struct file_lock___173 *);
	ssize_t (*sendpage)(struct file___173 *, struct page___179 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___173 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___173 *, long unsigned int);
	int (*flock)(struct file___173 *, int, struct file_lock___173 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___173 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___173 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___173 *, long int, struct file_lock___173 **, void **);
	long int (*fallocate)(struct file___173 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___151 *, struct file___173 *);
	ssize_t (*copy_file_range)(struct file___173 *, loff_t, struct file___173 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___173 *, loff_t, struct file___173 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___173 *, loff_t, loff_t, int);
};

struct vmacache___178 {
	u64 seqnum;
	struct vm_area_struct___178 *vmas[4];
};

struct page_frag___178 {
	struct page___179 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___179;

struct pid___153;

struct nsproxy___162;

struct signal_struct___174;

struct bio_list___81;

struct backing_dev_info___78;

struct io_context___81;

struct css_set___117;

struct mem_cgroup___69;

struct request_queue___81;

struct vm_struct___156;

struct task_struct___180 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___180 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___179 *mm;
	struct mm_struct___179 *active_mm;
	struct vmacache___178 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___180 *real_parent;
	struct task_struct___180 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___180 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___153 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___162 *nsproxy;
	struct signal_struct___174 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___180 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___81 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___78 *backing_dev_info;
	struct io_context___81 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___117 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___178 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___69 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___69 *active_memcg;
	struct request_queue___81 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___180 *oom_reaper_list;
	struct vm_struct___156 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___160;

struct kobj_type___160;

struct kernfs_node___160;

struct kobject___160 {
	const char *name;
	struct list_head entry;
	struct kobject___160 *parent;
	struct kset___160 *kset;
	struct kobj_type___160 *ktype;
	struct kernfs_node___160 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___157 {
	struct kobject___160 kobj;
	struct module___158 *mod;
	struct kobject___160 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___157 {
	struct module___158 *mod;
	struct latch_tree_node node;
};

struct module_layout___157 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___157 mtn;
};

struct module_attribute___157;

struct kernel_param___157;

struct module___158 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___157 mkobj;
	struct module_attribute___157 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___160 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___157 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___157 core_layout;
	struct module_layout___157 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___179 *pgtable_t___178;

struct address_space___173;

struct dev_pagemap___168;

struct page___179 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___173 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___179 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___178 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___179 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___168 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___168;

struct vm_area_struct___178 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___178 *vm_next;
	struct vm_area_struct___178 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___179 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___168 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___173 *vm_file;
	struct file___173 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___178;

struct mm_struct___179 {
	struct {
		struct vm_area_struct___178 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___173 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___178 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___180 *owner;
		struct user_namespace___25 *user_ns;
		struct file___173 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___173;

struct address_space___173 {
	struct inode___173 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___173 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___168;

struct dev_pagemap___168 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___168 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___173;

struct path___173 {
	struct vfsmount___173 *mnt;
	struct dentry___173 *dentry;
};

struct fown_struct___153 {
	rwlock_t lock;
	struct pid___153 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___173 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___173 f_path;
	struct inode___173 *f_inode;
	const struct file_operations___173 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___153 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___173 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___168;

struct vm_operations_struct___168 {
	void (*open)(struct vm_area_struct___178 *);
	void (*close)(struct vm_area_struct___178 *);
	int (*may_split)(struct vm_area_struct___178 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___178 *);
	int (*mprotect)(struct vm_area_struct___178 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___168 *);
	vm_fault_t (*huge_fault)(struct vm_fault___168 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___168 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___178 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___168 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___168 *);
	int (*access)(struct vm_area_struct___178 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___178 *);
	int (*set_policy)(struct vm_area_struct___178 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___178 *, long unsigned int);
	struct page___179 * (*find_special_page)(struct vm_area_struct___178 *, long unsigned int);
};

struct core_thread___178 {
	struct task_struct___180 *task;
	struct core_thread___178 *next;
};

struct core_state___178 {
	atomic_t nr_threads;
	struct core_thread___178 dumper;
	struct completion startup;
};

struct vm_fault___168 {
	const struct {
		struct vm_area_struct___178 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___179 *cow_page;
	struct page___179 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___178 prealloc_pte;
};

struct pglist_data___76;

struct lruvec___76 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___76 *pgdat;
};

struct zone___76 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___76 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___76 {
	struct zone___76 *zone;
	int zone_idx;
};

struct zonelist___76 {
	struct zoneref___76 _zonerefs[321];
};

struct pglist_data___76 {
	struct zone___76 node_zones[5];
	struct zonelist___76 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___180 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___180 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___76 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___69 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___69 *memcg;
};

struct cgroup___117;

struct cgroup_subsys___117;

struct cgroup_subsys_state___117 {
	struct cgroup___117 *cgroup;
	struct cgroup_subsys___117 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___117 *parent;
};

struct cgroup_file___117 {
	struct kernfs_node___160 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___69;

struct mem_cgroup_per_node___69;

struct mem_cgroup___69 {
	struct cgroup_subsys_state___117 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___117 events_file;
	struct cgroup_file___117 events_local_file;
	struct cgroup_file___117 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___69 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___180 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___69 *nodeinfo[0];
	long: 64;
};

struct shrinker___69 {
	long unsigned int (*count_objects)(struct shrinker___69 *, struct shrink_control___69 *);
	long unsigned int (*scan_objects)(struct shrinker___69 *, struct shrink_control___69 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___168 {
	void (*page_free)(struct page___179 *);
	void (*kill)(struct dev_pagemap___168 *);
	void (*cleanup)(struct dev_pagemap___168 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___168 *);
};

struct pid_namespace___153;

struct upid___153 {
	int nr;
	struct pid_namespace___153 *ns;
};

struct pid_namespace___153 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___180 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___153 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___153 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___153 numbers[1];
};

struct signal_struct___174 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___180 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___180 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___153 *pids[4];
	struct pid___153 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___179 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___117;

struct nsproxy___162 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___153 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___117 *cgroup_ns;
};

struct bio___82;

struct bio_list___81 {
	struct bio___82 *head;
	struct bio___82 *tail;
};

struct bdi_writeback___78 {
	struct backing_dev_info___78 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___117 *memcg_css;
	struct cgroup_subsys_state___117 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___126;

struct backing_dev_info___78 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___78 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___126 *dev;
	char dev_name[64];
	struct device___126 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___173 *debug_dir;
};

struct io_cq___81;

struct io_context___81 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___81 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___117 {
	struct cgroup_subsys_state___117 *subsys[14];
	refcount_t refcount;
	struct css_set___117 *dom_cset;
	struct cgroup___117 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___117 *mg_src_cgrp;
	struct cgroup___117 *mg_dst_cgrp;
	struct css_set___117 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___81;

struct blk_integrity___81 {
	const struct blk_integrity_profile___81 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___81 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___81 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___81;

struct elevator_queue___81;

struct blk_mq_ops___78;

struct blk_mq_ctx___2;

struct blk_mq_hw_ctx___78;

struct gendisk___83;

struct blk_stat_callback___2;

struct blkcg_gq___78;

struct blk_flush_queue___2;

struct blk_mq_tag_set___78;

struct request_queue___81 {
	struct request___81 *last_merge;
	struct elevator_queue___81 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___78 *mq_ops;
	struct blk_mq_ctx___2 *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___78 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___83 *disk;
	struct kobject___160 kobj;
	struct kobject___160 *mq_kobj;
	struct blk_integrity___81 integrity;
	struct device___126 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___2 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___78 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue___2 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___78 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___81 bio_split;
	struct dentry___173 *debugfs_dir;
	struct dentry___173 *sched_debugfs_dir;
	struct dentry___173 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___156 {
	struct vm_struct___156 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___179 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___173;

struct dentry___173 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___173 *d_parent;
	struct qstr d_name;
	struct inode___173 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___173 *d_op;
	struct super_block___173 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___173;

struct inode___173 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___173 *i_op;
	struct super_block___173 *i_sb;
	struct address_space___173 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___78 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___173 *i_fop;
		void (*free_inode)(struct inode___173 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___173 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___173 {
	int (*d_revalidate)(struct dentry___173 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___173 *, unsigned int);
	int (*d_hash)(const struct dentry___173 *, struct qstr *);
	int (*d_compare)(const struct dentry___173 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___173 *);
	int (*d_init)(struct dentry___173 *);
	void (*d_release)(struct dentry___173 *);
	void (*d_prune)(struct dentry___173 *);
	void (*d_iput)(struct dentry___173 *, struct inode___173 *);
	char * (*d_dname)(struct dentry___173 *, char *, int);
	struct vfsmount___173 * (*d_automount)(struct path___173 *);
	int (*d_manage)(const struct path___173 *, bool);
	struct dentry___173 * (*d_real)(struct dentry___173 *, const struct inode___173 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___173;

struct mem_dqinfo___173 {
	struct quota_format_type___173 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___173;

struct quota_info___173 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___173 *files[3];
	struct mem_dqinfo___173 info[3];
	const struct quota_format_ops___173 *ops[3];
};

struct rcuwait___174 {
	struct task_struct___180 *task;
};

struct percpu_rw_semaphore___174 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___174 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___173 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___174 rw_sem[3];
};

struct super_operations___173;

struct dquot_operations___173;

struct quotactl_ops___173;

struct export_operations___14;

struct block_device___84;

struct super_block___173 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___173 *s_type;
	const struct super_operations___173 *s_op;
	const struct dquot_operations___173 *dq_op;
	const struct quotactl_ops___173 *s_qcop;
	const struct export_operations___14 *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___173 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___84 *s_bdev;
	struct backing_dev_info___78 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___173 s_dquot;
	struct sb_writers___173 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___173 *s_d_op;
	int cleancache_poolid;
	struct shrinker___69 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___173 {
	struct dentry___173 *mnt_root;
	struct super_block___173 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct psi_group___117 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___180 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___117;

struct cgroup_rstat_cpu___117;

struct cgroup___117 {
	struct cgroup_subsys_state___117 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___160 *kn;
	struct cgroup_file___117 procs_file;
	struct cgroup_file___117 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___117 *subsys[14];
	struct cgroup_root___117 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___117 *dom_cgrp;
	struct cgroup___117 *old_dom_cgrp;
	struct cgroup_rstat_cpu___117 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___117 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___81 {
	struct request_queue___81 *q;
	struct io_context___81 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___75;

struct kiocb___173 {
	struct file___173 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___173 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___75 *ki_waitq;
	};
};

struct iattr___173 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___173 *ia_file;
};

struct dquot___173 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___173 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___173 {
	int qf_fmt_id;
	const struct quota_format_ops___173 *qf_ops;
	struct module___158 *qf_owner;
	struct quota_format_type___173 *qf_next;
};

struct quota_format_ops___173 {
	int (*check_quota_file)(struct super_block___173 *, int);
	int (*read_file_info)(struct super_block___173 *, int);
	int (*write_file_info)(struct super_block___173 *, int);
	int (*free_file_info)(struct super_block___173 *, int);
	int (*read_dqblk)(struct dquot___173 *);
	int (*commit_dqblk)(struct dquot___173 *);
	int (*release_dqblk)(struct dquot___173 *);
	int (*get_next_id)(struct super_block___173 *, struct kqid *);
};

struct dquot_operations___173 {
	int (*write_dquot)(struct dquot___173 *);
	struct dquot___173 * (*alloc_dquot)(struct super_block___173 *, int);
	void (*destroy_dquot)(struct dquot___173 *);
	int (*acquire_dquot)(struct dquot___173 *);
	int (*release_dquot)(struct dquot___173 *);
	int (*mark_dirty)(struct dquot___173 *);
	int (*write_info)(struct super_block___173 *, int);
	qsize_t * (*get_reserved_space)(struct inode___173 *);
	int (*get_projid)(struct inode___173 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___173 *, qsize_t *);
	int (*get_next_id)(struct super_block___173 *, struct kqid *);
};

struct quotactl_ops___173 {
	int (*quota_on)(struct super_block___173 *, int, int, const struct path___173 *);
	int (*quota_off)(struct super_block___173 *, int);
	int (*quota_enable)(struct super_block___173 *, unsigned int);
	int (*quota_disable)(struct super_block___173 *, unsigned int);
	int (*quota_sync)(struct super_block___173 *, int);
	int (*set_info)(struct super_block___173 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___173 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___173 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___173 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___173 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___173 *, unsigned int);
};

struct wait_page_queue___75 {
	struct page___179 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___78;

struct readahead_control___75;

struct swap_info_struct___38;

struct address_space_operations___173 {
	int (*writepage)(struct page___179 *, struct writeback_control___78 *);
	int (*readpage)(struct file___173 *, struct page___179 *);
	int (*writepages)(struct address_space___173 *, struct writeback_control___78 *);
	int (*set_page_dirty)(struct page___179 *);
	int (*readpages)(struct file___173 *, struct address_space___173 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___75 *);
	int (*write_begin)(struct file___173 *, struct address_space___173 *, loff_t, unsigned int, unsigned int, struct page___179 **, void **);
	int (*write_end)(struct file___173 *, struct address_space___173 *, loff_t, unsigned int, unsigned int, struct page___179 *, void *);
	sector_t (*bmap)(struct address_space___173 *, sector_t);
	void (*invalidatepage)(struct page___179 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___179 *, gfp_t);
	void (*freepage)(struct page___179 *);
	ssize_t (*direct_IO)(struct kiocb___173 *, struct iov_iter___98 *);
	int (*migratepage)(struct address_space___173 *, struct page___179 *, struct page___179 *, enum migrate_mode);
	bool (*isolate_page)(struct page___179 *, isolate_mode_t);
	void (*putback_page)(struct page___179 *);
	int (*launder_page)(struct page___179 *);
	int (*is_partially_uptodate)(struct page___179 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___179 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___173 *, struct page___179 *);
	int (*swap_activate)(struct swap_info_struct___38 *, struct file___173 *, sector_t *);
	void (*swap_deactivate)(struct file___173 *);
};

struct writeback_control___78 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___78 *wb;
	struct inode___173 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___75 {
	struct file___173 *file;
	struct address_space___173 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___96;

struct iov_iter___98 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___96 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___38 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___84 *bdev;
	struct file___173 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___173 {
	struct dentry___173 * (*lookup)(struct inode___173 *, struct dentry___173 *, unsigned int);
	const char * (*get_link)(struct dentry___173 *, struct inode___173 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___173 *, int);
	struct posix_acl * (*get_acl)(struct inode___173 *, int, bool);
	int (*readlink)(struct dentry___173 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___173 *, struct dentry___173 *, umode_t, bool);
	int (*link)(struct dentry___173 *, struct inode___173 *, struct dentry___173 *);
	int (*unlink)(struct inode___173 *, struct dentry___173 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___173 *, struct dentry___173 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___173 *, struct dentry___173 *, umode_t);
	int (*rmdir)(struct inode___173 *, struct dentry___173 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___173 *, struct dentry___173 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___173 *, struct dentry___173 *, struct inode___173 *, struct dentry___173 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___173 *, struct iattr___173 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___173 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___173 *, char *, size_t);
	int (*fiemap)(struct inode___173 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___173 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___173 *, struct dentry___173 *, struct file___173 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___173 *, struct dentry___173 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___173 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___173 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___173 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___173 {
	void (*fl_copy_lock)(struct file_lock___173 *, struct file_lock___173 *);
	void (*fl_release_private)(struct file_lock___173 *);
};

struct fasync_struct___173;

struct lock_manager_operations___173;

struct file_lock___173 {
	struct file_lock___173 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___173 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___173 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___173 *fl_ops;
	const struct lock_manager_operations___173 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___173 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___173 *);
	int (*lm_grant)(struct file_lock___173 *, int);
	bool (*lm_break)(struct file_lock___173 *);
	int (*lm_change)(struct file_lock___173 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___173 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___173 *);
};

struct fasync_struct___173 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___173 *fa_next;
	struct file___173 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___173 {
	struct inode___173 * (*alloc_inode)(struct super_block___173 *);
	void (*destroy_inode)(struct inode___173 *);
	void (*free_inode)(struct inode___173 *);
	void (*dirty_inode)(struct inode___173 *, int);
	int (*write_inode)(struct inode___173 *, struct writeback_control___78 *);
	int (*drop_inode)(struct inode___173 *);
	void (*evict_inode)(struct inode___173 *);
	void (*put_super)(struct super_block___173 *);
	int (*sync_fs)(struct super_block___173 *, int);
	int (*freeze_super)(struct super_block___173 *);
	int (*freeze_fs)(struct super_block___173 *);
	int (*thaw_super)(struct super_block___173 *);
	int (*unfreeze_fs)(struct super_block___173 *);
	int (*statfs)(struct dentry___173 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___173 *, int *, char *);
	void (*umount_begin)(struct super_block___173 *);
	int (*show_options)(struct seq_file___151 *, struct dentry___173 *);
	int (*show_devname)(struct seq_file___151 *, struct dentry___173 *);
	int (*show_path)(struct seq_file___151 *, struct dentry___173 *);
	int (*show_stats)(struct seq_file___151 *, struct dentry___173 *);
	ssize_t (*quota_read)(struct super_block___173 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___173 *, int, const char *, size_t, loff_t);
	struct dquot___173 ** (*get_dquots)(struct inode___173 *);
	long int (*nr_cached_objects)(struct super_block___173 *, struct shrink_control___69 *);
	long int (*free_cached_objects)(struct super_block___173 *, struct shrink_control___69 *);
	struct file___173 * (*real_loop)(struct file___173 *);
};

struct export_operations___14 {
	int (*encode_fh)(struct inode___173 *, __u32 *, int *, struct inode___173 *);
	struct dentry___173 * (*fh_to_dentry)(struct super_block___173 *, struct fid *, int, int);
	struct dentry___173 * (*fh_to_parent)(struct super_block___173 *, struct fid *, int, int);
	int (*get_name)(struct dentry___173 *, char *, struct dentry___173 *);
	struct dentry___173 * (*get_parent)(struct dentry___173 *);
	int (*commit_metadata)(struct inode___173 *);
	int (*get_uuid)(struct super_block___173 *, u8 *, u32 *, u64 *);
	int (*map_blocks)(struct inode___173 *, loff_t, u64, struct iomap *, bool, u32 *);
	int (*commit_blocks)(struct inode___173 *, struct iomap *, int, struct iattr___173 *);
	u64 (*fetch_iversion)(struct inode___173 *);
	long unsigned int flags;
};

struct wakeup_source___126;

struct dev_pm_info___126 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___126 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___126 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___126;

struct bus_type___126;

struct device_driver___126;

struct dev_pm_domain___126;

struct fwnode_handle___126;

struct class___126;

struct attribute_group___160;

struct device___126 {
	struct kobject___160 kobj;
	struct device___126 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___126 *type;
	struct bus_type___126 *bus;
	struct device_driver___126 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___126 power;
	struct dev_pm_domain___126 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___126 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___126 *class;
	const struct attribute_group___160 **groups;
	void (*release)(struct device___126 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___84 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___173 *bd_inode;
	struct super_block___173 *bd_super;
	void *bd_claiming;
	struct device___126 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___160 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___83 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___173 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___151;

struct seq_file___151 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___151 *op;
	int poll_event;
	const struct file___173 *file;
	void *private;
};

struct fc_log___31;

struct p_log___31 {
	const char *prefix;
	struct fc_log___31 *log;
};

struct fs_context_operations___31;

struct fs_context___31 {
	const struct fs_context_operations___31 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___173 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___173 *root;
	struct user_namespace___25 *user_ns;
	struct net *net_ns;
	const struct cred___30 *cred;
	struct p_log___31 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void bio_end_io_t___81(struct bio___82 *);

struct bio_vec___96 {
	struct page___179 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___81;

struct bio___82 {
	struct bio___82 *bi_next;
	struct block_device___84 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___81 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___78 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___81 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___96 *bi_io_vec;
	struct bio_set___81 *bi_pool;
	struct bio_vec___96 bi_inline_vecs[0];
};

struct fwnode_operations___126;

struct fwnode_handle___126 {
	struct fwnode_handle___126 *secondary;
	const struct fwnode_operations___126 *ops;
	struct device___126 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___126;

struct fwnode_endpoint___126;

struct fwnode_operations___126 {
	struct fwnode_handle___126 * (*get)(struct fwnode_handle___126 *);
	void (*put)(struct fwnode_handle___126 *);
	bool (*device_is_available)(const struct fwnode_handle___126 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___126 *, const struct device___126 *);
	bool (*property_present)(const struct fwnode_handle___126 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___126 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___126 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___126 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*get_parent)(const struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*get_next_child_node)(const struct fwnode_handle___126 *, struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*get_named_child_node)(const struct fwnode_handle___126 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___126 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___126 *);
	struct fwnode_handle___126 * (*graph_get_next_endpoint)(const struct fwnode_handle___126 *, struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*graph_get_remote_endpoint)(const struct fwnode_handle___126 *);
	struct fwnode_handle___126 * (*graph_get_port_parent)(struct fwnode_handle___126 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___126 *, struct fwnode_endpoint___126 *);
	int (*add_links)(struct fwnode_handle___126 *);
};

struct fwnode_endpoint___126 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___126 *local_fwnode;
};

struct fwnode_reference_args___126 {
	struct fwnode_handle___126 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___160;

struct kernfs_elem_dir___160 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___160 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___160;

struct kernfs_root___160 {
	struct kernfs_node___160 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___160 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___160 {
	struct kernfs_node___160 *target_kn;
};

struct kernfs_ops___160;

struct kernfs_elem_attr___160 {
	const struct kernfs_ops___160 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___160 *notify_next;
};

struct kernfs_node___160 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___160 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___160 dir;
		struct kernfs_elem_symlink___160 symlink;
		struct kernfs_elem_attr___160 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___160;

struct kernfs_ops___160 {
	int (*open)(struct kernfs_open_file___160 *);
	void (*release)(struct kernfs_open_file___160 *);
	int (*seq_show)(struct seq_file___151 *, void *);
	void * (*seq_start)(struct seq_file___151 *, loff_t *);
	void * (*seq_next)(struct seq_file___151 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___151 *, void *);
	ssize_t (*read)(struct kernfs_open_file___160 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___160 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___160 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___160 *, struct vm_area_struct___178 *);
};

struct kernfs_syscall_ops___160 {
	int (*show_options)(struct seq_file___151 *, struct kernfs_root___160 *);
	int (*mkdir)(struct kernfs_node___160 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___160 *);
	int (*rename)(struct kernfs_node___160 *, struct kernfs_node___160 *, const char *);
	int (*show_path)(struct seq_file___151 *, struct kernfs_node___160 *, struct kernfs_root___160 *);
};

struct kernfs_open_file___160 {
	struct kernfs_node___160 *kn;
	struct file___173 *file;
	struct seq_file___151 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___168 *vm_ops;
};

struct bin_attribute___160;

struct attribute_group___160 {
	const char *name;
	umode_t (*is_visible)(struct kobject___160 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___160 *, struct bin_attribute___160 *, int);
	struct attribute **attrs;
	struct bin_attribute___160 **bin_attrs;
};

struct bin_attribute___160 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___173 * (*f_mapping)();
	ssize_t (*read)(struct file___173 *, struct kobject___160 *, struct bin_attribute___160 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___173 *, struct kobject___160 *, struct bin_attribute___160 *, char *, loff_t, size_t);
	int (*mmap)(struct file___173 *, struct kobject___160 *, struct bin_attribute___160 *, struct vm_area_struct___178 *);
};

struct sysfs_ops___160 {
	ssize_t (*show)(struct kobject___160 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___160 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___160;

struct kset___160 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___160 kobj;
	const struct kset_uevent_ops___160 *uevent_ops;
};

struct kobj_type___160 {
	void (*release)(struct kobject___160 *);
	const struct sysfs_ops___160 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___160 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___160 *);
	const void * (*namespace)(struct kobject___160 *);
	void (*get_ownership)(struct kobject___160 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___160 {
	int (* const filter)(struct kset___160 *, struct kobject___160 *);
	const char * (* const name)(struct kset___160 *, struct kobject___160 *);
	int (* const uevent)(struct kset___160 *, struct kobject___160 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___157 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___157 *);
	int (*get)(char *, const struct kernel_param___157 *);
	void (*free)(void *);
};

struct kparam_array___157;

struct kernel_param___157 {
	const char *name;
	struct module___158 *mod;
	const struct kernel_param_ops___157 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___157 *arr;
	};
};

struct kparam_array___157 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___157 *ops;
	void *elem;
};

struct module_attribute___157 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___157 *, struct module_kobject___157 *, char *);
	ssize_t (*store)(struct module_attribute___157 *, struct module_kobject___157 *, const char *, size_t);
	void (*setup)(struct module___158 *, const char *);
	int (*test)(struct module___158 *);
	void (*free)(struct module___158 *);
};

struct cgroup_namespace___117 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___117 *root_cset;
};

struct dev_pm_ops___126 {
	int (*prepare)(struct device___126 *);
	void (*complete)(struct device___126 *);
	int (*suspend)(struct device___126 *);
	int (*resume)(struct device___126 *);
	int (*freeze)(struct device___126 *);
	int (*thaw)(struct device___126 *);
	int (*poweroff)(struct device___126 *);
	int (*restore)(struct device___126 *);
	int (*suspend_late)(struct device___126 *);
	int (*resume_early)(struct device___126 *);
	int (*freeze_late)(struct device___126 *);
	int (*thaw_early)(struct device___126 *);
	int (*poweroff_late)(struct device___126 *);
	int (*restore_early)(struct device___126 *);
	int (*suspend_noirq)(struct device___126 *);
	int (*resume_noirq)(struct device___126 *);
	int (*freeze_noirq)(struct device___126 *);
	int (*thaw_noirq)(struct device___126 *);
	int (*poweroff_noirq)(struct device___126 *);
	int (*restore_noirq)(struct device___126 *);
	int (*runtime_suspend)(struct device___126 *);
	int (*runtime_resume)(struct device___126 *);
	int (*runtime_idle)(struct device___126 *);
};

struct wakeup_source___126 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___126 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___126 {
	struct dev_pm_ops___126 ops;
	int (*start)(struct device___126 *);
	void (*detach)(struct device___126 *, bool);
	int (*activate)(struct device___126 *);
	void (*sync)(struct device___126 *);
	void (*dismiss)(struct device___126 *);
};

struct bus_type___126 {
	const char *name;
	const char *dev_name;
	struct device___126 *dev_root;
	const struct attribute_group___160 **bus_groups;
	const struct attribute_group___160 **dev_groups;
	const struct attribute_group___160 **drv_groups;
	int (*match)(struct device___126 *, struct device_driver___126 *);
	int (*uevent)(struct device___126 *, struct kobj_uevent_env *);
	int (*probe)(struct device___126 *);
	void (*sync_state)(struct device___126 *);
	void (*remove)(struct device___126 *);
	void (*shutdown)(struct device___126 *);
	int (*online)(struct device___126 *);
	int (*offline)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	int (*num_vf)(struct device___126 *);
	int (*dma_configure)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___126 {
	const char *name;
	struct bus_type___126 *bus;
	struct module___158 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___126 *);
	void (*sync_state)(struct device___126 *);
	int (*remove)(struct device___126 *);
	void (*shutdown)(struct device___126 *);
	int (*suspend)(struct device___126 *, pm_message_t);
	int (*resume)(struct device___126 *);
	const struct attribute_group___160 **groups;
	const struct attribute_group___160 **dev_groups;
	const struct dev_pm_ops___126 *pm;
	void (*coredump)(struct device___126 *);
	struct driver_private *p;
};

struct device_type___126 {
	const char *name;
	const struct attribute_group___160 **groups;
	int (*uevent)(struct device___126 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___126 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___126 *);
	const struct dev_pm_ops___126 *pm;
};

struct class___126 {
	const char *name;
	struct module___158 *owner;
	const struct attribute_group___160 **class_groups;
	const struct attribute_group___160 **dev_groups;
	struct kobject___160 *dev_kobj;
	int (*dev_uevent)(struct device___126 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___126 *, umode_t *);
	void (*class_release)(struct class___126 *);
	void (*dev_release)(struct device___126 *);
	int (*shutdown_pre)(struct device___126 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___126 *);
	void (*get_ownership)(struct device___126 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___126 *pm;
	struct subsys_private *p;
};

struct block_device_operations___82;

struct gendisk___83 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___84 *part0;
	const struct block_device_operations___82 *fops;
	struct request_queue___81 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___78 *bdi;
	struct kobject___160 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___160 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___81 {
	struct bio___82 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___96 *bip_vec;
	struct bio_vec___96 bip_inline_vecs[0];
};

struct blkcg___78;

struct blkg_policy_data___78;

struct blkcg_gq___78 {
	struct request_queue___81 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___78 *blkcg;
	struct blkcg_gq___78 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___78 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___81 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

enum {
	DISK_EVENT_MEDIA_CHANGE = 1,
	DISK_EVENT_EJECT_REQUEST = 2,
};

typedef void integrity_prepare_fn___81(struct request___81 *);

typedef void integrity_complete_fn___81(struct request___81 *, unsigned int);

struct blk_integrity_profile___81 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___81 *prepare_fn;
	integrity_complete_fn___81 *complete_fn;
	const char *name;
};

struct block_device_operations___82 {
	blk_qc_t (*submit_bio)(struct bio___82 *);
	int (*open)(struct block_device___84 *, fmode_t);
	void (*release)(struct gendisk___83 *, fmode_t);
	int (*rw_page)(struct block_device___84 *, sector_t, struct page___179 *, unsigned int);
	int (*ioctl)(struct block_device___84 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___84 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___83 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___83 *);
	int (*getgeo)(struct block_device___84 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___84 *, bool);
	void (*swap_slot_free_notify)(struct block_device___84 *, long unsigned int);
	int (*report_zones)(struct gendisk___83 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___83 *, umode_t *);
	struct module___158 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___83 *, sector_t *);
};

typedef void rq_end_io_fn___81(struct request___81 *, blk_status_t);

struct request___81 {
	struct request_queue___81 *q;
	struct blk_mq_ctx___2 *mq_ctx;
	struct blk_mq_hw_ctx___78 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___82 *bio;
	struct bio___82 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___96 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___81 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___81 *saved_end_io;
		} flush;
	};
	struct gendisk___83 *rq_disk;
	struct block_device___84 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___81 *end_io;
	void *end_io_data;
};

struct blk_mq_ctxs___2;

struct blk_mq_ctx___2 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___78 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___81 *queue;
	struct blk_mq_ctxs___2 *ctxs;
	struct kobject___160 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tags___2;

struct blk_mq_hw_ctx___78 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___81 *queue;
	struct blk_flush_queue___2 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___2 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___2 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___2 *tags;
	struct blk_mq_tags___2 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___160 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___173 *debugfs_dir;
	struct dentry___173 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___81;

struct blk_mq_alloc_data___2;

struct elevator_mq_ops___81 {
	int (*init_sched)(struct request_queue___81 *, struct elevator_type___81 *);
	void (*exit_sched)(struct elevator_queue___81 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___78 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___78 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___78 *);
	bool (*allow_merge)(struct request_queue___81 *, struct request___81 *, struct bio___82 *);
	bool (*bio_merge)(struct request_queue___81 *, struct bio___82 *, unsigned int);
	int (*request_merge)(struct request_queue___81 *, struct request___81 **, struct bio___82 *);
	void (*request_merged)(struct request_queue___81 *, struct request___81 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___81 *, struct request___81 *, struct request___81 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___2 *);
	void (*prepare_request)(struct request___81 *);
	void (*finish_request)(struct request___81 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___78 *, struct list_head *, bool);
	struct request___81 * (*dispatch_request)(struct blk_mq_hw_ctx___78 *);
	bool (*has_work)(struct blk_mq_hw_ctx___78 *);
	void (*completed_request)(struct request___81 *, u64);
	void (*requeue_request)(struct request___81 *);
	struct request___81 * (*former_request)(struct request_queue___81 *, struct request___81 *);
	struct request___81 * (*next_request)(struct request_queue___81 *, struct request___81 *);
	void (*init_icq)(struct io_cq___81 *);
	void (*exit_icq)(struct io_cq___81 *);
};

struct elv_fs_entry___81;

struct elevator_type___81 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___81 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___81 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___158 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___81 {
	struct elevator_type___81 *type;
	void *elevator_data;
	struct kobject___160 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___2 {
	struct request_queue___81 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___2 *ctx;
	struct blk_mq_hw_ctx___78 *hctx;
};

struct elv_fs_entry___81 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___81 *, char *);
	ssize_t (*store)(struct elevator_queue___81 *, const char *, size_t);
};

struct blk_mq_queue_data___78;

struct blk_mq_ops___78 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___78 *, const struct blk_mq_queue_data___78 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___78 *);
	int (*get_budget)(struct request_queue___81 *);
	void (*put_budget)(struct request_queue___81 *, int);
	void (*set_rq_budget_token)(struct request___81 *, int);
	int (*get_rq_budget_token)(struct request___81 *);
	enum blk_eh_timer_return (*timeout)(struct request___81 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___78 *);
	void (*complete)(struct request___81 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___78 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___78 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___78 *, struct request___81 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___78 *, struct request___81 *, unsigned int);
	void (*initialize_rq_fn)(struct request___81 *);
	void (*cleanup_rq)(struct request___81 *);
	bool (*busy)(struct request_queue___81 *);
	int (*map_queues)(struct blk_mq_tag_set___78 *);
	void (*show_rq)(struct seq_file___151 *, struct request___81 *);
};

struct blk_stat_callback___2 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___81 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___2 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___2 {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___81 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___78 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___78 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags___2 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___151 {
	void * (*start)(struct seq_file___151 *, loff_t *);
	void (*stop)(struct seq_file___151 *, void *);
	void * (*next)(struct seq_file___151 *, void *, loff_t *);
	int (*show)(struct seq_file___151 *, void *);
};

struct cftype___117;

struct cgroup_subsys___117 {
	struct cgroup_subsys_state___117 * (*css_alloc)(struct cgroup_subsys_state___117 *);
	int (*css_online)(struct cgroup_subsys_state___117 *);
	void (*css_offline)(struct cgroup_subsys_state___117 *);
	void (*css_released)(struct cgroup_subsys_state___117 *);
	void (*css_free)(struct cgroup_subsys_state___117 *);
	void (*css_reset)(struct cgroup_subsys_state___117 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___117 *, int);
	int (*css_extra_stat_show)(struct seq_file___151 *, struct cgroup_subsys_state___117 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___180 *, struct css_set___117 *);
	void (*cancel_fork)(struct task_struct___180 *, struct css_set___117 *);
	void (*fork)(struct task_struct___180 *);
	void (*exit)(struct task_struct___180 *);
	void (*release)(struct task_struct___180 *);
	void (*bind)(struct cgroup_subsys_state___117 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___117 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___117 *dfl_cftypes;
	struct cftype___117 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___117 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___117 *updated_children;
	struct cgroup___117 *updated_next;
};

struct cgroup_root___117 {
	struct kernfs_root___160 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___117 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___117 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___117 *ss;
	struct list_head node;
	struct kernfs_ops___160 *kf_ops;
	int (*open)(struct kernfs_open_file___160 *);
	void (*release)(struct kernfs_open_file___160 *);
	u64 (*read_u64)(struct cgroup_subsys_state___117 *, struct cftype___117 *);
	s64 (*read_s64)(struct cgroup_subsys_state___117 *, struct cftype___117 *);
	int (*seq_show)(struct seq_file___151 *, void *);
	void * (*seq_start)(struct seq_file___151 *, loff_t *);
	void * (*seq_next)(struct seq_file___151 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___151 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___117 *, struct cftype___117 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___117 *, struct cftype___117 *, s64);
	ssize_t (*write)(struct kernfs_open_file___160 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___160 *, struct poll_table_struct___5 *);
};

struct blk_mq_tags___2 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___81 **rqs;
	struct request___81 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

struct blk_mq_queue_data___78 {
	struct request___81 *rq;
	bool last;
};

struct blkcg_policy_data___78;

struct blkcg___78 {
	struct cgroup_subsys_state___117 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___78 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___78 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___78 {
	struct blkcg___78 *blkcg;
	int plid;
};

struct blkg_policy_data___78 {
	struct blkcg_gq___78 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___69 {
	struct mem_cgroup___69 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___69 {
	struct lruvec___76 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___69 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___69 *memcg;
};

struct obj_cgroup___69 {
	struct percpu_ref refcnt;
	struct mem_cgroup___69 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fs_parameter___31 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___173 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___31 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___158 *owner;
	char *buffer[8];
};

struct fs_context_operations___31 {
	void (*free)(struct fs_context___31 *);
	int (*dup)(struct fs_context___31 *, struct fs_context___31 *);
	int (*parse_param)(struct fs_context___31 *, struct fs_parameter___31 *);
	int (*parse_monolithic)(struct fs_context___31 *, void *);
	int (*get_tree)(struct fs_context___31 *);
	int (*reconfigure)(struct fs_context___31 *);
};

struct pseudo_fs_context___9 {
	const struct super_operations___173 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___173 *dops;
	long unsigned int magic;
};

struct blk_mq_ctxs___2 {
	struct kobject___160 kobj;
	struct blk_mq_ctx___2 *queue_ctx;
};

struct bdev_inode {
	struct block_device___84 bdev;
	struct inode___173 vfs_inode;
};

struct dentry___174;

struct super_block___174;

struct module___159;

struct file_system_type___174 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___174 * (*mount)(struct file_system_type___174 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___174 *);
	struct module___159 *owner;
	struct file_system_type___174 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___174;

struct kiocb___174;

struct iov_iter___99;

struct vm_area_struct___179;

struct inode___174;

struct file_lock___174;

struct page___180;

struct seq_file___152;

struct file_operations___174 {
	struct module___159 *owner;
	loff_t (*llseek)(struct file___174 *, loff_t, int);
	ssize_t (*read)(struct file___174 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___174 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___174 *, struct iov_iter___99 *);
	ssize_t (*write_iter)(struct kiocb___174 *, struct iov_iter___99 *);
	int (*iopoll)(struct kiocb___174 *, bool);
	int (*iterate)(struct file___174 *, struct dir_context *);
	int (*iterate_shared)(struct file___174 *, struct dir_context *);
	__poll_t (*poll)(struct file___174 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___174 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___174 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___174 *, struct vm_area_struct___179 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___174 *, struct file___174 *);
	int (*flush)(struct file___174 *, fl_owner_t);
	int (*release)(struct inode___174 *, struct file___174 *);
	int (*fsync)(struct file___174 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___174 *, int);
	int (*lock)(struct file___174 *, int, struct file_lock___174 *);
	ssize_t (*sendpage)(struct file___174 *, struct page___180 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___174 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___174 *, long unsigned int);
	int (*flock)(struct file___174 *, int, struct file_lock___174 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___174 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___174 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___174 *, long int, struct file_lock___174 **, void **);
	long int (*fallocate)(struct file___174 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___152 *, struct file___174 *);
	ssize_t (*copy_file_range)(struct file___174 *, loff_t, struct file___174 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___174 *, loff_t, struct file___174 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___174 *, loff_t, loff_t, int);
};

struct vmacache___179 {
	u64 seqnum;
	struct vm_area_struct___179 *vmas[4];
};

struct page_frag___179 {
	struct page___180 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___180;

struct pid___154;

struct nsproxy___163;

struct signal_struct___175;

struct bio_list___82;

struct backing_dev_info___79;

struct io_context___82;

struct css_set___118;

struct mem_cgroup___70;

struct request_queue___82;

struct vm_struct___157;

struct task_struct___181 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___181 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___180 *mm;
	struct mm_struct___180 *active_mm;
	struct vmacache___179 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___181 *real_parent;
	struct task_struct___181 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___181 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___154 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___163 *nsproxy;
	struct signal_struct___175 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___181 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___82 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___79 *backing_dev_info;
	struct io_context___82 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___118 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___179 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___70 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___70 *active_memcg;
	struct request_queue___82 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___181 *oom_reaper_list;
	struct vm_struct___157 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___161;

struct kobj_type___161;

struct kernfs_node___161;

struct kobject___161 {
	const char *name;
	struct list_head entry;
	struct kobject___161 *parent;
	struct kset___161 *kset;
	struct kobj_type___161 *ktype;
	struct kernfs_node___161 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___158 {
	struct kobject___161 kobj;
	struct module___159 *mod;
	struct kobject___161 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___158 {
	struct module___159 *mod;
	struct latch_tree_node node;
};

struct module_layout___158 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___158 mtn;
};

struct module_attribute___158;

struct kernel_param___158;

struct module___159 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___158 mkobj;
	struct module_attribute___158 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___161 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___158 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___158 core_layout;
	struct module_layout___158 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___180 *pgtable_t___179;

struct address_space___174;

struct dev_pagemap___169;

struct page___180 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___174 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___180 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___179 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___180 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___169 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___169;

struct vm_area_struct___179 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___179 *vm_next;
	struct vm_area_struct___179 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___180 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___169 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___174 *vm_file;
	struct file___174 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___179;

struct mm_struct___180 {
	struct {
		struct vm_area_struct___179 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___174 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___179 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___181 *owner;
		struct user_namespace___25 *user_ns;
		struct file___174 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___174;

struct address_space___174 {
	struct inode___174 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___174 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___169;

struct dev_pagemap___169 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___169 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___174;

struct path___174 {
	struct vfsmount___174 *mnt;
	struct dentry___174 *dentry;
};

struct fown_struct___154 {
	rwlock_t lock;
	struct pid___154 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___174 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___174 f_path;
	struct inode___174 *f_inode;
	const struct file_operations___174 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___154 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___174 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___169;

struct vm_operations_struct___169 {
	void (*open)(struct vm_area_struct___179 *);
	void (*close)(struct vm_area_struct___179 *);
	int (*may_split)(struct vm_area_struct___179 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___179 *);
	int (*mprotect)(struct vm_area_struct___179 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___169 *);
	vm_fault_t (*huge_fault)(struct vm_fault___169 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___169 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___179 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___169 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___169 *);
	int (*access)(struct vm_area_struct___179 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___179 *);
	int (*set_policy)(struct vm_area_struct___179 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___179 *, long unsigned int);
	struct page___180 * (*find_special_page)(struct vm_area_struct___179 *, long unsigned int);
};

struct core_thread___179 {
	struct task_struct___181 *task;
	struct core_thread___179 *next;
};

struct core_state___179 {
	atomic_t nr_threads;
	struct core_thread___179 dumper;
	struct completion startup;
};

struct vm_fault___169 {
	const struct {
		struct vm_area_struct___179 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___180 *cow_page;
	struct page___180 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___179 prealloc_pte;
};

struct pglist_data___77;

struct lruvec___77 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___77 *pgdat;
};

struct zone___77 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___77 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___77 {
	struct zone___77 *zone;
	int zone_idx;
};

struct zonelist___77 {
	struct zoneref___77 _zonerefs[321];
};

struct pglist_data___77 {
	struct zone___77 node_zones[5];
	struct zonelist___77 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___181 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___181 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___77 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___70 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___70 *memcg;
};

struct cgroup___118;

struct cgroup_subsys___118;

struct cgroup_subsys_state___118 {
	struct cgroup___118 *cgroup;
	struct cgroup_subsys___118 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___118 *parent;
};

struct cgroup_file___118 {
	struct kernfs_node___161 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___70;

struct mem_cgroup_per_node___70;

struct mem_cgroup___70 {
	struct cgroup_subsys_state___118 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___118 events_file;
	struct cgroup_file___118 events_local_file;
	struct cgroup_file___118 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___70 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___181 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___70 *nodeinfo[0];
	long: 64;
};

struct shrinker___70 {
	long unsigned int (*count_objects)(struct shrinker___70 *, struct shrink_control___70 *);
	long unsigned int (*scan_objects)(struct shrinker___70 *, struct shrink_control___70 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___169 {
	void (*page_free)(struct page___180 *);
	void (*kill)(struct dev_pagemap___169 *);
	void (*cleanup)(struct dev_pagemap___169 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___169 *);
};

struct pid_namespace___154;

struct upid___154 {
	int nr;
	struct pid_namespace___154 *ns;
};

struct pid_namespace___154 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___181 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___154 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___154 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___154 numbers[1];
};

struct signal_struct___175 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___181 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___181 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___154 *pids[4];
	struct pid___154 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___180 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___118;

struct nsproxy___163 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___154 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___118 *cgroup_ns;
};

struct bio___83;

struct bio_list___82 {
	struct bio___83 *head;
	struct bio___83 *tail;
};

struct bdi_writeback___79 {
	struct backing_dev_info___79 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___118 *memcg_css;
	struct cgroup_subsys_state___118 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___127;

struct backing_dev_info___79 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___79 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___127 *dev;
	char dev_name[64];
	struct device___127 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___174 *debug_dir;
};

struct io_cq___82;

struct io_context___82 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___82 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___118 {
	struct cgroup_subsys_state___118 *subsys[14];
	refcount_t refcount;
	struct css_set___118 *dom_cset;
	struct cgroup___118 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___118 *mg_src_cgrp;
	struct cgroup___118 *mg_dst_cgrp;
	struct css_set___118 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___82;

struct blk_integrity___82 {
	const struct blk_integrity_profile___82 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___82 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___82 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___82;

struct elevator_queue___82;

struct blk_mq_ops___79;

struct blk_mq_ctx___3;

struct blk_mq_hw_ctx___79;

struct gendisk___84;

struct blk_stat_callback___3;

struct blkcg_gq___79;

struct blk_flush_queue___3;

struct blk_mq_tag_set___79;

struct request_queue___82 {
	struct request___82 *last_merge;
	struct elevator_queue___82 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___79 *mq_ops;
	struct blk_mq_ctx___3 *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___79 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___84 *disk;
	struct kobject___161 kobj;
	struct kobject___161 *mq_kobj;
	struct blk_integrity___82 integrity;
	struct device___127 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___3 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___79 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue___3 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___79 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___82 bio_split;
	struct dentry___174 *debugfs_dir;
	struct dentry___174 *sched_debugfs_dir;
	struct dentry___174 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___157 {
	struct vm_struct___157 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___180 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___174;

struct dentry___174 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___174 *d_parent;
	struct qstr d_name;
	struct inode___174 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___174 *d_op;
	struct super_block___174 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___174;

struct inode___174 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___174 *i_op;
	struct super_block___174 *i_sb;
	struct address_space___174 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___79 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___174 *i_fop;
		void (*free_inode)(struct inode___174 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___174 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___174 {
	int (*d_revalidate)(struct dentry___174 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___174 *, unsigned int);
	int (*d_hash)(const struct dentry___174 *, struct qstr *);
	int (*d_compare)(const struct dentry___174 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___174 *);
	int (*d_init)(struct dentry___174 *);
	void (*d_release)(struct dentry___174 *);
	void (*d_prune)(struct dentry___174 *);
	void (*d_iput)(struct dentry___174 *, struct inode___174 *);
	char * (*d_dname)(struct dentry___174 *, char *, int);
	struct vfsmount___174 * (*d_automount)(struct path___174 *);
	int (*d_manage)(const struct path___174 *, bool);
	struct dentry___174 * (*d_real)(struct dentry___174 *, const struct inode___174 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___174;

struct mem_dqinfo___174 {
	struct quota_format_type___174 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___174;

struct quota_info___174 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___174 *files[3];
	struct mem_dqinfo___174 info[3];
	const struct quota_format_ops___174 *ops[3];
};

struct rcuwait___175 {
	struct task_struct___181 *task;
};

struct percpu_rw_semaphore___175 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___175 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___174 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___175 rw_sem[3];
};

struct super_operations___174;

struct dquot_operations___174;

struct quotactl_ops___174;

struct block_device___85;

struct super_block___174 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___174 *s_type;
	const struct super_operations___174 *s_op;
	const struct dquot_operations___174 *dq_op;
	const struct quotactl_ops___174 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___174 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___85 *s_bdev;
	struct backing_dev_info___79 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___174 s_dquot;
	struct sb_writers___174 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___174 *s_d_op;
	int cleancache_poolid;
	struct shrinker___70 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___174 {
	struct dentry___174 *mnt_root;
	struct super_block___174 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct psi_group___118 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___181 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___118;

struct cgroup_rstat_cpu___118;

struct cgroup___118 {
	struct cgroup_subsys_state___118 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___161 *kn;
	struct cgroup_file___118 procs_file;
	struct cgroup_file___118 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___118 *subsys[14];
	struct cgroup_root___118 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___118 *dom_cgrp;
	struct cgroup___118 *old_dom_cgrp;
	struct cgroup_rstat_cpu___118 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___118 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___82 {
	struct request_queue___82 *q;
	struct io_context___82 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___12;

typedef int get_block_t___6(struct inode___174 *, sector_t, struct buffer_head___12 *, int);

typedef void bh_end_io_t___12(struct buffer_head___12 *, int);

struct buffer_head___12 {
	long unsigned int b_state;
	struct buffer_head___12 *b_this_page;
	struct page___180 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___85 *b_bdev;
	bh_end_io_t___12 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___174 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___76;

struct kiocb___174 {
	struct file___174 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___174 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___76 *ki_waitq;
	};
};

struct iattr___174 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___174 *ia_file;
};

struct dquot___174 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___174 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___174 {
	int qf_fmt_id;
	const struct quota_format_ops___174 *qf_ops;
	struct module___159 *qf_owner;
	struct quota_format_type___174 *qf_next;
};

struct quota_format_ops___174 {
	int (*check_quota_file)(struct super_block___174 *, int);
	int (*read_file_info)(struct super_block___174 *, int);
	int (*write_file_info)(struct super_block___174 *, int);
	int (*free_file_info)(struct super_block___174 *, int);
	int (*read_dqblk)(struct dquot___174 *);
	int (*commit_dqblk)(struct dquot___174 *);
	int (*release_dqblk)(struct dquot___174 *);
	int (*get_next_id)(struct super_block___174 *, struct kqid *);
};

struct dquot_operations___174 {
	int (*write_dquot)(struct dquot___174 *);
	struct dquot___174 * (*alloc_dquot)(struct super_block___174 *, int);
	void (*destroy_dquot)(struct dquot___174 *);
	int (*acquire_dquot)(struct dquot___174 *);
	int (*release_dquot)(struct dquot___174 *);
	int (*mark_dirty)(struct dquot___174 *);
	int (*write_info)(struct super_block___174 *, int);
	qsize_t * (*get_reserved_space)(struct inode___174 *);
	int (*get_projid)(struct inode___174 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___174 *, qsize_t *);
	int (*get_next_id)(struct super_block___174 *, struct kqid *);
};

struct quotactl_ops___174 {
	int (*quota_on)(struct super_block___174 *, int, int, const struct path___174 *);
	int (*quota_off)(struct super_block___174 *, int);
	int (*quota_enable)(struct super_block___174 *, unsigned int);
	int (*quota_disable)(struct super_block___174 *, unsigned int);
	int (*quota_sync)(struct super_block___174 *, int);
	int (*set_info)(struct super_block___174 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___174 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___174 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___174 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___174 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___174 *, unsigned int);
};

struct wait_page_queue___76 {
	struct page___180 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___79;

struct readahead_control___76;

struct swap_info_struct___39;

struct address_space_operations___174 {
	int (*writepage)(struct page___180 *, struct writeback_control___79 *);
	int (*readpage)(struct file___174 *, struct page___180 *);
	int (*writepages)(struct address_space___174 *, struct writeback_control___79 *);
	int (*set_page_dirty)(struct page___180 *);
	int (*readpages)(struct file___174 *, struct address_space___174 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___76 *);
	int (*write_begin)(struct file___174 *, struct address_space___174 *, loff_t, unsigned int, unsigned int, struct page___180 **, void **);
	int (*write_end)(struct file___174 *, struct address_space___174 *, loff_t, unsigned int, unsigned int, struct page___180 *, void *);
	sector_t (*bmap)(struct address_space___174 *, sector_t);
	void (*invalidatepage)(struct page___180 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___180 *, gfp_t);
	void (*freepage)(struct page___180 *);
	ssize_t (*direct_IO)(struct kiocb___174 *, struct iov_iter___99 *);
	int (*migratepage)(struct address_space___174 *, struct page___180 *, struct page___180 *, enum migrate_mode);
	bool (*isolate_page)(struct page___180 *, isolate_mode_t);
	void (*putback_page)(struct page___180 *);
	int (*launder_page)(struct page___180 *);
	int (*is_partially_uptodate)(struct page___180 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___180 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___174 *, struct page___180 *);
	int (*swap_activate)(struct swap_info_struct___39 *, struct file___174 *, sector_t *);
	void (*swap_deactivate)(struct file___174 *);
};

struct writeback_control___79 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___79 *wb;
	struct inode___174 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___76 {
	struct file___174 *file;
	struct address_space___174 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___97;

struct iov_iter___99 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___97 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___39 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___85 *bdev;
	struct file___174 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___174 {
	struct dentry___174 * (*lookup)(struct inode___174 *, struct dentry___174 *, unsigned int);
	const char * (*get_link)(struct dentry___174 *, struct inode___174 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___174 *, int);
	struct posix_acl * (*get_acl)(struct inode___174 *, int, bool);
	int (*readlink)(struct dentry___174 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___174 *, struct dentry___174 *, umode_t, bool);
	int (*link)(struct dentry___174 *, struct inode___174 *, struct dentry___174 *);
	int (*unlink)(struct inode___174 *, struct dentry___174 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___174 *, struct dentry___174 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___174 *, struct dentry___174 *, umode_t);
	int (*rmdir)(struct inode___174 *, struct dentry___174 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___174 *, struct dentry___174 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___174 *, struct dentry___174 *, struct inode___174 *, struct dentry___174 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___174 *, struct iattr___174 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___174 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___174 *, char *, size_t);
	int (*fiemap)(struct inode___174 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___174 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___174 *, struct dentry___174 *, struct file___174 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___174 *, struct dentry___174 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___174 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___174 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___174 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___174 {
	void (*fl_copy_lock)(struct file_lock___174 *, struct file_lock___174 *);
	void (*fl_release_private)(struct file_lock___174 *);
};

struct fasync_struct___174;

struct lock_manager_operations___174;

struct file_lock___174 {
	struct file_lock___174 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___174 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___174 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___174 *fl_ops;
	const struct lock_manager_operations___174 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___174 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___174 *);
	int (*lm_grant)(struct file_lock___174 *, int);
	bool (*lm_break)(struct file_lock___174 *);
	int (*lm_change)(struct file_lock___174 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___174 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___174 *);
};

struct fasync_struct___174 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___174 *fa_next;
	struct file___174 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___174 {
	struct inode___174 * (*alloc_inode)(struct super_block___174 *);
	void (*destroy_inode)(struct inode___174 *);
	void (*free_inode)(struct inode___174 *);
	void (*dirty_inode)(struct inode___174 *, int);
	int (*write_inode)(struct inode___174 *, struct writeback_control___79 *);
	int (*drop_inode)(struct inode___174 *);
	void (*evict_inode)(struct inode___174 *);
	void (*put_super)(struct super_block___174 *);
	int (*sync_fs)(struct super_block___174 *, int);
	int (*freeze_super)(struct super_block___174 *);
	int (*freeze_fs)(struct super_block___174 *);
	int (*thaw_super)(struct super_block___174 *);
	int (*unfreeze_fs)(struct super_block___174 *);
	int (*statfs)(struct dentry___174 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___174 *, int *, char *);
	void (*umount_begin)(struct super_block___174 *);
	int (*show_options)(struct seq_file___152 *, struct dentry___174 *);
	int (*show_devname)(struct seq_file___152 *, struct dentry___174 *);
	int (*show_path)(struct seq_file___152 *, struct dentry___174 *);
	int (*show_stats)(struct seq_file___152 *, struct dentry___174 *);
	ssize_t (*quota_read)(struct super_block___174 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___174 *, int, const char *, size_t, loff_t);
	struct dquot___174 ** (*get_dquots)(struct inode___174 *);
	long int (*nr_cached_objects)(struct super_block___174 *, struct shrink_control___70 *);
	long int (*free_cached_objects)(struct super_block___174 *, struct shrink_control___70 *);
	struct file___174 * (*real_loop)(struct file___174 *);
};

struct wakeup_source___127;

struct dev_pm_info___127 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___127 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___127 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___127;

struct bus_type___127;

struct device_driver___127;

struct dev_pm_domain___127;

struct fwnode_handle___127;

struct class___127;

struct attribute_group___161;

struct device___127 {
	struct kobject___161 kobj;
	struct device___127 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___127 *type;
	struct bus_type___127 *bus;
	struct device_driver___127 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___127 power;
	struct dev_pm_domain___127 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___127 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___127 *class;
	const struct attribute_group___161 **groups;
	void (*release)(struct device___127 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___85 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___174 *bd_inode;
	struct super_block___174 *bd_super;
	void *bd_claiming;
	struct device___127 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___161 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___84 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___174 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___152;

struct seq_file___152 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___152 *op;
	int poll_event;
	const struct file___174 *file;
	void *private;
};

typedef void bio_end_io_t___82(struct bio___83 *);

struct bio_vec___97 {
	struct page___180 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___82;

struct bio___83 {
	struct bio___83 *bi_next;
	struct block_device___85 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___82 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___79 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___82 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___97 *bi_io_vec;
	struct bio_set___82 *bi_pool;
	struct bio_vec___97 bi_inline_vecs[0];
};

struct fwnode_operations___127;

struct fwnode_handle___127 {
	struct fwnode_handle___127 *secondary;
	const struct fwnode_operations___127 *ops;
	struct device___127 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___127;

struct fwnode_endpoint___127;

struct fwnode_operations___127 {
	struct fwnode_handle___127 * (*get)(struct fwnode_handle___127 *);
	void (*put)(struct fwnode_handle___127 *);
	bool (*device_is_available)(const struct fwnode_handle___127 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___127 *, const struct device___127 *);
	bool (*property_present)(const struct fwnode_handle___127 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___127 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___127 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___127 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*get_parent)(const struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*get_next_child_node)(const struct fwnode_handle___127 *, struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*get_named_child_node)(const struct fwnode_handle___127 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___127 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___127 *);
	struct fwnode_handle___127 * (*graph_get_next_endpoint)(const struct fwnode_handle___127 *, struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*graph_get_remote_endpoint)(const struct fwnode_handle___127 *);
	struct fwnode_handle___127 * (*graph_get_port_parent)(struct fwnode_handle___127 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___127 *, struct fwnode_endpoint___127 *);
	int (*add_links)(struct fwnode_handle___127 *);
};

struct fwnode_endpoint___127 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___127 *local_fwnode;
};

struct fwnode_reference_args___127 {
	struct fwnode_handle___127 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___161;

struct kernfs_elem_dir___161 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___161 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___161;

struct kernfs_root___161 {
	struct kernfs_node___161 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___161 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___161 {
	struct kernfs_node___161 *target_kn;
};

struct kernfs_ops___161;

struct kernfs_elem_attr___161 {
	const struct kernfs_ops___161 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___161 *notify_next;
};

struct kernfs_node___161 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___161 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___161 dir;
		struct kernfs_elem_symlink___161 symlink;
		struct kernfs_elem_attr___161 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___161;

struct kernfs_ops___161 {
	int (*open)(struct kernfs_open_file___161 *);
	void (*release)(struct kernfs_open_file___161 *);
	int (*seq_show)(struct seq_file___152 *, void *);
	void * (*seq_start)(struct seq_file___152 *, loff_t *);
	void * (*seq_next)(struct seq_file___152 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___152 *, void *);
	ssize_t (*read)(struct kernfs_open_file___161 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___161 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___161 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___161 *, struct vm_area_struct___179 *);
};

struct kernfs_syscall_ops___161 {
	int (*show_options)(struct seq_file___152 *, struct kernfs_root___161 *);
	int (*mkdir)(struct kernfs_node___161 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___161 *);
	int (*rename)(struct kernfs_node___161 *, struct kernfs_node___161 *, const char *);
	int (*show_path)(struct seq_file___152 *, struct kernfs_node___161 *, struct kernfs_root___161 *);
};

struct kernfs_open_file___161 {
	struct kernfs_node___161 *kn;
	struct file___174 *file;
	struct seq_file___152 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___169 *vm_ops;
};

struct bin_attribute___161;

struct attribute_group___161 {
	const char *name;
	umode_t (*is_visible)(struct kobject___161 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___161 *, struct bin_attribute___161 *, int);
	struct attribute **attrs;
	struct bin_attribute___161 **bin_attrs;
};

struct bin_attribute___161 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___174 * (*f_mapping)();
	ssize_t (*read)(struct file___174 *, struct kobject___161 *, struct bin_attribute___161 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___174 *, struct kobject___161 *, struct bin_attribute___161 *, char *, loff_t, size_t);
	int (*mmap)(struct file___174 *, struct kobject___161 *, struct bin_attribute___161 *, struct vm_area_struct___179 *);
};

struct sysfs_ops___161 {
	ssize_t (*show)(struct kobject___161 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___161 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___161;

struct kset___161 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___161 kobj;
	const struct kset_uevent_ops___161 *uevent_ops;
};

struct kobj_type___161 {
	void (*release)(struct kobject___161 *);
	const struct sysfs_ops___161 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___161 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___161 *);
	const void * (*namespace)(struct kobject___161 *);
	void (*get_ownership)(struct kobject___161 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___161 {
	int (* const filter)(struct kset___161 *, struct kobject___161 *);
	const char * (* const name)(struct kset___161 *, struct kobject___161 *);
	int (* const uevent)(struct kset___161 *, struct kobject___161 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___158 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___158 *);
	int (*get)(char *, const struct kernel_param___158 *);
	void (*free)(void *);
};

struct kparam_array___158;

struct kernel_param___158 {
	const char *name;
	struct module___159 *mod;
	const struct kernel_param_ops___158 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___158 *arr;
	};
};

struct kparam_array___158 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___158 *ops;
	void *elem;
};

struct module_attribute___158 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___158 *, struct module_kobject___158 *, char *);
	ssize_t (*store)(struct module_attribute___158 *, struct module_kobject___158 *, const char *, size_t);
	void (*setup)(struct module___159 *, const char *);
	int (*test)(struct module___159 *);
	void (*free)(struct module___159 *);
};

struct cgroup_namespace___118 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___118 *root_cset;
};

struct dev_pm_ops___127 {
	int (*prepare)(struct device___127 *);
	void (*complete)(struct device___127 *);
	int (*suspend)(struct device___127 *);
	int (*resume)(struct device___127 *);
	int (*freeze)(struct device___127 *);
	int (*thaw)(struct device___127 *);
	int (*poweroff)(struct device___127 *);
	int (*restore)(struct device___127 *);
	int (*suspend_late)(struct device___127 *);
	int (*resume_early)(struct device___127 *);
	int (*freeze_late)(struct device___127 *);
	int (*thaw_early)(struct device___127 *);
	int (*poweroff_late)(struct device___127 *);
	int (*restore_early)(struct device___127 *);
	int (*suspend_noirq)(struct device___127 *);
	int (*resume_noirq)(struct device___127 *);
	int (*freeze_noirq)(struct device___127 *);
	int (*thaw_noirq)(struct device___127 *);
	int (*poweroff_noirq)(struct device___127 *);
	int (*restore_noirq)(struct device___127 *);
	int (*runtime_suspend)(struct device___127 *);
	int (*runtime_resume)(struct device___127 *);
	int (*runtime_idle)(struct device___127 *);
};

struct wakeup_source___127 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___127 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___127 {
	struct dev_pm_ops___127 ops;
	int (*start)(struct device___127 *);
	void (*detach)(struct device___127 *, bool);
	int (*activate)(struct device___127 *);
	void (*sync)(struct device___127 *);
	void (*dismiss)(struct device___127 *);
};

struct bus_type___127 {
	const char *name;
	const char *dev_name;
	struct device___127 *dev_root;
	const struct attribute_group___161 **bus_groups;
	const struct attribute_group___161 **dev_groups;
	const struct attribute_group___161 **drv_groups;
	int (*match)(struct device___127 *, struct device_driver___127 *);
	int (*uevent)(struct device___127 *, struct kobj_uevent_env *);
	int (*probe)(struct device___127 *);
	void (*sync_state)(struct device___127 *);
	void (*remove)(struct device___127 *);
	void (*shutdown)(struct device___127 *);
	int (*online)(struct device___127 *);
	int (*offline)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	int (*num_vf)(struct device___127 *);
	int (*dma_configure)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___127 {
	const char *name;
	struct bus_type___127 *bus;
	struct module___159 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___127 *);
	void (*sync_state)(struct device___127 *);
	int (*remove)(struct device___127 *);
	void (*shutdown)(struct device___127 *);
	int (*suspend)(struct device___127 *, pm_message_t);
	int (*resume)(struct device___127 *);
	const struct attribute_group___161 **groups;
	const struct attribute_group___161 **dev_groups;
	const struct dev_pm_ops___127 *pm;
	void (*coredump)(struct device___127 *);
	struct driver_private *p;
};

struct device_type___127 {
	const char *name;
	const struct attribute_group___161 **groups;
	int (*uevent)(struct device___127 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___127 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___127 *);
	const struct dev_pm_ops___127 *pm;
};

struct class___127 {
	const char *name;
	struct module___159 *owner;
	const struct attribute_group___161 **class_groups;
	const struct attribute_group___161 **dev_groups;
	struct kobject___161 *dev_kobj;
	int (*dev_uevent)(struct device___127 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___127 *, umode_t *);
	void (*class_release)(struct class___127 *);
	void (*dev_release)(struct device___127 *);
	int (*shutdown_pre)(struct device___127 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___127 *);
	void (*get_ownership)(struct device___127 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___127 *pm;
	struct subsys_private *p;
};

struct block_device_operations___83;

struct gendisk___84 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___85 *part0;
	const struct block_device_operations___83 *fops;
	struct request_queue___82 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___79 *bdi;
	struct kobject___161 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___161 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___82 {
	struct bio___83 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___97 *bip_vec;
	struct bio_vec___97 bip_inline_vecs[0];
};

struct blkcg___79;

struct blkg_policy_data___79;

struct blkcg_gq___79 {
	struct request_queue___82 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___79 *blkcg;
	struct blkcg_gq___79 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___79 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___82 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___82(struct request___82 *);

typedef void integrity_complete_fn___82(struct request___82 *, unsigned int);

struct blk_integrity_profile___82 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___82 *prepare_fn;
	integrity_complete_fn___82 *complete_fn;
	const char *name;
};

struct block_device_operations___83 {
	blk_qc_t (*submit_bio)(struct bio___83 *);
	int (*open)(struct block_device___85 *, fmode_t);
	void (*release)(struct gendisk___84 *, fmode_t);
	int (*rw_page)(struct block_device___85 *, sector_t, struct page___180 *, unsigned int);
	int (*ioctl)(struct block_device___85 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___85 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___84 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___84 *);
	int (*getgeo)(struct block_device___85 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___85 *, bool);
	void (*swap_slot_free_notify)(struct block_device___85 *, long unsigned int);
	int (*report_zones)(struct gendisk___84 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___84 *, umode_t *);
	struct module___159 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___84 *, sector_t *);
};

typedef void rq_end_io_fn___82(struct request___82 *, blk_status_t);

struct request___82 {
	struct request_queue___82 *q;
	struct blk_mq_ctx___3 *mq_ctx;
	struct blk_mq_hw_ctx___79 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___83 *bio;
	struct bio___83 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___97 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___82 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___82 *saved_end_io;
		} flush;
	};
	struct gendisk___84 *rq_disk;
	struct block_device___85 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___82 *end_io;
	void *end_io_data;
};

struct blk_mq_ctxs___3;

struct blk_mq_ctx___3 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___79 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___82 *queue;
	struct blk_mq_ctxs___3 *ctxs;
	struct kobject___161 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tags___3;

struct blk_mq_hw_ctx___79 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___82 *queue;
	struct blk_flush_queue___3 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___3 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___3 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___3 *tags;
	struct blk_mq_tags___3 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___161 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___174 *debugfs_dir;
	struct dentry___174 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___82;

struct blk_mq_alloc_data___3;

struct elevator_mq_ops___82 {
	int (*init_sched)(struct request_queue___82 *, struct elevator_type___82 *);
	void (*exit_sched)(struct elevator_queue___82 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___79 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___79 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___79 *);
	bool (*allow_merge)(struct request_queue___82 *, struct request___82 *, struct bio___83 *);
	bool (*bio_merge)(struct request_queue___82 *, struct bio___83 *, unsigned int);
	int (*request_merge)(struct request_queue___82 *, struct request___82 **, struct bio___83 *);
	void (*request_merged)(struct request_queue___82 *, struct request___82 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___82 *, struct request___82 *, struct request___82 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___3 *);
	void (*prepare_request)(struct request___82 *);
	void (*finish_request)(struct request___82 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___79 *, struct list_head *, bool);
	struct request___82 * (*dispatch_request)(struct blk_mq_hw_ctx___79 *);
	bool (*has_work)(struct blk_mq_hw_ctx___79 *);
	void (*completed_request)(struct request___82 *, u64);
	void (*requeue_request)(struct request___82 *);
	struct request___82 * (*former_request)(struct request_queue___82 *, struct request___82 *);
	struct request___82 * (*next_request)(struct request_queue___82 *, struct request___82 *);
	void (*init_icq)(struct io_cq___82 *);
	void (*exit_icq)(struct io_cq___82 *);
};

struct elv_fs_entry___82;

struct elevator_type___82 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___82 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___82 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___159 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___82 {
	struct elevator_type___82 *type;
	void *elevator_data;
	struct kobject___161 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___3 {
	struct request_queue___82 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___3 *ctx;
	struct blk_mq_hw_ctx___79 *hctx;
};

struct elv_fs_entry___82 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___82 *, char *);
	ssize_t (*store)(struct elevator_queue___82 *, const char *, size_t);
};

struct blk_mq_queue_data___79;

struct blk_mq_ops___79 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___79 *, const struct blk_mq_queue_data___79 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___79 *);
	int (*get_budget)(struct request_queue___82 *);
	void (*put_budget)(struct request_queue___82 *, int);
	void (*set_rq_budget_token)(struct request___82 *, int);
	int (*get_rq_budget_token)(struct request___82 *);
	enum blk_eh_timer_return (*timeout)(struct request___82 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___79 *);
	void (*complete)(struct request___82 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___79 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___79 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___79 *, struct request___82 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___79 *, struct request___82 *, unsigned int);
	void (*initialize_rq_fn)(struct request___82 *);
	void (*cleanup_rq)(struct request___82 *);
	bool (*busy)(struct request_queue___82 *);
	int (*map_queues)(struct blk_mq_tag_set___79 *);
	void (*show_rq)(struct seq_file___152 *, struct request___82 *);
};

struct blk_stat_callback___3 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___82 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___3 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___3 {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___82 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___79 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___79 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags___3 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___152 {
	void * (*start)(struct seq_file___152 *, loff_t *);
	void (*stop)(struct seq_file___152 *, void *);
	void * (*next)(struct seq_file___152 *, void *, loff_t *);
	int (*show)(struct seq_file___152 *, void *);
};

struct cftype___118;

struct cgroup_subsys___118 {
	struct cgroup_subsys_state___118 * (*css_alloc)(struct cgroup_subsys_state___118 *);
	int (*css_online)(struct cgroup_subsys_state___118 *);
	void (*css_offline)(struct cgroup_subsys_state___118 *);
	void (*css_released)(struct cgroup_subsys_state___118 *);
	void (*css_free)(struct cgroup_subsys_state___118 *);
	void (*css_reset)(struct cgroup_subsys_state___118 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___118 *, int);
	int (*css_extra_stat_show)(struct seq_file___152 *, struct cgroup_subsys_state___118 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___181 *, struct css_set___118 *);
	void (*cancel_fork)(struct task_struct___181 *, struct css_set___118 *);
	void (*fork)(struct task_struct___181 *);
	void (*exit)(struct task_struct___181 *);
	void (*release)(struct task_struct___181 *);
	void (*bind)(struct cgroup_subsys_state___118 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___118 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___118 *dfl_cftypes;
	struct cftype___118 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___118 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___118 *updated_children;
	struct cgroup___118 *updated_next;
};

struct cgroup_root___118 {
	struct kernfs_root___161 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___118 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___118 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___118 *ss;
	struct list_head node;
	struct kernfs_ops___161 *kf_ops;
	int (*open)(struct kernfs_open_file___161 *);
	void (*release)(struct kernfs_open_file___161 *);
	u64 (*read_u64)(struct cgroup_subsys_state___118 *, struct cftype___118 *);
	s64 (*read_s64)(struct cgroup_subsys_state___118 *, struct cftype___118 *);
	int (*seq_show)(struct seq_file___152 *, void *);
	void * (*seq_start)(struct seq_file___152 *, loff_t *);
	void * (*seq_next)(struct seq_file___152 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___152 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___118 *, struct cftype___118 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___118 *, struct cftype___118 *, s64);
	ssize_t (*write)(struct kernfs_open_file___161 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___161 *, struct poll_table_struct___5 *);
};

struct blk_mq_tags___3 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___82 **rqs;
	struct request___82 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

struct blk_mq_queue_data___79 {
	struct request___82 *rq;
	bool last;
};

struct blkcg_policy_data___79;

struct blkcg___79 {
	struct cgroup_subsys_state___118 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___79 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___79 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___79 {
	struct blkcg___79 *blkcg;
	int plid;
};

struct blkg_policy_data___79 {
	struct blkcg_gq___79 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___70 {
	struct mem_cgroup___70 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___70 {
	struct lruvec___77 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___70 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___70 *memcg;
};

struct obj_cgroup___70 {
	struct percpu_ref refcnt;
	struct mem_cgroup___70 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct blk_mq_ctxs___3 {
	struct kobject___161 kobj;
	struct blk_mq_ctx___3 *queue_ctx;
};

struct blkdev_dio {
	union {
		struct kiocb___174 *iocb;
		struct task_struct___181 *waiter;
	};
	size_t size;
	atomic_t ref;
	bool multi_bio: 1;
	bool should_dirty: 1;
	bool is_sync: 1;
	long: 63;
	long: 64;
	long: 64;
	struct bio___83 bio;
};

struct dentry___175;

struct super_block___175;

struct module___160;

struct file_system_type___175 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___175 * (*mount)(struct file_system_type___175 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___175 *);
	struct module___160 *owner;
	struct file_system_type___175 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___175;

struct kiocb___175;

struct iov_iter___100;

struct poll_table_struct___113;

struct vm_area_struct___180;

struct inode___175;

struct file_lock___175;

struct page___181;

struct file_operations___175 {
	struct module___160 *owner;
	loff_t (*llseek)(struct file___175 *, loff_t, int);
	ssize_t (*read)(struct file___175 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___175 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___175 *, struct iov_iter___100 *);
	ssize_t (*write_iter)(struct kiocb___175 *, struct iov_iter___100 *);
	int (*iopoll)(struct kiocb___175 *, bool);
	int (*iterate)(struct file___175 *, struct dir_context *);
	int (*iterate_shared)(struct file___175 *, struct dir_context *);
	__poll_t (*poll)(struct file___175 *, struct poll_table_struct___113 *);
	long int (*unlocked_ioctl)(struct file___175 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___175 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___175 *, struct vm_area_struct___180 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___175 *, struct file___175 *);
	int (*flush)(struct file___175 *, fl_owner_t);
	int (*release)(struct inode___175 *, struct file___175 *);
	int (*fsync)(struct file___175 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___175 *, int);
	int (*lock)(struct file___175 *, int, struct file_lock___175 *);
	ssize_t (*sendpage)(struct file___175 *, struct page___181 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___175 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___175 *, long unsigned int);
	int (*flock)(struct file___175 *, int, struct file_lock___175 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___175 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___175 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___175 *, long int, struct file_lock___175 **, void **);
	long int (*fallocate)(struct file___175 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___3 *, struct file___175 *);
	ssize_t (*copy_file_range)(struct file___175 *, loff_t, struct file___175 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___175 *, loff_t, struct file___175 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___175 *, loff_t, loff_t, int);
};

struct vmacache___180 {
	u64 seqnum;
	struct vm_area_struct___180 *vmas[4];
};

struct page_frag___180 {
	struct page___181 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___181;

struct pid___155;

struct nsproxy___164;

struct signal_struct___176;

struct bio_list___83;

struct backing_dev_info___80;

struct io_context___83;

struct css_set___119;

struct mem_cgroup___71;

struct request_queue___83;

struct vm_struct___158;

struct task_struct___182 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___182 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___181 *mm;
	struct mm_struct___181 *active_mm;
	struct vmacache___180 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___182 *real_parent;
	struct task_struct___182 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___182 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___155 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___164 *nsproxy;
	struct signal_struct___176 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___182 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___83 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___80 *backing_dev_info;
	struct io_context___83 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___119 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___180 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___71 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___71 *active_memcg;
	struct request_queue___83 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___182 *oom_reaper_list;
	struct vm_struct___158 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___70 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___162;

struct kobj_type___162;

struct kernfs_node___162;

struct kobject___162 {
	const char *name;
	struct list_head entry;
	struct kobject___162 *parent;
	struct kset___162 *kset;
	struct kobj_type___162 *ktype;
	struct kernfs_node___162 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___159 {
	struct kobject___162 kobj;
	struct module___160 *mod;
	struct kobject___162 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___159 {
	struct module___160 *mod;
	struct latch_tree_node node;
};

struct module_layout___159 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___159 mtn;
};

struct module_attribute___159;

struct kernel_param___159;

struct module___160 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___159 mkobj;
	struct module_attribute___159 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___162 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___159 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___159 core_layout;
	struct module_layout___159 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___181 *pgtable_t___180;

struct address_space___175;

struct dev_pagemap___170;

struct page___181 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___175 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___181 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___180 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___181 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___170 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___170;

struct vm_area_struct___180 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___180 *vm_next;
	struct vm_area_struct___180 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___181 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___170 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___175 *vm_file;
	struct file___175 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___180;

struct mm_struct___181 {
	struct {
		struct vm_area_struct___180 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___175 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___180 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___182 *owner;
		struct user_namespace___25 *user_ns;
		struct file___175 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___175;

struct address_space___175 {
	struct inode___175 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___175 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___170;

struct dev_pagemap___170 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___170 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___175;

struct path___175 {
	struct vfsmount___175 *mnt;
	struct dentry___175 *dentry;
};

struct fown_struct___155 {
	rwlock_t lock;
	struct pid___155 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___175 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___175 f_path;
	struct inode___175 *f_inode;
	const struct file_operations___175 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___155 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___175 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___170;

struct vm_operations_struct___170 {
	void (*open)(struct vm_area_struct___180 *);
	void (*close)(struct vm_area_struct___180 *);
	int (*may_split)(struct vm_area_struct___180 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___180 *);
	int (*mprotect)(struct vm_area_struct___180 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___170 *);
	vm_fault_t (*huge_fault)(struct vm_fault___170 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___170 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___180 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___170 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___170 *);
	int (*access)(struct vm_area_struct___180 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___180 *);
	int (*set_policy)(struct vm_area_struct___180 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___180 *, long unsigned int);
	struct page___181 * (*find_special_page)(struct vm_area_struct___180 *, long unsigned int);
};

struct core_thread___180 {
	struct task_struct___182 *task;
	struct core_thread___180 *next;
};

struct core_state___180 {
	atomic_t nr_threads;
	struct core_thread___180 dumper;
	struct completion startup;
};

struct vm_fault___170 {
	const struct {
		struct vm_area_struct___180 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___181 *cow_page;
	struct page___181 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___180 prealloc_pte;
};

struct pglist_data___78;

struct lruvec___78 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___78 *pgdat;
};

struct zone___78 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___78 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___78 {
	struct zone___78 *zone;
	int zone_idx;
};

struct zonelist___78 {
	struct zoneref___78 _zonerefs[321];
};

struct pglist_data___78 {
	struct zone___78 node_zones[5];
	struct zonelist___78 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___182 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___182 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___78 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___71 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___71 *memcg;
};

struct cgroup___119;

struct cgroup_subsys___119;

struct cgroup_subsys_state___119 {
	struct cgroup___119 *cgroup;
	struct cgroup_subsys___119 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___119 *parent;
};

struct cgroup_file___119 {
	struct kernfs_node___162 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___71;

struct mem_cgroup_per_node___71;

struct mem_cgroup___71 {
	struct cgroup_subsys_state___119 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___119 events_file;
	struct cgroup_file___119 events_local_file;
	struct cgroup_file___119 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___71 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___182 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___71 *nodeinfo[0];
	long: 64;
};

struct shrinker___71 {
	long unsigned int (*count_objects)(struct shrinker___71 *, struct shrink_control___71 *);
	long unsigned int (*scan_objects)(struct shrinker___71 *, struct shrink_control___71 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___170 {
	void (*page_free)(struct page___181 *);
	void (*kill)(struct dev_pagemap___170 *);
	void (*cleanup)(struct dev_pagemap___170 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___170 *);
};

struct pid_namespace___155;

struct upid___155 {
	int nr;
	struct pid_namespace___155 *ns;
};

struct pid_namespace___155 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___182 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___155 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___155 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___155 numbers[1];
};

struct signal_struct___176 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___182 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___182 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___155 *pids[4];
	struct pid___155 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___181 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___119;

struct nsproxy___164 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___155 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___119 *cgroup_ns;
};

struct bio___84;

struct bio_list___83 {
	struct bio___84 *head;
	struct bio___84 *tail;
};

struct bdi_writeback___80 {
	struct backing_dev_info___80 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___119 *memcg_css;
	struct cgroup_subsys_state___119 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___128;

struct backing_dev_info___80 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___80 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___128 *dev;
	char dev_name[64];
	struct device___128 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___175 *debug_dir;
};

struct io_cq___83;

struct io_context___83 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___83 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___119 {
	struct cgroup_subsys_state___119 *subsys[14];
	refcount_t refcount;
	struct css_set___119 *dom_cset;
	struct cgroup___119 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___119 *mg_src_cgrp;
	struct cgroup___119 *mg_dst_cgrp;
	struct css_set___119 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___83;

struct blk_integrity___83 {
	const struct blk_integrity_profile___83 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___83 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___83 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___83;

struct elevator_queue___83;

struct blk_mq_ops___80;

struct blk_mq_ctx___4;

struct blk_mq_hw_ctx___80;

struct gendisk___85;

struct blk_stat_callback___4;

struct blkcg_gq___80;

struct blk_trace___3;

struct blk_flush_queue___4;

struct blk_mq_tag_set___80;

struct request_queue___83 {
	struct request___83 *last_merge;
	struct elevator_queue___83 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___80 *mq_ops;
	struct blk_mq_ctx___4 *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___80 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___85 *disk;
	struct kobject___162 kobj;
	struct kobject___162 *mq_kobj;
	struct blk_integrity___83 integrity;
	struct device___128 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___4 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___80 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___3 *blk_trace;
	struct blk_flush_queue___4 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___80 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___83 bio_split;
	struct dentry___175 *debugfs_dir;
	struct dentry___175 *sched_debugfs_dir;
	struct dentry___175 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___158 {
	struct vm_struct___158 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___181 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___175;

struct dentry___175 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___175 *d_parent;
	struct qstr d_name;
	struct inode___175 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___175 *d_op;
	struct super_block___175 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___175;

struct inode___175 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___175 *i_op;
	struct super_block___175 *i_sb;
	struct address_space___175 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___80 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___175 *i_fop;
		void (*free_inode)(struct inode___175 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___175 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___175 {
	int (*d_revalidate)(struct dentry___175 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___175 *, unsigned int);
	int (*d_hash)(const struct dentry___175 *, struct qstr *);
	int (*d_compare)(const struct dentry___175 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___175 *);
	int (*d_init)(struct dentry___175 *);
	void (*d_release)(struct dentry___175 *);
	void (*d_prune)(struct dentry___175 *);
	void (*d_iput)(struct dentry___175 *, struct inode___175 *);
	char * (*d_dname)(struct dentry___175 *, char *, int);
	struct vfsmount___175 * (*d_automount)(struct path___175 *);
	int (*d_manage)(const struct path___175 *, bool);
	struct dentry___175 * (*d_real)(struct dentry___175 *, const struct inode___175 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___175;

struct mem_dqinfo___175 {
	struct quota_format_type___175 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___175;

struct quota_info___175 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___175 *files[3];
	struct mem_dqinfo___175 info[3];
	const struct quota_format_ops___175 *ops[3];
};

struct rcuwait___176 {
	struct task_struct___182 *task;
};

struct percpu_rw_semaphore___176 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___176 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___175 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___176 rw_sem[3];
};

struct super_operations___175;

struct dquot_operations___175;

struct quotactl_ops___175;

struct super_block___175 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___175 *s_type;
	const struct super_operations___175 *s_op;
	const struct dquot_operations___175 *dq_op;
	const struct quotactl_ops___175 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___175 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___2 *s_bdev;
	struct backing_dev_info___80 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___175 s_dquot;
	struct sb_writers___175 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___175 *s_d_op;
	int cleancache_poolid;
	struct shrinker___71 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___175 {
	struct dentry___175 *mnt_root;
	struct super_block___175 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct psi_group___119 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___182 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___119;

struct cgroup_rstat_cpu___119;

struct cgroup___119 {
	struct cgroup_subsys_state___119 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___162 *kn;
	struct cgroup_file___119 procs_file;
	struct cgroup_file___119 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___119 *subsys[14];
	struct cgroup_root___119 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___119 *dom_cgrp;
	struct cgroup___119 *old_dom_cgrp;
	struct cgroup_rstat_cpu___119 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___119 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___83 {
	struct request_queue___83 *q;
	struct io_context___83 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___77;

struct kiocb___175 {
	struct file___175 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___175 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___77 *ki_waitq;
	};
};

struct iattr___175 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___175 *ia_file;
};

struct dquot___175 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___175 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___175 {
	int qf_fmt_id;
	const struct quota_format_ops___175 *qf_ops;
	struct module___160 *qf_owner;
	struct quota_format_type___175 *qf_next;
};

struct quota_format_ops___175 {
	int (*check_quota_file)(struct super_block___175 *, int);
	int (*read_file_info)(struct super_block___175 *, int);
	int (*write_file_info)(struct super_block___175 *, int);
	int (*free_file_info)(struct super_block___175 *, int);
	int (*read_dqblk)(struct dquot___175 *);
	int (*commit_dqblk)(struct dquot___175 *);
	int (*release_dqblk)(struct dquot___175 *);
	int (*get_next_id)(struct super_block___175 *, struct kqid *);
};

struct dquot_operations___175 {
	int (*write_dquot)(struct dquot___175 *);
	struct dquot___175 * (*alloc_dquot)(struct super_block___175 *, int);
	void (*destroy_dquot)(struct dquot___175 *);
	int (*acquire_dquot)(struct dquot___175 *);
	int (*release_dquot)(struct dquot___175 *);
	int (*mark_dirty)(struct dquot___175 *);
	int (*write_info)(struct super_block___175 *, int);
	qsize_t * (*get_reserved_space)(struct inode___175 *);
	int (*get_projid)(struct inode___175 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___175 *, qsize_t *);
	int (*get_next_id)(struct super_block___175 *, struct kqid *);
};

struct quotactl_ops___175 {
	int (*quota_on)(struct super_block___175 *, int, int, const struct path___175 *);
	int (*quota_off)(struct super_block___175 *, int);
	int (*quota_enable)(struct super_block___175 *, unsigned int);
	int (*quota_disable)(struct super_block___175 *, unsigned int);
	int (*quota_sync)(struct super_block___175 *, int);
	int (*set_info)(struct super_block___175 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___175 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___175 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___175 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___175 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___175 *, unsigned int);
};

struct wait_page_queue___77 {
	struct page___181 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___80;

struct readahead_control___77;

struct swap_info_struct___40;

struct address_space_operations___175 {
	int (*writepage)(struct page___181 *, struct writeback_control___80 *);
	int (*readpage)(struct file___175 *, struct page___181 *);
	int (*writepages)(struct address_space___175 *, struct writeback_control___80 *);
	int (*set_page_dirty)(struct page___181 *);
	int (*readpages)(struct file___175 *, struct address_space___175 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___77 *);
	int (*write_begin)(struct file___175 *, struct address_space___175 *, loff_t, unsigned int, unsigned int, struct page___181 **, void **);
	int (*write_end)(struct file___175 *, struct address_space___175 *, loff_t, unsigned int, unsigned int, struct page___181 *, void *);
	sector_t (*bmap)(struct address_space___175 *, sector_t);
	void (*invalidatepage)(struct page___181 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___181 *, gfp_t);
	void (*freepage)(struct page___181 *);
	ssize_t (*direct_IO)(struct kiocb___175 *, struct iov_iter___100 *);
	int (*migratepage)(struct address_space___175 *, struct page___181 *, struct page___181 *, enum migrate_mode);
	bool (*isolate_page)(struct page___181 *, isolate_mode_t);
	void (*putback_page)(struct page___181 *);
	int (*launder_page)(struct page___181 *);
	int (*is_partially_uptodate)(struct page___181 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___181 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___175 *, struct page___181 *);
	int (*swap_activate)(struct swap_info_struct___40 *, struct file___175 *, sector_t *);
	void (*swap_deactivate)(struct file___175 *);
};

struct writeback_control___80 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___80 *wb;
	struct inode___175 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___77 {
	struct file___175 *file;
	struct address_space___175 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___98;

struct iov_iter___100 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___98 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___40 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___2 *bdev;
	struct file___175 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___175 {
	struct dentry___175 * (*lookup)(struct inode___175 *, struct dentry___175 *, unsigned int);
	const char * (*get_link)(struct dentry___175 *, struct inode___175 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___175 *, int);
	struct posix_acl * (*get_acl)(struct inode___175 *, int, bool);
	int (*readlink)(struct dentry___175 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___175 *, struct dentry___175 *, umode_t, bool);
	int (*link)(struct dentry___175 *, struct inode___175 *, struct dentry___175 *);
	int (*unlink)(struct inode___175 *, struct dentry___175 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___175 *, struct dentry___175 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___175 *, struct dentry___175 *, umode_t);
	int (*rmdir)(struct inode___175 *, struct dentry___175 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___175 *, struct dentry___175 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___175 *, struct dentry___175 *, struct inode___175 *, struct dentry___175 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___175 *, struct iattr___175 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___175 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___175 *, char *, size_t);
	int (*fiemap)(struct inode___175 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___175 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___175 *, struct dentry___175 *, struct file___175 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___175 *, struct dentry___175 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___175 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___175 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___175 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___175 {
	void (*fl_copy_lock)(struct file_lock___175 *, struct file_lock___175 *);
	void (*fl_release_private)(struct file_lock___175 *);
};

struct fasync_struct___175;

struct lock_manager_operations___175;

struct file_lock___175 {
	struct file_lock___175 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___175 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___175 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___175 *fl_ops;
	const struct lock_manager_operations___175 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___175 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___175 *);
	int (*lm_grant)(struct file_lock___175 *, int);
	bool (*lm_break)(struct file_lock___175 *);
	int (*lm_change)(struct file_lock___175 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___175 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___175 *);
};

struct fasync_struct___175 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___175 *fa_next;
	struct file___175 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___175 {
	struct inode___175 * (*alloc_inode)(struct super_block___175 *);
	void (*destroy_inode)(struct inode___175 *);
	void (*free_inode)(struct inode___175 *);
	void (*dirty_inode)(struct inode___175 *, int);
	int (*write_inode)(struct inode___175 *, struct writeback_control___80 *);
	int (*drop_inode)(struct inode___175 *);
	void (*evict_inode)(struct inode___175 *);
	void (*put_super)(struct super_block___175 *);
	int (*sync_fs)(struct super_block___175 *, int);
	int (*freeze_super)(struct super_block___175 *);
	int (*freeze_fs)(struct super_block___175 *);
	int (*thaw_super)(struct super_block___175 *);
	int (*unfreeze_fs)(struct super_block___175 *);
	int (*statfs)(struct dentry___175 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___175 *, int *, char *);
	void (*umount_begin)(struct super_block___175 *);
	int (*show_options)(struct seq_file___3 *, struct dentry___175 *);
	int (*show_devname)(struct seq_file___3 *, struct dentry___175 *);
	int (*show_path)(struct seq_file___3 *, struct dentry___175 *);
	int (*show_stats)(struct seq_file___3 *, struct dentry___175 *);
	ssize_t (*quota_read)(struct super_block___175 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___175 *, int, const char *, size_t, loff_t);
	struct dquot___175 ** (*get_dquots)(struct inode___175 *);
	long int (*nr_cached_objects)(struct super_block___175 *, struct shrink_control___71 *);
	long int (*free_cached_objects)(struct super_block___175 *, struct shrink_control___71 *);
	struct file___175 * (*real_loop)(struct file___175 *);
};

struct wakeup_source___128;

struct dev_pm_info___128 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___128 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___128 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___128;

struct bus_type___128;

struct device_driver___128;

struct dev_pm_domain___128;

struct fwnode_handle___128;

struct class___128;

struct attribute_group___162;

struct device___128 {
	struct kobject___162 kobj;
	struct device___128 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___128 *type;
	struct bus_type___128 *bus;
	struct device_driver___128 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___128 power;
	struct dev_pm_domain___128 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___128 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___128 *class;
	const struct attribute_group___162 **groups;
	void (*release)(struct device___128 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___2 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___175 *bd_inode;
	struct super_block___175 *bd_super;
	void *bd_claiming;
	struct device___128 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___162 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___85 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___175 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___115)(struct file___175 *, wait_queue_head_t *, struct poll_table_struct___113 *);

struct poll_table_struct___113 {
	poll_queue_proc___115 _qproc;
	__poll_t _key;
};

struct seq_file___3 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___2 *op;
	int poll_event;
	const struct file___175 *file;
	void *private;
};

typedef void bio_end_io_t___83(struct bio___84 *);

struct bio_vec___98 {
	struct page___181 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___83;

struct bio___84 {
	struct bio___84 *bi_next;
	struct block_device___2 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___83 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___80 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___83 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___98 *bi_io_vec;
	struct bio_set___83 *bi_pool;
	struct bio_vec___98 bi_inline_vecs[0];
};

struct seq_operations___2 {
	void * (*start)(struct seq_file___3 *, loff_t *);
	void (*stop)(struct seq_file___3 *, void *);
	void * (*next)(struct seq_file___3 *, void *, loff_t *);
	int (*show)(struct seq_file___3 *, void *);
};

struct kernfs_root___162;

struct kernfs_elem_dir___162 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___162 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___162;

struct kernfs_root___162 {
	struct kernfs_node___162 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___162 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___162 {
	struct kernfs_node___162 *target_kn;
};

struct kernfs_ops___162;

struct kernfs_elem_attr___162 {
	const struct kernfs_ops___162 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___162 *notify_next;
};

struct kernfs_node___162 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___162 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___162 dir;
		struct kernfs_elem_symlink___162 symlink;
		struct kernfs_elem_attr___162 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___162;

struct kernfs_ops___162 {
	int (*open)(struct kernfs_open_file___162 *);
	void (*release)(struct kernfs_open_file___162 *);
	int (*seq_show)(struct seq_file___3 *, void *);
	void * (*seq_start)(struct seq_file___3 *, loff_t *);
	void * (*seq_next)(struct seq_file___3 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___3 *, void *);
	ssize_t (*read)(struct kernfs_open_file___162 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___162 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___162 *, struct poll_table_struct___113 *);
	int (*mmap)(struct kernfs_open_file___162 *, struct vm_area_struct___180 *);
};

struct kernfs_syscall_ops___162 {
	int (*show_options)(struct seq_file___3 *, struct kernfs_root___162 *);
	int (*mkdir)(struct kernfs_node___162 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___162 *);
	int (*rename)(struct kernfs_node___162 *, struct kernfs_node___162 *, const char *);
	int (*show_path)(struct seq_file___3 *, struct kernfs_node___162 *, struct kernfs_root___162 *);
};

struct kernfs_open_file___162 {
	struct kernfs_node___162 *kn;
	struct file___175 *file;
	struct seq_file___3 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___170 *vm_ops;
};

struct cgroup_namespace___119 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___119 *root_cset;
};

struct fwnode_operations___128;

struct fwnode_handle___128 {
	struct fwnode_handle___128 *secondary;
	const struct fwnode_operations___128 *ops;
	struct device___128 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___128;

struct fwnode_endpoint___128;

struct fwnode_operations___128 {
	struct fwnode_handle___128 * (*get)(struct fwnode_handle___128 *);
	void (*put)(struct fwnode_handle___128 *);
	bool (*device_is_available)(const struct fwnode_handle___128 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___128 *, const struct device___128 *);
	bool (*property_present)(const struct fwnode_handle___128 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___128 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___128 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___128 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*get_parent)(const struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*get_next_child_node)(const struct fwnode_handle___128 *, struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*get_named_child_node)(const struct fwnode_handle___128 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___128 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___128 *);
	struct fwnode_handle___128 * (*graph_get_next_endpoint)(const struct fwnode_handle___128 *, struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*graph_get_remote_endpoint)(const struct fwnode_handle___128 *);
	struct fwnode_handle___128 * (*graph_get_port_parent)(struct fwnode_handle___128 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___128 *, struct fwnode_endpoint___128 *);
	int (*add_links)(struct fwnode_handle___128 *);
};

struct fwnode_endpoint___128 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___128 *local_fwnode;
};

struct fwnode_reference_args___128 {
	struct fwnode_handle___128 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___162;

struct attribute_group___162 {
	const char *name;
	umode_t (*is_visible)(struct kobject___162 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___162 *, struct bin_attribute___162 *, int);
	struct attribute **attrs;
	struct bin_attribute___162 **bin_attrs;
};

struct bin_attribute___162 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___175 * (*f_mapping)();
	ssize_t (*read)(struct file___175 *, struct kobject___162 *, struct bin_attribute___162 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___175 *, struct kobject___162 *, struct bin_attribute___162 *, char *, loff_t, size_t);
	int (*mmap)(struct file___175 *, struct kobject___162 *, struct bin_attribute___162 *, struct vm_area_struct___180 *);
};

struct sysfs_ops___162 {
	ssize_t (*show)(struct kobject___162 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___162 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___162;

struct kset___162 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___162 kobj;
	const struct kset_uevent_ops___162 *uevent_ops;
};

struct kobj_type___162 {
	void (*release)(struct kobject___162 *);
	const struct sysfs_ops___162 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___162 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___162 *);
	const void * (*namespace)(struct kobject___162 *);
	void (*get_ownership)(struct kobject___162 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___162 {
	int (* const filter)(struct kset___162 *, struct kobject___162 *);
	const char * (* const name)(struct kset___162 *, struct kobject___162 *);
	int (* const uevent)(struct kset___162 *, struct kobject___162 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___159 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___159 *);
	int (*get)(char *, const struct kernel_param___159 *);
	void (*free)(void *);
};

struct kparam_array___159;

struct kernel_param___159 {
	const char *name;
	struct module___160 *mod;
	const struct kernel_param_ops___159 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___159 *arr;
	};
};

struct kparam_array___159 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___159 *ops;
	void *elem;
};

struct module_attribute___159 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___159 *, struct module_kobject___159 *, char *);
	ssize_t (*store)(struct module_attribute___159 *, struct module_kobject___159 *, const char *, size_t);
	void (*setup)(struct module___160 *, const char *);
	int (*test)(struct module___160 *);
	void (*free)(struct module___160 *);
};

struct cftype___119;

struct cgroup_subsys___119 {
	struct cgroup_subsys_state___119 * (*css_alloc)(struct cgroup_subsys_state___119 *);
	int (*css_online)(struct cgroup_subsys_state___119 *);
	void (*css_offline)(struct cgroup_subsys_state___119 *);
	void (*css_released)(struct cgroup_subsys_state___119 *);
	void (*css_free)(struct cgroup_subsys_state___119 *);
	void (*css_reset)(struct cgroup_subsys_state___119 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___119 *, int);
	int (*css_extra_stat_show)(struct seq_file___3 *, struct cgroup_subsys_state___119 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___182 *, struct css_set___119 *);
	void (*cancel_fork)(struct task_struct___182 *, struct css_set___119 *);
	void (*fork)(struct task_struct___182 *);
	void (*exit)(struct task_struct___182 *);
	void (*release)(struct task_struct___182 *);
	void (*bind)(struct cgroup_subsys_state___119 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___119 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___119 *dfl_cftypes;
	struct cftype___119 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___119 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___119 *updated_children;
	struct cgroup___119 *updated_next;
};

struct cgroup_root___119 {
	struct kernfs_root___162 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___119 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___119 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___119 *ss;
	struct list_head node;
	struct kernfs_ops___162 *kf_ops;
	int (*open)(struct kernfs_open_file___162 *);
	void (*release)(struct kernfs_open_file___162 *);
	u64 (*read_u64)(struct cgroup_subsys_state___119 *, struct cftype___119 *);
	s64 (*read_s64)(struct cgroup_subsys_state___119 *, struct cftype___119 *);
	int (*seq_show)(struct seq_file___3 *, void *);
	void * (*seq_start)(struct seq_file___3 *, loff_t *);
	void * (*seq_next)(struct seq_file___3 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___3 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___119 *, struct cftype___119 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___119 *, struct cftype___119 *, s64);
	ssize_t (*write)(struct kernfs_open_file___162 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___162 *, struct poll_table_struct___113 *);
};

struct bvec_iter_all___7 {
	struct bio_vec___98 bv;
	int idx;
	unsigned int done;
};

struct dev_pm_ops___128 {
	int (*prepare)(struct device___128 *);
	void (*complete)(struct device___128 *);
	int (*suspend)(struct device___128 *);
	int (*resume)(struct device___128 *);
	int (*freeze)(struct device___128 *);
	int (*thaw)(struct device___128 *);
	int (*poweroff)(struct device___128 *);
	int (*restore)(struct device___128 *);
	int (*suspend_late)(struct device___128 *);
	int (*resume_early)(struct device___128 *);
	int (*freeze_late)(struct device___128 *);
	int (*thaw_early)(struct device___128 *);
	int (*poweroff_late)(struct device___128 *);
	int (*restore_early)(struct device___128 *);
	int (*suspend_noirq)(struct device___128 *);
	int (*resume_noirq)(struct device___128 *);
	int (*freeze_noirq)(struct device___128 *);
	int (*thaw_noirq)(struct device___128 *);
	int (*poweroff_noirq)(struct device___128 *);
	int (*restore_noirq)(struct device___128 *);
	int (*runtime_suspend)(struct device___128 *);
	int (*runtime_resume)(struct device___128 *);
	int (*runtime_idle)(struct device___128 *);
};

struct wakeup_source___128 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___128 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___128 {
	struct dev_pm_ops___128 ops;
	int (*start)(struct device___128 *);
	void (*detach)(struct device___128 *, bool);
	int (*activate)(struct device___128 *);
	void (*sync)(struct device___128 *);
	void (*dismiss)(struct device___128 *);
};

struct bus_type___128 {
	const char *name;
	const char *dev_name;
	struct device___128 *dev_root;
	const struct attribute_group___162 **bus_groups;
	const struct attribute_group___162 **dev_groups;
	const struct attribute_group___162 **drv_groups;
	int (*match)(struct device___128 *, struct device_driver___128 *);
	int (*uevent)(struct device___128 *, struct kobj_uevent_env *);
	int (*probe)(struct device___128 *);
	void (*sync_state)(struct device___128 *);
	void (*remove)(struct device___128 *);
	void (*shutdown)(struct device___128 *);
	int (*online)(struct device___128 *);
	int (*offline)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	int (*num_vf)(struct device___128 *);
	int (*dma_configure)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___128 {
	const char *name;
	struct bus_type___128 *bus;
	struct module___160 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___128 *);
	void (*sync_state)(struct device___128 *);
	int (*remove)(struct device___128 *);
	void (*shutdown)(struct device___128 *);
	int (*suspend)(struct device___128 *, pm_message_t);
	int (*resume)(struct device___128 *);
	const struct attribute_group___162 **groups;
	const struct attribute_group___162 **dev_groups;
	const struct dev_pm_ops___128 *pm;
	void (*coredump)(struct device___128 *);
	struct driver_private *p;
};

struct device_type___128 {
	const char *name;
	const struct attribute_group___162 **groups;
	int (*uevent)(struct device___128 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___128 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___128 *);
	const struct dev_pm_ops___128 *pm;
};

struct class___128 {
	const char *name;
	struct module___160 *owner;
	const struct attribute_group___162 **class_groups;
	const struct attribute_group___162 **dev_groups;
	struct kobject___162 *dev_kobj;
	int (*dev_uevent)(struct device___128 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___128 *, umode_t *);
	void (*class_release)(struct class___128 *);
	void (*dev_release)(struct device___128 *);
	int (*shutdown_pre)(struct device___128 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___128 *);
	void (*get_ownership)(struct device___128 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___128 *pm;
	struct subsys_private *p;
};

struct block_device_operations___84;

struct gendisk___85 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___2 *part0;
	const struct block_device_operations___84 *fops;
	struct request_queue___83 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___80 *bdi;
	struct kobject___162 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___162 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___83 {
	struct bio___84 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___98 *bip_vec;
	struct bio_vec___98 bip_inline_vecs[0];
};

struct blkcg___80;

struct blkg_policy_data___80;

struct blkcg_gq___80 {
	struct request_queue___83 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___80 *blkcg;
	struct blkcg_gq___80 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___80 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___83 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___83(struct request___83 *);

typedef void integrity_complete_fn___83(struct request___83 *, unsigned int);

struct blk_integrity_profile___83 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___83 *prepare_fn;
	integrity_complete_fn___83 *complete_fn;
	const char *name;
};

struct block_device_operations___84 {
	blk_qc_t (*submit_bio)(struct bio___84 *);
	int (*open)(struct block_device___2 *, fmode_t);
	void (*release)(struct gendisk___85 *, fmode_t);
	int (*rw_page)(struct block_device___2 *, sector_t, struct page___181 *, unsigned int);
	int (*ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___2 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___85 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___85 *);
	int (*getgeo)(struct block_device___2 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___2 *, bool);
	void (*swap_slot_free_notify)(struct block_device___2 *, long unsigned int);
	int (*report_zones)(struct gendisk___85 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___85 *, umode_t *);
	struct module___160 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___85 *, sector_t *);
};

struct bio_alloc_cache {
	struct bio_list___83 free_list;
	unsigned int nr;
};

typedef void rq_end_io_fn___83(struct request___83 *, blk_status_t);

struct request___83 {
	struct request_queue___83 *q;
	struct blk_mq_ctx___4 *mq_ctx;
	struct blk_mq_hw_ctx___80 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___84 *bio;
	struct bio___84 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___98 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___83 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___83 *saved_end_io;
		} flush;
	};
	struct gendisk___85 *rq_disk;
	struct block_device___2 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___83 *end_io;
	void *end_io_data;
};

struct blk_mq_ctxs___4;

struct blk_mq_ctx___4 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___80 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___83 *queue;
	struct blk_mq_ctxs___4 *ctxs;
	struct kobject___162 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tags___4;

struct blk_mq_hw_ctx___80 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___83 *queue;
	struct blk_flush_queue___4 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___4 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___4 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___4 *tags;
	struct blk_mq_tags___4 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___162 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___175 *debugfs_dir;
	struct dentry___175 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___83;

struct blk_mq_alloc_data___4;

struct elevator_mq_ops___83 {
	int (*init_sched)(struct request_queue___83 *, struct elevator_type___83 *);
	void (*exit_sched)(struct elevator_queue___83 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___80 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___80 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___80 *);
	bool (*allow_merge)(struct request_queue___83 *, struct request___83 *, struct bio___84 *);
	bool (*bio_merge)(struct request_queue___83 *, struct bio___84 *, unsigned int);
	int (*request_merge)(struct request_queue___83 *, struct request___83 **, struct bio___84 *);
	void (*request_merged)(struct request_queue___83 *, struct request___83 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___83 *, struct request___83 *, struct request___83 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___4 *);
	void (*prepare_request)(struct request___83 *);
	void (*finish_request)(struct request___83 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___80 *, struct list_head *, bool);
	struct request___83 * (*dispatch_request)(struct blk_mq_hw_ctx___80 *);
	bool (*has_work)(struct blk_mq_hw_ctx___80 *);
	void (*completed_request)(struct request___83 *, u64);
	void (*requeue_request)(struct request___83 *);
	struct request___83 * (*former_request)(struct request_queue___83 *, struct request___83 *);
	struct request___83 * (*next_request)(struct request_queue___83 *, struct request___83 *);
	void (*init_icq)(struct io_cq___83 *);
	void (*exit_icq)(struct io_cq___83 *);
};

struct elv_fs_entry___83;

struct elevator_type___83 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___83 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___83 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___160 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___83 {
	struct elevator_type___83 *type;
	void *elevator_data;
	struct kobject___162 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___4 {
	struct request_queue___83 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___4 *ctx;
	struct blk_mq_hw_ctx___80 *hctx;
};

struct elv_fs_entry___83 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___83 *, char *);
	ssize_t (*store)(struct elevator_queue___83 *, const char *, size_t);
};

enum rq_qos_id {
	RQ_QOS_WBT = 0,
	RQ_QOS_LATENCY = 1,
	RQ_QOS_COST = 2,
	RQ_QOS_IOPRIO = 3,
};

struct rq_qos_ops;

struct rq_qos {
	struct rq_qos_ops *ops;
	struct request_queue___83 *q;
	enum rq_qos_id id;
	struct rq_qos *next;
	struct dentry___175 *debugfs_dir;
};

struct blk_mq_queue_data___80;

struct blk_mq_ops___80 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___80 *, const struct blk_mq_queue_data___80 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___80 *);
	int (*get_budget)(struct request_queue___83 *);
	void (*put_budget)(struct request_queue___83 *, int);
	void (*set_rq_budget_token)(struct request___83 *, int);
	int (*get_rq_budget_token)(struct request___83 *);
	enum blk_eh_timer_return (*timeout)(struct request___83 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___80 *);
	void (*complete)(struct request___83 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___80 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___80 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___80 *, struct request___83 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___80 *, struct request___83 *, unsigned int);
	void (*initialize_rq_fn)(struct request___83 *);
	void (*cleanup_rq)(struct request___83 *);
	bool (*busy)(struct request_queue___83 *);
	int (*map_queues)(struct blk_mq_tag_set___80 *);
	void (*show_rq)(struct seq_file___3 *, struct request___83 *);
};

struct blk_stat_callback___4 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___83 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___4 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___4;

struct blk_trace___3 {
	int trace_state;
	struct rchan___4 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___175 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___4 {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___83 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___80 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___80 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags___4 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_tags___4 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___83 **rqs;
	struct request___83 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

struct blk_mq_queue_data___80 {
	struct request___83 *rq;
	bool last;
};

struct blkcg_policy_data___80;

struct blkcg___80 {
	struct cgroup_subsys_state___119 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___80 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___80 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___80 {
	struct blkcg___80 *blkcg;
	int plid;
};

struct blkg_policy_data___80 {
	struct blkcg_gq___80 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___71 {
	struct mem_cgroup___71 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___71 {
	struct lruvec___78 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___71 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___71 *memcg;
};

struct obj_cgroup___71 {
	struct percpu_ref refcnt;
	struct mem_cgroup___71 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct rchan_buf___4 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___4 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___175 *dentry;
	struct kref kref;
	struct page___181 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___4;

struct rchan___4 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___4 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___4 **buf;
	int is_global;
	struct list_head list;
	struct dentry___175 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___4 {
	int (*subbuf_start)(struct rchan_buf___4 *, void *, void *, size_t);
	struct dentry___175 * (*create_buf_file)(const char *, struct dentry___175 *, umode_t, struct rchan_buf___4 *, int *);
	int (*remove_buf_file)(struct dentry___175 *);
};

struct blk_mq_ctxs___4 {
	struct kobject___162 kobj;
	struct blk_mq_ctx___4 *queue_ctx;
};

struct rq_qos_ops {
	void (*throttle)(struct rq_qos *, struct bio___84 *);
	void (*track)(struct rq_qos *, struct request___83 *, struct bio___84 *);
	void (*merge)(struct rq_qos *, struct request___83 *, struct bio___84 *);
	void (*issue)(struct rq_qos *, struct request___83 *);
	void (*requeue)(struct rq_qos *, struct request___83 *);
	void (*done)(struct rq_qos *, struct request___83 *);
	void (*done_bio)(struct rq_qos *, struct bio___84 *);
	void (*cleanup)(struct rq_qos *, struct bio___84 *);
	void (*queue_depth_changed)(struct rq_qos *);
	void (*exit)(struct rq_qos *);
	const struct blk_mq_debugfs_attr *debugfs_attrs;
};

struct biovec_slab {
	int nr_vecs;
	char *name;
	struct kmem_cache *slab;
};

struct bio_slab {
	struct kmem_cache *slab;
	unsigned int slab_ref;
	unsigned int slab_size;
	char name[8];
};

enum {
	BLK_MQ_F_SHOULD_MERGE = 1,
	BLK_MQ_F_TAG_QUEUE_SHARED = 2,
	BLK_MQ_F_STACKING = 4,
	BLK_MQ_F_TAG_HCTX_SHARED = 8,
	BLK_MQ_F_BLOCKING = 32,
	BLK_MQ_F_NO_SCHED = 64,
	BLK_MQ_F_NO_SCHED_BY_DEFAULT = 128,
	BLK_MQ_F_ALLOC_POLICY_START_BIT = 8,
	BLK_MQ_F_ALLOC_POLICY_BITS = 1,
	BLK_MQ_S_STOPPED = 0,
	BLK_MQ_S_TAG_ACTIVE = 1,
	BLK_MQ_S_SCHED_RESTART = 2,
	BLK_MQ_S_INACTIVE = 3,
	BLK_MQ_MAX_DEPTH = 10240,
	BLK_MQ_CPU_WORK_BATCH = 8,
};

enum {
	WBT_RWQ_BG = 0,
	WBT_RWQ_KSWAPD = 1,
	WBT_RWQ_DISCARD = 2,
	WBT_NUM_RWQ = 3,
};

struct dentry___176;

struct super_block___176;

struct module___161;

struct file_system_type___176 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___176 * (*mount)(struct file_system_type___176 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___176 *);
	struct module___161 *owner;
	struct file_system_type___176 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___176;

struct kiocb___176;

struct iov_iter___101;

struct poll_table_struct___114;

struct vm_area_struct___181;

struct inode___176;

struct file_lock___176;

struct page___182;

struct seq_file___153;

struct file_operations___176 {
	struct module___161 *owner;
	loff_t (*llseek)(struct file___176 *, loff_t, int);
	ssize_t (*read)(struct file___176 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___176 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___176 *, struct iov_iter___101 *);
	ssize_t (*write_iter)(struct kiocb___176 *, struct iov_iter___101 *);
	int (*iopoll)(struct kiocb___176 *, bool);
	int (*iterate)(struct file___176 *, struct dir_context *);
	int (*iterate_shared)(struct file___176 *, struct dir_context *);
	__poll_t (*poll)(struct file___176 *, struct poll_table_struct___114 *);
	long int (*unlocked_ioctl)(struct file___176 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___176 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___176 *, struct vm_area_struct___181 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___176 *, struct file___176 *);
	int (*flush)(struct file___176 *, fl_owner_t);
	int (*release)(struct inode___176 *, struct file___176 *);
	int (*fsync)(struct file___176 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___176 *, int);
	int (*lock)(struct file___176 *, int, struct file_lock___176 *);
	ssize_t (*sendpage)(struct file___176 *, struct page___182 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___176 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___176 *, long unsigned int);
	int (*flock)(struct file___176 *, int, struct file_lock___176 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___176 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___176 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___176 *, long int, struct file_lock___176 **, void **);
	long int (*fallocate)(struct file___176 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___153 *, struct file___176 *);
	ssize_t (*copy_file_range)(struct file___176 *, loff_t, struct file___176 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___176 *, loff_t, struct file___176 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___176 *, loff_t, loff_t, int);
};

struct vmacache___181 {
	u64 seqnum;
	struct vm_area_struct___181 *vmas[4];
};

struct page_frag___181 {
	struct page___182 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___71;

struct debug_info___71 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___71 *hbp_break[16];
	struct perf_event___71 *hbp_watch[16];
};

struct thread_struct___71 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___71 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___182;

struct pid___156;

struct nsproxy___165;

struct signal_struct___177;

struct bio_list___84;

struct backing_dev_info___81;

struct io_context___84;

struct css_set___120;

struct perf_event_context___71;

struct mem_cgroup___72;

struct request_queue___84;

struct vm_struct___159;

struct task_struct___183 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___183 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___182 *mm;
	struct mm_struct___182 *active_mm;
	struct vmacache___181 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___183 *real_parent;
	struct task_struct___183 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___183 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___156 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___165 *nsproxy;
	struct signal_struct___177 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___183 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___84 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___81 *backing_dev_info;
	struct io_context___84 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___120 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___71 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___181 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___72 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___72 *active_memcg;
	struct request_queue___84 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___183 *oom_reaper_list;
	struct vm_struct___159 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___71 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___163;

struct kobj_type___163;

struct kernfs_node___163;

struct kobject___163 {
	const char *name;
	struct list_head entry;
	struct kobject___163 *parent;
	struct kset___163 *kset;
	struct kobj_type___163 *ktype;
	struct kernfs_node___163 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___160 {
	struct kobject___163 kobj;
	struct module___161 *mod;
	struct kobject___163 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___160 {
	struct module___161 *mod;
	struct latch_tree_node node;
};

struct module_layout___160 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___160 mtn;
};

struct module_attribute___160;

struct kernel_param___160;

struct trace_event_call___65;

struct module___161 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___160 mkobj;
	struct module_attribute___160 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___163 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___160 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___160 core_layout;
	struct module_layout___160 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___65 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___71 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___183 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___71)(struct perf_event___71 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___71;

struct fasync_struct___176;

struct pid_namespace___156;

struct perf_cgroup___71;

struct perf_event___71 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___71 *group_leader;
	struct pmu___71 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___71 hw;
	struct perf_event_context___71 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___71 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___183 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___176 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___71 *aux_event;
	void (*destroy)(struct perf_event___71 *);
	struct callback_head callback_head;
	struct pid_namespace___156 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___71 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___71 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___65 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___71 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___156 {
	int nr;
	struct pid_namespace___156 *ns;
};

struct pid_namespace___156 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___183 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___156 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___156 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___156 numbers[1];
};

typedef struct page___182 *pgtable_t___181;

struct address_space___176;

struct dev_pagemap___171;

struct page___182 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___176 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___182 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___181 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___182 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___171 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___171;

struct vm_area_struct___181 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___181 *vm_next;
	struct vm_area_struct___181 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___182 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___171 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___176 *vm_file;
	struct file___176 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___177 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___183 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___183 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___156 *pids[4];
	struct pid___156 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___182 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___181;

struct mm_struct___182 {
	struct {
		struct vm_area_struct___181 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___176 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___181 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___183 *owner;
		struct user_namespace___25 *user_ns;
		struct file___176 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___120;

struct nsproxy___165 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___156 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___120 *cgroup_ns;
};

struct bio___85;

struct bio_list___84 {
	struct bio___85 *head;
	struct bio___85 *tail;
};

struct cgroup_subsys_state___120;

struct bdi_writeback___81 {
	struct backing_dev_info___81 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___120 *memcg_css;
	struct cgroup_subsys_state___120 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___129;

struct backing_dev_info___81 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___81 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___129 *dev;
	char dev_name[64];
	struct device___129 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___176 *debug_dir;
};

struct io_cq___84;

struct io_context___84 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___84 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___120;

struct css_set___120 {
	struct cgroup_subsys_state___120 *subsys[14];
	refcount_t refcount;
	struct css_set___120 *dom_cset;
	struct cgroup___120 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___120 *mg_src_cgrp;
	struct cgroup___120 *mg_dst_cgrp;
	struct css_set___120 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___71 {
	struct pmu___71 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___183 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___71 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___120;

struct cgroup_subsys_state___120 {
	struct cgroup___120 *cgroup;
	struct cgroup_subsys___120 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___120 *parent;
};

struct cgroup_file___120 {
	struct kernfs_node___163 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___72;

struct mem_cgroup_per_node___72;

struct mem_cgroup___72 {
	struct cgroup_subsys_state___120 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___120 events_file;
	struct cgroup_file___120 events_local_file;
	struct cgroup_file___120 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___72 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___183 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___72 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___84;

struct blk_integrity___84 {
	const struct blk_integrity_profile___84 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___84 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___84 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___84;

struct elevator_queue___84;

struct rq_qos___2;

struct blk_mq_ops___81;

struct blk_mq_ctx___5;

struct blk_mq_hw_ctx___81;

struct gendisk___86;

struct blk_stat_callback___5;

struct blkcg_gq___81;

struct blk_trace___4;

struct blk_flush_queue___5;

struct blk_mq_tag_set___81;

struct request_queue___84 {
	struct request___84 *last_merge;
	struct elevator_queue___84 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos___2 *rq_qos;
	const struct blk_mq_ops___81 *mq_ops;
	struct blk_mq_ctx___5 *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___81 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___86 *disk;
	struct kobject___163 kobj;
	struct kobject___163 *mq_kobj;
	struct blk_integrity___84 integrity;
	struct device___129 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___5 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___81 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___4 *blk_trace;
	struct blk_flush_queue___5 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___81 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___84 bio_split;
	struct dentry___176 *debugfs_dir;
	struct dentry___176 *sched_debugfs_dir;
	struct dentry___176 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___159 {
	struct vm_struct___159 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___182 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___176;

struct address_space___176 {
	struct inode___176 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___176 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___171;

struct dev_pagemap___171 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___171 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___176;

struct path___176 {
	struct vfsmount___176 *mnt;
	struct dentry___176 *dentry;
};

struct fown_struct___156 {
	rwlock_t lock;
	struct pid___156 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___176 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___176 f_path;
	struct inode___176 *f_inode;
	const struct file_operations___176 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___156 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___176 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___171;

struct vm_operations_struct___171 {
	void (*open)(struct vm_area_struct___181 *);
	void (*close)(struct vm_area_struct___181 *);
	int (*may_split)(struct vm_area_struct___181 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___181 *);
	int (*mprotect)(struct vm_area_struct___181 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___171 *);
	vm_fault_t (*huge_fault)(struct vm_fault___171 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___171 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___181 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___171 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___171 *);
	int (*access)(struct vm_area_struct___181 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___181 *);
	int (*set_policy)(struct vm_area_struct___181 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___181 *, long unsigned int);
	struct page___182 * (*find_special_page)(struct vm_area_struct___181 *, long unsigned int);
};

struct core_thread___181 {
	struct task_struct___183 *task;
	struct core_thread___181 *next;
};

struct core_state___181 {
	atomic_t nr_threads;
	struct core_thread___181 dumper;
	struct completion startup;
};

struct vm_fault___171 {
	const struct {
		struct vm_area_struct___181 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___182 *cow_page;
	struct page___182 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___181 prealloc_pte;
};

struct pglist_data___79;

struct lruvec___79 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___79 *pgdat;
};

struct zone___79 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___79 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___79 {
	struct zone___79 *zone;
	int zone_idx;
};

struct zonelist___79 {
	struct zoneref___79 _zonerefs[321];
};

struct pglist_data___79 {
	struct zone___79 node_zones[5];
	struct zonelist___79 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___183 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___183 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___79 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___176;

struct dentry___176 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___176 *d_parent;
	struct qstr d_name;
	struct inode___176 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___176 *d_op;
	struct super_block___176 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___176;

struct inode___176 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___176 *i_op;
	struct super_block___176 *i_sb;
	struct address_space___176 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___81 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___176 *i_fop;
		void (*free_inode)(struct inode___176 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___176 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___31 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___176 {
	int (*d_revalidate)(struct dentry___176 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___176 *, unsigned int);
	int (*d_hash)(const struct dentry___176 *, struct qstr *);
	int (*d_compare)(const struct dentry___176 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___176 *);
	int (*d_init)(struct dentry___176 *);
	void (*d_release)(struct dentry___176 *);
	void (*d_prune)(struct dentry___176 *);
	void (*d_iput)(struct dentry___176 *, struct inode___176 *);
	char * (*d_dname)(struct dentry___176 *, char *, int);
	struct vfsmount___176 * (*d_automount)(struct path___176 *);
	int (*d_manage)(const struct path___176 *, bool);
	struct dentry___176 * (*d_real)(struct dentry___176 *, const struct inode___176 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___176;

struct mem_dqinfo___176 {
	struct quota_format_type___176 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___176;

struct quota_info___176 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___176 *files[3];
	struct mem_dqinfo___176 info[3];
	const struct quota_format_ops___176 *ops[3];
};

struct rcuwait___177 {
	struct task_struct___183 *task;
};

struct percpu_rw_semaphore___177 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___177 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___176 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___177 rw_sem[3];
};

struct shrink_control___72;

struct shrinker___72 {
	long unsigned int (*count_objects)(struct shrinker___72 *, struct shrink_control___72 *);
	long unsigned int (*scan_objects)(struct shrinker___72 *, struct shrink_control___72 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___176;

struct dquot_operations___176;

struct quotactl_ops___176;

struct block_device___86;

struct super_block___176 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___176 *s_type;
	const struct super_operations___176 *s_op;
	const struct dquot_operations___176 *dq_op;
	const struct quotactl_ops___176 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___176 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___86 *s_bdev;
	struct backing_dev_info___81 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___176 s_dquot;
	struct sb_writers___176 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___176 *s_d_op;
	int cleancache_poolid;
	struct shrinker___72 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___176 {
	struct dentry___176 *mnt_root;
	struct super_block___176 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___72 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___72 *memcg;
};

struct psi_group___120 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___183 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___120;

struct cgroup_rstat_cpu___120;

struct cgroup___120 {
	struct cgroup_subsys_state___120 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___163 *kn;
	struct cgroup_file___120 procs_file;
	struct cgroup_file___120 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___120 *subsys[14];
	struct cgroup_root___120 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___120 *dom_cgrp;
	struct cgroup___120 *old_dom_cgrp;
	struct cgroup_rstat_cpu___120 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___120 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___84 {
	struct request_queue___84 *q;
	struct io_context___84 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct buffer_head___13;

typedef void bh_end_io_t___13(struct buffer_head___13 *, int);

struct buffer_head___13 {
	long unsigned int b_state;
	struct buffer_head___13 *b_this_page;
	struct page___182 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___86 *b_bdev;
	bh_end_io_t___13 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___176 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

struct wait_page_queue___78;

struct kiocb___176 {
	struct file___176 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___176 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___78 *ki_waitq;
	};
};

struct iattr___176 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___176 *ia_file;
};

struct dquot___176 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___176 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___176 {
	int qf_fmt_id;
	const struct quota_format_ops___176 *qf_ops;
	struct module___161 *qf_owner;
	struct quota_format_type___176 *qf_next;
};

struct quota_format_ops___176 {
	int (*check_quota_file)(struct super_block___176 *, int);
	int (*read_file_info)(struct super_block___176 *, int);
	int (*write_file_info)(struct super_block___176 *, int);
	int (*free_file_info)(struct super_block___176 *, int);
	int (*read_dqblk)(struct dquot___176 *);
	int (*commit_dqblk)(struct dquot___176 *);
	int (*release_dqblk)(struct dquot___176 *);
	int (*get_next_id)(struct super_block___176 *, struct kqid *);
};

struct dquot_operations___176 {
	int (*write_dquot)(struct dquot___176 *);
	struct dquot___176 * (*alloc_dquot)(struct super_block___176 *, int);
	void (*destroy_dquot)(struct dquot___176 *);
	int (*acquire_dquot)(struct dquot___176 *);
	int (*release_dquot)(struct dquot___176 *);
	int (*mark_dirty)(struct dquot___176 *);
	int (*write_info)(struct super_block___176 *, int);
	qsize_t * (*get_reserved_space)(struct inode___176 *);
	int (*get_projid)(struct inode___176 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___176 *, qsize_t *);
	int (*get_next_id)(struct super_block___176 *, struct kqid *);
};

struct quotactl_ops___176 {
	int (*quota_on)(struct super_block___176 *, int, int, const struct path___176 *);
	int (*quota_off)(struct super_block___176 *, int);
	int (*quota_enable)(struct super_block___176 *, unsigned int);
	int (*quota_disable)(struct super_block___176 *, unsigned int);
	int (*quota_sync)(struct super_block___176 *, int);
	int (*set_info)(struct super_block___176 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___176 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___176 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___176 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___176 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___176 *, unsigned int);
};

struct wait_page_queue___78 {
	struct page___182 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___81;

struct readahead_control___78;

struct swap_info_struct___41;

struct address_space_operations___176 {
	int (*writepage)(struct page___182 *, struct writeback_control___81 *);
	int (*readpage)(struct file___176 *, struct page___182 *);
	int (*writepages)(struct address_space___176 *, struct writeback_control___81 *);
	int (*set_page_dirty)(struct page___182 *);
	int (*readpages)(struct file___176 *, struct address_space___176 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___78 *);
	int (*write_begin)(struct file___176 *, struct address_space___176 *, loff_t, unsigned int, unsigned int, struct page___182 **, void **);
	int (*write_end)(struct file___176 *, struct address_space___176 *, loff_t, unsigned int, unsigned int, struct page___182 *, void *);
	sector_t (*bmap)(struct address_space___176 *, sector_t);
	void (*invalidatepage)(struct page___182 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___182 *, gfp_t);
	void (*freepage)(struct page___182 *);
	ssize_t (*direct_IO)(struct kiocb___176 *, struct iov_iter___101 *);
	int (*migratepage)(struct address_space___176 *, struct page___182 *, struct page___182 *, enum migrate_mode);
	bool (*isolate_page)(struct page___182 *, isolate_mode_t);
	void (*putback_page)(struct page___182 *);
	int (*launder_page)(struct page___182 *);
	int (*is_partially_uptodate)(struct page___182 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___182 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___176 *, struct page___182 *);
	int (*swap_activate)(struct swap_info_struct___41 *, struct file___176 *, sector_t *);
	void (*swap_deactivate)(struct file___176 *);
};

struct writeback_control___81 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___81 *wb;
	struct inode___176 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___78 {
	struct file___176 *file;
	struct address_space___176 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___99;

struct iov_iter___101 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___99 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___41 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___86 *bdev;
	struct file___176 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___176 {
	struct dentry___176 * (*lookup)(struct inode___176 *, struct dentry___176 *, unsigned int);
	const char * (*get_link)(struct dentry___176 *, struct inode___176 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___176 *, int);
	struct posix_acl * (*get_acl)(struct inode___176 *, int, bool);
	int (*readlink)(struct dentry___176 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___176 *, struct dentry___176 *, umode_t, bool);
	int (*link)(struct dentry___176 *, struct inode___176 *, struct dentry___176 *);
	int (*unlink)(struct inode___176 *, struct dentry___176 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___176 *, struct dentry___176 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___176 *, struct dentry___176 *, umode_t);
	int (*rmdir)(struct inode___176 *, struct dentry___176 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___176 *, struct dentry___176 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___176 *, struct dentry___176 *, struct inode___176 *, struct dentry___176 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___176 *, struct iattr___176 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___176 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___176 *, char *, size_t);
	int (*fiemap)(struct inode___176 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___176 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___176 *, struct dentry___176 *, struct file___176 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___176 *, struct dentry___176 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___176 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___176 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___176 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___176 {
	void (*fl_copy_lock)(struct file_lock___176 *, struct file_lock___176 *);
	void (*fl_release_private)(struct file_lock___176 *);
};

struct lock_manager_operations___176;

struct file_lock___176 {
	struct file_lock___176 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___176 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___176 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___176 *fl_ops;
	const struct lock_manager_operations___176 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___176 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___176 *);
	int (*lm_grant)(struct file_lock___176 *, int);
	bool (*lm_break)(struct file_lock___176 *);
	int (*lm_change)(struct file_lock___176 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___176 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___176 *);
};

struct fasync_struct___176 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___176 *fa_next;
	struct file___176 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___176 {
	struct inode___176 * (*alloc_inode)(struct super_block___176 *);
	void (*destroy_inode)(struct inode___176 *);
	void (*free_inode)(struct inode___176 *);
	void (*dirty_inode)(struct inode___176 *, int);
	int (*write_inode)(struct inode___176 *, struct writeback_control___81 *);
	int (*drop_inode)(struct inode___176 *);
	void (*evict_inode)(struct inode___176 *);
	void (*put_super)(struct super_block___176 *);
	int (*sync_fs)(struct super_block___176 *, int);
	int (*freeze_super)(struct super_block___176 *);
	int (*freeze_fs)(struct super_block___176 *);
	int (*thaw_super)(struct super_block___176 *);
	int (*unfreeze_fs)(struct super_block___176 *);
	int (*statfs)(struct dentry___176 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___176 *, int *, char *);
	void (*umount_begin)(struct super_block___176 *);
	int (*show_options)(struct seq_file___153 *, struct dentry___176 *);
	int (*show_devname)(struct seq_file___153 *, struct dentry___176 *);
	int (*show_path)(struct seq_file___153 *, struct dentry___176 *);
	int (*show_stats)(struct seq_file___153 *, struct dentry___176 *);
	ssize_t (*quota_read)(struct super_block___176 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___176 *, int, const char *, size_t, loff_t);
	struct dquot___176 ** (*get_dquots)(struct inode___176 *);
	long int (*nr_cached_objects)(struct super_block___176 *, struct shrink_control___72 *);
	long int (*free_cached_objects)(struct super_block___176 *, struct shrink_control___72 *);
	struct file___176 * (*real_loop)(struct file___176 *);
};

struct wakeup_source___129;

struct dev_pm_info___129 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___129 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___129 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___129;

struct bus_type___129;

struct device_driver___129;

struct dev_pm_domain___129;

struct fwnode_handle___129;

struct class___129;

struct attribute_group___163;

struct device___129 {
	struct kobject___163 kobj;
	struct device___129 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___129 *type;
	struct bus_type___129 *bus;
	struct device_driver___129 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___129 power;
	struct dev_pm_domain___129 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___129 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___129 *class;
	const struct attribute_group___163 **groups;
	void (*release)(struct device___129 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___86 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___176 *bd_inode;
	struct super_block___176 *bd_super;
	void *bd_claiming;
	struct device___129 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___163 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___86 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___176 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___116)(struct file___176 *, wait_queue_head_t *, struct poll_table_struct___114 *);

struct poll_table_struct___114 {
	poll_queue_proc___116 _qproc;
	__poll_t _key;
};

struct seq_operations___153;

struct seq_file___153 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___153 *op;
	int poll_event;
	const struct file___176 *file;
	void *private;
};

typedef void bio_end_io_t___84(struct bio___85 *);

struct bio_vec___99 {
	struct page___182 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___84;

struct bio___85 {
	struct bio___85 *bi_next;
	struct block_device___86 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___84 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___81 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___84 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___99 *bi_io_vec;
	struct bio_set___84 *bi_pool;
	struct bio_vec___99 bi_inline_vecs[0];
};

struct kernfs_root___163;

struct kernfs_elem_dir___163 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___163 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___163;

struct kernfs_root___163 {
	struct kernfs_node___163 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___163 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___163 {
	struct kernfs_node___163 *target_kn;
};

struct kernfs_ops___163;

struct kernfs_elem_attr___163 {
	const struct kernfs_ops___163 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___163 *notify_next;
};

struct kernfs_node___163 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___163 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___163 dir;
		struct kernfs_elem_symlink___163 symlink;
		struct kernfs_elem_attr___163 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___163;

struct kernfs_ops___163 {
	int (*open)(struct kernfs_open_file___163 *);
	void (*release)(struct kernfs_open_file___163 *);
	int (*seq_show)(struct seq_file___153 *, void *);
	void * (*seq_start)(struct seq_file___153 *, loff_t *);
	void * (*seq_next)(struct seq_file___153 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___153 *, void *);
	ssize_t (*read)(struct kernfs_open_file___163 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___163 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___163 *, struct poll_table_struct___114 *);
	int (*mmap)(struct kernfs_open_file___163 *, struct vm_area_struct___181 *);
};

struct kernfs_syscall_ops___163 {
	int (*show_options)(struct seq_file___153 *, struct kernfs_root___163 *);
	int (*mkdir)(struct kernfs_node___163 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___163 *);
	int (*rename)(struct kernfs_node___163 *, struct kernfs_node___163 *, const char *);
	int (*show_path)(struct seq_file___153 *, struct kernfs_node___163 *, struct kernfs_root___163 *);
};

struct kernfs_open_file___163 {
	struct kernfs_node___163 *kn;
	struct file___176 *file;
	struct seq_file___153 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___171 *vm_ops;
};

struct bin_attribute___163;

struct attribute_group___163 {
	const char *name;
	umode_t (*is_visible)(struct kobject___163 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___163 *, struct bin_attribute___163 *, int);
	struct attribute **attrs;
	struct bin_attribute___163 **bin_attrs;
};

struct bin_attribute___163 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___176 * (*f_mapping)();
	ssize_t (*read)(struct file___176 *, struct kobject___163 *, struct bin_attribute___163 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___176 *, struct kobject___163 *, struct bin_attribute___163 *, char *, loff_t, size_t);
	int (*mmap)(struct file___176 *, struct kobject___163 *, struct bin_attribute___163 *, struct vm_area_struct___181 *);
};

struct sysfs_ops___163 {
	ssize_t (*show)(struct kobject___163 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___163 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___163;

struct kset___163 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___163 kobj;
	const struct kset_uevent_ops___163 *uevent_ops;
};

struct kobj_type___163 {
	void (*release)(struct kobject___163 *);
	const struct sysfs_ops___163 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___163 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___163 *);
	const void * (*namespace)(struct kobject___163 *);
	void (*get_ownership)(struct kobject___163 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___163 {
	int (* const filter)(struct kset___163 *, struct kobject___163 *);
	const char * (* const name)(struct kset___163 *, struct kobject___163 *);
	int (* const uevent)(struct kset___163 *, struct kobject___163 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___160 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___160 *);
	int (*get)(char *, const struct kernel_param___160 *);
	void (*free)(void *);
};

struct kparam_array___160;

struct kernel_param___160 {
	const char *name;
	struct module___161 *mod;
	const struct kernel_param_ops___160 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___160 *arr;
	};
};

struct kparam_array___160 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___160 *ops;
	void *elem;
};

struct module_attribute___160 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___160 *, struct module_kobject___160 *, char *);
	ssize_t (*store)(struct module_attribute___160 *, struct module_kobject___160 *, const char *, size_t);
	void (*setup)(struct module___161 *, const char *);
	int (*test)(struct module___161 *);
	void (*free)(struct module___161 *);
};

struct trace_event_class___65;

struct trace_event_call___65 {
	struct list_head list;
	struct trace_event_class___65 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___65 *, struct perf_event___71 *);
};

struct dev_pagemap_ops___171 {
	void (*page_free)(struct page___182 *);
	void (*kill)(struct dev_pagemap___171 *);
	void (*cleanup)(struct dev_pagemap___171 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___171 *);
};

struct fwnode_operations___129;

struct fwnode_handle___129 {
	struct fwnode_handle___129 *secondary;
	const struct fwnode_operations___129 *ops;
	struct device___129 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___129;

struct fwnode_endpoint___129;

struct fwnode_operations___129 {
	struct fwnode_handle___129 * (*get)(struct fwnode_handle___129 *);
	void (*put)(struct fwnode_handle___129 *);
	bool (*device_is_available)(const struct fwnode_handle___129 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___129 *, const struct device___129 *);
	bool (*property_present)(const struct fwnode_handle___129 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___129 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___129 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___129 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*get_parent)(const struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*get_next_child_node)(const struct fwnode_handle___129 *, struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*get_named_child_node)(const struct fwnode_handle___129 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___129 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___129 *);
	struct fwnode_handle___129 * (*graph_get_next_endpoint)(const struct fwnode_handle___129 *, struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*graph_get_remote_endpoint)(const struct fwnode_handle___129 *);
	struct fwnode_handle___129 * (*graph_get_port_parent)(struct fwnode_handle___129 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___129 *, struct fwnode_endpoint___129 *);
	int (*add_links)(struct fwnode_handle___129 *);
};

struct fwnode_endpoint___129 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___129 *local_fwnode;
};

struct fwnode_reference_args___129 {
	struct fwnode_handle___129 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___120 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___120 *root_cset;
};

struct dev_pm_ops___129 {
	int (*prepare)(struct device___129 *);
	void (*complete)(struct device___129 *);
	int (*suspend)(struct device___129 *);
	int (*resume)(struct device___129 *);
	int (*freeze)(struct device___129 *);
	int (*thaw)(struct device___129 *);
	int (*poweroff)(struct device___129 *);
	int (*restore)(struct device___129 *);
	int (*suspend_late)(struct device___129 *);
	int (*resume_early)(struct device___129 *);
	int (*freeze_late)(struct device___129 *);
	int (*thaw_early)(struct device___129 *);
	int (*poweroff_late)(struct device___129 *);
	int (*restore_early)(struct device___129 *);
	int (*suspend_noirq)(struct device___129 *);
	int (*resume_noirq)(struct device___129 *);
	int (*freeze_noirq)(struct device___129 *);
	int (*thaw_noirq)(struct device___129 *);
	int (*poweroff_noirq)(struct device___129 *);
	int (*restore_noirq)(struct device___129 *);
	int (*runtime_suspend)(struct device___129 *);
	int (*runtime_resume)(struct device___129 *);
	int (*runtime_idle)(struct device___129 *);
};

struct wakeup_source___129 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___129 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___129 {
	struct dev_pm_ops___129 ops;
	int (*start)(struct device___129 *);
	void (*detach)(struct device___129 *, bool);
	int (*activate)(struct device___129 *);
	void (*sync)(struct device___129 *);
	void (*dismiss)(struct device___129 *);
};

struct bus_type___129 {
	const char *name;
	const char *dev_name;
	struct device___129 *dev_root;
	const struct attribute_group___163 **bus_groups;
	const struct attribute_group___163 **dev_groups;
	const struct attribute_group___163 **drv_groups;
	int (*match)(struct device___129 *, struct device_driver___129 *);
	int (*uevent)(struct device___129 *, struct kobj_uevent_env *);
	int (*probe)(struct device___129 *);
	void (*sync_state)(struct device___129 *);
	void (*remove)(struct device___129 *);
	void (*shutdown)(struct device___129 *);
	int (*online)(struct device___129 *);
	int (*offline)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	int (*num_vf)(struct device___129 *);
	int (*dma_configure)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___129 {
	const char *name;
	struct bus_type___129 *bus;
	struct module___161 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___129 *);
	void (*sync_state)(struct device___129 *);
	int (*remove)(struct device___129 *);
	void (*shutdown)(struct device___129 *);
	int (*suspend)(struct device___129 *, pm_message_t);
	int (*resume)(struct device___129 *);
	const struct attribute_group___163 **groups;
	const struct attribute_group___163 **dev_groups;
	const struct dev_pm_ops___129 *pm;
	void (*coredump)(struct device___129 *);
	struct driver_private *p;
};

struct device_type___129 {
	const char *name;
	const struct attribute_group___163 **groups;
	int (*uevent)(struct device___129 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___129 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___129 *);
	const struct dev_pm_ops___129 *pm;
};

struct class___129 {
	const char *name;
	struct module___161 *owner;
	const struct attribute_group___163 **class_groups;
	const struct attribute_group___163 **dev_groups;
	struct kobject___163 *dev_kobj;
	int (*dev_uevent)(struct device___129 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___129 *, umode_t *);
	void (*class_release)(struct class___129 *);
	void (*dev_release)(struct device___129 *);
	int (*shutdown_pre)(struct device___129 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___129 *);
	void (*get_ownership)(struct device___129 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___129 *pm;
	struct subsys_private *p;
};

struct block_device_operations___85;

struct gendisk___86 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___86 *part0;
	const struct block_device_operations___85 *fops;
	struct request_queue___84 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___81 *bdi;
	struct kobject___163 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___163 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___84 {
	struct bio___85 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___99 *bip_vec;
	struct bio_vec___99 bip_inline_vecs[0];
};

struct blkcg___81;

struct blkg_policy_data___81;

struct blkcg_gq___81 {
	struct request_queue___84 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___81 *blkcg;
	struct blkcg_gq___81 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___81 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___84 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___84(struct request___84 *);

typedef void integrity_complete_fn___84(struct request___84 *, unsigned int);

struct blk_integrity_profile___84 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___84 *prepare_fn;
	integrity_complete_fn___84 *complete_fn;
	const char *name;
};

struct block_device_operations___85 {
	blk_qc_t (*submit_bio)(struct bio___85 *);
	int (*open)(struct block_device___86 *, fmode_t);
	void (*release)(struct gendisk___86 *, fmode_t);
	int (*rw_page)(struct block_device___86 *, sector_t, struct page___182 *, unsigned int);
	int (*ioctl)(struct block_device___86 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___86 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___86 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___86 *);
	int (*getgeo)(struct block_device___86 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___86 *, bool);
	void (*swap_slot_free_notify)(struct block_device___86 *, long unsigned int);
	int (*report_zones)(struct gendisk___86 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___86 *, umode_t *);
	struct module___161 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___86 *, sector_t *);
};

typedef void rq_end_io_fn___84(struct request___84 *, blk_status_t);

struct request___84 {
	struct request_queue___84 *q;
	struct blk_mq_ctx___5 *mq_ctx;
	struct blk_mq_hw_ctx___81 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___85 *bio;
	struct bio___85 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___99 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___84 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___84 *saved_end_io;
		} flush;
	};
	struct gendisk___86 *rq_disk;
	struct block_device___86 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___84 *end_io;
	void *end_io_data;
};

struct blk_mq_ctxs___5;

struct blk_mq_ctx___5 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___81 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___84 *queue;
	struct blk_mq_ctxs___5 *ctxs;
	struct kobject___163 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tags___5;

struct blk_mq_hw_ctx___81 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___84 *queue;
	struct blk_flush_queue___5 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___5 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___5 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___5 *tags;
	struct blk_mq_tags___5 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___163 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___176 *debugfs_dir;
	struct dentry___176 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___84;

struct blk_mq_alloc_data___5;

struct elevator_mq_ops___84 {
	int (*init_sched)(struct request_queue___84 *, struct elevator_type___84 *);
	void (*exit_sched)(struct elevator_queue___84 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___81 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___81 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___81 *);
	bool (*allow_merge)(struct request_queue___84 *, struct request___84 *, struct bio___85 *);
	bool (*bio_merge)(struct request_queue___84 *, struct bio___85 *, unsigned int);
	int (*request_merge)(struct request_queue___84 *, struct request___84 **, struct bio___85 *);
	void (*request_merged)(struct request_queue___84 *, struct request___84 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___84 *, struct request___84 *, struct request___84 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___5 *);
	void (*prepare_request)(struct request___84 *);
	void (*finish_request)(struct request___84 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___81 *, struct list_head *, bool);
	struct request___84 * (*dispatch_request)(struct blk_mq_hw_ctx___81 *);
	bool (*has_work)(struct blk_mq_hw_ctx___81 *);
	void (*completed_request)(struct request___84 *, u64);
	void (*requeue_request)(struct request___84 *);
	struct request___84 * (*former_request)(struct request_queue___84 *, struct request___84 *);
	struct request___84 * (*next_request)(struct request_queue___84 *, struct request___84 *);
	void (*init_icq)(struct io_cq___84 *);
	void (*exit_icq)(struct io_cq___84 *);
};

struct elv_fs_entry___84;

struct blk_mq_debugfs_attr___2;

struct elevator_type___84 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___84 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___84 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___161 *elevator_owner;
	const struct blk_mq_debugfs_attr___2 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___2 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___84 {
	struct elevator_type___84 *type;
	void *elevator_data;
	struct kobject___163 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___5 {
	struct request_queue___84 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___5 *ctx;
	struct blk_mq_hw_ctx___81 *hctx;
};

struct elv_fs_entry___84 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___84 *, char *);
	ssize_t (*store)(struct elevator_queue___84 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___2 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___153 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___153 *seq_ops;
};

struct rq_qos_ops___2;

struct rq_qos___2 {
	struct rq_qos_ops___2 *ops;
	struct request_queue___84 *q;
	enum rq_qos_id id;
	struct rq_qos___2 *next;
	struct dentry___176 *debugfs_dir;
};

struct blk_mq_queue_data___81;

struct blk_mq_ops___81 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___81 *, const struct blk_mq_queue_data___81 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___81 *);
	int (*get_budget)(struct request_queue___84 *);
	void (*put_budget)(struct request_queue___84 *, int);
	void (*set_rq_budget_token)(struct request___84 *, int);
	int (*get_rq_budget_token)(struct request___84 *);
	enum blk_eh_timer_return (*timeout)(struct request___84 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___81 *);
	void (*complete)(struct request___84 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___81 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___81 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___81 *, struct request___84 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___81 *, struct request___84 *, unsigned int);
	void (*initialize_rq_fn)(struct request___84 *);
	void (*cleanup_rq)(struct request___84 *);
	bool (*busy)(struct request_queue___84 *);
	int (*map_queues)(struct blk_mq_tag_set___81 *);
	void (*show_rq)(struct seq_file___153 *, struct request___84 *);
};

struct blk_stat_callback___5 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___84 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___5 *);
	void *data;
	struct callback_head rcu;
};

struct rchan___5;

struct blk_trace___4 {
	int trace_state;
	struct rchan___5 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___176 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_flush_queue___5 {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___84 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___81 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___81 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags___5 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct req_iterator {
	struct bvec_iter iter;
	struct bio___85 *bio;
};

struct blk_plug_cb;

typedef void (*blk_plug_cb_fn)(struct blk_plug_cb *, bool);

struct blk_plug_cb {
	struct list_head list;
	blk_plug_cb_fn callback;
	void *data;
};

struct blk_mq_tags___5 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___84 **rqs;
	struct request___84 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

struct blk_mq_queue_data___81 {
	struct request___84 *rq;
	bool last;
};

enum {
	BLK_MQ_REQ_NOWAIT = 1,
	BLK_MQ_REQ_RESERVED = 2,
	BLK_MQ_REQ_PM = 4,
};

struct seq_operations___153 {
	void * (*start)(struct seq_file___153 *, loff_t *);
	void (*stop)(struct seq_file___153 *, void *);
	void * (*next)(struct seq_file___153 *, void *, loff_t *);
	int (*show)(struct seq_file___153 *, void *);
};

struct cftype___120;

struct cgroup_subsys___120 {
	struct cgroup_subsys_state___120 * (*css_alloc)(struct cgroup_subsys_state___120 *);
	int (*css_online)(struct cgroup_subsys_state___120 *);
	void (*css_offline)(struct cgroup_subsys_state___120 *);
	void (*css_released)(struct cgroup_subsys_state___120 *);
	void (*css_free)(struct cgroup_subsys_state___120 *);
	void (*css_reset)(struct cgroup_subsys_state___120 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___120 *, int);
	int (*css_extra_stat_show)(struct seq_file___153 *, struct cgroup_subsys_state___120 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___183 *, struct css_set___120 *);
	void (*cancel_fork)(struct task_struct___183 *, struct css_set___120 *);
	void (*fork)(struct task_struct___183 *);
	void (*exit)(struct task_struct___183 *);
	void (*release)(struct task_struct___183 *);
	void (*bind)(struct cgroup_subsys_state___120 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___120 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___120 *dfl_cftypes;
	struct cftype___120 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___120 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___120 *updated_children;
	struct cgroup___120 *updated_next;
};

struct cgroup_root___120 {
	struct kernfs_root___163 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___120 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___120 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___120 *ss;
	struct list_head node;
	struct kernfs_ops___163 *kf_ops;
	int (*open)(struct kernfs_open_file___163 *);
	void (*release)(struct kernfs_open_file___163 *);
	u64 (*read_u64)(struct cgroup_subsys_state___120 *, struct cftype___120 *);
	s64 (*read_s64)(struct cgroup_subsys_state___120 *, struct cftype___120 *);
	int (*seq_show)(struct seq_file___153 *, void *);
	void * (*seq_start)(struct seq_file___153 *, loff_t *);
	void * (*seq_next)(struct seq_file___153 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___153 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___120 *, struct cftype___120 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___120 *, struct cftype___120 *, s64);
	ssize_t (*write)(struct kernfs_open_file___163 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___163 *, struct poll_table_struct___114 *);
};

struct blkcg_policy_data___81;

struct blkcg___81 {
	struct cgroup_subsys_state___120 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___81 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___81 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___81 {
	struct blkcg___81 *blkcg;
	int plid;
};

struct blkg_policy_data___81 {
	struct blkcg_gq___81 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___72 {
	struct mem_cgroup___72 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___72 {
	struct lruvec___79 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___72 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___72 *memcg;
};

struct obj_cgroup___72 {
	struct percpu_ref refcnt;
	struct mem_cgroup___72 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct rchan_buf___5 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___5 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___176 *dentry;
	struct kref kref;
	struct page___182 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___5;

struct rchan___5 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___5 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___5 **buf;
	int is_global;
	struct list_head list;
	struct dentry___176 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___5 {
	int (*subbuf_start)(struct rchan_buf___5 *, void *, void *, size_t);
	struct dentry___176 * (*create_buf_file)(const char *, struct dentry___176 *, umode_t, struct rchan_buf___5 *, int *);
	int (*remove_buf_file)(struct dentry___176 *);
};

struct perf_cpu_context___71;

struct perf_output_handle___71;

struct pmu___71 {
	struct list_head entry;
	struct module___161 *module;
	struct device___129 *dev;
	const struct attribute_group___163 **attr_groups;
	const struct attribute_group___163 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___71 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___71 *);
	void (*pmu_disable)(struct pmu___71 *);
	int (*event_init)(struct perf_event___71 *);
	void (*event_mapped)(struct perf_event___71 *, struct mm_struct___182 *);
	void (*event_unmapped)(struct perf_event___71 *, struct mm_struct___182 *);
	int (*add)(struct perf_event___71 *, int);
	void (*del)(struct perf_event___71 *, int);
	void (*start)(struct perf_event___71 *, int);
	void (*stop)(struct perf_event___71 *, int);
	void (*read)(struct perf_event___71 *);
	void (*start_txn)(struct pmu___71 *, unsigned int);
	int (*commit_txn)(struct pmu___71 *);
	void (*cancel_txn)(struct pmu___71 *);
	int (*event_idx)(struct perf_event___71 *);
	void (*sched_task)(struct perf_event_context___71 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___71 *, struct perf_event_context___71 *);
	void * (*setup_aux)(struct perf_event___71 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___71 *, struct perf_output_handle___71 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___71 *);
	int (*aux_output_match)(struct perf_event___71 *);
	int (*filter_match)(struct perf_event___71 *);
	int (*check_period)(struct perf_event___71 *, u64);
};

struct perf_cpu_context___71 {
	struct perf_event_context___71 ctx;
	struct perf_event_context___71 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___71 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___71 **heap;
	struct perf_event___71 *heap_default[2];
};

struct perf_output_handle___71 {
	struct perf_event___71 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___71 {
	struct cgroup_subsys_state___120 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___65 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___65 *);
	};
};

struct trace_event_class___65 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___65 *, enum trace_reg, void *);
	struct trace_event_fields___65 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___65 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___65 *);
};

struct trace_event_file___28;

struct trace_event_buffer___27 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___28 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___28 {
	struct list_head list;
	struct trace_event_call___65 *event_call;
	struct event_filter *filter;
	struct dentry___176 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_block_buffer {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	size_t size;
	char __data[0];
};

struct trace_event_raw_block_rq_requeue {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	u32 __data_loc_cmd;
	char __data[0];
};

struct trace_event_raw_block_rq_complete {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int error;
	char rwbs[8];
	u32 __data_loc_cmd;
	char __data[0];
};

struct trace_event_raw_block_rq {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	unsigned int bytes;
	char rwbs[8];
	char comm[16];
	u32 __data_loc_cmd;
	char __data[0];
};

struct trace_event_raw_block_bio_complete {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	int error;
	char rwbs[8];
	char __data[0];
};

struct trace_event_raw_block_bio {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_plug {
	struct trace_entry ent;
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_unplug {
	struct trace_entry ent;
	int nr_rq;
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_split {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	sector_t new_sector;
	char rwbs[8];
	char comm[16];
	char __data[0];
};

struct trace_event_raw_block_bio_remap {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	dev_t old_dev;
	sector_t old_sector;
	char rwbs[8];
	char __data[0];
};

struct trace_event_raw_block_rq_remap {
	struct trace_entry ent;
	dev_t dev;
	sector_t sector;
	unsigned int nr_sector;
	dev_t old_dev;
	sector_t old_sector;
	unsigned int nr_bios;
	char rwbs[8];
	char __data[0];
};

struct trace_event_data_offsets_block_buffer {};

struct trace_event_data_offsets_block_rq_requeue {
	u32 cmd;
};

struct trace_event_data_offsets_block_rq_complete {
	u32 cmd;
};

struct trace_event_data_offsets_block_rq {
	u32 cmd;
};

struct trace_event_data_offsets_block_bio_complete {};

struct trace_event_data_offsets_block_bio {};

struct trace_event_data_offsets_block_plug {};

struct trace_event_data_offsets_block_unplug {};

struct trace_event_data_offsets_block_split {};

struct trace_event_data_offsets_block_bio_remap {};

struct trace_event_data_offsets_block_rq_remap {};

typedef void (*btf_trace_block_touch_buffer)(void *, struct buffer_head___13 *);

typedef void (*btf_trace_block_dirty_buffer)(void *, struct buffer_head___13 *);

typedef void (*btf_trace_block_rq_requeue)(void *, struct request___84 *);

typedef void (*btf_trace_block_rq_complete)(void *, struct request___84 *, int, unsigned int);

typedef void (*btf_trace_block_rq_insert)(void *, struct request___84 *);

typedef void (*btf_trace_block_rq_issue)(void *, struct request___84 *);

typedef void (*btf_trace_block_rq_merge)(void *, struct request___84 *);

typedef void (*btf_trace_block_bio_complete)(void *, struct request_queue___84 *, struct bio___85 *);

typedef void (*btf_trace_block_bio_bounce)(void *, struct bio___85 *);

typedef void (*btf_trace_block_bio_backmerge)(void *, struct bio___85 *);

typedef void (*btf_trace_block_bio_frontmerge)(void *, struct bio___85 *);

typedef void (*btf_trace_block_bio_queue)(void *, struct bio___85 *);

typedef void (*btf_trace_block_getrq)(void *, struct bio___85 *);

typedef void (*btf_trace_block_plug)(void *, struct request_queue___84 *);

typedef void (*btf_trace_block_unplug)(void *, struct request_queue___84 *, unsigned int, bool);

typedef void (*btf_trace_block_split)(void *, struct bio___85 *, unsigned int);

typedef void (*btf_trace_block_bio_remap)(void *, struct bio___85 *, dev_t, sector_t);

typedef void (*btf_trace_block_rq_remap)(void *, struct request___84 *, dev_t, sector_t);

enum {
	BLK_MQ_NO_TAG = 4294967295,
	BLK_MQ_TAG_MIN = 1,
	BLK_MQ_TAG_MAX = 4294967294,
};

struct blk_mq_ctxs___5 {
	struct kobject___163 kobj;
	struct blk_mq_ctx___5 *queue_ctx;
};

struct rq_qos_ops___2 {
	void (*throttle)(struct rq_qos___2 *, struct bio___85 *);
	void (*track)(struct rq_qos___2 *, struct request___84 *, struct bio___85 *);
	void (*merge)(struct rq_qos___2 *, struct request___84 *, struct bio___85 *);
	void (*issue)(struct rq_qos___2 *, struct request___84 *);
	void (*requeue)(struct rq_qos___2 *, struct request___84 *);
	void (*done)(struct rq_qos___2 *, struct request___84 *);
	void (*done_bio)(struct rq_qos___2 *, struct bio___85 *);
	void (*cleanup)(struct rq_qos___2 *, struct bio___85 *);
	void (*queue_depth_changed)(struct rq_qos___2 *);
	void (*exit)(struct rq_qos___2 *);
	const struct blk_mq_debugfs_attr___2 *debugfs_attrs;
};

struct queue_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct request_queue___83 *, char *);
	ssize_t (*store)(struct request_queue___83 *, const char *, size_t);
};

enum {
	REQ_FSEQ_PREFLUSH = 1,
	REQ_FSEQ_DATA = 2,
	REQ_FSEQ_POSTFLUSH = 4,
	REQ_FSEQ_DONE = 8,
	REQ_FSEQ_ACTIONS = 7,
	FLUSH_PENDING_TIMEOUT = 1250,
};

enum {
	ICQ_EXITED = 4,
	ICQ_DESTROYED = 8,
};

struct rq_map_data {
	struct page___181 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct bio_map_data {
	bool is_our_pages: 1;
	bool is_null_mapped: 1;
	struct iov_iter___100 iter;
	struct iovec iov[0];
};

struct req_iterator___2 {
	struct bvec_iter iter;
	struct bio___84 *bio;
};

enum bio_merge_status {
	BIO_MERGE_OK = 0,
	BIO_MERGE_NONE = 1,
	BIO_MERGE_FAILED = 2,
};

struct hrtimer_sleeper___5 {
	struct hrtimer timer;
	struct task_struct___182 *task;
};

typedef bool (*sb_for_each_fn)(struct sbitmap *, unsigned int, void *);

typedef bool busy_iter_fn(struct blk_mq_hw_ctx___80 *, struct request___83 *, void *, bool);

typedef bool busy_tag_iter_fn(struct request___83 *, void *, bool);

enum {
	BLK_MQ_UNIQUE_TAG_BITS = 16,
	BLK_MQ_UNIQUE_TAG_MASK = 65535,
};

struct mq_inflight {
	struct block_device___2 *part;
	unsigned int inflight[2];
};

struct flush_busy_ctx_data {
	struct blk_mq_hw_ctx___80 *hctx;
	struct list_head *list;
};

struct dispatch_rq_data {
	struct blk_mq_hw_ctx___80 *hctx;
	struct request___83 *rq;
};

enum prep_dispatch {
	PREP_DISPATCH_OK = 0,
	PREP_DISPATCH_NO_TAG = 1,
	PREP_DISPATCH_NO_BUDGET = 2,
};

struct rq_iter_data {
	struct blk_mq_hw_ctx___80 *hctx;
	bool has_rq;
};

struct blk_mq_qe_pair {
	struct list_head node;
	struct request_queue___83 *q;
	struct elevator_type___83 *type;
};

struct sbq_wait {
	struct sbitmap_queue *sbq;
	struct wait_queue_entry wait;
};

struct bt_iter_data {
	struct blk_mq_hw_ctx___80 *hctx;
	busy_iter_fn *fn;
	void *data;
	bool reserved;
};

struct bt_tags_iter_data {
	struct blk_mq_tags___4 *tags;
	busy_tag_iter_fn *fn;
	void *data;
	unsigned int flags;
};

struct blk_queue_stats {
	struct list_head callbacks;
	spinlock_t lock;
	bool enable_accounting;
};

struct blk_mq_hw_ctx_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_mq_hw_ctx___80 *, char *);
	ssize_t (*store)(struct blk_mq_hw_ctx___80 *, const char *, size_t);
};

typedef u32 compat_caddr_t;

struct hd_geometry {
	unsigned char heads;
	unsigned char sectors;
	short unsigned int cylinders;
	long unsigned int start;
};

struct blkpg_ioctl_arg {
	int op;
	int flags;
	int datalen;
	void *data;
};

struct blkpg_partition {
	long long int start;
	long long int length;
	int pno;
	char devname[64];
	char volname[64];
};

struct pr_reservation {
	__u64 key;
	__u32 type;
	__u32 flags;
};

struct pr_registration {
	__u64 old_key;
	__u64 new_key;
	__u32 flags;
	__u32 __pad;
};

struct pr_preempt {
	__u64 old_key;
	__u64 new_key;
	__u32 type;
	__u32 flags;
};

struct pr_clear {
	__u64 key;
	__u32 flags;
	__u32 __pad;
};

struct compat_blkpg_ioctl_arg {
	compat_int_t op;
	compat_int_t flags;
	compat_int_t datalen;
	compat_caddr_t data;
};

struct compat_hd_geometry {
	unsigned char heads;
	unsigned char sectors;
	short unsigned int cylinders;
	u32 start;
};

struct klist_node;

struct klist {
	spinlock_t k_lock;
	struct list_head k_list;
	void (*get)(struct klist_node *);
	void (*put)(struct klist_node *);
};

struct klist_node {
	void *n_klist;
	struct list_head n_node;
	struct kref n_ref;
};

struct klist_iter {
	struct klist *i_klist;
	struct klist_node *i_cur;
};

struct class_dev_iter {
	struct klist_iter ki;
	const struct device_type___128 *type;
};

struct badblocks {
	struct device___128 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

struct blk_major_name {
	struct blk_major_name *next;
	int major;
	char name[16];
	void (*probe)(dev_t);
};

enum {
	IOPRIO_WHO_PROCESS = 1,
	IOPRIO_WHO_PGRP = 2,
	IOPRIO_WHO_USER = 3,
};

typedef int (*key_restrict_link_func_t___20)(struct key___6 *, const struct key_type *, const union key_payload *, struct key___6 *);

typedef void (*poll_queue_proc___117)(struct file___149 *, wait_queue_head_t *, struct poll_table_struct___5 *);

typedef int filler_t___7(void *, struct page___181 *);

struct parsed_partitions {
	struct gendisk___85 *disk;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

typedef struct {
	struct page___181 *v;
} Sector;

struct RigidDiskBlock {
	__u32 rdb_ID;
	__be32 rdb_SummedLongs;
	__s32 rdb_ChkSum;
	__u32 rdb_HostID;
	__be32 rdb_BlockBytes;
	__u32 rdb_Flags;
	__u32 rdb_BadBlockList;
	__be32 rdb_PartitionList;
	__u32 rdb_FileSysHeaderList;
	__u32 rdb_DriveInit;
	__u32 rdb_Reserved1[6];
	__u32 rdb_Cylinders;
	__u32 rdb_Sectors;
	__u32 rdb_Heads;
	__u32 rdb_Interleave;
	__u32 rdb_Park;
	__u32 rdb_Reserved2[3];
	__u32 rdb_WritePreComp;
	__u32 rdb_ReducedWrite;
	__u32 rdb_StepRate;
	__u32 rdb_Reserved3[5];
	__u32 rdb_RDBBlocksLo;
	__u32 rdb_RDBBlocksHi;
	__u32 rdb_LoCylinder;
	__u32 rdb_HiCylinder;
	__u32 rdb_CylBlocks;
	__u32 rdb_AutoParkSeconds;
	__u32 rdb_HighRDSKBlock;
	__u32 rdb_Reserved4;
	char rdb_DiskVendor[8];
	char rdb_DiskProduct[16];
	char rdb_DiskRevision[4];
	char rdb_ControllerVendor[8];
	char rdb_ControllerProduct[16];
	char rdb_ControllerRevision[4];
	__u32 rdb_Reserved5[10];
};

struct PartitionBlock {
	__be32 pb_ID;
	__be32 pb_SummedLongs;
	__s32 pb_ChkSum;
	__u32 pb_HostID;
	__be32 pb_Next;
	__u32 pb_Flags;
	__u32 pb_Reserved1[2];
	__u32 pb_DevFlags;
	__u8 pb_DriveName[32];
	__u32 pb_Reserved2[15];
	__be32 pb_Environment[17];
	__u32 pb_EReserved[15];
};

struct partition_info {
	u8 flg;
	char id[3];
	__be32 st;
	__be32 siz;
};

struct rootsector {
	char unused[342];
	struct partition_info icdpart[8];
	char unused2[12];
	u32 hd_siz;
	struct partition_info part[4];
	u32 bsl_st;
	u32 bsl_cnt;
	u16 checksum;
} __attribute__((packed));

struct lvm_rec {
	char lvm_id[4];
	char reserved4[16];
	__be32 lvmarea_len;
	__be32 vgda_len;
	__be32 vgda_psn[2];
	char reserved36[10];
	__be16 pp_size;
	char reserved46[12];
	__be16 version;
};

struct vgda {
	__be32 secs;
	__be32 usec;
	char reserved8[16];
	__be16 numlvs;
	__be16 maxlvs;
	__be16 pp_size;
	__be16 numpvs;
	__be16 total_vgdas;
	__be16 vgda_size;
};

struct lvd {
	__be16 lv_ix;
	__be16 res2;
	__be16 res4;
	__be16 maxsize;
	__be16 lv_state;
	__be16 mirror;
	__be16 mirror_policy;
	__be16 num_lps;
	__be16 res10[8];
};

struct lvname {
	char name[64];
};

struct ppe {
	__be16 lv_ix;
	short unsigned int res2;
	short unsigned int res4;
	__be16 lp_ix;
	short unsigned int res8[12];
};

struct pvd {
	char reserved0[16];
	__be16 pp_count;
	char reserved18[2];
	__be32 psn_part1;
	char reserved24[8];
	struct ppe ppe[1016];
};

struct lv_info {
	short unsigned int pps_per_lv;
	short unsigned int pps_found;
	unsigned char lv_is_contiguous;
};

struct cmdline_subpart {
	char name[32];
	sector_t from;
	sector_t size;
	int flags;
	struct cmdline_subpart *next_subpart;
};

struct cmdline_parts {
	char name[32];
	unsigned int nr_subparts;
	struct cmdline_subpart *subpart;
	struct cmdline_parts *next_parts;
};

struct mac_partition {
	__be16 signature;
	__be16 res1;
	__be32 map_count;
	__be32 start_block;
	__be32 block_count;
	char name[32];
	char type[32];
	__be32 data_start;
	__be32 data_count;
	__be32 status;
	__be32 boot_start;
	__be32 boot_size;
	__be32 boot_load;
	__be32 boot_load2;
	__be32 boot_entry;
	__be32 boot_entry2;
	__be32 boot_cksum;
	char processor[16];
};

struct mac_driver_desc {
	__be16 signature;
	__be16 block_size;
	__be32 block_count;
};

struct msdos_partition {
	u8 boot_ind;
	u8 head;
	u8 sector;
	u8 cyl;
	u8 sys_ind;
	u8 end_head;
	u8 end_sector;
	u8 end_cyl;
	__le32 start_sect;
	__le32 nr_sects;
};

struct frag {
	struct list_head list;
	u32 group;
	u8 num;
	u8 rec;
	u8 map;
	u8 data[0];
};

struct privhead {
	u16 ver_major;
	u16 ver_minor;
	u64 logical_disk_start;
	u64 logical_disk_size;
	u64 config_start;
	u64 config_size;
	uuid_t disk_id;
};

struct tocblock {
	u8 bitmap1_name[16];
	u64 bitmap1_start;
	u64 bitmap1_size;
	u8 bitmap2_name[16];
	u64 bitmap2_start;
	u64 bitmap2_size;
};

struct vmdb {
	u16 ver_major;
	u16 ver_minor;
	u32 vblk_size;
	u32 vblk_offset;
	u32 last_vblk_seq;
};

struct vblk_comp {
	u8 state[16];
	u64 parent_id;
	u8 type;
	u8 children;
	u16 chunksize;
};

struct vblk_dgrp {
	u8 disk_id[64];
};

struct vblk_disk {
	uuid_t disk_id;
	u8 alt_name[128];
};

struct vblk_part {
	u64 start;
	u64 size;
	u64 volume_offset;
	u64 parent_id;
	u64 disk_id;
	u8 partnum;
};

struct vblk_volu {
	u8 volume_type[16];
	u8 volume_state[16];
	u8 guid[16];
	u8 drive_hint[4];
	u64 size;
	u8 partition_type;
};

struct vblk {
	u8 name[64];
	u64 obj_id;
	u32 sequence;
	u8 flags;
	u8 type;
	union {
		struct vblk_comp comp;
		struct vblk_dgrp dgrp;
		struct vblk_disk disk;
		struct vblk_part part;
		struct vblk_volu volu;
	} vblk;
	struct list_head list;
};

struct ldmdb {
	struct privhead ph;
	struct tocblock toc;
	struct vmdb vm;
	struct list_head v_dgrp;
	struct list_head v_disk;
	struct list_head v_volu;
	struct list_head v_comp;
	struct list_head v_part;
};

enum msdos_sys_ind {
	DOS_EXTENDED_PARTITION = 5,
	LINUX_EXTENDED_PARTITION = 133,
	WIN98_EXTENDED_PARTITION = 15,
	LINUX_DATA_PARTITION = 131,
	LINUX_LVM_PARTITION = 142,
	LINUX_RAID_PARTITION = 253,
	SOLARIS_X86_PARTITION = 130,
	NEW_SOLARIS_X86_PARTITION = 191,
	DM6_AUX1PARTITION = 81,
	DM6_AUX3PARTITION = 83,
	DM6_PARTITION = 84,
	EZD_PARTITION = 85,
	FREEBSD_PARTITION = 165,
	OPENBSD_PARTITION = 166,
	NETBSD_PARTITION = 169,
	BSDI_PARTITION = 183,
	MINIX_PARTITION = 129,
	UNIXWARE_PARTITION = 99,
};

struct dentry___177;

struct super_block___177;

struct module___162;

struct file_system_type___177 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___177 * (*mount)(struct file_system_type___177 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___177 *);
	struct module___162 *owner;
	struct file_system_type___177 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___177;

struct kiocb___177;

struct iov_iter___102;

struct poll_table_struct___115;

struct vm_area_struct___182;

struct inode___177;

struct file_lock___177;

struct page___183;

struct seq_file___154;

struct file_operations___177 {
	struct module___162 *owner;
	loff_t (*llseek)(struct file___177 *, loff_t, int);
	ssize_t (*read)(struct file___177 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___177 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___177 *, struct iov_iter___102 *);
	ssize_t (*write_iter)(struct kiocb___177 *, struct iov_iter___102 *);
	int (*iopoll)(struct kiocb___177 *, bool);
	int (*iterate)(struct file___177 *, struct dir_context *);
	int (*iterate_shared)(struct file___177 *, struct dir_context *);
	__poll_t (*poll)(struct file___177 *, struct poll_table_struct___115 *);
	long int (*unlocked_ioctl)(struct file___177 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___177 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___177 *, struct vm_area_struct___182 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___177 *, struct file___177 *);
	int (*flush)(struct file___177 *, fl_owner_t);
	int (*release)(struct inode___177 *, struct file___177 *);
	int (*fsync)(struct file___177 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___177 *, int);
	int (*lock)(struct file___177 *, int, struct file_lock___177 *);
	ssize_t (*sendpage)(struct file___177 *, struct page___183 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___177 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___177 *, long unsigned int);
	int (*flock)(struct file___177 *, int, struct file_lock___177 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___177 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___177 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___177 *, long int, struct file_lock___177 **, void **);
	long int (*fallocate)(struct file___177 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___154 *, struct file___177 *);
	ssize_t (*copy_file_range)(struct file___177 *, loff_t, struct file___177 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___177 *, loff_t, struct file___177 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___177 *, loff_t, loff_t, int);
};

struct vmacache___182 {
	u64 seqnum;
	struct vm_area_struct___182 *vmas[4];
};

struct page_frag___182 {
	struct page___183 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___183;

struct pid___157;

struct nsproxy___166;

struct signal_struct___178;

struct bio_list___85;

struct io_context___85;

struct request_queue___85;

struct vm_struct___160;

struct task_struct___184 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___184 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___183 *mm;
	struct mm_struct___183 *active_mm;
	struct vmacache___182 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___184 *real_parent;
	struct task_struct___184 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___184 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___157 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___166 *nsproxy;
	struct signal_struct___178 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___184 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___85 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___85 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___182 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___85 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___184 *oom_reaper_list;
	struct vm_struct___160 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___71 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___164;

struct kobj_type___164;

struct kernfs_node___164;

struct kobject___164 {
	const char *name;
	struct list_head entry;
	struct kobject___164 *parent;
	struct kset___164 *kset;
	struct kobj_type___164 *ktype;
	struct kernfs_node___164 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___161 {
	struct kobject___164 kobj;
	struct module___162 *mod;
	struct kobject___164 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___161 {
	struct module___162 *mod;
	struct latch_tree_node node;
};

struct module_layout___161 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___161 mtn;
};

struct module_attribute___161;

struct kernel_param___161;

struct module___162 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___161 mkobj;
	struct module_attribute___161 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___164 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___161 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___161 core_layout;
	struct module_layout___161 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___183 *pgtable_t___182;

struct address_space___177;

struct dev_pagemap___172;

struct page___183 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___177 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___183 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___182 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___183 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___172 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___172;

struct vm_area_struct___182 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___182 *vm_next;
	struct vm_area_struct___182 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___183 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___172 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___177 *vm_file;
	struct file___177 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___182;

struct mm_struct___183 {
	struct {
		struct vm_area_struct___182 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___177 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___182 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___184 *owner;
		struct user_namespace *user_ns;
		struct file___177 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___177;

struct address_space___177 {
	struct inode___177 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___177 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___172;

struct dev_pagemap___172 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___172 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___177;

struct path___177 {
	struct vfsmount___177 *mnt;
	struct dentry___177 *dentry;
};

struct fown_struct___157 {
	rwlock_t lock;
	struct pid___157 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___177 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___177 f_path;
	struct inode___177 *f_inode;
	const struct file_operations___177 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___157 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___177 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___172;

struct vm_operations_struct___172 {
	void (*open)(struct vm_area_struct___182 *);
	void (*close)(struct vm_area_struct___182 *);
	int (*may_split)(struct vm_area_struct___182 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___182 *);
	int (*mprotect)(struct vm_area_struct___182 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___172 *);
	vm_fault_t (*huge_fault)(struct vm_fault___172 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___172 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___182 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___172 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___172 *);
	int (*access)(struct vm_area_struct___182 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___182 *);
	int (*set_policy)(struct vm_area_struct___182 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___182 *, long unsigned int);
	struct page___183 * (*find_special_page)(struct vm_area_struct___182 *, long unsigned int);
};

struct core_thread___182 {
	struct task_struct___184 *task;
	struct core_thread___182 *next;
};

struct core_state___182 {
	atomic_t nr_threads;
	struct core_thread___182 dumper;
	struct completion startup;
};

struct vm_fault___172 {
	const struct {
		struct vm_area_struct___182 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___183 *cow_page;
	struct page___183 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___182 prealloc_pte;
};

struct dev_pagemap_ops___172 {
	void (*page_free)(struct page___183 *);
	void (*kill)(struct dev_pagemap___172 *);
	void (*cleanup)(struct dev_pagemap___172 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___172 *);
};

struct pid_namespace___157;

struct upid___157 {
	int nr;
	struct pid_namespace___157 *ns;
};

struct pid_namespace___157 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___184 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___157 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___157 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___157 numbers[1];
};

struct signal_struct___178 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___184 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___184 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___157 *pids[4];
	struct pid___157 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___183 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___166 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___157 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___86;

struct bio_list___85 {
	struct bio___86 *head;
	struct bio___86 *tail;
};

struct io_cq___85;

struct io_context___85 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___85 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___85;

struct blk_integrity___85 {
	const struct blk_integrity_profile___85 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___85 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___85 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___85;

struct elevator_queue___85;

struct blk_mq_ops___82;

struct blk_mq_ctx___6;

struct blk_mq_hw_ctx___82;

struct gendisk___87;

struct device___130;

struct blk_stat_callback___6;

struct blk_flush_queue___6;

struct blk_mq_tag_set___82;

struct request_queue___85 {
	struct request___85 *last_merge;
	struct elevator_queue___85 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___82 *mq_ops;
	struct blk_mq_ctx___6 *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___82 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___87 *disk;
	struct kobject___164 kobj;
	struct kobject___164 *mq_kobj;
	struct blk_integrity___85 integrity;
	struct device___130 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___6 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue___6 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___82 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___85 bio_split;
	struct dentry___177 *debugfs_dir;
	struct dentry___177 *sched_debugfs_dir;
	struct dentry___177 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___160 {
	struct vm_struct___160 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___183 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___177;

struct dentry___177 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___177 *d_parent;
	struct qstr d_name;
	struct inode___177 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___177 *d_op;
	struct super_block___177 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___177;

struct cdev___32;

struct inode___177 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___177 *i_op;
	struct super_block___177 *i_sb;
	struct address_space___177 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___177 *i_fop;
		void (*free_inode)(struct inode___177 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___177 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___32 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___177 {
	int (*d_revalidate)(struct dentry___177 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___177 *, unsigned int);
	int (*d_hash)(const struct dentry___177 *, struct qstr *);
	int (*d_compare)(const struct dentry___177 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___177 *);
	int (*d_init)(struct dentry___177 *);
	void (*d_release)(struct dentry___177 *);
	void (*d_prune)(struct dentry___177 *);
	void (*d_iput)(struct dentry___177 *, struct inode___177 *);
	char * (*d_dname)(struct dentry___177 *, char *, int);
	struct vfsmount___177 * (*d_automount)(struct path___177 *);
	int (*d_manage)(const struct path___177 *, bool);
	struct dentry___177 * (*d_real)(struct dentry___177 *, const struct inode___177 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___177;

struct mem_dqinfo___177 {
	struct quota_format_type___177 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___177;

struct quota_info___177 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___177 *files[3];
	struct mem_dqinfo___177 info[3];
	const struct quota_format_ops___177 *ops[3];
};

struct rcuwait___178 {
	struct task_struct___184 *task;
};

struct percpu_rw_semaphore___178 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___178 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___177 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___178 rw_sem[3];
};

struct super_operations___177;

struct dquot_operations___177;

struct quotactl_ops___177;

struct block_device___87;

struct super_block___177 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___177 *s_type;
	const struct super_operations___177 *s_op;
	const struct dquot_operations___177 *dq_op;
	const struct quotactl_ops___177 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___177 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___87 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___177 s_dquot;
	struct sb_writers___177 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___177 *s_d_op;
	int cleancache_poolid;
	struct shrinker___72 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___177 {
	struct dentry___177 *mnt_root;
	struct super_block___177 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___85 {
	struct request_queue___85 *q;
	struct io_context___85 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___79;

struct kiocb___177 {
	struct file___177 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___177 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___79 *ki_waitq;
	};
};

struct iattr___177 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___177 *ia_file;
};

struct dquot___177 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___177 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___177 {
	int qf_fmt_id;
	const struct quota_format_ops___177 *qf_ops;
	struct module___162 *qf_owner;
	struct quota_format_type___177 *qf_next;
};

struct quota_format_ops___177 {
	int (*check_quota_file)(struct super_block___177 *, int);
	int (*read_file_info)(struct super_block___177 *, int);
	int (*write_file_info)(struct super_block___177 *, int);
	int (*free_file_info)(struct super_block___177 *, int);
	int (*read_dqblk)(struct dquot___177 *);
	int (*commit_dqblk)(struct dquot___177 *);
	int (*release_dqblk)(struct dquot___177 *);
	int (*get_next_id)(struct super_block___177 *, struct kqid *);
};

struct dquot_operations___177 {
	int (*write_dquot)(struct dquot___177 *);
	struct dquot___177 * (*alloc_dquot)(struct super_block___177 *, int);
	void (*destroy_dquot)(struct dquot___177 *);
	int (*acquire_dquot)(struct dquot___177 *);
	int (*release_dquot)(struct dquot___177 *);
	int (*mark_dirty)(struct dquot___177 *);
	int (*write_info)(struct super_block___177 *, int);
	qsize_t * (*get_reserved_space)(struct inode___177 *);
	int (*get_projid)(struct inode___177 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___177 *, qsize_t *);
	int (*get_next_id)(struct super_block___177 *, struct kqid *);
};

struct quotactl_ops___177 {
	int (*quota_on)(struct super_block___177 *, int, int, const struct path___177 *);
	int (*quota_off)(struct super_block___177 *, int);
	int (*quota_enable)(struct super_block___177 *, unsigned int);
	int (*quota_disable)(struct super_block___177 *, unsigned int);
	int (*quota_sync)(struct super_block___177 *, int);
	int (*set_info)(struct super_block___177 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___177 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___177 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___177 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___177 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___177 *, unsigned int);
};

struct wait_page_queue___79 {
	struct page___183 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___79;

struct address_space_operations___177 {
	int (*writepage)(struct page___183 *, struct writeback_control___3 *);
	int (*readpage)(struct file___177 *, struct page___183 *);
	int (*writepages)(struct address_space___177 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___183 *);
	int (*readpages)(struct file___177 *, struct address_space___177 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___79 *);
	int (*write_begin)(struct file___177 *, struct address_space___177 *, loff_t, unsigned int, unsigned int, struct page___183 **, void **);
	int (*write_end)(struct file___177 *, struct address_space___177 *, loff_t, unsigned int, unsigned int, struct page___183 *, void *);
	sector_t (*bmap)(struct address_space___177 *, sector_t);
	void (*invalidatepage)(struct page___183 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___183 *, gfp_t);
	void (*freepage)(struct page___183 *);
	ssize_t (*direct_IO)(struct kiocb___177 *, struct iov_iter___102 *);
	int (*migratepage)(struct address_space___177 *, struct page___183 *, struct page___183 *, enum migrate_mode);
	bool (*isolate_page)(struct page___183 *, isolate_mode_t);
	void (*putback_page)(struct page___183 *);
	int (*launder_page)(struct page___183 *);
	int (*is_partially_uptodate)(struct page___183 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___183 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___177 *, struct page___183 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___177 *, sector_t *);
	void (*swap_deactivate)(struct file___177 *);
};

struct readahead_control___79 {
	struct file___177 *file;
	struct address_space___177 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___100;

struct iov_iter___102 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___100 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___32 {
	struct kobject___164 kobj;
	struct module___162 *owner;
	const struct file_operations___177 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___177 {
	struct dentry___177 * (*lookup)(struct inode___177 *, struct dentry___177 *, unsigned int);
	const char * (*get_link)(struct dentry___177 *, struct inode___177 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___177 *, int);
	struct posix_acl * (*get_acl)(struct inode___177 *, int, bool);
	int (*readlink)(struct dentry___177 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___177 *, struct dentry___177 *, umode_t, bool);
	int (*link)(struct dentry___177 *, struct inode___177 *, struct dentry___177 *);
	int (*unlink)(struct inode___177 *, struct dentry___177 *);
	int (*symlink)(struct user_namespace *, struct inode___177 *, struct dentry___177 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___177 *, struct dentry___177 *, umode_t);
	int (*rmdir)(struct inode___177 *, struct dentry___177 *);
	int (*mknod)(struct user_namespace *, struct inode___177 *, struct dentry___177 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___177 *, struct dentry___177 *, struct inode___177 *, struct dentry___177 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___177 *, struct iattr___177 *);
	int (*getattr)(struct user_namespace *, const struct path___177 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___177 *, char *, size_t);
	int (*fiemap)(struct inode___177 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___177 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___177 *, struct dentry___177 *, struct file___177 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___177 *, struct dentry___177 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___177 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___177 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___177 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___177 {
	void (*fl_copy_lock)(struct file_lock___177 *, struct file_lock___177 *);
	void (*fl_release_private)(struct file_lock___177 *);
};

struct fasync_struct___177;

struct lock_manager_operations___177;

struct file_lock___177 {
	struct file_lock___177 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___177 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___177 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___177 *fl_ops;
	const struct lock_manager_operations___177 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___177 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___177 *);
	int (*lm_grant)(struct file_lock___177 *, int);
	bool (*lm_break)(struct file_lock___177 *);
	int (*lm_change)(struct file_lock___177 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___177 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___177 *);
};

struct fasync_struct___177 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___177 *fa_next;
	struct file___177 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___177 {
	struct inode___177 * (*alloc_inode)(struct super_block___177 *);
	void (*destroy_inode)(struct inode___177 *);
	void (*free_inode)(struct inode___177 *);
	void (*dirty_inode)(struct inode___177 *, int);
	int (*write_inode)(struct inode___177 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___177 *);
	void (*evict_inode)(struct inode___177 *);
	void (*put_super)(struct super_block___177 *);
	int (*sync_fs)(struct super_block___177 *, int);
	int (*freeze_super)(struct super_block___177 *);
	int (*freeze_fs)(struct super_block___177 *);
	int (*thaw_super)(struct super_block___177 *);
	int (*unfreeze_fs)(struct super_block___177 *);
	int (*statfs)(struct dentry___177 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___177 *, int *, char *);
	void (*umount_begin)(struct super_block___177 *);
	int (*show_options)(struct seq_file___154 *, struct dentry___177 *);
	int (*show_devname)(struct seq_file___154 *, struct dentry___177 *);
	int (*show_path)(struct seq_file___154 *, struct dentry___177 *);
	int (*show_stats)(struct seq_file___154 *, struct dentry___177 *);
	ssize_t (*quota_read)(struct super_block___177 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___177 *, int, const char *, size_t, loff_t);
	struct dquot___177 ** (*get_dquots)(struct inode___177 *);
	long int (*nr_cached_objects)(struct super_block___177 *, struct shrink_control___72 *);
	long int (*free_cached_objects)(struct super_block___177 *, struct shrink_control___72 *);
	struct file___177 * (*real_loop)(struct file___177 *);
};

struct wakeup_source___130;

struct dev_pm_info___130 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___130 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___130 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___130;

struct bus_type___130;

struct device_driver___130;

struct dev_pm_domain___130;

struct fwnode_handle___130;

struct class___130;

struct attribute_group___164;

struct device___130 {
	struct kobject___164 kobj;
	struct device___130 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___130 *type;
	struct bus_type___130 *bus;
	struct device_driver___130 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___130 power;
	struct dev_pm_domain___130 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___130 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___130 *class;
	const struct attribute_group___164 **groups;
	void (*release)(struct device___130 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___87 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___177 *bd_inode;
	struct super_block___177 *bd_super;
	void *bd_claiming;
	struct device___130 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___164 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___87 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___177 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___118)(struct file___177 *, wait_queue_head_t *, struct poll_table_struct___115 *);

struct poll_table_struct___115 {
	poll_queue_proc___118 _qproc;
	__poll_t _key;
};

struct seq_operations___154;

struct seq_file___154 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___154 *op;
	int poll_event;
	const struct file___177 *file;
	void *private;
};

typedef void bio_end_io_t___85(struct bio___86 *);

struct bio_vec___100 {
	struct page___183 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___85;

struct bio___86 {
	struct bio___86 *bi_next;
	struct block_device___87 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___85 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___85 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___100 *bi_io_vec;
	struct bio_set___85 *bi_pool;
	struct bio_vec___100 bi_inline_vecs[0];
};

struct fwnode_operations___130;

struct fwnode_handle___130 {
	struct fwnode_handle___130 *secondary;
	const struct fwnode_operations___130 *ops;
	struct device___130 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___130;

struct fwnode_endpoint___130;

struct fwnode_operations___130 {
	struct fwnode_handle___130 * (*get)(struct fwnode_handle___130 *);
	void (*put)(struct fwnode_handle___130 *);
	bool (*device_is_available)(const struct fwnode_handle___130 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___130 *, const struct device___130 *);
	bool (*property_present)(const struct fwnode_handle___130 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___130 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___130 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___130 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*get_parent)(const struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*get_next_child_node)(const struct fwnode_handle___130 *, struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*get_named_child_node)(const struct fwnode_handle___130 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___130 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___130 *);
	struct fwnode_handle___130 * (*graph_get_next_endpoint)(const struct fwnode_handle___130 *, struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*graph_get_remote_endpoint)(const struct fwnode_handle___130 *);
	struct fwnode_handle___130 * (*graph_get_port_parent)(struct fwnode_handle___130 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___130 *, struct fwnode_endpoint___130 *);
	int (*add_links)(struct fwnode_handle___130 *);
};

struct fwnode_endpoint___130 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___130 *local_fwnode;
};

struct fwnode_reference_args___130 {
	struct fwnode_handle___130 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___164;

struct kernfs_elem_dir___164 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___164 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___164;

struct kernfs_root___164 {
	struct kernfs_node___164 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___164 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___164 {
	struct kernfs_node___164 *target_kn;
};

struct kernfs_ops___164;

struct kernfs_elem_attr___164 {
	const struct kernfs_ops___164 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___164 *notify_next;
};

struct kernfs_node___164 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___164 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___164 dir;
		struct kernfs_elem_symlink___164 symlink;
		struct kernfs_elem_attr___164 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___164;

struct kernfs_ops___164 {
	int (*open)(struct kernfs_open_file___164 *);
	void (*release)(struct kernfs_open_file___164 *);
	int (*seq_show)(struct seq_file___154 *, void *);
	void * (*seq_start)(struct seq_file___154 *, loff_t *);
	void * (*seq_next)(struct seq_file___154 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___154 *, void *);
	ssize_t (*read)(struct kernfs_open_file___164 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___164 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___164 *, struct poll_table_struct___115 *);
	int (*mmap)(struct kernfs_open_file___164 *, struct vm_area_struct___182 *);
};

struct kernfs_syscall_ops___164 {
	int (*show_options)(struct seq_file___154 *, struct kernfs_root___164 *);
	int (*mkdir)(struct kernfs_node___164 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___164 *);
	int (*rename)(struct kernfs_node___164 *, struct kernfs_node___164 *, const char *);
	int (*show_path)(struct seq_file___154 *, struct kernfs_node___164 *, struct kernfs_root___164 *);
};

struct kernfs_open_file___164 {
	struct kernfs_node___164 *kn;
	struct file___177 *file;
	struct seq_file___154 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___172 *vm_ops;
};

struct bin_attribute___164;

struct attribute_group___164 {
	const char *name;
	umode_t (*is_visible)(struct kobject___164 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___164 *, struct bin_attribute___164 *, int);
	struct attribute **attrs;
	struct bin_attribute___164 **bin_attrs;
};

struct bin_attribute___164 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___177 * (*f_mapping)();
	ssize_t (*read)(struct file___177 *, struct kobject___164 *, struct bin_attribute___164 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___177 *, struct kobject___164 *, struct bin_attribute___164 *, char *, loff_t, size_t);
	int (*mmap)(struct file___177 *, struct kobject___164 *, struct bin_attribute___164 *, struct vm_area_struct___182 *);
};

struct sysfs_ops___164 {
	ssize_t (*show)(struct kobject___164 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___164 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___164;

struct kset___164 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___164 kobj;
	const struct kset_uevent_ops___164 *uevent_ops;
};

struct kobj_type___164 {
	void (*release)(struct kobject___164 *);
	const struct sysfs_ops___164 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___164 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___164 *);
	const void * (*namespace)(struct kobject___164 *);
	void (*get_ownership)(struct kobject___164 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___164 {
	int (* const filter)(struct kset___164 *, struct kobject___164 *);
	const char * (* const name)(struct kset___164 *, struct kobject___164 *);
	int (* const uevent)(struct kset___164 *, struct kobject___164 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___161 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___161 *);
	int (*get)(char *, const struct kernel_param___161 *);
	void (*free)(void *);
};

struct kparam_array___161;

struct kernel_param___161 {
	const char *name;
	struct module___162 *mod;
	const struct kernel_param_ops___161 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___161 *arr;
	};
};

struct kparam_array___161 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___161 *ops;
	void *elem;
};

struct module_attribute___161 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___161 *, struct module_kobject___161 *, char *);
	ssize_t (*store)(struct module_attribute___161 *, struct module_kobject___161 *, const char *, size_t);
	void (*setup)(struct module___162 *, const char *);
	int (*test)(struct module___162 *);
	void (*free)(struct module___162 *);
};

struct dev_pm_ops___130 {
	int (*prepare)(struct device___130 *);
	void (*complete)(struct device___130 *);
	int (*suspend)(struct device___130 *);
	int (*resume)(struct device___130 *);
	int (*freeze)(struct device___130 *);
	int (*thaw)(struct device___130 *);
	int (*poweroff)(struct device___130 *);
	int (*restore)(struct device___130 *);
	int (*suspend_late)(struct device___130 *);
	int (*resume_early)(struct device___130 *);
	int (*freeze_late)(struct device___130 *);
	int (*thaw_early)(struct device___130 *);
	int (*poweroff_late)(struct device___130 *);
	int (*restore_early)(struct device___130 *);
	int (*suspend_noirq)(struct device___130 *);
	int (*resume_noirq)(struct device___130 *);
	int (*freeze_noirq)(struct device___130 *);
	int (*thaw_noirq)(struct device___130 *);
	int (*poweroff_noirq)(struct device___130 *);
	int (*restore_noirq)(struct device___130 *);
	int (*runtime_suspend)(struct device___130 *);
	int (*runtime_resume)(struct device___130 *);
	int (*runtime_idle)(struct device___130 *);
};

struct wakeup_source___130 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___130 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___130 {
	struct dev_pm_ops___130 ops;
	int (*start)(struct device___130 *);
	void (*detach)(struct device___130 *, bool);
	int (*activate)(struct device___130 *);
	void (*sync)(struct device___130 *);
	void (*dismiss)(struct device___130 *);
};

struct bus_type___130 {
	const char *name;
	const char *dev_name;
	struct device___130 *dev_root;
	const struct attribute_group___164 **bus_groups;
	const struct attribute_group___164 **dev_groups;
	const struct attribute_group___164 **drv_groups;
	int (*match)(struct device___130 *, struct device_driver___130 *);
	int (*uevent)(struct device___130 *, struct kobj_uevent_env *);
	int (*probe)(struct device___130 *);
	void (*sync_state)(struct device___130 *);
	void (*remove)(struct device___130 *);
	void (*shutdown)(struct device___130 *);
	int (*online)(struct device___130 *);
	int (*offline)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	int (*num_vf)(struct device___130 *);
	int (*dma_configure)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___130 {
	const char *name;
	struct bus_type___130 *bus;
	struct module___162 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___130 *);
	void (*sync_state)(struct device___130 *);
	int (*remove)(struct device___130 *);
	void (*shutdown)(struct device___130 *);
	int (*suspend)(struct device___130 *, pm_message_t);
	int (*resume)(struct device___130 *);
	const struct attribute_group___164 **groups;
	const struct attribute_group___164 **dev_groups;
	const struct dev_pm_ops___130 *pm;
	void (*coredump)(struct device___130 *);
	struct driver_private *p;
};

struct device_type___130 {
	const char *name;
	const struct attribute_group___164 **groups;
	int (*uevent)(struct device___130 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___130 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___130 *);
	const struct dev_pm_ops___130 *pm;
};

struct class___130 {
	const char *name;
	struct module___162 *owner;
	const struct attribute_group___164 **class_groups;
	const struct attribute_group___164 **dev_groups;
	struct kobject___164 *dev_kobj;
	int (*dev_uevent)(struct device___130 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___130 *, umode_t *);
	void (*class_release)(struct class___130 *);
	void (*dev_release)(struct device___130 *);
	int (*shutdown_pre)(struct device___130 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___130 *);
	void (*get_ownership)(struct device___130 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___130 *pm;
	struct subsys_private *p;
};

struct block_device_operations___86;

struct gendisk___87 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___87 *part0;
	const struct block_device_operations___86 *fops;
	struct request_queue___85 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___164 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___164 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___85 {
	struct bio___86 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___100 *bip_vec;
	struct bio_vec___100 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___85(struct request___85 *);

typedef void integrity_complete_fn___85(struct request___85 *, unsigned int);

struct blk_integrity_profile___85 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___85 *prepare_fn;
	integrity_complete_fn___85 *complete_fn;
	const char *name;
};

struct block_device_operations___86 {
	blk_qc_t (*submit_bio)(struct bio___86 *);
	int (*open)(struct block_device___87 *, fmode_t);
	void (*release)(struct gendisk___87 *, fmode_t);
	int (*rw_page)(struct block_device___87 *, sector_t, struct page___183 *, unsigned int);
	int (*ioctl)(struct block_device___87 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___87 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___87 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___87 *);
	int (*getgeo)(struct block_device___87 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___87 *, bool);
	void (*swap_slot_free_notify)(struct block_device___87 *, long unsigned int);
	int (*report_zones)(struct gendisk___87 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___87 *, umode_t *);
	struct module___162 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___87 *, sector_t *);
};

typedef void rq_end_io_fn___85(struct request___85 *, blk_status_t);

struct request___85 {
	struct request_queue___85 *q;
	struct blk_mq_ctx___6 *mq_ctx;
	struct blk_mq_hw_ctx___82 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___86 *bio;
	struct bio___86 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___100 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___85 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___85 *saved_end_io;
		} flush;
	};
	struct gendisk___87 *rq_disk;
	struct block_device___87 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___85 *end_io;
	void *end_io_data;
};

struct blk_mq_ctxs___6;

struct blk_mq_ctx___6 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___82 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___85 *queue;
	struct blk_mq_ctxs___6 *ctxs;
	struct kobject___164 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tags___6;

struct blk_mq_hw_ctx___82 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___85 *queue;
	struct blk_flush_queue___6 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___6 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___6 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___6 *tags;
	struct blk_mq_tags___6 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___164 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___177 *debugfs_dir;
	struct dentry___177 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___85;

struct blk_mq_alloc_data___6;

struct elevator_mq_ops___85 {
	int (*init_sched)(struct request_queue___85 *, struct elevator_type___85 *);
	void (*exit_sched)(struct elevator_queue___85 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___82 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___82 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___82 *);
	bool (*allow_merge)(struct request_queue___85 *, struct request___85 *, struct bio___86 *);
	bool (*bio_merge)(struct request_queue___85 *, struct bio___86 *, unsigned int);
	int (*request_merge)(struct request_queue___85 *, struct request___85 **, struct bio___86 *);
	void (*request_merged)(struct request_queue___85 *, struct request___85 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___85 *, struct request___85 *, struct request___85 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___6 *);
	void (*prepare_request)(struct request___85 *);
	void (*finish_request)(struct request___85 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___82 *, struct list_head *, bool);
	struct request___85 * (*dispatch_request)(struct blk_mq_hw_ctx___82 *);
	bool (*has_work)(struct blk_mq_hw_ctx___82 *);
	void (*completed_request)(struct request___85 *, u64);
	void (*requeue_request)(struct request___85 *);
	struct request___85 * (*former_request)(struct request_queue___85 *, struct request___85 *);
	struct request___85 * (*next_request)(struct request_queue___85 *, struct request___85 *);
	void (*init_icq)(struct io_cq___85 *);
	void (*exit_icq)(struct io_cq___85 *);
};

struct elv_fs_entry___85;

struct elevator_type___85 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___85 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___85 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___162 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___85 {
	struct elevator_type___85 *type;
	void *elevator_data;
	struct kobject___164 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___6 {
	struct request_queue___85 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___6 *ctx;
	struct blk_mq_hw_ctx___82 *hctx;
};

struct elv_fs_entry___85 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___85 *, char *);
	ssize_t (*store)(struct elevator_queue___85 *, const char *, size_t);
};

struct blk_mq_queue_data___82;

struct blk_mq_ops___82 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___82 *, const struct blk_mq_queue_data___82 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___82 *);
	int (*get_budget)(struct request_queue___85 *);
	void (*put_budget)(struct request_queue___85 *, int);
	void (*set_rq_budget_token)(struct request___85 *, int);
	int (*get_rq_budget_token)(struct request___85 *);
	enum blk_eh_timer_return (*timeout)(struct request___85 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___82 *);
	void (*complete)(struct request___85 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___82 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___82 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___82 *, struct request___85 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___82 *, struct request___85 *, unsigned int);
	void (*initialize_rq_fn)(struct request___85 *);
	void (*cleanup_rq)(struct request___85 *);
	bool (*busy)(struct request_queue___85 *);
	int (*map_queues)(struct blk_mq_tag_set___82 *);
	void (*show_rq)(struct seq_file___154 *, struct request___85 *);
};

struct blk_stat_callback___6 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___85 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___6 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___6 {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___85 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___82 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___82 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags___6 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_tags___6 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___85 **rqs;
	struct request___85 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

struct blk_mq_queue_data___82 {
	struct request___85 *rq;
	bool last;
};

struct blk_mq_ctxs___6 {
	struct kobject___164 kobj;
	struct blk_mq_ctx___6 *queue_ctx;
};

struct parsed_partitions___2 {
	struct gendisk___87 *disk;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

typedef struct {
	struct page___183 *v;
} Sector___2;

struct seq_operations___154 {
	void * (*start)(struct seq_file___154 *, loff_t *);
	void (*stop)(struct seq_file___154 *, void *);
	void * (*next)(struct seq_file___154 *, void *, loff_t *);
	int (*show)(struct seq_file___154 *, void *);
};

struct solaris_x86_slice {
	__le16 s_tag;
	__le16 s_flag;
	__le32 s_start;
	__le32 s_size;
};

struct solaris_x86_vtoc {
	unsigned int v_bootinfo[3];
	__le32 v_sanity;
	__le32 v_version;
	char v_volume[8];
	__le16 v_sectorsz;
	__le16 v_nparts;
	unsigned int v_reserved[10];
	struct solaris_x86_slice v_slice[16];
	unsigned int timestamp[16];
	char v_asciilabel[128];
};

struct bsd_partition {
	__le32 p_size;
	__le32 p_offset;
	__le32 p_fsize;
	__u8 p_fstype;
	__u8 p_frag;
	__le16 p_cpg;
};

struct bsd_disklabel {
	__le32 d_magic;
	__s16 d_type;
	__s16 d_subtype;
	char d_typename[16];
	char d_packname[16];
	__u32 d_secsize;
	__u32 d_nsectors;
	__u32 d_ntracks;
	__u32 d_ncylinders;
	__u32 d_secpercyl;
	__u32 d_secperunit;
	__u16 d_sparespertrack;
	__u16 d_sparespercyl;
	__u32 d_acylinders;
	__u16 d_rpm;
	__u16 d_interleave;
	__u16 d_trackskew;
	__u16 d_cylskew;
	__u32 d_headswitch;
	__u32 d_trkseek;
	__u32 d_flags;
	__u32 d_drivedata[5];
	__u32 d_spare[5];
	__le32 d_magic2;
	__le16 d_checksum;
	__le16 d_npartitions;
	__le32 d_bbsize;
	__le32 d_sbsize;
	struct bsd_partition d_partitions[16];
};

struct unixware_slice {
	__le16 s_label;
	__le16 s_flags;
	__le32 start_sect;
	__le32 nr_sects;
};

struct unixware_vtoc {
	__le32 v_magic;
	__le32 v_version;
	char v_name[8];
	__le16 v_nslices;
	__le16 v_unknown1;
	__le32 v_reserved[10];
	struct unixware_slice v_slice[16];
};

struct unixware_disklabel {
	__le32 d_type;
	__le32 d_magic;
	__le32 d_version;
	char d_serial[12];
	__le32 d_ncylinders;
	__le32 d_ntracks;
	__le32 d_nsectors;
	__le32 d_secsize;
	__le32 d_part_start;
	__le32 d_unknown1[12];
	__le32 d_alt_tbl;
	__le32 d_alt_len;
	__le32 d_phys_cyl;
	__le32 d_phys_trk;
	__le32 d_phys_sec;
	__le32 d_phys_bytes;
	__le32 d_unknown2;
	__le32 d_unknown3;
	__le32 d_pad[8];
	struct unixware_vtoc vtoc;
};

struct d_partition {
	__le32 p_size;
	__le32 p_offset;
	__le32 p_fsize;
	u8 p_fstype;
	u8 p_frag;
	__le16 p_cpg;
};

struct disklabel {
	__le32 d_magic;
	__le16 d_type;
	__le16 d_subtype;
	u8 d_typename[16];
	u8 d_packname[16];
	__le32 d_secsize;
	__le32 d_nsectors;
	__le32 d_ntracks;
	__le32 d_ncylinders;
	__le32 d_secpercyl;
	__le32 d_secprtunit;
	__le16 d_sparespertrack;
	__le16 d_sparespercyl;
	__le32 d_acylinders;
	__le16 d_rpm;
	__le16 d_interleave;
	__le16 d_trackskew;
	__le16 d_cylskew;
	__le32 d_headswitch;
	__le32 d_trkseek;
	__le32 d_flags;
	__le32 d_drivedata[5];
	__le32 d_spare[5];
	__le32 d_magic2;
	__le16 d_checksum;
	__le16 d_npartitions;
	__le32 d_bbsize;
	__le32 d_sbsize;
	struct d_partition d_partitions[18];
};

enum {
	LINUX_RAID_PARTITION___2 = 253,
};

struct sgi_volume {
	s8 name[8];
	__be32 block_num;
	__be32 num_bytes;
};

struct sgi_partition {
	__be32 num_blocks;
	__be32 first_block;
	__be32 type;
};

struct sgi_disklabel {
	__be32 magic_mushroom;
	__be16 root_part_num;
	__be16 swap_part_num;
	s8 boot_file[16];
	u8 _unused0[48];
	struct sgi_volume volume[15];
	struct sgi_partition partitions[16];
	__be32 csum;
	__be32 _unused1;
};

enum {
	SUN_WHOLE_DISK = 5,
	LINUX_RAID_PARTITION___3 = 253,
};

struct sun_info {
	__be16 id;
	__be16 flags;
};

struct sun_vtoc {
	__be32 version;
	char volume[8];
	__be16 nparts;
	struct sun_info infos[8];
	__be16 padding;
	__be32 bootinfo[3];
	__be32 sanity;
	__be32 reserved[10];
	__be32 timestamp[8];
};

struct sun_partition {
	__be32 start_cylinder;
	__be32 num_sectors;
};

struct sun_disklabel {
	unsigned char info[128];
	struct sun_vtoc vtoc;
	__be32 write_reinstruct;
	__be32 read_reinstruct;
	unsigned char spare[148];
	__be16 rspeed;
	__be16 pcylcount;
	__be16 sparecyl;
	__be16 obs1;
	__be16 obs2;
	__be16 ilfact;
	__be16 ncyl;
	__be16 nacyl;
	__be16 ntrks;
	__be16 nsect;
	__be16 obs3;
	__be16 obs4;
	struct sun_partition partitions[8];
	__be16 magic;
	__be16 csum;
};

struct pt_info {
	s32 pi_nblocks;
	u32 pi_blkoff;
};

struct ultrix_disklabel {
	s32 pt_magic;
	s32 pt_valid;
	struct pt_info pt_part[8];
};

struct dentry___178;

struct super_block___178;

struct file_system_type___178 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___178 * (*mount)(struct file_system_type___178 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___178 *);
	struct module___154 *owner;
	struct file_system_type___178 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___178;

struct kiocb___178;

struct iov_iter___103;

struct poll_table_struct___116;

struct vm_area_struct___183;

struct inode___178;

struct file_lock___178;

struct seq_file___155;

struct file_operations___178 {
	struct module___154 *owner;
	loff_t (*llseek)(struct file___178 *, loff_t, int);
	ssize_t (*read)(struct file___178 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___178 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___178 *, struct iov_iter___103 *);
	ssize_t (*write_iter)(struct kiocb___178 *, struct iov_iter___103 *);
	int (*iopoll)(struct kiocb___178 *, bool);
	int (*iterate)(struct file___178 *, struct dir_context *);
	int (*iterate_shared)(struct file___178 *, struct dir_context *);
	__poll_t (*poll)(struct file___178 *, struct poll_table_struct___116 *);
	long int (*unlocked_ioctl)(struct file___178 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___178 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___178 *, struct vm_area_struct___183 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___178 *, struct file___178 *);
	int (*flush)(struct file___178 *, fl_owner_t);
	int (*release)(struct inode___178 *, struct file___178 *);
	int (*fsync)(struct file___178 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___178 *, int);
	int (*lock)(struct file___178 *, int, struct file_lock___178 *);
	ssize_t (*sendpage)(struct file___178 *, struct page___175 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___178 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___178 *, long unsigned int);
	int (*flock)(struct file___178 *, int, struct file_lock___178 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___178 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___178 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___178 *, long int, struct file_lock___178 **, void **);
	long int (*fallocate)(struct file___178 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___155 *, struct file___178 *);
	ssize_t (*copy_file_range)(struct file___178 *, loff_t, struct file___178 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___178 *, loff_t, struct file___178 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___178 *, loff_t, loff_t, int);
};

struct vmacache___183 {
	u64 seqnum;
	struct vm_area_struct___183 *vmas[4];
};

struct page_frag___183 {
	struct page___175 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___184;

struct pid___158;

struct nsproxy___167;

struct signal_struct___179;

struct bio_list___86;

struct io_context___86;

struct request_queue___86;

struct vm_struct___161;

struct task_struct___185 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___185 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___184 *mm;
	struct mm_struct___184 *active_mm;
	struct vmacache___183 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___185 *real_parent;
	struct task_struct___185 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___185 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___158 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___167 *nsproxy;
	struct signal_struct___179 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___185 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___86 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___86 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___183 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___86 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___185 *oom_reaper_list;
	struct vm_struct___161 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___71 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___165;

struct kobj_type___165;

struct kernfs_node___165;

struct kobject___165 {
	const char *name;
	struct list_head entry;
	struct kobject___165 *parent;
	struct kset___165 *kset;
	struct kobj_type___165 *ktype;
	struct kernfs_node___165 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___162 {
	struct kobject___165 kobj;
	struct module___154 *mod;
	struct kobject___165 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___162 {
	struct module___154 *mod;
	struct latch_tree_node node;
};

struct module_layout___162 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___162 mtn;
};

struct module_attribute___162;

struct kernel_param___162;

struct module___154 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___162 mkobj;
	struct module_attribute___162 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___165 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___162 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___162 core_layout;
	struct module_layout___162 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___175 *pgtable_t___183;

struct address_space___178;

struct dev_pagemap___173;

struct page___175 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___178 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___175 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___183 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___184 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___173 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___173;

struct vm_area_struct___183 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___183 *vm_next;
	struct vm_area_struct___183 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___184 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___173 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___178 *vm_file;
	struct file___178 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___183;

struct mm_struct___184 {
	struct {
		struct vm_area_struct___183 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___178 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___183 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___185 *owner;
		struct user_namespace *user_ns;
		struct file___178 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___178;

struct address_space___178 {
	struct inode___178 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___178 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___173;

struct dev_pagemap___173 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___173 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___178;

struct path___178 {
	struct vfsmount___178 *mnt;
	struct dentry___178 *dentry;
};

struct fown_struct___158 {
	rwlock_t lock;
	struct pid___158 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___178 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___178 f_path;
	struct inode___178 *f_inode;
	const struct file_operations___178 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___158 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___178 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___173;

struct vm_operations_struct___173 {
	void (*open)(struct vm_area_struct___183 *);
	void (*close)(struct vm_area_struct___183 *);
	int (*may_split)(struct vm_area_struct___183 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___183 *);
	int (*mprotect)(struct vm_area_struct___183 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___173 *);
	vm_fault_t (*huge_fault)(struct vm_fault___173 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___173 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___183 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___173 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___173 *);
	int (*access)(struct vm_area_struct___183 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___183 *);
	int (*set_policy)(struct vm_area_struct___183 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___183 *, long unsigned int);
	struct page___175 * (*find_special_page)(struct vm_area_struct___183 *, long unsigned int);
};

struct core_thread___183 {
	struct task_struct___185 *task;
	struct core_thread___183 *next;
};

struct core_state___183 {
	atomic_t nr_threads;
	struct core_thread___183 dumper;
	struct completion startup;
};

struct vm_fault___173 {
	const struct {
		struct vm_area_struct___183 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___175 *cow_page;
	struct page___175 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___183 prealloc_pte;
};

struct dev_pagemap_ops___173 {
	void (*page_free)(struct page___175 *);
	void (*kill)(struct dev_pagemap___173 *);
	void (*cleanup)(struct dev_pagemap___173 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___173 *);
};

struct pid_namespace___158;

struct upid___158 {
	int nr;
	struct pid_namespace___158 *ns;
};

struct pid_namespace___158 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___185 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___158 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___158 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___158 numbers[1];
};

struct signal_struct___179 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___185 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___185 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___158 *pids[4];
	struct pid___158 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___184 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___167 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___158 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio_list___86 {
	struct bio___81 *head;
	struct bio___81 *tail;
};

struct io_cq___86;

struct io_context___86 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___86 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___86;

struct blk_integrity___86 {
	const struct blk_integrity_profile___86 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___86 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___86 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___86;

struct elevator_queue___86;

struct blk_mq_ops___83;

struct blk_mq_ctx___7;

struct blk_mq_hw_ctx___83;

struct device___131;

struct blk_stat_callback___7;

struct blk_flush_queue___7;

struct blk_mq_tag_set___83;

struct request_queue___86 {
	struct request___86 *last_merge;
	struct elevator_queue___86 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___83 *mq_ops;
	struct blk_mq_ctx___7 *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___83 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___82 *disk;
	struct kobject___165 kobj;
	struct kobject___165 *mq_kobj;
	struct blk_integrity___86 integrity;
	struct device___131 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___7 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue___7 *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___83 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___86 bio_split;
	struct dentry___178 *debugfs_dir;
	struct dentry___178 *sched_debugfs_dir;
	struct dentry___178 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___161 {
	struct vm_struct___161 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___175 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___178;

struct dentry___178 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___178 *d_parent;
	struct qstr d_name;
	struct inode___178 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___178 *d_op;
	struct super_block___178 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___178;

struct cdev___33;

struct inode___178 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___178 *i_op;
	struct super_block___178 *i_sb;
	struct address_space___178 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___178 *i_fop;
		void (*free_inode)(struct inode___178 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___178 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___33 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___178 {
	int (*d_revalidate)(struct dentry___178 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___178 *, unsigned int);
	int (*d_hash)(const struct dentry___178 *, struct qstr *);
	int (*d_compare)(const struct dentry___178 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___178 *);
	int (*d_init)(struct dentry___178 *);
	void (*d_release)(struct dentry___178 *);
	void (*d_prune)(struct dentry___178 *);
	void (*d_iput)(struct dentry___178 *, struct inode___178 *);
	char * (*d_dname)(struct dentry___178 *, char *, int);
	struct vfsmount___178 * (*d_automount)(struct path___178 *);
	int (*d_manage)(const struct path___178 *, bool);
	struct dentry___178 * (*d_real)(struct dentry___178 *, const struct inode___178 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___178;

struct mem_dqinfo___178 {
	struct quota_format_type___178 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___178;

struct quota_info___178 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___178 *files[3];
	struct mem_dqinfo___178 info[3];
	const struct quota_format_ops___178 *ops[3];
};

struct rcuwait___179 {
	struct task_struct___185 *task;
};

struct percpu_rw_semaphore___179 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___179 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___178 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___179 rw_sem[3];
};

struct super_operations___178;

struct dquot_operations___178;

struct quotactl_ops___178;

struct super_block___178 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___178 *s_type;
	const struct super_operations___178 *s_op;
	const struct dquot_operations___178 *dq_op;
	const struct quotactl_ops___178 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___178 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___83 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___178 s_dquot;
	struct sb_writers___178 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___178 *s_d_op;
	int cleancache_poolid;
	struct shrinker___72 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___178 {
	struct dentry___178 *mnt_root;
	struct super_block___178 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___86 {
	struct request_queue___86 *q;
	struct io_context___86 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___80;

struct kiocb___178 {
	struct file___178 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___178 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___80 *ki_waitq;
	};
};

struct iattr___178 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___178 *ia_file;
};

struct dquot___178 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___178 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___178 {
	int qf_fmt_id;
	const struct quota_format_ops___178 *qf_ops;
	struct module___154 *qf_owner;
	struct quota_format_type___178 *qf_next;
};

struct quota_format_ops___178 {
	int (*check_quota_file)(struct super_block___178 *, int);
	int (*read_file_info)(struct super_block___178 *, int);
	int (*write_file_info)(struct super_block___178 *, int);
	int (*free_file_info)(struct super_block___178 *, int);
	int (*read_dqblk)(struct dquot___178 *);
	int (*commit_dqblk)(struct dquot___178 *);
	int (*release_dqblk)(struct dquot___178 *);
	int (*get_next_id)(struct super_block___178 *, struct kqid *);
};

struct dquot_operations___178 {
	int (*write_dquot)(struct dquot___178 *);
	struct dquot___178 * (*alloc_dquot)(struct super_block___178 *, int);
	void (*destroy_dquot)(struct dquot___178 *);
	int (*acquire_dquot)(struct dquot___178 *);
	int (*release_dquot)(struct dquot___178 *);
	int (*mark_dirty)(struct dquot___178 *);
	int (*write_info)(struct super_block___178 *, int);
	qsize_t * (*get_reserved_space)(struct inode___178 *);
	int (*get_projid)(struct inode___178 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___178 *, qsize_t *);
	int (*get_next_id)(struct super_block___178 *, struct kqid *);
};

struct quotactl_ops___178 {
	int (*quota_on)(struct super_block___178 *, int, int, const struct path___178 *);
	int (*quota_off)(struct super_block___178 *, int);
	int (*quota_enable)(struct super_block___178 *, unsigned int);
	int (*quota_disable)(struct super_block___178 *, unsigned int);
	int (*quota_sync)(struct super_block___178 *, int);
	int (*set_info)(struct super_block___178 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___178 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___178 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___178 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___178 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___178 *, unsigned int);
};

struct wait_page_queue___80 {
	struct page___175 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___80;

struct address_space_operations___178 {
	int (*writepage)(struct page___175 *, struct writeback_control___3 *);
	int (*readpage)(struct file___178 *, struct page___175 *);
	int (*writepages)(struct address_space___178 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___175 *);
	int (*readpages)(struct file___178 *, struct address_space___178 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___80 *);
	int (*write_begin)(struct file___178 *, struct address_space___178 *, loff_t, unsigned int, unsigned int, struct page___175 **, void **);
	int (*write_end)(struct file___178 *, struct address_space___178 *, loff_t, unsigned int, unsigned int, struct page___175 *, void *);
	sector_t (*bmap)(struct address_space___178 *, sector_t);
	void (*invalidatepage)(struct page___175 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___175 *, gfp_t);
	void (*freepage)(struct page___175 *);
	ssize_t (*direct_IO)(struct kiocb___178 *, struct iov_iter___103 *);
	int (*migratepage)(struct address_space___178 *, struct page___175 *, struct page___175 *, enum migrate_mode);
	bool (*isolate_page)(struct page___175 *, isolate_mode_t);
	void (*putback_page)(struct page___175 *);
	int (*launder_page)(struct page___175 *);
	int (*is_partially_uptodate)(struct page___175 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___175 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___178 *, struct page___175 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___178 *, sector_t *);
	void (*swap_deactivate)(struct file___178 *);
};

struct readahead_control___80 {
	struct file___178 *file;
	struct address_space___178 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___101;

struct iov_iter___103 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___101 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___33 {
	struct kobject___165 kobj;
	struct module___154 *owner;
	const struct file_operations___178 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___178 {
	struct dentry___178 * (*lookup)(struct inode___178 *, struct dentry___178 *, unsigned int);
	const char * (*get_link)(struct dentry___178 *, struct inode___178 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___178 *, int);
	struct posix_acl * (*get_acl)(struct inode___178 *, int, bool);
	int (*readlink)(struct dentry___178 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___178 *, struct dentry___178 *, umode_t, bool);
	int (*link)(struct dentry___178 *, struct inode___178 *, struct dentry___178 *);
	int (*unlink)(struct inode___178 *, struct dentry___178 *);
	int (*symlink)(struct user_namespace *, struct inode___178 *, struct dentry___178 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___178 *, struct dentry___178 *, umode_t);
	int (*rmdir)(struct inode___178 *, struct dentry___178 *);
	int (*mknod)(struct user_namespace *, struct inode___178 *, struct dentry___178 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___178 *, struct dentry___178 *, struct inode___178 *, struct dentry___178 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___178 *, struct iattr___178 *);
	int (*getattr)(struct user_namespace *, const struct path___178 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___178 *, char *, size_t);
	int (*fiemap)(struct inode___178 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___178 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___178 *, struct dentry___178 *, struct file___178 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___178 *, struct dentry___178 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___178 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___178 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___178 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___178 {
	void (*fl_copy_lock)(struct file_lock___178 *, struct file_lock___178 *);
	void (*fl_release_private)(struct file_lock___178 *);
};

struct fasync_struct___178;

struct lock_manager_operations___178;

struct file_lock___178 {
	struct file_lock___178 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___178 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___178 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___178 *fl_ops;
	const struct lock_manager_operations___178 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___178 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___178 *);
	int (*lm_grant)(struct file_lock___178 *, int);
	bool (*lm_break)(struct file_lock___178 *);
	int (*lm_change)(struct file_lock___178 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___178 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___178 *);
};

struct fasync_struct___178 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___178 *fa_next;
	struct file___178 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___178 {
	struct inode___178 * (*alloc_inode)(struct super_block___178 *);
	void (*destroy_inode)(struct inode___178 *);
	void (*free_inode)(struct inode___178 *);
	void (*dirty_inode)(struct inode___178 *, int);
	int (*write_inode)(struct inode___178 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___178 *);
	void (*evict_inode)(struct inode___178 *);
	void (*put_super)(struct super_block___178 *);
	int (*sync_fs)(struct super_block___178 *, int);
	int (*freeze_super)(struct super_block___178 *);
	int (*freeze_fs)(struct super_block___178 *);
	int (*thaw_super)(struct super_block___178 *);
	int (*unfreeze_fs)(struct super_block___178 *);
	int (*statfs)(struct dentry___178 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___178 *, int *, char *);
	void (*umount_begin)(struct super_block___178 *);
	int (*show_options)(struct seq_file___155 *, struct dentry___178 *);
	int (*show_devname)(struct seq_file___155 *, struct dentry___178 *);
	int (*show_path)(struct seq_file___155 *, struct dentry___178 *);
	int (*show_stats)(struct seq_file___155 *, struct dentry___178 *);
	ssize_t (*quota_read)(struct super_block___178 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___178 *, int, const char *, size_t, loff_t);
	struct dquot___178 ** (*get_dquots)(struct inode___178 *);
	long int (*nr_cached_objects)(struct super_block___178 *, struct shrink_control___72 *);
	long int (*free_cached_objects)(struct super_block___178 *, struct shrink_control___72 *);
	struct file___178 * (*real_loop)(struct file___178 *);
};

struct wakeup_source___131;

struct dev_pm_info___131 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___131 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___131 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___131;

struct bus_type___131;

struct device_driver___131;

struct dev_pm_domain___131;

struct fwnode_handle___131;

struct class___131;

struct attribute_group___165;

struct device___131 {
	struct kobject___165 kobj;
	struct device___131 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___131 *type;
	struct bus_type___131 *bus;
	struct device_driver___131 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___131 power;
	struct dev_pm_domain___131 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___131 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___131 *class;
	const struct attribute_group___165 **groups;
	void (*release)(struct device___131 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___83 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___178 *bd_inode;
	struct super_block___178 *bd_super;
	void *bd_claiming;
	struct device___131 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___165 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___82 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___178 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___119)(struct file___178 *, wait_queue_head_t *, struct poll_table_struct___116 *);

struct poll_table_struct___116 {
	poll_queue_proc___119 _qproc;
	__poll_t _key;
};

struct seq_operations___155;

struct seq_file___155 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___155 *op;
	int poll_event;
	const struct file___178 *file;
	void *private;
};

typedef void bio_end_io_t___86(struct bio___81 *);

struct bio_vec___101 {
	struct page___175 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___86;

struct bio___81 {
	struct bio___81 *bi_next;
	struct block_device___83 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___86 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___86 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___101 *bi_io_vec;
	struct bio_set___86 *bi_pool;
	struct bio_vec___101 bi_inline_vecs[0];
};

struct fwnode_operations___131;

struct fwnode_handle___131 {
	struct fwnode_handle___131 *secondary;
	const struct fwnode_operations___131 *ops;
	struct device___131 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___131;

struct fwnode_endpoint___131;

struct fwnode_operations___131 {
	struct fwnode_handle___131 * (*get)(struct fwnode_handle___131 *);
	void (*put)(struct fwnode_handle___131 *);
	bool (*device_is_available)(const struct fwnode_handle___131 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___131 *, const struct device___131 *);
	bool (*property_present)(const struct fwnode_handle___131 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___131 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___131 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___131 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*get_parent)(const struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*get_next_child_node)(const struct fwnode_handle___131 *, struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*get_named_child_node)(const struct fwnode_handle___131 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___131 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___131 *);
	struct fwnode_handle___131 * (*graph_get_next_endpoint)(const struct fwnode_handle___131 *, struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*graph_get_remote_endpoint)(const struct fwnode_handle___131 *);
	struct fwnode_handle___131 * (*graph_get_port_parent)(struct fwnode_handle___131 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___131 *, struct fwnode_endpoint___131 *);
	int (*add_links)(struct fwnode_handle___131 *);
};

struct fwnode_endpoint___131 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___131 *local_fwnode;
};

struct fwnode_reference_args___131 {
	struct fwnode_handle___131 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___165;

struct kernfs_elem_dir___165 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___165 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___165;

struct kernfs_root___165 {
	struct kernfs_node___165 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___165 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___165 {
	struct kernfs_node___165 *target_kn;
};

struct kernfs_ops___165;

struct kernfs_elem_attr___165 {
	const struct kernfs_ops___165 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___165 *notify_next;
};

struct kernfs_node___165 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___165 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___165 dir;
		struct kernfs_elem_symlink___165 symlink;
		struct kernfs_elem_attr___165 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___165;

struct kernfs_ops___165 {
	int (*open)(struct kernfs_open_file___165 *);
	void (*release)(struct kernfs_open_file___165 *);
	int (*seq_show)(struct seq_file___155 *, void *);
	void * (*seq_start)(struct seq_file___155 *, loff_t *);
	void * (*seq_next)(struct seq_file___155 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___155 *, void *);
	ssize_t (*read)(struct kernfs_open_file___165 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___165 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___165 *, struct poll_table_struct___116 *);
	int (*mmap)(struct kernfs_open_file___165 *, struct vm_area_struct___183 *);
};

struct kernfs_syscall_ops___165 {
	int (*show_options)(struct seq_file___155 *, struct kernfs_root___165 *);
	int (*mkdir)(struct kernfs_node___165 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___165 *);
	int (*rename)(struct kernfs_node___165 *, struct kernfs_node___165 *, const char *);
	int (*show_path)(struct seq_file___155 *, struct kernfs_node___165 *, struct kernfs_root___165 *);
};

struct kernfs_open_file___165 {
	struct kernfs_node___165 *kn;
	struct file___178 *file;
	struct seq_file___155 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___173 *vm_ops;
};

struct bin_attribute___165;

struct attribute_group___165 {
	const char *name;
	umode_t (*is_visible)(struct kobject___165 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___165 *, struct bin_attribute___165 *, int);
	struct attribute **attrs;
	struct bin_attribute___165 **bin_attrs;
};

struct bin_attribute___165 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___178 * (*f_mapping)();
	ssize_t (*read)(struct file___178 *, struct kobject___165 *, struct bin_attribute___165 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___178 *, struct kobject___165 *, struct bin_attribute___165 *, char *, loff_t, size_t);
	int (*mmap)(struct file___178 *, struct kobject___165 *, struct bin_attribute___165 *, struct vm_area_struct___183 *);
};

struct sysfs_ops___165 {
	ssize_t (*show)(struct kobject___165 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___165 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___165;

struct kset___165 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___165 kobj;
	const struct kset_uevent_ops___165 *uevent_ops;
};

struct kobj_type___165 {
	void (*release)(struct kobject___165 *);
	const struct sysfs_ops___165 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___165 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___165 *);
	const void * (*namespace)(struct kobject___165 *);
	void (*get_ownership)(struct kobject___165 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___165 {
	int (* const filter)(struct kset___165 *, struct kobject___165 *);
	const char * (* const name)(struct kset___165 *, struct kobject___165 *);
	int (* const uevent)(struct kset___165 *, struct kobject___165 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___162 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___162 *);
	int (*get)(char *, const struct kernel_param___162 *);
	void (*free)(void *);
};

struct kparam_array___162;

struct kernel_param___162 {
	const char *name;
	struct module___154 *mod;
	const struct kernel_param_ops___162 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___162 *arr;
	};
};

struct kparam_array___162 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___162 *ops;
	void *elem;
};

struct module_attribute___162 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___162 *, struct module_kobject___162 *, char *);
	ssize_t (*store)(struct module_attribute___162 *, struct module_kobject___162 *, const char *, size_t);
	void (*setup)(struct module___154 *, const char *);
	int (*test)(struct module___154 *);
	void (*free)(struct module___154 *);
};

struct dev_pm_ops___131 {
	int (*prepare)(struct device___131 *);
	void (*complete)(struct device___131 *);
	int (*suspend)(struct device___131 *);
	int (*resume)(struct device___131 *);
	int (*freeze)(struct device___131 *);
	int (*thaw)(struct device___131 *);
	int (*poweroff)(struct device___131 *);
	int (*restore)(struct device___131 *);
	int (*suspend_late)(struct device___131 *);
	int (*resume_early)(struct device___131 *);
	int (*freeze_late)(struct device___131 *);
	int (*thaw_early)(struct device___131 *);
	int (*poweroff_late)(struct device___131 *);
	int (*restore_early)(struct device___131 *);
	int (*suspend_noirq)(struct device___131 *);
	int (*resume_noirq)(struct device___131 *);
	int (*freeze_noirq)(struct device___131 *);
	int (*thaw_noirq)(struct device___131 *);
	int (*poweroff_noirq)(struct device___131 *);
	int (*restore_noirq)(struct device___131 *);
	int (*runtime_suspend)(struct device___131 *);
	int (*runtime_resume)(struct device___131 *);
	int (*runtime_idle)(struct device___131 *);
};

struct wakeup_source___131 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___131 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___131 {
	struct dev_pm_ops___131 ops;
	int (*start)(struct device___131 *);
	void (*detach)(struct device___131 *, bool);
	int (*activate)(struct device___131 *);
	void (*sync)(struct device___131 *);
	void (*dismiss)(struct device___131 *);
};

struct bus_type___131 {
	const char *name;
	const char *dev_name;
	struct device___131 *dev_root;
	const struct attribute_group___165 **bus_groups;
	const struct attribute_group___165 **dev_groups;
	const struct attribute_group___165 **drv_groups;
	int (*match)(struct device___131 *, struct device_driver___131 *);
	int (*uevent)(struct device___131 *, struct kobj_uevent_env *);
	int (*probe)(struct device___131 *);
	void (*sync_state)(struct device___131 *);
	void (*remove)(struct device___131 *);
	void (*shutdown)(struct device___131 *);
	int (*online)(struct device___131 *);
	int (*offline)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	int (*num_vf)(struct device___131 *);
	int (*dma_configure)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___131 {
	const char *name;
	struct bus_type___131 *bus;
	struct module___154 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___131 *);
	void (*sync_state)(struct device___131 *);
	int (*remove)(struct device___131 *);
	void (*shutdown)(struct device___131 *);
	int (*suspend)(struct device___131 *, pm_message_t);
	int (*resume)(struct device___131 *);
	const struct attribute_group___165 **groups;
	const struct attribute_group___165 **dev_groups;
	const struct dev_pm_ops___131 *pm;
	void (*coredump)(struct device___131 *);
	struct driver_private *p;
};

struct device_type___131 {
	const char *name;
	const struct attribute_group___165 **groups;
	int (*uevent)(struct device___131 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___131 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___131 *);
	const struct dev_pm_ops___131 *pm;
};

struct class___131 {
	const char *name;
	struct module___154 *owner;
	const struct attribute_group___165 **class_groups;
	const struct attribute_group___165 **dev_groups;
	struct kobject___165 *dev_kobj;
	int (*dev_uevent)(struct device___131 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___131 *, umode_t *);
	void (*class_release)(struct class___131 *);
	void (*dev_release)(struct device___131 *);
	int (*shutdown_pre)(struct device___131 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___131 *);
	void (*get_ownership)(struct device___131 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___131 *pm;
	struct subsys_private *p;
};

struct gendisk___82 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___83 *part0;
	const struct block_device_operations___81 *fops;
	struct request_queue___86 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___165 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___165 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___86 {
	struct bio___81 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___101 *bip_vec;
	struct bio_vec___101 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___86(struct request___86 *);

typedef void integrity_complete_fn___86(struct request___86 *, unsigned int);

struct blk_integrity_profile___86 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___86 *prepare_fn;
	integrity_complete_fn___86 *complete_fn;
	const char *name;
};

typedef void rq_end_io_fn___86(struct request___86 *, blk_status_t);

struct request___86 {
	struct request_queue___86 *q;
	struct blk_mq_ctx___7 *mq_ctx;
	struct blk_mq_hw_ctx___83 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___81 *bio;
	struct bio___81 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___101 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___86 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___86 *saved_end_io;
		} flush;
	};
	struct gendisk___82 *rq_disk;
	struct block_device___83 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___86 *end_io;
	void *end_io_data;
};

struct blk_mq_ctxs___7;

struct blk_mq_ctx___7 {
	struct {
		spinlock_t lock;
		struct list_head rq_lists[3];
		long: 64;
	};
	unsigned int cpu;
	short unsigned int index_hw[3];
	struct blk_mq_hw_ctx___83 *hctxs[3];
	long unsigned int rq_dispatched[2];
	long unsigned int rq_merged;
	long unsigned int rq_completed[2];
	struct request_queue___86 *queue;
	struct blk_mq_ctxs___7 *ctxs;
	struct kobject___165 kobj;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct blk_mq_tags___7;

struct blk_mq_hw_ctx___83 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___86 *queue;
	struct blk_flush_queue___7 *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx___7 *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx___7 **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags___7 *tags;
	struct blk_mq_tags___7 *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___165 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___178 *debugfs_dir;
	struct dentry___178 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___86;

struct blk_mq_alloc_data___7;

struct elevator_mq_ops___86 {
	int (*init_sched)(struct request_queue___86 *, struct elevator_type___86 *);
	void (*exit_sched)(struct elevator_queue___86 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___83 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___83 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___83 *);
	bool (*allow_merge)(struct request_queue___86 *, struct request___86 *, struct bio___81 *);
	bool (*bio_merge)(struct request_queue___86 *, struct bio___81 *, unsigned int);
	int (*request_merge)(struct request_queue___86 *, struct request___86 **, struct bio___81 *);
	void (*request_merged)(struct request_queue___86 *, struct request___86 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___86 *, struct request___86 *, struct request___86 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data___7 *);
	void (*prepare_request)(struct request___86 *);
	void (*finish_request)(struct request___86 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___83 *, struct list_head *, bool);
	struct request___86 * (*dispatch_request)(struct blk_mq_hw_ctx___83 *);
	bool (*has_work)(struct blk_mq_hw_ctx___83 *);
	void (*completed_request)(struct request___86 *, u64);
	void (*requeue_request)(struct request___86 *);
	struct request___86 * (*former_request)(struct request_queue___86 *, struct request___86 *);
	struct request___86 * (*next_request)(struct request_queue___86 *, struct request___86 *);
	void (*init_icq)(struct io_cq___86 *);
	void (*exit_icq)(struct io_cq___86 *);
};

struct elv_fs_entry___86;

struct elevator_type___86 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___86 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___86 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___154 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___86 {
	struct elevator_type___86 *type;
	void *elevator_data;
	struct kobject___165 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct blk_mq_alloc_data___7 {
	struct request_queue___86 *q;
	blk_mq_req_flags_t flags;
	unsigned int shallow_depth;
	unsigned int cmd_flags;
	struct blk_mq_ctx___7 *ctx;
	struct blk_mq_hw_ctx___83 *hctx;
};

struct elv_fs_entry___86 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___86 *, char *);
	ssize_t (*store)(struct elevator_queue___86 *, const char *, size_t);
};

struct blk_mq_queue_data___83;

struct blk_mq_ops___83 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___83 *, const struct blk_mq_queue_data___83 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___83 *);
	int (*get_budget)(struct request_queue___86 *);
	void (*put_budget)(struct request_queue___86 *, int);
	void (*set_rq_budget_token)(struct request___86 *, int);
	int (*get_rq_budget_token)(struct request___86 *);
	enum blk_eh_timer_return (*timeout)(struct request___86 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___83 *);
	void (*complete)(struct request___86 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___83 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___83 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___83 *, struct request___86 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___83 *, struct request___86 *, unsigned int);
	void (*initialize_rq_fn)(struct request___86 *);
	void (*cleanup_rq)(struct request___86 *);
	bool (*busy)(struct request_queue___86 *);
	int (*map_queues)(struct blk_mq_tag_set___83 *);
	void (*show_rq)(struct seq_file___155 *, struct request___86 *);
};

struct blk_stat_callback___7 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___86 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___7 *);
	void *data;
	struct callback_head rcu;
};

struct blk_flush_queue___7 {
	unsigned int flush_pending_idx: 1;
	unsigned int flush_running_idx: 1;
	blk_status_t rq_status;
	long unsigned int flush_pending_since;
	struct list_head flush_queue[2];
	struct list_head flush_data_in_flight;
	struct request___86 *flush_rq;
	spinlock_t mq_flush_lock;
};

struct blk_mq_tag_set___83 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___83 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags___7 **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_tags___7 {
	unsigned int nr_tags;
	unsigned int nr_reserved_tags;
	atomic_t active_queues;
	struct sbitmap_queue *bitmap_tags;
	struct sbitmap_queue *breserved_tags;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct request___86 **rqs;
	struct request___86 **static_rqs;
	struct list_head page_list;
	spinlock_t lock;
};

struct blk_mq_queue_data___83 {
	struct request___86 *rq;
	bool last;
};

struct blk_mq_ctxs___7 {
	struct kobject___165 kobj;
	struct blk_mq_ctx___7 *queue_ctx;
};

struct parsed_partitions___3 {
	struct gendisk___82 *disk;
	char name[32];
	struct {
		sector_t from;
		sector_t size;
		int flags;
		bool has_info;
		struct partition_meta_info info;
	} *parts;
	int next;
	int limit;
	bool access_beyond_eod;
	char *pp_buf;
};

typedef struct {
	struct page___175 *v;
} Sector___3;

struct seq_operations___155 {
	void * (*start)(struct seq_file___155 *, loff_t *);
	void (*stop)(struct seq_file___155 *, void *);
	void * (*next)(struct seq_file___155 *, void *, loff_t *);
	int (*show)(struct seq_file___155 *, void *);
};

struct _gpt_header {
	__le64 signature;
	__le32 revision;
	__le32 header_size;
	__le32 header_crc32;
	__le32 reserved1;
	__le64 my_lba;
	__le64 alternate_lba;
	__le64 first_usable_lba;
	__le64 last_usable_lba;
	efi_guid_t disk_guid;
	__le64 partition_entry_lba;
	__le32 num_partition_entries;
	__le32 sizeof_partition_entry;
	__le32 partition_entry_array_crc32;
} __attribute__((packed));

typedef struct _gpt_header gpt_header;

struct _gpt_entry_attributes {
	u64 required_to_function: 1;
	u64 reserved: 47;
	u64 type_guid_specific: 16;
};

typedef struct _gpt_entry_attributes gpt_entry_attributes;

struct _gpt_entry {
	efi_guid_t partition_type_guid;
	efi_guid_t unique_partition_guid;
	__le64 starting_lba;
	__le64 ending_lba;
	gpt_entry_attributes attributes;
	__le16 partition_name[36];
};

typedef struct _gpt_entry gpt_entry;

struct _gpt_mbr_record {
	u8 boot_indicator;
	u8 start_head;
	u8 start_sector;
	u8 start_track;
	u8 os_type;
	u8 end_head;
	u8 end_sector;
	u8 end_track;
	__le32 starting_lba;
	__le32 size_in_lba;
};

typedef struct _gpt_mbr_record gpt_mbr_record;

struct _legacy_mbr {
	u8 boot_code[440];
	__le32 unique_mbr_signature;
	__le16 unknown;
	gpt_mbr_record partition_record[4];
	__le16 signature;
} __attribute__((packed));

typedef struct _legacy_mbr legacy_mbr;

struct d_partition___2 {
	__le32 p_res;
	u8 p_fstype;
	u8 p_res2[3];
	__le32 p_offset;
	__le32 p_size;
};

struct disklabel___2 {
	u8 d_reserved[270];
	struct d_partition___2 d_partitions[2];
	u8 d_blank[208];
	__le16 d_magic;
} __attribute__((packed));

struct volumeid {
	u8 vid_unused[248];
	u8 vid_mac[8];
};

struct dkconfig {
	u8 ios_unused0[128];
	__be32 ios_slcblk;
	__be16 ios_slccnt;
	u8 ios_unused1[122];
};

struct dkblk0 {
	struct volumeid dk_vid;
	struct dkconfig dk_ios;
};

struct slice {
	__be32 nblocks;
	__be32 blkoff;
};

struct rq_wait {
	wait_queue_head_t wait;
	atomic_t inflight;
};

struct rq_depth {
	unsigned int max_depth;
	int scale_step;
	bool scaled_max;
	unsigned int queue_depth;
	unsigned int default_depth;
};

typedef bool acquire_inflight_cb_t(struct rq_wait *, void *);

typedef void cleanup_cb_t(struct rq_wait *, void *);

struct rq_qos_wait_data {
	struct wait_queue_entry wq;
	struct task_struct___184 *task;
	struct rq_wait *rqw;
	acquire_inflight_cb_t *cb;
	void *private_data;
	bool got_token;
};

enum {
	DISK_EVENT_FLAG_POLL = 1,
	DISK_EVENT_FLAG_UEVENT = 2,
};

struct disk_events {
	struct list_head node;
	struct gendisk___87 *disk;
	spinlock_t lock;
	struct mutex block_mutex;
	int block;
	unsigned int pending;
	unsigned int clearing;
	long int poll_msecs;
	struct delayed_work dwork;
};

struct sg_io_v4 {
	__s32 guard;
	__u32 protocol;
	__u32 subprotocol;
	__u32 request_len;
	__u64 request;
	__u64 request_tag;
	__u32 request_attr;
	__u32 request_priority;
	__u32 request_extra;
	__u32 max_response_len;
	__u64 response;
	__u32 dout_iovec_count;
	__u32 dout_xfer_len;
	__u32 din_iovec_count;
	__u32 din_xfer_len;
	__u64 dout_xferp;
	__u64 din_xferp;
	__u32 timeout;
	__u32 flags;
	__u64 usr_ptr;
	__u32 spare_in;
	__u32 driver_status;
	__u32 transport_status;
	__u32 device_status;
	__u32 retry_delay;
	__u32 info;
	__u32 duration;
	__u32 response_len;
	__s32 din_resid;
	__s32 dout_resid;
	__u64 generated_tag;
	__u32 spare_out;
	__u32 padding;
};

typedef int bsg_sg_io_fn(struct request_queue___85 *, struct sg_io_v4 *, fmode_t, unsigned int);

struct bsg_device {
	struct request_queue___85 *queue;
	struct device___130 device;
	struct cdev___32 cdev;
	int max_queue;
	unsigned int timeout;
	unsigned int reserved_size;
	bsg_sg_io_fn *sg_io_fn;
};

struct rq_map_data___2 {
	struct page___183 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct bsg_job;

typedef int bsg_job_fn(struct bsg_job *);

struct bsg_buffer {
	unsigned int payload_len;
	int sg_cnt;
	struct scatterlist *sg_list;
};

struct bsg_job {
	struct device___130 *dev;
	struct kref kref;
	unsigned int timeout;
	void *request;
	void *reply;
	unsigned int request_len;
	unsigned int reply_len;
	struct bsg_buffer request_payload;
	struct bsg_buffer reply_payload;
	int result;
	unsigned int reply_payload_rcv_len;
	struct request___85 *bidi_rq;
	struct bio___86 *bidi_bio;
	void *dd_data;
};

typedef enum blk_eh_timer_return bsg_timeout_fn(struct request___85 *);

enum scsi_device_event {
	SDEV_EVT_MEDIA_CHANGE = 1,
	SDEV_EVT_INQUIRY_CHANGE_REPORTED = 2,
	SDEV_EVT_CAPACITY_CHANGE_REPORTED = 3,
	SDEV_EVT_SOFT_THRESHOLD_REACHED_REPORTED = 4,
	SDEV_EVT_MODE_PARAMETER_CHANGE_REPORTED = 5,
	SDEV_EVT_LUN_CHANGE_REPORTED = 6,
	SDEV_EVT_ALUA_STATE_CHANGE_REPORTED = 7,
	SDEV_EVT_POWER_ON_RESET_OCCURRED = 8,
	SDEV_EVT_FIRST = 1,
	SDEV_EVT_LAST = 8,
	SDEV_EVT_MAXBITS = 9,
};

struct bsg_device___2;

struct bsg_set {
	struct blk_mq_tag_set___82 tag_set;
	struct bsg_device___2 *bd;
	bsg_job_fn *job_fn;
	bsg_timeout_fn *timeout_fn;
};

typedef struct blkcg_policy_data___80 *blkcg_pol_alloc_cpd_fn(gfp_t);

typedef void blkcg_pol_init_cpd_fn(struct blkcg_policy_data___80 *);

typedef void blkcg_pol_free_cpd_fn(struct blkcg_policy_data___80 *);

typedef void blkcg_pol_bind_cpd_fn(struct blkcg_policy_data___80 *);

typedef struct blkg_policy_data___80 *blkcg_pol_alloc_pd_fn(gfp_t, struct request_queue___83 *, struct blkcg___80 *);

typedef void blkcg_pol_init_pd_fn(struct blkg_policy_data___80 *);

typedef void blkcg_pol_online_pd_fn(struct blkg_policy_data___80 *);

typedef void blkcg_pol_offline_pd_fn(struct blkg_policy_data___80 *);

typedef void blkcg_pol_free_pd_fn(struct blkg_policy_data___80 *);

typedef void blkcg_pol_reset_pd_stats_fn(struct blkg_policy_data___80 *);

typedef bool blkcg_pol_stat_pd_fn(struct blkg_policy_data___80 *, struct seq_file___3 *);

struct blkcg_policy {
	int plid;
	struct cftype___119 *dfl_cftypes;
	struct cftype___119 *legacy_cftypes;
	blkcg_pol_alloc_cpd_fn *cpd_alloc_fn;
	blkcg_pol_init_cpd_fn *cpd_init_fn;
	blkcg_pol_free_cpd_fn *cpd_free_fn;
	blkcg_pol_bind_cpd_fn *cpd_bind_fn;
	blkcg_pol_alloc_pd_fn *pd_alloc_fn;
	blkcg_pol_init_pd_fn *pd_init_fn;
	blkcg_pol_online_pd_fn *pd_online_fn;
	blkcg_pol_offline_pd_fn *pd_offline_fn;
	blkcg_pol_free_pd_fn *pd_free_fn;
	blkcg_pol_reset_pd_stats_fn *pd_reset_stats_fn;
	blkcg_pol_stat_pd_fn *pd_stat_fn;
};

struct blkg_conf_ctx {
	struct block_device___2 *bdev;
	struct blkcg_gq___80 *blkg;
	char *body;
};

typedef struct blkcg_policy_data___3 *blkcg_pol_alloc_cpd_fn___2(gfp_t);

typedef void blkcg_pol_init_cpd_fn___2(struct blkcg_policy_data___3 *);

typedef void blkcg_pol_free_cpd_fn___2(struct blkcg_policy_data___3 *);

typedef void blkcg_pol_bind_cpd_fn___2(struct blkcg_policy_data___3 *);

typedef struct blkg_policy_data___3 *blkcg_pol_alloc_pd_fn___2(gfp_t, struct request_queue___6 *, struct blkcg___3 *);

typedef void blkcg_pol_init_pd_fn___2(struct blkg_policy_data___3 *);

typedef void blkcg_pol_online_pd_fn___2(struct blkg_policy_data___3 *);

typedef void blkcg_pol_offline_pd_fn___2(struct blkg_policy_data___3 *);

typedef void blkcg_pol_free_pd_fn___2(struct blkg_policy_data___3 *);

typedef void blkcg_pol_reset_pd_stats_fn___2(struct blkg_policy_data___3 *);

typedef bool blkcg_pol_stat_pd_fn___2(struct blkg_policy_data___3 *, struct seq_file___154 *);

enum blkg_rwstat_type {
	BLKG_RWSTAT_READ = 0,
	BLKG_RWSTAT_WRITE = 1,
	BLKG_RWSTAT_SYNC = 2,
	BLKG_RWSTAT_ASYNC = 3,
	BLKG_RWSTAT_DISCARD = 4,
	BLKG_RWSTAT_NR = 5,
	BLKG_RWSTAT_TOTAL = 5,
};

struct blkg_rwstat {
	struct percpu_counter cpu_cnt[5];
	atomic64_t aux_cnt[5];
};

struct blkg_rwstat_sample {
	u64 cnt[5];
};

struct throtl_service_queue {
	struct throtl_service_queue *parent_sq;
	struct list_head queued[2];
	unsigned int nr_queued[2];
	struct rb_root_cached pending_tree;
	unsigned int nr_pending;
	long unsigned int first_pending_disptime;
	struct timer_list pending_timer;
};

struct latency_bucket {
	long unsigned int total_latency;
	int samples;
};

struct avg_latency_bucket {
	long unsigned int latency;
	bool valid;
};

struct throtl_data {
	struct throtl_service_queue service_queue;
	struct request_queue___6 *queue;
	unsigned int nr_queued[2];
	unsigned int throtl_slice;
	struct work_struct dispatch_work;
	unsigned int limit_index;
	bool limit_valid[2];
	long unsigned int low_upgrade_time;
	long unsigned int low_downgrade_time;
	unsigned int scale;
	struct latency_bucket tmp_buckets[18];
	struct avg_latency_bucket avg_buckets[18];
	struct latency_bucket *latency_buckets[2];
	long unsigned int last_calculate_time;
	long unsigned int filtered_latency;
	bool track_bio_latency;
};

typedef void (*poll_queue_proc___120)(struct file___177 *, wait_queue_head_t *, struct poll_table_struct___5 *);

typedef struct blkcg_policy_data___24 *blkcg_pol_alloc_cpd_fn___3(gfp_t);

typedef void blkcg_pol_init_cpd_fn___3(struct blkcg_policy_data___24 *);

typedef void blkcg_pol_free_cpd_fn___3(struct blkcg_policy_data___24 *);

typedef void blkcg_pol_bind_cpd_fn___3(struct blkcg_policy_data___24 *);

typedef struct blkg_policy_data___24 *blkcg_pol_alloc_pd_fn___3(gfp_t, struct request_queue___6 *, struct blkcg___24 *);

typedef void blkcg_pol_init_pd_fn___3(struct blkg_policy_data___24 *);

typedef void blkcg_pol_online_pd_fn___3(struct blkg_policy_data___24 *);

typedef void blkcg_pol_offline_pd_fn___3(struct blkg_policy_data___24 *);

typedef void blkcg_pol_free_pd_fn___3(struct blkg_policy_data___24 *);

typedef void blkcg_pol_reset_pd_stats_fn___3(struct blkg_policy_data___24 *);

typedef bool blkcg_pol_stat_pd_fn___3(struct blkg_policy_data___24 *, struct seq_file___154 *);

struct throtl_grp;

struct throtl_qnode {
	struct list_head node;
	struct bio_list___2 bios;
	struct throtl_grp *tg;
};

struct throtl_grp {
	struct blkg_policy_data___24 pd;
	struct rb_node rb_node;
	struct throtl_data *td;
	struct throtl_service_queue service_queue;
	struct throtl_qnode qnode_on_self[2];
	struct throtl_qnode qnode_on_parent[2];
	long unsigned int disptime;
	unsigned int flags;
	bool has_rules[2];
	uint64_t bps[4];
	uint64_t bps_conf[4];
	unsigned int iops[4];
	unsigned int iops_conf[4];
	uint64_t bytes_disp[2];
	unsigned int io_disp[2];
	long unsigned int last_low_overflow_time[2];
	uint64_t last_bytes_disp[2];
	unsigned int last_io_disp[2];
	long unsigned int last_check_time;
	long unsigned int latency_target;
	long unsigned int latency_target_conf;
	long unsigned int slice_start[2];
	long unsigned int slice_end[2];
	long unsigned int last_finish_time;
	long unsigned int checked_last_finish_time;
	long unsigned int avg_idletime;
	long unsigned int idletime_threshold;
	long unsigned int idletime_threshold_conf;
	unsigned int bio_cnt;
	unsigned int bad_bio_cnt;
	long unsigned int bio_cnt_reset_time;
	atomic_t io_split_cnt[2];
	atomic_t last_io_split_cnt[2];
	struct blkg_rwstat stat_bytes;
	struct blkg_rwstat stat_ios;
};

enum tg_state_flags {
	THROTL_TG_PENDING = 1,
	THROTL_TG_WAS_EMPTY = 2,
};

enum {
	LIMIT_LOW = 0,
	LIMIT_MAX = 1,
	LIMIT_CNT = 2,
};

typedef struct blkg_policy_data___80 *blkcg_pol_alloc_pd_fn___4(gfp_t, struct request_queue___6 *, struct blkcg___80 *);

typedef bool blkcg_pol_stat_pd_fn___4(struct blkg_policy_data___80 *, struct seq_file___154 *);

enum prio_policy {
	POLICY_NO_CHANGE = 0,
	POLICY_NONE_TO_RT = 1,
	POLICY_RESTRICT_TO_BE = 2,
	POLICY_ALL_TO_IDLE = 3,
};

struct ioprio_blkg {
	struct blkg_policy_data___80 pd;
};

struct ioprio_blkcg {
	struct blkcg_policy_data___80 cpd;
	enum prio_policy prio_policy;
};

struct blk_ioprio {
	struct rq_qos rqos;
};

struct dentry___179;

struct super_block___179;

struct module___163;

struct file_system_type___179 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___179 * (*mount)(struct file_system_type___179 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___179 *);
	struct module___163 *owner;
	struct file_system_type___179 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___179;

struct kiocb___179;

struct iov_iter___104;

struct poll_table_struct___117;

struct vm_area_struct___184;

struct inode___179;

struct file_lock___179;

struct page___184;

struct seq_file___156;

struct file_operations___179 {
	struct module___163 *owner;
	loff_t (*llseek)(struct file___179 *, loff_t, int);
	ssize_t (*read)(struct file___179 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___179 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___179 *, struct iov_iter___104 *);
	ssize_t (*write_iter)(struct kiocb___179 *, struct iov_iter___104 *);
	int (*iopoll)(struct kiocb___179 *, bool);
	int (*iterate)(struct file___179 *, struct dir_context *);
	int (*iterate_shared)(struct file___179 *, struct dir_context *);
	__poll_t (*poll)(struct file___179 *, struct poll_table_struct___117 *);
	long int (*unlocked_ioctl)(struct file___179 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___179 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___179 *, struct vm_area_struct___184 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___179 *, struct file___179 *);
	int (*flush)(struct file___179 *, fl_owner_t);
	int (*release)(struct inode___179 *, struct file___179 *);
	int (*fsync)(struct file___179 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___179 *, int);
	int (*lock)(struct file___179 *, int, struct file_lock___179 *);
	ssize_t (*sendpage)(struct file___179 *, struct page___184 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___179 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___179 *, long unsigned int);
	int (*flock)(struct file___179 *, int, struct file_lock___179 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___179 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___179 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___179 *, long int, struct file_lock___179 **, void **);
	long int (*fallocate)(struct file___179 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___156 *, struct file___179 *);
	ssize_t (*copy_file_range)(struct file___179 *, loff_t, struct file___179 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___179 *, loff_t, struct file___179 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___179 *, loff_t, loff_t, int);
};

struct vmacache___184 {
	u64 seqnum;
	struct vm_area_struct___184 *vmas[4];
};

struct page_frag___184 {
	struct page___184 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___72;

struct debug_info___72 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___72 *hbp_break[16];
	struct perf_event___72 *hbp_watch[16];
};

struct thread_struct___72 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___72 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___185;

struct pid___159;

struct nsproxy___168;

struct signal_struct___180;

struct bio_list___87;

struct io_context___87;

struct css_set___121;

struct perf_event_context___72;

struct request_queue___87;

struct vm_struct___162;

struct task_struct___186 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___186 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___185 *mm;
	struct mm_struct___185 *active_mm;
	struct vmacache___184 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___186 *real_parent;
	struct task_struct___186 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___186 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___159 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___168 *nsproxy;
	struct signal_struct___180 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___186 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___87 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___87 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___121 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___72 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___184 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___87 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___186 *oom_reaper_list;
	struct vm_struct___162 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___72 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___166;

struct kobj_type___166;

struct kernfs_node___166;

struct kobject___166 {
	const char *name;
	struct list_head entry;
	struct kobject___166 *parent;
	struct kset___166 *kset;
	struct kobj_type___166 *ktype;
	struct kernfs_node___166 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___163 {
	struct kobject___166 kobj;
	struct module___163 *mod;
	struct kobject___166 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___163 {
	struct module___163 *mod;
	struct latch_tree_node node;
};

struct module_layout___163 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___163 mtn;
};

struct module_attribute___163;

struct kernel_param___163;

struct trace_event_call___66;

struct module___163 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___163 mkobj;
	struct module_attribute___163 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___166 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___163 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___163 core_layout;
	struct module_layout___163 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___66 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___72 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___186 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___72)(struct perf_event___72 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___72;

struct fasync_struct___179;

struct pid_namespace___159;

struct perf_cgroup___72;

struct perf_event___72 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___72 *group_leader;
	struct pmu___72 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___72 hw;
	struct perf_event_context___72 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___72 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___186 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___179 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___72 *aux_event;
	void (*destroy)(struct perf_event___72 *);
	struct callback_head callback_head;
	struct pid_namespace___159 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___72 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___72 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___66 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___72 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___159 {
	int nr;
	struct pid_namespace___159 *ns;
};

struct pid_namespace___159 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___186 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___159 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___159 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___159 numbers[1];
};

typedef struct page___184 *pgtable_t___184;

struct address_space___179;

struct dev_pagemap___174;

struct page___184 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___179 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___184 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___184 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___185 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___174 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___174;

struct vm_area_struct___184 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___184 *vm_next;
	struct vm_area_struct___184 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___185 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___174 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___179 *vm_file;
	struct file___179 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___180 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___186 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___186 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___159 *pids[4];
	struct pid___159 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___185 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___184;

struct mm_struct___185 {
	struct {
		struct vm_area_struct___184 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___179 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___184 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___186 *owner;
		struct user_namespace___25 *user_ns;
		struct file___179 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___121;

struct nsproxy___168 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___159 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___121 *cgroup_ns;
};

struct bio___87;

struct bio_list___87 {
	struct bio___87 *head;
	struct bio___87 *tail;
};

struct io_cq___87;

struct io_context___87 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___87 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___121;

struct cgroup___121;

struct css_set___121 {
	struct cgroup_subsys_state___121 *subsys[14];
	refcount_t refcount;
	struct css_set___121 *dom_cset;
	struct cgroup___121 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___121 *mg_src_cgrp;
	struct cgroup___121 *mg_dst_cgrp;
	struct css_set___121 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___72 {
	struct pmu___72 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___186 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___72 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct blk_integrity_profile___87;

struct blk_integrity___87 {
	const struct blk_integrity_profile___87 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___87 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___87 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___87;

struct elevator_queue___87;

struct rq_qos___3;

struct blk_mq_ops___84;

struct blk_mq_hw_ctx___84;

struct gendisk___88;

struct device___132;

struct blk_stat_callback___8;

struct blkcg_gq___82;

struct blk_mq_tag_set___84;

struct request_queue___87 {
	struct request___87 *last_merge;
	struct elevator_queue___87 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos___3 *rq_qos;
	const struct blk_mq_ops___84 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___84 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___88 *disk;
	struct kobject___166 kobj;
	struct kobject___166 *mq_kobj;
	struct blk_integrity___87 integrity;
	struct device___132 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___8 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___82 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___84 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___87 bio_split;
	struct dentry___179 *debugfs_dir;
	struct dentry___179 *sched_debugfs_dir;
	struct dentry___179 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___162 {
	struct vm_struct___162 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___184 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___179;

struct address_space___179 {
	struct inode___179 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___179 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___174;

struct dev_pagemap___174 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___174 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___179;

struct path___179 {
	struct vfsmount___179 *mnt;
	struct dentry___179 *dentry;
};

struct fown_struct___159 {
	rwlock_t lock;
	struct pid___159 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___179 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___179 f_path;
	struct inode___179 *f_inode;
	const struct file_operations___179 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___159 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___179 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___174;

struct vm_operations_struct___174 {
	void (*open)(struct vm_area_struct___184 *);
	void (*close)(struct vm_area_struct___184 *);
	int (*may_split)(struct vm_area_struct___184 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___184 *);
	int (*mprotect)(struct vm_area_struct___184 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___174 *);
	vm_fault_t (*huge_fault)(struct vm_fault___174 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___174 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___184 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___174 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___174 *);
	int (*access)(struct vm_area_struct___184 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___184 *);
	int (*set_policy)(struct vm_area_struct___184 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___184 *, long unsigned int);
	struct page___184 * (*find_special_page)(struct vm_area_struct___184 *, long unsigned int);
};

struct core_thread___184 {
	struct task_struct___186 *task;
	struct core_thread___184 *next;
};

struct core_state___184 {
	atomic_t nr_threads;
	struct core_thread___184 dumper;
	struct completion startup;
};

struct vm_fault___174 {
	const struct {
		struct vm_area_struct___184 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___184 *cow_page;
	struct page___184 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___184 prealloc_pte;
};

struct dentry_operations___179;

struct dentry___179 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___179 *d_parent;
	struct qstr d_name;
	struct inode___179 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___179 *d_op;
	struct super_block___179 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___179;

struct inode___179 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___179 *i_op;
	struct super_block___179 *i_sb;
	struct address_space___179 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___179 *i_fop;
		void (*free_inode)(struct inode___179 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___179 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___33 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___179 {
	int (*d_revalidate)(struct dentry___179 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___179 *, unsigned int);
	int (*d_hash)(const struct dentry___179 *, struct qstr *);
	int (*d_compare)(const struct dentry___179 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___179 *);
	int (*d_init)(struct dentry___179 *);
	void (*d_release)(struct dentry___179 *);
	void (*d_prune)(struct dentry___179 *);
	void (*d_iput)(struct dentry___179 *, struct inode___179 *);
	char * (*d_dname)(struct dentry___179 *, char *, int);
	struct vfsmount___179 * (*d_automount)(struct path___179 *);
	int (*d_manage)(const struct path___179 *, bool);
	struct dentry___179 * (*d_real)(struct dentry___179 *, const struct inode___179 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___179;

struct mem_dqinfo___179 {
	struct quota_format_type___179 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___179;

struct quota_info___179 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___179 *files[3];
	struct mem_dqinfo___179 info[3];
	const struct quota_format_ops___179 *ops[3];
};

struct rcuwait___180 {
	struct task_struct___186 *task;
};

struct percpu_rw_semaphore___180 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___180 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___179 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___180 rw_sem[3];
};

struct super_operations___179;

struct dquot_operations___179;

struct quotactl_ops___179;

struct block_device___88;

struct super_block___179 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___179 *s_type;
	const struct super_operations___179 *s_op;
	const struct dquot_operations___179 *dq_op;
	const struct quotactl_ops___179 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___179 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___88 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___179 s_dquot;
	struct sb_writers___179 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___179 *s_d_op;
	int cleancache_poolid;
	struct shrinker___72 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___179 {
	struct dentry___179 *mnt_root;
	struct super_block___179 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct cgroup_subsys___121;

struct cgroup_subsys_state___121 {
	struct cgroup___121 *cgroup;
	struct cgroup_subsys___121 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___121 *parent;
};

struct cgroup_file___121 {
	struct kernfs_node___166 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___121 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___186 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___121;

struct cgroup_rstat_cpu___121;

struct cgroup___121 {
	struct cgroup_subsys_state___121 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___166 *kn;
	struct cgroup_file___121 procs_file;
	struct cgroup_file___121 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___121 *subsys[14];
	struct cgroup_root___121 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___121 *dom_cgrp;
	struct cgroup___121 *old_dom_cgrp;
	struct cgroup_rstat_cpu___121 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___121 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___87 {
	struct request_queue___87 *q;
	struct io_context___87 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___179 {
	struct file___179 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___179 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___80 *ki_waitq;
	};
};

struct iattr___179 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___179 *ia_file;
};

struct dquot___179 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___179 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___179 {
	int qf_fmt_id;
	const struct quota_format_ops___179 *qf_ops;
	struct module___163 *qf_owner;
	struct quota_format_type___179 *qf_next;
};

struct quota_format_ops___179 {
	int (*check_quota_file)(struct super_block___179 *, int);
	int (*read_file_info)(struct super_block___179 *, int);
	int (*write_file_info)(struct super_block___179 *, int);
	int (*free_file_info)(struct super_block___179 *, int);
	int (*read_dqblk)(struct dquot___179 *);
	int (*commit_dqblk)(struct dquot___179 *);
	int (*release_dqblk)(struct dquot___179 *);
	int (*get_next_id)(struct super_block___179 *, struct kqid *);
};

struct dquot_operations___179 {
	int (*write_dquot)(struct dquot___179 *);
	struct dquot___179 * (*alloc_dquot)(struct super_block___179 *, int);
	void (*destroy_dquot)(struct dquot___179 *);
	int (*acquire_dquot)(struct dquot___179 *);
	int (*release_dquot)(struct dquot___179 *);
	int (*mark_dirty)(struct dquot___179 *);
	int (*write_info)(struct super_block___179 *, int);
	qsize_t * (*get_reserved_space)(struct inode___179 *);
	int (*get_projid)(struct inode___179 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___179 *, qsize_t *);
	int (*get_next_id)(struct super_block___179 *, struct kqid *);
};

struct quotactl_ops___179 {
	int (*quota_on)(struct super_block___179 *, int, int, const struct path___179 *);
	int (*quota_off)(struct super_block___179 *, int);
	int (*quota_enable)(struct super_block___179 *, unsigned int);
	int (*quota_disable)(struct super_block___179 *, unsigned int);
	int (*quota_sync)(struct super_block___179 *, int);
	int (*set_info)(struct super_block___179 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___179 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___179 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___179 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___179 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___179 *, unsigned int);
};

struct address_space_operations___179 {
	int (*writepage)(struct page___184 *, struct writeback_control___3 *);
	int (*readpage)(struct file___179 *, struct page___184 *);
	int (*writepages)(struct address_space___179 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___184 *);
	int (*readpages)(struct file___179 *, struct address_space___179 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___179 *, struct address_space___179 *, loff_t, unsigned int, unsigned int, struct page___184 **, void **);
	int (*write_end)(struct file___179 *, struct address_space___179 *, loff_t, unsigned int, unsigned int, struct page___184 *, void *);
	sector_t (*bmap)(struct address_space___179 *, sector_t);
	void (*invalidatepage)(struct page___184 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___184 *, gfp_t);
	void (*freepage)(struct page___184 *);
	ssize_t (*direct_IO)(struct kiocb___179 *, struct iov_iter___104 *);
	int (*migratepage)(struct address_space___179 *, struct page___184 *, struct page___184 *, enum migrate_mode);
	bool (*isolate_page)(struct page___184 *, isolate_mode_t);
	void (*putback_page)(struct page___184 *);
	int (*launder_page)(struct page___184 *);
	int (*is_partially_uptodate)(struct page___184 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___184 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___179 *, struct page___184 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___179 *, sector_t *);
	void (*swap_deactivate)(struct file___179 *);
};

struct bio_vec___102;

struct iov_iter___104 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___102 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___179 {
	struct dentry___179 * (*lookup)(struct inode___179 *, struct dentry___179 *, unsigned int);
	const char * (*get_link)(struct dentry___179 *, struct inode___179 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___179 *, int);
	struct posix_acl * (*get_acl)(struct inode___179 *, int, bool);
	int (*readlink)(struct dentry___179 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___179 *, struct dentry___179 *, umode_t, bool);
	int (*link)(struct dentry___179 *, struct inode___179 *, struct dentry___179 *);
	int (*unlink)(struct inode___179 *, struct dentry___179 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___179 *, struct dentry___179 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___179 *, struct dentry___179 *, umode_t);
	int (*rmdir)(struct inode___179 *, struct dentry___179 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___179 *, struct dentry___179 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___179 *, struct dentry___179 *, struct inode___179 *, struct dentry___179 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___179 *, struct iattr___179 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___179 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___179 *, char *, size_t);
	int (*fiemap)(struct inode___179 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___179 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___179 *, struct dentry___179 *, struct file___179 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___179 *, struct dentry___179 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___179 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___179 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___179 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___179 {
	void (*fl_copy_lock)(struct file_lock___179 *, struct file_lock___179 *);
	void (*fl_release_private)(struct file_lock___179 *);
};

struct lock_manager_operations___179;

struct file_lock___179 {
	struct file_lock___179 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___179 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___179 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___179 *fl_ops;
	const struct lock_manager_operations___179 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___179 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___179 *);
	int (*lm_grant)(struct file_lock___179 *, int);
	bool (*lm_break)(struct file_lock___179 *);
	int (*lm_change)(struct file_lock___179 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___179 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___179 *);
};

struct fasync_struct___179 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___179 *fa_next;
	struct file___179 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___179 {
	struct inode___179 * (*alloc_inode)(struct super_block___179 *);
	void (*destroy_inode)(struct inode___179 *);
	void (*free_inode)(struct inode___179 *);
	void (*dirty_inode)(struct inode___179 *, int);
	int (*write_inode)(struct inode___179 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___179 *);
	void (*evict_inode)(struct inode___179 *);
	void (*put_super)(struct super_block___179 *);
	int (*sync_fs)(struct super_block___179 *, int);
	int (*freeze_super)(struct super_block___179 *);
	int (*freeze_fs)(struct super_block___179 *);
	int (*thaw_super)(struct super_block___179 *);
	int (*unfreeze_fs)(struct super_block___179 *);
	int (*statfs)(struct dentry___179 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___179 *, int *, char *);
	void (*umount_begin)(struct super_block___179 *);
	int (*show_options)(struct seq_file___156 *, struct dentry___179 *);
	int (*show_devname)(struct seq_file___156 *, struct dentry___179 *);
	int (*show_path)(struct seq_file___156 *, struct dentry___179 *);
	int (*show_stats)(struct seq_file___156 *, struct dentry___179 *);
	ssize_t (*quota_read)(struct super_block___179 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___179 *, int, const char *, size_t, loff_t);
	struct dquot___179 ** (*get_dquots)(struct inode___179 *);
	long int (*nr_cached_objects)(struct super_block___179 *, struct shrink_control___72 *);
	long int (*free_cached_objects)(struct super_block___179 *, struct shrink_control___72 *);
	struct file___179 * (*real_loop)(struct file___179 *);
};

struct wakeup_source___132;

struct dev_pm_info___132 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___132 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___132 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___132;

struct bus_type___132;

struct device_driver___132;

struct dev_pm_domain___132;

struct fwnode_handle___132;

struct class___132;

struct attribute_group___166;

struct device___132 {
	struct kobject___166 kobj;
	struct device___132 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___132 *type;
	struct bus_type___132 *bus;
	struct device_driver___132 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___132 power;
	struct dev_pm_domain___132 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___132 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___132 *class;
	const struct attribute_group___166 **groups;
	void (*release)(struct device___132 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___88 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___179 *bd_inode;
	struct super_block___179 *bd_super;
	void *bd_claiming;
	struct device___132 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___166 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___88 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___179 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___121)(struct file___179 *, wait_queue_head_t *, struct poll_table_struct___117 *);

struct poll_table_struct___117 {
	poll_queue_proc___121 _qproc;
	__poll_t _key;
};

struct seq_operations___156;

struct seq_file___156 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___156 *op;
	int poll_event;
	const struct file___179 *file;
	void *private;
};

typedef void bio_end_io_t___87(struct bio___87 *);

struct bio_vec___102 {
	struct page___184 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___87;

struct bio___87 {
	struct bio___87 *bi_next;
	struct block_device___88 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___87 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___82 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___87 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___102 *bi_io_vec;
	struct bio_set___87 *bi_pool;
	struct bio_vec___102 bi_inline_vecs[0];
};

struct kernfs_root___166;

struct kernfs_elem_dir___166 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___166 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___166;

struct kernfs_root___166 {
	struct kernfs_node___166 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___166 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___166 {
	struct kernfs_node___166 *target_kn;
};

struct kernfs_ops___166;

struct kernfs_elem_attr___166 {
	const struct kernfs_ops___166 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___166 *notify_next;
};

struct kernfs_node___166 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___166 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___166 dir;
		struct kernfs_elem_symlink___166 symlink;
		struct kernfs_elem_attr___166 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___166;

struct kernfs_ops___166 {
	int (*open)(struct kernfs_open_file___166 *);
	void (*release)(struct kernfs_open_file___166 *);
	int (*seq_show)(struct seq_file___156 *, void *);
	void * (*seq_start)(struct seq_file___156 *, loff_t *);
	void * (*seq_next)(struct seq_file___156 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___156 *, void *);
	ssize_t (*read)(struct kernfs_open_file___166 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___166 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___166 *, struct poll_table_struct___117 *);
	int (*mmap)(struct kernfs_open_file___166 *, struct vm_area_struct___184 *);
};

struct kernfs_syscall_ops___166 {
	int (*show_options)(struct seq_file___156 *, struct kernfs_root___166 *);
	int (*mkdir)(struct kernfs_node___166 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___166 *);
	int (*rename)(struct kernfs_node___166 *, struct kernfs_node___166 *, const char *);
	int (*show_path)(struct seq_file___156 *, struct kernfs_node___166 *, struct kernfs_root___166 *);
};

struct kernfs_open_file___166 {
	struct kernfs_node___166 *kn;
	struct file___179 *file;
	struct seq_file___156 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___174 *vm_ops;
};

struct bin_attribute___166;

struct attribute_group___166 {
	const char *name;
	umode_t (*is_visible)(struct kobject___166 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___166 *, struct bin_attribute___166 *, int);
	struct attribute **attrs;
	struct bin_attribute___166 **bin_attrs;
};

struct bin_attribute___166 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___179 * (*f_mapping)();
	ssize_t (*read)(struct file___179 *, struct kobject___166 *, struct bin_attribute___166 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___179 *, struct kobject___166 *, struct bin_attribute___166 *, char *, loff_t, size_t);
	int (*mmap)(struct file___179 *, struct kobject___166 *, struct bin_attribute___166 *, struct vm_area_struct___184 *);
};

struct sysfs_ops___166 {
	ssize_t (*show)(struct kobject___166 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___166 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___166;

struct kset___166 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___166 kobj;
	const struct kset_uevent_ops___166 *uevent_ops;
};

struct kobj_type___166 {
	void (*release)(struct kobject___166 *);
	const struct sysfs_ops___166 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___166 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___166 *);
	const void * (*namespace)(struct kobject___166 *);
	void (*get_ownership)(struct kobject___166 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___166 {
	int (* const filter)(struct kset___166 *, struct kobject___166 *);
	const char * (* const name)(struct kset___166 *, struct kobject___166 *);
	int (* const uevent)(struct kset___166 *, struct kobject___166 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___163 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___163 *);
	int (*get)(char *, const struct kernel_param___163 *);
	void (*free)(void *);
};

struct kparam_array___163;

struct kernel_param___163 {
	const char *name;
	struct module___163 *mod;
	const struct kernel_param_ops___163 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___163 *arr;
	};
};

struct kparam_array___163 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___163 *ops;
	void *elem;
};

struct module_attribute___163 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___163 *, struct module_kobject___163 *, char *);
	ssize_t (*store)(struct module_attribute___163 *, struct module_kobject___163 *, const char *, size_t);
	void (*setup)(struct module___163 *, const char *);
	int (*test)(struct module___163 *);
	void (*free)(struct module___163 *);
};

struct trace_event_class___66;

struct trace_event_call___66 {
	struct list_head list;
	struct trace_event_class___66 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___66 *, struct perf_event___72 *);
};

struct seq_operations___156 {
	void * (*start)(struct seq_file___156 *, loff_t *);
	void (*stop)(struct seq_file___156 *, void *);
	void * (*next)(struct seq_file___156 *, void *, loff_t *);
	int (*show)(struct seq_file___156 *, void *);
};

struct cgroup_namespace___121 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___121 *root_cset;
};

struct fwnode_operations___132;

struct fwnode_handle___132 {
	struct fwnode_handle___132 *secondary;
	const struct fwnode_operations___132 *ops;
	struct device___132 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___132;

struct fwnode_endpoint___132;

struct fwnode_operations___132 {
	struct fwnode_handle___132 * (*get)(struct fwnode_handle___132 *);
	void (*put)(struct fwnode_handle___132 *);
	bool (*device_is_available)(const struct fwnode_handle___132 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___132 *, const struct device___132 *);
	bool (*property_present)(const struct fwnode_handle___132 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___132 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___132 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___132 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*get_parent)(const struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*get_next_child_node)(const struct fwnode_handle___132 *, struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*get_named_child_node)(const struct fwnode_handle___132 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___132 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___132 *);
	struct fwnode_handle___132 * (*graph_get_next_endpoint)(const struct fwnode_handle___132 *, struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*graph_get_remote_endpoint)(const struct fwnode_handle___132 *);
	struct fwnode_handle___132 * (*graph_get_port_parent)(struct fwnode_handle___132 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___132 *, struct fwnode_endpoint___132 *);
	int (*add_links)(struct fwnode_handle___132 *);
};

struct fwnode_endpoint___132 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___132 *local_fwnode;
};

struct fwnode_reference_args___132 {
	struct fwnode_handle___132 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pagemap_ops___174 {
	void (*page_free)(struct page___184 *);
	void (*kill)(struct dev_pagemap___174 *);
	void (*cleanup)(struct dev_pagemap___174 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___174 *);
};

struct cftype___121;

struct cgroup_subsys___121 {
	struct cgroup_subsys_state___121 * (*css_alloc)(struct cgroup_subsys_state___121 *);
	int (*css_online)(struct cgroup_subsys_state___121 *);
	void (*css_offline)(struct cgroup_subsys_state___121 *);
	void (*css_released)(struct cgroup_subsys_state___121 *);
	void (*css_free)(struct cgroup_subsys_state___121 *);
	void (*css_reset)(struct cgroup_subsys_state___121 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___121 *, int);
	int (*css_extra_stat_show)(struct seq_file___156 *, struct cgroup_subsys_state___121 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___186 *, struct css_set___121 *);
	void (*cancel_fork)(struct task_struct___186 *, struct css_set___121 *);
	void (*fork)(struct task_struct___186 *);
	void (*exit)(struct task_struct___186 *);
	void (*release)(struct task_struct___186 *);
	void (*bind)(struct cgroup_subsys_state___121 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___121 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___121 *dfl_cftypes;
	struct cftype___121 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___121 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___121 *updated_children;
	struct cgroup___121 *updated_next;
};

struct cgroup_root___121 {
	struct kernfs_root___166 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___121 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___121 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___121 *ss;
	struct list_head node;
	struct kernfs_ops___166 *kf_ops;
	int (*open)(struct kernfs_open_file___166 *);
	void (*release)(struct kernfs_open_file___166 *);
	u64 (*read_u64)(struct cgroup_subsys_state___121 *, struct cftype___121 *);
	s64 (*read_s64)(struct cgroup_subsys_state___121 *, struct cftype___121 *);
	int (*seq_show)(struct seq_file___156 *, void *);
	void * (*seq_start)(struct seq_file___156 *, loff_t *);
	void * (*seq_next)(struct seq_file___156 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___156 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___121 *, struct cftype___121 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___121 *, struct cftype___121 *, s64);
	ssize_t (*write)(struct kernfs_open_file___166 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___166 *, struct poll_table_struct___117 *);
};

struct dev_pm_ops___132 {
	int (*prepare)(struct device___132 *);
	void (*complete)(struct device___132 *);
	int (*suspend)(struct device___132 *);
	int (*resume)(struct device___132 *);
	int (*freeze)(struct device___132 *);
	int (*thaw)(struct device___132 *);
	int (*poweroff)(struct device___132 *);
	int (*restore)(struct device___132 *);
	int (*suspend_late)(struct device___132 *);
	int (*resume_early)(struct device___132 *);
	int (*freeze_late)(struct device___132 *);
	int (*thaw_early)(struct device___132 *);
	int (*poweroff_late)(struct device___132 *);
	int (*restore_early)(struct device___132 *);
	int (*suspend_noirq)(struct device___132 *);
	int (*resume_noirq)(struct device___132 *);
	int (*freeze_noirq)(struct device___132 *);
	int (*thaw_noirq)(struct device___132 *);
	int (*poweroff_noirq)(struct device___132 *);
	int (*restore_noirq)(struct device___132 *);
	int (*runtime_suspend)(struct device___132 *);
	int (*runtime_resume)(struct device___132 *);
	int (*runtime_idle)(struct device___132 *);
};

struct wakeup_source___132 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___132 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___132 {
	struct dev_pm_ops___132 ops;
	int (*start)(struct device___132 *);
	void (*detach)(struct device___132 *, bool);
	int (*activate)(struct device___132 *);
	void (*sync)(struct device___132 *);
	void (*dismiss)(struct device___132 *);
};

struct bus_type___132 {
	const char *name;
	const char *dev_name;
	struct device___132 *dev_root;
	const struct attribute_group___166 **bus_groups;
	const struct attribute_group___166 **dev_groups;
	const struct attribute_group___166 **drv_groups;
	int (*match)(struct device___132 *, struct device_driver___132 *);
	int (*uevent)(struct device___132 *, struct kobj_uevent_env *);
	int (*probe)(struct device___132 *);
	void (*sync_state)(struct device___132 *);
	void (*remove)(struct device___132 *);
	void (*shutdown)(struct device___132 *);
	int (*online)(struct device___132 *);
	int (*offline)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	int (*num_vf)(struct device___132 *);
	int (*dma_configure)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___132 {
	const char *name;
	struct bus_type___132 *bus;
	struct module___163 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___132 *);
	void (*sync_state)(struct device___132 *);
	int (*remove)(struct device___132 *);
	void (*shutdown)(struct device___132 *);
	int (*suspend)(struct device___132 *, pm_message_t);
	int (*resume)(struct device___132 *);
	const struct attribute_group___166 **groups;
	const struct attribute_group___166 **dev_groups;
	const struct dev_pm_ops___132 *pm;
	void (*coredump)(struct device___132 *);
	struct driver_private *p;
};

struct device_type___132 {
	const char *name;
	const struct attribute_group___166 **groups;
	int (*uevent)(struct device___132 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___132 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___132 *);
	const struct dev_pm_ops___132 *pm;
};

struct class___132 {
	const char *name;
	struct module___163 *owner;
	const struct attribute_group___166 **class_groups;
	const struct attribute_group___166 **dev_groups;
	struct kobject___166 *dev_kobj;
	int (*dev_uevent)(struct device___132 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___132 *, umode_t *);
	void (*class_release)(struct class___132 *);
	void (*dev_release)(struct device___132 *);
	int (*shutdown_pre)(struct device___132 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___132 *);
	void (*get_ownership)(struct device___132 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___132 *pm;
	struct subsys_private *p;
};

struct block_device_operations___87;

struct gendisk___88 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___88 *part0;
	const struct block_device_operations___87 *fops;
	struct request_queue___87 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___166 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___166 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___87 {
	struct bio___87 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___102 *bip_vec;
	struct bio_vec___102 bip_inline_vecs[0];
};

struct blkcg___82;

struct blkg_policy_data___82;

struct blkcg_gq___82 {
	struct request_queue___87 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___82 *blkcg;
	struct blkcg_gq___82 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___82 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___87 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___87(struct request___87 *);

typedef void integrity_complete_fn___87(struct request___87 *, unsigned int);

struct blk_integrity_profile___87 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___87 *prepare_fn;
	integrity_complete_fn___87 *complete_fn;
	const char *name;
};

struct block_device_operations___87 {
	blk_qc_t (*submit_bio)(struct bio___87 *);
	int (*open)(struct block_device___88 *, fmode_t);
	void (*release)(struct gendisk___88 *, fmode_t);
	int (*rw_page)(struct block_device___88 *, sector_t, struct page___184 *, unsigned int);
	int (*ioctl)(struct block_device___88 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___88 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___88 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___88 *);
	int (*getgeo)(struct block_device___88 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___88 *, bool);
	void (*swap_slot_free_notify)(struct block_device___88 *, long unsigned int);
	int (*report_zones)(struct gendisk___88 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___88 *, umode_t *);
	struct module___163 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___88 *, sector_t *);
};

typedef void rq_end_io_fn___87(struct request___87 *, blk_status_t);

struct request___87 {
	struct request_queue___87 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___84 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___87 *bio;
	struct bio___87 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___102 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___87 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___87 *saved_end_io;
		} flush;
	};
	struct gendisk___88 *rq_disk;
	struct block_device___88 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___87 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___84 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___87 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___166 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___179 *debugfs_dir;
	struct dentry___179 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___87;

struct elevator_mq_ops___87 {
	int (*init_sched)(struct request_queue___87 *, struct elevator_type___87 *);
	void (*exit_sched)(struct elevator_queue___87 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___84 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___84 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___84 *);
	bool (*allow_merge)(struct request_queue___87 *, struct request___87 *, struct bio___87 *);
	bool (*bio_merge)(struct request_queue___87 *, struct bio___87 *, unsigned int);
	int (*request_merge)(struct request_queue___87 *, struct request___87 **, struct bio___87 *);
	void (*request_merged)(struct request_queue___87 *, struct request___87 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___87 *, struct request___87 *, struct request___87 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___87 *);
	void (*finish_request)(struct request___87 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___84 *, struct list_head *, bool);
	struct request___87 * (*dispatch_request)(struct blk_mq_hw_ctx___84 *);
	bool (*has_work)(struct blk_mq_hw_ctx___84 *);
	void (*completed_request)(struct request___87 *, u64);
	void (*requeue_request)(struct request___87 *);
	struct request___87 * (*former_request)(struct request_queue___87 *, struct request___87 *);
	struct request___87 * (*next_request)(struct request_queue___87 *, struct request___87 *);
	void (*init_icq)(struct io_cq___87 *);
	void (*exit_icq)(struct io_cq___87 *);
};

struct elv_fs_entry___87;

struct blk_mq_debugfs_attr___3;

struct elevator_type___87 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___87 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___87 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___163 *elevator_owner;
	const struct blk_mq_debugfs_attr___3 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___3 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___87 {
	struct elevator_type___87 *type;
	void *elevator_data;
	struct kobject___166 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___87 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___87 *, char *);
	ssize_t (*store)(struct elevator_queue___87 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___3 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___156 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___156 *seq_ops;
};

struct rq_qos_ops___3;

struct rq_qos___3 {
	struct rq_qos_ops___3 *ops;
	struct request_queue___87 *q;
	enum rq_qos_id id;
	struct rq_qos___3 *next;
	struct dentry___179 *debugfs_dir;
};

struct blk_mq_queue_data___84;

struct blk_mq_ops___84 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___84 *, const struct blk_mq_queue_data___84 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___84 *);
	int (*get_budget)(struct request_queue___87 *);
	void (*put_budget)(struct request_queue___87 *, int);
	void (*set_rq_budget_token)(struct request___87 *, int);
	int (*get_rq_budget_token)(struct request___87 *);
	enum blk_eh_timer_return (*timeout)(struct request___87 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___84 *);
	void (*complete)(struct request___87 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___84 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___84 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___84 *, struct request___87 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___84 *, struct request___87 *, unsigned int);
	void (*initialize_rq_fn)(struct request___87 *);
	void (*cleanup_rq)(struct request___87 *);
	bool (*busy)(struct request_queue___87 *);
	int (*map_queues)(struct blk_mq_tag_set___84 *);
	void (*show_rq)(struct seq_file___156 *, struct request___87 *);
};

struct blk_stat_callback___8 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___87 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___8 *);
	void *data;
	struct callback_head rcu;
};

struct blk_mq_tag_set___84 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___84 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___84 {
	struct request___87 *rq;
	bool last;
};

struct blkcg_policy_data___82;

struct blkcg___82 {
	struct cgroup_subsys_state___121 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___82 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___82 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___82 {
	struct blkcg___82 *blkcg;
	int plid;
};

struct blkg_policy_data___82 {
	struct blkcg_gq___82 *blkg;
	int plid;
};

typedef struct blkcg_policy_data___82 *blkcg_pol_alloc_cpd_fn___4(gfp_t);

typedef void blkcg_pol_init_cpd_fn___4(struct blkcg_policy_data___82 *);

typedef void blkcg_pol_free_cpd_fn___4(struct blkcg_policy_data___82 *);

typedef void blkcg_pol_bind_cpd_fn___4(struct blkcg_policy_data___82 *);

typedef struct blkg_policy_data___82 *blkcg_pol_alloc_pd_fn___5(gfp_t, struct request_queue___87 *, struct blkcg___82 *);

typedef void blkcg_pol_init_pd_fn___4(struct blkg_policy_data___82 *);

typedef void blkcg_pol_online_pd_fn___4(struct blkg_policy_data___82 *);

typedef void blkcg_pol_offline_pd_fn___4(struct blkg_policy_data___82 *);

typedef void blkcg_pol_free_pd_fn___4(struct blkg_policy_data___82 *);

typedef void blkcg_pol_reset_pd_stats_fn___4(struct blkg_policy_data___82 *);

typedef bool blkcg_pol_stat_pd_fn___5(struct blkg_policy_data___82 *, struct seq_file___156 *);

struct blkcg_policy___2 {
	int plid;
	struct cftype___121 *dfl_cftypes;
	struct cftype___121 *legacy_cftypes;
	blkcg_pol_alloc_cpd_fn___4 *cpd_alloc_fn;
	blkcg_pol_init_cpd_fn___4 *cpd_init_fn;
	blkcg_pol_free_cpd_fn___4 *cpd_free_fn;
	blkcg_pol_bind_cpd_fn___4 *cpd_bind_fn;
	blkcg_pol_alloc_pd_fn___5 *pd_alloc_fn;
	blkcg_pol_init_pd_fn___4 *pd_init_fn;
	blkcg_pol_online_pd_fn___4 *pd_online_fn;
	blkcg_pol_offline_pd_fn___4 *pd_offline_fn;
	blkcg_pol_free_pd_fn___4 *pd_free_fn;
	blkcg_pol_reset_pd_stats_fn___4 *pd_reset_stats_fn;
	blkcg_pol_stat_pd_fn___5 *pd_stat_fn;
};

struct blkg_conf_ctx___2 {
	struct block_device___88 *bdev;
	struct blkcg_gq___82 *blkg;
	char *body;
};

struct rq_qos_ops___3 {
	void (*throttle)(struct rq_qos___3 *, struct bio___87 *);
	void (*track)(struct rq_qos___3 *, struct request___87 *, struct bio___87 *);
	void (*merge)(struct rq_qos___3 *, struct request___87 *, struct bio___87 *);
	void (*issue)(struct rq_qos___3 *, struct request___87 *);
	void (*requeue)(struct rq_qos___3 *, struct request___87 *);
	void (*done)(struct rq_qos___3 *, struct request___87 *);
	void (*done_bio)(struct rq_qos___3 *, struct bio___87 *);
	void (*cleanup)(struct rq_qos___3 *, struct bio___87 *);
	void (*queue_depth_changed)(struct rq_qos___3 *);
	void (*exit)(struct rq_qos___3 *);
	const struct blk_mq_debugfs_attr___3 *debugfs_attrs;
};

enum {
	MILLION = 1000000,
	MIN_PERIOD = 1000,
	MAX_PERIOD = 1000000,
	MARGIN_MIN_PCT = 10,
	MARGIN_LOW_PCT = 20,
	MARGIN_TARGET_PCT = 50,
	INUSE_ADJ_STEP_PCT = 25,
	TIMER_SLACK_PCT = 1,
	WEIGHT_ONE = 65536,
	VTIME_PER_SEC_SHIFT = 37,
	VTIME_PER_SEC = 0,
	VTIME_PER_USEC = 137438,
	VTIME_PER_NSEC = 137,
	VRATE_MIN_PPM = 10000,
	VRATE_MAX_PPM = 100000000,
	VRATE_MIN = 1374,
	VRATE_CLAMP_ADJ_PCT = 4,
	RQ_WAIT_BUSY_PCT = 5,
	UNBUSY_THR_PCT = 75,
	MIN_DELAY_THR_PCT = 500,
	MAX_DELAY_THR_PCT = 25000,
	MIN_DELAY = 250,
	MAX_DELAY = 250000,
	DFGV_USAGE_PCT = 50,
	DFGV_PERIOD = 100000,
	MAX_LAGGING_PERIODS = 10,
	AUTOP_CYCLE_NSEC = 1410065408,
	IOC_PAGE_SHIFT = 12,
	IOC_PAGE_SIZE = 4096,
	IOC_SECT_TO_PAGE_SHIFT = 3,
	LCOEF_RANDIO_PAGES = 4096,
};

enum ioc_running {
	IOC_IDLE = 0,
	IOC_RUNNING = 1,
	IOC_STOP = 2,
};

enum {
	QOS_ENABLE = 0,
	QOS_CTRL = 1,
	NR_QOS_CTRL_PARAMS = 2,
};

enum {
	QOS_RPPM = 0,
	QOS_RLAT = 1,
	QOS_WPPM = 2,
	QOS_WLAT = 3,
	QOS_MIN = 4,
	QOS_MAX = 5,
	NR_QOS_PARAMS = 6,
};

enum {
	COST_CTRL = 0,
	COST_MODEL = 1,
	NR_COST_CTRL_PARAMS = 2,
};

enum {
	I_LCOEF_RBPS = 0,
	I_LCOEF_RSEQIOPS = 1,
	I_LCOEF_RRANDIOPS = 2,
	I_LCOEF_WBPS = 3,
	I_LCOEF_WSEQIOPS = 4,
	I_LCOEF_WRANDIOPS = 5,
	NR_I_LCOEFS = 6,
};

enum {
	LCOEF_RPAGE = 0,
	LCOEF_RSEQIO = 1,
	LCOEF_RRANDIO = 2,
	LCOEF_WPAGE = 3,
	LCOEF_WSEQIO = 4,
	LCOEF_WRANDIO = 5,
	NR_LCOEFS = 6,
};

enum {
	AUTOP_INVALID = 0,
	AUTOP_HDD = 1,
	AUTOP_SSD_QD1 = 2,
	AUTOP_SSD_DFL = 3,
	AUTOP_SSD_FAST = 4,
};

struct ioc_params {
	u32 qos[6];
	u64 i_lcoefs[6];
	u64 lcoefs[6];
	u32 too_fast_vrate_pct;
	u32 too_slow_vrate_pct;
};

struct ioc_margins {
	s64 min;
	s64 low;
	s64 target;
};

struct ioc_missed {
	local_t nr_met;
	local_t nr_missed;
	u32 last_met;
	u32 last_missed;
};

struct ioc_pcpu_stat {
	struct ioc_missed missed[2];
	local64_t rq_wait_ns;
	u64 last_rq_wait_ns;
};

struct ioc {
	struct rq_qos___3 rqos;
	bool enabled;
	struct ioc_params params;
	struct ioc_margins margins;
	u32 period_us;
	u32 timer_slack_ns;
	u64 vrate_min;
	u64 vrate_max;
	spinlock_t lock;
	struct timer_list timer;
	struct list_head active_iocgs;
	struct ioc_pcpu_stat *pcpu_stat;
	enum ioc_running running;
	atomic64_t vtime_rate;
	u64 vtime_base_rate;
	s64 vtime_err;
	seqcount_spinlock_t period_seqcount;
	u64 period_at;
	u64 period_at_vtime;
	atomic64_t cur_period;
	int busy_level;
	bool weights_updated;
	atomic_t hweight_gen;
	u64 dfgv_period_at;
	u64 dfgv_period_rem;
	u64 dfgv_usage_us_sum;
	u64 autop_too_fast_at;
	u64 autop_too_slow_at;
	int autop_idx;
	bool user_qos_params: 1;
	bool user_cost_model: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct iocg_pcpu_stat {
	local64_t abs_vusage;
};

struct iocg_stat {
	u64 usage_us;
	u64 wait_us;
	u64 indebt_us;
	u64 indelay_us;
};

struct ioc_gq {
	struct blkg_policy_data___82 pd;
	struct ioc *ioc;
	u32 cfg_weight;
	u32 weight;
	u32 active;
	u32 inuse;
	u32 last_inuse;
	s64 saved_margin;
	sector_t cursor;
	atomic64_t vtime;
	atomic64_t done_vtime;
	u64 abs_vdebt;
	u64 delay;
	u64 delay_at;
	atomic64_t active_period;
	struct list_head active_list;
	u64 child_active_sum;
	u64 child_inuse_sum;
	u64 child_adjusted_sum;
	int hweight_gen;
	u32 hweight_active;
	u32 hweight_inuse;
	u32 hweight_donating;
	u32 hweight_after_donation;
	struct list_head walk_list;
	struct list_head surplus_list;
	struct wait_queue_head waitq;
	struct hrtimer waitq_timer;
	u64 activated_at;
	struct iocg_pcpu_stat *pcpu_stat;
	struct iocg_stat local_stat;
	struct iocg_stat desc_stat;
	struct iocg_stat last_stat;
	u64 last_stat_abs_vusage;
	u64 usage_delta_us;
	u64 wait_since;
	u64 indebt_since;
	u64 indelay_since;
	int level;
	struct ioc_gq *ancestors[0];
};

struct ioc_cgrp {
	struct blkcg_policy_data___82 cpd;
	unsigned int dfl_weight;
};

struct ioc_now {
	u64 now_ns;
	u64 now;
	u64 vnow;
	u64 vrate;
};

struct iocg_wait {
	struct wait_queue_entry wait;
	struct bio___87 *bio;
	u64 abs_cost;
	bool committed;
};

struct iocg_wake_ctx {
	struct ioc_gq *iocg;
	u32 hw_inuse;
	s64 vbudget;
};

struct perf_cpu_context___72;

struct perf_output_handle___72;

struct pmu___72 {
	struct list_head entry;
	struct module___163 *module;
	struct device___132 *dev;
	const struct attribute_group___166 **attr_groups;
	const struct attribute_group___166 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___72 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___72 *);
	void (*pmu_disable)(struct pmu___72 *);
	int (*event_init)(struct perf_event___72 *);
	void (*event_mapped)(struct perf_event___72 *, struct mm_struct___185 *);
	void (*event_unmapped)(struct perf_event___72 *, struct mm_struct___185 *);
	int (*add)(struct perf_event___72 *, int);
	void (*del)(struct perf_event___72 *, int);
	void (*start)(struct perf_event___72 *, int);
	void (*stop)(struct perf_event___72 *, int);
	void (*read)(struct perf_event___72 *);
	void (*start_txn)(struct pmu___72 *, unsigned int);
	int (*commit_txn)(struct pmu___72 *);
	void (*cancel_txn)(struct pmu___72 *);
	int (*event_idx)(struct perf_event___72 *);
	void (*sched_task)(struct perf_event_context___72 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___72 *, struct perf_event_context___72 *);
	void * (*setup_aux)(struct perf_event___72 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___72 *, struct perf_output_handle___72 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___72 *);
	int (*aux_output_match)(struct perf_event___72 *);
	int (*filter_match)(struct perf_event___72 *);
	int (*check_period)(struct perf_event___72 *, u64);
};

struct perf_cpu_context___72 {
	struct perf_event_context___72 ctx;
	struct perf_event_context___72 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___72 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___72 **heap;
	struct perf_event___72 *heap_default[2];
};

struct perf_output_handle___72 {
	struct perf_event___72 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___72 {
	struct cgroup_subsys_state___121 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___66 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___66 *);
	};
};

struct trace_event_class___66 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___66 *, enum trace_reg, void *);
	struct trace_event_fields___66 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___66 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___66 *);
};

struct trace_event_file___29;

struct trace_event_buffer___28 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___29 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___29 {
	struct list_head list;
	struct trace_event_call___66 *event_call;
	struct event_filter *filter;
	struct dentry___179 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_iocost_iocg_state {
	struct trace_entry ent;
	u32 __data_loc_devname;
	u32 __data_loc_cgroup;
	u64 now;
	u64 vnow;
	u64 vrate;
	u64 last_period;
	u64 cur_period;
	u64 vtime;
	u32 weight;
	u32 inuse;
	u64 hweight_active;
	u64 hweight_inuse;
	char __data[0];
};

struct trace_event_raw_iocg_inuse_update {
	struct trace_entry ent;
	u32 __data_loc_devname;
	u32 __data_loc_cgroup;
	u64 now;
	u32 old_inuse;
	u32 new_inuse;
	u64 old_hweight_inuse;
	u64 new_hweight_inuse;
	char __data[0];
};

struct trace_event_raw_iocost_ioc_vrate_adj {
	struct trace_entry ent;
	u32 __data_loc_devname;
	u64 old_vrate;
	u64 new_vrate;
	int busy_level;
	u32 read_missed_ppm;
	u32 write_missed_ppm;
	u32 rq_wait_pct;
	int nr_lagging;
	int nr_shortages;
	char __data[0];
};

struct trace_event_raw_iocost_iocg_forgive_debt {
	struct trace_entry ent;
	u32 __data_loc_devname;
	u32 __data_loc_cgroup;
	u64 now;
	u64 vnow;
	u32 usage_pct;
	u64 old_debt;
	u64 new_debt;
	u64 old_delay;
	u64 new_delay;
	char __data[0];
};

struct trace_event_data_offsets_iocost_iocg_state {
	u32 devname;
	u32 cgroup;
};

struct trace_event_data_offsets_iocg_inuse_update {
	u32 devname;
	u32 cgroup;
};

struct trace_event_data_offsets_iocost_ioc_vrate_adj {
	u32 devname;
};

struct trace_event_data_offsets_iocost_iocg_forgive_debt {
	u32 devname;
	u32 cgroup;
};

typedef void (*btf_trace_iocost_iocg_activate)(void *, struct ioc_gq *, const char *, struct ioc_now *, u64, u64, u64);

typedef void (*btf_trace_iocost_iocg_idle)(void *, struct ioc_gq *, const char *, struct ioc_now *, u64, u64, u64);

typedef void (*btf_trace_iocost_inuse_shortage)(void *, struct ioc_gq *, const char *, struct ioc_now *, u32, u32, u64, u64);

typedef void (*btf_trace_iocost_inuse_transfer)(void *, struct ioc_gq *, const char *, struct ioc_now *, u32, u32, u64, u64);

typedef void (*btf_trace_iocost_inuse_adjust)(void *, struct ioc_gq *, const char *, struct ioc_now *, u32, u32, u64, u64);

typedef void (*btf_trace_iocost_ioc_vrate_adj)(void *, struct ioc *, u64, u32 *, u32, int, int);

typedef void (*btf_trace_iocost_iocg_forgive_debt)(void *, struct ioc_gq *, const char *, struct ioc_now *, u32, u64, u64, u64, u64);

typedef void (*poll_queue_proc___122)(struct file___177 *, wait_queue_head_t *, struct poll_table_struct___113 *);

enum dd_data_dir {
	DD_READ = 0,
	DD_WRITE = 1,
};

enum {
	DD_DIR_COUNT = 2,
};

enum dd_prio {
	DD_RT_PRIO = 0,
	DD_BE_PRIO = 1,
	DD_IDLE_PRIO = 2,
	DD_PRIO_MAX = 2,
};

enum {
	DD_PRIO_COUNT = 3,
};

struct io_stats_per_prio {
	local_t inserted;
	local_t merged;
	local_t dispatched;
	local_t completed;
};

struct io_stats {
	struct io_stats_per_prio stats[3];
};

struct dd_per_prio {
	struct list_head dispatch;
	struct rb_root sort_list[2];
	struct list_head fifo_list[2];
	struct request___85 *next_rq[2];
};

struct deadline_data {
	struct dd_per_prio per_prio[3];
	enum dd_data_dir last_dir;
	unsigned int batching;
	unsigned int starved;
	struct io_stats *stats;
	int fifo_expire[2];
	int fifo_batch;
	int writes_starved;
	int front_merges;
	u32 async_depth;
	spinlock_t lock;
	spinlock_t zone_lock;
};

enum bip_flags {
	BIP_BLOCK_INTEGRITY = 1,
	BIP_MAPPED_INTEGRITY = 2,
	BIP_CTRL_NOCHECK = 4,
	BIP_DISK_NOCHECK = 8,
	BIP_IP_CHECKSUM = 16,
};

enum blk_integrity_flags {
	BLK_INTEGRITY_VERIFY = 1,
	BLK_INTEGRITY_GENERATE = 2,
	BLK_INTEGRITY_DEVICE_CAPABLE = 4,
	BLK_INTEGRITY_IP_CHECKSUM = 8,
};

struct integrity_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct blk_integrity___25 *, char *);
	ssize_t (*store)(struct blk_integrity___25 *, const char *, size_t);
};

enum t10_dif_type {
	T10_PI_TYPE0_PROTECTION = 0,
	T10_PI_TYPE1_PROTECTION = 1,
	T10_PI_TYPE2_PROTECTION = 2,
	T10_PI_TYPE3_PROTECTION = 3,
};

struct t10_pi_tuple {
	__be16 guard_tag;
	__be16 app_tag;
	__be32 ref_tag;
};

typedef __be16 csum_fn(void *, unsigned int);

struct pci_bus___2;

struct pci_slot___2 {
	struct pci_bus___2 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___166 kobj;
};

struct pci_dev___2;

struct pci_ops___2;

struct pci_bus___2 {
	struct list_head node;
	struct pci_bus___2 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___2 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___2 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___132 *bridge;
	struct device___132 dev;
	struct bin_attribute___166 *legacy_io;
	struct bin_attribute___166 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___2;

struct pci_dev___2 {
	struct list_head bus_list;
	struct pci_bus___2 *bus;
	struct pci_bus___2 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___2 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___2 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___2 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___132 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___166 *res_attr[17];
	struct bin_attribute___166 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___166 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___2 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___2;

struct pci_driver___2 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___2 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___2 *);
	int (*suspend)(struct pci_dev___2 *, pm_message_t);
	int (*resume)(struct pci_dev___2 *);
	void (*shutdown)(struct pci_dev___2 *);
	int (*sriov_configure)(struct pci_dev___2 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___2 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___2 *);
	const struct pci_error_handlers___2 *err_handler;
	const struct attribute_group___166 **groups;
	const struct attribute_group___166 **dev_groups;
	struct device_driver___50 driver;
	struct pci_dynids dynids;
};

struct pci_ops___2 {
	int (*add_bus)(struct pci_bus___2 *);
	void (*remove_bus)(struct pci_bus___2 *);
	void * (*map_bus)(struct pci_bus___2 *, unsigned int, int);
	int (*read)(struct pci_bus___2 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___2 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___2 {
	pci_ers_result_t (*error_detected)(struct pci_dev___2 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___2 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___2 *);
	void (*reset_prepare)(struct pci_dev___2 *);
	void (*reset_done)(struct pci_dev___2 *);
	void (*resume)(struct pci_dev___2 *);
};

struct virtio_device_id {
	__u32 device;
	__u32 vendor;
};

struct virtio_device;

struct virtqueue {
	struct list_head list;
	void (*callback)(struct virtqueue *);
	const char *name;
	struct virtio_device *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct vringh_config_ops;

struct virtio_config_ops;

struct virtio_device {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___132 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t(struct virtqueue *);

struct virtio_shm_region;

struct virtio_config_ops {
	void (*get)(struct virtio_device *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device *);
	u8 (*get_status)(struct virtio_device *);
	void (*set_status)(struct virtio_device *, u8);
	void (*reset)(struct virtio_device *);
	int (*find_vqs)(struct virtio_device *, unsigned int, struct virtqueue **, vq_callback_t **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device *);
	u64 (*get_features)(struct virtio_device *);
	int (*finalize_features)(struct virtio_device *);
	const char * (*bus_name)(struct virtio_device *);
	int (*set_vq_affinity)(struct virtqueue *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device *, int);
	bool (*get_shm_region)(struct virtio_device *, struct virtio_shm_region *, u8);
};

struct virtio_shm_region {
	u64 addr;
	u64 len;
};

struct irq_poll;

typedef int irq_poll_fn(struct irq_poll *, int);

struct irq_poll {
	struct list_head list;
	long unsigned int state;
	int weight;
	irq_poll_fn *poll;
};

struct rdma_cgroup___2 {
	struct cgroup_subsys_state___109 css;
	struct list_head rpools;
};

struct dim_sample {
	ktime_t time;
	u32 pkt_ctr;
	u32 byte_ctr;
	u16 event_ctr;
	u32 comp_ctr;
};

struct dim_stats {
	int ppms;
	int bpms;
	int epms;
	int cpms;
	int cpe_ratio;
};

struct dim {
	u8 state;
	struct dim_stats prev_stats;
	struct dim_sample start_sample;
	struct dim_sample measuring_sample;
	struct work_struct work;
	void *priv;
	u8 profile_ix;
	u8 mode;
	u8 tune_state;
	u8 steps_right;
	u8 steps_left;
	u8 tired;
};

enum rdma_nl_counter_mode {
	RDMA_COUNTER_MODE_NONE = 0,
	RDMA_COUNTER_MODE_AUTO = 1,
	RDMA_COUNTER_MODE_MANUAL = 2,
	RDMA_COUNTER_MODE_MAX = 3,
};

enum rdma_nl_counter_mask {
	RDMA_COUNTER_MASK_QP_TYPE = 1,
	RDMA_COUNTER_MASK_PID = 2,
};

enum rdma_restrack_type {
	RDMA_RESTRACK_PD = 0,
	RDMA_RESTRACK_CQ = 1,
	RDMA_RESTRACK_QP = 2,
	RDMA_RESTRACK_CM_ID = 3,
	RDMA_RESTRACK_MR = 4,
	RDMA_RESTRACK_CTX = 5,
	RDMA_RESTRACK_COUNTER = 6,
	RDMA_RESTRACK_SRQ = 7,
	RDMA_RESTRACK_MAX = 8,
};

struct rdma_restrack_entry {
	bool valid;
	u8 no_track: 1;
	struct kref kref;
	struct completion comp;
	struct task_struct___167 *task;
	const char *kern_name;
	enum rdma_restrack_type type;
	bool user;
	u32 id;
};

struct rdma_link_ops {
	struct list_head list;
	const char *type;
	int (*newlink)(const char *, struct net_device___2 *);
};

struct auto_mode_param {
	int qp_type;
};

struct rdma_counter_mode {
	enum rdma_nl_counter_mode mode;
	enum rdma_nl_counter_mask mask;
	struct auto_mode_param param;
};

struct rdma_hw_stats;

struct rdma_port_counter {
	struct rdma_counter_mode mode;
	struct rdma_hw_stats *hstats;
	unsigned int num_counters;
	struct mutex lock;
};

struct rdma_hw_stats {
	struct mutex lock;
	long unsigned int timestamp;
	long unsigned int lifespan;
	const char * const *names;
	int num_counters;
	u64 value[0];
};

struct ib_device;

struct rdma_counter {
	struct rdma_restrack_entry res;
	struct ib_device *device;
	uint32_t id;
	struct kref kref;
	struct rdma_counter_mode mode;
	struct mutex lock;
	struct rdma_hw_stats *stats;
	u32 port;
};

enum rdma_driver_id {
	RDMA_DRIVER_UNKNOWN = 0,
	RDMA_DRIVER_MLX5 = 1,
	RDMA_DRIVER_MLX4 = 2,
	RDMA_DRIVER_CXGB3 = 3,
	RDMA_DRIVER_CXGB4 = 4,
	RDMA_DRIVER_MTHCA = 5,
	RDMA_DRIVER_BNXT_RE = 6,
	RDMA_DRIVER_OCRDMA = 7,
	RDMA_DRIVER_NES = 8,
	RDMA_DRIVER_I40IW = 9,
	RDMA_DRIVER_IRDMA = 9,
	RDMA_DRIVER_VMW_PVRDMA = 10,
	RDMA_DRIVER_QEDR = 11,
	RDMA_DRIVER_HNS = 12,
	RDMA_DRIVER_USNIC = 13,
	RDMA_DRIVER_RXE = 14,
	RDMA_DRIVER_HFI1 = 15,
	RDMA_DRIVER_QIB = 16,
	RDMA_DRIVER_EFA = 17,
	RDMA_DRIVER_SIW = 18,
};

enum ib_cq_notify_flags {
	IB_CQ_SOLICITED = 1,
	IB_CQ_NEXT_COMP = 2,
	IB_CQ_SOLICITED_MASK = 3,
	IB_CQ_REPORT_MISSED_EVENTS = 4,
};

struct ib_mad;

enum rdma_link_layer {
	IB_LINK_LAYER_UNSPECIFIED = 0,
	IB_LINK_LAYER_INFINIBAND = 1,
	IB_LINK_LAYER_ETHERNET = 2,
};

enum rdma_netdev_t {
	RDMA_NETDEV_OPA_VNIC = 0,
	RDMA_NETDEV_IPOIB = 1,
};

enum ib_srq_attr_mask {
	IB_SRQ_MAX_WR = 1,
	IB_SRQ_LIMIT = 2,
};

enum ib_mr_type {
	IB_MR_TYPE_MEM_REG = 0,
	IB_MR_TYPE_SG_GAPS = 1,
	IB_MR_TYPE_DM = 2,
	IB_MR_TYPE_USER = 3,
	IB_MR_TYPE_DMA = 4,
	IB_MR_TYPE_INTEGRITY = 5,
};

enum ib_uverbs_advise_mr_advice {
	IB_UVERBS_ADVISE_MR_ADVICE_PREFETCH = 0,
	IB_UVERBS_ADVISE_MR_ADVICE_PREFETCH_WRITE = 1,
	IB_UVERBS_ADVISE_MR_ADVICE_PREFETCH_NO_FAULT = 2,
};

struct uverbs_attr_bundle;

struct rdma_cm_id;

struct iw_cm_id;

struct iw_cm_conn_param;

struct ib_qp;

struct ib_send_wr;

struct ib_recv_wr;

struct ib_cq;

struct ib_wc;

struct ib_srq;

struct ib_grh;

struct ib_device_attr;

struct ib_udata;

struct ib_device_modify;

struct ib_port_attr;

struct ib_port_modify;

struct ib_port_immutable;

struct rdma_netdev_alloc_params;

union ib_gid;

struct ib_gid_attr;

struct ib_ucontext;

struct rdma_user_mmap_entry;

struct ib_pd;

struct ib_ah;

struct rdma_ah_init_attr;

struct rdma_ah_attr;

struct ib_srq_init_attr;

struct ib_srq_attr;

struct ib_qp_init_attr;

struct ib_qp_attr;

struct ib_cq_init_attr;

struct ib_mr;

struct ib_sge;

struct ib_mr_status;

struct ib_mw;

struct ib_xrcd;

struct ib_flow;

struct ib_flow_attr;

struct ib_flow_action;

struct ib_flow_action_attrs_esp;

struct ib_wq;

struct ib_wq_init_attr;

struct ib_wq_attr;

struct ib_rwq_ind_table;

struct ib_rwq_ind_table_init_attr;

struct ib_dm;

struct ib_dm_alloc_attr;

struct ib_dm_mr_attr;

struct ib_counters;

struct ib_counters_read_attr;

struct ib_device_ops {
	struct module___4 *owner;
	enum rdma_driver_id driver_id;
	u32 uverbs_abi_ver;
	unsigned int uverbs_no_driver_id_binding: 1;
	long: 63;
	long: 64;
	long: 64;
	const struct attribute_group___147 *device_group;
	const struct attribute_group___147 **port_groups;
	int (*post_send)(struct ib_qp *, const struct ib_send_wr *, const struct ib_send_wr **);
	int (*post_recv)(struct ib_qp *, const struct ib_recv_wr *, const struct ib_recv_wr **);
	void (*drain_rq)(struct ib_qp *);
	void (*drain_sq)(struct ib_qp *);
	int (*poll_cq)(struct ib_cq *, int, struct ib_wc *);
	int (*peek_cq)(struct ib_cq *, int);
	int (*req_notify_cq)(struct ib_cq *, enum ib_cq_notify_flags);
	int (*post_srq_recv)(struct ib_srq *, const struct ib_recv_wr *, const struct ib_recv_wr **);
	int (*process_mad)(struct ib_device *, int, u32, const struct ib_wc *, const struct ib_grh *, const struct ib_mad *, struct ib_mad *, size_t *, u16 *);
	int (*query_device)(struct ib_device *, struct ib_device_attr *, struct ib_udata *);
	int (*modify_device)(struct ib_device *, int, struct ib_device_modify *);
	void (*get_dev_fw_str)(struct ib_device *, char *);
	const struct cpumask * (*get_vector_affinity)(struct ib_device *, int);
	int (*query_port)(struct ib_device *, u32, struct ib_port_attr *);
	int (*modify_port)(struct ib_device *, u32, int, struct ib_port_modify *);
	int (*get_port_immutable)(struct ib_device *, u32, struct ib_port_immutable *);
	enum rdma_link_layer (*get_link_layer)(struct ib_device *, u32);
	struct net_device___2 * (*get_netdev)(struct ib_device *, u32);
	struct net_device___2 * (*alloc_rdma_netdev)(struct ib_device *, u32, enum rdma_netdev_t, const char *, unsigned char, void (*)(struct net_device___2 *));
	int (*rdma_netdev_get_params)(struct ib_device *, u32, enum rdma_netdev_t, struct rdma_netdev_alloc_params *);
	int (*query_gid)(struct ib_device *, u32, int, union ib_gid *);
	int (*add_gid)(const struct ib_gid_attr *, void **);
	int (*del_gid)(const struct ib_gid_attr *, void **);
	int (*query_pkey)(struct ib_device *, u32, u16, u16 *);
	int (*alloc_ucontext)(struct ib_ucontext *, struct ib_udata *);
	void (*dealloc_ucontext)(struct ib_ucontext *);
	int (*mmap)(struct ib_ucontext *, struct vm_area_struct___165 *);
	void (*mmap_free)(struct rdma_user_mmap_entry *);
	void (*disassociate_ucontext)(struct ib_ucontext *);
	int (*alloc_pd)(struct ib_pd *, struct ib_udata *);
	int (*dealloc_pd)(struct ib_pd *, struct ib_udata *);
	int (*create_ah)(struct ib_ah *, struct rdma_ah_init_attr *, struct ib_udata *);
	int (*create_user_ah)(struct ib_ah *, struct rdma_ah_init_attr *, struct ib_udata *);
	int (*modify_ah)(struct ib_ah *, struct rdma_ah_attr *);
	int (*query_ah)(struct ib_ah *, struct rdma_ah_attr *);
	int (*destroy_ah)(struct ib_ah *, u32);
	int (*create_srq)(struct ib_srq *, struct ib_srq_init_attr *, struct ib_udata *);
	int (*modify_srq)(struct ib_srq *, struct ib_srq_attr *, enum ib_srq_attr_mask, struct ib_udata *);
	int (*query_srq)(struct ib_srq *, struct ib_srq_attr *);
	int (*destroy_srq)(struct ib_srq *, struct ib_udata *);
	int (*create_qp)(struct ib_qp *, struct ib_qp_init_attr *, struct ib_udata *);
	int (*modify_qp)(struct ib_qp *, struct ib_qp_attr *, int, struct ib_udata *);
	int (*query_qp)(struct ib_qp *, struct ib_qp_attr *, int, struct ib_qp_init_attr *);
	int (*destroy_qp)(struct ib_qp *, struct ib_udata *);
	int (*create_cq)(struct ib_cq *, const struct ib_cq_init_attr *, struct ib_udata *);
	int (*modify_cq)(struct ib_cq *, u16, u16);
	int (*destroy_cq)(struct ib_cq *, struct ib_udata *);
	int (*resize_cq)(struct ib_cq *, int, struct ib_udata *);
	struct ib_mr * (*get_dma_mr)(struct ib_pd *, int);
	struct ib_mr * (*reg_user_mr)(struct ib_pd *, u64, u64, u64, int, struct ib_udata *);
	struct ib_mr * (*reg_user_mr_dmabuf)(struct ib_pd *, u64, u64, u64, int, int, struct ib_udata *);
	struct ib_mr * (*rereg_user_mr)(struct ib_mr *, int, u64, u64, u64, int, struct ib_pd *, struct ib_udata *);
	int (*dereg_mr)(struct ib_mr *, struct ib_udata *);
	struct ib_mr * (*alloc_mr)(struct ib_pd *, enum ib_mr_type, u32);
	struct ib_mr * (*alloc_mr_integrity)(struct ib_pd *, u32, u32);
	int (*advise_mr)(struct ib_pd *, enum ib_uverbs_advise_mr_advice, u32, struct ib_sge *, u32, struct uverbs_attr_bundle *);
	int (*map_mr_sg)(struct ib_mr *, struct scatterlist *, int, unsigned int *);
	int (*check_mr_status)(struct ib_mr *, u32, struct ib_mr_status *);
	int (*alloc_mw)(struct ib_mw *, struct ib_udata *);
	int (*dealloc_mw)(struct ib_mw *);
	int (*attach_mcast)(struct ib_qp *, union ib_gid *, u16);
	int (*detach_mcast)(struct ib_qp *, union ib_gid *, u16);
	int (*alloc_xrcd)(struct ib_xrcd *, struct ib_udata *);
	int (*dealloc_xrcd)(struct ib_xrcd *, struct ib_udata *);
	struct ib_flow * (*create_flow)(struct ib_qp *, struct ib_flow_attr *, struct ib_udata *);
	int (*destroy_flow)(struct ib_flow *);
	struct ib_flow_action * (*create_flow_action_esp)(struct ib_device *, const struct ib_flow_action_attrs_esp *, struct uverbs_attr_bundle *);
	int (*destroy_flow_action)(struct ib_flow_action *);
	int (*modify_flow_action_esp)(struct ib_flow_action *, const struct ib_flow_action_attrs_esp *, struct uverbs_attr_bundle *);
	int (*set_vf_link_state)(struct ib_device *, int, u32, int);
	int (*get_vf_config)(struct ib_device *, int, u32, struct ifla_vf_info *);
	int (*get_vf_stats)(struct ib_device *, int, u32, struct ifla_vf_stats *);
	int (*get_vf_guid)(struct ib_device *, int, u32, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*set_vf_guid)(struct ib_device *, int, u32, u64, int);
	struct ib_wq * (*create_wq)(struct ib_pd *, struct ib_wq_init_attr *, struct ib_udata *);
	int (*destroy_wq)(struct ib_wq *, struct ib_udata *);
	int (*modify_wq)(struct ib_wq *, struct ib_wq_attr *, u32, struct ib_udata *);
	int (*create_rwq_ind_table)(struct ib_rwq_ind_table *, struct ib_rwq_ind_table_init_attr *, struct ib_udata *);
	int (*destroy_rwq_ind_table)(struct ib_rwq_ind_table *);
	struct ib_dm * (*alloc_dm)(struct ib_device *, struct ib_ucontext *, struct ib_dm_alloc_attr *, struct uverbs_attr_bundle *);
	int (*dealloc_dm)(struct ib_dm *, struct uverbs_attr_bundle *);
	struct ib_mr * (*reg_dm_mr)(struct ib_pd *, struct ib_dm *, struct ib_dm_mr_attr *, struct uverbs_attr_bundle *);
	int (*create_counters)(struct ib_counters *, struct uverbs_attr_bundle *);
	int (*destroy_counters)(struct ib_counters *);
	int (*read_counters)(struct ib_counters *, struct ib_counters_read_attr *, struct uverbs_attr_bundle *);
	int (*map_mr_sg_pi)(struct ib_mr *, struct scatterlist *, int, unsigned int *, struct scatterlist *, int, unsigned int *);
	struct rdma_hw_stats * (*alloc_hw_device_stats)(struct ib_device *);
	struct rdma_hw_stats * (*alloc_hw_port_stats)(struct ib_device *, u32);
	int (*get_hw_stats)(struct ib_device *, struct rdma_hw_stats *, u32, int);
	int (*fill_res_mr_entry)(struct sk_buff___2 *, struct ib_mr *);
	int (*fill_res_mr_entry_raw)(struct sk_buff___2 *, struct ib_mr *);
	int (*fill_res_cq_entry)(struct sk_buff___2 *, struct ib_cq *);
	int (*fill_res_cq_entry_raw)(struct sk_buff___2 *, struct ib_cq *);
	int (*fill_res_qp_entry)(struct sk_buff___2 *, struct ib_qp *);
	int (*fill_res_qp_entry_raw)(struct sk_buff___2 *, struct ib_qp *);
	int (*fill_res_cm_id_entry)(struct sk_buff___2 *, struct rdma_cm_id *);
	int (*enable_driver)(struct ib_device *);
	void (*dealloc_driver)(struct ib_device *);
	void (*iw_add_ref)(struct ib_qp *);
	void (*iw_rem_ref)(struct ib_qp *);
	struct ib_qp * (*iw_get_qp)(struct ib_device *, int);
	int (*iw_connect)(struct iw_cm_id *, struct iw_cm_conn_param *);
	int (*iw_accept)(struct iw_cm_id *, struct iw_cm_conn_param *);
	int (*iw_reject)(struct iw_cm_id *, const void *, u8);
	int (*iw_create_listen)(struct iw_cm_id *, int);
	int (*iw_destroy_listen)(struct iw_cm_id *);
	int (*counter_bind_qp)(struct rdma_counter *, struct ib_qp *);
	int (*counter_unbind_qp)(struct ib_qp *);
	int (*counter_dealloc)(struct rdma_counter *);
	struct rdma_hw_stats * (*counter_alloc_stats)(struct rdma_counter *);
	int (*counter_update_stats)(struct rdma_counter *);
	int (*fill_stat_mr_entry)(struct sk_buff___2 *, struct ib_mr *);
	int (*query_ucontext)(struct ib_ucontext *, struct uverbs_attr_bundle *);
	int (*get_numa_node)(struct ib_device *);
	size_t size_ib_ah;
	size_t size_ib_counters;
	size_t size_ib_cq;
	size_t size_ib_mw;
	size_t size_ib_pd;
	size_t size_ib_qp;
	size_t size_ib_rwq_ind_table;
	size_t size_ib_srq;
	size_t size_ib_ucontext;
	size_t size_ib_xrcd;
};

struct ib_core_device {
	struct device___116 dev;
	possible_net_t___28 rdma_net;
	struct kobject___147 *ports_kobj;
	struct list_head port_list;
	struct ib_device *owner;
};

enum ib_atomic_cap {
	IB_ATOMIC_NONE = 0,
	IB_ATOMIC_HCA = 1,
	IB_ATOMIC_GLOB = 2,
};

struct ib_odp_caps {
	uint64_t general_caps;
	struct {
		uint32_t rc_odp_caps;
		uint32_t uc_odp_caps;
		uint32_t ud_odp_caps;
		uint32_t xrc_odp_caps;
	} per_transport_caps;
};

struct ib_rss_caps {
	u32 supported_qpts;
	u32 max_rwq_indirection_tables;
	u32 max_rwq_indirection_table_size;
};

struct ib_tm_caps {
	u32 max_rndv_hdr_size;
	u32 max_num_tags;
	u32 flags;
	u32 max_ops;
	u32 max_sge;
};

struct ib_cq_caps {
	u16 max_cq_moderation_count;
	u16 max_cq_moderation_period;
};

struct ib_device_attr {
	u64 fw_ver;
	__be64 sys_image_guid;
	u64 max_mr_size;
	u64 page_size_cap;
	u32 vendor_id;
	u32 vendor_part_id;
	u32 hw_ver;
	int max_qp;
	int max_qp_wr;
	u64 device_cap_flags;
	int max_send_sge;
	int max_recv_sge;
	int max_sge_rd;
	int max_cq;
	int max_cqe;
	int max_mr;
	int max_pd;
	int max_qp_rd_atom;
	int max_ee_rd_atom;
	int max_res_rd_atom;
	int max_qp_init_rd_atom;
	int max_ee_init_rd_atom;
	enum ib_atomic_cap atomic_cap;
	enum ib_atomic_cap masked_atomic_cap;
	int max_ee;
	int max_rdd;
	int max_mw;
	int max_raw_ipv6_qp;
	int max_raw_ethy_qp;
	int max_mcast_grp;
	int max_mcast_qp_attach;
	int max_total_mcast_qp_attach;
	int max_ah;
	int max_srq;
	int max_srq_wr;
	int max_srq_sge;
	unsigned int max_fast_reg_page_list_len;
	unsigned int max_pi_fast_reg_page_list_len;
	u16 max_pkeys;
	u8 local_ca_ack_delay;
	int sig_prot_cap;
	int sig_guard_cap;
	struct ib_odp_caps odp_caps;
	uint64_t timestamp_mask;
	uint64_t hca_core_clock;
	struct ib_rss_caps rss_caps;
	u32 max_wq_type_rq;
	u32 raw_packet_caps;
	struct ib_tm_caps tm_caps;
	struct ib_cq_caps cq_caps;
	u64 max_dm_size;
	u32 max_sgl_rd;
};

struct hw_stats_device_data;

struct rdma_restrack_root;

struct uapi_definition;

struct ib_port_data;

struct ib_device {
	struct device___116 *dma_device;
	struct ib_device_ops ops;
	char name[64];
	struct callback_head callback_head;
	struct list_head event_handler_list;
	struct rw_semaphore event_handler_rwsem;
	spinlock_t qp_open_list_lock;
	struct rw_semaphore client_data_rwsem;
	struct xarray client_data;
	struct mutex unregistration_lock;
	rwlock_t cache_lock;
	struct ib_port_data *port_data;
	int num_comp_vectors;
	union {
		struct device___116 dev;
		struct ib_core_device coredev;
	};
	const struct attribute_group___147 *groups[4];
	u64 uverbs_cmd_mask;
	char node_desc[64];
	__be64 node_guid;
	u32 local_dma_lkey;
	u16 is_switch: 1;
	u16 kverbs_provider: 1;
	u16 use_cq_dim: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 node_type;
	u32 phys_port_cnt;
	struct ib_device_attr attrs;
	struct hw_stats_device_data *hw_stats_data;
	struct rdmacg_device cg_device;
	u32 index;
	spinlock_t cq_pools_lock;
	struct list_head cq_pools[3];
	struct rdma_restrack_root *res;
	const struct uapi_definition *driver_def;
	refcount_t refcount;
	struct completion unreg_completion;
	struct work_struct unregistration_work;
	const struct rdma_link_ops *link_ops;
	struct mutex compat_devs_mutex;
	struct xarray compat_devs;
	char iw_ifname[16];
	u32 iw_driver_flags;
	u32 lag_flags;
};

enum ib_signature_type {
	IB_SIG_TYPE_NONE = 0,
	IB_SIG_TYPE_T10_DIF = 1,
};

enum ib_t10_dif_bg_type {
	IB_T10DIF_CRC = 0,
	IB_T10DIF_CSUM = 1,
};

struct ib_t10_dif_domain {
	enum ib_t10_dif_bg_type bg_type;
	u16 pi_interval;
	u16 bg;
	u16 app_tag;
	u32 ref_tag;
	bool ref_remap;
	bool app_escape;
	bool ref_escape;
	u16 apptag_check_mask;
};

struct ib_sig_domain {
	enum ib_signature_type sig_type;
	union {
		struct ib_t10_dif_domain dif;
	} sig;
};

struct ib_sig_attrs {
	u8 check_mask;
	struct ib_sig_domain mem;
	struct ib_sig_domain wire;
	int meta_length;
};

enum ib_sig_err_type {
	IB_SIG_BAD_GUARD = 0,
	IB_SIG_BAD_REFTAG = 1,
	IB_SIG_BAD_APPTAG = 2,
};

struct ib_sig_err {
	enum ib_sig_err_type err_type;
	u32 expected;
	u32 actual;
	u64 sig_err_offset;
	u32 key;
};

enum ib_uverbs_flow_action_esp_keymat {
	IB_UVERBS_FLOW_ACTION_ESP_KEYMAT_AES_GCM = 0,
};

struct ib_uverbs_flow_action_esp_keymat_aes_gcm {
	__u64 iv;
	__u32 iv_algo;
	__u32 salt;
	__u32 icv_len;
	__u32 key_len;
	__u32 aes_key[8];
};

enum ib_uverbs_flow_action_esp_replay {
	IB_UVERBS_FLOW_ACTION_ESP_REPLAY_NONE = 0,
	IB_UVERBS_FLOW_ACTION_ESP_REPLAY_BMP = 1,
};

struct ib_uverbs_flow_action_esp_replay_bmp {
	__u32 size;
};

union ib_gid {
	u8 raw[16];
	struct {
		__be64 subnet_prefix;
		__be64 interface_id;
	} global;
};

enum ib_gid_type {
	IB_GID_TYPE_IB = 0,
	IB_GID_TYPE_ROCE = 1,
	IB_GID_TYPE_ROCE_UDP_ENCAP = 2,
	IB_GID_TYPE_SIZE = 3,
};

struct ib_gid_attr {
	struct net_device___2 *ndev;
	struct ib_device *device;
	union ib_gid gid;
	enum ib_gid_type gid_type;
	u16 index;
	u32 port_num;
};

struct ib_cq_init_attr {
	unsigned int cqe;
	u32 comp_vector;
	u32 flags;
};

struct ib_dm_mr_attr {
	u64 length;
	u64 offset;
	u32 access_flags;
};

struct ib_dm_alloc_attr {
	u64 length;
	u32 alignment;
	u32 flags;
};

enum ib_mtu {
	IB_MTU_256 = 1,
	IB_MTU_512 = 2,
	IB_MTU_1024 = 3,
	IB_MTU_2048 = 4,
	IB_MTU_4096 = 5,
};

enum ib_port_state {
	IB_PORT_NOP = 0,
	IB_PORT_DOWN = 1,
	IB_PORT_INIT = 2,
	IB_PORT_ARMED = 3,
	IB_PORT_ACTIVE = 4,
	IB_PORT_ACTIVE_DEFER = 5,
};

struct ib_port_attr {
	u64 subnet_prefix;
	enum ib_port_state state;
	enum ib_mtu max_mtu;
	enum ib_mtu active_mtu;
	u32 phys_mtu;
	int gid_tbl_len;
	unsigned int ip_gids: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	u32 port_cap_flags;
	u32 max_msg_sz;
	u32 bad_pkey_cntr;
	u32 qkey_viol_cntr;
	u16 pkey_tbl_len;
	u32 sm_lid;
	u32 lid;
	u8 lmc;
	u8 max_vl_num;
	u8 sm_sl;
	u8 subnet_timeout;
	u8 init_type_reply;
	u8 active_width;
	u16 active_speed;
	u8 phys_state;
	u16 port_cap_flags2;
};

struct ib_device_modify {
	u64 sys_image_guid;
	char node_desc[64];
};

struct ib_port_modify {
	u32 set_port_cap_mask;
	u32 clr_port_cap_mask;
	u8 init_type;
};

enum ib_event_type {
	IB_EVENT_CQ_ERR = 0,
	IB_EVENT_QP_FATAL = 1,
	IB_EVENT_QP_REQ_ERR = 2,
	IB_EVENT_QP_ACCESS_ERR = 3,
	IB_EVENT_COMM_EST = 4,
	IB_EVENT_SQ_DRAINED = 5,
	IB_EVENT_PATH_MIG = 6,
	IB_EVENT_PATH_MIG_ERR = 7,
	IB_EVENT_DEVICE_FATAL = 8,
	IB_EVENT_PORT_ACTIVE = 9,
	IB_EVENT_PORT_ERR = 10,
	IB_EVENT_LID_CHANGE = 11,
	IB_EVENT_PKEY_CHANGE = 12,
	IB_EVENT_SM_CHANGE = 13,
	IB_EVENT_SRQ_ERR = 14,
	IB_EVENT_SRQ_LIMIT_REACHED = 15,
	IB_EVENT_QP_LAST_WQE_REACHED = 16,
	IB_EVENT_CLIENT_REREGISTER = 17,
	IB_EVENT_GID_CHANGE = 18,
	IB_EVENT_WQ_FATAL = 19,
};

struct ib_ucq_object;

typedef void (*ib_comp_handler)(struct ib_cq *, void *);

struct ib_event;

struct ib_cq {
	struct ib_device *device;
	struct ib_ucq_object *uobject;
	ib_comp_handler comp_handler;
	void (*event_handler)(struct ib_event *, void *);
	void *cq_context;
	int cqe;
	unsigned int cqe_used;
	atomic_t usecnt;
	enum ib_poll_context poll_ctx;
	struct ib_wc *wc;
	struct list_head pool_entry;
	union {
		struct irq_poll iop;
		struct work_struct work;
	};
	struct workqueue_struct *comp_wq;
	struct dim *dim;
	ktime_t timestamp;
	u8 interrupt: 1;
	u8 shared: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int comp_vector;
	struct rdma_restrack_entry res;
};

struct ib_uqp_object;

enum ib_qp_type {
	IB_QPT_SMI = 0,
	IB_QPT_GSI = 1,
	IB_QPT_RC = 2,
	IB_QPT_UC = 3,
	IB_QPT_UD = 4,
	IB_QPT_RAW_IPV6 = 5,
	IB_QPT_RAW_ETHERTYPE = 6,
	IB_QPT_RAW_PACKET = 8,
	IB_QPT_XRC_INI = 9,
	IB_QPT_XRC_TGT = 10,
	IB_QPT_MAX = 11,
	IB_QPT_DRIVER = 255,
	IB_QPT_RESERVED1 = 4096,
	IB_QPT_RESERVED2 = 4097,
	IB_QPT_RESERVED3 = 4098,
	IB_QPT_RESERVED4 = 4099,
	IB_QPT_RESERVED5 = 4100,
	IB_QPT_RESERVED6 = 4101,
	IB_QPT_RESERVED7 = 4102,
	IB_QPT_RESERVED8 = 4103,
	IB_QPT_RESERVED9 = 4104,
	IB_QPT_RESERVED10 = 4105,
};

struct ib_qp_security;

struct ib_qp {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_cq *send_cq;
	struct ib_cq *recv_cq;
	spinlock_t mr_lock;
	int mrs_used;
	struct list_head rdma_mrs;
	struct list_head sig_mrs;
	struct ib_srq *srq;
	struct ib_xrcd *xrcd;
	struct list_head xrcd_list;
	atomic_t usecnt;
	struct list_head open_list;
	struct ib_qp *real_qp;
	struct ib_uqp_object *uobject;
	void (*event_handler)(struct ib_event *, void *);
	void *qp_context;
	const struct ib_gid_attr *av_sgid_attr;
	const struct ib_gid_attr *alt_path_sgid_attr;
	u32 qp_num;
	u32 max_write_sge;
	u32 max_read_sge;
	enum ib_qp_type qp_type;
	struct ib_rwq_ind_table *rwq_ind_tbl;
	struct ib_qp_security *qp_sec;
	u32 port;
	bool integrity_en;
	struct rdma_restrack_entry res;
	struct rdma_counter *counter;
};

struct ib_usrq_object;

enum ib_srq_type {
	IB_SRQT_BASIC = 0,
	IB_SRQT_XRC = 1,
	IB_SRQT_TM = 2,
};

struct ib_srq {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_usrq_object *uobject;
	void (*event_handler)(struct ib_event *, void *);
	void *srq_context;
	enum ib_srq_type srq_type;
	atomic_t usecnt;
	struct {
		struct ib_cq *cq;
		union {
			struct {
				struct ib_xrcd *xrcd;
				u32 srq_num;
			} xrc;
		};
	} ext;
	struct rdma_restrack_entry res;
};

struct ib_uwq_object;

enum ib_wq_state {
	IB_WQS_RESET = 0,
	IB_WQS_RDY = 1,
	IB_WQS_ERR = 2,
};

enum ib_wq_type {
	IB_WQT_RQ = 0,
};

struct ib_wq {
	struct ib_device *device;
	struct ib_uwq_object *uobject;
	void *wq_context;
	void (*event_handler)(struct ib_event *, void *);
	struct ib_pd *pd;
	struct ib_cq *cq;
	u32 wq_num;
	enum ib_wq_state state;
	enum ib_wq_type wq_type;
	atomic_t usecnt;
};

struct ib_event {
	struct ib_device *device;
	union {
		struct ib_cq *cq;
		struct ib_qp *qp;
		struct ib_srq *srq;
		struct ib_wq *wq;
		u32 port_num;
	} element;
	enum ib_event_type event;
};

struct ib_global_route {
	const struct ib_gid_attr *sgid_attr;
	union ib_gid dgid;
	u32 flow_label;
	u8 sgid_index;
	u8 hop_limit;
	u8 traffic_class;
};

struct ib_grh {
	__be32 version_tclass_flow;
	__be16 paylen;
	u8 next_hdr;
	u8 hop_limit;
	union ib_gid sgid;
	union ib_gid dgid;
};

struct ib_mr_status {
	u32 fail_status;
	struct ib_sig_err sig_err;
};

struct rdma_ah_init_attr {
	struct rdma_ah_attr *ah_attr;
	u32 flags;
	struct net_device___2 *xmit_slave;
};

enum rdma_ah_attr_type {
	RDMA_AH_ATTR_TYPE_UNDEFINED = 0,
	RDMA_AH_ATTR_TYPE_IB = 1,
	RDMA_AH_ATTR_TYPE_ROCE = 2,
	RDMA_AH_ATTR_TYPE_OPA = 3,
};

struct ib_ah_attr {
	u16 dlid;
	u8 src_path_bits;
};

struct roce_ah_attr {
	u8 dmac[6];
};

struct opa_ah_attr {
	u32 dlid;
	u8 src_path_bits;
	bool make_grd;
};

struct rdma_ah_attr {
	struct ib_global_route grh;
	u8 sl;
	u8 static_rate;
	u32 port_num;
	u8 ah_flags;
	enum rdma_ah_attr_type type;
	union {
		struct ib_ah_attr ib;
		struct roce_ah_attr roce;
		struct opa_ah_attr opa;
	};
};

enum ib_wc_status {
	IB_WC_SUCCESS = 0,
	IB_WC_LOC_LEN_ERR = 1,
	IB_WC_LOC_QP_OP_ERR = 2,
	IB_WC_LOC_EEC_OP_ERR = 3,
	IB_WC_LOC_PROT_ERR = 4,
	IB_WC_WR_FLUSH_ERR = 5,
	IB_WC_MW_BIND_ERR = 6,
	IB_WC_BAD_RESP_ERR = 7,
	IB_WC_LOC_ACCESS_ERR = 8,
	IB_WC_REM_INV_REQ_ERR = 9,
	IB_WC_REM_ACCESS_ERR = 10,
	IB_WC_REM_OP_ERR = 11,
	IB_WC_RETRY_EXC_ERR = 12,
	IB_WC_RNR_RETRY_EXC_ERR = 13,
	IB_WC_LOC_RDD_VIOL_ERR = 14,
	IB_WC_REM_INV_RD_REQ_ERR = 15,
	IB_WC_REM_ABORT_ERR = 16,
	IB_WC_INV_EECN_ERR = 17,
	IB_WC_INV_EEC_STATE_ERR = 18,
	IB_WC_FATAL_ERR = 19,
	IB_WC_RESP_TIMEOUT_ERR = 20,
	IB_WC_GENERAL_ERR = 21,
};

enum ib_wc_opcode {
	IB_WC_SEND = 0,
	IB_WC_RDMA_WRITE = 1,
	IB_WC_RDMA_READ = 2,
	IB_WC_COMP_SWAP = 3,
	IB_WC_FETCH_ADD = 4,
	IB_WC_BIND_MW = 5,
	IB_WC_LOCAL_INV = 6,
	IB_WC_LSO = 7,
	IB_WC_REG_MR = 8,
	IB_WC_MASKED_COMP_SWAP = 9,
	IB_WC_MASKED_FETCH_ADD = 10,
	IB_WC_RECV = 128,
	IB_WC_RECV_RDMA_WITH_IMM = 129,
};

struct ib_cqe {
	void (*done)(struct ib_cq *, struct ib_wc *);
};

struct ib_wc {
	union {
		u64 wr_id;
		struct ib_cqe *wr_cqe;
	};
	enum ib_wc_status status;
	enum ib_wc_opcode opcode;
	u32 vendor_err;
	u32 byte_len;
	struct ib_qp *qp;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
	u32 src_qp;
	u32 slid;
	int wc_flags;
	u16 pkey_index;
	u8 sl;
	u8 dlid_path_bits;
	u32 port_num;
	u8 smac[6];
	u16 vlan_id;
	u8 network_hdr_type;
};

struct ib_srq_attr {
	u32 max_wr;
	u32 max_sge;
	u32 srq_limit;
};

struct ib_xrcd {
	struct ib_device *device;
	atomic_t usecnt;
	struct inode___160 *inode;
	struct rw_semaphore tgt_qps_rwsem;
	struct xarray tgt_qps;
};

struct ib_srq_init_attr {
	void (*event_handler)(struct ib_event *, void *);
	void *srq_context;
	struct ib_srq_attr attr;
	enum ib_srq_type srq_type;
	struct {
		struct ib_cq *cq;
		union {
			struct {
				struct ib_xrcd *xrcd;
			} xrc;
			struct {
				u32 max_num_tags;
			} tag_matching;
		};
	} ext;
};

struct ib_qp_cap {
	u32 max_send_wr;
	u32 max_recv_wr;
	u32 max_send_sge;
	u32 max_recv_sge;
	u32 max_inline_data;
	u32 max_rdma_ctxs;
};

enum ib_sig_type {
	IB_SIGNAL_ALL_WR = 0,
	IB_SIGNAL_REQ_WR = 1,
};

struct ib_qp_init_attr {
	void (*event_handler)(struct ib_event *, void *);
	void *qp_context;
	struct ib_cq *send_cq;
	struct ib_cq *recv_cq;
	struct ib_srq *srq;
	struct ib_xrcd *xrcd;
	struct ib_qp_cap cap;
	enum ib_sig_type sq_sig_type;
	enum ib_qp_type qp_type;
	u32 create_flags;
	u32 port_num;
	struct ib_rwq_ind_table *rwq_ind_tbl;
	u32 source_qpn;
};

struct ib_uobject;

struct ib_rwq_ind_table {
	struct ib_device *device;
	struct ib_uobject *uobject;
	atomic_t usecnt;
	u32 ind_tbl_num;
	u32 log_ind_tbl_size;
	struct ib_wq **ind_tbl;
};

enum ib_qp_state {
	IB_QPS_RESET = 0,
	IB_QPS_INIT = 1,
	IB_QPS_RTR = 2,
	IB_QPS_RTS = 3,
	IB_QPS_SQD = 4,
	IB_QPS_SQE = 5,
	IB_QPS_ERR = 6,
};

enum ib_mig_state {
	IB_MIG_MIGRATED = 0,
	IB_MIG_REARM = 1,
	IB_MIG_ARMED = 2,
};

enum ib_mw_type {
	IB_MW_TYPE_1 = 1,
	IB_MW_TYPE_2 = 2,
};

struct ib_qp_attr {
	enum ib_qp_state qp_state;
	enum ib_qp_state cur_qp_state;
	enum ib_mtu path_mtu;
	enum ib_mig_state path_mig_state;
	u32 qkey;
	u32 rq_psn;
	u32 sq_psn;
	u32 dest_qp_num;
	int qp_access_flags;
	struct ib_qp_cap cap;
	struct rdma_ah_attr ah_attr;
	struct rdma_ah_attr alt_ah_attr;
	u16 pkey_index;
	u16 alt_pkey_index;
	u8 en_sqd_async_notify;
	u8 sq_draining;
	u8 max_rd_atomic;
	u8 max_dest_rd_atomic;
	u8 min_rnr_timer;
	u32 port_num;
	u8 timeout;
	u8 retry_cnt;
	u8 rnr_retry;
	u32 alt_port_num;
	u8 alt_timeout;
	u32 rate_limit;
	struct net_device___2 *xmit_slave;
};

enum ib_wr_opcode {
	IB_WR_RDMA_WRITE = 0,
	IB_WR_RDMA_WRITE_WITH_IMM = 1,
	IB_WR_SEND = 2,
	IB_WR_SEND_WITH_IMM = 3,
	IB_WR_RDMA_READ = 4,
	IB_WR_ATOMIC_CMP_AND_SWP = 5,
	IB_WR_ATOMIC_FETCH_AND_ADD = 6,
	IB_WR_BIND_MW = 8,
	IB_WR_LSO = 10,
	IB_WR_SEND_WITH_INV = 9,
	IB_WR_RDMA_READ_WITH_INV = 11,
	IB_WR_LOCAL_INV = 7,
	IB_WR_MASKED_ATOMIC_CMP_AND_SWP = 12,
	IB_WR_MASKED_ATOMIC_FETCH_AND_ADD = 13,
	IB_WR_REG_MR = 32,
	IB_WR_REG_MR_INTEGRITY = 33,
	IB_WR_RESERVED1 = 240,
	IB_WR_RESERVED2 = 241,
	IB_WR_RESERVED3 = 242,
	IB_WR_RESERVED4 = 243,
	IB_WR_RESERVED5 = 244,
	IB_WR_RESERVED6 = 245,
	IB_WR_RESERVED7 = 246,
	IB_WR_RESERVED8 = 247,
	IB_WR_RESERVED9 = 248,
	IB_WR_RESERVED10 = 249,
};

struct ib_sge {
	u64 addr;
	u32 length;
	u32 lkey;
};

struct ib_send_wr {
	struct ib_send_wr *next;
	union {
		u64 wr_id;
		struct ib_cqe *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
	enum ib_wr_opcode opcode;
	int send_flags;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
};

struct ib_ah {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_uobject *uobject;
	const struct ib_gid_attr *sgid_attr;
	enum rdma_ah_attr_type type;
};

struct ib_mr {
	struct ib_device *device;
	struct ib_pd *pd;
	u32 lkey;
	u32 rkey;
	u64 iova;
	u64 length;
	unsigned int page_size;
	enum ib_mr_type type;
	bool need_inval;
	union {
		struct ib_uobject *uobject;
		struct list_head qp_entry;
	};
	struct ib_dm *dm;
	struct ib_sig_attrs *sig_attrs;
	struct rdma_restrack_entry res;
};

struct ib_recv_wr {
	struct ib_recv_wr *next;
	union {
		u64 wr_id;
		struct ib_cqe *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
};

struct ib_rdmacg_object {
	struct rdma_cgroup___2 *cg;
};

struct ib_uverbs_file;

struct ib_ucontext {
	struct ib_device *device;
	struct ib_uverbs_file *ufile;
	struct ib_rdmacg_object cg_obj;
	struct rdma_restrack_entry res;
	struct xarray mmap_xa;
};

struct uverbs_api_object;

struct ib_uobject {
	u64 user_handle;
	struct ib_uverbs_file *ufile;
	struct ib_ucontext *context;
	void *object;
	struct list_head list;
	struct ib_rdmacg_object cg_obj;
	int id;
	struct kref ref;
	atomic_t usecnt;
	struct callback_head rcu;
	const struct uverbs_api_object *uapi_object;
};

struct ib_udata {
	const void *inbuf;
	void *outbuf;
	size_t inlen;
	size_t outlen;
};

struct ib_pd {
	u32 local_dma_lkey;
	u32 flags;
	struct ib_device *device;
	struct ib_uobject *uobject;
	atomic_t usecnt;
	u32 unsafe_global_rkey;
	struct ib_mr *__internal_mr;
	struct rdma_restrack_entry res;
};

struct ib_wq_init_attr {
	void *wq_context;
	enum ib_wq_type wq_type;
	u32 max_wr;
	u32 max_sge;
	struct ib_cq *cq;
	void (*event_handler)(struct ib_event *, void *);
	u32 create_flags;
};

struct ib_wq_attr {
	enum ib_wq_state wq_state;
	enum ib_wq_state curr_wq_state;
	u32 flags;
	u32 flags_mask;
};

struct ib_rwq_ind_table_init_attr {
	u32 log_ind_tbl_size;
	struct ib_wq **ind_tbl;
};

enum port_pkey_state {
	IB_PORT_PKEY_NOT_VALID = 0,
	IB_PORT_PKEY_VALID = 1,
	IB_PORT_PKEY_LISTED = 2,
};

struct ib_port_pkey {
	enum port_pkey_state state;
	u16 pkey_index;
	u32 port_num;
	struct list_head qp_list;
	struct list_head to_error_list;
	struct ib_qp_security *sec;
};

struct ib_ports_pkeys;

struct ib_qp_security {
	struct ib_qp *qp;
	struct ib_device *dev;
	struct mutex mutex;
	struct ib_ports_pkeys *ports_pkeys;
	struct list_head shared_qp_list;
	void *security;
	bool destroying;
	atomic_t error_list_count;
	struct completion error_complete;
	int error_comps_pending;
};

struct ib_ports_pkeys {
	struct ib_port_pkey main;
	struct ib_port_pkey alt;
};

struct ib_dm {
	struct ib_device *device;
	u32 length;
	u32 flags;
	struct ib_uobject *uobject;
	atomic_t usecnt;
};

struct ib_mw {
	struct ib_device *device;
	struct ib_pd *pd;
	struct ib_uobject *uobject;
	u32 rkey;
	enum ib_mw_type type;
};

enum ib_flow_attr_type {
	IB_FLOW_ATTR_NORMAL = 0,
	IB_FLOW_ATTR_ALL_DEFAULT = 1,
	IB_FLOW_ATTR_MC_DEFAULT = 2,
	IB_FLOW_ATTR_SNIFFER = 3,
};

enum ib_flow_spec_type {
	IB_FLOW_SPEC_ETH = 32,
	IB_FLOW_SPEC_IB = 34,
	IB_FLOW_SPEC_IPV4 = 48,
	IB_FLOW_SPEC_IPV6 = 49,
	IB_FLOW_SPEC_ESP = 52,
	IB_FLOW_SPEC_TCP = 64,
	IB_FLOW_SPEC_UDP = 65,
	IB_FLOW_SPEC_VXLAN_TUNNEL = 80,
	IB_FLOW_SPEC_GRE = 81,
	IB_FLOW_SPEC_MPLS = 96,
	IB_FLOW_SPEC_INNER = 256,
	IB_FLOW_SPEC_ACTION_TAG = 4096,
	IB_FLOW_SPEC_ACTION_DROP = 4097,
	IB_FLOW_SPEC_ACTION_HANDLE = 4098,
	IB_FLOW_SPEC_ACTION_COUNT = 4099,
};

struct ib_flow_eth_filter {
	u8 dst_mac[6];
	u8 src_mac[6];
	__be16 ether_type;
	__be16 vlan_tag;
	u8 real_sz[0];
};

struct ib_flow_spec_eth {
	u32 type;
	u16 size;
	struct ib_flow_eth_filter val;
	struct ib_flow_eth_filter mask;
};

struct ib_flow_ib_filter {
	__be16 dlid;
	__u8 sl;
	u8 real_sz[0];
};

struct ib_flow_spec_ib {
	u32 type;
	u16 size;
	struct ib_flow_ib_filter val;
	struct ib_flow_ib_filter mask;
};

struct ib_flow_ipv4_filter {
	__be32 src_ip;
	__be32 dst_ip;
	u8 proto;
	u8 tos;
	u8 ttl;
	u8 flags;
	u8 real_sz[0];
};

struct ib_flow_spec_ipv4 {
	u32 type;
	u16 size;
	struct ib_flow_ipv4_filter val;
	struct ib_flow_ipv4_filter mask;
};

struct ib_flow_ipv6_filter {
	u8 src_ip[16];
	u8 dst_ip[16];
	__be32 flow_label;
	u8 next_hdr;
	u8 traffic_class;
	u8 hop_limit;
	u8 real_sz[0];
};

struct ib_flow_spec_ipv6 {
	u32 type;
	u16 size;
	struct ib_flow_ipv6_filter val;
	struct ib_flow_ipv6_filter mask;
};

struct ib_flow_tcp_udp_filter {
	__be16 dst_port;
	__be16 src_port;
	u8 real_sz[0];
};

struct ib_flow_spec_tcp_udp {
	u32 type;
	u16 size;
	struct ib_flow_tcp_udp_filter val;
	struct ib_flow_tcp_udp_filter mask;
};

struct ib_flow_tunnel_filter {
	__be32 tunnel_id;
	u8 real_sz[0];
};

struct ib_flow_spec_tunnel {
	u32 type;
	u16 size;
	struct ib_flow_tunnel_filter val;
	struct ib_flow_tunnel_filter mask;
};

struct ib_flow_esp_filter {
	__be32 spi;
	__be32 seq;
	u8 real_sz[0];
};

struct ib_flow_spec_esp {
	u32 type;
	u16 size;
	struct ib_flow_esp_filter val;
	struct ib_flow_esp_filter mask;
};

struct ib_flow_gre_filter {
	__be16 c_ks_res0_ver;
	__be16 protocol;
	__be32 key;
	u8 real_sz[0];
};

struct ib_flow_spec_gre {
	u32 type;
	u16 size;
	struct ib_flow_gre_filter val;
	struct ib_flow_gre_filter mask;
};

struct ib_flow_mpls_filter {
	__be32 tag;
	u8 real_sz[0];
};

struct ib_flow_spec_mpls {
	u32 type;
	u16 size;
	struct ib_flow_mpls_filter val;
	struct ib_flow_mpls_filter mask;
};

struct ib_flow_spec_action_tag {
	enum ib_flow_spec_type type;
	u16 size;
	u32 tag_id;
};

struct ib_flow_spec_action_drop {
	enum ib_flow_spec_type type;
	u16 size;
};

struct ib_flow_spec_action_handle {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_flow_action *act;
};

enum ib_flow_action_type {
	IB_FLOW_ACTION_UNSPECIFIED = 0,
	IB_FLOW_ACTION_ESP = 1,
};

struct ib_flow_action {
	struct ib_device *device;
	struct ib_uobject *uobject;
	enum ib_flow_action_type type;
	atomic_t usecnt;
};

struct ib_flow_spec_action_count {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_counters *counters;
};

struct ib_counters {
	struct ib_device *device;
	struct ib_uobject *uobject;
	atomic_t usecnt;
};

union ib_flow_spec {
	struct {
		u32 type;
		u16 size;
	};
	struct ib_flow_spec_eth eth;
	struct ib_flow_spec_ib ib;
	struct ib_flow_spec_ipv4 ipv4;
	struct ib_flow_spec_tcp_udp tcp_udp;
	struct ib_flow_spec_ipv6 ipv6;
	struct ib_flow_spec_tunnel tunnel;
	struct ib_flow_spec_esp esp;
	struct ib_flow_spec_gre gre;
	struct ib_flow_spec_mpls mpls;
	struct ib_flow_spec_action_tag flow_tag;
	struct ib_flow_spec_action_drop drop;
	struct ib_flow_spec_action_handle action;
	struct ib_flow_spec_action_count flow_count;
};

struct ib_flow_attr {
	enum ib_flow_attr_type type;
	u16 size;
	u16 priority;
	u32 flags;
	u8 num_of_specs;
	u32 port;
	union ib_flow_spec flows[0];
};

struct ib_flow {
	struct ib_qp *qp;
	struct ib_device *device;
	struct ib_uobject *uobject;
};

struct ib_flow_action_attrs_esp_keymats {
	enum ib_uverbs_flow_action_esp_keymat protocol;
	union {
		struct ib_uverbs_flow_action_esp_keymat_aes_gcm aes_gcm;
	} keymat;
};

struct ib_flow_action_attrs_esp_replays {
	enum ib_uverbs_flow_action_esp_replay protocol;
	union {
		struct ib_uverbs_flow_action_esp_replay_bmp bmp;
	} replay;
};

struct ib_flow_spec_list {
	struct ib_flow_spec_list *next;
	union ib_flow_spec spec;
};

struct ib_flow_action_attrs_esp {
	struct ib_flow_action_attrs_esp_keymats *keymat;
	struct ib_flow_action_attrs_esp_replays *replay;
	struct ib_flow_spec_list *encap;
	u32 esn;
	u32 spi;
	u32 seq;
	u32 tfc_pad;
	u64 flags;
	u64 hard_limit_pkts;
};

struct ib_pkey_cache;

struct ib_gid_table;

struct ib_port_cache {
	u64 subnet_prefix;
	struct ib_pkey_cache *pkey;
	struct ib_gid_table *gid;
	u8 lmc;
	enum ib_port_state port_state;
};

struct ib_port_immutable {
	int pkey_tbl_len;
	int gid_tbl_len;
	u32 core_cap_flags;
	u32 max_mad_size;
};

struct ib_port;

struct ib_port_data {
	struct ib_device *ib_dev;
	struct ib_port_immutable immutable;
	spinlock_t pkey_list_lock;
	spinlock_t netdev_lock;
	struct list_head pkey_list;
	struct ib_port_cache cache;
	struct net_device___2 *netdev;
	struct hlist_node ndev_hash_link;
	struct rdma_port_counter port_counter;
	struct ib_port *sysfs;
};

struct rdma_netdev_alloc_params {
	size_t sizeof_priv;
	unsigned int txqs;
	unsigned int rxqs;
	void *param;
	int (*initialize_rdma_netdev)(struct ib_device *, u32, struct net_device___2 *, void *);
};

struct ib_counters_read_attr {
	u64 *counters_buff;
	u32 ncounters;
	u32 flags;
};

struct rdma_user_mmap_entry {
	struct kref ref;
	struct ib_ucontext *ucontext;
	long unsigned int start_pgoff;
	size_t npages;
	bool driver_removed;
};

enum blk_zone_type {
	BLK_ZONE_TYPE_CONVENTIONAL = 1,
	BLK_ZONE_TYPE_SEQWRITE_REQ = 2,
	BLK_ZONE_TYPE_SEQWRITE_PREF = 3,
};

enum blk_zone_cond {
	BLK_ZONE_COND_NOT_WP = 0,
	BLK_ZONE_COND_EMPTY = 1,
	BLK_ZONE_COND_IMP_OPEN = 2,
	BLK_ZONE_COND_EXP_OPEN = 3,
	BLK_ZONE_COND_CLOSED = 4,
	BLK_ZONE_COND_READONLY = 13,
	BLK_ZONE_COND_FULL = 14,
	BLK_ZONE_COND_OFFLINE = 15,
};

enum blk_zone_report_flags {
	BLK_ZONE_REP_CAPACITY = 1,
};

struct blk_zone_report {
	__u64 sector;
	__u32 nr_zones;
	__u32 flags;
	struct blk_zone zones[0];
};

struct blk_zone_range {
	__u64 sector;
	__u64 nr_sectors;
};

struct zone_report_args {
	struct blk_zone *zones;
};

struct blk_revalidate_zone_args {
	struct gendisk___25 *disk;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int nr_zones;
	sector_t zone_sectors;
	sector_t sector;
};

struct dentry___180;

struct super_block___180;

struct module___164;

struct file_system_type___180 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___180 * (*mount)(struct file_system_type___180 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___180 *);
	struct module___164 *owner;
	struct file_system_type___180 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___180;

struct kiocb___180;

struct iov_iter___105;

struct poll_table_struct___118;

struct vm_area_struct___185;

struct inode___180;

struct file_lock___180;

struct page___185;

struct seq_file___157;

struct file_operations___180 {
	struct module___164 *owner;
	loff_t (*llseek)(struct file___180 *, loff_t, int);
	ssize_t (*read)(struct file___180 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___180 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___180 *, struct iov_iter___105 *);
	ssize_t (*write_iter)(struct kiocb___180 *, struct iov_iter___105 *);
	int (*iopoll)(struct kiocb___180 *, bool);
	int (*iterate)(struct file___180 *, struct dir_context *);
	int (*iterate_shared)(struct file___180 *, struct dir_context *);
	__poll_t (*poll)(struct file___180 *, struct poll_table_struct___118 *);
	long int (*unlocked_ioctl)(struct file___180 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___180 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___180 *, struct vm_area_struct___185 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___180 *, struct file___180 *);
	int (*flush)(struct file___180 *, fl_owner_t);
	int (*release)(struct inode___180 *, struct file___180 *);
	int (*fsync)(struct file___180 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___180 *, int);
	int (*lock)(struct file___180 *, int, struct file_lock___180 *);
	ssize_t (*sendpage)(struct file___180 *, struct page___185 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___180 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___180 *, long unsigned int);
	int (*flock)(struct file___180 *, int, struct file_lock___180 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___180 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___180 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___180 *, long int, struct file_lock___180 **, void **);
	long int (*fallocate)(struct file___180 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___157 *, struct file___180 *);
	ssize_t (*copy_file_range)(struct file___180 *, loff_t, struct file___180 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___180 *, loff_t, struct file___180 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___180 *, loff_t, loff_t, int);
};

struct vmacache___185 {
	u64 seqnum;
	struct vm_area_struct___185 *vmas[4];
};

struct page_frag___185 {
	struct page___185 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___73;

struct debug_info___73 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___73 *hbp_break[16];
	struct perf_event___73 *hbp_watch[16];
};

struct thread_struct___73 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___73 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___186;

struct pid___160;

struct nsproxy___169;

struct signal_struct___181;

struct bio_list___88;

struct backing_dev_info___82;

struct io_context___88;

struct css_set___122;

struct perf_event_context___73;

struct mem_cgroup___73;

struct request_queue___88;

struct vm_struct___163;

struct task_struct___187 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___187 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___186 *mm;
	struct mm_struct___186 *active_mm;
	struct vmacache___185 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___187 *real_parent;
	struct task_struct___187 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___187 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___160 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___169 *nsproxy;
	struct signal_struct___181 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___187 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___88 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___82 *backing_dev_info;
	struct io_context___88 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___122 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___73 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___185 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___73 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___73 *active_memcg;
	struct request_queue___88 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___187 *oom_reaper_list;
	struct vm_struct___163 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___167;

struct kobj_type___167;

struct kernfs_node___167;

struct kobject___167 {
	const char *name;
	struct list_head entry;
	struct kobject___167 *parent;
	struct kset___167 *kset;
	struct kobj_type___167 *ktype;
	struct kernfs_node___167 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___164 {
	struct kobject___167 kobj;
	struct module___164 *mod;
	struct kobject___167 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___164 {
	struct module___164 *mod;
	struct latch_tree_node node;
};

struct module_layout___164 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___164 mtn;
};

struct module_attribute___164;

struct kernel_param___164;

struct trace_event_call___67;

struct module___164 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___164 mkobj;
	struct module_attribute___164 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___167 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___164 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___164 core_layout;
	struct module_layout___164 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___67 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___73 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___187 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___73)(struct perf_event___73 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___73;

struct fasync_struct___180;

struct pid_namespace___160;

struct perf_cgroup___73;

struct perf_event___73 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___73 *group_leader;
	struct pmu___73 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___73 hw;
	struct perf_event_context___73 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___73 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___187 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___180 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___73 *aux_event;
	void (*destroy)(struct perf_event___73 *);
	struct callback_head callback_head;
	struct pid_namespace___160 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___73 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___73 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___67 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___73 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___180;

struct dentry___180 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___180 *d_parent;
	struct qstr d_name;
	struct inode___180 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___180 *d_op;
	struct super_block___180 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___180;

struct address_space___180 {
	struct inode___180 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___180 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___180;

struct bdi_writeback___82;

struct inode___180 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___180 *i_op;
	struct super_block___180 *i_sb;
	struct address_space___180 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___82 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___180 *i_fop;
		void (*free_inode)(struct inode___180 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___180 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___33 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___180;

struct path___180;

struct dentry_operations___180 {
	int (*d_revalidate)(struct dentry___180 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___180 *, unsigned int);
	int (*d_hash)(const struct dentry___180 *, struct qstr *);
	int (*d_compare)(const struct dentry___180 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___180 *);
	int (*d_init)(struct dentry___180 *);
	void (*d_release)(struct dentry___180 *);
	void (*d_prune)(struct dentry___180 *);
	void (*d_iput)(struct dentry___180 *, struct inode___180 *);
	char * (*d_dname)(struct dentry___180 *, char *, int);
	struct vfsmount___180 * (*d_automount)(struct path___180 *);
	int (*d_manage)(const struct path___180 *, bool);
	struct dentry___180 * (*d_real)(struct dentry___180 *, const struct inode___180 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___180;

struct mem_dqinfo___180 {
	struct quota_format_type___180 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___180;

struct quota_info___180 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___180 *files[3];
	struct mem_dqinfo___180 info[3];
	const struct quota_format_ops___180 *ops[3];
};

struct rcuwait___181 {
	struct task_struct___187 *task;
};

struct percpu_rw_semaphore___181 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___181 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___180 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___181 rw_sem[3];
};

struct shrink_control___73;

struct shrinker___73 {
	long unsigned int (*count_objects)(struct shrinker___73 *, struct shrink_control___73 *);
	long unsigned int (*scan_objects)(struct shrinker___73 *, struct shrink_control___73 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___180;

struct dquot_operations___180;

struct quotactl_ops___180;

struct block_device___89;

struct super_block___180 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___180 *s_type;
	const struct super_operations___180 *s_op;
	const struct dquot_operations___180 *dq_op;
	const struct quotactl_ops___180 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___180 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___89 *s_bdev;
	struct backing_dev_info___82 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___180 s_dquot;
	struct sb_writers___180 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___180 *s_d_op;
	int cleancache_poolid;
	struct shrinker___73 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___180 {
	struct dentry___180 *mnt_root;
	struct super_block___180 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct path___180 {
	struct vfsmount___180 *mnt;
	struct dentry___180 *dentry;
};

struct upid___160 {
	int nr;
	struct pid_namespace___160 *ns;
};

struct pid_namespace___160 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___187 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___160 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___160 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___160 numbers[1];
};

typedef struct page___185 *pgtable_t___185;

struct dev_pagemap___175;

struct page___185 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___180 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___185 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___185 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___186 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___175 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___175;

struct vm_area_struct___185 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___185 *vm_next;
	struct vm_area_struct___185 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___186 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___175 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___180 *vm_file;
	struct file___180 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___181 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___187 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___187 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___160 *pids[4];
	struct pid___160 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___186 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___185;

struct mm_struct___186 {
	struct {
		struct vm_area_struct___185 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___180 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___185 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___187 *owner;
		struct user_namespace___25 *user_ns;
		struct file___180 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___122;

struct nsproxy___169 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___160 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___122 *cgroup_ns;
};

struct bio___88;

struct bio_list___88 {
	struct bio___88 *head;
	struct bio___88 *tail;
};

struct cgroup_subsys_state___122;

struct bdi_writeback___82 {
	struct backing_dev_info___82 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___122 *memcg_css;
	struct cgroup_subsys_state___122 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___133;

struct backing_dev_info___82 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___82 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___133 *dev;
	char dev_name[64];
	struct device___133 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___180 *debug_dir;
};

struct io_cq___88;

struct io_context___88 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___88 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___122;

struct css_set___122 {
	struct cgroup_subsys_state___122 *subsys[14];
	refcount_t refcount;
	struct css_set___122 *dom_cset;
	struct cgroup___122 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___122 *mg_src_cgrp;
	struct cgroup___122 *mg_dst_cgrp;
	struct css_set___122 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___73 {
	struct pmu___73 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___187 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___73 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___122;

struct cgroup_subsys_state___122 {
	struct cgroup___122 *cgroup;
	struct cgroup_subsys___122 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___122 *parent;
};

struct cgroup_file___122 {
	struct kernfs_node___167 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___73;

struct mem_cgroup_per_node___73;

struct mem_cgroup___73 {
	struct cgroup_subsys_state___122 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___122 events_file;
	struct cgroup_file___122 events_local_file;
	struct cgroup_file___122 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___73 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___187 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___73 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___88;

struct blk_integrity___88 {
	const struct blk_integrity_profile___88 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___88 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___88 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___88;

struct elevator_queue___88;

struct rq_qos___4;

struct blk_mq_ops___85;

struct blk_mq_hw_ctx___85;

struct gendisk___89;

struct blk_stat_callback___9;

struct blkcg_gq___83;

struct blk_mq_tag_set___85;

struct request_queue___88 {
	struct request___88 *last_merge;
	struct elevator_queue___88 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos___4 *rq_qos;
	const struct blk_mq_ops___85 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___85 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___89 *disk;
	struct kobject___167 kobj;
	struct kobject___167 *mq_kobj;
	struct blk_integrity___88 integrity;
	struct device___133 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback___9 *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___83 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___85 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___88 bio_split;
	struct dentry___180 *debugfs_dir;
	struct dentry___180 *sched_debugfs_dir;
	struct dentry___180 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___163 {
	struct vm_struct___163 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___185 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___73 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___73 *memcg;
};

struct dev_pagemap_ops___175;

struct dev_pagemap___175 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___175 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___160 {
	rwlock_t lock;
	struct pid___160 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___180 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___180 f_path;
	struct inode___180 *f_inode;
	const struct file_operations___180 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___160 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___180 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___175;

struct vm_operations_struct___175 {
	void (*open)(struct vm_area_struct___185 *);
	void (*close)(struct vm_area_struct___185 *);
	int (*may_split)(struct vm_area_struct___185 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___185 *);
	int (*mprotect)(struct vm_area_struct___185 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___175 *);
	vm_fault_t (*huge_fault)(struct vm_fault___175 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___175 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___185 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___175 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___175 *);
	int (*access)(struct vm_area_struct___185 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___185 *);
	int (*set_policy)(struct vm_area_struct___185 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___185 *, long unsigned int);
	struct page___185 * (*find_special_page)(struct vm_area_struct___185 *, long unsigned int);
};

struct core_thread___185 {
	struct task_struct___187 *task;
	struct core_thread___185 *next;
};

struct core_state___185 {
	atomic_t nr_threads;
	struct core_thread___185 dumper;
	struct completion startup;
};

struct vm_fault___175 {
	const struct {
		struct vm_area_struct___185 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___185 *cow_page;
	struct page___185 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___185 prealloc_pte;
};

struct pglist_data___80;

struct lruvec___80 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___80 *pgdat;
};

struct zone___80 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___80 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___80 {
	struct zone___80 *zone;
	int zone_idx;
};

struct zonelist___80 {
	struct zoneref___80 _zonerefs[321];
};

struct pglist_data___80 {
	struct zone___80 node_zones[5];
	struct zonelist___80 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___187 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___187 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___80 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___122 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___187 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___122;

struct cgroup_rstat_cpu___122;

struct cgroup___122 {
	struct cgroup_subsys_state___122 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___167 *kn;
	struct cgroup_file___122 procs_file;
	struct cgroup_file___122 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___122 *subsys[14];
	struct cgroup_root___122 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___122 *dom_cgrp;
	struct cgroup___122 *old_dom_cgrp;
	struct cgroup_rstat_cpu___122 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___122 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___88 {
	struct request_queue___88 *q;
	struct io_context___88 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___81;

struct kiocb___180 {
	struct file___180 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___180 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___81 *ki_waitq;
	};
};

struct iattr___180 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___180 *ia_file;
};

struct dquot___180 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___180 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___180 {
	int qf_fmt_id;
	const struct quota_format_ops___180 *qf_ops;
	struct module___164 *qf_owner;
	struct quota_format_type___180 *qf_next;
};

struct quota_format_ops___180 {
	int (*check_quota_file)(struct super_block___180 *, int);
	int (*read_file_info)(struct super_block___180 *, int);
	int (*write_file_info)(struct super_block___180 *, int);
	int (*free_file_info)(struct super_block___180 *, int);
	int (*read_dqblk)(struct dquot___180 *);
	int (*commit_dqblk)(struct dquot___180 *);
	int (*release_dqblk)(struct dquot___180 *);
	int (*get_next_id)(struct super_block___180 *, struct kqid *);
};

struct dquot_operations___180 {
	int (*write_dquot)(struct dquot___180 *);
	struct dquot___180 * (*alloc_dquot)(struct super_block___180 *, int);
	void (*destroy_dquot)(struct dquot___180 *);
	int (*acquire_dquot)(struct dquot___180 *);
	int (*release_dquot)(struct dquot___180 *);
	int (*mark_dirty)(struct dquot___180 *);
	int (*write_info)(struct super_block___180 *, int);
	qsize_t * (*get_reserved_space)(struct inode___180 *);
	int (*get_projid)(struct inode___180 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___180 *, qsize_t *);
	int (*get_next_id)(struct super_block___180 *, struct kqid *);
};

struct quotactl_ops___180 {
	int (*quota_on)(struct super_block___180 *, int, int, const struct path___180 *);
	int (*quota_off)(struct super_block___180 *, int);
	int (*quota_enable)(struct super_block___180 *, unsigned int);
	int (*quota_disable)(struct super_block___180 *, unsigned int);
	int (*quota_sync)(struct super_block___180 *, int);
	int (*set_info)(struct super_block___180 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___180 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___180 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___180 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___180 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___180 *, unsigned int);
};

struct wait_page_queue___81 {
	struct page___185 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___82;

struct readahead_control___81;

struct swap_info_struct___42;

struct address_space_operations___180 {
	int (*writepage)(struct page___185 *, struct writeback_control___82 *);
	int (*readpage)(struct file___180 *, struct page___185 *);
	int (*writepages)(struct address_space___180 *, struct writeback_control___82 *);
	int (*set_page_dirty)(struct page___185 *);
	int (*readpages)(struct file___180 *, struct address_space___180 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___81 *);
	int (*write_begin)(struct file___180 *, struct address_space___180 *, loff_t, unsigned int, unsigned int, struct page___185 **, void **);
	int (*write_end)(struct file___180 *, struct address_space___180 *, loff_t, unsigned int, unsigned int, struct page___185 *, void *);
	sector_t (*bmap)(struct address_space___180 *, sector_t);
	void (*invalidatepage)(struct page___185 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___185 *, gfp_t);
	void (*freepage)(struct page___185 *);
	ssize_t (*direct_IO)(struct kiocb___180 *, struct iov_iter___105 *);
	int (*migratepage)(struct address_space___180 *, struct page___185 *, struct page___185 *, enum migrate_mode);
	bool (*isolate_page)(struct page___185 *, isolate_mode_t);
	void (*putback_page)(struct page___185 *);
	int (*launder_page)(struct page___185 *);
	int (*is_partially_uptodate)(struct page___185 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___185 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___180 *, struct page___185 *);
	int (*swap_activate)(struct swap_info_struct___42 *, struct file___180 *, sector_t *);
	void (*swap_deactivate)(struct file___180 *);
};

struct writeback_control___82 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___82 *wb;
	struct inode___180 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___81 {
	struct file___180 *file;
	struct address_space___180 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___103;

struct iov_iter___105 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___103 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___42 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___89 *bdev;
	struct file___180 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___180 {
	struct dentry___180 * (*lookup)(struct inode___180 *, struct dentry___180 *, unsigned int);
	const char * (*get_link)(struct dentry___180 *, struct inode___180 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___180 *, int);
	struct posix_acl * (*get_acl)(struct inode___180 *, int, bool);
	int (*readlink)(struct dentry___180 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___180 *, struct dentry___180 *, umode_t, bool);
	int (*link)(struct dentry___180 *, struct inode___180 *, struct dentry___180 *);
	int (*unlink)(struct inode___180 *, struct dentry___180 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___180 *, struct dentry___180 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___180 *, struct dentry___180 *, umode_t);
	int (*rmdir)(struct inode___180 *, struct dentry___180 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___180 *, struct dentry___180 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___180 *, struct dentry___180 *, struct inode___180 *, struct dentry___180 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___180 *, struct iattr___180 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___180 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___180 *, char *, size_t);
	int (*fiemap)(struct inode___180 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___180 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___180 *, struct dentry___180 *, struct file___180 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___180 *, struct dentry___180 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___180 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___180 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___180 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___180 {
	void (*fl_copy_lock)(struct file_lock___180 *, struct file_lock___180 *);
	void (*fl_release_private)(struct file_lock___180 *);
};

struct lock_manager_operations___180;

struct file_lock___180 {
	struct file_lock___180 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___180 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___180 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___180 *fl_ops;
	const struct lock_manager_operations___180 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___180 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___180 *);
	int (*lm_grant)(struct file_lock___180 *, int);
	bool (*lm_break)(struct file_lock___180 *);
	int (*lm_change)(struct file_lock___180 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___180 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___180 *);
};

struct fasync_struct___180 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___180 *fa_next;
	struct file___180 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___180 {
	struct inode___180 * (*alloc_inode)(struct super_block___180 *);
	void (*destroy_inode)(struct inode___180 *);
	void (*free_inode)(struct inode___180 *);
	void (*dirty_inode)(struct inode___180 *, int);
	int (*write_inode)(struct inode___180 *, struct writeback_control___82 *);
	int (*drop_inode)(struct inode___180 *);
	void (*evict_inode)(struct inode___180 *);
	void (*put_super)(struct super_block___180 *);
	int (*sync_fs)(struct super_block___180 *, int);
	int (*freeze_super)(struct super_block___180 *);
	int (*freeze_fs)(struct super_block___180 *);
	int (*thaw_super)(struct super_block___180 *);
	int (*unfreeze_fs)(struct super_block___180 *);
	int (*statfs)(struct dentry___180 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___180 *, int *, char *);
	void (*umount_begin)(struct super_block___180 *);
	int (*show_options)(struct seq_file___157 *, struct dentry___180 *);
	int (*show_devname)(struct seq_file___157 *, struct dentry___180 *);
	int (*show_path)(struct seq_file___157 *, struct dentry___180 *);
	int (*show_stats)(struct seq_file___157 *, struct dentry___180 *);
	ssize_t (*quota_read)(struct super_block___180 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___180 *, int, const char *, size_t, loff_t);
	struct dquot___180 ** (*get_dquots)(struct inode___180 *);
	long int (*nr_cached_objects)(struct super_block___180 *, struct shrink_control___73 *);
	long int (*free_cached_objects)(struct super_block___180 *, struct shrink_control___73 *);
	struct file___180 * (*real_loop)(struct file___180 *);
};

struct wakeup_source___133;

struct dev_pm_info___133 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___133 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___133 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___133;

struct bus_type___133;

struct device_driver___133;

struct dev_pm_domain___133;

struct fwnode_handle___133;

struct class___133;

struct attribute_group___167;

struct device___133 {
	struct kobject___167 kobj;
	struct device___133 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___133 *type;
	struct bus_type___133 *bus;
	struct device_driver___133 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___133 power;
	struct dev_pm_domain___133 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___133 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___133 *class;
	const struct attribute_group___167 **groups;
	void (*release)(struct device___133 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___89 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___180 *bd_inode;
	struct super_block___180 *bd_super;
	void *bd_claiming;
	struct device___133 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___167 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___89 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___180 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___123)(struct file___180 *, wait_queue_head_t *, struct poll_table_struct___118 *);

struct poll_table_struct___118 {
	poll_queue_proc___123 _qproc;
	__poll_t _key;
};

struct seq_operations___157;

struct seq_file___157 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___157 *op;
	int poll_event;
	const struct file___180 *file;
	void *private;
};

typedef void bio_end_io_t___88(struct bio___88 *);

struct bio_vec___103 {
	struct page___185 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___88;

struct bio___88 {
	struct bio___88 *bi_next;
	struct block_device___89 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___88 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___83 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___88 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___103 *bi_io_vec;
	struct bio_set___88 *bi_pool;
	struct bio_vec___103 bi_inline_vecs[0];
};

struct dev_pagemap_ops___175 {
	void (*page_free)(struct page___185 *);
	void (*kill)(struct dev_pagemap___175 *);
	void (*cleanup)(struct dev_pagemap___175 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___175 *);
};

struct fwnode_operations___133;

struct fwnode_handle___133 {
	struct fwnode_handle___133 *secondary;
	const struct fwnode_operations___133 *ops;
	struct device___133 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___133;

struct fwnode_endpoint___133;

struct fwnode_operations___133 {
	struct fwnode_handle___133 * (*get)(struct fwnode_handle___133 *);
	void (*put)(struct fwnode_handle___133 *);
	bool (*device_is_available)(const struct fwnode_handle___133 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___133 *, const struct device___133 *);
	bool (*property_present)(const struct fwnode_handle___133 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___133 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___133 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___133 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*get_parent)(const struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*get_next_child_node)(const struct fwnode_handle___133 *, struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*get_named_child_node)(const struct fwnode_handle___133 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___133 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___133 *);
	struct fwnode_handle___133 * (*graph_get_next_endpoint)(const struct fwnode_handle___133 *, struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*graph_get_remote_endpoint)(const struct fwnode_handle___133 *);
	struct fwnode_handle___133 * (*graph_get_port_parent)(struct fwnode_handle___133 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___133 *, struct fwnode_endpoint___133 *);
	int (*add_links)(struct fwnode_handle___133 *);
};

struct fwnode_endpoint___133 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___133 *local_fwnode;
};

struct fwnode_reference_args___133 {
	struct fwnode_handle___133 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___167;

struct kernfs_elem_dir___167 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___167 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___167;

struct kernfs_root___167 {
	struct kernfs_node___167 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___167 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___167 {
	struct kernfs_node___167 *target_kn;
};

struct kernfs_ops___167;

struct kernfs_elem_attr___167 {
	const struct kernfs_ops___167 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___167 *notify_next;
};

struct kernfs_node___167 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___167 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___167 dir;
		struct kernfs_elem_symlink___167 symlink;
		struct kernfs_elem_attr___167 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___167;

struct kernfs_ops___167 {
	int (*open)(struct kernfs_open_file___167 *);
	void (*release)(struct kernfs_open_file___167 *);
	int (*seq_show)(struct seq_file___157 *, void *);
	void * (*seq_start)(struct seq_file___157 *, loff_t *);
	void * (*seq_next)(struct seq_file___157 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___157 *, void *);
	ssize_t (*read)(struct kernfs_open_file___167 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___167 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___167 *, struct poll_table_struct___118 *);
	int (*mmap)(struct kernfs_open_file___167 *, struct vm_area_struct___185 *);
};

struct kernfs_syscall_ops___167 {
	int (*show_options)(struct seq_file___157 *, struct kernfs_root___167 *);
	int (*mkdir)(struct kernfs_node___167 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___167 *);
	int (*rename)(struct kernfs_node___167 *, struct kernfs_node___167 *, const char *);
	int (*show_path)(struct seq_file___157 *, struct kernfs_node___167 *, struct kernfs_root___167 *);
};

struct kernfs_open_file___167 {
	struct kernfs_node___167 *kn;
	struct file___180 *file;
	struct seq_file___157 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___175 *vm_ops;
};

struct bin_attribute___167;

struct attribute_group___167 {
	const char *name;
	umode_t (*is_visible)(struct kobject___167 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___167 *, struct bin_attribute___167 *, int);
	struct attribute **attrs;
	struct bin_attribute___167 **bin_attrs;
};

struct bin_attribute___167 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___180 * (*f_mapping)();
	ssize_t (*read)(struct file___180 *, struct kobject___167 *, struct bin_attribute___167 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___180 *, struct kobject___167 *, struct bin_attribute___167 *, char *, loff_t, size_t);
	int (*mmap)(struct file___180 *, struct kobject___167 *, struct bin_attribute___167 *, struct vm_area_struct___185 *);
};

struct sysfs_ops___167 {
	ssize_t (*show)(struct kobject___167 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___167 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___167;

struct kset___167 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___167 kobj;
	const struct kset_uevent_ops___167 *uevent_ops;
};

struct kobj_type___167 {
	void (*release)(struct kobject___167 *);
	const struct sysfs_ops___167 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___167 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___167 *);
	const void * (*namespace)(struct kobject___167 *);
	void (*get_ownership)(struct kobject___167 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___167 {
	int (* const filter)(struct kset___167 *, struct kobject___167 *);
	const char * (* const name)(struct kset___167 *, struct kobject___167 *);
	int (* const uevent)(struct kset___167 *, struct kobject___167 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___164 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___164 *);
	int (*get)(char *, const struct kernel_param___164 *);
	void (*free)(void *);
};

struct kparam_array___164;

struct kernel_param___164 {
	const char *name;
	struct module___164 *mod;
	const struct kernel_param_ops___164 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___164 *arr;
	};
};

struct kparam_array___164 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___164 *ops;
	void *elem;
};

struct module_attribute___164 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___164 *, struct module_kobject___164 *, char *);
	ssize_t (*store)(struct module_attribute___164 *, struct module_kobject___164 *, const char *, size_t);
	void (*setup)(struct module___164 *, const char *);
	int (*test)(struct module___164 *);
	void (*free)(struct module___164 *);
};

struct trace_event_class___67;

struct trace_event_call___67 {
	struct list_head list;
	struct trace_event_class___67 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___35 *prog_array;
	int (*perf_perm)(struct trace_event_call___67 *, struct perf_event___73 *);
};

struct cgroup_namespace___122 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___122 *root_cset;
};

struct dev_pm_ops___133 {
	int (*prepare)(struct device___133 *);
	void (*complete)(struct device___133 *);
	int (*suspend)(struct device___133 *);
	int (*resume)(struct device___133 *);
	int (*freeze)(struct device___133 *);
	int (*thaw)(struct device___133 *);
	int (*poweroff)(struct device___133 *);
	int (*restore)(struct device___133 *);
	int (*suspend_late)(struct device___133 *);
	int (*resume_early)(struct device___133 *);
	int (*freeze_late)(struct device___133 *);
	int (*thaw_early)(struct device___133 *);
	int (*poweroff_late)(struct device___133 *);
	int (*restore_early)(struct device___133 *);
	int (*suspend_noirq)(struct device___133 *);
	int (*resume_noirq)(struct device___133 *);
	int (*freeze_noirq)(struct device___133 *);
	int (*thaw_noirq)(struct device___133 *);
	int (*poweroff_noirq)(struct device___133 *);
	int (*restore_noirq)(struct device___133 *);
	int (*runtime_suspend)(struct device___133 *);
	int (*runtime_resume)(struct device___133 *);
	int (*runtime_idle)(struct device___133 *);
};

struct wakeup_source___133 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___133 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___133 {
	struct dev_pm_ops___133 ops;
	int (*start)(struct device___133 *);
	void (*detach)(struct device___133 *, bool);
	int (*activate)(struct device___133 *);
	void (*sync)(struct device___133 *);
	void (*dismiss)(struct device___133 *);
};

struct bus_type___133 {
	const char *name;
	const char *dev_name;
	struct device___133 *dev_root;
	const struct attribute_group___167 **bus_groups;
	const struct attribute_group___167 **dev_groups;
	const struct attribute_group___167 **drv_groups;
	int (*match)(struct device___133 *, struct device_driver___133 *);
	int (*uevent)(struct device___133 *, struct kobj_uevent_env *);
	int (*probe)(struct device___133 *);
	void (*sync_state)(struct device___133 *);
	void (*remove)(struct device___133 *);
	void (*shutdown)(struct device___133 *);
	int (*online)(struct device___133 *);
	int (*offline)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	int (*num_vf)(struct device___133 *);
	int (*dma_configure)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___133 {
	const char *name;
	struct bus_type___133 *bus;
	struct module___164 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___133 *);
	void (*sync_state)(struct device___133 *);
	int (*remove)(struct device___133 *);
	void (*shutdown)(struct device___133 *);
	int (*suspend)(struct device___133 *, pm_message_t);
	int (*resume)(struct device___133 *);
	const struct attribute_group___167 **groups;
	const struct attribute_group___167 **dev_groups;
	const struct dev_pm_ops___133 *pm;
	void (*coredump)(struct device___133 *);
	struct driver_private *p;
};

struct device_type___133 {
	const char *name;
	const struct attribute_group___167 **groups;
	int (*uevent)(struct device___133 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___133 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___133 *);
	const struct dev_pm_ops___133 *pm;
};

struct class___133 {
	const char *name;
	struct module___164 *owner;
	const struct attribute_group___167 **class_groups;
	const struct attribute_group___167 **dev_groups;
	struct kobject___167 *dev_kobj;
	int (*dev_uevent)(struct device___133 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___133 *, umode_t *);
	void (*class_release)(struct class___133 *);
	void (*dev_release)(struct device___133 *);
	int (*shutdown_pre)(struct device___133 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___133 *);
	void (*get_ownership)(struct device___133 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___133 *pm;
	struct subsys_private *p;
};

struct block_device_operations___88;

struct gendisk___89 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___89 *part0;
	const struct block_device_operations___88 *fops;
	struct request_queue___88 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___82 *bdi;
	struct kobject___167 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___167 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___88 {
	struct bio___88 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___103 *bip_vec;
	struct bio_vec___103 bip_inline_vecs[0];
};

struct blkcg___83;

struct blkg_policy_data___83;

struct blkcg_gq___83 {
	struct request_queue___88 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___83 *blkcg;
	struct blkcg_gq___83 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___83 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___88 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___88(struct request___88 *);

typedef void integrity_complete_fn___88(struct request___88 *, unsigned int);

struct blk_integrity_profile___88 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___88 *prepare_fn;
	integrity_complete_fn___88 *complete_fn;
	const char *name;
};

struct block_device_operations___88 {
	blk_qc_t (*submit_bio)(struct bio___88 *);
	int (*open)(struct block_device___89 *, fmode_t);
	void (*release)(struct gendisk___89 *, fmode_t);
	int (*rw_page)(struct block_device___89 *, sector_t, struct page___185 *, unsigned int);
	int (*ioctl)(struct block_device___89 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___89 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___89 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___89 *);
	int (*getgeo)(struct block_device___89 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___89 *, bool);
	void (*swap_slot_free_notify)(struct block_device___89 *, long unsigned int);
	int (*report_zones)(struct gendisk___89 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___89 *, umode_t *);
	struct module___164 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___89 *, sector_t *);
};

typedef void rq_end_io_fn___88(struct request___88 *, blk_status_t);

struct request___88 {
	struct request_queue___88 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___85 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___88 *bio;
	struct bio___88 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___103 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___88 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___88 *saved_end_io;
		} flush;
	};
	struct gendisk___89 *rq_disk;
	struct block_device___89 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___88 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___85 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___88 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___167 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___180 *debugfs_dir;
	struct dentry___180 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___88;

struct elevator_mq_ops___88 {
	int (*init_sched)(struct request_queue___88 *, struct elevator_type___88 *);
	void (*exit_sched)(struct elevator_queue___88 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___85 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___85 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___85 *);
	bool (*allow_merge)(struct request_queue___88 *, struct request___88 *, struct bio___88 *);
	bool (*bio_merge)(struct request_queue___88 *, struct bio___88 *, unsigned int);
	int (*request_merge)(struct request_queue___88 *, struct request___88 **, struct bio___88 *);
	void (*request_merged)(struct request_queue___88 *, struct request___88 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___88 *, struct request___88 *, struct request___88 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___88 *);
	void (*finish_request)(struct request___88 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___85 *, struct list_head *, bool);
	struct request___88 * (*dispatch_request)(struct blk_mq_hw_ctx___85 *);
	bool (*has_work)(struct blk_mq_hw_ctx___85 *);
	void (*completed_request)(struct request___88 *, u64);
	void (*requeue_request)(struct request___88 *);
	struct request___88 * (*former_request)(struct request_queue___88 *, struct request___88 *);
	struct request___88 * (*next_request)(struct request_queue___88 *, struct request___88 *);
	void (*init_icq)(struct io_cq___88 *);
	void (*exit_icq)(struct io_cq___88 *);
};

struct elv_fs_entry___88;

struct blk_mq_debugfs_attr___4;

struct elevator_type___88 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___88 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___88 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___164 *elevator_owner;
	const struct blk_mq_debugfs_attr___4 *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr___4 *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___88 {
	struct elevator_type___88 *type;
	void *elevator_data;
	struct kobject___167 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___88 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___88 *, char *);
	ssize_t (*store)(struct elevator_queue___88 *, const char *, size_t);
};

struct blk_mq_debugfs_attr___4 {
	const char *name;
	umode_t mode;
	int (*show)(void *, struct seq_file___157 *);
	ssize_t (*write)(void *, const char *, size_t, loff_t *);
	const struct seq_operations___157 *seq_ops;
};

struct rq_qos_ops___4;

struct rq_qos___4 {
	struct rq_qos_ops___4 *ops;
	struct request_queue___88 *q;
	enum rq_qos_id id;
	struct rq_qos___4 *next;
	struct dentry___180 *debugfs_dir;
};

struct blk_mq_queue_data___85;

struct blk_mq_ops___85 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___85 *, const struct blk_mq_queue_data___85 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___85 *);
	int (*get_budget)(struct request_queue___88 *);
	void (*put_budget)(struct request_queue___88 *, int);
	void (*set_rq_budget_token)(struct request___88 *, int);
	int (*get_rq_budget_token)(struct request___88 *);
	enum blk_eh_timer_return (*timeout)(struct request___88 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___85 *);
	void (*complete)(struct request___88 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___85 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___85 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___85 *, struct request___88 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___85 *, struct request___88 *, unsigned int);
	void (*initialize_rq_fn)(struct request___88 *);
	void (*cleanup_rq)(struct request___88 *);
	bool (*busy)(struct request_queue___88 *);
	int (*map_queues)(struct blk_mq_tag_set___85 *);
	void (*show_rq)(struct seq_file___157 *, struct request___88 *);
};

struct blk_stat_callback___9 {
	struct list_head list;
	struct timer_list timer;
	struct blk_rq_stat *cpu_stat;
	int (*bucket_fn)(const struct request___88 *);
	unsigned int buckets;
	struct blk_rq_stat *stat;
	void (*timer_fn)(struct blk_stat_callback___9 *);
	void *data;
	struct callback_head rcu;
};

struct blk_mq_tag_set___85 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___85 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___157 {
	void * (*start)(struct seq_file___157 *, loff_t *);
	void (*stop)(struct seq_file___157 *, void *);
	void * (*next)(struct seq_file___157 *, void *, loff_t *);
	int (*show)(struct seq_file___157 *, void *);
};

struct cftype___122;

struct cgroup_subsys___122 {
	struct cgroup_subsys_state___122 * (*css_alloc)(struct cgroup_subsys_state___122 *);
	int (*css_online)(struct cgroup_subsys_state___122 *);
	void (*css_offline)(struct cgroup_subsys_state___122 *);
	void (*css_released)(struct cgroup_subsys_state___122 *);
	void (*css_free)(struct cgroup_subsys_state___122 *);
	void (*css_reset)(struct cgroup_subsys_state___122 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___122 *, int);
	int (*css_extra_stat_show)(struct seq_file___157 *, struct cgroup_subsys_state___122 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___187 *, struct css_set___122 *);
	void (*cancel_fork)(struct task_struct___187 *, struct css_set___122 *);
	void (*fork)(struct task_struct___187 *);
	void (*exit)(struct task_struct___187 *);
	void (*release)(struct task_struct___187 *);
	void (*bind)(struct cgroup_subsys_state___122 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___122 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___122 *dfl_cftypes;
	struct cftype___122 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___122 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___122 *updated_children;
	struct cgroup___122 *updated_next;
};

struct cgroup_root___122 {
	struct kernfs_root___167 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___122 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___122 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___122 *ss;
	struct list_head node;
	struct kernfs_ops___167 *kf_ops;
	int (*open)(struct kernfs_open_file___167 *);
	void (*release)(struct kernfs_open_file___167 *);
	u64 (*read_u64)(struct cgroup_subsys_state___122 *, struct cftype___122 *);
	s64 (*read_s64)(struct cgroup_subsys_state___122 *, struct cftype___122 *);
	int (*seq_show)(struct seq_file___157 *, void *);
	void * (*seq_start)(struct seq_file___157 *, loff_t *);
	void * (*seq_next)(struct seq_file___157 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___157 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___122 *, struct cftype___122 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___122 *, struct cftype___122 *, s64);
	ssize_t (*write)(struct kernfs_open_file___167 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___167 *, struct poll_table_struct___118 *);
};

struct blk_mq_queue_data___85 {
	struct request___88 *rq;
	bool last;
};

struct blkcg_policy_data___83;

struct blkcg___83 {
	struct cgroup_subsys_state___122 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___83 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___83 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___83 {
	struct blkcg___83 *blkcg;
	int plid;
};

struct blkg_policy_data___83 {
	struct blkcg_gq___83 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___73 {
	struct mem_cgroup___73 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___73 {
	struct lruvec___80 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___73 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___73 *memcg;
};

struct obj_cgroup___73 {
	struct percpu_ref refcnt;
	struct mem_cgroup___73 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct rq_qos_ops___4 {
	void (*throttle)(struct rq_qos___4 *, struct bio___88 *);
	void (*track)(struct rq_qos___4 *, struct request___88 *, struct bio___88 *);
	void (*merge)(struct rq_qos___4 *, struct request___88 *, struct bio___88 *);
	void (*issue)(struct rq_qos___4 *, struct request___88 *);
	void (*requeue)(struct rq_qos___4 *, struct request___88 *);
	void (*done)(struct rq_qos___4 *, struct request___88 *);
	void (*done_bio)(struct rq_qos___4 *, struct bio___88 *);
	void (*cleanup)(struct rq_qos___4 *, struct bio___88 *);
	void (*queue_depth_changed)(struct rq_qos___4 *);
	void (*exit)(struct rq_qos___4 *);
	const struct blk_mq_debugfs_attr___4 *debugfs_attrs;
};

enum wbt_flags {
	WBT_TRACKED = 1,
	WBT_READ = 2,
	WBT_KSWAPD = 4,
	WBT_DISCARD = 8,
	WBT_NR_BITS = 4,
};

enum {
	WBT_STATE_ON_DEFAULT = 1,
	WBT_STATE_ON_MANUAL = 2,
	WBT_STATE_OFF_DEFAULT = 3,
};

struct rq_wb {
	unsigned int wb_background;
	unsigned int wb_normal;
	short int enable_state;
	unsigned int unknown_cnt;
	u64 win_nsec;
	u64 cur_win_nsec;
	struct blk_stat_callback___9 *cb;
	u64 sync_issue;
	void *sync_cookie;
	unsigned int wc;
	long unsigned int last_issue;
	long unsigned int last_comp;
	long unsigned int min_lat_nsec;
	struct rq_qos___4 rqos;
	struct rq_wait rq_wait[3];
	struct rq_depth rq_depth;
};

struct perf_cpu_context___73;

struct perf_output_handle___73;

struct pmu___73 {
	struct list_head entry;
	struct module___164 *module;
	struct device___133 *dev;
	const struct attribute_group___167 **attr_groups;
	const struct attribute_group___167 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___73 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___73 *);
	void (*pmu_disable)(struct pmu___73 *);
	int (*event_init)(struct perf_event___73 *);
	void (*event_mapped)(struct perf_event___73 *, struct mm_struct___186 *);
	void (*event_unmapped)(struct perf_event___73 *, struct mm_struct___186 *);
	int (*add)(struct perf_event___73 *, int);
	void (*del)(struct perf_event___73 *, int);
	void (*start)(struct perf_event___73 *, int);
	void (*stop)(struct perf_event___73 *, int);
	void (*read)(struct perf_event___73 *);
	void (*start_txn)(struct pmu___73 *, unsigned int);
	int (*commit_txn)(struct pmu___73 *);
	void (*cancel_txn)(struct pmu___73 *);
	int (*event_idx)(struct perf_event___73 *);
	void (*sched_task)(struct perf_event_context___73 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___73 *, struct perf_event_context___73 *);
	void * (*setup_aux)(struct perf_event___73 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___73 *, struct perf_output_handle___73 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___73 *);
	int (*aux_output_match)(struct perf_event___73 *);
	int (*filter_match)(struct perf_event___73 *);
	int (*check_period)(struct perf_event___73 *, u64);
};

struct perf_cpu_context___73 {
	struct perf_event_context___73 ctx;
	struct perf_event_context___73 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___73 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___73 **heap;
	struct perf_event___73 *heap_default[2];
};

struct perf_output_handle___73 {
	struct perf_event___73 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___73 {
	struct cgroup_subsys_state___122 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___67 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___67 *);
	};
};

struct trace_event_class___67 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___67 *, enum trace_reg, void *);
	struct trace_event_fields___67 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___67 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___67 *);
};

struct trace_event_file___30;

struct trace_event_buffer___29 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___30 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___30 {
	struct list_head list;
	struct trace_event_call___67 *event_call;
	struct event_filter *filter;
	struct dentry___180 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_wbt_stat {
	struct trace_entry ent;
	char name[32];
	s64 rmean;
	u64 rmin;
	u64 rmax;
	s64 rnr_samples;
	s64 rtime;
	s64 wmean;
	u64 wmin;
	u64 wmax;
	s64 wnr_samples;
	s64 wtime;
	char __data[0];
};

struct trace_event_raw_wbt_lat {
	struct trace_entry ent;
	char name[32];
	long unsigned int lat;
	char __data[0];
};

struct trace_event_raw_wbt_step {
	struct trace_entry ent;
	char name[32];
	const char *msg;
	int step;
	long unsigned int window;
	unsigned int bg;
	unsigned int normal;
	unsigned int max;
	char __data[0];
};

struct trace_event_raw_wbt_timer {
	struct trace_entry ent;
	char name[32];
	unsigned int status;
	int step;
	unsigned int inflight;
	char __data[0];
};

struct trace_event_data_offsets_wbt_stat {};

struct trace_event_data_offsets_wbt_lat {};

struct trace_event_data_offsets_wbt_step {};

struct trace_event_data_offsets_wbt_timer {};

typedef void (*btf_trace_wbt_stat)(void *, struct backing_dev_info___82 *, struct blk_rq_stat *);

typedef void (*btf_trace_wbt_lat)(void *, struct backing_dev_info___82 *, long unsigned int);

typedef void (*btf_trace_wbt_step)(void *, struct backing_dev_info___82 *, const char *, int, long unsigned int, unsigned int, unsigned int, unsigned int);

typedef void (*btf_trace_wbt_timer)(void *, struct backing_dev_info___82 *, unsigned int, int, unsigned int);

enum {
	RWB_DEF_DEPTH = 16,
	RWB_WINDOW_NSEC = 100000000,
	RWB_MIN_WRITE_SAMPLES = 3,
	RWB_UNKNOWN_BUMP = 5,
};

enum {
	LAT_OK = 1,
	LAT_UNKNOWN = 2,
	LAT_UNKNOWN_WRITES = 3,
	LAT_EXCEEDED = 4,
};

struct wbt_wait_data {
	struct rq_wb *rwb;
	enum wbt_flags wb_acct;
	long unsigned int rw;
};

typedef bool busy_tag_iter_fn___2(struct request___88 *, void *, bool);

struct show_busy_params {
	struct seq_file___157 *m;
	struct blk_mq_hw_ctx___24 *hctx;
};

enum opal_mbr {
	OPAL_MBR_ENABLE = 0,
	OPAL_MBR_DISABLE = 1,
};

enum opal_mbr_done_flag {
	OPAL_MBR_NOT_DONE = 0,
	OPAL_MBR_DONE = 1,
};

enum opal_user {
	OPAL_ADMIN1 = 0,
	OPAL_USER1 = 1,
	OPAL_USER2 = 2,
	OPAL_USER3 = 3,
	OPAL_USER4 = 4,
	OPAL_USER5 = 5,
	OPAL_USER6 = 6,
	OPAL_USER7 = 7,
	OPAL_USER8 = 8,
	OPAL_USER9 = 9,
};

enum opal_lock_state {
	OPAL_RO = 1,
	OPAL_RW = 2,
	OPAL_LK = 4,
};

struct opal_key {
	__u8 lr;
	__u8 key_len;
	__u8 __align[6];
	__u8 key[256];
};

struct opal_lr_act {
	struct opal_key key;
	__u32 sum;
	__u8 num_lrs;
	__u8 lr[9];
	__u8 align[2];
};

struct opal_session_info {
	__u32 sum;
	__u32 who;
	struct opal_key opal_key;
};

struct opal_user_lr_setup {
	__u64 range_start;
	__u64 range_length;
	__u32 RLE;
	__u32 WLE;
	struct opal_session_info session;
};

struct opal_lock_unlock {
	struct opal_session_info session;
	__u32 l_state;
	__u8 __align[4];
};

struct opal_new_pw {
	struct opal_session_info session;
	struct opal_session_info new_user_pw;
};

struct opal_mbr_data {
	struct opal_key key;
	__u8 enable_disable;
	__u8 __align[7];
};

struct opal_mbr_done {
	struct opal_key key;
	__u8 done_flag;
	__u8 __align[7];
};

struct opal_shadow_mbr {
	struct opal_key key;
	const __u64 data;
	__u64 offset;
	__u64 size;
};

enum opal_table_ops {
	OPAL_READ_TABLE = 0,
	OPAL_WRITE_TABLE = 1,
};

struct opal_read_write_table {
	struct opal_key key;
	const __u64 data;
	const __u8 table_uid[8];
	__u64 offset;
	__u64 size;
	__u64 flags;
	__u64 priv;
};

typedef int sec_send_recv(void *, u16, u8, void *, size_t, bool);

enum {
	TCG_SECP_00 = 0,
	TCG_SECP_01 = 1,
};

enum opal_response_token {
	OPAL_DTA_TOKENID_BYTESTRING = 224,
	OPAL_DTA_TOKENID_SINT = 225,
	OPAL_DTA_TOKENID_UINT = 226,
	OPAL_DTA_TOKENID_TOKEN = 227,
	OPAL_DTA_TOKENID_INVALID = 0,
};

enum opal_uid {
	OPAL_SMUID_UID = 0,
	OPAL_THISSP_UID = 1,
	OPAL_ADMINSP_UID = 2,
	OPAL_LOCKINGSP_UID = 3,
	OPAL_ENTERPRISE_LOCKINGSP_UID = 4,
	OPAL_ANYBODY_UID = 5,
	OPAL_SID_UID = 6,
	OPAL_ADMIN1_UID = 7,
	OPAL_USER1_UID = 8,
	OPAL_USER2_UID = 9,
	OPAL_PSID_UID = 10,
	OPAL_ENTERPRISE_BANDMASTER0_UID = 11,
	OPAL_ENTERPRISE_ERASEMASTER_UID = 12,
	OPAL_TABLE_TABLE = 13,
	OPAL_LOCKINGRANGE_GLOBAL = 14,
	OPAL_LOCKINGRANGE_ACE_RDLOCKED = 15,
	OPAL_LOCKINGRANGE_ACE_WRLOCKED = 16,
	OPAL_MBRCONTROL = 17,
	OPAL_MBR = 18,
	OPAL_AUTHORITY_TABLE = 19,
	OPAL_C_PIN_TABLE = 20,
	OPAL_LOCKING_INFO_TABLE = 21,
	OPAL_ENTERPRISE_LOCKING_INFO_TABLE = 22,
	OPAL_DATASTORE = 23,
	OPAL_C_PIN_MSID = 24,
	OPAL_C_PIN_SID = 25,
	OPAL_C_PIN_ADMIN1 = 26,
	OPAL_HALF_UID_AUTHORITY_OBJ_REF = 27,
	OPAL_HALF_UID_BOOLEAN_ACE = 28,
	OPAL_UID_HEXFF = 29,
};

enum opal_method {
	OPAL_PROPERTIES = 0,
	OPAL_STARTSESSION = 1,
	OPAL_REVERT = 2,
	OPAL_ACTIVATE = 3,
	OPAL_EGET = 4,
	OPAL_ESET = 5,
	OPAL_NEXT = 6,
	OPAL_EAUTHENTICATE = 7,
	OPAL_GETACL = 8,
	OPAL_GENKEY = 9,
	OPAL_REVERTSP = 10,
	OPAL_GET = 11,
	OPAL_SET = 12,
	OPAL_AUTHENTICATE = 13,
	OPAL_RANDOM = 14,
	OPAL_ERASE = 15,
};

enum opal_token {
	OPAL_TRUE = 1,
	OPAL_FALSE = 0,
	OPAL_BOOLEAN_EXPR = 3,
	OPAL_TABLE = 0,
	OPAL_STARTROW = 1,
	OPAL_ENDROW = 2,
	OPAL_STARTCOLUMN = 3,
	OPAL_ENDCOLUMN = 4,
	OPAL_VALUES = 1,
	OPAL_TABLE_UID = 0,
	OPAL_TABLE_NAME = 1,
	OPAL_TABLE_COMMON = 2,
	OPAL_TABLE_TEMPLATE = 3,
	OPAL_TABLE_KIND = 4,
	OPAL_TABLE_COLUMN = 5,
	OPAL_TABLE_COLUMNS = 6,
	OPAL_TABLE_ROWS = 7,
	OPAL_TABLE_ROWS_FREE = 8,
	OPAL_TABLE_ROW_BYTES = 9,
	OPAL_TABLE_LASTID = 10,
	OPAL_TABLE_MIN = 11,
	OPAL_TABLE_MAX = 12,
	OPAL_PIN = 3,
	OPAL_RANGESTART = 3,
	OPAL_RANGELENGTH = 4,
	OPAL_READLOCKENABLED = 5,
	OPAL_WRITELOCKENABLED = 6,
	OPAL_READLOCKED = 7,
	OPAL_WRITELOCKED = 8,
	OPAL_ACTIVEKEY = 10,
	OPAL_LIFECYCLE = 6,
	OPAL_MAXRANGES = 4,
	OPAL_MBRENABLE = 1,
	OPAL_MBRDONE = 2,
	OPAL_HOSTPROPERTIES = 0,
	OPAL_STARTLIST = 240,
	OPAL_ENDLIST = 241,
	OPAL_STARTNAME = 242,
	OPAL_ENDNAME = 243,
	OPAL_CALL = 248,
	OPAL_ENDOFDATA = 249,
	OPAL_ENDOFSESSION = 250,
	OPAL_STARTTRANSACTON = 251,
	OPAL_ENDTRANSACTON = 252,
	OPAL_EMPTYATOM = 255,
	OPAL_WHERE = 0,
};

enum opal_parameter {
	OPAL_SUM_SET_LIST = 393216,
};

struct opal_compacket {
	__be32 reserved0;
	u8 extendedComID[4];
	__be32 outstandingData;
	__be32 minTransfer;
	__be32 length;
};

struct opal_packet {
	__be32 tsn;
	__be32 hsn;
	__be32 seq_number;
	__be16 reserved0;
	__be16 ack_type;
	__be32 acknowledgment;
	__be32 length;
};

struct opal_data_subpacket {
	u8 reserved0[6];
	__be16 kind;
	__be32 length;
};

struct opal_header {
	struct opal_compacket cp;
	struct opal_packet pkt;
	struct opal_data_subpacket subpkt;
};

struct d0_header {
	__be32 length;
	__be32 revision;
	__be32 reserved01;
	__be32 reserved02;
	u8 ignored[32];
};

struct d0_tper_features {
	u8 supported_features;
	u8 reserved01[3];
	__be32 reserved02;
	__be32 reserved03;
};

struct d0_locking_features {
	u8 supported_features;
	u8 reserved01[3];
	__be32 reserved02;
	__be32 reserved03;
};

struct d0_geometry_features {
	u8 header[4];
	u8 reserved01;
	u8 reserved02[7];
	__be32 logical_block_size;
	__be64 alignment_granularity;
	__be64 lowest_aligned_lba;
};

struct d0_opal_v100 {
	__be16 baseComID;
	__be16 numComIDs;
};

struct d0_single_user_mode {
	__be32 num_locking_objects;
	u8 reserved01;
	u8 reserved02;
	__be16 reserved03;
	__be32 reserved04;
};

struct d0_opal_v200 {
	__be16 baseComID;
	__be16 numComIDs;
	u8 range_crossing;
	u8 num_locking_admin_auth[2];
	u8 num_locking_user_auth[2];
	u8 initialPIN;
	u8 revertedPIN;
	u8 reserved01;
	__be32 reserved02;
};

struct d0_features {
	__be16 code;
	u8 r_version;
	u8 length;
	u8 features[0];
};

struct opal_dev;

struct opal_step {
	int (*fn)(struct opal_dev *, void *);
	void *data;
};

enum opal_atom_width {
	OPAL_WIDTH_TINY = 0,
	OPAL_WIDTH_SHORT = 1,
	OPAL_WIDTH_MEDIUM = 2,
	OPAL_WIDTH_LONG = 3,
	OPAL_WIDTH_TOKEN = 4,
};

struct opal_resp_tok {
	const u8 *pos;
	size_t len;
	enum opal_response_token type;
	enum opal_atom_width width;
	union {
		u64 u;
		s64 s;
	} stored;
};

struct parsed_resp {
	int num;
	struct opal_resp_tok toks[64];
};

struct opal_dev {
	bool supported;
	bool mbr_enabled;
	void *data;
	sec_send_recv *send_recv;
	struct mutex dev_lock;
	u16 comid;
	u32 hsn;
	u32 tsn;
	u64 align;
	u64 lowest_lba;
	size_t pos;
	u8 cmd[2048];
	u8 resp[2048];
	struct parsed_resp parsed;
	size_t prev_d_len;
	void *prev_data;
	struct list_head unlk_lst;
};

typedef int cont_fn(struct opal_dev *);

struct opal_suspend_data {
	struct opal_lock_unlock unlk;
	u8 lr;
	struct list_head node;
};

struct blk_ksm_keyslot {
	atomic_t slot_refs;
	struct list_head idle_slot_node;
	struct hlist_node hash_node;
	const struct blk_crypto_key *key;
	struct blk_keyslot_manager *ksm;
};

struct blk_ksm_ll_ops {
	int (*keyslot_program)(struct blk_keyslot_manager *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager {
	struct blk_ksm_ll_ops ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___133 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct blk_crypto_mode {
	const char *cipher_str;
	unsigned int keysize;
	unsigned int ivsize;
};

struct dentry___181;

struct super_block___181;

struct module___165;

struct file_system_type___181 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___181 * (*mount)(struct file_system_type___181 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___181 *);
	struct module___165 *owner;
	struct file_system_type___181 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___181;

struct kiocb___181;

struct iov_iter___106;

struct vm_area_struct___186;

struct inode___181;

struct file_lock___181;

struct page___186;

struct seq_file___158;

struct file_operations___181 {
	struct module___165 *owner;
	loff_t (*llseek)(struct file___181 *, loff_t, int);
	ssize_t (*read)(struct file___181 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___181 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___181 *, struct iov_iter___106 *);
	ssize_t (*write_iter)(struct kiocb___181 *, struct iov_iter___106 *);
	int (*iopoll)(struct kiocb___181 *, bool);
	int (*iterate)(struct file___181 *, struct dir_context *);
	int (*iterate_shared)(struct file___181 *, struct dir_context *);
	__poll_t (*poll)(struct file___181 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___181 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___181 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___181 *, struct vm_area_struct___186 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___181 *, struct file___181 *);
	int (*flush)(struct file___181 *, fl_owner_t);
	int (*release)(struct inode___181 *, struct file___181 *);
	int (*fsync)(struct file___181 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___181 *, int);
	int (*lock)(struct file___181 *, int, struct file_lock___181 *);
	ssize_t (*sendpage)(struct file___181 *, struct page___186 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___181 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___181 *, long unsigned int);
	int (*flock)(struct file___181 *, int, struct file_lock___181 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___181 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___181 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___181 *, long int, struct file_lock___181 **, void **);
	long int (*fallocate)(struct file___181 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___158 *, struct file___181 *);
	ssize_t (*copy_file_range)(struct file___181 *, loff_t, struct file___181 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___181 *, loff_t, struct file___181 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___181 *, loff_t, loff_t, int);
};

struct vmacache___186 {
	u64 seqnum;
	struct vm_area_struct___186 *vmas[4];
};

struct page_frag___186 {
	struct page___186 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___187;

struct pid___161;

struct nsproxy___170;

struct signal_struct___182;

struct bio_list___89;

struct io_context___89;

struct css_set___123;

struct request_queue___89;

struct vm_struct___164;

struct task_struct___188 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___188 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___187 *mm;
	struct mm_struct___187 *active_mm;
	struct vmacache___186 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___188 *real_parent;
	struct task_struct___188 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___188 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___161 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___170 *nsproxy;
	struct signal_struct___182 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___188 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___89 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___89 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___123 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___186 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___89 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___188 *oom_reaper_list;
	struct vm_struct___164 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___168;

struct kobj_type___168;

struct kernfs_node___168;

struct kobject___168 {
	const char *name;
	struct list_head entry;
	struct kobject___168 *parent;
	struct kset___168 *kset;
	struct kobj_type___168 *ktype;
	struct kernfs_node___168 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___165 {
	struct kobject___168 kobj;
	struct module___165 *mod;
	struct kobject___168 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___165 {
	struct module___165 *mod;
	struct latch_tree_node node;
};

struct module_layout___165 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___165 mtn;
};

struct module_attribute___165;

struct kernel_param___165;

struct module___165 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___165 mkobj;
	struct module_attribute___165 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___168 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___165 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___165 core_layout;
	struct module_layout___165 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___186 *pgtable_t___186;

struct address_space___181;

struct dev_pagemap___176;

struct page___186 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___181 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___186 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___186 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___187 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___176 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___176;

struct vm_area_struct___186 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___186 *vm_next;
	struct vm_area_struct___186 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___187 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___176 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___181 *vm_file;
	struct file___181 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___186;

struct mm_struct___187 {
	struct {
		struct vm_area_struct___186 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___181 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___186 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___188 *owner;
		struct user_namespace___25 *user_ns;
		struct file___181 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___181;

struct address_space___181 {
	struct inode___181 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___181 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___176;

struct dev_pagemap___176 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___176 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___181;

struct path___181 {
	struct vfsmount___181 *mnt;
	struct dentry___181 *dentry;
};

struct fown_struct___161 {
	rwlock_t lock;
	struct pid___161 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___181 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___181 f_path;
	struct inode___181 *f_inode;
	const struct file_operations___181 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___161 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___181 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___176;

struct vm_operations_struct___176 {
	void (*open)(struct vm_area_struct___186 *);
	void (*close)(struct vm_area_struct___186 *);
	int (*may_split)(struct vm_area_struct___186 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___186 *);
	int (*mprotect)(struct vm_area_struct___186 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___176 *);
	vm_fault_t (*huge_fault)(struct vm_fault___176 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___176 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___186 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___176 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___176 *);
	int (*access)(struct vm_area_struct___186 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___186 *);
	int (*set_policy)(struct vm_area_struct___186 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___186 *, long unsigned int);
	struct page___186 * (*find_special_page)(struct vm_area_struct___186 *, long unsigned int);
};

struct core_thread___186 {
	struct task_struct___188 *task;
	struct core_thread___186 *next;
};

struct core_state___186 {
	atomic_t nr_threads;
	struct core_thread___186 dumper;
	struct completion startup;
};

struct vm_fault___176 {
	const struct {
		struct vm_area_struct___186 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___186 *cow_page;
	struct page___186 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___186 prealloc_pte;
};

struct crypto_async_request___8;

typedef void (*crypto_completion_t___8)(struct crypto_async_request___8 *, int);

struct crypto_tfm___21;

struct crypto_async_request___8 {
	struct list_head list;
	crypto_completion_t___8 complete;
	void *data;
	struct crypto_tfm___21 *tfm;
	u32 flags;
};

struct crypto_alg___21;

struct crypto_tfm___21 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___21 *);
	struct crypto_alg___21 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___21 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___21 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___21 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___21 *, u8 *, const u8 *);
};

struct compress_alg___21 {
	int (*coa_compress)(struct crypto_tfm___21 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___21 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___21 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___21 cipher;
		struct compress_alg___21 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___21 *);
	void (*cra_exit)(struct crypto_tfm___21 *);
	void (*cra_destroy)(struct crypto_alg___21 *);
	struct module___165 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct skcipher_request___5 {
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	struct crypto_async_request___8 base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_skcipher___8 {
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___21 base;
};

struct pid_namespace___161;

struct upid___161 {
	int nr;
	struct pid_namespace___161 *ns;
};

struct pid_namespace___161 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___188 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___161 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___161 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___161 numbers[1];
};

struct signal_struct___182 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___188 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___188 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___161 *pids[4];
	struct pid___161 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___187 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___123;

struct nsproxy___170 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___161 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___123 *cgroup_ns;
};

struct bio___89;

struct bio_list___89 {
	struct bio___89 *head;
	struct bio___89 *tail;
};

struct io_cq___89;

struct io_context___89 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___89 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup_subsys_state___123;

struct cgroup___123;

struct css_set___123 {
	struct cgroup_subsys_state___123 *subsys[14];
	refcount_t refcount;
	struct css_set___123 *dom_cset;
	struct cgroup___123 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___123 *mg_src_cgrp;
	struct cgroup___123 *mg_dst_cgrp;
	struct css_set___123 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___89;

struct blk_integrity___89 {
	const struct blk_integrity_profile___89 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___89 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___89 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___89;

struct elevator_queue___89;

struct blk_mq_ops___86;

struct blk_mq_hw_ctx___86;

struct gendisk___90;

struct device___134;

struct blk_keyslot_manager___2;

struct blkcg_gq___84;

struct blk_mq_tag_set___86;

struct request_queue___89 {
	struct request___89 *last_merge;
	struct elevator_queue___89 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___86 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___86 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___90 *disk;
	struct kobject___168 kobj;
	struct kobject___168 *mq_kobj;
	struct blk_integrity___89 integrity;
	struct device___134 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___2 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___84 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___86 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___89 bio_split;
	struct dentry___181 *debugfs_dir;
	struct dentry___181 *sched_debugfs_dir;
	struct dentry___181 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___164 {
	struct vm_struct___164 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___186 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___181;

struct dentry___181 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___181 *d_parent;
	struct qstr d_name;
	struct inode___181 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___181 *d_op;
	struct super_block___181 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___181;

struct inode___181 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___181 *i_op;
	struct super_block___181 *i_sb;
	struct address_space___181 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___181 *i_fop;
		void (*free_inode)(struct inode___181 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___181 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___33 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___181 {
	int (*d_revalidate)(struct dentry___181 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___181 *, unsigned int);
	int (*d_hash)(const struct dentry___181 *, struct qstr *);
	int (*d_compare)(const struct dentry___181 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___181 *);
	int (*d_init)(struct dentry___181 *);
	void (*d_release)(struct dentry___181 *);
	void (*d_prune)(struct dentry___181 *);
	void (*d_iput)(struct dentry___181 *, struct inode___181 *);
	char * (*d_dname)(struct dentry___181 *, char *, int);
	struct vfsmount___181 * (*d_automount)(struct path___181 *);
	int (*d_manage)(const struct path___181 *, bool);
	struct dentry___181 * (*d_real)(struct dentry___181 *, const struct inode___181 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___181;

struct mem_dqinfo___181 {
	struct quota_format_type___181 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___181;

struct quota_info___181 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___181 *files[3];
	struct mem_dqinfo___181 info[3];
	const struct quota_format_ops___181 *ops[3];
};

struct rcuwait___182 {
	struct task_struct___188 *task;
};

struct percpu_rw_semaphore___182 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___182 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___181 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___182 rw_sem[3];
};

struct super_operations___181;

struct dquot_operations___181;

struct quotactl_ops___181;

struct block_device___90;

struct super_block___181 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___181 *s_type;
	const struct super_operations___181 *s_op;
	const struct dquot_operations___181 *dq_op;
	const struct quotactl_ops___181 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___181 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___90 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___181 s_dquot;
	struct sb_writers___181 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___181 *s_d_op;
	int cleancache_poolid;
	struct shrinker___73 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___181 {
	struct dentry___181 *mnt_root;
	struct super_block___181 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct cgroup_subsys___123;

struct cgroup_subsys_state___123 {
	struct cgroup___123 *cgroup;
	struct cgroup_subsys___123 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___123 *parent;
};

struct cgroup_file___123 {
	struct kernfs_node___168 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___123 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___188 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___123;

struct cgroup_rstat_cpu___123;

struct cgroup___123 {
	struct cgroup_subsys_state___123 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___168 *kn;
	struct cgroup_file___123 procs_file;
	struct cgroup_file___123 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___123 *subsys[14];
	struct cgroup_root___123 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___123 *dom_cgrp;
	struct cgroup___123 *old_dom_cgrp;
	struct cgroup_rstat_cpu___123 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___123 psi;
	struct cgroup_bpf___35 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___89 {
	struct request_queue___89 *q;
	struct io_context___89 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___181 {
	struct file___181 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___181 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___81 *ki_waitq;
	};
};

struct iattr___181 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___181 *ia_file;
};

struct dquot___181 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___181 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___181 {
	int qf_fmt_id;
	const struct quota_format_ops___181 *qf_ops;
	struct module___165 *qf_owner;
	struct quota_format_type___181 *qf_next;
};

struct quota_format_ops___181 {
	int (*check_quota_file)(struct super_block___181 *, int);
	int (*read_file_info)(struct super_block___181 *, int);
	int (*write_file_info)(struct super_block___181 *, int);
	int (*free_file_info)(struct super_block___181 *, int);
	int (*read_dqblk)(struct dquot___181 *);
	int (*commit_dqblk)(struct dquot___181 *);
	int (*release_dqblk)(struct dquot___181 *);
	int (*get_next_id)(struct super_block___181 *, struct kqid *);
};

struct dquot_operations___181 {
	int (*write_dquot)(struct dquot___181 *);
	struct dquot___181 * (*alloc_dquot)(struct super_block___181 *, int);
	void (*destroy_dquot)(struct dquot___181 *);
	int (*acquire_dquot)(struct dquot___181 *);
	int (*release_dquot)(struct dquot___181 *);
	int (*mark_dirty)(struct dquot___181 *);
	int (*write_info)(struct super_block___181 *, int);
	qsize_t * (*get_reserved_space)(struct inode___181 *);
	int (*get_projid)(struct inode___181 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___181 *, qsize_t *);
	int (*get_next_id)(struct super_block___181 *, struct kqid *);
};

struct quotactl_ops___181 {
	int (*quota_on)(struct super_block___181 *, int, int, const struct path___181 *);
	int (*quota_off)(struct super_block___181 *, int);
	int (*quota_enable)(struct super_block___181 *, unsigned int);
	int (*quota_disable)(struct super_block___181 *, unsigned int);
	int (*quota_sync)(struct super_block___181 *, int);
	int (*set_info)(struct super_block___181 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___181 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___181 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___181 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___181 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___181 *, unsigned int);
};

struct address_space_operations___181 {
	int (*writepage)(struct page___186 *, struct writeback_control___3 *);
	int (*readpage)(struct file___181 *, struct page___186 *);
	int (*writepages)(struct address_space___181 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___186 *);
	int (*readpages)(struct file___181 *, struct address_space___181 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___181 *, struct address_space___181 *, loff_t, unsigned int, unsigned int, struct page___186 **, void **);
	int (*write_end)(struct file___181 *, struct address_space___181 *, loff_t, unsigned int, unsigned int, struct page___186 *, void *);
	sector_t (*bmap)(struct address_space___181 *, sector_t);
	void (*invalidatepage)(struct page___186 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___186 *, gfp_t);
	void (*freepage)(struct page___186 *);
	ssize_t (*direct_IO)(struct kiocb___181 *, struct iov_iter___106 *);
	int (*migratepage)(struct address_space___181 *, struct page___186 *, struct page___186 *, enum migrate_mode);
	bool (*isolate_page)(struct page___186 *, isolate_mode_t);
	void (*putback_page)(struct page___186 *);
	int (*launder_page)(struct page___186 *);
	int (*is_partially_uptodate)(struct page___186 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___186 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___181 *, struct page___186 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___181 *, sector_t *);
	void (*swap_deactivate)(struct file___181 *);
};

struct bio_vec___104;

struct iov_iter___106 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___104 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___181 {
	struct dentry___181 * (*lookup)(struct inode___181 *, struct dentry___181 *, unsigned int);
	const char * (*get_link)(struct dentry___181 *, struct inode___181 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___181 *, int);
	struct posix_acl * (*get_acl)(struct inode___181 *, int, bool);
	int (*readlink)(struct dentry___181 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___181 *, struct dentry___181 *, umode_t, bool);
	int (*link)(struct dentry___181 *, struct inode___181 *, struct dentry___181 *);
	int (*unlink)(struct inode___181 *, struct dentry___181 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___181 *, struct dentry___181 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___181 *, struct dentry___181 *, umode_t);
	int (*rmdir)(struct inode___181 *, struct dentry___181 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___181 *, struct dentry___181 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___181 *, struct dentry___181 *, struct inode___181 *, struct dentry___181 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___181 *, struct iattr___181 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___181 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___181 *, char *, size_t);
	int (*fiemap)(struct inode___181 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___181 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___181 *, struct dentry___181 *, struct file___181 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___181 *, struct dentry___181 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___181 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___181 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___181 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___181 {
	void (*fl_copy_lock)(struct file_lock___181 *, struct file_lock___181 *);
	void (*fl_release_private)(struct file_lock___181 *);
};

struct fasync_struct___181;

struct lock_manager_operations___181;

struct file_lock___181 {
	struct file_lock___181 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___181 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___181 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___181 *fl_ops;
	const struct lock_manager_operations___181 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___181 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___181 *);
	int (*lm_grant)(struct file_lock___181 *, int);
	bool (*lm_break)(struct file_lock___181 *);
	int (*lm_change)(struct file_lock___181 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___181 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___181 *);
};

struct fasync_struct___181 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___181 *fa_next;
	struct file___181 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___181 {
	struct inode___181 * (*alloc_inode)(struct super_block___181 *);
	void (*destroy_inode)(struct inode___181 *);
	void (*free_inode)(struct inode___181 *);
	void (*dirty_inode)(struct inode___181 *, int);
	int (*write_inode)(struct inode___181 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___181 *);
	void (*evict_inode)(struct inode___181 *);
	void (*put_super)(struct super_block___181 *);
	int (*sync_fs)(struct super_block___181 *, int);
	int (*freeze_super)(struct super_block___181 *);
	int (*freeze_fs)(struct super_block___181 *);
	int (*thaw_super)(struct super_block___181 *);
	int (*unfreeze_fs)(struct super_block___181 *);
	int (*statfs)(struct dentry___181 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___181 *, int *, char *);
	void (*umount_begin)(struct super_block___181 *);
	int (*show_options)(struct seq_file___158 *, struct dentry___181 *);
	int (*show_devname)(struct seq_file___158 *, struct dentry___181 *);
	int (*show_path)(struct seq_file___158 *, struct dentry___181 *);
	int (*show_stats)(struct seq_file___158 *, struct dentry___181 *);
	ssize_t (*quota_read)(struct super_block___181 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___181 *, int, const char *, size_t, loff_t);
	struct dquot___181 ** (*get_dquots)(struct inode___181 *);
	long int (*nr_cached_objects)(struct super_block___181 *, struct shrink_control___73 *);
	long int (*free_cached_objects)(struct super_block___181 *, struct shrink_control___73 *);
	struct file___181 * (*real_loop)(struct file___181 *);
};

struct wakeup_source___134;

struct dev_pm_info___134 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___134 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___134 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___134;

struct bus_type___134;

struct device_driver___134;

struct dev_pm_domain___134;

struct fwnode_handle___134;

struct class___134;

struct attribute_group___168;

struct device___134 {
	struct kobject___168 kobj;
	struct device___134 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___134 *type;
	struct bus_type___134 *bus;
	struct device_driver___134 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___134 power;
	struct dev_pm_domain___134 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___134 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___134 *class;
	const struct attribute_group___168 **groups;
	void (*release)(struct device___134 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___90 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___181 *bd_inode;
	struct super_block___181 *bd_super;
	void *bd_claiming;
	struct device___134 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___168 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___90 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___181 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___158;

struct seq_file___158 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___158 *op;
	int poll_event;
	const struct file___181 *file;
	void *private;
};

typedef void bio_end_io_t___89(struct bio___89 *);

struct bio_vec___104 {
	struct page___186 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___89;

struct bio___89 {
	struct bio___89 *bi_next;
	struct block_device___90 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___89 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___84 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___89 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___104 *bi_io_vec;
	struct bio_set___89 *bi_pool;
	struct bio_vec___104 bi_inline_vecs[0];
};

struct seq_operations___158 {
	void * (*start)(struct seq_file___158 *, loff_t *);
	void (*stop)(struct seq_file___158 *, void *);
	void * (*next)(struct seq_file___158 *, void *, loff_t *);
	int (*show)(struct seq_file___158 *, void *);
};

struct kernfs_root___168;

struct kernfs_elem_dir___168 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___168 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___168;

struct kernfs_root___168 {
	struct kernfs_node___168 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___168 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___168 {
	struct kernfs_node___168 *target_kn;
};

struct kernfs_ops___168;

struct kernfs_elem_attr___168 {
	const struct kernfs_ops___168 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___168 *notify_next;
};

struct kernfs_node___168 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___168 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___168 dir;
		struct kernfs_elem_symlink___168 symlink;
		struct kernfs_elem_attr___168 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___168;

struct kernfs_ops___168 {
	int (*open)(struct kernfs_open_file___168 *);
	void (*release)(struct kernfs_open_file___168 *);
	int (*seq_show)(struct seq_file___158 *, void *);
	void * (*seq_start)(struct seq_file___158 *, loff_t *);
	void * (*seq_next)(struct seq_file___158 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___158 *, void *);
	ssize_t (*read)(struct kernfs_open_file___168 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___168 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___168 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___168 *, struct vm_area_struct___186 *);
};

struct kernfs_syscall_ops___168 {
	int (*show_options)(struct seq_file___158 *, struct kernfs_root___168 *);
	int (*mkdir)(struct kernfs_node___168 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___168 *);
	int (*rename)(struct kernfs_node___168 *, struct kernfs_node___168 *, const char *);
	int (*show_path)(struct seq_file___158 *, struct kernfs_node___168 *, struct kernfs_root___168 *);
};

struct kernfs_open_file___168 {
	struct kernfs_node___168 *kn;
	struct file___181 *file;
	struct seq_file___158 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___176 *vm_ops;
};

struct cgroup_namespace___123 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___123 *root_cset;
};

struct fwnode_operations___134;

struct fwnode_handle___134 {
	struct fwnode_handle___134 *secondary;
	const struct fwnode_operations___134 *ops;
	struct device___134 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___134;

struct fwnode_endpoint___134;

struct fwnode_operations___134 {
	struct fwnode_handle___134 * (*get)(struct fwnode_handle___134 *);
	void (*put)(struct fwnode_handle___134 *);
	bool (*device_is_available)(const struct fwnode_handle___134 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___134 *, const struct device___134 *);
	bool (*property_present)(const struct fwnode_handle___134 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___134 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___134 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___134 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*get_parent)(const struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*get_next_child_node)(const struct fwnode_handle___134 *, struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*get_named_child_node)(const struct fwnode_handle___134 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___134 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___134 *);
	struct fwnode_handle___134 * (*graph_get_next_endpoint)(const struct fwnode_handle___134 *, struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*graph_get_remote_endpoint)(const struct fwnode_handle___134 *);
	struct fwnode_handle___134 * (*graph_get_port_parent)(struct fwnode_handle___134 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___134 *, struct fwnode_endpoint___134 *);
	int (*add_links)(struct fwnode_handle___134 *);
};

struct fwnode_endpoint___134 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___134 *local_fwnode;
};

struct fwnode_reference_args___134 {
	struct fwnode_handle___134 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bin_attribute___168;

struct attribute_group___168 {
	const char *name;
	umode_t (*is_visible)(struct kobject___168 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___168 *, struct bin_attribute___168 *, int);
	struct attribute **attrs;
	struct bin_attribute___168 **bin_attrs;
};

struct bin_attribute___168 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___181 * (*f_mapping)();
	ssize_t (*read)(struct file___181 *, struct kobject___168 *, struct bin_attribute___168 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___181 *, struct kobject___168 *, struct bin_attribute___168 *, char *, loff_t, size_t);
	int (*mmap)(struct file___181 *, struct kobject___168 *, struct bin_attribute___168 *, struct vm_area_struct___186 *);
};

struct sysfs_ops___168 {
	ssize_t (*show)(struct kobject___168 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___168 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___168;

struct kset___168 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___168 kobj;
	const struct kset_uevent_ops___168 *uevent_ops;
};

struct kobj_type___168 {
	void (*release)(struct kobject___168 *);
	const struct sysfs_ops___168 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___168 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___168 *);
	const void * (*namespace)(struct kobject___168 *);
	void (*get_ownership)(struct kobject___168 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___168 {
	int (* const filter)(struct kset___168 *, struct kobject___168 *);
	const char * (* const name)(struct kset___168 *, struct kobject___168 *);
	int (* const uevent)(struct kset___168 *, struct kobject___168 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___165 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___165 *);
	int (*get)(char *, const struct kernel_param___165 *);
	void (*free)(void *);
};

struct kparam_array___165;

struct kernel_param___165 {
	const char *name;
	struct module___165 *mod;
	const struct kernel_param_ops___165 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___165 *arr;
	};
};

struct kparam_array___165 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___165 *ops;
	void *elem;
};

struct module_attribute___165 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___165 *, struct module_kobject___165 *, char *);
	ssize_t (*store)(struct module_attribute___165 *, struct module_kobject___165 *, const char *, size_t);
	void (*setup)(struct module___165 *, const char *);
	int (*test)(struct module___165 *);
	void (*free)(struct module___165 *);
};

struct dev_pagemap_ops___176 {
	void (*page_free)(struct page___186 *);
	void (*kill)(struct dev_pagemap___176 *);
	void (*cleanup)(struct dev_pagemap___176 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___176 *);
};

struct cftype___123;

struct cgroup_subsys___123 {
	struct cgroup_subsys_state___123 * (*css_alloc)(struct cgroup_subsys_state___123 *);
	int (*css_online)(struct cgroup_subsys_state___123 *);
	void (*css_offline)(struct cgroup_subsys_state___123 *);
	void (*css_released)(struct cgroup_subsys_state___123 *);
	void (*css_free)(struct cgroup_subsys_state___123 *);
	void (*css_reset)(struct cgroup_subsys_state___123 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___123 *, int);
	int (*css_extra_stat_show)(struct seq_file___158 *, struct cgroup_subsys_state___123 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___188 *, struct css_set___123 *);
	void (*cancel_fork)(struct task_struct___188 *, struct css_set___123 *);
	void (*fork)(struct task_struct___188 *);
	void (*exit)(struct task_struct___188 *);
	void (*release)(struct task_struct___188 *);
	void (*bind)(struct cgroup_subsys_state___123 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___123 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___123 *dfl_cftypes;
	struct cftype___123 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___123 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___123 *updated_children;
	struct cgroup___123 *updated_next;
};

struct cgroup_root___123 {
	struct kernfs_root___168 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___123 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___123 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___123 *ss;
	struct list_head node;
	struct kernfs_ops___168 *kf_ops;
	int (*open)(struct kernfs_open_file___168 *);
	void (*release)(struct kernfs_open_file___168 *);
	u64 (*read_u64)(struct cgroup_subsys_state___123 *, struct cftype___123 *);
	s64 (*read_s64)(struct cgroup_subsys_state___123 *, struct cftype___123 *);
	int (*seq_show)(struct seq_file___158 *, void *);
	void * (*seq_start)(struct seq_file___158 *, loff_t *);
	void * (*seq_next)(struct seq_file___158 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___158 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___123 *, struct cftype___123 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___123 *, struct cftype___123 *, s64);
	ssize_t (*write)(struct kernfs_open_file___168 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___168 *, struct poll_table_struct___5 *);
};

struct dev_pm_ops___134 {
	int (*prepare)(struct device___134 *);
	void (*complete)(struct device___134 *);
	int (*suspend)(struct device___134 *);
	int (*resume)(struct device___134 *);
	int (*freeze)(struct device___134 *);
	int (*thaw)(struct device___134 *);
	int (*poweroff)(struct device___134 *);
	int (*restore)(struct device___134 *);
	int (*suspend_late)(struct device___134 *);
	int (*resume_early)(struct device___134 *);
	int (*freeze_late)(struct device___134 *);
	int (*thaw_early)(struct device___134 *);
	int (*poweroff_late)(struct device___134 *);
	int (*restore_early)(struct device___134 *);
	int (*suspend_noirq)(struct device___134 *);
	int (*resume_noirq)(struct device___134 *);
	int (*freeze_noirq)(struct device___134 *);
	int (*thaw_noirq)(struct device___134 *);
	int (*poweroff_noirq)(struct device___134 *);
	int (*restore_noirq)(struct device___134 *);
	int (*runtime_suspend)(struct device___134 *);
	int (*runtime_resume)(struct device___134 *);
	int (*runtime_idle)(struct device___134 *);
};

struct wakeup_source___134 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___134 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___134 {
	struct dev_pm_ops___134 ops;
	int (*start)(struct device___134 *);
	void (*detach)(struct device___134 *, bool);
	int (*activate)(struct device___134 *);
	void (*sync)(struct device___134 *);
	void (*dismiss)(struct device___134 *);
};

struct bus_type___134 {
	const char *name;
	const char *dev_name;
	struct device___134 *dev_root;
	const struct attribute_group___168 **bus_groups;
	const struct attribute_group___168 **dev_groups;
	const struct attribute_group___168 **drv_groups;
	int (*match)(struct device___134 *, struct device_driver___134 *);
	int (*uevent)(struct device___134 *, struct kobj_uevent_env *);
	int (*probe)(struct device___134 *);
	void (*sync_state)(struct device___134 *);
	void (*remove)(struct device___134 *);
	void (*shutdown)(struct device___134 *);
	int (*online)(struct device___134 *);
	int (*offline)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	int (*num_vf)(struct device___134 *);
	int (*dma_configure)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___134 {
	const char *name;
	struct bus_type___134 *bus;
	struct module___165 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___134 *);
	void (*sync_state)(struct device___134 *);
	int (*remove)(struct device___134 *);
	void (*shutdown)(struct device___134 *);
	int (*suspend)(struct device___134 *, pm_message_t);
	int (*resume)(struct device___134 *);
	const struct attribute_group___168 **groups;
	const struct attribute_group___168 **dev_groups;
	const struct dev_pm_ops___134 *pm;
	void (*coredump)(struct device___134 *);
	struct driver_private *p;
};

struct device_type___134 {
	const char *name;
	const struct attribute_group___168 **groups;
	int (*uevent)(struct device___134 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___134 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___134 *);
	const struct dev_pm_ops___134 *pm;
};

struct class___134 {
	const char *name;
	struct module___165 *owner;
	const struct attribute_group___168 **class_groups;
	const struct attribute_group___168 **dev_groups;
	struct kobject___168 *dev_kobj;
	int (*dev_uevent)(struct device___134 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___134 *, umode_t *);
	void (*class_release)(struct class___134 *);
	void (*dev_release)(struct device___134 *);
	int (*shutdown_pre)(struct device___134 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___134 *);
	void (*get_ownership)(struct device___134 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___134 *pm;
	struct subsys_private *p;
};

struct block_device_operations___89;

struct gendisk___90 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___90 *part0;
	const struct block_device_operations___89 *fops;
	struct request_queue___89 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___168 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___168 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___89 {
	struct bio___89 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___104 *bip_vec;
	struct bio_vec___104 bip_inline_vecs[0];
};

struct blkcg___84;

struct blkg_policy_data___84;

struct blkcg_gq___84 {
	struct request_queue___89 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___84 *blkcg;
	struct blkcg_gq___84 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___84 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___89 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___89(struct request___89 *);

typedef void integrity_complete_fn___89(struct request___89 *, unsigned int);

struct blk_integrity_profile___89 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___89 *prepare_fn;
	integrity_complete_fn___89 *complete_fn;
	const char *name;
};

struct block_device_operations___89 {
	blk_qc_t (*submit_bio)(struct bio___89 *);
	int (*open)(struct block_device___90 *, fmode_t);
	void (*release)(struct gendisk___90 *, fmode_t);
	int (*rw_page)(struct block_device___90 *, sector_t, struct page___186 *, unsigned int);
	int (*ioctl)(struct block_device___90 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___90 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___90 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___90 *);
	int (*getgeo)(struct block_device___90 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___90 *, bool);
	void (*swap_slot_free_notify)(struct block_device___90 *, long unsigned int);
	int (*report_zones)(struct gendisk___90 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___90 *, umode_t *);
	struct module___165 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___90 *, sector_t *);
};

typedef void rq_end_io_fn___89(struct request___89 *, blk_status_t);

struct request___89 {
	struct request_queue___89 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___86 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___89 *bio;
	struct bio___89 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___104 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___89 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___89 *saved_end_io;
		} flush;
	};
	struct gendisk___90 *rq_disk;
	struct block_device___90 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___89 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___86 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___89 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___168 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___181 *debugfs_dir;
	struct dentry___181 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___89;

struct elevator_mq_ops___89 {
	int (*init_sched)(struct request_queue___89 *, struct elevator_type___89 *);
	void (*exit_sched)(struct elevator_queue___89 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___86 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___86 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___86 *);
	bool (*allow_merge)(struct request_queue___89 *, struct request___89 *, struct bio___89 *);
	bool (*bio_merge)(struct request_queue___89 *, struct bio___89 *, unsigned int);
	int (*request_merge)(struct request_queue___89 *, struct request___89 **, struct bio___89 *);
	void (*request_merged)(struct request_queue___89 *, struct request___89 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___89 *, struct request___89 *, struct request___89 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___89 *);
	void (*finish_request)(struct request___89 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___86 *, struct list_head *, bool);
	struct request___89 * (*dispatch_request)(struct blk_mq_hw_ctx___86 *);
	bool (*has_work)(struct blk_mq_hw_ctx___86 *);
	void (*completed_request)(struct request___89 *, u64);
	void (*requeue_request)(struct request___89 *);
	struct request___89 * (*former_request)(struct request_queue___89 *, struct request___89 *);
	struct request___89 * (*next_request)(struct request_queue___89 *, struct request___89 *);
	void (*init_icq)(struct io_cq___89 *);
	void (*exit_icq)(struct io_cq___89 *);
};

struct elv_fs_entry___89;

struct elevator_type___89 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___89 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___89 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___165 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___89 {
	struct elevator_type___89 *type;
	void *elevator_data;
	struct kobject___168 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___89 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___89 *, char *);
	ssize_t (*store)(struct elevator_queue___89 *, const char *, size_t);
};

struct blk_mq_queue_data___86;

struct blk_mq_ops___86 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___86 *, const struct blk_mq_queue_data___86 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___86 *);
	int (*get_budget)(struct request_queue___89 *);
	void (*put_budget)(struct request_queue___89 *, int);
	void (*set_rq_budget_token)(struct request___89 *, int);
	int (*get_rq_budget_token)(struct request___89 *);
	enum blk_eh_timer_return (*timeout)(struct request___89 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___86 *);
	void (*complete)(struct request___89 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___86 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___86 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___86 *, struct request___89 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___86 *, struct request___89 *, unsigned int);
	void (*initialize_rq_fn)(struct request___89 *);
	void (*cleanup_rq)(struct request___89 *);
	bool (*busy)(struct request_queue___89 *);
	int (*map_queues)(struct blk_mq_tag_set___86 *);
	void (*show_rq)(struct seq_file___158 *, struct request___89 *);
};

struct blk_ksm_ll_ops___2 {
	int (*keyslot_program)(struct blk_keyslot_manager___2 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___2 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___2 {
	struct blk_ksm_ll_ops___2 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___134 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct blk_mq_tag_set___86 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___86 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___86 {
	struct request___89 *rq;
	bool last;
};

struct blkcg_policy_data___84;

struct blkcg___84 {
	struct cgroup_subsys_state___123 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___84 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___84 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___84 {
	struct blkcg___84 *blkcg;
	int plid;
};

struct blkg_policy_data___84 {
	struct blkcg_gq___84 *blkg;
	int plid;
};

struct bio_fallback_crypt_ctx {
	struct bio_crypt_ctx crypt_ctx;
	struct bvec_iter crypt_iter;
	union {
		struct {
			struct work_struct work;
			struct bio___89 *bio;
		};
		struct {
			void *bi_private_orig;
			bio_end_io_t___89 *bi_end_io_orig;
		};
	};
};

struct blk_crypto_keyslot {
	enum blk_crypto_mode_num crypto_mode;
	struct crypto_skcipher___8 *tfms[4];
};

union blk_crypto_iv {
	__le64 dun[4];
	u8 bytes[32];
};

struct bd_holder_disk {
	struct list_head list;
	struct block_device___90 *bdev;
	int refcnt;
};

typedef int (*cmp_r_func_t)(const void *, const void *, const void *);

struct random_ready_callback___2 {
	struct list_head list;
	void (*func)(struct random_ready_callback___2 *);
	struct module___10 *owner;
};

struct siprand_state {
	long unsigned int v0;
	long unsigned int v1;
	long unsigned int v2;
	long unsigned int v3;
};

struct region {
	unsigned int start;
	unsigned int off;
	unsigned int group_len;
	unsigned int end;
	unsigned int nbits;
};

enum {
	REG_OP_ISFREE = 0,
	REG_OP_ALLOC = 1,
	REG_OP_RELEASE = 2,
};

struct sg_append_table {
	struct sg_table sgt;
	struct scatterlist *prv;
	unsigned int total_nents;
};

typedef struct scatterlist *sg_alloc_fn(unsigned int, gfp_t);

typedef void sg_free_fn(struct scatterlist *, unsigned int);

struct sg_page_iter {
	struct scatterlist *sg;
	unsigned int sg_pgoffset;
	unsigned int __nents;
	int __pg_advance;
};

struct sg_dma_page_iter {
	struct sg_page_iter base;
};

struct sg_mapping_iter {
	struct page___177 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

typedef struct {
	__u8 b[16];
} guid_t___2;

typedef struct {
	__u8 b[16];
} uuid_t___2;

struct dentry___182;

struct super_block___182;

struct module___166;

struct file_system_type___182 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___182 * (*mount)(struct file_system_type___182 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___182 *);
	struct module___166 *owner;
	struct file_system_type___182 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___182;

struct kiocb___182;

struct iov_iter___107;

struct vm_area_struct___187;

struct inode___182;

struct file_lock___182;

struct page___187;

struct pipe_inode_info___61;

struct file_operations___182 {
	struct module___166 *owner;
	loff_t (*llseek)(struct file___182 *, loff_t, int);
	ssize_t (*read)(struct file___182 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___182 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___182 *, struct iov_iter___107 *);
	ssize_t (*write_iter)(struct kiocb___182 *, struct iov_iter___107 *);
	int (*iopoll)(struct kiocb___182 *, bool);
	int (*iterate)(struct file___182 *, struct dir_context *);
	int (*iterate_shared)(struct file___182 *, struct dir_context *);
	__poll_t (*poll)(struct file___182 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___182 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___182 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___182 *, struct vm_area_struct___187 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___182 *, struct file___182 *);
	int (*flush)(struct file___182 *, fl_owner_t);
	int (*release)(struct inode___182 *, struct file___182 *);
	int (*fsync)(struct file___182 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___182 *, int);
	int (*lock)(struct file___182 *, int, struct file_lock___182 *);
	ssize_t (*sendpage)(struct file___182 *, struct page___187 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___182 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___182 *, long unsigned int);
	int (*flock)(struct file___182 *, int, struct file_lock___182 *);
	ssize_t (*splice_write)(struct pipe_inode_info___61 *, struct file___182 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___182 *, loff_t *, struct pipe_inode_info___61 *, size_t, unsigned int);
	int (*setlease)(struct file___182 *, long int, struct file_lock___182 **, void **);
	long int (*fallocate)(struct file___182 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___182 *);
	ssize_t (*copy_file_range)(struct file___182 *, loff_t, struct file___182 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___182 *, loff_t, struct file___182 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___182 *, loff_t, loff_t, int);
};

struct vmacache___187 {
	u64 seqnum;
	struct vm_area_struct___187 *vmas[4];
};

struct page_frag___187 {
	struct page___187 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___188;

struct pid___162;

struct nsproxy___171;

struct signal_struct___183;

struct vm_struct___165;

struct task_struct___189 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___189 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity___3 dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___188 *mm;
	struct mm_struct___188 *active_mm;
	struct vmacache___187 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork;
	unsigned int sched_contributes_to_load;
	unsigned int sched_migrated;
	unsigned int sched_psi_wake_requeue;
	unsigned int sched_remote_wakeup;
	unsigned int in_execve;
	unsigned int in_iowait;
	unsigned int in_user_fault;
	unsigned int no_cgroup_migration;
	unsigned int frozen;
	unsigned int use_memdelay;
	unsigned int in_memstall;
	unsigned int in_eventfd_signal;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___189 *real_parent;
	struct task_struct___189 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___189 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___162 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___171 *nsproxy;
	struct signal_struct___183 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___189 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___89 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___61 *splice_pipe;
	struct page_frag___187 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___189 *oom_reaper_list;
	struct vm_struct___165 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___169;

struct kobj_type___169;

struct kernfs_node___169;

struct kobject___169 {
	const char *name;
	struct list_head entry;
	struct kobject___169 *parent;
	struct kset___169 *kset;
	struct kobj_type___169 *ktype;
	struct kernfs_node___169 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___166 {
	struct kobject___169 kobj;
	struct module___166 *mod;
	struct kobject___169 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___166 {
	struct module___166 *mod;
	struct latch_tree_node node;
};

struct module_layout___166 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___166 mtn;
};

struct module_attribute___166;

struct kernel_param___166;

struct module___166 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___166 mkobj;
	struct module_attribute___166 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___169 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___166 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___166 core_layout;
	struct module_layout___166 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___187 *pgtable_t___187;

struct address_space___182;

struct dev_pagemap___177;

struct page___187 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___182 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___51 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___187 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___187 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___188 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___177 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___177;

struct vm_area_struct___187 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___187 *vm_next;
	struct vm_area_struct___187 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___188 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___177 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___182 *vm_file;
	struct file___182 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___187;

struct mm_struct___188 {
	struct {
		struct vm_area_struct___187 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___182 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___187 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___189 *owner;
		struct user_namespace *user_ns;
		struct file___182 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___182;

struct address_space___182 {
	struct inode___182 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___182 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___177;

struct dev_pagemap___177 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___177 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___182;

struct path___182 {
	struct vfsmount___182 *mnt;
	struct dentry___182 *dentry;
};

struct fown_struct___162 {
	rwlock_t lock;
	struct pid___162 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___182 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___182 f_path;
	struct inode___182 *f_inode;
	const struct file_operations___182 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___162 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___182 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___177;

struct vm_operations_struct___177 {
	void (*open)(struct vm_area_struct___187 *);
	void (*close)(struct vm_area_struct___187 *);
	int (*may_split)(struct vm_area_struct___187 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___187 *);
	int (*mprotect)(struct vm_area_struct___187 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___177 *);
	vm_fault_t (*huge_fault)(struct vm_fault___177 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___177 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___187 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___177 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___177 *);
	int (*access)(struct vm_area_struct___187 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___187 *);
	int (*set_policy)(struct vm_area_struct___187 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___187 *, long unsigned int);
	struct page___187 * (*find_special_page)(struct vm_area_struct___187 *, long unsigned int);
};

struct core_thread___187 {
	struct task_struct___189 *task;
	struct core_thread___187 *next;
};

struct core_state___187 {
	atomic_t nr_threads;
	struct core_thread___187 dumper;
	struct completion startup;
};

struct vm_fault___177 {
	const struct {
		struct vm_area_struct___187 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___187 *cow_page;
	struct page___187 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___187 prealloc_pte;
};

struct crypto_async_request___9;

typedef void (*crypto_completion_t___9)(struct crypto_async_request___9 *, int);

struct crypto_tfm___22;

struct crypto_async_request___9 {
	struct list_head list;
	crypto_completion_t___9 complete;
	void *data;
	struct crypto_tfm___22 *tfm;
	u32 flags;
};

struct crypto_alg___22;

struct crypto_tfm___22 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___22 *);
	struct crypto_alg___22 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___22 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___22 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___22 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___22 *, u8 *, const u8 *);
};

struct compress_alg___22 {
	int (*coa_compress)(struct crypto_tfm___22 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___22 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___22 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___22 cipher;
		struct compress_alg___22 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___22 *);
	void (*cra_exit)(struct crypto_tfm___22 *);
	void (*cra_destroy)(struct crypto_alg___22 *);
	struct module___166 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ahash_request___5 {
	struct crypto_async_request___9 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___5 {
	int (*init)(struct ahash_request___5 *);
	int (*update)(struct ahash_request___5 *);
	int (*final)(struct ahash_request___5 *);
	int (*finup)(struct ahash_request___5 *);
	int (*digest)(struct ahash_request___5 *);
	int (*export)(struct ahash_request___5 *, void *);
	int (*import)(struct ahash_request___5 *, const void *);
	int (*setkey)(struct crypto_ahash___5 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___22 base;
};

struct dentry_operations___182;

struct dentry___182 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___182 *d_parent;
	struct qstr d_name;
	struct inode___182 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___182 *d_op;
	struct super_block___182 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___182;

struct inode___182 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___182 *i_op;
	struct super_block___182 *i_sb;
	struct address_space___182 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___182 *i_fop;
		void (*free_inode)(struct inode___182 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___182 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___61 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___182 {
	int (*d_revalidate)(struct dentry___182 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___182 *, unsigned int);
	int (*d_hash)(const struct dentry___182 *, struct qstr *);
	int (*d_compare)(const struct dentry___182 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___182 *);
	int (*d_init)(struct dentry___182 *);
	void (*d_release)(struct dentry___182 *);
	void (*d_prune)(struct dentry___182 *);
	void (*d_iput)(struct dentry___182 *, struct inode___182 *);
	char * (*d_dname)(struct dentry___182 *, char *, int);
	struct vfsmount___182 * (*d_automount)(struct path___182 *);
	int (*d_manage)(const struct path___182 *, bool);
	struct dentry___182 * (*d_real)(struct dentry___182 *, const struct inode___182 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___182;

struct mem_dqinfo___182 {
	struct quota_format_type___182 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___182;

struct quota_info___182 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___182 *files[3];
	struct mem_dqinfo___182 info[3];
	const struct quota_format_ops___182 *ops[3];
};

struct rcuwait___183 {
	struct task_struct___189 *task;
};

struct percpu_rw_semaphore___183 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___183 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___182 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___183 rw_sem[3];
};

struct super_operations___182;

struct dquot_operations___182;

struct quotactl_ops___182;

struct super_block___182 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___182 *s_type;
	const struct super_operations___182 *s_op;
	const struct dquot_operations___182 *dq_op;
	const struct quotactl_ops___182 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___182 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___182 s_dquot;
	struct sb_writers___182 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___182 *s_d_op;
	int cleancache_poolid;
	struct shrinker___73 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___182 {
	struct dentry___182 *mnt_root;
	struct super_block___182 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct pid_namespace___162;

struct upid___162 {
	int nr;
	struct pid_namespace___162 *ns;
};

struct pid_namespace___162 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___189 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___162 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___162 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___162 numbers[1];
};

struct signal_struct___183 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___189 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___189 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___162 *pids[4];
	struct pid___162 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___188 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___171 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___162 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___182;

struct pipe_buffer___61;

struct pipe_inode_info___61 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___187 *tmp_page;
	struct fasync_struct___182 *fasync_readers;
	struct fasync_struct___182 *fasync_writers;
	struct pipe_buffer___61 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___165 {
	struct vm_struct___165 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___187 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct wait_page_queue___82;

struct kiocb___182 {
	struct file___182 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___182 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___82 *ki_waitq;
	};
};

struct iattr___182 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___182 *ia_file;
};

struct dquot___182 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___182 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___182 {
	int qf_fmt_id;
	const struct quota_format_ops___182 *qf_ops;
	struct module___166 *qf_owner;
	struct quota_format_type___182 *qf_next;
};

struct quota_format_ops___182 {
	int (*check_quota_file)(struct super_block___182 *, int);
	int (*read_file_info)(struct super_block___182 *, int);
	int (*write_file_info)(struct super_block___182 *, int);
	int (*free_file_info)(struct super_block___182 *, int);
	int (*read_dqblk)(struct dquot___182 *);
	int (*commit_dqblk)(struct dquot___182 *);
	int (*release_dqblk)(struct dquot___182 *);
	int (*get_next_id)(struct super_block___182 *, struct kqid *);
};

struct dquot_operations___182 {
	int (*write_dquot)(struct dquot___182 *);
	struct dquot___182 * (*alloc_dquot)(struct super_block___182 *, int);
	void (*destroy_dquot)(struct dquot___182 *);
	int (*acquire_dquot)(struct dquot___182 *);
	int (*release_dquot)(struct dquot___182 *);
	int (*mark_dirty)(struct dquot___182 *);
	int (*write_info)(struct super_block___182 *, int);
	qsize_t * (*get_reserved_space)(struct inode___182 *);
	int (*get_projid)(struct inode___182 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___182 *, qsize_t *);
	int (*get_next_id)(struct super_block___182 *, struct kqid *);
};

struct quotactl_ops___182 {
	int (*quota_on)(struct super_block___182 *, int, int, const struct path___182 *);
	int (*quota_off)(struct super_block___182 *, int);
	int (*quota_enable)(struct super_block___182 *, unsigned int);
	int (*quota_disable)(struct super_block___182 *, unsigned int);
	int (*quota_sync)(struct super_block___182 *, int);
	int (*set_info)(struct super_block___182 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___182 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___182 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___182 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___182 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___182 *, unsigned int);
};

struct wait_page_queue___82 {
	struct page___187 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___82;

struct address_space_operations___182 {
	int (*writepage)(struct page___187 *, struct writeback_control___3 *);
	int (*readpage)(struct file___182 *, struct page___187 *);
	int (*writepages)(struct address_space___182 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___187 *);
	int (*readpages)(struct file___182 *, struct address_space___182 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___82 *);
	int (*write_begin)(struct file___182 *, struct address_space___182 *, loff_t, unsigned int, unsigned int, struct page___187 **, void **);
	int (*write_end)(struct file___182 *, struct address_space___182 *, loff_t, unsigned int, unsigned int, struct page___187 *, void *);
	sector_t (*bmap)(struct address_space___182 *, sector_t);
	void (*invalidatepage)(struct page___187 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___187 *, gfp_t);
	void (*freepage)(struct page___187 *);
	ssize_t (*direct_IO)(struct kiocb___182 *, struct iov_iter___107 *);
	int (*migratepage)(struct address_space___182 *, struct page___187 *, struct page___187 *, enum migrate_mode);
	bool (*isolate_page)(struct page___187 *, isolate_mode_t);
	void (*putback_page)(struct page___187 *);
	int (*launder_page)(struct page___187 *);
	int (*is_partially_uptodate)(struct page___187 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___187 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___182 *, struct page___187 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___182 *, sector_t *);
	void (*swap_deactivate)(struct file___182 *);
};

struct readahead_control___82 {
	struct file___182 *file;
	struct address_space___182 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___105;

struct iov_iter___107 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___105 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___61 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___182 {
	struct dentry___182 * (*lookup)(struct inode___182 *, struct dentry___182 *, unsigned int);
	const char * (*get_link)(struct dentry___182 *, struct inode___182 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___182 *, int);
	struct posix_acl * (*get_acl)(struct inode___182 *, int, bool);
	int (*readlink)(struct dentry___182 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___182 *, struct dentry___182 *, umode_t, bool);
	int (*link)(struct dentry___182 *, struct inode___182 *, struct dentry___182 *);
	int (*unlink)(struct inode___182 *, struct dentry___182 *);
	int (*symlink)(struct user_namespace *, struct inode___182 *, struct dentry___182 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___182 *, struct dentry___182 *, umode_t);
	int (*rmdir)(struct inode___182 *, struct dentry___182 *);
	int (*mknod)(struct user_namespace *, struct inode___182 *, struct dentry___182 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___182 *, struct dentry___182 *, struct inode___182 *, struct dentry___182 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___182 *, struct iattr___182 *);
	int (*getattr)(struct user_namespace *, const struct path___182 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___182 *, char *, size_t);
	int (*fiemap)(struct inode___182 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___182 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___182 *, struct dentry___182 *, struct file___182 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___182 *, struct dentry___182 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___182 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___182 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___182 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___182 {
	void (*fl_copy_lock)(struct file_lock___182 *, struct file_lock___182 *);
	void (*fl_release_private)(struct file_lock___182 *);
};

struct lock_manager_operations___182;

struct file_lock___182 {
	struct file_lock___182 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___182 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___182 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___182 *fl_ops;
	const struct lock_manager_operations___182 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___182 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___182 *);
	int (*lm_grant)(struct file_lock___182 *, int);
	bool (*lm_break)(struct file_lock___182 *);
	int (*lm_change)(struct file_lock___182 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___182 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___182 *);
};

struct fasync_struct___182 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___182 *fa_next;
	struct file___182 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___182 {
	struct inode___182 * (*alloc_inode)(struct super_block___182 *);
	void (*destroy_inode)(struct inode___182 *);
	void (*free_inode)(struct inode___182 *);
	void (*dirty_inode)(struct inode___182 *, int);
	int (*write_inode)(struct inode___182 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___182 *);
	void (*evict_inode)(struct inode___182 *);
	void (*put_super)(struct super_block___182 *);
	int (*sync_fs)(struct super_block___182 *, int);
	int (*freeze_super)(struct super_block___182 *);
	int (*freeze_fs)(struct super_block___182 *);
	int (*thaw_super)(struct super_block___182 *);
	int (*unfreeze_fs)(struct super_block___182 *);
	int (*statfs)(struct dentry___182 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___182 *, int *, char *);
	void (*umount_begin)(struct super_block___182 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___182 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___182 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___182 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___182 *);
	ssize_t (*quota_read)(struct super_block___182 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___182 *, int, const char *, size_t, loff_t);
	struct dquot___182 ** (*get_dquots)(struct inode___182 *);
	long int (*nr_cached_objects)(struct super_block___182 *, struct shrink_control___73 *);
	long int (*free_cached_objects)(struct super_block___182 *, struct shrink_control___73 *);
	struct file___182 * (*real_loop)(struct file___182 *);
};

struct dev_pagemap_ops___177 {
	void (*page_free)(struct page___187 *);
	void (*kill)(struct dev_pagemap___177 *);
	void (*cleanup)(struct dev_pagemap___177 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___177 *);
};

struct kernfs_root___169;

struct kernfs_elem_dir___169 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___169 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___169;

struct kernfs_root___169 {
	struct kernfs_node___169 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___169 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___169 {
	struct kernfs_node___169 *target_kn;
};

struct kernfs_ops___169;

struct kernfs_elem_attr___169 {
	const struct kernfs_ops___169 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___169 *notify_next;
};

struct kernfs_node___169 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___169 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___169 dir;
		struct kernfs_elem_symlink___169 symlink;
		struct kernfs_elem_attr___169 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___169;

struct kernfs_ops___169 {
	int (*open)(struct kernfs_open_file___169 *);
	void (*release)(struct kernfs_open_file___169 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___169 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___169 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___169 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___169 *, struct vm_area_struct___187 *);
};

struct kernfs_syscall_ops___169 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___169 *);
	int (*mkdir)(struct kernfs_node___169 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___169 *);
	int (*rename)(struct kernfs_node___169 *, struct kernfs_node___169 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___169 *, struct kernfs_root___169 *);
};

struct kernfs_open_file___169 {
	struct kernfs_node___169 *kn;
	struct file___182 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___177 *vm_ops;
};

struct bin_attribute___169;

struct attribute_group___169 {
	const char *name;
	umode_t (*is_visible)(struct kobject___169 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___169 *, struct bin_attribute___169 *, int);
	struct attribute **attrs;
	struct bin_attribute___169 **bin_attrs;
};

struct bin_attribute___169 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___182 * (*f_mapping)();
	ssize_t (*read)(struct file___182 *, struct kobject___169 *, struct bin_attribute___169 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___182 *, struct kobject___169 *, struct bin_attribute___169 *, char *, loff_t, size_t);
	int (*mmap)(struct file___182 *, struct kobject___169 *, struct bin_attribute___169 *, struct vm_area_struct___187 *);
};

struct sysfs_ops___169 {
	ssize_t (*show)(struct kobject___169 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___169 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___169;

struct kset___169 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___169 kobj;
	const struct kset_uevent_ops___169 *uevent_ops;
};

struct kobj_type___169 {
	void (*release)(struct kobject___169 *);
	const struct sysfs_ops___169 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___169 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___169 *);
	const void * (*namespace)(struct kobject___169 *);
	void (*get_ownership)(struct kobject___169 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___169 {
	int (* const filter)(struct kset___169 *, struct kobject___169 *);
	const char * (* const name)(struct kset___169 *, struct kobject___169 *);
	int (* const uevent)(struct kset___169 *, struct kobject___169 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___166 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___166 *);
	int (*get)(char *, const struct kernel_param___166 *);
	void (*free)(void *);
};

struct kparam_array___166;

struct kernel_param___166 {
	const char *name;
	struct module___166 *mod;
	const struct kernel_param_ops___166 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___166 *arr;
	};
};

struct kparam_array___166 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___166 *ops;
	void *elem;
};

struct module_attribute___166 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___166 *, struct module_kobject___166 *, char *);
	ssize_t (*store)(struct module_attribute___166 *, struct module_kobject___166 *, const char *, size_t);
	void (*setup)(struct module___166 *, const char *);
	int (*test)(struct module___166 *);
	void (*free)(struct module___166 *);
};

struct bio_vec___105 {
	struct page___187 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct csum_state {
	__wsum csum;
	size_t off;
};

struct pipe_buf_operations___61;

struct pipe_buffer___61 {
	struct page___187 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___61 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___61 {
	int (*confirm)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
	void (*release)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
	bool (*try_steal)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
	bool (*get)(struct pipe_inode_info___61 *, struct pipe_buffer___61 *);
};

struct static_key___5 {
	atomic_t enabled;
	union {
		long unsigned int type;
		struct jump_entry *entries;
		struct static_key_mod *next;
	};
	long: 64;
};

struct static_key_false___6 {
	struct static_key___5 key;
};

struct percpu_ref___2;

typedef void percpu_ref_func_t___2(struct percpu_ref___2 *);

struct percpu_ref_data___2;

struct percpu_ref___2 {
	long unsigned int percpu_count_ptr;
	struct percpu_ref_data___2 *data;
};

struct percpu_ref_data___2 {
	atomic_long_t count;
	percpu_ref_func_t___2 *release;
	percpu_ref_func_t___2 *confirm_switch;
	bool force_atomic;
	bool allow_reinit;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct percpu_ref___2 *ref;
};

struct rhltable {
	struct rhashtable ht;
};

struct rhashtable_walker {
	struct list_head list;
	struct bucket_table *tbl;
};

struct rhashtable_iter {
	struct rhashtable *ht;
	struct rhash_head *p;
	struct rhlist_head *list;
	struct rhashtable_walker walker;
	unsigned int slot;
	unsigned int skip;
	bool end_of_table;
};

union nested_table {
	union nested_table *table;
	struct rhash_lock_head *bucket;
};

struct once_work {
	struct work_struct work;
	struct static_key_true *key;
	struct module___166 *module;
};

struct genradix_iter {
	size_t offset;
	size_t pos;
	long: 64;
};

struct genradix_node {
	union {
		struct genradix_node *children[512];
		u8 data[4096];
	};
};

struct reciprocal_value___2 {
	u32 m;
	u8 sh1;
	u8 sh2;
};

struct reciprocal_value_adv {
	u32 m;
	u8 sh;
	u8 exp;
	bool is_wide_m;
};

typedef void (*dr_release_t___6)(struct device___134 *, void *);

typedef int (*dr_match_t___5)(struct device___134 *, void *, void *);

enum devm_ioremap_type {
	DEVM_IOREMAP = 0,
	DEVM_IOREMAP_UC = 1,
	DEVM_IOREMAP_WC = 2,
	DEVM_IOREMAP_NP = 3,
};

struct pcim_iomap_devres {
	void *table[6];
};

struct mempool_s___2 {
	spinlock_t___2 lock;
	int min_nr;
	int curr_nr;
	void **elements;
	void *pool_data;
	mempool_alloc_t *alloc;
	mempool_free_t *free;
	wait_queue_head_t___2 wait;
};

typedef struct mempool_s___2 mempool_t___2;

struct btree_head {
	long unsigned int *node;
	mempool_t___2 *mempool;
	int height;
};

struct btree_geo {
	int keylen;
	int no_pairs;
	int no_longs;
};

typedef void (*visitor128_t)(void *, long unsigned int, u64, u64, size_t);

typedef void (*visitorl_t)(void *, long unsigned int, long unsigned int, size_t);

typedef void (*visitor32_t)(void *, long unsigned int, u32, size_t);

typedef void (*visitor64_t)(void *, long unsigned int, u64, size_t);

enum assoc_array_walk_status {
	assoc_array_walk_tree_empty = 0,
	assoc_array_walk_found_terminal_node = 1,
	assoc_array_walk_found_wrong_shortcut = 2,
};

struct assoc_array_walk_result {
	struct {
		struct assoc_array_node *node;
		int level;
		int slot;
	} terminal_node;
	struct {
		struct assoc_array_shortcut *shortcut;
		int level;
		int sc_level;
		long unsigned int sc_segments;
		long unsigned int dissimilarity;
	} wrong_shortcut;
};

struct assoc_array_delete_collapse_context {
	struct assoc_array_node *node;
	const void *skip_leaf;
	int slot;
};

struct linear_range {
	unsigned int min;
	unsigned int min_sel;
	unsigned int max_sel;
	unsigned int step;
};

enum packing_op {
	PACK = 0,
	UNPACK = 1,
};

struct xxh32_state {
	uint32_t total_len_32;
	uint32_t large_len;
	uint32_t v1;
	uint32_t v2;
	uint32_t v3;
	uint32_t v4;
	uint32_t mem32[4];
	uint32_t memsize;
};

struct xxh64_state {
	uint64_t total_len;
	uint64_t v1;
	uint64_t v2;
	uint64_t v3;
	uint64_t v4;
	uint64_t mem64[4];
	uint32_t memsize;
};

struct gen_pool_chunk {
	struct list_head next_chunk;
	atomic_long_t avail;
	phys_addr_t phys_addr;
	void *owner;
	long unsigned int start_addr;
	long unsigned int end_addr;
	long unsigned int bits[0];
};

struct genpool_data_align {
	int align;
};

struct genpool_data_fixed {
	long unsigned int offset;
};

typedef void (*dr_release_t___7)(struct device___38 *, void *);

typedef int (*dr_match_t___6)(struct device___38 *, void *, void *);

struct platform_device___4 {
	const char *name;
	int id;
	bool id_auto;
	struct device___38 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

typedef struct {
	unsigned char op;
	unsigned char bits;
	short unsigned int val;
} code;

typedef enum {
	HEAD = 0,
	FLAGS = 1,
	TIME = 2,
	OS = 3,
	EXLEN = 4,
	EXTRA = 5,
	NAME = 6,
	COMMENT = 7,
	HCRC = 8,
	DICTID = 9,
	DICT = 10,
	TYPE = 11,
	TYPEDO = 12,
	STORED = 13,
	COPY = 14,
	TABLE = 15,
	LENLENS = 16,
	CODELENS = 17,
	LEN = 18,
	LENEXT = 19,
	DIST = 20,
	DISTEXT = 21,
	MATCH = 22,
	LIT = 23,
	CHECK = 24,
	LENGTH = 25,
	DONE = 26,
	BAD = 27,
	MEM = 28,
	SYNC = 29,
} inflate_mode;

struct inflate_state {
	inflate_mode mode;
	int last;
	int wrap;
	int havedict;
	int flags;
	unsigned int dmax;
	long unsigned int check;
	long unsigned int total;
	unsigned int wbits;
	unsigned int wsize;
	unsigned int whave;
	unsigned int write;
	unsigned char *window;
	long unsigned int hold;
	unsigned int bits;
	unsigned int length;
	unsigned int offset;
	unsigned int extra;
	const code *lencode;
	const code *distcode;
	unsigned int lenbits;
	unsigned int distbits;
	unsigned int ncode;
	unsigned int nlen;
	unsigned int ndist;
	unsigned int have;
	code *next;
	short unsigned int lens[320];
	short unsigned int work[288];
	code codes[2048];
};

union uu {
	short unsigned int us;
	unsigned char b[2];
};

typedef unsigned int uInt;

typedef enum {
	CODES = 0,
	LENS = 1,
	DISTS = 2,
} codetype;

struct inflate_workspace {
	struct inflate_state inflate_state;
	unsigned char working_window[32768];
};

typedef unsigned char uch;

typedef short unsigned int ush;

typedef long unsigned int ulg;

struct ct_data_s {
	union {
		ush freq;
		ush code;
	} fc;
	short: 16;
	union {
		ush dad;
		ush len;
	} dl;
	short: 16;
};

typedef struct ct_data_s ct_data;

struct static_tree_desc_s {
	const ct_data *static_tree;
	const int *extra_bits;
	int extra_base;
	int elems;
	int max_length;
};

typedef struct static_tree_desc_s static_tree_desc;

struct tree_desc_s {
	ct_data *dyn_tree;
	int max_code;
	static_tree_desc *stat_desc;
};

typedef ush Pos;

typedef unsigned int IPos;

struct deflate_state {
	z_streamp strm;
	int status;
	Byte *pending_buf;
	ulg pending_buf_size;
	Byte *pending_out;
	int pending;
	int noheader;
	Byte data_type;
	Byte method;
	int last_flush;
	uInt w_size;
	uInt w_bits;
	uInt w_mask;
	Byte *window;
	ulg window_size;
	Pos *prev;
	Pos *head;
	uInt ins_h;
	uInt hash_size;
	uInt hash_bits;
	uInt hash_mask;
	uInt hash_shift;
	long int block_start;
	uInt match_length;
	IPos prev_match;
	int match_available;
	uInt strstart;
	uInt match_start;
	uInt lookahead;
	uInt prev_length;
	uInt max_chain_length;
	uInt max_lazy_match;
	int level;
	int strategy;
	uInt good_match;
	int nice_match;
	struct ct_data_s dyn_ltree[573];
	struct ct_data_s dyn_dtree[61];
	struct ct_data_s bl_tree[39];
	struct tree_desc_s l_desc;
	struct tree_desc_s d_desc;
	struct tree_desc_s bl_desc;
	ush bl_count[16];
	int heap[573];
	int heap_len;
	int heap_max;
	uch depth[573];
	uch *l_buf;
	uInt lit_bufsize;
	uInt last_lit;
	ush *d_buf;
	ulg opt_len;
	ulg static_len;
	ulg compressed_len;
	uInt matches;
	int last_eob_len;
	ush bi_buf;
	int bi_valid;
};

typedef struct deflate_state deflate_state;

typedef enum {
	need_more = 0,
	block_done = 1,
	finish_started = 2,
	finish_done = 3,
} block_state;

typedef block_state (*compress_func)(deflate_state *, int);

struct deflate_workspace {
	deflate_state deflate_memory;
	Byte *window_memory;
	Pos *prev_memory;
	Pos *head_memory;
	char *overlay_memory;
};

typedef struct deflate_workspace deflate_workspace;

struct config_s {
	ush good_length;
	ush max_lazy;
	ush nice_length;
	ush max_chain;
	compress_func func;
};

typedef struct config_s config;

typedef struct tree_desc_s tree_desc;

typedef struct {
	const uint8_t *externalDict;
	size_t extDictSize;
	const uint8_t *prefixEnd;
	size_t prefixSize;
} LZ4_streamDecode_t_internal;

typedef union {
	long long unsigned int table[4];
	LZ4_streamDecode_t_internal internal_donotuse;
} LZ4_streamDecode_t;

typedef uint8_t BYTE;

typedef uint16_t U16;

typedef uint32_t U32;

typedef uint64_t U64;

typedef uintptr_t uptrval;

typedef enum {
	noDict = 0,
	withPrefix64k = 1,
	usingExtDict = 2,
} dict_directive;

typedef enum {
	endOnOutputSize = 0,
	endOnInputSize = 1,
} endCondition_directive;

typedef enum {
	decode_full_block = 0,
	partial_decode = 1,
} earlyEnd_directive;

typedef struct {
	size_t bitContainer;
	unsigned int bitsConsumed;
	const char *ptr;
	const char *start;
} BIT_DStream_t;

typedef enum {
	BIT_DStream_unfinished = 0,
	BIT_DStream_endOfBuffer = 1,
	BIT_DStream_completed = 2,
	BIT_DStream_overflow = 3,
} BIT_DStream_status;

typedef U32 HUF_DTable;

typedef struct {
	BYTE maxTableLog;
	BYTE tableType;
	BYTE tableLog;
	BYTE reserved;
} DTableDesc;

typedef struct {
	BYTE byte;
	BYTE nbBits;
} HUF_DEltX2;

typedef struct {
	U16 sequence;
	BYTE nbBits;
	BYTE length;
} HUF_DEltX4;

typedef struct {
	BYTE symbol;
	BYTE weight;
} sortedSymbol_t;

typedef U32 rankValCol_t[13];

typedef struct {
	U32 tableTime;
	U32 decode256Time;
} algo_time_t;

typedef unsigned int FSE_DTable;

typedef struct {
	FSE_DTable LLTable[513];
	FSE_DTable OFTable[257];
	FSE_DTable MLTable[513];
	HUF_DTable hufTable[4097];
	U64 workspace[384];
	U32 rep[3];
} ZSTD_entropyTables_t;

typedef struct {
	long long unsigned int frameContentSize;
	unsigned int windowSize;
	unsigned int dictID;
	unsigned int checksumFlag;
} ZSTD_frameParams;

typedef enum {
	bt_raw = 0,
	bt_rle = 1,
	bt_compressed = 2,
	bt_reserved = 3,
} blockType_e;

typedef enum {
	ZSTDds_getFrameHeaderSize = 0,
	ZSTDds_decodeFrameHeader = 1,
	ZSTDds_decodeBlockHeader = 2,
	ZSTDds_decompressBlock = 3,
	ZSTDds_decompressLastBlock = 4,
	ZSTDds_checkChecksum = 5,
	ZSTDds_decodeSkippableHeader = 6,
	ZSTDds_skipFrame = 7,
} ZSTD_dStage;

typedef void * (*ZSTD_allocFunction)(void *, size_t);

typedef void (*ZSTD_freeFunction)(void *, void *);

typedef struct {
	ZSTD_allocFunction customAlloc;
	ZSTD_freeFunction customFree;
	void *opaque;
} ZSTD_customMem;

struct ZSTD_DCtx_s {
	const FSE_DTable *LLTptr;
	const FSE_DTable *MLTptr;
	const FSE_DTable *OFTptr;
	const HUF_DTable *HUFptr;
	ZSTD_entropyTables_t entropy;
	const void *previousDstEnd;
	const void *base;
	const void *vBase;
	const void *dictEnd;
	size_t expected;
	ZSTD_frameParams fParams;
	blockType_e bType;
	ZSTD_dStage stage;
	U32 litEntropy;
	U32 fseEntropy;
	struct xxh64_state xxhState;
	size_t headerSize;
	U32 dictID;
	const BYTE *litPtr;
	ZSTD_customMem customMem;
	size_t litSize;
	size_t rleSize;
	BYTE litBuffer[131080];
	BYTE headerBuffer[18];
};

typedef struct ZSTD_DCtx_s ZSTD_DCtx;

struct ZSTD_DDict_s {
	void *dictBuffer;
	const void *dictContent;
	size_t dictSize;
	ZSTD_entropyTables_t entropy;
	U32 dictID;
	U32 entropyPresent;
	ZSTD_customMem cMem;
};

typedef struct ZSTD_DDict_s ZSTD_DDict;

typedef enum {
	zdss_init = 0,
	zdss_loadHeader = 1,
	zdss_read = 2,
	zdss_load = 3,
	zdss_flush = 4,
} ZSTD_dStreamStage;

struct ZSTD_DStream_s___2 {
	ZSTD_DCtx *dctx;
	ZSTD_DDict *ddictLocal;
	const ZSTD_DDict *ddict;
	ZSTD_frameParams fParams;
	ZSTD_dStreamStage stage;
	char *inBuff;
	size_t inBuffSize;
	size_t inPos;
	size_t maxWindowSize;
	char *outBuff;
	size_t outBuffSize;
	size_t outStart;
	size_t outEnd;
	size_t blockSize;
	BYTE headerBuffer[18];
	size_t lhSize;
	ZSTD_customMem customMem;
	void *legacyContext;
	U32 previousLegacyVersion;
	U32 legacyVersion;
	U32 hostageByte;
};

typedef struct ZSTD_DStream_s___2 ZSTD_DStream___2;

typedef enum {
	ZSTDnit_frameHeader = 0,
	ZSTDnit_blockHeader = 1,
	ZSTDnit_block = 2,
	ZSTDnit_lastBlock = 3,
	ZSTDnit_checksum = 4,
	ZSTDnit_skippableFrame = 5,
} ZSTD_nextInputType_e;

typedef int16_t S16;

typedef uintptr_t uPtrDiff;

typedef struct {
	size_t state;
	const void *table;
} FSE_DState_t;

typedef struct {
	U16 tableLog;
	U16 fastMode;
} FSE_DTableHeader;

typedef struct {
	short unsigned int newState;
	unsigned char symbol;
	unsigned char nbBits;
} FSE_decode_t;

typedef enum {
	set_basic = 0,
	set_rle = 1,
	set_compressed = 2,
	set_repeat = 3,
} symbolEncodingType_e;

typedef struct {
	blockType_e blockType;
	U32 lastBlock;
	U32 origSize;
} blockProperties_t;

typedef union {
	FSE_decode_t realData;
	U32 alignedBy4;
} FSE_decode_t4;

typedef struct {
	size_t litLength;
	size_t matchLength;
	size_t offset;
	const BYTE *match;
} seq_t;

typedef struct {
	BIT_DStream_t DStream;
	FSE_DState_t stateLL;
	FSE_DState_t stateOffb;
	FSE_DState_t stateML;
	size_t prevOffset[3];
	const BYTE *base;
	size_t pos;
	uPtrDiff gotoDict;
} seqState_t;

typedef struct {
	void *ptr;
	const void *end;
} ZSTD_stack;

struct module_version_attribute___3 {
	struct module_attribute___166 mattr;
	const char *module_name;
	const char *version;
};

typedef uint64_t vli_type;

enum xz_check {
	XZ_CHECK_NONE = 0,
	XZ_CHECK_CRC32 = 1,
	XZ_CHECK_CRC64 = 4,
	XZ_CHECK_SHA256 = 10,
};

struct xz_dec_hash {
	vli_type unpadded;
	vli_type uncompressed;
	uint32_t crc32;
};

struct xz_dec_lzma2;

struct xz_dec_bcj;

struct xz_dec___2 {
	enum {
		SEQ_STREAM_HEADER = 0,
		SEQ_BLOCK_START = 1,
		SEQ_BLOCK_HEADER = 2,
		SEQ_BLOCK_UNCOMPRESS = 3,
		SEQ_BLOCK_PADDING = 4,
		SEQ_BLOCK_CHECK = 5,
		SEQ_INDEX = 6,
		SEQ_INDEX_PADDING = 7,
		SEQ_INDEX_CRC32 = 8,
		SEQ_STREAM_FOOTER = 9,
	} sequence;
	uint32_t pos;
	vli_type vli;
	size_t in_start;
	size_t out_start;
	uint32_t crc32;
	enum xz_check check_type;
	enum xz_mode mode;
	bool allow_buf_error;
	struct {
		vli_type compressed;
		vli_type uncompressed;
		uint32_t size;
	} block_header;
	struct {
		vli_type compressed;
		vli_type uncompressed;
		vli_type count;
		struct xz_dec_hash hash;
	} block;
	struct {
		enum {
			SEQ_INDEX_COUNT = 0,
			SEQ_INDEX_UNPADDED = 1,
			SEQ_INDEX_UNCOMPRESSED = 2,
		} sequence;
		vli_type size;
		vli_type count;
		struct xz_dec_hash hash;
	} index;
	struct {
		size_t pos;
		size_t size;
		uint8_t buf[1024];
	} temp;
	struct xz_dec_lzma2 *lzma2;
	struct xz_dec_bcj *bcj;
	bool bcj_active;
};

enum lzma_state {
	STATE_LIT_LIT = 0,
	STATE_MATCH_LIT_LIT = 1,
	STATE_REP_LIT_LIT = 2,
	STATE_SHORTREP_LIT_LIT = 3,
	STATE_MATCH_LIT = 4,
	STATE_REP_LIT = 5,
	STATE_SHORTREP_LIT = 6,
	STATE_LIT_MATCH = 7,
	STATE_LIT_LONGREP = 8,
	STATE_LIT_SHORTREP = 9,
	STATE_NONLIT_MATCH = 10,
	STATE_NONLIT_REP = 11,
};

struct dictionary {
	uint8_t *buf;
	size_t start;
	size_t pos;
	size_t full;
	size_t limit;
	size_t end;
	uint32_t size;
	uint32_t size_max;
	uint32_t allocated;
	enum xz_mode mode;
};

struct rc_dec {
	uint32_t range;
	uint32_t code;
	uint32_t init_bytes_left;
	const uint8_t *in;
	size_t in_pos;
	size_t in_limit;
};

struct lzma_len_dec {
	uint16_t choice;
	uint16_t choice2;
	uint16_t low[128];
	uint16_t mid[128];
	uint16_t high[256];
};

struct lzma_dec {
	uint32_t rep0;
	uint32_t rep1;
	uint32_t rep2;
	uint32_t rep3;
	enum lzma_state state;
	uint32_t len;
	uint32_t lc;
	uint32_t literal_pos_mask;
	uint32_t pos_mask;
	uint16_t is_match[192];
	uint16_t is_rep[12];
	uint16_t is_rep0[12];
	uint16_t is_rep1[12];
	uint16_t is_rep2[12];
	uint16_t is_rep0_long[192];
	uint16_t dist_slot[256];
	uint16_t dist_special[114];
	uint16_t dist_align[16];
	struct lzma_len_dec match_len_dec;
	struct lzma_len_dec rep_len_dec;
	uint16_t literal[12288];
};

enum lzma2_seq {
	SEQ_CONTROL = 0,
	SEQ_UNCOMPRESSED_1 = 1,
	SEQ_UNCOMPRESSED_2 = 2,
	SEQ_COMPRESSED_0 = 3,
	SEQ_COMPRESSED_1 = 4,
	SEQ_PROPERTIES = 5,
	SEQ_LZMA_PREPARE = 6,
	SEQ_LZMA_RUN = 7,
	SEQ_COPY = 8,
};

struct lzma2_dec {
	enum lzma2_seq sequence;
	enum lzma2_seq next_sequence;
	uint32_t uncompressed;
	uint32_t compressed;
	bool need_dict_reset;
	bool need_props;
};

struct xz_dec_lzma2___2 {
	struct rc_dec rc;
	struct dictionary dict;
	struct lzma2_dec lzma2;
	struct lzma_dec lzma;
	struct {
		uint32_t size;
		uint8_t buf[63];
	} temp;
};

struct xz_dec_bcj___2 {
	enum {
		BCJ_X86 = 4,
		BCJ_POWERPC = 5,
		BCJ_IA64 = 6,
		BCJ_ARM = 7,
		BCJ_ARMTHUMB = 8,
		BCJ_SPARC = 9,
	} type;
	enum xz_ret ret;
	bool single_call;
	uint32_t pos;
	uint32_t x86_prev_mask;
	uint8_t *out;
	size_t out_pos;
	size_t out_size;
	struct {
		size_t filtered;
		size_t size;
		uint8_t buf[16];
	} temp;
};

struct ts_state {
	unsigned int offset;
	char cb[48];
};

struct ts_config;

struct ts_ops {
	const char *name;
	struct ts_config * (*init)(const void *, unsigned int, gfp_t, int);
	unsigned int (*find)(struct ts_config *, struct ts_state *);
	void (*destroy)(struct ts_config *);
	void * (*get_pattern)(struct ts_config *);
	unsigned int (*get_pattern_len)(struct ts_config *);
	struct module___166 *owner;
	struct list_head list;
};

struct ts_config {
	struct ts_ops *ops;
	int flags;
	unsigned int (*get_next_block)(unsigned int, const u8 **, struct ts_config *, struct ts_state *);
	void (*finish)(struct ts_config *, struct ts_state *);
};

struct ts_linear_state {
	unsigned int len;
	const void *data;
};

struct ei_entry {
	struct list_head list;
	long unsigned int start_addr;
	long unsigned int end_addr;
	int etype;
	void *priv;
};

struct proc_ops___20 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___156 *, struct file___156 *);
	ssize_t (*proc_read)(struct file___156 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___156 *, struct iov_iter___85 *);
	ssize_t (*proc_write)(struct file___156 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___156 *, loff_t, int);
	int (*proc_release)(struct inode___156 *, struct file___156 *);
	__poll_t (*proc_poll)(struct file___156 *, struct poll_table_struct___97 *);
	long int (*proc_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___156 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___156 *, struct vm_area_struct___161 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___156 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct rdma_cgroup___3 {
	struct cgroup_subsys_state___105 css;
	struct list_head rpools;
};

struct rdma_restrack_entry___2 {
	bool valid;
	u8 no_track: 1;
	struct kref kref;
	struct completion comp;
	struct task_struct___163 *task;
	const char *kern_name;
	enum rdma_restrack_type type;
	bool user;
	u32 id;
};

struct rdma_link_ops___2 {
	struct list_head list;
	const char *type;
	int (*newlink)(const char *, struct net_device___3 *);
};

struct ib_device___2;

struct rdma_counter___2 {
	struct rdma_restrack_entry___2 res;
	struct ib_device___2 *device;
	uint32_t id;
	struct kref kref;
	struct rdma_counter_mode mode;
	struct mutex lock;
	struct rdma_hw_stats *stats;
	u32 port;
};

struct ib_qp___2;

struct ib_send_wr___2;

struct ib_recv_wr___2;

struct ib_cq___2;

struct ib_wc___2;

struct ib_srq___2;

struct ib_port_attr___2;

struct rdma_netdev_alloc_params___2;

struct ib_gid_attr___2;

struct ib_ucontext___2;

struct rdma_user_mmap_entry___2;

struct ib_pd___2;

struct ib_ah___2;

struct rdma_ah_init_attr___2;

struct rdma_ah_attr___2;

struct ib_srq_init_attr___2;

struct ib_qp_init_attr___2;

struct ib_qp_attr___2;

struct ib_mr___2;

struct ib_mw___2;

struct ib_xrcd___2;

struct ib_flow___2;

struct ib_flow_attr___2;

struct ib_flow_action___2;

struct ib_flow_action_attrs_esp___2;

struct ib_wq___2;

struct ib_wq_init_attr___2;

struct ib_rwq_ind_table___2;

struct ib_rwq_ind_table_init_attr___2;

struct ib_dm___2;

struct ib_counters___2;

struct ib_device_ops___2 {
	struct module___141 *owner;
	enum rdma_driver_id driver_id;
	u32 uverbs_abi_ver;
	unsigned int uverbs_no_driver_id_binding;
	long: 32;
	long: 64;
	long: 64;
	const struct attribute_group___143 *device_group;
	const struct attribute_group___143 **port_groups;
	int (*post_send)(struct ib_qp___2 *, const struct ib_send_wr___2 *, const struct ib_send_wr___2 **);
	int (*post_recv)(struct ib_qp___2 *, const struct ib_recv_wr___2 *, const struct ib_recv_wr___2 **);
	void (*drain_rq)(struct ib_qp___2 *);
	void (*drain_sq)(struct ib_qp___2 *);
	int (*poll_cq)(struct ib_cq___2 *, int, struct ib_wc___2 *);
	int (*peek_cq)(struct ib_cq___2 *, int);
	int (*req_notify_cq)(struct ib_cq___2 *, enum ib_cq_notify_flags);
	int (*post_srq_recv)(struct ib_srq___2 *, const struct ib_recv_wr___2 *, const struct ib_recv_wr___2 **);
	int (*process_mad)(struct ib_device___2 *, int, u32, const struct ib_wc___2 *, const struct ib_grh *, const struct ib_mad *, struct ib_mad *, size_t *, u16 *);
	int (*query_device)(struct ib_device___2 *, struct ib_device_attr *, struct ib_udata *);
	int (*modify_device)(struct ib_device___2 *, int, struct ib_device_modify *);
	void (*get_dev_fw_str)(struct ib_device___2 *, char *);
	const struct cpumask * (*get_vector_affinity)(struct ib_device___2 *, int);
	int (*query_port)(struct ib_device___2 *, u32, struct ib_port_attr___2 *);
	int (*modify_port)(struct ib_device___2 *, u32, int, struct ib_port_modify *);
	int (*get_port_immutable)(struct ib_device___2 *, u32, struct ib_port_immutable *);
	enum rdma_link_layer (*get_link_layer)(struct ib_device___2 *, u32);
	struct net_device___3 * (*get_netdev)(struct ib_device___2 *, u32);
	struct net_device___3 * (*alloc_rdma_netdev)(struct ib_device___2 *, u32, enum rdma_netdev_t, const char *, unsigned char, void (*)(struct net_device___3 *));
	int (*rdma_netdev_get_params)(struct ib_device___2 *, u32, enum rdma_netdev_t, struct rdma_netdev_alloc_params___2 *);
	int (*query_gid)(struct ib_device___2 *, u32, int, union ib_gid *);
	int (*add_gid)(const struct ib_gid_attr___2 *, void **);
	int (*del_gid)(const struct ib_gid_attr___2 *, void **);
	int (*query_pkey)(struct ib_device___2 *, u32, u16, u16 *);
	int (*alloc_ucontext)(struct ib_ucontext___2 *, struct ib_udata *);
	void (*dealloc_ucontext)(struct ib_ucontext___2 *);
	int (*mmap)(struct ib_ucontext___2 *, struct vm_area_struct___161 *);
	void (*mmap_free)(struct rdma_user_mmap_entry___2 *);
	void (*disassociate_ucontext)(struct ib_ucontext___2 *);
	int (*alloc_pd)(struct ib_pd___2 *, struct ib_udata *);
	int (*dealloc_pd)(struct ib_pd___2 *, struct ib_udata *);
	int (*create_ah)(struct ib_ah___2 *, struct rdma_ah_init_attr___2 *, struct ib_udata *);
	int (*create_user_ah)(struct ib_ah___2 *, struct rdma_ah_init_attr___2 *, struct ib_udata *);
	int (*modify_ah)(struct ib_ah___2 *, struct rdma_ah_attr___2 *);
	int (*query_ah)(struct ib_ah___2 *, struct rdma_ah_attr___2 *);
	int (*destroy_ah)(struct ib_ah___2 *, u32);
	int (*create_srq)(struct ib_srq___2 *, struct ib_srq_init_attr___2 *, struct ib_udata *);
	int (*modify_srq)(struct ib_srq___2 *, struct ib_srq_attr *, enum ib_srq_attr_mask, struct ib_udata *);
	int (*query_srq)(struct ib_srq___2 *, struct ib_srq_attr *);
	int (*destroy_srq)(struct ib_srq___2 *, struct ib_udata *);
	int (*create_qp)(struct ib_qp___2 *, struct ib_qp_init_attr___2 *, struct ib_udata *);
	int (*modify_qp)(struct ib_qp___2 *, struct ib_qp_attr___2 *, int, struct ib_udata *);
	int (*query_qp)(struct ib_qp___2 *, struct ib_qp_attr___2 *, int, struct ib_qp_init_attr___2 *);
	int (*destroy_qp)(struct ib_qp___2 *, struct ib_udata *);
	int (*create_cq)(struct ib_cq___2 *, const struct ib_cq_init_attr *, struct ib_udata *);
	int (*modify_cq)(struct ib_cq___2 *, u16, u16);
	int (*destroy_cq)(struct ib_cq___2 *, struct ib_udata *);
	int (*resize_cq)(struct ib_cq___2 *, int, struct ib_udata *);
	struct ib_mr___2 * (*get_dma_mr)(struct ib_pd___2 *, int);
	struct ib_mr___2 * (*reg_user_mr)(struct ib_pd___2 *, u64, u64, u64, int, struct ib_udata *);
	struct ib_mr___2 * (*reg_user_mr_dmabuf)(struct ib_pd___2 *, u64, u64, u64, int, int, struct ib_udata *);
	struct ib_mr___2 * (*rereg_user_mr)(struct ib_mr___2 *, int, u64, u64, u64, int, struct ib_pd___2 *, struct ib_udata *);
	int (*dereg_mr)(struct ib_mr___2 *, struct ib_udata *);
	struct ib_mr___2 * (*alloc_mr)(struct ib_pd___2 *, enum ib_mr_type, u32);
	struct ib_mr___2 * (*alloc_mr_integrity)(struct ib_pd___2 *, u32, u32);
	int (*advise_mr)(struct ib_pd___2 *, enum ib_uverbs_advise_mr_advice, u32, struct ib_sge *, u32, struct uverbs_attr_bundle *);
	int (*map_mr_sg)(struct ib_mr___2 *, struct scatterlist *, int, unsigned int *);
	int (*check_mr_status)(struct ib_mr___2 *, u32, struct ib_mr_status *);
	int (*alloc_mw)(struct ib_mw___2 *, struct ib_udata *);
	int (*dealloc_mw)(struct ib_mw___2 *);
	int (*attach_mcast)(struct ib_qp___2 *, union ib_gid *, u16);
	int (*detach_mcast)(struct ib_qp___2 *, union ib_gid *, u16);
	int (*alloc_xrcd)(struct ib_xrcd___2 *, struct ib_udata *);
	int (*dealloc_xrcd)(struct ib_xrcd___2 *, struct ib_udata *);
	struct ib_flow___2 * (*create_flow)(struct ib_qp___2 *, struct ib_flow_attr___2 *, struct ib_udata *);
	int (*destroy_flow)(struct ib_flow___2 *);
	struct ib_flow_action___2 * (*create_flow_action_esp)(struct ib_device___2 *, const struct ib_flow_action_attrs_esp___2 *, struct uverbs_attr_bundle *);
	int (*destroy_flow_action)(struct ib_flow_action___2 *);
	int (*modify_flow_action_esp)(struct ib_flow_action___2 *, const struct ib_flow_action_attrs_esp___2 *, struct uverbs_attr_bundle *);
	int (*set_vf_link_state)(struct ib_device___2 *, int, u32, int);
	int (*get_vf_config)(struct ib_device___2 *, int, u32, struct ifla_vf_info *);
	int (*get_vf_stats)(struct ib_device___2 *, int, u32, struct ifla_vf_stats *);
	int (*get_vf_guid)(struct ib_device___2 *, int, u32, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*set_vf_guid)(struct ib_device___2 *, int, u32, u64, int);
	struct ib_wq___2 * (*create_wq)(struct ib_pd___2 *, struct ib_wq_init_attr___2 *, struct ib_udata *);
	int (*destroy_wq)(struct ib_wq___2 *, struct ib_udata *);
	int (*modify_wq)(struct ib_wq___2 *, struct ib_wq_attr *, u32, struct ib_udata *);
	int (*create_rwq_ind_table)(struct ib_rwq_ind_table___2 *, struct ib_rwq_ind_table_init_attr___2 *, struct ib_udata *);
	int (*destroy_rwq_ind_table)(struct ib_rwq_ind_table___2 *);
	struct ib_dm___2 * (*alloc_dm)(struct ib_device___2 *, struct ib_ucontext___2 *, struct ib_dm_alloc_attr *, struct uverbs_attr_bundle *);
	int (*dealloc_dm)(struct ib_dm___2 *, struct uverbs_attr_bundle *);
	struct ib_mr___2 * (*reg_dm_mr)(struct ib_pd___2 *, struct ib_dm___2 *, struct ib_dm_mr_attr *, struct uverbs_attr_bundle *);
	int (*create_counters)(struct ib_counters___2 *, struct uverbs_attr_bundle *);
	int (*destroy_counters)(struct ib_counters___2 *);
	int (*read_counters)(struct ib_counters___2 *, struct ib_counters_read_attr *, struct uverbs_attr_bundle *);
	int (*map_mr_sg_pi)(struct ib_mr___2 *, struct scatterlist *, int, unsigned int *, struct scatterlist *, int, unsigned int *);
	struct rdma_hw_stats * (*alloc_hw_device_stats)(struct ib_device___2 *);
	struct rdma_hw_stats * (*alloc_hw_port_stats)(struct ib_device___2 *, u32);
	int (*get_hw_stats)(struct ib_device___2 *, struct rdma_hw_stats *, u32, int);
	int (*fill_res_mr_entry)(struct sk_buff___26 *, struct ib_mr___2 *);
	int (*fill_res_mr_entry_raw)(struct sk_buff___26 *, struct ib_mr___2 *);
	int (*fill_res_cq_entry)(struct sk_buff___26 *, struct ib_cq___2 *);
	int (*fill_res_cq_entry_raw)(struct sk_buff___26 *, struct ib_cq___2 *);
	int (*fill_res_qp_entry)(struct sk_buff___26 *, struct ib_qp___2 *);
	int (*fill_res_qp_entry_raw)(struct sk_buff___26 *, struct ib_qp___2 *);
	int (*fill_res_cm_id_entry)(struct sk_buff___26 *, struct rdma_cm_id *);
	int (*enable_driver)(struct ib_device___2 *);
	void (*dealloc_driver)(struct ib_device___2 *);
	void (*iw_add_ref)(struct ib_qp___2 *);
	void (*iw_rem_ref)(struct ib_qp___2 *);
	struct ib_qp___2 * (*iw_get_qp)(struct ib_device___2 *, int);
	int (*iw_connect)(struct iw_cm_id *, struct iw_cm_conn_param *);
	int (*iw_accept)(struct iw_cm_id *, struct iw_cm_conn_param *);
	int (*iw_reject)(struct iw_cm_id *, const void *, u8);
	int (*iw_create_listen)(struct iw_cm_id *, int);
	int (*iw_destroy_listen)(struct iw_cm_id *);
	int (*counter_bind_qp)(struct rdma_counter___2 *, struct ib_qp___2 *);
	int (*counter_unbind_qp)(struct ib_qp___2 *);
	int (*counter_dealloc)(struct rdma_counter___2 *);
	struct rdma_hw_stats * (*counter_alloc_stats)(struct rdma_counter___2 *);
	int (*counter_update_stats)(struct rdma_counter___2 *);
	int (*fill_stat_mr_entry)(struct sk_buff___26 *, struct ib_mr___2 *);
	int (*query_ucontext)(struct ib_ucontext___2 *, struct uverbs_attr_bundle *);
	int (*get_numa_node)(struct ib_device___2 *);
	size_t size_ib_ah;
	size_t size_ib_counters;
	size_t size_ib_cq;
	size_t size_ib_mw;
	size_t size_ib_pd;
	size_t size_ib_qp;
	size_t size_ib_rwq_ind_table;
	size_t size_ib_srq;
	size_t size_ib_ucontext;
	size_t size_ib_xrcd;
};

struct ib_core_device___2 {
	struct device___112 dev;
	possible_net_t___24 rdma_net;
	struct kobject___143 *ports_kobj;
	struct list_head port_list;
	struct ib_device___2 *owner;
};

struct ib_port_data___2;

struct ib_device___2 {
	struct device___112 *dma_device;
	struct ib_device_ops___2 ops;
	char name[64];
	struct callback_head callback_head;
	struct list_head event_handler_list;
	struct rw_semaphore event_handler_rwsem;
	spinlock_t qp_open_list_lock;
	struct rw_semaphore client_data_rwsem;
	struct xarray client_data;
	struct mutex unregistration_lock;
	rwlock_t cache_lock;
	struct ib_port_data___2 *port_data;
	int num_comp_vectors;
	union {
		struct device___112 dev;
		struct ib_core_device___2 coredev;
	};
	const struct attribute_group___143 *groups[4];
	u64 uverbs_cmd_mask;
	char node_desc[64];
	__be64 node_guid;
	u32 local_dma_lkey;
	u16 is_switch;
	u16 kverbs_provider;
	u16 use_cq_dim;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 node_type;
	u32 phys_port_cnt;
	struct ib_device_attr attrs;
	struct hw_stats_device_data *hw_stats_data;
	struct rdmacg_device cg_device;
	u32 index;
	spinlock_t cq_pools_lock;
	struct list_head cq_pools[3];
	struct rdma_restrack_root *res;
	const struct uapi_definition *driver_def;
	refcount_t refcount;
	struct completion unreg_completion;
	struct work_struct unregistration_work;
	const struct rdma_link_ops___2 *link_ops;
	struct mutex compat_devs_mutex;
	struct xarray compat_devs;
	char iw_ifname[16];
	u32 iw_driver_flags;
	u32 lag_flags;
};

struct ib_gid_attr___2 {
	struct net_device___3 *ndev;
	struct ib_device___2 *device;
	union ib_gid gid;
	enum ib_gid_type gid_type;
	u16 index;
	u32 port_num;
};

struct ib_port_attr___2 {
	u64 subnet_prefix;
	enum ib_port_state state;
	enum ib_mtu max_mtu;
	enum ib_mtu active_mtu;
	u32 phys_mtu;
	int gid_tbl_len;
	unsigned int ip_gids;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	u32 port_cap_flags;
	u32 max_msg_sz;
	u32 bad_pkey_cntr;
	u32 qkey_viol_cntr;
	u16 pkey_tbl_len;
	u32 sm_lid;
	u32 lid;
	u8 lmc;
	u8 max_vl_num;
	u8 sm_sl;
	u8 subnet_timeout;
	u8 init_type_reply;
	u8 active_width;
	u16 active_speed;
	u8 phys_state;
	u16 port_cap_flags2;
};

typedef void (*ib_comp_handler___2)(struct ib_cq___2 *, void *);

struct ib_event___2;

struct ib_cq___2 {
	struct ib_device___2 *device;
	struct ib_ucq_object *uobject;
	ib_comp_handler___2 comp_handler;
	void (*event_handler)(struct ib_event___2 *, void *);
	void *cq_context;
	int cqe;
	unsigned int cqe_used;
	atomic_t usecnt;
	enum ib_poll_context poll_ctx;
	struct ib_wc___2 *wc;
	struct list_head pool_entry;
	union {
		struct irq_poll iop;
		struct work_struct work;
	};
	struct workqueue_struct *comp_wq;
	struct dim *dim;
	ktime_t timestamp;
	u8 interrupt;
	u8 shared;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int comp_vector;
	struct rdma_restrack_entry___2 res;
};

struct ib_qp_security___2;

struct ib_qp___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_cq___2 *send_cq;
	struct ib_cq___2 *recv_cq;
	spinlock_t mr_lock;
	int mrs_used;
	struct list_head rdma_mrs;
	struct list_head sig_mrs;
	struct ib_srq___2 *srq;
	struct ib_xrcd___2 *xrcd;
	struct list_head xrcd_list;
	atomic_t usecnt;
	struct list_head open_list;
	struct ib_qp___2 *real_qp;
	struct ib_uqp_object *uobject;
	void (*event_handler)(struct ib_event___2 *, void *);
	void *qp_context;
	const struct ib_gid_attr___2 *av_sgid_attr;
	const struct ib_gid_attr___2 *alt_path_sgid_attr;
	u32 qp_num;
	u32 max_write_sge;
	u32 max_read_sge;
	enum ib_qp_type qp_type;
	struct ib_rwq_ind_table___2 *rwq_ind_tbl;
	struct ib_qp_security___2 *qp_sec;
	u32 port;
	bool integrity_en;
	struct rdma_restrack_entry___2 res;
	struct rdma_counter___2 *counter;
};

struct ib_srq___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_usrq_object *uobject;
	void (*event_handler)(struct ib_event___2 *, void *);
	void *srq_context;
	enum ib_srq_type srq_type;
	atomic_t usecnt;
	struct {
		struct ib_cq___2 *cq;
		union {
			struct {
				struct ib_xrcd___2 *xrcd;
				u32 srq_num;
			} xrc;
		};
	} ext;
	struct rdma_restrack_entry___2 res;
};

struct ib_wq___2 {
	struct ib_device___2 *device;
	struct ib_uwq_object *uobject;
	void *wq_context;
	void (*event_handler)(struct ib_event___2 *, void *);
	struct ib_pd___2 *pd;
	struct ib_cq___2 *cq;
	u32 wq_num;
	enum ib_wq_state state;
	enum ib_wq_type wq_type;
	atomic_t usecnt;
};

struct ib_event___2 {
	struct ib_device___2 *device;
	union {
		struct ib_cq___2 *cq;
		struct ib_qp___2 *qp;
		struct ib_srq___2 *srq;
		struct ib_wq___2 *wq;
		u32 port_num;
	} element;
	enum ib_event_type event;
};

struct ib_global_route___2 {
	const struct ib_gid_attr___2 *sgid_attr;
	union ib_gid dgid;
	u32 flow_label;
	u8 sgid_index;
	u8 hop_limit;
	u8 traffic_class;
};

struct rdma_ah_init_attr___2 {
	struct rdma_ah_attr___2 *ah_attr;
	u32 flags;
	struct net_device___3 *xmit_slave;
};

struct rdma_ah_attr___2 {
	struct ib_global_route___2 grh;
	u8 sl;
	u8 static_rate;
	u32 port_num;
	u8 ah_flags;
	enum rdma_ah_attr_type type;
	union {
		struct ib_ah_attr ib;
		struct roce_ah_attr roce;
		struct opa_ah_attr opa;
	};
};

struct ib_cqe___2 {
	void (*done)(struct ib_cq___2 *, struct ib_wc___2 *);
};

struct ib_wc___2 {
	union {
		u64 wr_id;
		struct ib_cqe___2 *wr_cqe;
	};
	enum ib_wc_status status;
	enum ib_wc_opcode opcode;
	u32 vendor_err;
	u32 byte_len;
	struct ib_qp___2 *qp;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
	u32 src_qp;
	u32 slid;
	int wc_flags;
	u16 pkey_index;
	u8 sl;
	u8 dlid_path_bits;
	u32 port_num;
	u8 smac[6];
	u16 vlan_id;
	u8 network_hdr_type;
};

struct ib_xrcd___2 {
	struct ib_device___2 *device;
	atomic_t usecnt;
	struct inode___156 *inode;
	struct rw_semaphore tgt_qps_rwsem;
	struct xarray tgt_qps;
};

struct ib_srq_init_attr___2 {
	void (*event_handler)(struct ib_event___2 *, void *);
	void *srq_context;
	struct ib_srq_attr attr;
	enum ib_srq_type srq_type;
	struct {
		struct ib_cq___2 *cq;
		union {
			struct {
				struct ib_xrcd___2 *xrcd;
			} xrc;
			struct {
				u32 max_num_tags;
			} tag_matching;
		};
	} ext;
};

struct ib_qp_init_attr___2 {
	void (*event_handler)(struct ib_event___2 *, void *);
	void *qp_context;
	struct ib_cq___2 *send_cq;
	struct ib_cq___2 *recv_cq;
	struct ib_srq___2 *srq;
	struct ib_xrcd___2 *xrcd;
	struct ib_qp_cap cap;
	enum ib_sig_type sq_sig_type;
	enum ib_qp_type qp_type;
	u32 create_flags;
	u32 port_num;
	struct ib_rwq_ind_table___2 *rwq_ind_tbl;
	u32 source_qpn;
};

struct ib_uobject___2;

struct ib_rwq_ind_table___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
	u32 ind_tbl_num;
	u32 log_ind_tbl_size;
	struct ib_wq___2 **ind_tbl;
};

struct ib_qp_attr___2 {
	enum ib_qp_state qp_state;
	enum ib_qp_state cur_qp_state;
	enum ib_mtu path_mtu;
	enum ib_mig_state path_mig_state;
	u32 qkey;
	u32 rq_psn;
	u32 sq_psn;
	u32 dest_qp_num;
	int qp_access_flags;
	struct ib_qp_cap cap;
	struct rdma_ah_attr___2 ah_attr;
	struct rdma_ah_attr___2 alt_ah_attr;
	u16 pkey_index;
	u16 alt_pkey_index;
	u8 en_sqd_async_notify;
	u8 sq_draining;
	u8 max_rd_atomic;
	u8 max_dest_rd_atomic;
	u8 min_rnr_timer;
	u32 port_num;
	u8 timeout;
	u8 retry_cnt;
	u8 rnr_retry;
	u32 alt_port_num;
	u8 alt_timeout;
	u32 rate_limit;
	struct net_device___3 *xmit_slave;
};

struct ib_send_wr___2 {
	struct ib_send_wr___2 *next;
	union {
		u64 wr_id;
		struct ib_cqe___2 *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
	enum ib_wr_opcode opcode;
	int send_flags;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
};

struct ib_ah___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_uobject___2 *uobject;
	const struct ib_gid_attr___2 *sgid_attr;
	enum rdma_ah_attr_type type;
};

struct ib_mr___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	u32 lkey;
	u32 rkey;
	u64 iova;
	u64 length;
	unsigned int page_size;
	enum ib_mr_type type;
	bool need_inval;
	union {
		struct ib_uobject___2 *uobject;
		struct list_head qp_entry;
	};
	struct ib_dm___2 *dm;
	struct ib_sig_attrs *sig_attrs;
	struct rdma_restrack_entry___2 res;
};

struct ib_recv_wr___2 {
	struct ib_recv_wr___2 *next;
	union {
		u64 wr_id;
		struct ib_cqe___2 *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
};

struct ib_rdmacg_object___2 {
	struct rdma_cgroup___3 *cg;
};

struct ib_ucontext___2 {
	struct ib_device___2 *device;
	struct ib_uverbs_file *ufile;
	struct ib_rdmacg_object___2 cg_obj;
	struct rdma_restrack_entry___2 res;
	struct xarray mmap_xa;
};

struct ib_uobject___2 {
	u64 user_handle;
	struct ib_uverbs_file *ufile;
	struct ib_ucontext___2 *context;
	void *object;
	struct list_head list;
	struct ib_rdmacg_object___2 cg_obj;
	int id;
	struct kref ref;
	atomic_t usecnt;
	struct callback_head rcu;
	const struct uverbs_api_object *uapi_object;
};

struct ib_pd___2 {
	u32 local_dma_lkey;
	u32 flags;
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
	u32 unsafe_global_rkey;
	struct ib_mr___2 *__internal_mr;
	struct rdma_restrack_entry___2 res;
};

struct ib_wq_init_attr___2 {
	void *wq_context;
	enum ib_wq_type wq_type;
	u32 max_wr;
	u32 max_sge;
	struct ib_cq___2 *cq;
	void (*event_handler)(struct ib_event___2 *, void *);
	u32 create_flags;
};

struct ib_rwq_ind_table_init_attr___2 {
	u32 log_ind_tbl_size;
	struct ib_wq___2 **ind_tbl;
};

struct ib_port_pkey___2 {
	enum port_pkey_state state;
	u16 pkey_index;
	u32 port_num;
	struct list_head qp_list;
	struct list_head to_error_list;
	struct ib_qp_security___2 *sec;
};

struct ib_ports_pkeys___2;

struct ib_qp_security___2 {
	struct ib_qp___2 *qp;
	struct ib_device___2 *dev;
	struct mutex mutex;
	struct ib_ports_pkeys___2 *ports_pkeys;
	struct list_head shared_qp_list;
	void *security;
	bool destroying;
	atomic_t error_list_count;
	struct completion error_complete;
	int error_comps_pending;
};

struct ib_ports_pkeys___2 {
	struct ib_port_pkey___2 main;
	struct ib_port_pkey___2 alt;
};

struct ib_dm___2 {
	struct ib_device___2 *device;
	u32 length;
	u32 flags;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
};

struct ib_mw___2 {
	struct ib_device___2 *device;
	struct ib_pd___2 *pd;
	struct ib_uobject___2 *uobject;
	u32 rkey;
	enum ib_mw_type type;
};

struct ib_flow_spec_action_handle___2 {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_flow_action___2 *act;
};

struct ib_flow_action___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	enum ib_flow_action_type type;
	atomic_t usecnt;
};

struct ib_flow_spec_action_count___2 {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_counters___2 *counters;
};

struct ib_counters___2 {
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
	atomic_t usecnt;
};

union ib_flow_spec___2 {
	struct {
		u32 type;
		u16 size;
	};
	struct ib_flow_spec_eth eth;
	struct ib_flow_spec_ib ib;
	struct ib_flow_spec_ipv4 ipv4;
	struct ib_flow_spec_tcp_udp tcp_udp;
	struct ib_flow_spec_ipv6 ipv6;
	struct ib_flow_spec_tunnel tunnel;
	struct ib_flow_spec_esp esp;
	struct ib_flow_spec_gre gre;
	struct ib_flow_spec_mpls mpls;
	struct ib_flow_spec_action_tag flow_tag;
	struct ib_flow_spec_action_drop drop;
	struct ib_flow_spec_action_handle___2 action;
	struct ib_flow_spec_action_count___2 flow_count;
};

struct ib_flow_attr___2 {
	enum ib_flow_attr_type type;
	u16 size;
	u16 priority;
	u32 flags;
	u8 num_of_specs;
	u32 port;
	union ib_flow_spec___2 flows[0];
};

struct ib_flow___2 {
	struct ib_qp___2 *qp;
	struct ib_device___2 *device;
	struct ib_uobject___2 *uobject;
};

struct ib_flow_spec_list___2 {
	struct ib_flow_spec_list___2 *next;
	union ib_flow_spec___2 spec;
};

struct ib_flow_action_attrs_esp___2 {
	struct ib_flow_action_attrs_esp_keymats *keymat;
	struct ib_flow_action_attrs_esp_replays *replay;
	struct ib_flow_spec_list___2 *encap;
	u32 esn;
	u32 spi;
	u32 seq;
	u32 tfc_pad;
	u64 flags;
	u64 hard_limit_pkts;
};

struct ib_port_data___2 {
	struct ib_device___2 *ib_dev;
	struct ib_port_immutable immutable;
	spinlock_t pkey_list_lock;
	spinlock_t netdev_lock;
	struct list_head pkey_list;
	struct ib_port_cache cache;
	struct net_device___3 *netdev;
	struct hlist_node ndev_hash_link;
	struct rdma_port_counter port_counter;
	struct ib_port *sysfs;
};

struct rdma_netdev_alloc_params___2 {
	size_t sizeof_priv;
	unsigned int txqs;
	unsigned int rxqs;
	void *param;
	int (*initialize_rdma_netdev)(struct ib_device___2 *, u32, struct net_device___3 *, void *);
};

struct rdma_user_mmap_entry___2 {
	struct kref ref;
	struct ib_ucontext___2 *ucontext;
	long unsigned int start_pgoff;
	size_t npages;
	bool driver_removed;
};

struct ddebug_table {
	struct list_head link;
	const char *mod_name;
	unsigned int num_ddebugs;
	struct _ddebug *ddebugs;
};

struct ddebug_query {
	const char *filename;
	const char *module;
	const char *function;
	const char *format;
	unsigned int first_lineno;
	unsigned int last_lineno;
};

struct ddebug_iter {
	struct ddebug_table *table;
	unsigned int idx;
};

struct flag_settings {
	unsigned int flags;
	unsigned int mask;
};

struct flagsbuf {
	char buf[7];
};

struct nla_bitfield32 {
	__u32 value;
	__u32 selector;
};

enum nla_policy_validation {
	NLA_VALIDATE_NONE = 0,
	NLA_VALIDATE_RANGE = 1,
	NLA_VALIDATE_RANGE_WARN_TOO_LONG = 2,
	NLA_VALIDATE_MIN = 3,
	NLA_VALIDATE_MAX = 4,
	NLA_VALIDATE_MASK = 5,
	NLA_VALIDATE_RANGE_PTR = 6,
	NLA_VALIDATE_FUNCTION = 7,
};

enum netlink_validation {
	NL_VALIDATE_LIBERAL = 0,
	NL_VALIDATE_TRAILING = 1,
	NL_VALIDATE_MAXTYPE = 2,
	NL_VALIDATE_UNSPEC = 4,
	NL_VALIDATE_STRICT_ATTRS = 8,
	NL_VALIDATE_NESTED = 16,
};

struct cpu_rmap___2 {
	struct kref refcount;
	u16 size;
	u16 used;
	void **obj;
	long: 64;
	struct {
		u16 index;
		u16 dist;
	} near[0];
};

struct irq_glue {
	struct irq_affinity_notify notify;
	struct cpu_rmap___2 *rmap;
	u16 index;
};

typedef mpi_limb_t *mpi_ptr_t;

typedef int mpi_size_t;

typedef mpi_limb_t UWtype;

typedef unsigned int UHWtype;

enum gcry_mpi_constants {
	MPI_C_ZERO = 0,
	MPI_C_ONE = 1,
	MPI_C_TWO = 2,
	MPI_C_THREE = 3,
	MPI_C_FOUR = 4,
	MPI_C_EIGHT = 5,
};

struct barrett_ctx_s;

typedef struct barrett_ctx_s *mpi_barrett_t;

struct gcry_mpi_point {
	MPI x;
	MPI y;
	MPI z;
};

typedef struct gcry_mpi_point *MPI_POINT;

enum gcry_mpi_ec_models {
	MPI_EC_WEIERSTRASS = 0,
	MPI_EC_MONTGOMERY = 1,
	MPI_EC_EDWARDS = 2,
};

enum ecc_dialects {
	ECC_DIALECT_STANDARD = 0,
	ECC_DIALECT_ED25519 = 1,
	ECC_DIALECT_SAFECURVE = 2,
};

struct mpi_ec_ctx {
	enum gcry_mpi_ec_models model;
	enum ecc_dialects dialect;
	int flags;
	unsigned int nbits;
	MPI p;
	MPI a;
	MPI b;
	MPI_POINT G;
	MPI n;
	unsigned int h;
	MPI_POINT Q;
	MPI d;
	const char *name;
	struct {
		struct {
			unsigned int a_is_pminus3;
			unsigned int two_inv_p;
		} valid;
		int a_is_pminus3;
		MPI two_inv_p;
		mpi_barrett_t p_barrett;
		MPI scratch[11];
	} t;
	void (*addm)(MPI, MPI, MPI, struct mpi_ec_ctx *);
	void (*subm)(MPI, MPI, MPI, struct mpi_ec_ctx *);
	void (*mulm)(MPI, MPI, MPI, struct mpi_ec_ctx *);
	void (*pow2)(MPI, const MPI, struct mpi_ec_ctx *);
	void (*mul2)(MPI, MPI, struct mpi_ec_ctx *);
};

struct field_table {
	const char *p;
	void (*addm)(MPI, MPI, MPI, struct mpi_ec_ctx *);
	void (*subm)(MPI, MPI, MPI, struct mpi_ec_ctx *);
	void (*mulm)(MPI, MPI, MPI, struct mpi_ec_ctx *);
	void (*mul2)(MPI, MPI, struct mpi_ec_ctx *);
	void (*pow2)(MPI, const MPI, struct mpi_ec_ctx *);
};

enum gcry_mpi_format {
	GCRYMPI_FMT_NONE = 0,
	GCRYMPI_FMT_STD = 1,
	GCRYMPI_FMT_PGP = 2,
	GCRYMPI_FMT_SSH = 3,
	GCRYMPI_FMT_HEX = 4,
	GCRYMPI_FMT_USG = 5,
	GCRYMPI_FMT_OPAQUE = 8,
};

struct barrett_ctx_s___2;

typedef struct barrett_ctx_s___2 *mpi_barrett_t___2;

struct barrett_ctx_s___2 {
	MPI m;
	int m_copied;
	int k;
	MPI y;
	MPI r1;
	MPI r2;
	MPI r3;
};

struct karatsuba_ctx {
	struct karatsuba_ctx *next;
	mpi_ptr_t tspace;
	mpi_size_t tspace_size;
	mpi_ptr_t tp;
	mpi_size_t tp_size;
};

typedef long int mpi_limb_signed_t;

struct gcry_mpi___2 {
	int alloced;
	int nlimbs;
	int nbits;
	int sign;
	unsigned int flags;
	mpi_limb_t *d;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct gcry_mpi___2 *MPI___2;

struct karatsuba_ctx___2 {
	struct karatsuba_ctx___2 *next;
	mpi_ptr_t tspace;
	mpi_size_t tspace_size;
	mpi_ptr_t tp;
	long: 64;
	long: 64;
	long: 64;
	mpi_size_t tp_size;
};

enum dim_tune_state {
	DIM_PARKING_ON_TOP = 0,
	DIM_PARKING_TIRED = 1,
	DIM_GOING_RIGHT = 2,
	DIM_GOING_LEFT = 3,
};

struct dim_cq_moder {
	u16 usec;
	u16 pkts;
	u16 comps;
	u8 cq_period_mode;
};

enum dim_cq_period_mode {
	DIM_CQ_PERIOD_MODE_START_FROM_EQE = 0,
	DIM_CQ_PERIOD_MODE_START_FROM_CQE = 1,
	DIM_CQ_PERIOD_NUM_MODES = 2,
};

enum dim_state {
	DIM_START_MEASURE = 0,
	DIM_MEASURE_IN_PROGRESS = 1,
	DIM_APPLY_NEW_PROFILE = 2,
};

enum dim_stats_state {
	DIM_STATS_WORSE = 0,
	DIM_STATS_SAME = 1,
	DIM_STATS_BETTER = 2,
};

enum dim_step_result {
	DIM_STEPPED = 0,
	DIM_TOO_TIRED = 1,
	DIM_ON_EDGE = 2,
};

enum pubkey_algo {
	PUBKEY_ALGO_RSA = 0,
	PUBKEY_ALGO_MAX = 1,
};

struct pubkey_hdr {
	uint8_t version;
	uint32_t timestamp;
	uint8_t algo;
	uint8_t nmpi;
	char mpi[0];
} __attribute__((packed));

struct signature_hdr {
	uint8_t version;
	uint32_t timestamp;
	uint8_t algo;
	uint8_t hash;
	uint8_t keyid[8];
	uint8_t nmpi;
	char mpi[0];
} __attribute__((packed));

struct sg_splitter {
	struct scatterlist *in_sg0;
	int nents;
	off_t skip_sg0;
	unsigned int length_last_sg;
	struct scatterlist *out_sg;
};

struct sg_pool {
	size_t size;
	char *name;
	struct kmem_cache *slab;
	mempool_t___2 *pool;
};

struct qspinlock___3 {
	union {
		atomic_t val;
		struct {
			u8 locked;
			u8 pending;
		};
		struct {
			u16 locked_pending;
			u16 tail;
		};
	};
};

typedef struct qspinlock___3 arch_spinlock_t___3;

struct raw_spinlock___3 {
	arch_spinlock_t___3 raw_lock;
};

struct spinlock___3 {
	union {
		struct raw_spinlock___3 rlock;
	};
};

typedef struct spinlock___3 spinlock_t___3;

struct xarray___2 {
	spinlock_t___3 xa_lock;
	int: 32;
	gfp_t xa_flags;
	void *xa_head;
};

struct ida___2 {
	struct xarray___2 xa;
};

enum {
	IRQ_POLL_F_SCHED = 0,
	IRQ_POLL_F_DISABLE = 1,
};

struct font_desc {
	int idx;
	const char *name;
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	const void *data;
	int pref;
};

struct font_data {
	unsigned int extra[4];
	const unsigned char data[0];
};

enum {
	type_kind_int = 0,
	type_kind_float = 1,
	type_unknown = 65535,
};

struct type_descriptor {
	u16 type_kind;
	u16 type_info;
	char type_name[1];
};

struct source_location {
	const char *file_name;
	union {
		long unsigned int reported;
		struct {
			u32 line;
			u32 column;
		};
	};
};

struct overflow_data {
	struct source_location location;
	struct type_descriptor *type;
};

struct type_mismatch_data {
	struct source_location location;
	struct type_descriptor *type;
	long unsigned int alignment;
	unsigned char type_check_kind;
};

struct type_mismatch_data_v1 {
	struct source_location location;
	struct type_descriptor *type;
	unsigned char log_alignment;
	unsigned char type_check_kind;
};

struct type_mismatch_data_common {
	struct source_location *location;
	struct type_descriptor *type;
	long unsigned int alignment;
	unsigned char type_check_kind;
};

struct out_of_bounds_data {
	struct source_location location;
	struct type_descriptor *array_type;
	struct type_descriptor *index_type;
};

struct shift_out_of_bounds_data {
	struct source_location location;
	struct type_descriptor *lhs_type;
	struct type_descriptor *rhs_type;
};

struct unreachable_data {
	struct source_location location;
};

struct invalid_value_data {
	struct source_location location;
	struct type_descriptor *type;
};

struct alignment_assumption_data {
	struct source_location location;
	struct source_location assumption_location;
	struct type_descriptor *type;
};

typedef __int128 s_max;

typedef __int128 unsigned u_max;

struct firmware {
	size_t size;
	const u8 *data;
	void *priv;
};

struct pci_bus___3;

struct pci_slot___3 {
	struct pci_bus___3 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___165 kobj;
};

struct pci_dev___3;

struct pci_ops___3;

struct pci_bus___3 {
	struct list_head node;
	struct pci_bus___3 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___3 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___3 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___131 *bridge;
	struct device___131 dev;
	struct bin_attribute___165 *legacy_io;
	struct bin_attribute___165 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___3;

struct pci_dev___3 {
	struct list_head bus_list;
	struct pci_bus___3 *bus;
	struct pci_bus___3 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___3 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___3 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___3 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___131 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___165 *res_attr[17];
	struct bin_attribute___165 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___165 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___3 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___3;

struct pci_driver___3 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___3 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___3 *);
	int (*suspend)(struct pci_dev___3 *, pm_message_t);
	int (*resume)(struct pci_dev___3 *);
	void (*shutdown)(struct pci_dev___3 *);
	int (*sriov_configure)(struct pci_dev___3 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___3 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___3 *);
	const struct pci_error_handlers___3 *err_handler;
	const struct attribute_group___165 **groups;
	const struct attribute_group___165 **dev_groups;
	struct device_driver___131 driver;
	struct pci_dynids dynids;
};

struct pci_ops___3 {
	int (*add_bus)(struct pci_bus___3 *);
	void (*remove_bus)(struct pci_bus___3 *);
	void * (*map_bus)(struct pci_bus___3 *, unsigned int, int);
	int (*read)(struct pci_bus___3 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___3 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___3 {
	pci_ers_result_t (*error_detected)(struct pci_dev___3 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___3 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___3 *);
	void (*reset_prepare)(struct pci_dev___3 *);
	void (*reset_done)(struct pci_dev___3 *);
	void (*resume)(struct pci_dev___3 *);
};

struct pldmfw_record {
	struct list_head entry;
	struct list_head descs;
	const u8 *version_string;
	u8 version_type;
	u8 version_len;
	u16 package_data_len;
	u32 device_update_flags;
	const u8 *package_data;
	long unsigned int *component_bitmap;
	u16 component_bitmap_len;
};

struct pldmfw_desc_tlv {
	struct list_head entry;
	const u8 *data;
	u16 type;
	u16 size;
};

struct pldmfw_component {
	struct list_head entry;
	u16 classification;
	u16 identifier;
	u16 options;
	u16 activation_method;
	u32 comparison_stamp;
	u32 component_size;
	const u8 *component_data;
	const u8 *version_string;
	u8 version_type;
	u8 version_len;
	u8 index;
};

struct pldmfw_ops;

struct pldmfw {
	const struct pldmfw_ops *ops;
	struct device___131 *dev;
};

struct pldmfw_ops {
	bool (*match_record)(struct pldmfw *, struct pldmfw_record *);
	int (*send_package_data)(struct pldmfw *, const u8 *, u16);
	int (*send_component_table)(struct pldmfw *, struct pldmfw_component *, u8);
	int (*flash_component)(struct pldmfw *, struct pldmfw_component *);
	int (*finalize_update)(struct pldmfw *);
};

struct __pldm_timestamp {
	u8 b[13];
};

struct __pldm_header {
	uuid_t id;
	u8 revision;
	__le16 size;
	struct __pldm_timestamp release_date;
	__le16 component_bitmap_len;
	u8 version_type;
	u8 version_len;
	u8 version_string[0];
} __attribute__((packed));

struct __pldmfw_record_info {
	__le16 record_len;
	u8 descriptor_count;
	__le32 device_update_flags;
	u8 version_type;
	u8 version_len;
	__le16 package_data_len;
	u8 variable_record_data[0];
} __attribute__((packed));

struct __pldmfw_desc_tlv {
	__le16 type;
	__le16 size;
	u8 data[0];
};

struct __pldmfw_record_area {
	u8 record_count;
	u8 records[0];
};

struct __pldmfw_component_info {
	__le16 classification;
	__le16 identifier;
	__le32 comparison_stamp;
	__le16 options;
	__le16 activation_method;
	__le32 location_offset;
	__le32 size;
	u8 version_type;
	u8 version_len;
	u8 version_string[0];
} __attribute__((packed));

struct __pldmfw_component_area {
	__le16 component_image_count;
	u8 components[0];
};

struct pldmfw_priv {
	struct pldmfw *context;
	const struct firmware *fw;
	size_t offset;
	struct list_head records;
	struct list_head components;
	const struct __pldm_header *header;
	u16 total_header_size;
	u16 component_bitmap_len;
	u16 bitmap_size;
	u16 component_count;
	const u8 *component_start;
	const u8 *record_start;
	u8 record_count;
	u32 header_crc;
	struct pldmfw_record *matching_record;
};

struct pldm_pci_record_id {
	int vendor;
	int device;
	int subsystem_vendor;
	int subsystem_device;
};

typedef long unsigned int cycles_t;

enum aarch64_insn_prfm_type {
	AARCH64_INSN_PRFM_TYPE_PLD = 0,
	AARCH64_INSN_PRFM_TYPE_PLI = 1,
	AARCH64_INSN_PRFM_TYPE_PST = 2,
};

enum aarch64_insn_prfm_target {
	AARCH64_INSN_PRFM_TARGET_L1 = 0,
	AARCH64_INSN_PRFM_TARGET_L2 = 1,
	AARCH64_INSN_PRFM_TARGET_L3 = 2,
};

enum aarch64_insn_prfm_policy {
	AARCH64_INSN_PRFM_POLICY_KEEP = 0,
	AARCH64_INSN_PRFM_POLICY_STRM = 1,
};

struct warn_args___2;

struct compress_format {
	unsigned char magic[2];
	const char *name;
	decompress_fn decompressor;
};

struct group_data {
	int limit[21];
	int base[20];
	int permute[258];
	int minLen;
	int maxLen;
};

struct bunzip_data {
	int writeCopies;
	int writePos;
	int writeRunCountdown;
	int writeCount;
	int writeCurrent;
	long int (*fill)(void *, long unsigned int);
	long int inbufCount;
	long int inbufPos;
	unsigned char *inbuf;
	unsigned int inbufBitCount;
	unsigned int inbufBits;
	unsigned int crc32Table[256];
	unsigned int headerCRC;
	unsigned int totalCRC;
	unsigned int writeCRC;
	unsigned int *dbuf;
	unsigned int dbufSize;
	unsigned char selectors[32768];
	struct group_data groups[6];
	int io_error;
	int byteCount[256];
	unsigned char symToByte[256];
	unsigned char mtfSymbol[256];
};

struct rc {
	long int (*fill)(void *, long unsigned int);
	uint8_t *ptr;
	uint8_t *buffer;
	uint8_t *buffer_end;
	long int buffer_size;
	uint32_t code;
	uint32_t range;
	uint32_t bound;
	void (*error)(char *);
};

struct lzma_header {
	uint8_t pos;
	uint32_t dict_size;
	uint64_t dst_size;
} __attribute__((packed));

struct writer {
	uint8_t *buffer;
	uint8_t previous_byte;
	size_t buffer_pos;
	int bufsize;
	size_t global_pos;
	long int (*flush)(void *, long unsigned int);
	struct lzma_header *header;
};

struct cstate {
	int state;
	uint32_t rep0;
	uint32_t rep1;
	uint32_t rep2;
	uint32_t rep3;
};

struct ZSTD_DCtx_s___2;

typedef struct ZSTD_DCtx_s___2 ZSTD_DCtx___2;

struct ZSTD_inBuffer_s___2 {
	const void *src;
	size_t size;
	size_t pos;
};

typedef struct ZSTD_inBuffer_s___2 ZSTD_inBuffer___2;

struct ZSTD_outBuffer_s___2 {
	void *dst;
	size_t size;
	size_t pos;
};

typedef struct ZSTD_outBuffer_s___2 ZSTD_outBuffer___2;

struct cpio_data {
	void *data;
	size_t size;
	char name[18];
};

enum cpio_fields {
	C_MAGIC = 0,
	C_INO = 1,
	C_MODE = 2,
	C_UID = 3,
	C_GID = 4,
	C_NLINK = 5,
	C_MTIME = 6,
	C_FILESIZE = 7,
	C_MAJ = 8,
	C_MIN = 9,
	C_RMAJ = 10,
	C_RMIN = 11,
	C_NAMESIZE = 12,
	C_CHKSUM = 13,
	C_NFIELDS = 14,
};

enum {
	ASSUME_PERFECT = 255,
	ASSUME_VALID_DTB = 1,
	ASSUME_VALID_INPUT = 2,
	ASSUME_LATEST = 4,
	ASSUME_NO_ROLLBACK = 8,
	ASSUME_LIBFDT_ORDER = 16,
	ASSUME_LIBFDT_FLAWLESS = 32,
};

struct fdt_reserve_entry {
	fdt64_t address;
	fdt64_t size;
};

struct fdt_node_header {
	fdt32_t tag;
	char name[0];
};

struct fdt_property {
	fdt32_t tag;
	fdt32_t len;
	fdt32_t nameoff;
	char data[0];
};

struct fdt_errtabent {
	const char *str;
};

struct fprop_local_single {
	long unsigned int events;
	unsigned int period;
	raw_spinlock_t lock;
};

struct radix_tree_iter___2 {
	long unsigned int index;
	long unsigned int next_index;
	long unsigned int tags;
	struct xa_node___2 *node;
};

struct ida_bitmap {
	long unsigned int bitmap[16];
};

struct klist_waiter {
	struct list_head list;
	struct klist_node *node;
	struct task_struct___3 *process;
	int woken;
};

struct kernfs_root___170;

struct kernfs_elem_dir___170 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___170 *root;
	long unsigned int rev;
};

struct kernfs_node___170;

struct kernfs_syscall_ops___170;

struct kernfs_root___170 {
	struct kernfs_node___170 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___170 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___170 {
	struct kernfs_node___170 *target_kn;
};

struct kernfs_ops___170;

struct kernfs_elem_attr___170 {
	const struct kernfs_ops___170 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___170 *notify_next;
};

struct kernfs_node___170 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___170 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___170 dir;
		struct kernfs_elem_symlink___170 symlink;
		struct kernfs_elem_attr___170 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___170;

struct kernfs_ops___170 {
	int (*open)(struct kernfs_open_file___170 *);
	void (*release)(struct kernfs_open_file___170 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___170 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___170 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___170 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___170 *, struct vm_area_struct___41 *);
};

struct kernfs_syscall_ops___170 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___170 *);
	int (*mkdir)(struct kernfs_node___170 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___170 *);
	int (*rename)(struct kernfs_node___170 *, struct kernfs_node___170 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___170 *, struct kernfs_root___170 *);
};

struct kernfs_open_file___170 {
	struct kernfs_node___170 *kn;
	struct file___29 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___8 *vm_ops;
};

struct kobject___170;

struct bin_attribute___170;

struct attribute_group___170 {
	const char *name;
	umode_t (*is_visible)(struct kobject___170 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___170 *, struct bin_attribute___170 *, int);
	struct attribute **attrs;
	struct bin_attribute___170 **bin_attrs;
};

struct kset___170;

struct kobj_type___170;

struct kobject___170 {
	const char *name;
	struct list_head entry;
	struct kobject___170 *parent;
	struct kset___170 *kset;
	struct kobj_type___170 *ktype;
	struct kernfs_node___170 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bin_attribute___170 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___27 * (*f_mapping)();
	ssize_t (*read)(struct file___29 *, struct kobject___170 *, struct bin_attribute___170 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___29 *, struct kobject___170 *, struct bin_attribute___170 *, char *, loff_t, size_t);
	int (*mmap)(struct file___29 *, struct kobject___170 *, struct bin_attribute___170 *, struct vm_area_struct___41 *);
};

struct sysfs_ops___170 {
	ssize_t (*show)(struct kobject___170 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___170 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___170;

struct kset___170 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___170 kobj;
	const struct kset_uevent_ops___170 *uevent_ops;
};

struct kobj_type___170 {
	void (*release)(struct kobject___170 *);
	const struct sysfs_ops___170 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___170 **default_groups;
	const struct kobj_ns_type_operations___28 * (*child_ns_type)(struct kobject___170 *);
	const void * (*namespace)(struct kobject___170 *);
	void (*get_ownership)(struct kobject___170 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___170 {
	int (* const filter)(struct kset___170 *, struct kobject___170 *);
	const char * (* const name)(struct kset___170 *, struct kobject___170 *);
	int (* const uevent)(struct kset___170 *, struct kobject___170 *, struct kobj_uevent_env *);
};

struct kobj_attribute___9 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___170 *, struct kobj_attribute___9 *, char *);
	ssize_t (*store)(struct kobject___170 *, struct kobj_attribute___9 *, const char *, size_t);
};

struct netlink_skb_parms___2 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___18 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___2 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___26 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___30 *, int);
	void (*unbind)(struct net___30 *, int);
	bool (*compare)(struct net___30 *, struct sock___18 *);
};

struct uevent_sock {
	struct list_head list;
	struct sock___18 *sk;
};

enum {
	LOGIC_PIO_INDIRECT = 0,
	LOGIC_PIO_CPU_MMIO = 1,
};

struct logic_pio_host_ops;

struct logic_pio_hwaddr {
	struct list_head list;
	struct fwnode_handle___134 *fwnode;
	resource_size_t hw_start;
	resource_size_t io_start;
	resource_size_t size;
	long unsigned int flags;
	void *hostdata;
	const struct logic_pio_host_ops *ops;
};

struct logic_pio_host_ops {
	u32 (*in)(void *, long unsigned int, size_t);
	void (*out)(void *, long unsigned int, u32, size_t);
	u32 (*ins)(void *, long unsigned int, void *, size_t, unsigned int);
	void (*outs)(void *, long unsigned int, const void *, size_t, unsigned int);
};

struct radix_tree_preload {
	unsigned int nr;
	struct xa_node *nodes;
};

typedef struct {
	long unsigned int key[2];
} hsiphash_key_t;

struct dentry___183;

struct super_block___183;

struct module___167;

struct file_system_type___183 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___183 * (*mount)(struct file_system_type___183 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___183 *);
	struct module___167 *owner;
	struct file_system_type___183 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___183;

struct kiocb___183;

struct iov_iter___108;

struct poll_table_struct___119;

struct vm_area_struct___188;

struct inode___183;

struct file_lock___183;

struct page___188;

struct pipe_inode_info___62;

struct seq_file___159;

struct file_operations___183 {
	struct module___167 *owner;
	loff_t (*llseek)(struct file___183 *, loff_t, int);
	ssize_t (*read)(struct file___183 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___183 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___183 *, struct iov_iter___108 *);
	ssize_t (*write_iter)(struct kiocb___183 *, struct iov_iter___108 *);
	int (*iopoll)(struct kiocb___183 *, bool);
	int (*iterate)(struct file___183 *, struct dir_context *);
	int (*iterate_shared)(struct file___183 *, struct dir_context *);
	__poll_t (*poll)(struct file___183 *, struct poll_table_struct___119 *);
	long int (*unlocked_ioctl)(struct file___183 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___183 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___183 *, struct vm_area_struct___188 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___183 *, struct file___183 *);
	int (*flush)(struct file___183 *, fl_owner_t);
	int (*release)(struct inode___183 *, struct file___183 *);
	int (*fsync)(struct file___183 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___183 *, int);
	int (*lock)(struct file___183 *, int, struct file_lock___183 *);
	ssize_t (*sendpage)(struct file___183 *, struct page___188 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___183 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___183 *, long unsigned int);
	int (*flock)(struct file___183 *, int, struct file_lock___183 *);
	ssize_t (*splice_write)(struct pipe_inode_info___62 *, struct file___183 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___183 *, loff_t *, struct pipe_inode_info___62 *, size_t, unsigned int);
	int (*setlease)(struct file___183 *, long int, struct file_lock___183 **, void **);
	long int (*fallocate)(struct file___183 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___159 *, struct file___183 *);
	ssize_t (*copy_file_range)(struct file___183 *, loff_t, struct file___183 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___183 *, loff_t, struct file___183 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___183 *, loff_t, loff_t, int);
};

struct vmacache___188 {
	u64 seqnum;
	struct vm_area_struct___188 *vmas[4];
};

struct page_frag___188 {
	struct page___188 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___189;

struct pid___163;

struct nsproxy___172;

struct signal_struct___184;

struct bio_list___90;

struct backing_dev_info___83;

struct io_context___90;

struct capture_control___12;

struct css_set___124;

struct mem_cgroup___74;

struct request_queue___90;

struct vm_struct___166;

struct task_struct___190 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___190 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___189 *mm;
	struct mm_struct___189 *active_mm;
	struct vmacache___188 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___190 *real_parent;
	struct task_struct___190 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___190 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___163 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___172 *nsproxy;
	struct signal_struct___184 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___190 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___90 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___83 *backing_dev_info;
	struct io_context___90 *io_context;
	struct capture_control___12 *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___124 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___62 *splice_pipe;
	struct page_frag___188 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___74 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___74 *active_memcg;
	struct request_queue___90 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___190 *oom_reaper_list;
	struct vm_struct___166 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct random_ready_callback___3 {
	struct list_head list;
	void (*func)(struct random_ready_callback___3 *);
	struct module___167 *owner;
};

struct kset___171;

struct kobj_type___171;

struct kernfs_node___171;

struct kobject___171 {
	const char *name;
	struct list_head entry;
	struct kobject___171 *parent;
	struct kset___171 *kset;
	struct kobj_type___171 *ktype;
	struct kernfs_node___171 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___167 {
	struct kobject___171 kobj;
	struct module___167 *mod;
	struct kobject___171 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___167 {
	struct module___167 *mod;
	struct latch_tree_node node;
};

struct module_layout___167 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___167 mtn;
};

struct module_attribute___167;

struct kernel_param___167;

struct module___167 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___167 mkobj;
	struct module_attribute___167 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___171 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___167 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___167 core_layout;
	struct module_layout___167 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct clk_core;

struct clk {
	struct clk_core *core;
	struct device *dev;
	const char *dev_id;
	const char *con_id;
	long unsigned int min_rate;
	long unsigned int max_rate;
	unsigned int exclusive_count;
	struct hlist_node clks_node;
};

typedef struct page___188 *pgtable_t___188;

struct address_space___183;

struct page_pool___52;

struct dev_pagemap___178;

struct page___188 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___183 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___52 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___188 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___188 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___189 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___178 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___178;

struct vm_area_struct___188 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___188 *vm_next;
	struct vm_area_struct___188 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___189 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___178 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___183 *vm_file;
	struct file___183 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___188;

struct mm_struct___189 {
	struct {
		struct vm_area_struct___188 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___183 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___188 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___190 *owner;
		struct user_namespace___25 *user_ns;
		struct file___183 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___183;

struct address_space___183 {
	struct inode___183 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___183 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___135;

struct page_pool_params___52 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___135 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___52 {
	u32 count;
	struct page___188 *cache[128];
};

struct page_pool___52 {
	struct page_pool_params___52 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___188 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___52 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___178;

struct dev_pagemap___178 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___178 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___183;

struct path___183 {
	struct vfsmount___183 *mnt;
	struct dentry___183 *dentry;
};

struct fown_struct___163 {
	rwlock_t lock;
	struct pid___163 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___183 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___183 f_path;
	struct inode___183 *f_inode;
	const struct file_operations___183 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___163 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___183 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___178;

struct vm_operations_struct___178 {
	void (*open)(struct vm_area_struct___188 *);
	void (*close)(struct vm_area_struct___188 *);
	int (*may_split)(struct vm_area_struct___188 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___188 *);
	int (*mprotect)(struct vm_area_struct___188 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___178 *);
	vm_fault_t (*huge_fault)(struct vm_fault___178 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___178 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___188 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___178 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___178 *);
	int (*access)(struct vm_area_struct___188 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___188 *);
	int (*set_policy)(struct vm_area_struct___188 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___188 *, long unsigned int);
	struct page___188 * (*find_special_page)(struct vm_area_struct___188 *, long unsigned int);
};

struct core_thread___188 {
	struct task_struct___190 *task;
	struct core_thread___188 *next;
};

struct core_state___188 {
	atomic_t nr_threads;
	struct core_thread___188 dumper;
	struct completion startup;
};

struct vm_fault___178 {
	const struct {
		struct vm_area_struct___188 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___188 *cow_page;
	struct page___188 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___188 prealloc_pte;
};

struct pglist_data___81;

struct lruvec___81 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___81 *pgdat;
};

struct zone___81 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___81 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___81 {
	struct zone___81 *zone;
	int zone_idx;
};

struct zonelist___81 {
	struct zoneref___81 _zonerefs[321];
};

struct pglist_data___81 {
	struct zone___81 node_zones[5];
	struct zonelist___81 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___190 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___190 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___81 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___171;

struct kernfs_elem_dir___171 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___171 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___171;

struct kernfs_root___171 {
	struct kernfs_node___171 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___171 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___171 {
	struct kernfs_node___171 *target_kn;
};

struct kernfs_ops___171;

struct kernfs_elem_attr___171 {
	const struct kernfs_ops___171 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___171 *notify_next;
};

struct kernfs_node___171 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___171 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___171 dir;
		struct kernfs_elem_symlink___171 symlink;
		struct kernfs_elem_attr___171 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___171;

struct kernfs_ops___171 {
	int (*open)(struct kernfs_open_file___171 *);
	void (*release)(struct kernfs_open_file___171 *);
	int (*seq_show)(struct seq_file___159 *, void *);
	void * (*seq_start)(struct seq_file___159 *, loff_t *);
	void * (*seq_next)(struct seq_file___159 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___159 *, void *);
	ssize_t (*read)(struct kernfs_open_file___171 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___171 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___171 *, struct poll_table_struct___119 *);
	int (*mmap)(struct kernfs_open_file___171 *, struct vm_area_struct___188 *);
};

struct kernfs_syscall_ops___171 {
	int (*show_options)(struct seq_file___159 *, struct kernfs_root___171 *);
	int (*mkdir)(struct kernfs_node___171 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___171 *);
	int (*rename)(struct kernfs_node___171 *, struct kernfs_node___171 *, const char *);
	int (*show_path)(struct seq_file___159 *, struct kernfs_node___171 *, struct kernfs_root___171 *);
};

struct seq_operations___159;

struct seq_file___159 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___159 *op;
	int poll_event;
	const struct file___183 *file;
	void *private;
};

struct kernfs_open_file___171 {
	struct kernfs_node___171 *kn;
	struct file___183 *file;
	struct seq_file___159 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___178 *vm_ops;
};

typedef void (*poll_queue_proc___124)(struct file___183 *, wait_queue_head_t *, struct poll_table_struct___119 *);

struct poll_table_struct___119 {
	poll_queue_proc___124 _qproc;
	__poll_t _key;
};

struct sock___30;

struct kobj_ns_type_operations___29 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___30 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___41;

typedef struct {
	struct net___41 *net;
} possible_net_t___36;

struct proto___29;

struct sock_common___29 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___29 *skc_prot;
	possible_net_t___36 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___30 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___37;

struct sk_buff_head___36 {
	struct sk_buff___37 *next;
	struct sk_buff___37 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct cgroup___124;

struct sock_cgroup_data___29 {
	struct cgroup___124 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___29;

struct socket_wq___30;

struct dst_entry___29;

struct socket___31;

struct net_device___38;

struct sock___30 {
	struct sock_common___29 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___36 sk_error_queue;
	struct sk_buff___37 *sk_rx_skb_cache;
	struct sk_buff_head___36 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___37 *head;
		struct sk_buff___37 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___29 *sk_filter;
	union {
		struct socket_wq___30 *sk_wq;
		struct socket_wq___30 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___29 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___29 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___37 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___37 *sk_tx_skb_cache;
	struct sk_buff_head___36 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___188 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___29 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___163 *sk_peer_pid;
	const struct cred___30 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___31 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___29 sk_cgrp_data;
	struct mem_cgroup___74 *sk_memcg;
	void (*sk_state_change)(struct sock___30 *);
	void (*sk_data_ready)(struct sock___30 *);
	void (*sk_write_space)(struct sock___30 *);
	void (*sk_error_report)(struct sock___30 *);
	int (*sk_backlog_rcv)(struct sock___30 *, struct sk_buff___37 *);
	struct sk_buff___37 * (*sk_validate_xmit_skb)(struct sock___30 *, struct net_device___38 *, struct sk_buff___37 *);
	void (*sk_destruct)(struct sock___30 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct pid_namespace___163;

struct upid___163 {
	int nr;
	struct pid_namespace___163 *ns;
};

struct pid_namespace___163 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___190 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___163 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___163 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___163 numbers[1];
};

struct signal_struct___184 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___190 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___190 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___163 *pids[4];
	struct pid___163 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___189 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___124;

struct nsproxy___172 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___163 *pid_ns_for_children;
	struct net___41 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___124 *cgroup_ns;
};

struct bio___90;

struct bio_list___90 {
	struct bio___90 *head;
	struct bio___90 *tail;
};

struct cgroup_subsys_state___124;

struct bdi_writeback___83 {
	struct backing_dev_info___83 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___124 *memcg_css;
	struct cgroup_subsys_state___124 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___83 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___83 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___135 *dev;
	char dev_name[64];
	struct device___135 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___183 *debug_dir;
};

struct io_cq___90;

struct io_context___90 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___90 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct compact_control___12;

struct capture_control___12 {
	struct compact_control___12 *cc;
	struct page___188 *page;
};

struct css_set___124 {
	struct cgroup_subsys_state___124 *subsys[14];
	refcount_t refcount;
	struct css_set___124 *dom_cset;
	struct cgroup___124 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___124 *mg_src_cgrp;
	struct cgroup___124 *mg_dst_cgrp;
	struct css_set___124 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___183;

struct pipe_buffer___62;

struct pipe_inode_info___62 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___188 *tmp_page;
	struct fasync_struct___183 *fasync_readers;
	struct fasync_struct___183 *fasync_writers;
	struct pipe_buffer___62 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___124;

struct cgroup_subsys_state___124 {
	struct cgroup___124 *cgroup;
	struct cgroup_subsys___124 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___124 *parent;
};

struct cgroup_file___124 {
	struct kernfs_node___171 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___74;

struct mem_cgroup_per_node___74;

struct mem_cgroup___74 {
	struct cgroup_subsys_state___124 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___124 events_file;
	struct cgroup_file___124 events_local_file;
	struct cgroup_file___124 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___74 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___190 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___74 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___90;

struct blk_integrity___90 {
	const struct blk_integrity_profile___90 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___90 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___90 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___90;

struct elevator_queue___90;

struct blk_mq_ops___87;

struct blk_mq_hw_ctx___87;

struct gendisk___91;

struct blkcg_gq___85;

struct blk_mq_tag_set___87;

struct request_queue___90 {
	struct request___90 *last_merge;
	struct elevator_queue___90 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___87 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___87 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___91 *disk;
	struct kobject___171 kobj;
	struct kobject___171 *mq_kobj;
	struct blk_integrity___90 integrity;
	struct device___135 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___85 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___87 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___90 bio_split;
	struct dentry___183 *debugfs_dir;
	struct dentry___183 *sched_debugfs_dir;
	struct dentry___183 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___166 {
	struct vm_struct___166 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___188 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___171;

struct attribute_group___171 {
	const char *name;
	umode_t (*is_visible)(struct kobject___171 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___171 *, struct bin_attribute___171 *, int);
	struct attribute **attrs;
	struct bin_attribute___171 **bin_attrs;
};

struct bin_attribute___171 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___183 * (*f_mapping)();
	ssize_t (*read)(struct file___183 *, struct kobject___171 *, struct bin_attribute___171 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___183 *, struct kobject___171 *, struct bin_attribute___171 *, char *, loff_t, size_t);
	int (*mmap)(struct file___183 *, struct kobject___171 *, struct bin_attribute___171 *, struct vm_area_struct___188 *);
};

struct sysfs_ops___171 {
	ssize_t (*show)(struct kobject___171 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___171 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___171;

struct kset___171 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___171 kobj;
	const struct kset_uevent_ops___171 *uevent_ops;
};

struct kobj_type___171 {
	void (*release)(struct kobject___171 *);
	const struct sysfs_ops___171 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___171 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___171 *);
	const void * (*namespace)(struct kobject___171 *);
	void (*get_ownership)(struct kobject___171 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___171 {
	int (* const filter)(struct kset___171 *, struct kobject___171 *);
	const char * (* const name)(struct kset___171 *, struct kobject___171 *);
	int (* const uevent)(struct kset___171 *, struct kobject___171 *, struct kobj_uevent_env *);
};

struct fwnode_operations___135;

struct fwnode_handle___135 {
	struct fwnode_handle___135 *secondary;
	const struct fwnode_operations___135 *ops;
	struct device___135 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___135;

struct fwnode_endpoint___135;

struct fwnode_operations___135 {
	struct fwnode_handle___135 * (*get)(struct fwnode_handle___135 *);
	void (*put)(struct fwnode_handle___135 *);
	bool (*device_is_available)(const struct fwnode_handle___135 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___135 *, const struct device___135 *);
	bool (*property_present)(const struct fwnode_handle___135 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___135 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___135 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___135 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*get_parent)(const struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*get_next_child_node)(const struct fwnode_handle___135 *, struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*get_named_child_node)(const struct fwnode_handle___135 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___135 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___135 *);
	struct fwnode_handle___135 * (*graph_get_next_endpoint)(const struct fwnode_handle___135 *, struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*graph_get_remote_endpoint)(const struct fwnode_handle___135 *);
	struct fwnode_handle___135 * (*graph_get_port_parent)(struct fwnode_handle___135 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___135 *, struct fwnode_endpoint___135 *);
	int (*add_links)(struct fwnode_handle___135 *);
};

struct wakeup_source___135;

struct dev_pm_info___135 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___135 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___135 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___135;

struct bus_type___135;

struct device_driver___135;

struct dev_pm_domain___135;

struct device_node___37;

struct class___135;

struct device___135 {
	struct kobject___171 kobj;
	struct device___135 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___135 *type;
	struct bus_type___135 *bus;
	struct device_driver___135 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___135 power;
	struct dev_pm_domain___135 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___37 *of_node;
	struct fwnode_handle___135 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___135 *class;
	const struct attribute_group___171 **groups;
	void (*release)(struct device___135 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___135 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___135 *local_fwnode;
};

struct fwnode_reference_args___135 {
	struct fwnode_handle___135 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___33 {
	char *name;
	int length;
	void *value;
	struct property___33 *next;
	long unsigned int _flags;
	struct bin_attribute___171 attr;
};

struct device_node___37 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___135 fwnode;
	struct property___33 *properties;
	struct property___33 *deadprops;
	struct device_node___37 *parent;
	struct device_node___37 *child;
	struct device_node___37 *sibling;
	struct kobject___171 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___183;

struct dentry___183 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___183 *d_parent;
	struct qstr d_name;
	struct inode___183 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___183 *d_op;
	struct super_block___183 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___183;

struct cdev___34;

struct inode___183 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___183 *i_op;
	struct super_block___183 *i_sb;
	struct address_space___183 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___83 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___183 *i_fop;
		void (*free_inode)(struct inode___183 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___183 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___62 *i_pipe;
		struct cdev___34 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___183 {
	int (*d_revalidate)(struct dentry___183 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___183 *, unsigned int);
	int (*d_hash)(const struct dentry___183 *, struct qstr *);
	int (*d_compare)(const struct dentry___183 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___183 *);
	int (*d_init)(struct dentry___183 *);
	void (*d_release)(struct dentry___183 *);
	void (*d_prune)(struct dentry___183 *);
	void (*d_iput)(struct dentry___183 *, struct inode___183 *);
	char * (*d_dname)(struct dentry___183 *, char *, int);
	struct vfsmount___183 * (*d_automount)(struct path___183 *);
	int (*d_manage)(const struct path___183 *, bool);
	struct dentry___183 * (*d_real)(struct dentry___183 *, const struct inode___183 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___183;

struct mem_dqinfo___183 {
	struct quota_format_type___183 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___183;

struct quota_info___183 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___183 *files[3];
	struct mem_dqinfo___183 info[3];
	const struct quota_format_ops___183 *ops[3];
};

struct rcuwait___184 {
	struct task_struct___190 *task;
};

struct percpu_rw_semaphore___184 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___184 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___183 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___184 rw_sem[3];
};

struct shrink_control___74;

struct shrinker___74 {
	long unsigned int (*count_objects)(struct shrinker___74 *, struct shrink_control___74 *);
	long unsigned int (*scan_objects)(struct shrinker___74 *, struct shrink_control___74 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___183;

struct dquot_operations___183;

struct quotactl_ops___183;

struct block_device___91;

struct super_block___183 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___183 *s_type;
	const struct super_operations___183 *s_op;
	const struct dquot_operations___183 *dq_op;
	const struct quotactl_ops___183 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___183 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___91 *s_bdev;
	struct backing_dev_info___83 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___183 s_dquot;
	struct sb_writers___183 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___183 *s_d_op;
	int cleancache_poolid;
	struct shrinker___74 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___183 {
	struct dentry___183 *mnt_root;
	struct super_block___183 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___74 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___74 *memcg;
};

struct psi_group___124 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___190 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___36;

struct cgroup_bpf___36 {
	struct bpf_prog_array___36 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___36 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___124;

struct cgroup_rstat_cpu___124;

struct cgroup___124 {
	struct cgroup_subsys_state___124 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___171 *kn;
	struct cgroup_file___124 procs_file;
	struct cgroup_file___124 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___124 *subsys[14];
	struct cgroup_root___124 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___124 *dom_cgrp;
	struct cgroup___124 *old_dom_cgrp;
	struct cgroup_rstat_cpu___124 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___124 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___90 {
	struct request_queue___90 *q;
	struct io_context___90 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___83;

struct kiocb___183 {
	struct file___183 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___183 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___83 *ki_waitq;
	};
};

struct iattr___183 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___183 *ia_file;
};

struct dquot___183 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___183 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___183 {
	int qf_fmt_id;
	const struct quota_format_ops___183 *qf_ops;
	struct module___167 *qf_owner;
	struct quota_format_type___183 *qf_next;
};

struct quota_format_ops___183 {
	int (*check_quota_file)(struct super_block___183 *, int);
	int (*read_file_info)(struct super_block___183 *, int);
	int (*write_file_info)(struct super_block___183 *, int);
	int (*free_file_info)(struct super_block___183 *, int);
	int (*read_dqblk)(struct dquot___183 *);
	int (*commit_dqblk)(struct dquot___183 *);
	int (*release_dqblk)(struct dquot___183 *);
	int (*get_next_id)(struct super_block___183 *, struct kqid *);
};

struct dquot_operations___183 {
	int (*write_dquot)(struct dquot___183 *);
	struct dquot___183 * (*alloc_dquot)(struct super_block___183 *, int);
	void (*destroy_dquot)(struct dquot___183 *);
	int (*acquire_dquot)(struct dquot___183 *);
	int (*release_dquot)(struct dquot___183 *);
	int (*mark_dirty)(struct dquot___183 *);
	int (*write_info)(struct super_block___183 *, int);
	qsize_t * (*get_reserved_space)(struct inode___183 *);
	int (*get_projid)(struct inode___183 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___183 *, qsize_t *);
	int (*get_next_id)(struct super_block___183 *, struct kqid *);
};

struct quotactl_ops___183 {
	int (*quota_on)(struct super_block___183 *, int, int, const struct path___183 *);
	int (*quota_off)(struct super_block___183 *, int);
	int (*quota_enable)(struct super_block___183 *, unsigned int);
	int (*quota_disable)(struct super_block___183 *, unsigned int);
	int (*quota_sync)(struct super_block___183 *, int);
	int (*set_info)(struct super_block___183 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___183 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___183 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___183 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___183 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___183 *, unsigned int);
};

struct wait_page_queue___83 {
	struct page___188 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___83;

struct readahead_control___83;

struct address_space_operations___183 {
	int (*writepage)(struct page___188 *, struct writeback_control___83 *);
	int (*readpage)(struct file___183 *, struct page___188 *);
	int (*writepages)(struct address_space___183 *, struct writeback_control___83 *);
	int (*set_page_dirty)(struct page___188 *);
	int (*readpages)(struct file___183 *, struct address_space___183 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___83 *);
	int (*write_begin)(struct file___183 *, struct address_space___183 *, loff_t, unsigned int, unsigned int, struct page___188 **, void **);
	int (*write_end)(struct file___183 *, struct address_space___183 *, loff_t, unsigned int, unsigned int, struct page___188 *, void *);
	sector_t (*bmap)(struct address_space___183 *, sector_t);
	void (*invalidatepage)(struct page___188 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___188 *, gfp_t);
	void (*freepage)(struct page___188 *);
	ssize_t (*direct_IO)(struct kiocb___183 *, struct iov_iter___108 *);
	int (*migratepage)(struct address_space___183 *, struct page___188 *, struct page___188 *, enum migrate_mode);
	bool (*isolate_page)(struct page___188 *, isolate_mode_t);
	void (*putback_page)(struct page___188 *);
	int (*launder_page)(struct page___188 *);
	int (*is_partially_uptodate)(struct page___188 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___188 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___183 *, struct page___188 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___183 *, sector_t *);
	void (*swap_deactivate)(struct file___183 *);
};

struct writeback_control___83 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___83 *wb;
	struct inode___183 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___83 {
	struct file___183 *file;
	struct address_space___183 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___106;

struct iov_iter___108 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___106 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___62 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___34 {
	struct kobject___171 kobj;
	struct module___167 *owner;
	const struct file_operations___183 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___183 {
	struct dentry___183 * (*lookup)(struct inode___183 *, struct dentry___183 *, unsigned int);
	const char * (*get_link)(struct dentry___183 *, struct inode___183 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___183 *, int);
	struct posix_acl * (*get_acl)(struct inode___183 *, int, bool);
	int (*readlink)(struct dentry___183 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___183 *, struct dentry___183 *, umode_t, bool);
	int (*link)(struct dentry___183 *, struct inode___183 *, struct dentry___183 *);
	int (*unlink)(struct inode___183 *, struct dentry___183 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___183 *, struct dentry___183 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___183 *, struct dentry___183 *, umode_t);
	int (*rmdir)(struct inode___183 *, struct dentry___183 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___183 *, struct dentry___183 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___183 *, struct dentry___183 *, struct inode___183 *, struct dentry___183 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___183 *, struct iattr___183 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___183 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___183 *, char *, size_t);
	int (*fiemap)(struct inode___183 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___183 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___183 *, struct dentry___183 *, struct file___183 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___183 *, struct dentry___183 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___183 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___183 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___183 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___183 {
	void (*fl_copy_lock)(struct file_lock___183 *, struct file_lock___183 *);
	void (*fl_release_private)(struct file_lock___183 *);
};

struct lock_manager_operations___183;

struct file_lock___183 {
	struct file_lock___183 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___183 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___183 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___183 *fl_ops;
	const struct lock_manager_operations___183 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___183 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___183 *);
	int (*lm_grant)(struct file_lock___183 *, int);
	bool (*lm_break)(struct file_lock___183 *);
	int (*lm_change)(struct file_lock___183 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___183 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___183 *);
};

struct fasync_struct___183 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___183 *fa_next;
	struct file___183 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___183 {
	struct inode___183 * (*alloc_inode)(struct super_block___183 *);
	void (*destroy_inode)(struct inode___183 *);
	void (*free_inode)(struct inode___183 *);
	void (*dirty_inode)(struct inode___183 *, int);
	int (*write_inode)(struct inode___183 *, struct writeback_control___83 *);
	int (*drop_inode)(struct inode___183 *);
	void (*evict_inode)(struct inode___183 *);
	void (*put_super)(struct super_block___183 *);
	int (*sync_fs)(struct super_block___183 *, int);
	int (*freeze_super)(struct super_block___183 *);
	int (*freeze_fs)(struct super_block___183 *);
	int (*thaw_super)(struct super_block___183 *);
	int (*unfreeze_fs)(struct super_block___183 *);
	int (*statfs)(struct dentry___183 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___183 *, int *, char *);
	void (*umount_begin)(struct super_block___183 *);
	int (*show_options)(struct seq_file___159 *, struct dentry___183 *);
	int (*show_devname)(struct seq_file___159 *, struct dentry___183 *);
	int (*show_path)(struct seq_file___159 *, struct dentry___183 *);
	int (*show_stats)(struct seq_file___159 *, struct dentry___183 *);
	ssize_t (*quota_read)(struct super_block___183 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___183 *, int, const char *, size_t, loff_t);
	struct dquot___183 ** (*get_dquots)(struct inode___183 *);
	long int (*nr_cached_objects)(struct super_block___183 *, struct shrink_control___74 *);
	long int (*free_cached_objects)(struct super_block___183 *, struct shrink_control___74 *);
	struct file___183 * (*real_loop)(struct file___183 *);
};

struct block_device___91 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___183 *bd_inode;
	struct super_block___183 *bd_super;
	void *bd_claiming;
	struct device___135 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___171 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___91 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___183 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___90(struct bio___90 *);

struct bio_vec___106 {
	struct page___188 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___90;

struct bio___90 {
	struct bio___90 *bi_next;
	struct block_device___91 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___90 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___85 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___90 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___106 *bi_io_vec;
	struct bio_set___90 *bi_pool;
	struct bio_vec___106 bi_inline_vecs[0];
};

struct kernel_param_ops___167 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___167 *);
	int (*get)(char *, const struct kernel_param___167 *);
	void (*free)(void *);
};

struct kparam_array___167;

struct kernel_param___167 {
	const char *name;
	struct module___167 *mod;
	const struct kernel_param_ops___167 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___167 *arr;
	};
};

struct kparam_array___167 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___167 *ops;
	void *elem;
};

struct module_attribute___167 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___167 *, struct module_kobject___167 *, char *);
	ssize_t (*store)(struct module_attribute___167 *, struct module_kobject___167 *, const char *, size_t);
	void (*setup)(struct module___167 *, const char *);
	int (*test)(struct module___167 *);
	void (*free)(struct module___167 *);
};

struct dev_pagemap_ops___178 {
	void (*page_free)(struct page___188 *);
	void (*kill)(struct dev_pagemap___178 *);
	void (*cleanup)(struct dev_pagemap___178 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___178 *);
};

struct dev_pm_ops___135 {
	int (*prepare)(struct device___135 *);
	void (*complete)(struct device___135 *);
	int (*suspend)(struct device___135 *);
	int (*resume)(struct device___135 *);
	int (*freeze)(struct device___135 *);
	int (*thaw)(struct device___135 *);
	int (*poweroff)(struct device___135 *);
	int (*restore)(struct device___135 *);
	int (*suspend_late)(struct device___135 *);
	int (*resume_early)(struct device___135 *);
	int (*freeze_late)(struct device___135 *);
	int (*thaw_early)(struct device___135 *);
	int (*poweroff_late)(struct device___135 *);
	int (*restore_early)(struct device___135 *);
	int (*suspend_noirq)(struct device___135 *);
	int (*resume_noirq)(struct device___135 *);
	int (*freeze_noirq)(struct device___135 *);
	int (*thaw_noirq)(struct device___135 *);
	int (*poweroff_noirq)(struct device___135 *);
	int (*restore_noirq)(struct device___135 *);
	int (*runtime_suspend)(struct device___135 *);
	int (*runtime_resume)(struct device___135 *);
	int (*runtime_idle)(struct device___135 *);
};

struct wakeup_source___135 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___135 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___135 {
	struct dev_pm_ops___135 ops;
	int (*start)(struct device___135 *);
	void (*detach)(struct device___135 *, bool);
	int (*activate)(struct device___135 *);
	void (*sync)(struct device___135 *);
	void (*dismiss)(struct device___135 *);
};

struct bus_type___135 {
	const char *name;
	const char *dev_name;
	struct device___135 *dev_root;
	const struct attribute_group___171 **bus_groups;
	const struct attribute_group___171 **dev_groups;
	const struct attribute_group___171 **drv_groups;
	int (*match)(struct device___135 *, struct device_driver___135 *);
	int (*uevent)(struct device___135 *, struct kobj_uevent_env *);
	int (*probe)(struct device___135 *);
	void (*sync_state)(struct device___135 *);
	void (*remove)(struct device___135 *);
	void (*shutdown)(struct device___135 *);
	int (*online)(struct device___135 *);
	int (*offline)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	int (*num_vf)(struct device___135 *);
	int (*dma_configure)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___135 {
	const char *name;
	struct bus_type___135 *bus;
	struct module___167 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___135 *);
	void (*sync_state)(struct device___135 *);
	int (*remove)(struct device___135 *);
	void (*shutdown)(struct device___135 *);
	int (*suspend)(struct device___135 *, pm_message_t);
	int (*resume)(struct device___135 *);
	const struct attribute_group___171 **groups;
	const struct attribute_group___171 **dev_groups;
	const struct dev_pm_ops___135 *pm;
	void (*coredump)(struct device___135 *);
	struct driver_private *p;
};

struct device_type___135 {
	const char *name;
	const struct attribute_group___171 **groups;
	int (*uevent)(struct device___135 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___135 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___135 *);
	const struct dev_pm_ops___135 *pm;
};

struct class___135 {
	const char *name;
	struct module___167 *owner;
	const struct attribute_group___171 **class_groups;
	const struct attribute_group___171 **dev_groups;
	struct kobject___171 *dev_kobj;
	int (*dev_uevent)(struct device___135 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___135 *, umode_t *);
	void (*class_release)(struct class___135 *);
	void (*dev_release)(struct device___135 *);
	int (*shutdown_pre)(struct device___135 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___135 *);
	void (*get_ownership)(struct device___135 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___135 *pm;
	struct subsys_private *p;
};

struct seq_operations___159 {
	void * (*start)(struct seq_file___159 *, loff_t *);
	void (*stop)(struct seq_file___159 *, void *);
	void * (*next)(struct seq_file___159 *, void *, loff_t *);
	int (*show)(struct seq_file___159 *, void *);
};

struct msghdr___31 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___108 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___183 *msg_iocb;
};

struct fib_rules_ops___29;

struct fqdir___41;

struct fib_notifier_ops___29;

struct netns_ipv4___41 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___29 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___30 *fibnl;
	struct sock___30 **icmp_sk;
	struct sock___30 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___30 **tcp_sk;
	struct fqdir___41 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___29 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___29 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___29 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___29;

struct dst_ops___41 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___41 *);
	struct dst_entry___29 * (*check)(struct dst_entry___29 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___29 *);
	unsigned int (*mtu)(const struct dst_entry___29 *);
	u32 * (*cow_metrics)(struct dst_entry___29 *, long unsigned int);
	void (*destroy)(struct dst_entry___29 *);
	void (*ifdown)(struct dst_entry___29 *, struct net_device___38 *, int);
	struct dst_entry___29 * (*negative_advice)(struct dst_entry___29 *);
	void (*link_failure)(struct sk_buff___37 *);
	void (*update_pmtu)(struct dst_entry___29 *, struct sock___30 *, struct sk_buff___37 *, u32, bool);
	void (*redirect)(struct dst_entry___29 *, struct sock___30 *, struct sk_buff___37 *);
	int (*local_out)(struct net___41 *, struct sock___30 *, struct sk_buff___37 *);
	struct neighbour___29 * (*neigh_lookup)(const struct dst_entry___29 *, struct sk_buff___37 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___29 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___41 {
	struct dst_ops___41 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___41 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___29 *fib6_rules_ops;
	struct sock___30 **icmp_sk;
	struct sock___30 *ndisc_sk;
	struct sock___30 *tcp_sk;
	struct sock___30 *igmp_sk;
	struct sock___30 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___29 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___29 *notifier_ops;
	struct fib_notifier_ops___29 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___41 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___41 *fqdir;
};

struct netns_sctp___29 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___30 *ctl_sock;
	struct sock___30 *udp4_sock;
	struct sock___30 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___36;

struct netns_bpf___36 {
	struct bpf_prog_array___36 *run_array[2];
	struct bpf_prog___36 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___41 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___30 *nlsk;
	struct sock___30 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___41 xfrm4_dst_ops;
	struct dst_ops___41 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___41 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___30 *rtnl;
	struct sock___30 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___38 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___41 ipv4;
	struct netns_ipv6___41 ipv6;
	struct netns_ieee802154_lowpan___41 ieee802154_lowpan;
	struct netns_sctp___29 sctp;
	struct netns_nf___3 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___36 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___36 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___41 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___30 *crypto_nlsk;
	struct sock___30 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___124 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___124 *root_cset;
};

struct socket_wq___30 {
	wait_queue_head_t wait;
	struct fasync_struct___183 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___30;

struct socket___31 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___183 *file;
	struct sock___30 *sk;
	const struct proto_ops___30 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___30 wq;
};

typedef int (*sk_read_actor_t___29)(read_descriptor_t *, struct sk_buff___37 *, unsigned int, size_t);

struct proto_ops___30 {
	int family;
	struct module___167 *owner;
	int (*release)(struct socket___31 *);
	int (*bind)(struct socket___31 *, struct sockaddr *, int);
	int (*connect)(struct socket___31 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___31 *, struct socket___31 *);
	int (*accept)(struct socket___31 *, struct socket___31 *, int, bool);
	int (*getname)(struct socket___31 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___183 *, struct socket___31 *, struct poll_table_struct___119 *);
	int (*ioctl)(struct socket___31 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___31 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___31 *, void *, bool, bool);
	int (*listen)(struct socket___31 *, int);
	int (*shutdown)(struct socket___31 *, int);
	int (*setsockopt)(struct socket___31 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___31 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___159 *, struct socket___31 *);
	int (*sendmsg)(struct socket___31 *, struct msghdr___31 *, size_t);
	int (*recvmsg)(struct socket___31 *, struct msghdr___31 *, size_t, int);
	int (*mmap)(struct file___183 *, struct socket___31 *, struct vm_area_struct___188 *);
	ssize_t (*sendpage)(struct socket___31 *, struct page___188 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___31 *, loff_t *, struct pipe_inode_info___62 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___30 *, int);
	int (*peek_len)(struct socket___31 *);
	int (*read_sock)(struct sock___30 *, read_descriptor_t *, sk_read_actor_t___29);
	int (*sendpage_locked)(struct sock___30 *, struct page___188 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___30 *, struct msghdr___31 *, size_t);
	int (*set_rcvlowat)(struct sock___30 *, int);
};

struct sk_buff___37 {
	union {
		struct {
			struct sk_buff___37 *next;
			struct sk_buff___37 *prev;
			union {
				struct net_device___38 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___37 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct pipe_buf_operations___62;

struct pipe_buffer___62 {
	struct page___188 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___62 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___62 {
	int (*confirm)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
	void (*release)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
	bool (*try_steal)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
	bool (*get)(struct pipe_inode_info___62 *, struct pipe_buffer___62 *);
};

typedef rx_handler_result_t rx_handler_func_t___36(struct sk_buff___37 **);

struct bpf_xdp_entity___36 {
	struct bpf_prog___36 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___36;

struct net_device_ops___36;

struct l3mdev_ops___29;

struct ndisc_ops___19;

struct xfrmdev_ops___36;

struct header_ops___36;

struct inet6_dev___19;

struct netdev_rx_queue___36;

struct mini_Qdisc___36;

struct netdev_queue___36;

struct Qdisc___36;

struct rtnl_link_ops___36;

struct dcbnl_rtnl_ops___36;

struct net_device___38 {
	char name[16];
	struct netdev_name_node___36 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___36 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___29 *l3mdev_ops;
	const struct ndisc_ops___19 *ndisc_ops;
	const struct xfrmdev_ops___36 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___36 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___171 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___19 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___36 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___36 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___36 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___36 *miniq_ingress;
	struct netdev_queue___36 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___36 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___36 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___36 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___36 = 0,
		NETREG_REGISTERED___36 = 1,
		NETREG_UNREGISTERING___36 = 2,
		NETREG_UNREGISTERED___36 = 3,
		NETREG_RELEASED___36 = 4,
		NETREG_DUMMY___36 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___36 = 0,
		RTNL_LINK_INITIALIZING___36 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___38 *);
	struct netpoll_info *npinfo;
	possible_net_t___36 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___135 dev;
	const struct attribute_group___171 *sysfs_groups[4];
	const struct attribute_group___171 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___36 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___36 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___36 xdp_state[3];
	long: 64;
};

struct inet_frags___41;

struct fqdir___41 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___41 *f;
	struct net___41 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___41;

struct inet_frags___41 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___41 *, const void *);
	void (*destructor)(struct inet_frag_queue___41 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___41 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___37 *fragments_tail;
	struct sk_buff___37 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___41 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___29;

struct fib_lookup_arg___29;

struct fib_rules_ops___29 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___29 *, struct flowi *, int, struct fib_lookup_arg___29 *);
	bool (*suppress)(struct fib_rule___29 *, int, struct fib_lookup_arg___29 *);
	int (*match)(struct fib_rule___29 *, struct flowi *, int);
	int (*configure)(struct fib_rule___29 *, struct sk_buff___37 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___29 *);
	int (*compare)(struct fib_rule___29 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___29 *, struct sk_buff___37 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___29 *);
	void (*flush_cache)(struct fib_rules_ops___29 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___167 *owner;
	struct net___41 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___29 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___41 *);
	int (*fib_dump)(struct net___41 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___167 *owner;
	struct callback_head rcu;
};

struct dst_entry___29 {
	struct net_device___38 *dev;
	struct dst_ops___41 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___37 *);
	int (*output)(struct net___41 *, struct sock___30 *, struct sk_buff___37 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___29;

struct neigh_parms___29;

struct neigh_ops___29;

struct neighbour___29 {
	struct neighbour___29 *next;
	struct neigh_table___29 *tbl;
	struct neigh_parms___29 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___36 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___29 *, struct sk_buff___37 *);
	const struct neigh_ops___29 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___38 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___36 {
	struct bpf_prog___36 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___36 {
	struct callback_head rcu;
	struct bpf_prog_array_item___36 items[0];
};

struct bpf_prog_aux___39;

struct bpf_prog___36 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___39 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dcbnl_rtnl_ops___36 {
	int (*ieee_getets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___38 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___38 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___38 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___38 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___38 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___38 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___38 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___38 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___38 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___38 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___38 *);
	u8 (*setstate)(struct net_device___38 *, u8);
	void (*getpermhwaddr)(struct net_device___38 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___38 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___38 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___38 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___38 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___38 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___38 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___38 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___38 *, int, u8 *);
	void (*setpfccfg)(struct net_device___38 *, int, u8);
	void (*getpfccfg)(struct net_device___38 *, int, u8 *);
	u8 (*setall)(struct net_device___38 *);
	u8 (*getcap)(struct net_device___38 *, int, u8 *);
	int (*getnumtcs)(struct net_device___38 *, int, u8 *);
	int (*setnumtcs)(struct net_device___38 *, int, u8);
	u8 (*getpfcstate)(struct net_device___38 *);
	void (*setpfcstate)(struct net_device___38 *, u8);
	void (*getbcncfg)(struct net_device___38 *, int, u32 *);
	void (*setbcncfg)(struct net_device___38 *, int, u32);
	void (*getbcnrp)(struct net_device___38 *, int, u8 *);
	void (*setbcnrp)(struct net_device___38 *, int, u8);
	int (*setapp)(struct net_device___38 *, u8, u16, u8);
	int (*getapp)(struct net_device___38 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___38 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___38 *, int, u8);
	u8 (*getdcbx)(struct net_device___38 *);
	u8 (*setdcbx)(struct net_device___38 *, u8);
	int (*peer_getappinfo)(struct net_device___38 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___38 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___38 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___38 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___38 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___38 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___39;

typedef int (*bpf_iter_init_seq_priv_t___38)(void *, struct bpf_iter_aux_info___39 *);

struct bpf_map___39;

struct bpf_iter_aux_info___39 {
	struct bpf_map___39 *map;
};

struct bpf_iter_seq_info___38 {
	const struct seq_operations___159 *seq_ops;
	bpf_iter_init_seq_priv_t___38 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___38 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___39 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___39 *, struct file___183 *);
	void (*map_free)(struct bpf_map___39 *);
	int (*map_get_next_key)(struct bpf_map___39 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___39 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___39 *, void *);
	int (*map_lookup_batch)(struct bpf_map___39 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___39 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___39 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___39 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___39 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___39 *, void *);
	int (*map_update_elem)(struct bpf_map___39 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___39 *, void *);
	int (*map_push_elem)(struct bpf_map___39 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___39 *, void *);
	int (*map_peek_elem)(struct bpf_map___39 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___39 *, struct file___183 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___39 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___39 *, void *, struct seq_file___159 *);
	int (*map_check_btf)(const struct bpf_map___39 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___39 *, struct bpf_prog_aux___39 *);
	void (*map_poke_untrack)(struct bpf_map___39 *, struct bpf_prog_aux___39 *);
	void (*map_poke_run)(struct bpf_map___39 *, u32, struct bpf_prog___36 *, struct bpf_prog___36 *);
	int (*map_direct_value_addr)(const struct bpf_map___39 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___39 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___39 *, struct vm_area_struct___188 *);
	__poll_t (*map_poll)(struct bpf_map___39 *, struct file___183 *, struct poll_table_struct___119 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___39 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___39 *, const struct bpf_map___39 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___39 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___38 *iter_seq_info;
};

struct bpf_map___39 {
	const struct bpf_map_ops___38 *ops;
	struct bpf_map___39 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___74 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___38;

struct bpf_jit_poke_descriptor___38;

struct bpf_prog_ops___36;

struct btf_mod_pair___38;

struct bpf_prog_offload___36;

struct bpf_prog_aux___39 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___36 *dst_prog;
	struct bpf_trampoline___38 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___36 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___38 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___36 *ops;
	struct bpf_map___39 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___38 *used_btfs;
	struct bpf_prog___36 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___39 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___36 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___36;

struct bpf_map_dev_ops___36 {
	int (*map_get_next_key)(struct bpf_offloaded_map___36 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___36 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___36 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___36 *, void *);
};

struct bpf_offloaded_map___36 {
	struct bpf_map___39 map;
	struct net_device___38 *netdev;
	const struct bpf_map_dev_ops___36 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___36 {
	int (*test_run)(struct bpf_prog___36 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___36 {
	struct bpf_prog___36 *prog;
	struct net_device___38 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___38 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___36 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___167 *mod;
};

struct bpf_jit_poke_descriptor___38 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___39 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___38 {
	struct btf *btf;
	struct module___167 *module;
};

struct cftype___124;

struct cgroup_subsys___124 {
	struct cgroup_subsys_state___124 * (*css_alloc)(struct cgroup_subsys_state___124 *);
	int (*css_online)(struct cgroup_subsys_state___124 *);
	void (*css_offline)(struct cgroup_subsys_state___124 *);
	void (*css_released)(struct cgroup_subsys_state___124 *);
	void (*css_free)(struct cgroup_subsys_state___124 *);
	void (*css_reset)(struct cgroup_subsys_state___124 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___124 *, int);
	int (*css_extra_stat_show)(struct seq_file___159 *, struct cgroup_subsys_state___124 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___190 *, struct css_set___124 *);
	void (*cancel_fork)(struct task_struct___190 *, struct css_set___124 *);
	void (*fork)(struct task_struct___190 *);
	void (*exit)(struct task_struct___190 *);
	void (*release)(struct task_struct___190 *);
	void (*bind)(struct cgroup_subsys_state___124 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___124 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___124 *dfl_cftypes;
	struct cftype___124 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___124 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___124 *updated_children;
	struct cgroup___124 *updated_next;
};

struct cgroup_root___124 {
	struct kernfs_root___171 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___124 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___124 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___124 *ss;
	struct list_head node;
	struct kernfs_ops___171 *kf_ops;
	int (*open)(struct kernfs_open_file___171 *);
	void (*release)(struct kernfs_open_file___171 *);
	u64 (*read_u64)(struct cgroup_subsys_state___124 *, struct cftype___124 *);
	s64 (*read_s64)(struct cgroup_subsys_state___124 *, struct cftype___124 *);
	int (*seq_show)(struct seq_file___159 *, void *);
	void * (*seq_start)(struct seq_file___159 *, loff_t *);
	void * (*seq_next)(struct seq_file___159 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___159 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___124 *, struct cftype___124 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___124 *, struct cftype___124 *, s64);
	ssize_t (*write)(struct kernfs_open_file___171 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___171 *, struct poll_table_struct___119 *);
};

struct xdp_rxq_info___36 {
	struct net_device___38 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___36 {
	struct net_device___38 *dev;
};

struct xdp_buff___36 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___36 *rxq;
	struct xdp_txq_info___36 *txq;
	u32 frame_sz;
};

struct xdp_frame___36 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___38 *dev_rx;
};

struct netlink_callback___36 {
	struct sk_buff___37 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___37 *, struct netlink_callback___36 *);
	int (*done)(struct netlink_callback___36 *);
	void *data;
	struct module___167 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___36 {
	int (*create)(struct sk_buff___37 *, struct net_device___38 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___37 *, unsigned char *);
	int (*cache)(const struct neighbour___29 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___38 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___37 *);
};

struct netdev_queue___36 {
	struct net_device___38 *dev;
	struct Qdisc___36 *qdisc;
	struct Qdisc___36 *qdisc_sleeping;
	struct kobject___171 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___38 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___36 {
	struct sk_buff___37 *head;
	struct sk_buff___37 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___36;

struct Qdisc___36 {
	int (*enqueue)(struct sk_buff___37 *, struct Qdisc___36 *, struct sk_buff___37 **);
	struct sk_buff___37 * (*dequeue)(struct Qdisc___36 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___36 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___36 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___36 gso_skb;
	struct qdisc_skb_head___36 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___36 *next_sched;
	struct sk_buff_head___36 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___36 {
	struct xdp_rxq_info___36 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___171 kobj;
	struct net_device___38 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___36 {
	enum net_device_path_type type;
	const struct net_device___38 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___36 = 0,
				DEV_PATH_BR_VLAN_TAG___36 = 1,
				DEV_PATH_BR_VLAN_UNTAG___36 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___36 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___36 {
	const struct net_device___38 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___36 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___36 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___36 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___36 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___37 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___36 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___38 *dev;
	const char *name;
};

struct net_device_ops___36 {
	int (*ndo_init)(struct net_device___38 *);
	void (*ndo_uninit)(struct net_device___38 *);
	int (*ndo_open)(struct net_device___38 *);
	int (*ndo_stop)(struct net_device___38 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___37 *, struct net_device___38 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___37 *, struct net_device___38 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___38 *, struct sk_buff___37 *, struct net_device___38 *);
	void (*ndo_change_rx_flags)(struct net_device___38 *, int);
	void (*ndo_set_rx_mode)(struct net_device___38 *);
	int (*ndo_set_mac_address)(struct net_device___38 *, void *);
	int (*ndo_validate_addr)(struct net_device___38 *);
	int (*ndo_do_ioctl)(struct net_device___38 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___38 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___38 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___38 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___38 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___38 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___38 *, int);
	int (*ndo_neigh_setup)(struct net_device___38 *, struct neigh_parms___29 *);
	void (*ndo_tx_timeout)(struct net_device___38 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___38 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___38 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___38 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___38 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___38 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___38 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___38 *);
	int (*ndo_netpoll_setup)(struct net_device___38 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___38 *);
	int (*ndo_set_vf_mac)(struct net_device___38 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___38 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___38 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___38 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___38 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___38 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___38 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___38 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___38 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___38 *, int, struct sk_buff___37 *);
	int (*ndo_get_vf_guid)(struct net_device___38 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___38 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___38 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___38 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___38 *);
	int (*ndo_fcoe_disable)(struct net_device___38 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___38 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___38 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___38 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___38 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___38 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___38 *, const struct sk_buff___37 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___38 *, struct net_device___38 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___38 *, struct net_device___38 *);
	struct net_device___38 * (*ndo_get_xmit_slave)(struct net_device___38 *, struct sk_buff___37 *, bool);
	struct net_device___38 * (*ndo_sk_get_lower_dev)(struct net_device___38 *, struct sock___30 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___38 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___38 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___38 *, struct neighbour___29 *);
	void (*ndo_neigh_destroy)(struct net_device___38 *, struct neighbour___29 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___37 *, struct netlink_callback___36 *, struct net_device___38 *, struct net_device___38 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___37 *, struct nlattr **, struct net_device___38 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___38 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___37 *, u32, u32, struct net_device___38 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___38 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___38 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___38 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___38 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___38 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___38 *, struct net_device___38 *);
	void (*ndo_dfwd_del_station)(struct net_device___38 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___38 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___38 *);
	int (*ndo_change_proto_down)(struct net_device___38 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___38 *, struct sk_buff___37 *);
	void (*ndo_set_rx_headroom)(struct net_device___38 *, int);
	int (*ndo_bpf)(struct net_device___38 *, struct netdev_bpf___36 *);
	int (*ndo_xdp_xmit)(struct net_device___38 *, int, struct xdp_frame___36 **, u32);
	struct net_device___38 * (*ndo_xdp_get_xmit_slave)(struct net_device___38 *, struct xdp_buff___36 *);
	int (*ndo_xsk_wakeup)(struct net_device___38 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___38 *);
	int (*ndo_tunnel_ctl)(struct net_device___38 *, struct ip_tunnel_parm *, int);
	struct net_device___38 * (*ndo_get_peer_dev)(struct net_device___38 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___36 *, struct net_device_path___36 *);
};

struct neigh_parms___29 {
	possible_net_t___36 net;
	struct net_device___38 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___29 *);
	struct neigh_table___29 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___29 {
	u32 (*l3mdev_fib_table)(const struct net_device___38 *);
	struct sk_buff___37 * (*l3mdev_l3_rcv)(struct net_device___38 *, struct sk_buff___37 *, u16);
	struct sk_buff___37 * (*l3mdev_l3_out)(struct net_device___38 *, struct sock___30 *, struct sk_buff___37 *, u16);
	struct dst_entry___29 * (*l3mdev_link_scope_lookup)(const struct net_device___38 *, struct flowi6 *);
};

struct ndisc_ops___19 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___38 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___38 *, struct neighbour___29 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___38 *, u8, struct neighbour___29 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___38 *, struct sk_buff___37 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___41 *, struct net_device___38 *, const struct prefix_info *, struct inet6_dev___19 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___19;

struct inet6_dev___19 {
	struct net_device___38 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___19 *mc_list;
	struct ifmcaddr6___19 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___36 mc_query_queue;
	struct sk_buff_head___36 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___29 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___36;

struct tcf_block___36;

struct mini_Qdisc___36 {
	struct tcf_proto___36 *filter_list;
	struct tcf_block___36 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___36 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___38 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___38 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___41 *, struct net_device___38 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___38 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___38 *, struct list_head *);
	size_t (*get_size)(const struct net_device___38 *);
	int (*fill_info)(struct sk_buff___37 *, const struct net_device___38 *);
	size_t (*get_xstats_size)(const struct net_device___38 *);
	int (*fill_xstats)(struct sk_buff___37 *, const struct net_device___38 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___38 *, struct net_device___38 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___38 *, const struct net_device___38 *);
	int (*fill_slave_info)(struct sk_buff___37 *, const struct net_device___38 *, const struct net_device___38 *);
	struct net___41 * (*get_link_net)(const struct net_device___38 *);
	size_t (*get_linkxstats_size)(const struct net_device___38 *, int);
	int (*fill_linkxstats)(struct sk_buff___37 *, const struct net_device___38 *, int *, int);
};

struct block_device_operations___90;

struct gendisk___91 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___91 *part0;
	const struct block_device_operations___90 *fops;
	struct request_queue___90 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___83 *bdi;
	struct kobject___171 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___171 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___90 {
	struct bio___90 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___106 *bip_vec;
	struct bio_vec___106 bip_inline_vecs[0];
};

struct blkcg___85;

struct blkg_policy_data___85;

struct blkcg_gq___85 {
	struct request_queue___90 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___85 *blkcg;
	struct blkcg_gq___85 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___85 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___90 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___90(struct request___90 *);

typedef void integrity_complete_fn___90(struct request___90 *, unsigned int);

struct blk_integrity_profile___90 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___90 *prepare_fn;
	integrity_complete_fn___90 *complete_fn;
	const char *name;
};

struct block_device_operations___90 {
	blk_qc_t (*submit_bio)(struct bio___90 *);
	int (*open)(struct block_device___91 *, fmode_t);
	void (*release)(struct gendisk___91 *, fmode_t);
	int (*rw_page)(struct block_device___91 *, sector_t, struct page___188 *, unsigned int);
	int (*ioctl)(struct block_device___91 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___91 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___91 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___91 *);
	int (*getgeo)(struct block_device___91 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___91 *, bool);
	void (*swap_slot_free_notify)(struct block_device___91 *, long unsigned int);
	int (*report_zones)(struct gendisk___91 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___91 *, umode_t *);
	struct module___167 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___91 *, sector_t *);
};

typedef void rq_end_io_fn___90(struct request___90 *, blk_status_t);

struct request___90 {
	struct request_queue___90 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___87 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___90 *bio;
	struct bio___90 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___106 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___90 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___90 *saved_end_io;
		} flush;
	};
	struct gendisk___91 *rq_disk;
	struct block_device___91 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___90 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___87 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___90 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___171 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___183 *debugfs_dir;
	struct dentry___183 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___90;

struct elevator_mq_ops___90 {
	int (*init_sched)(struct request_queue___90 *, struct elevator_type___90 *);
	void (*exit_sched)(struct elevator_queue___90 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___87 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___87 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___87 *);
	bool (*allow_merge)(struct request_queue___90 *, struct request___90 *, struct bio___90 *);
	bool (*bio_merge)(struct request_queue___90 *, struct bio___90 *, unsigned int);
	int (*request_merge)(struct request_queue___90 *, struct request___90 **, struct bio___90 *);
	void (*request_merged)(struct request_queue___90 *, struct request___90 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___90 *, struct request___90 *, struct request___90 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___90 *);
	void (*finish_request)(struct request___90 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___87 *, struct list_head *, bool);
	struct request___90 * (*dispatch_request)(struct blk_mq_hw_ctx___87 *);
	bool (*has_work)(struct blk_mq_hw_ctx___87 *);
	void (*completed_request)(struct request___90 *, u64);
	void (*requeue_request)(struct request___90 *);
	struct request___90 * (*former_request)(struct request_queue___90 *, struct request___90 *);
	struct request___90 * (*next_request)(struct request_queue___90 *, struct request___90 *);
	void (*init_icq)(struct io_cq___90 *);
	void (*exit_icq)(struct io_cq___90 *);
};

struct elv_fs_entry___90;

struct elevator_type___90 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___90 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___90 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___167 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___90 {
	struct elevator_type___90 *type;
	void *elevator_data;
	struct kobject___171 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___90 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___90 *, char *);
	ssize_t (*store)(struct elevator_queue___90 *, const char *, size_t);
};

struct blk_mq_queue_data___87;

struct blk_mq_ops___87 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___87 *, const struct blk_mq_queue_data___87 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___87 *);
	int (*get_budget)(struct request_queue___90 *);
	void (*put_budget)(struct request_queue___90 *, int);
	void (*set_rq_budget_token)(struct request___90 *, int);
	int (*get_rq_budget_token)(struct request___90 *);
	enum blk_eh_timer_return (*timeout)(struct request___90 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___87 *);
	void (*complete)(struct request___90 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___87 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___87 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___87 *, struct request___90 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___87 *, struct request___90 *, unsigned int);
	void (*initialize_rq_fn)(struct request___90 *);
	void (*cleanup_rq)(struct request___90 *);
	bool (*busy)(struct request_queue___90 *);
	int (*map_queues)(struct blk_mq_tag_set___87 *);
	void (*show_rq)(struct seq_file___159 *, struct request___90 *);
};

struct blk_mq_tag_set___87 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___87 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___87 {
	struct request___90 *rq;
	bool last;
};

struct blkcg_policy_data___85;

struct blkcg___85 {
	struct cgroup_subsys_state___124 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___85 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___85 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___85 {
	struct blkcg___85 *blkcg;
	int plid;
};

struct blkg_policy_data___85 {
	struct blkcg_gq___85 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___74 {
	struct mem_cgroup___74 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___74 {
	struct lruvec___81 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___74 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___74 *memcg;
};

struct obj_cgroup___74 {
	struct percpu_ref refcnt;
	struct mem_cgroup___74 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___36 {
	spinlock_t *lock;
	struct sk_buff___37 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___36;

struct Qdisc_ops___36 {
	struct Qdisc_ops___36 *next;
	const struct Qdisc_class_ops___36 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___37 *, struct Qdisc___36 *, struct sk_buff___37 **);
	struct sk_buff___37 * (*dequeue)(struct Qdisc___36 *);
	struct sk_buff___37 * (*peek)(struct Qdisc___36 *);
	int (*init)(struct Qdisc___36 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___36 *);
	void (*destroy)(struct Qdisc___36 *);
	int (*change)(struct Qdisc___36 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___36 *);
	int (*change_tx_queue_len)(struct Qdisc___36 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___36 *, unsigned int);
	int (*dump)(struct Qdisc___36 *, struct sk_buff___37 *);
	int (*dump_stats)(struct Qdisc___36 *, struct gnet_dump___36 *);
	void (*ingress_block_set)(struct Qdisc___36 *, u32);
	void (*egress_block_set)(struct Qdisc___36 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___36 *);
	u32 (*egress_block_get)(struct Qdisc___36 *);
	struct module___167 *owner;
};

struct Qdisc_class_ops___36 {
	unsigned int flags;
	struct netdev_queue___36 * (*select_queue)(struct Qdisc___36 *, struct tcmsg *);
	int (*graft)(struct Qdisc___36 *, long unsigned int, struct Qdisc___36 *, struct Qdisc___36 **, struct netlink_ext_ack *);
	struct Qdisc___36 * (*leaf)(struct Qdisc___36 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___36 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___36 *, u32);
	int (*change)(struct Qdisc___36 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___36 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___36 *, struct qdisc_walker *);
	struct tcf_block___36 * (*tcf_block)(struct Qdisc___36 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___36 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___36 *, long unsigned int);
	int (*dump)(struct Qdisc___36 *, long unsigned int, struct sk_buff___37 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___36 *, long unsigned int, struct gnet_dump___36 *);
};

struct tcf_chain___36;

struct tcf_block___36 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___41 *net;
	struct Qdisc___36 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___36 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___36;

struct tcf_proto_ops___36;

struct tcf_proto___36 {
	struct tcf_proto___36 *next;
	void *root;
	int (*classify)(struct sk_buff___37 *, const struct tcf_proto___36 *, struct tcf_result___36 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___36 *ops;
	struct tcf_chain___36 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___36 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___36 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___36 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___37 *, const struct tcf_proto___36 *, struct tcf_result___36 *);
	int (*init)(struct tcf_proto___36 *);
	void (*destroy)(struct tcf_proto___36 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___36 *, u32);
	void (*put)(struct tcf_proto___36 *, void *);
	int (*change)(struct net___41 *, struct sk_buff___37 *, struct tcf_proto___36 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___36 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___36 *);
	void (*walk)(struct tcf_proto___36 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___36 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___36 *, void *);
	void (*hw_del)(struct tcf_proto___36 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___41 *, struct tcf_chain___36 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___41 *, struct tcf_proto___36 *, void *, struct sk_buff___37 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___41 *, struct tcf_proto___36 *, void *, struct sk_buff___37 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___37 *, struct net___41 *, void *);
	struct module___167 *owner;
	int flags;
};

struct tcf_chain___36 {
	struct mutex filter_chain_lock;
	struct tcf_proto___36 *filter_chain;
	struct list_head list;
	struct tcf_block___36 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___36 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___29 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___36 *prog;
};

struct pneigh_entry___29;

struct neigh_hash_table___29;

struct neigh_table___29 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___38 *, __u32 *);
	bool (*key_eq)(const struct neighbour___29 *, const void *);
	int (*constructor)(struct neighbour___29 *);
	int (*pconstructor)(struct pneigh_entry___29 *);
	void (*pdestructor)(struct pneigh_entry___29 *);
	void (*proxy_redo)(struct sk_buff___37 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___38 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___29 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___36 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___29 *nht;
	struct pneigh_entry___29 **phash_buckets;
};

struct neigh_ops___29 {
	int family;
	void (*solicit)(struct neighbour___29 *, struct sk_buff___37 *);
	void (*error_report)(struct neighbour___29 *, struct sk_buff___37 *);
	int (*output)(struct neighbour___29 *, struct sk_buff___37 *);
	int (*connected_output)(struct neighbour___29 *, struct sk_buff___37 *);
};

struct pneigh_entry___29 {
	struct pneigh_entry___29 *next;
	possible_net_t___36 net;
	struct net_device___38 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___29 {
	struct neighbour___29 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___29 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___29 *ctarget;
	struct net___41 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___29 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___29 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___19;

struct timewait_sock_ops___19;

struct proto___29 {
	void (*close)(struct sock___30 *, long int);
	int (*pre_connect)(struct sock___30 *, struct sockaddr *, int);
	int (*connect)(struct sock___30 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___30 *, int);
	struct sock___30 * (*accept)(struct sock___30 *, int, int *, bool);
	int (*ioctl)(struct sock___30 *, int, long unsigned int);
	int (*init)(struct sock___30 *);
	void (*destroy)(struct sock___30 *);
	void (*shutdown)(struct sock___30 *, int);
	int (*setsockopt)(struct sock___30 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___30 *, int, int, char *, int *);
	void (*keepalive)(struct sock___30 *, int);
	int (*compat_ioctl)(struct sock___30 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___30 *, struct msghdr___31 *, size_t);
	int (*recvmsg)(struct sock___30 *, struct msghdr___31 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___30 *, struct page___188 *, int, size_t, int);
	int (*bind)(struct sock___30 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___30 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___30 *, struct sk_buff___37 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___30 *);
	int (*hash)(struct sock___30 *);
	void (*unhash)(struct sock___30 *);
	void (*rehash)(struct sock___30 *);
	int (*get_port)(struct sock___30 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___30 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___30 *, int);
	bool (*sock_is_readable)(struct sock___30 *);
	void (*enter_memory_pressure)(struct sock___30 *);
	void (*leave_memory_pressure)(struct sock___30 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___19 *rsk_prot;
	struct timewait_sock_ops___19 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___167 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___30 *, int);
};

struct request_sock___20;

struct request_sock_ops___19 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___30 *, struct request_sock___20 *);
	void (*send_ack)(const struct sock___30 *, struct sk_buff___37 *, struct request_sock___20 *);
	void (*send_reset)(const struct sock___30 *, struct sk_buff___37 *);
	void (*destructor)(struct request_sock___20 *);
	void (*syn_ack_timeout)(const struct request_sock___20 *);
};

struct timewait_sock_ops___19 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___30 *, struct sock___30 *, void *);
	void (*twsk_destructor)(struct sock___30 *);
};

struct request_sock___20 {
	struct sock_common___29 __req_common;
	struct request_sock___20 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___19 *rsk_ops;
	struct sock___30 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___19 {
	struct in6_addr mca_addr;
	struct inet6_dev___19 *idev;
	struct ifmcaddr6___19 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct compact_control___12 {
	struct list_head freepages;
	struct list_head migratepages;
	unsigned int nr_freepages;
	unsigned int nr_migratepages;
	long unsigned int free_pfn;
	long unsigned int migrate_pfn;
	long unsigned int fast_start_pfn;
	struct zone___81 *zone;
	long unsigned int total_migrate_scanned;
	long unsigned int total_free_scanned;
	short unsigned int fast_search_fail;
	short int search_order;
	const gfp_t gfp_mask;
	int order;
	int migratetype;
	const unsigned int alloc_flags;
	const int highest_zoneidx;
	enum migrate_mode mode;
	bool ignore_skip_hint;
	bool no_set_skip_hint;
	bool ignore_block_suitable;
	bool direct_compaction;
	bool proactive_compaction;
	bool whole_zone;
	bool contended;
	bool rescan;
	bool alloc_contig;
};

enum format_type {
	FORMAT_TYPE_NONE = 0,
	FORMAT_TYPE_WIDTH = 1,
	FORMAT_TYPE_PRECISION = 2,
	FORMAT_TYPE_CHAR = 3,
	FORMAT_TYPE_STR = 4,
	FORMAT_TYPE_PTR = 5,
	FORMAT_TYPE_PERCENT_CHAR = 6,
	FORMAT_TYPE_INVALID = 7,
	FORMAT_TYPE_LONG_LONG = 8,
	FORMAT_TYPE_ULONG = 9,
	FORMAT_TYPE_LONG = 10,
	FORMAT_TYPE_UBYTE = 11,
	FORMAT_TYPE_BYTE = 12,
	FORMAT_TYPE_USHORT = 13,
	FORMAT_TYPE_SHORT = 14,
	FORMAT_TYPE_UINT = 15,
	FORMAT_TYPE_INT = 16,
	FORMAT_TYPE_SIZE_T = 17,
	FORMAT_TYPE_PTRDIFF = 18,
};

struct printf_spec {
	unsigned int type: 8;
	int field_width: 24;
	unsigned int flags: 8;
	unsigned int base: 8;
	int precision: 16;
	long: 48;
};

struct page_flags_fields {
	int width;
	int shift;
	int mask;
	const struct printf_spec *spec;
	const char *name;
};

struct minmax_sample {
	u32 t;
	u32 v;
};

struct minmax {
	struct minmax_sample s[3];
};

struct acpi_probe_entry;

typedef bool (*acpi_probe_entry_validate_subtbl)(struct acpi_subtable_header *, struct acpi_probe_entry *);

struct acpi_probe_entry {
	__u8 id[5];
	__u8 type;
	acpi_probe_entry_validate_subtbl subtable_valid;
	union {
		acpi_tbl_table_handler probe_table;
		acpi_tbl_entry_handler probe_subtbl;
	};
	kernel_ulong_t driver_data;
};

typedef int (*of_irq_init_cb_t)(struct device_node___34 *, struct device_node___34 *);

typedef int (*of_init_fn_2)(struct device_node___36 *, struct device_node___36 *);

enum al_fic_state {
	AL_FIC_UNCONFIGURED = 0,
	AL_FIC_CONFIGURED_LEVEL = 1,
	AL_FIC_CONFIGURED_RISING_EDGE = 2,
};

struct al_fic {
	void *base;
	struct irq_domain___17 *domain;
	const char *name;
	unsigned int parent_irq;
	enum al_fic_state state;
};

typedef int (*of_init_fn_2___2)(struct device_node___34 *, struct device_node___34 *);

struct armctrl_ic {
	void *base;
	void *pending[3];
	void *enable[3];
	void *disable[3];
	struct irq_domain___15 *domain;
};

struct bcm2836_arm_irqchip_intc {
	struct irq_domain___15 *domain;
	void *base;
};

struct of_phandle_args___4 {
	struct device_node___34 *np;
	int args_count;
	uint32_t args[16];
};

struct owl_sirq_params {
	bool reg_shared;
	u16 reg_offset[3];
};

struct owl_sirq_chip_data {
	const struct owl_sirq_params *params;
	void *base;
	raw_spinlock_t lock;
	u32 ext_irqs[3];
};

typedef int (*of_init_fn_2___3)(struct device_node___2 *, struct device_node___2 *);

struct tegra_ictlr_soc {
	unsigned int num_ictlrs;
};

struct tegra_ictlr_info {
	void *base[6];
	u32 cop_ier[6];
	u32 cop_iep[6];
	u32 cpu_ier[6];
	u32 cpu_iep[6];
	u32 ictlr_wake_mask[6];
};

struct sun4i_irq_chip_data {
	void *irq_base;
	struct irq_domain___15 *irq_domain;
	u32 enable_reg_offset;
	u32 mask_reg_offset;
};

struct sun6i_r_intc_variant {
	u32 first_mux_irq;
	u32 nr_mux_irqs;
	u32 mux_valid[4];
};

enum {
	SUNXI_SRC_TYPE_LEVEL_LOW = 0,
	SUNXI_SRC_TYPE_EDGE_FALLING = 1,
	SUNXI_SRC_TYPE_LEVEL_HIGH = 2,
	SUNXI_SRC_TYPE_EDGE_RISING = 3,
};

struct sunxi_sc_nmi_reg_offs {
	u32 ctrl;
	u32 pend;
	u32 enable;
};

struct acpi_madt_generic_distributor {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 gic_id;
	u64 base_address;
	u32 global_irq_base;
	u8 version;
	u8 reserved2[3];
};

enum acpi_madt_gic_version {
	ACPI_MADT_GIC_VERSION_NONE = 0,
	ACPI_MADT_GIC_VERSION_V1 = 1,
	ACPI_MADT_GIC_VERSION_V2 = 2,
	ACPI_MADT_GIC_VERSION_V3 = 3,
	ACPI_MADT_GIC_VERSION_V4 = 4,
	ACPI_MADT_GIC_VERSION_RESERVED = 5,
};

enum acpi_irq_model_id {
	ACPI_IRQ_MODEL_PIC = 0,
	ACPI_IRQ_MODEL_IOAPIC = 1,
	ACPI_IRQ_MODEL_IOSAPIC = 2,
	ACPI_IRQ_MODEL_PLATFORM = 3,
	ACPI_IRQ_MODEL_GIC = 4,
	ACPI_IRQ_MODEL_COUNT = 5,
};

struct gic_quirk {
	const char *desc;
	const char *compatible;
	bool (*init)(void *);
	u32 iidr;
	u32 mask;
};

union gic_base {
	void *common_base;
	void **percpu_base;
};

struct gic_chip_data {
	struct irq_chip___16 chip;
	union gic_base dist_base;
	union gic_base cpu_base;
	void *raw_dist_base;
	void *raw_cpu_base;
	u32 percpu_offset;
	u32 saved_spi_enable[32];
	u32 saved_spi_active[32];
	u32 saved_spi_conf[64];
	u32 saved_spi_target[255];
	u32 *saved_ppi_enable;
	u32 *saved_ppi_active;
	u32 *saved_ppi_conf;
	struct irq_domain___15 *domain;
	unsigned int gic_irqs;
};

struct clk_bulk_data {
	const char *id;
	struct clk *clk;
};

struct gic_clk_data {
	unsigned int num_clocks;
	const char * const *clocks;
};

struct gic_chip_data___2;

struct gic_chip_pm {
	struct gic_chip_data___2 *chip_data;
	const struct gic_clk_data *clk_data;
	struct clk_bulk_data *clks;
};

struct irq_desc___20;

typedef void (*irq_flow_handler_t___20)(struct irq_desc___20 *);

struct msi_desc___5;

struct irq_common_data___5 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___5 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___19;

struct irq_domain___18;

struct irq_data___19 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___5 *common;
	struct irq_chip___19 *chip;
	struct irq_domain___18 *domain;
	struct irq_data___19 *parent_data;
	void *chip_data;
};

struct irq_desc___20 {
	struct irq_common_data___5 irq_common_data;
	struct irq_data___19 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___20 handle_irq;
	struct irqaction___12 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___164 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___162 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___136;

struct device___136;

struct fwnode_handle___136 {
	struct fwnode_handle___136 *secondary;
	const struct fwnode_operations___136 *ops;
	struct device___136 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___136;

struct fwnode_endpoint___136;

struct fwnode_operations___136 {
	struct fwnode_handle___136 * (*get)(struct fwnode_handle___136 *);
	void (*put)(struct fwnode_handle___136 *);
	bool (*device_is_available)(const struct fwnode_handle___136 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___136 *, const struct device___136 *);
	bool (*property_present)(const struct fwnode_handle___136 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___136 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___136 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___136 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*get_parent)(const struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*get_next_child_node)(const struct fwnode_handle___136 *, struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*get_named_child_node)(const struct fwnode_handle___136 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___136 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___136 *);
	struct fwnode_handle___136 * (*graph_get_next_endpoint)(const struct fwnode_handle___136 *, struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*graph_get_remote_endpoint)(const struct fwnode_handle___136 *);
	struct fwnode_handle___136 * (*graph_get_port_parent)(struct fwnode_handle___136 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___136 *, struct fwnode_endpoint___136 *);
	int (*add_links)(struct fwnode_handle___136 *);
};

struct wakeup_source___136;

struct dev_pm_info___136 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___136 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___136 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___136;

struct bus_type___136;

struct device_driver___136;

struct dev_pm_domain___136;

struct device_node___38;

struct class___136;

struct dev_iommu___3;

struct device___136 {
	struct kobject___164 kobj;
	struct device___136 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___136 *type;
	struct bus_type___136 *bus;
	struct device_driver___136 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___136 power;
	struct dev_pm_domain___136 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___18 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___38 *of_node;
	struct fwnode_handle___136 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___136 *class;
	const struct attribute_group___164 **groups;
	void (*release)(struct device___136 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___3 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___136 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___136 *local_fwnode;
};

struct fwnode_reference_args___136 {
	struct fwnode_handle___136 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___38 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___136 fwnode;
	struct property___30 *properties;
	struct property___30 *deadprops;
	struct device_node___38 *parent;
	struct device_node___38 *child;
	struct device_node___38 *sibling;
	struct kobject___164 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___5 {
	struct device_node___38 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___17 {
	struct fwnode_handle___136 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___18 {
	int (*match)(struct irq_domain___18 *, struct device_node___38 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___18 *, struct irq_fwspec___17 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___18 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___18 *, unsigned int);
	int (*xlate)(struct irq_domain___18 *, struct device_node___38 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___18 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___18 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___18 *, struct irq_data___19 *, bool);
	void (*deactivate)(struct irq_domain___18 *, struct irq_data___19 *);
	int (*translate)(struct irq_domain___18 *, struct irq_fwspec___17 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___18;

struct irq_domain___18 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___18 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___136 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___18 *gc;
	struct irq_domain___18 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___19 *revmap[0];
};

struct irq_chip_generic___18;

struct irq_domain_chip_generic___18 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___18 *gc[0];
};

struct dev_pm_ops___136 {
	int (*prepare)(struct device___136 *);
	void (*complete)(struct device___136 *);
	int (*suspend)(struct device___136 *);
	int (*resume)(struct device___136 *);
	int (*freeze)(struct device___136 *);
	int (*thaw)(struct device___136 *);
	int (*poweroff)(struct device___136 *);
	int (*restore)(struct device___136 *);
	int (*suspend_late)(struct device___136 *);
	int (*resume_early)(struct device___136 *);
	int (*freeze_late)(struct device___136 *);
	int (*thaw_early)(struct device___136 *);
	int (*poweroff_late)(struct device___136 *);
	int (*restore_early)(struct device___136 *);
	int (*suspend_noirq)(struct device___136 *);
	int (*resume_noirq)(struct device___136 *);
	int (*freeze_noirq)(struct device___136 *);
	int (*thaw_noirq)(struct device___136 *);
	int (*poweroff_noirq)(struct device___136 *);
	int (*restore_noirq)(struct device___136 *);
	int (*runtime_suspend)(struct device___136 *);
	int (*runtime_resume)(struct device___136 *);
	int (*runtime_idle)(struct device___136 *);
};

struct wakeup_source___136 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___136 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___136 {
	struct dev_pm_ops___136 ops;
	int (*start)(struct device___136 *);
	void (*detach)(struct device___136 *, bool);
	int (*activate)(struct device___136 *);
	void (*sync)(struct device___136 *);
	void (*dismiss)(struct device___136 *);
};

struct iommu_ops___3;

struct bus_type___136 {
	const char *name;
	const char *dev_name;
	struct device___136 *dev_root;
	const struct attribute_group___164 **bus_groups;
	const struct attribute_group___164 **dev_groups;
	const struct attribute_group___164 **drv_groups;
	int (*match)(struct device___136 *, struct device_driver___136 *);
	int (*uevent)(struct device___136 *, struct kobj_uevent_env *);
	int (*probe)(struct device___136 *);
	void (*sync_state)(struct device___136 *);
	void (*remove)(struct device___136 *);
	void (*shutdown)(struct device___136 *);
	int (*online)(struct device___136 *);
	int (*offline)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	int (*num_vf)(struct device___136 *);
	int (*dma_configure)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
	const struct iommu_ops___3 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___136 {
	const char *name;
	struct bus_type___136 *bus;
	struct module___162 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___136 *);
	void (*sync_state)(struct device___136 *);
	int (*remove)(struct device___136 *);
	void (*shutdown)(struct device___136 *);
	int (*suspend)(struct device___136 *, pm_message_t);
	int (*resume)(struct device___136 *);
	const struct attribute_group___164 **groups;
	const struct attribute_group___164 **dev_groups;
	const struct dev_pm_ops___136 *pm;
	void (*coredump)(struct device___136 *);
	struct driver_private *p;
};

struct iommu_domain___3;

struct iommu_iotlb_gather___3;

struct iommu_device___3;

struct iommu_sva___3;

struct iommu_ops___3 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___3 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___3 *);
	int (*attach_dev)(struct iommu_domain___3 *, struct device___136 *);
	void (*detach_dev)(struct iommu_domain___3 *, struct device___136 *);
	int (*map)(struct iommu_domain___3 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___3 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___3 *, long unsigned int, size_t, struct iommu_iotlb_gather___3 *);
	size_t (*unmap_pages)(struct iommu_domain___3 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___3 *);
	void (*flush_iotlb_all)(struct iommu_domain___3 *);
	void (*iotlb_sync_map)(struct iommu_domain___3 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___3 *, struct iommu_iotlb_gather___3 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___3 *, dma_addr_t);
	struct iommu_device___3 * (*probe_device)(struct device___136 *);
	void (*release_device)(struct device___136 *);
	void (*probe_finalize)(struct device___136 *);
	struct iommu_group * (*device_group)(struct device___136 *);
	int (*enable_nesting)(struct iommu_domain___3 *);
	int (*set_pgtable_quirks)(struct iommu_domain___3 *, long unsigned int);
	void (*get_resv_regions)(struct device___136 *, struct list_head *);
	void (*put_resv_regions)(struct device___136 *, struct list_head *);
	void (*apply_resv_region)(struct device___136 *, struct iommu_domain___3 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___136 *, struct of_phandle_args___5 *);
	bool (*is_attach_deferred)(struct iommu_domain___3 *, struct device___136 *);
	bool (*dev_has_feat)(struct device___136 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___136 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___136 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___136 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___3 *, struct device___136 *);
	void (*aux_detach_dev)(struct iommu_domain___3 *, struct device___136 *);
	int (*aux_get_pasid)(struct iommu_domain___3 *, struct device___136 *);
	struct iommu_sva___3 * (*sva_bind)(struct device___136 *, struct mm_struct___183 *, void *);
	void (*sva_unbind)(struct iommu_sva___3 *);
	u32 (*sva_get_pasid)(struct iommu_sva___3 *);
	int (*page_response)(struct device___136 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___3 *, struct device___136 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___3 *, struct device___136 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___136 *, u32);
	int (*def_domain_type)(struct device___136 *);
	long unsigned int pgsize_bitmap;
	struct module___162 *owner;
};

struct device_type___136 {
	const char *name;
	const struct attribute_group___164 **groups;
	int (*uevent)(struct device___136 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___136 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___136 *);
	const struct dev_pm_ops___136 *pm;
};

struct class___136 {
	const char *name;
	struct module___162 *owner;
	const struct attribute_group___164 **class_groups;
	const struct attribute_group___164 **dev_groups;
	struct kobject___164 *dev_kobj;
	int (*dev_uevent)(struct device___136 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___136 *, umode_t *);
	void (*class_release)(struct class___136 *);
	void (*dev_release)(struct device___136 *);
	int (*shutdown_pre)(struct device___136 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___136 *);
	void (*get_ownership)(struct device___136 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___136 *pm;
	struct subsys_private *p;
};

struct iommu_fwspec___3;

struct dev_iommu___3 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___3 *fwspec;
	struct iommu_device___3 *iommu_dev;
	void *priv;
};

struct acpi_table_madt {
	struct acpi_table_header header;
	u32 address;
	u32 flags;
};

struct acpi_madt_generic_msi_frame {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 msi_frame_id;
	u64 base_address;
	u32 flags;
	u16 spi_count;
	u16 spi_base;
};

struct msi_desc___5 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___136 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___5 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___19 {
	struct device___136 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___19 *);
	void (*irq_shutdown)(struct irq_data___19 *);
	void (*irq_enable)(struct irq_data___19 *);
	void (*irq_disable)(struct irq_data___19 *);
	void (*irq_ack)(struct irq_data___19 *);
	void (*irq_mask)(struct irq_data___19 *);
	void (*irq_mask_ack)(struct irq_data___19 *);
	void (*irq_unmask)(struct irq_data___19 *);
	void (*irq_eoi)(struct irq_data___19 *);
	int (*irq_set_affinity)(struct irq_data___19 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___19 *);
	int (*irq_set_type)(struct irq_data___19 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___19 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___19 *);
	void (*irq_bus_sync_unlock)(struct irq_data___19 *);
	void (*irq_cpu_online)(struct irq_data___19 *);
	void (*irq_cpu_offline)(struct irq_data___19 *);
	void (*irq_suspend)(struct irq_data___19 *);
	void (*irq_resume)(struct irq_data___19 *);
	void (*irq_pm_shutdown)(struct irq_data___19 *);
	void (*irq_calc_mask)(struct irq_data___19 *);
	void (*irq_print_chip)(struct irq_data___19 *, struct seq_file___154 *);
	int (*irq_request_resources)(struct irq_data___19 *);
	void (*irq_release_resources)(struct irq_data___19 *);
	void (*irq_compose_msi_msg)(struct irq_data___19 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___19 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___19 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___19 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___19 *, void *);
	void (*ipi_send_single)(struct irq_data___19 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___19 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___19 *);
	void (*irq_nmi_teardown)(struct irq_data___19 *);
	long unsigned int flags;
};

struct irq_chip_type___18 {
	struct irq_chip___19 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___20 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___18 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___18 *);
	void (*resume)(struct irq_chip_generic___18 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___18 *domain;
	struct list_head list;
	struct irq_chip_type___18 chip_types[0];
};

typedef int (*iommu_fault_handler_t___3)(struct iommu_domain___3 *, struct device___136 *, long unsigned int, int, void *);

struct iommu_domain___3 {
	unsigned int type;
	const struct iommu_ops___3 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___3 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___3 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___183 *freelist;
	bool queued;
};

struct iommu_device___3 {
	struct list_head list;
	const struct iommu_ops___3 *ops;
	struct fwnode_handle___136 *fwnode;
	struct device___136 *dev;
};

struct iommu_sva___3 {
	struct device___136 *dev;
};

struct iommu_fwspec___3 {
	const struct iommu_ops___3 *ops;
	struct fwnode_handle___136 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct msi_alloc_info___2 {
	struct msi_desc___5 *desc;
	irq_hw_number_t hwirq;
	long unsigned int flags;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___2 msi_alloc_info_t___2;

struct msi_domain_info___2;

struct msi_domain_ops___2 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___2 *, msi_alloc_info_t___2 *);
	int (*msi_init)(struct irq_domain___18 *, struct msi_domain_info___2 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___2 *);
	void (*msi_free)(struct irq_domain___18 *, struct msi_domain_info___2 *, unsigned int);
	int (*msi_check)(struct irq_domain___18 *, struct msi_domain_info___2 *, struct device___136 *);
	int (*msi_prepare)(struct irq_domain___18 *, struct device___136 *, int, msi_alloc_info_t___2 *);
	void (*msi_finish)(msi_alloc_info_t___2 *, int);
	void (*set_desc)(msi_alloc_info_t___2 *, struct msi_desc___5 *);
	int (*handle_error)(struct irq_domain___18 *, struct msi_desc___5 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___18 *, struct device___136 *, int);
	void (*domain_free_irqs)(struct irq_domain___18 *, struct device___136 *);
};

struct msi_domain_info___2 {
	u32 flags;
	struct msi_domain_ops___2 *ops;
	struct irq_chip___19 *chip;
	void *chip_data;
	irq_flow_handler_t___20 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct v2m_data {
	struct list_head entry;
	struct fwnode_handle___136 *fwnode;
	struct resource res;
	void *base;
	u32 spi_start;
	u32 nr_spis;
	u32 spi_offset;
	long unsigned int *bm;
	u32 flags;
};

struct acpi_madt_generic_redistributor {
	struct acpi_subtable_header header;
	u16 reserved;
	u64 base_address;
	u32 length;
} __attribute__((packed));

struct rdists {
	struct {
		raw_spinlock_t rd_lock;
		void *rd_base;
		struct page___158 *pend_page;
		phys_addr_t phys_base;
		bool lpi_enabled;
		cpumask_t *vpe_table_mask;
		void *vpe_l1_base;
	} *rdist;
	phys_addr_t prop_table_pa;
	void *prop_table_va;
	u64 flags;
	u32 gicd_typer;
	u32 gicd_typer2;
	bool has_vlpis;
	bool has_rvpeid;
	bool has_direct_lpi;
	bool has_vpend_valid_dirty;
};

struct partition_affinity {
	cpumask_t mask;
	void *partition_id;
};

struct redist_region {
	void *redist_base;
	phys_addr_t phys_base;
	bool single_redist;
};

struct partition_desc;

struct gic_chip_data___3 {
	struct fwnode_handle___109 *fwnode;
	void *dist_base;
	struct redist_region *redist_regions;
	struct rdists rdists;
	struct irq_domain___15 *domain;
	u64 redist_stride;
	u32 nr_redist_regions;
	u64 flags;
	bool has_rss;
	unsigned int ppi_nr;
	struct partition_desc **ppi_descs;
};

enum gic_intid_range {
	SGI_RANGE = 0,
	PPI_RANGE = 1,
	SPI_RANGE = 2,
	EPPI_RANGE = 3,
	ESPI_RANGE = 4,
	LPI_RANGE = 5,
	__INVALID_RANGE__ = 6,
};

struct wakeup_source___137;

struct device___137;

struct dev_pm_info___137 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___137 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___137 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___137;

struct bus_type___137;

struct device_driver___137;

struct dev_pm_domain___137;

struct irq_domain___19;

struct device_node___39;

struct fwnode_handle___137;

struct class___137;

struct dev_iommu___4;

struct device___137 {
	struct kobject___168 kobj;
	struct device___137 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___137 *type;
	struct bus_type___137 *bus;
	struct device_driver___137 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___137 power;
	struct dev_pm_domain___137 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___19 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___39 *of_node;
	struct fwnode_handle___137 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___137 *class;
	const struct attribute_group___168 **groups;
	void (*release)(struct device___137 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___4 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___137 {
	int (*prepare)(struct device___137 *);
	void (*complete)(struct device___137 *);
	int (*suspend)(struct device___137 *);
	int (*resume)(struct device___137 *);
	int (*freeze)(struct device___137 *);
	int (*thaw)(struct device___137 *);
	int (*poweroff)(struct device___137 *);
	int (*restore)(struct device___137 *);
	int (*suspend_late)(struct device___137 *);
	int (*resume_early)(struct device___137 *);
	int (*freeze_late)(struct device___137 *);
	int (*thaw_early)(struct device___137 *);
	int (*poweroff_late)(struct device___137 *);
	int (*restore_early)(struct device___137 *);
	int (*suspend_noirq)(struct device___137 *);
	int (*resume_noirq)(struct device___137 *);
	int (*freeze_noirq)(struct device___137 *);
	int (*thaw_noirq)(struct device___137 *);
	int (*poweroff_noirq)(struct device___137 *);
	int (*restore_noirq)(struct device___137 *);
	int (*runtime_suspend)(struct device___137 *);
	int (*runtime_resume)(struct device___137 *);
	int (*runtime_idle)(struct device___137 *);
};

struct wakeup_source___137 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___137 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___137 {
	struct dev_pm_ops___137 ops;
	int (*start)(struct device___137 *);
	void (*detach)(struct device___137 *, bool);
	int (*activate)(struct device___137 *);
	void (*sync)(struct device___137 *);
	void (*dismiss)(struct device___137 *);
};

struct iommu_ops___4;

struct bus_type___137 {
	const char *name;
	const char *dev_name;
	struct device___137 *dev_root;
	const struct attribute_group___168 **bus_groups;
	const struct attribute_group___168 **dev_groups;
	const struct attribute_group___168 **drv_groups;
	int (*match)(struct device___137 *, struct device_driver___137 *);
	int (*uevent)(struct device___137 *, struct kobj_uevent_env *);
	int (*probe)(struct device___137 *);
	void (*sync_state)(struct device___137 *);
	void (*remove)(struct device___137 *);
	void (*shutdown)(struct device___137 *);
	int (*online)(struct device___137 *);
	int (*offline)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	int (*num_vf)(struct device___137 *);
	int (*dma_configure)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
	const struct iommu_ops___4 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___137 {
	const char *name;
	struct bus_type___137 *bus;
	struct module___165 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___137 *);
	void (*sync_state)(struct device___137 *);
	int (*remove)(struct device___137 *);
	void (*shutdown)(struct device___137 *);
	int (*suspend)(struct device___137 *, pm_message_t);
	int (*resume)(struct device___137 *);
	const struct attribute_group___168 **groups;
	const struct attribute_group___168 **dev_groups;
	const struct dev_pm_ops___137 *pm;
	void (*coredump)(struct device___137 *);
	struct driver_private *p;
};

struct iommu_domain___4;

struct iommu_device___4;

struct of_phandle_args___6;

struct iommu_sva___4;

struct iommu_ops___4 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___4 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___4 *);
	int (*attach_dev)(struct iommu_domain___4 *, struct device___137 *);
	void (*detach_dev)(struct iommu_domain___4 *, struct device___137 *);
	int (*map)(struct iommu_domain___4 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___4 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___4 *, long unsigned int, size_t, struct iommu_iotlb_gather___2 *);
	size_t (*unmap_pages)(struct iommu_domain___4 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___2 *);
	void (*flush_iotlb_all)(struct iommu_domain___4 *);
	void (*iotlb_sync_map)(struct iommu_domain___4 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___4 *, struct iommu_iotlb_gather___2 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___4 *, dma_addr_t);
	struct iommu_device___4 * (*probe_device)(struct device___137 *);
	void (*release_device)(struct device___137 *);
	void (*probe_finalize)(struct device___137 *);
	struct iommu_group * (*device_group)(struct device___137 *);
	int (*enable_nesting)(struct iommu_domain___4 *);
	int (*set_pgtable_quirks)(struct iommu_domain___4 *, long unsigned int);
	void (*get_resv_regions)(struct device___137 *, struct list_head *);
	void (*put_resv_regions)(struct device___137 *, struct list_head *);
	void (*apply_resv_region)(struct device___137 *, struct iommu_domain___4 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___137 *, struct of_phandle_args___6 *);
	bool (*is_attach_deferred)(struct iommu_domain___4 *, struct device___137 *);
	bool (*dev_has_feat)(struct device___137 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___137 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___137 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___137 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___4 *, struct device___137 *);
	void (*aux_detach_dev)(struct iommu_domain___4 *, struct device___137 *);
	int (*aux_get_pasid)(struct iommu_domain___4 *, struct device___137 *);
	struct iommu_sva___4 * (*sva_bind)(struct device___137 *, struct mm_struct___187 *, void *);
	void (*sva_unbind)(struct iommu_sva___4 *);
	u32 (*sva_get_pasid)(struct iommu_sva___4 *);
	int (*page_response)(struct device___137 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___4 *, struct device___137 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___4 *, struct device___137 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___137 *, u32);
	int (*def_domain_type)(struct device___137 *);
	long unsigned int pgsize_bitmap;
	struct module___165 *owner;
};

struct device_type___137 {
	const char *name;
	const struct attribute_group___168 **groups;
	int (*uevent)(struct device___137 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___137 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___137 *);
	const struct dev_pm_ops___137 *pm;
};

struct class___137 {
	const char *name;
	struct module___165 *owner;
	const struct attribute_group___168 **class_groups;
	const struct attribute_group___168 **dev_groups;
	struct kobject___168 *dev_kobj;
	int (*dev_uevent)(struct device___137 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___137 *, umode_t *);
	void (*class_release)(struct class___137 *);
	void (*dev_release)(struct device___137 *);
	int (*shutdown_pre)(struct device___137 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___137 *);
	void (*get_ownership)(struct device___137 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___137 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___19;

struct irq_domain_chip_generic___19;

struct irq_data___20;

struct irq_domain___19 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___19 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___137 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___19 *gc;
	struct irq_domain___19 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___20 *revmap[0];
};

struct fwnode_operations___137;

struct fwnode_handle___137 {
	struct fwnode_handle___137 *secondary;
	const struct fwnode_operations___137 *ops;
	struct device___137 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___39 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___137 fwnode;
	struct property___30 *properties;
	struct property___30 *deadprops;
	struct device_node___39 *parent;
	struct device_node___39 *child;
	struct device_node___39 *sibling;
	struct kobject___168 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___4;

struct dev_iommu___4 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___4 *fwspec;
	struct iommu_device___4 *iommu_dev;
	void *priv;
};

struct fwnode_reference_args___137;

struct fwnode_endpoint___137;

struct fwnode_operations___137 {
	struct fwnode_handle___137 * (*get)(struct fwnode_handle___137 *);
	void (*put)(struct fwnode_handle___137 *);
	bool (*device_is_available)(const struct fwnode_handle___137 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___137 *, const struct device___137 *);
	bool (*property_present)(const struct fwnode_handle___137 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___137 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___137 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___137 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*get_parent)(const struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*get_next_child_node)(const struct fwnode_handle___137 *, struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*get_named_child_node)(const struct fwnode_handle___137 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___137 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___137 *);
	struct fwnode_handle___137 * (*graph_get_next_endpoint)(const struct fwnode_handle___137 *, struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*graph_get_remote_endpoint)(const struct fwnode_handle___137 *);
	struct fwnode_handle___137 * (*graph_get_port_parent)(struct fwnode_handle___137 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___137 *, struct fwnode_endpoint___137 *);
	int (*add_links)(struct fwnode_handle___137 *);
};

struct fwnode_endpoint___137 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___137 *local_fwnode;
};

struct fwnode_reference_args___137 {
	struct fwnode_handle___137 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct of_phandle_args___6 {
	struct device_node___39 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___4)(struct iommu_domain___4 *, struct device___137 *, long unsigned int, int, void *);

struct iommu_domain___4 {
	unsigned int type;
	const struct iommu_ops___4 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___4 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_device___4 {
	struct list_head list;
	const struct iommu_ops___4 *ops;
	struct fwnode_handle___137 *fwnode;
	struct device___137 *dev;
};

struct iommu_sva___4 {
	struct device___137 *dev;
};

struct iommu_fwspec___4 {
	const struct iommu_ops___4 *ops;
	struct fwnode_handle___137 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct msi_desc___6;

struct msi_alloc_info___3 {
	struct msi_desc___6 *desc;
	irq_hw_number_t hwirq;
	long unsigned int flags;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

struct msi_desc___6 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___137 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___6 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

typedef struct msi_alloc_info___3 msi_alloc_info_t___3;

struct irq_desc___21;

typedef void (*irq_flow_handler_t___21)(struct irq_desc___21 *);

struct irq_common_data___6 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___6 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___20;

struct irq_data___20 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___6 *common;
	struct irq_chip___20 *chip;
	struct irq_domain___19 *domain;
	struct irq_data___20 *parent_data;
	void *chip_data;
};

struct irq_desc___21 {
	struct irq_common_data___6 irq_common_data;
	struct irq_data___20 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___21 handle_irq;
	struct irqaction___12 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___168 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___165 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_domain_info___3;

struct msi_domain_ops___3 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___3 *, msi_alloc_info_t___3 *);
	int (*msi_init)(struct irq_domain___19 *, struct msi_domain_info___3 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___3 *);
	void (*msi_free)(struct irq_domain___19 *, struct msi_domain_info___3 *, unsigned int);
	int (*msi_check)(struct irq_domain___19 *, struct msi_domain_info___3 *, struct device___137 *);
	int (*msi_prepare)(struct irq_domain___19 *, struct device___137 *, int, msi_alloc_info_t___3 *);
	void (*msi_finish)(msi_alloc_info_t___3 *, int);
	void (*set_desc)(msi_alloc_info_t___3 *, struct msi_desc___6 *);
	int (*handle_error)(struct irq_domain___19 *, struct msi_desc___6 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___19 *, struct device___137 *, int);
	void (*domain_free_irqs)(struct irq_domain___19 *, struct device___137 *);
};

struct msi_domain_info___3 {
	u32 flags;
	struct msi_domain_ops___3 *ops;
	struct irq_chip___20 *chip;
	void *chip_data;
	irq_flow_handler_t___21 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct irq_chip___20 {
	struct device___137 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___20 *);
	void (*irq_shutdown)(struct irq_data___20 *);
	void (*irq_enable)(struct irq_data___20 *);
	void (*irq_disable)(struct irq_data___20 *);
	void (*irq_ack)(struct irq_data___20 *);
	void (*irq_mask)(struct irq_data___20 *);
	void (*irq_mask_ack)(struct irq_data___20 *);
	void (*irq_unmask)(struct irq_data___20 *);
	void (*irq_eoi)(struct irq_data___20 *);
	int (*irq_set_affinity)(struct irq_data___20 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___20 *);
	int (*irq_set_type)(struct irq_data___20 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___20 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___20 *);
	void (*irq_bus_sync_unlock)(struct irq_data___20 *);
	void (*irq_cpu_online)(struct irq_data___20 *);
	void (*irq_cpu_offline)(struct irq_data___20 *);
	void (*irq_suspend)(struct irq_data___20 *);
	void (*irq_resume)(struct irq_data___20 *);
	void (*irq_pm_shutdown)(struct irq_data___20 *);
	void (*irq_calc_mask)(struct irq_data___20 *);
	void (*irq_print_chip)(struct irq_data___20 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___20 *);
	void (*irq_release_resources)(struct irq_data___20 *);
	void (*irq_compose_msi_msg)(struct irq_data___20 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___20 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___20 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___20 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___20 *, void *);
	void (*ipi_send_single)(struct irq_data___20 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___20 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___20 *);
	void (*irq_nmi_teardown)(struct irq_data___20 *);
	long unsigned int flags;
};

struct irq_chip_type___19 {
	struct irq_chip___20 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___21 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___19 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___19 *);
	void (*resume)(struct irq_chip_generic___19 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___19 *domain;
	struct list_head list;
	struct irq_chip_type___19 chip_types[0];
};

struct irq_domain_chip_generic___19 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___19 *gc[0];
};

struct irq_fwspec___18 {
	struct fwnode_handle___137 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___19 {
	int (*match)(struct irq_domain___19 *, struct device_node___39 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___19 *, struct irq_fwspec___18 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___19 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___19 *, unsigned int);
	int (*xlate)(struct irq_domain___19 *, struct device_node___39 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___19 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___19 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___19 *, struct irq_data___20 *, bool);
	void (*deactivate)(struct irq_domain___19 *, struct irq_data___20 *);
	int (*translate)(struct irq_domain___19 *, struct irq_fwspec___18 *, long unsigned int *, unsigned int *);
};

struct mbi_range {
	u32 spi_start;
	u32 nr_spis;
	long unsigned int *bm;
};

struct irq_desc___22;

typedef void (*irq_flow_handler_t___22)(struct irq_desc___22 *);

struct msi_desc___7;

struct irq_common_data___7 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___7 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___21;

struct irq_domain___20;

struct irq_data___21 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___7 *common;
	struct irq_chip___21 *chip;
	struct irq_domain___20 *domain;
	struct irq_data___21 *parent_data;
	void *chip_data;
};

struct irq_desc___22 {
	struct irq_common_data___7 irq_common_data;
	struct irq_data___21 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___22 handle_irq;
	struct irqaction___14 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___165 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___154 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___138;

struct device___138;

struct fwnode_handle___138 {
	struct fwnode_handle___138 *secondary;
	const struct fwnode_operations___138 *ops;
	struct device___138 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___138;

struct fwnode_endpoint___138;

struct fwnode_operations___138 {
	struct fwnode_handle___138 * (*get)(struct fwnode_handle___138 *);
	void (*put)(struct fwnode_handle___138 *);
	bool (*device_is_available)(const struct fwnode_handle___138 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___138 *, const struct device___138 *);
	bool (*property_present)(const struct fwnode_handle___138 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___138 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___138 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___138 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*get_parent)(const struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*get_next_child_node)(const struct fwnode_handle___138 *, struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*get_named_child_node)(const struct fwnode_handle___138 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___138 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___138 *);
	struct fwnode_handle___138 * (*graph_get_next_endpoint)(const struct fwnode_handle___138 *, struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*graph_get_remote_endpoint)(const struct fwnode_handle___138 *);
	struct fwnode_handle___138 * (*graph_get_port_parent)(struct fwnode_handle___138 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___138 *, struct fwnode_endpoint___138 *);
	int (*add_links)(struct fwnode_handle___138 *);
};

struct wakeup_source___138;

struct dev_pm_info___138 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___138 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___138 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___138;

struct bus_type___138;

struct device_driver___138;

struct dev_pm_domain___138;

struct device_node___40;

struct class___138;

struct dev_iommu___5;

struct device___138 {
	struct kobject___165 kobj;
	struct device___138 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___138 *type;
	struct bus_type___138 *bus;
	struct device_driver___138 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___138 power;
	struct dev_pm_domain___138 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___20 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___40 *of_node;
	struct fwnode_handle___138 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___138 *class;
	const struct attribute_group___165 **groups;
	void (*release)(struct device___138 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___5 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___138 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___138 *local_fwnode;
};

struct fwnode_reference_args___138 {
	struct fwnode_handle___138 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___40 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___138 fwnode;
	struct property___32 *properties;
	struct property___32 *deadprops;
	struct device_node___40 *parent;
	struct device_node___40 *child;
	struct device_node___40 *sibling;
	struct kobject___165 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___7 {
	struct device_node___40 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___19 {
	struct fwnode_handle___138 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___20 {
	int (*match)(struct irq_domain___20 *, struct device_node___40 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___20 *, struct irq_fwspec___19 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___20 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___20 *, unsigned int);
	int (*xlate)(struct irq_domain___20 *, struct device_node___40 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___20 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___20 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___20 *, struct irq_data___21 *, bool);
	void (*deactivate)(struct irq_domain___20 *, struct irq_data___21 *);
	int (*translate)(struct irq_domain___20 *, struct irq_fwspec___19 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___20;

struct irq_domain___20 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___20 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___138 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___20 *gc;
	struct irq_domain___20 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___21 *revmap[0];
};

struct irq_chip_generic___20;

struct irq_domain_chip_generic___20 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___20 *gc[0];
};

struct dev_pm_ops___138 {
	int (*prepare)(struct device___138 *);
	void (*complete)(struct device___138 *);
	int (*suspend)(struct device___138 *);
	int (*resume)(struct device___138 *);
	int (*freeze)(struct device___138 *);
	int (*thaw)(struct device___138 *);
	int (*poweroff)(struct device___138 *);
	int (*restore)(struct device___138 *);
	int (*suspend_late)(struct device___138 *);
	int (*resume_early)(struct device___138 *);
	int (*freeze_late)(struct device___138 *);
	int (*thaw_early)(struct device___138 *);
	int (*poweroff_late)(struct device___138 *);
	int (*restore_early)(struct device___138 *);
	int (*suspend_noirq)(struct device___138 *);
	int (*resume_noirq)(struct device___138 *);
	int (*freeze_noirq)(struct device___138 *);
	int (*thaw_noirq)(struct device___138 *);
	int (*poweroff_noirq)(struct device___138 *);
	int (*restore_noirq)(struct device___138 *);
	int (*runtime_suspend)(struct device___138 *);
	int (*runtime_resume)(struct device___138 *);
	int (*runtime_idle)(struct device___138 *);
};

struct wakeup_source___138 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___138 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___138 {
	struct dev_pm_ops___138 ops;
	int (*start)(struct device___138 *);
	void (*detach)(struct device___138 *, bool);
	int (*activate)(struct device___138 *);
	void (*sync)(struct device___138 *);
	void (*dismiss)(struct device___138 *);
};

struct iommu_ops___5;

struct bus_type___138 {
	const char *name;
	const char *dev_name;
	struct device___138 *dev_root;
	const struct attribute_group___165 **bus_groups;
	const struct attribute_group___165 **dev_groups;
	const struct attribute_group___165 **drv_groups;
	int (*match)(struct device___138 *, struct device_driver___138 *);
	int (*uevent)(struct device___138 *, struct kobj_uevent_env *);
	int (*probe)(struct device___138 *);
	void (*sync_state)(struct device___138 *);
	void (*remove)(struct device___138 *);
	void (*shutdown)(struct device___138 *);
	int (*online)(struct device___138 *);
	int (*offline)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	int (*num_vf)(struct device___138 *);
	int (*dma_configure)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
	const struct iommu_ops___5 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___138 {
	const char *name;
	struct bus_type___138 *bus;
	struct module___154 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___138 *);
	void (*sync_state)(struct device___138 *);
	int (*remove)(struct device___138 *);
	void (*shutdown)(struct device___138 *);
	int (*suspend)(struct device___138 *, pm_message_t);
	int (*resume)(struct device___138 *);
	const struct attribute_group___165 **groups;
	const struct attribute_group___165 **dev_groups;
	const struct dev_pm_ops___138 *pm;
	void (*coredump)(struct device___138 *);
	struct driver_private *p;
};

struct iommu_domain___5;

struct iommu_iotlb_gather___4;

struct iommu_device___5;

struct iommu_sva___5;

struct iommu_ops___5 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___5 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___5 *);
	int (*attach_dev)(struct iommu_domain___5 *, struct device___138 *);
	void (*detach_dev)(struct iommu_domain___5 *, struct device___138 *);
	int (*map)(struct iommu_domain___5 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___5 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___5 *, long unsigned int, size_t, struct iommu_iotlb_gather___4 *);
	size_t (*unmap_pages)(struct iommu_domain___5 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___4 *);
	void (*flush_iotlb_all)(struct iommu_domain___5 *);
	void (*iotlb_sync_map)(struct iommu_domain___5 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___5 *, struct iommu_iotlb_gather___4 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___5 *, dma_addr_t);
	struct iommu_device___5 * (*probe_device)(struct device___138 *);
	void (*release_device)(struct device___138 *);
	void (*probe_finalize)(struct device___138 *);
	struct iommu_group * (*device_group)(struct device___138 *);
	int (*enable_nesting)(struct iommu_domain___5 *);
	int (*set_pgtable_quirks)(struct iommu_domain___5 *, long unsigned int);
	void (*get_resv_regions)(struct device___138 *, struct list_head *);
	void (*put_resv_regions)(struct device___138 *, struct list_head *);
	void (*apply_resv_region)(struct device___138 *, struct iommu_domain___5 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___138 *, struct of_phandle_args___7 *);
	bool (*is_attach_deferred)(struct iommu_domain___5 *, struct device___138 *);
	bool (*dev_has_feat)(struct device___138 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___138 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___138 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___138 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___5 *, struct device___138 *);
	void (*aux_detach_dev)(struct iommu_domain___5 *, struct device___138 *);
	int (*aux_get_pasid)(struct iommu_domain___5 *, struct device___138 *);
	struct iommu_sva___5 * (*sva_bind)(struct device___138 *, struct mm_struct___184 *, void *);
	void (*sva_unbind)(struct iommu_sva___5 *);
	u32 (*sva_get_pasid)(struct iommu_sva___5 *);
	int (*page_response)(struct device___138 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___5 *, struct device___138 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___5 *, struct device___138 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___138 *, u32);
	int (*def_domain_type)(struct device___138 *);
	long unsigned int pgsize_bitmap;
	struct module___154 *owner;
};

struct device_type___138 {
	const char *name;
	const struct attribute_group___165 **groups;
	int (*uevent)(struct device___138 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___138 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___138 *);
	const struct dev_pm_ops___138 *pm;
};

struct class___138 {
	const char *name;
	struct module___154 *owner;
	const struct attribute_group___165 **class_groups;
	const struct attribute_group___165 **dev_groups;
	struct kobject___165 *dev_kobj;
	int (*dev_uevent)(struct device___138 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___138 *, umode_t *);
	void (*class_release)(struct class___138 *);
	void (*dev_release)(struct device___138 *);
	int (*shutdown_pre)(struct device___138 *);
	const struct kobj_ns_type_operations___28 *ns_type;
	const void * (*namespace)(struct device___138 *);
	void (*get_ownership)(struct device___138 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___138 *pm;
	struct subsys_private *p;
};

struct iommu_fwspec___5;

struct dev_iommu___5 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___5 *fwspec;
	struct iommu_device___5 *iommu_dev;
	void *priv;
};

struct acpi_madt_generic_translator {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 translation_id;
	u64 base_address;
	u32 reserved2;
} __attribute__((packed));

struct acpi_srat_gic_its_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u16 reserved;
	u32 its_id;
} __attribute__((packed));

struct msi_desc___7 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___138 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___7 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___21 {
	struct device___138 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___21 *);
	void (*irq_shutdown)(struct irq_data___21 *);
	void (*irq_enable)(struct irq_data___21 *);
	void (*irq_disable)(struct irq_data___21 *);
	void (*irq_ack)(struct irq_data___21 *);
	void (*irq_mask)(struct irq_data___21 *);
	void (*irq_mask_ack)(struct irq_data___21 *);
	void (*irq_unmask)(struct irq_data___21 *);
	void (*irq_eoi)(struct irq_data___21 *);
	int (*irq_set_affinity)(struct irq_data___21 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___21 *);
	int (*irq_set_type)(struct irq_data___21 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___21 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___21 *);
	void (*irq_bus_sync_unlock)(struct irq_data___21 *);
	void (*irq_cpu_online)(struct irq_data___21 *);
	void (*irq_cpu_offline)(struct irq_data___21 *);
	void (*irq_suspend)(struct irq_data___21 *);
	void (*irq_resume)(struct irq_data___21 *);
	void (*irq_pm_shutdown)(struct irq_data___21 *);
	void (*irq_calc_mask)(struct irq_data___21 *);
	void (*irq_print_chip)(struct irq_data___21 *, struct seq_file___155 *);
	int (*irq_request_resources)(struct irq_data___21 *);
	void (*irq_release_resources)(struct irq_data___21 *);
	void (*irq_compose_msi_msg)(struct irq_data___21 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___21 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___21 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___21 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___21 *, void *);
	void (*ipi_send_single)(struct irq_data___21 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___21 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___21 *);
	void (*irq_nmi_teardown)(struct irq_data___21 *);
	long unsigned int flags;
};

struct irq_chip_type___20 {
	struct irq_chip___21 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___22 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___20 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___20 *);
	void (*resume)(struct irq_chip_generic___20 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___20 *domain;
	struct list_head list;
	struct irq_chip_type___20 chip_types[0];
};

typedef int (*iommu_fault_handler_t___5)(struct iommu_domain___5 *, struct device___138 *, long unsigned int, int, void *);

struct iommu_domain___5 {
	unsigned int type;
	const struct iommu_ops___5 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___5 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___4 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___175 *freelist;
	bool queued;
};

struct iommu_device___5 {
	struct list_head list;
	const struct iommu_ops___5 *ops;
	struct fwnode_handle___138 *fwnode;
	struct device___138 *dev;
};

struct iommu_sva___5 {
	struct device___138 *dev;
};

struct iommu_fwspec___5 {
	const struct iommu_ops___5 *ops;
	struct fwnode_handle___138 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct msi_alloc_info___4 {
	struct msi_desc___7 *desc;
	irq_hw_number_t hwirq;
	long unsigned int flags;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___4 msi_alloc_info_t___4;

struct msi_domain_info___4;

struct msi_domain_ops___4 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___4 *, msi_alloc_info_t___4 *);
	int (*msi_init)(struct irq_domain___20 *, struct msi_domain_info___4 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___4 *);
	void (*msi_free)(struct irq_domain___20 *, struct msi_domain_info___4 *, unsigned int);
	int (*msi_check)(struct irq_domain___20 *, struct msi_domain_info___4 *, struct device___138 *);
	int (*msi_prepare)(struct irq_domain___20 *, struct device___138 *, int, msi_alloc_info_t___4 *);
	void (*msi_finish)(msi_alloc_info_t___4 *, int);
	void (*set_desc)(msi_alloc_info_t___4 *, struct msi_desc___7 *);
	int (*handle_error)(struct irq_domain___20 *, struct msi_desc___7 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___20 *, struct device___138 *, int);
	void (*domain_free_irqs)(struct irq_domain___20 *, struct device___138 *);
};

struct msi_domain_info___4 {
	u32 flags;
	struct msi_domain_ops___4 *ops;
	struct irq_chip___21 *chip;
	void *chip_data;
	irq_flow_handler_t___22 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct rdists___2 {
	struct {
		raw_spinlock_t rd_lock;
		void *rd_base;
		struct page___175 *pend_page;
		phys_addr_t phys_base;
		bool lpi_enabled;
		cpumask_t *vpe_table_mask;
		void *vpe_l1_base;
	} *rdist;
	phys_addr_t prop_table_pa;
	void *prop_table_va;
	u64 flags;
	u32 gicd_typer;
	u32 gicd_typer2;
	bool has_vlpis;
	bool has_rvpeid;
	bool has_direct_lpi;
	bool has_vpend_valid_dirty;
};

struct its_vpe___7;

struct its_vm___7 {
	struct fwnode_handle___138 *fwnode;
	struct irq_domain___20 *domain;
	struct page___175 *vprop_page;
	struct its_vpe___7 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct its_vpe___7 {
	struct page___175 *vpt_page;
	struct its_vm___7 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___138 *fwnode;
			struct irq_domain___20 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct its_vlpi_map___2 {
	struct its_vm___7 *vm;
	struct its_vpe___7 *vpe;
	u32 vintid;
	u8 properties;
	bool db_enabled;
};

enum its_vcpu_info_cmd_type {
	MAP_VLPI = 0,
	GET_VLPI = 1,
	PROP_UPDATE_VLPI = 2,
	PROP_UPDATE_AND_INV_VLPI = 3,
	SCHEDULE_VPE = 4,
	DESCHEDULE_VPE = 5,
	COMMIT_VPE = 6,
	INVALL_VPE = 7,
	PROP_UPDATE_VSGI = 8,
};

struct its_cmd_info {
	enum its_vcpu_info_cmd_type cmd_type;
	union {
		struct its_vlpi_map___2 *map;
		u8 config;
		bool req_db;
		struct {
			bool g0en;
			bool g1en;
		};
		struct {
			u8 priority;
			bool group;
		};
	};
};

struct its_collection___2 {
	u64 target_address;
	u16 col_id;
};

struct its_baser {
	void *base;
	u64 val;
	u32 order;
	u32 psz;
};

struct its_cmd_block;

struct its_device___2;

struct its_node {
	raw_spinlock_t lock;
	struct mutex dev_alloc_lock;
	struct list_head entry;
	void *base;
	void *sgir_base;
	phys_addr_t phys_base;
	struct its_cmd_block *cmd_base;
	struct its_cmd_block *cmd_write;
	struct its_baser tables[8];
	struct its_collection___2 *collections;
	struct fwnode_handle___138 *fwnode_handle;
	u64 (*get_msi_base)(struct its_device___2 *);
	u64 typer;
	u64 cbaser_save;
	u32 ctlr_save;
	u32 mpidr;
	struct list_head its_device_list;
	u64 flags;
	long unsigned int list_nr;
	int numa_node;
	unsigned int msi_domain_flags;
	u32 pre_its_base;
	int vlpi_redist_offset;
};

struct its_cmd_block {
	union {
		u64 raw_cmd[4];
		__le64 raw_cmd_le[4];
	};
};

struct event_lpi_map {
	long unsigned int *lpi_map;
	u16 *col_map;
	irq_hw_number_t lpi_base;
	int nr_lpis;
	raw_spinlock_t vlpi_lock;
	struct its_vm___7 *vm;
	struct its_vlpi_map___2 *vlpi_maps;
	int nr_vlpis;
};

struct its_device___2 {
	struct list_head entry;
	struct its_node *its;
	struct event_lpi_map event_map;
	void *itt;
	u32 nr_ites;
	u32 device_id;
	bool shared;
};

struct cpu_lpi_count {
	atomic_t managed;
	atomic_t unmanaged;
};

struct its_cmd_desc {
	union {
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_inv_cmd;
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_clear_cmd;
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_int_cmd;
		struct {
			struct its_device___2 *dev;
			int valid;
		} its_mapd_cmd;
		struct {
			struct its_collection___2 *col;
			int valid;
		} its_mapc_cmd;
		struct {
			struct its_device___2 *dev;
			u32 phys_id;
			u32 event_id;
		} its_mapti_cmd;
		struct {
			struct its_device___2 *dev;
			struct its_collection___2 *col;
			u32 event_id;
		} its_movi_cmd;
		struct {
			struct its_device___2 *dev;
			u32 event_id;
		} its_discard_cmd;
		struct {
			struct its_collection___2 *col;
		} its_invall_cmd;
		struct {
			struct its_vpe___7 *vpe;
		} its_vinvall_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_collection___2 *col;
			bool valid;
		} its_vmapp_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_device___2 *dev;
			u32 virt_id;
			u32 event_id;
			bool db_enabled;
		} its_vmapti_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_device___2 *dev;
			u32 event_id;
			bool db_enabled;
		} its_vmovi_cmd;
		struct {
			struct its_vpe___7 *vpe;
			struct its_collection___2 *col;
			u16 seq_num;
			u16 its_list;
		} its_vmovp_cmd;
		struct {
			struct its_vpe___7 *vpe;
		} its_invdb_cmd;
		struct {
			struct its_vpe___7 *vpe;
			u8 sgi;
			u8 priority;
			bool enable;
			bool group;
			bool clear;
		} its_vsgi_cmd;
	};
};

typedef struct its_collection___2 * (*its_cmd_builder_t)(struct its_node *, struct its_cmd_block *, struct its_cmd_desc *);

typedef struct its_vpe___7 * (*its_cmd_vbuilder_t)(struct its_node *, struct its_cmd_block *, struct its_cmd_desc *);

struct lpi_range {
	struct list_head entry;
	u32 base_id;
	u32 span;
};

struct its_srat_map {
	u32 numa_node;
	u32 its_id;
};

struct irq_desc___23;

typedef void (*irq_flow_handler_t___23)(struct irq_desc___23 *);

struct msi_desc___8;

struct irq_common_data___8 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___8 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___22;

struct irq_domain___21;

struct irq_data___22 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___8 *common;
	struct irq_chip___22 *chip;
	struct irq_domain___21 *domain;
	struct irq_data___22 *parent_data;
	void *chip_data;
};

struct irqaction___15;

struct irq_desc___23 {
	struct irq_common_data___8 irq_common_data;
	struct irq_data___22 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___23 handle_irq;
	struct irqaction___15 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___43 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_affinity_desc___2;

struct msi_desc___8 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___9 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc___2 *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___8 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___22 {
	struct device___9 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___22 *);
	void (*irq_shutdown)(struct irq_data___22 *);
	void (*irq_enable)(struct irq_data___22 *);
	void (*irq_disable)(struct irq_data___22 *);
	void (*irq_ack)(struct irq_data___22 *);
	void (*irq_mask)(struct irq_data___22 *);
	void (*irq_mask_ack)(struct irq_data___22 *);
	void (*irq_unmask)(struct irq_data___22 *);
	void (*irq_eoi)(struct irq_data___22 *);
	int (*irq_set_affinity)(struct irq_data___22 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___22 *);
	int (*irq_set_type)(struct irq_data___22 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___22 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___22 *);
	void (*irq_bus_sync_unlock)(struct irq_data___22 *);
	void (*irq_cpu_online)(struct irq_data___22 *);
	void (*irq_cpu_offline)(struct irq_data___22 *);
	void (*irq_suspend)(struct irq_data___22 *);
	void (*irq_resume)(struct irq_data___22 *);
	void (*irq_pm_shutdown)(struct irq_data___22 *);
	void (*irq_calc_mask)(struct irq_data___22 *);
	void (*irq_print_chip)(struct irq_data___22 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___22 *);
	void (*irq_release_resources)(struct irq_data___22 *);
	void (*irq_compose_msi_msg)(struct irq_data___22 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___22 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___22 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___22 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___22 *, void *);
	void (*ipi_send_single)(struct irq_data___22 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___22 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___22 *);
	void (*irq_nmi_teardown)(struct irq_data___22 *);
	long unsigned int flags;
};

struct irq_domain_ops___21;

struct irq_domain_chip_generic___21;

struct irq_domain___21 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___21 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___138 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___21 *gc;
	struct irq_domain___21 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___22 *revmap[0];
};

struct irqaction___15 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___15 *next;
	irq_handler_t thread_fn;
	struct task_struct___42 *thread;
	struct irqaction___15 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___21 {
	struct irq_chip___22 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___23 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___21 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___21 *);
	void (*resume)(struct irq_chip_generic___21 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___21 *domain;
	struct list_head list;
	struct irq_chip_type___21 chip_types[0];
};

struct irq_domain_chip_generic___21 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___21 *gc[0];
};

struct irq_affinity_desc___2 {
	struct cpumask mask;
	unsigned int is_managed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_domain_ops___21 {
	int (*match)(struct irq_domain___21 *, struct device_node___24 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___21 *, struct irq_fwspec___19 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___21 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___21 *, unsigned int);
	int (*xlate)(struct irq_domain___21 *, struct device_node___24 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___21 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___21 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___21 *, struct irq_data___22 *, bool);
	void (*deactivate)(struct irq_domain___21 *, struct irq_data___22 *);
	int (*translate)(struct irq_domain___21 *, struct irq_fwspec___19 *, long unsigned int *, unsigned int *);
};

struct its_vpe___8;

struct its_vm___8 {
	struct fwnode_handle___138 *fwnode;
	struct irq_domain___21 *domain;
	struct page___41 *vprop_page;
	struct its_vpe___8 **vpes;
	int nr_vpes;
	irq_hw_number_t db_lpi_base;
	long unsigned int *db_bitmap;
	int nr_db_lpis;
	u32 vlpi_count[16];
};

struct its_vpe___8 {
	struct page___41 *vpt_page;
	struct its_vm___8 *its_vm;
	atomic_t vlpi_count;
	int irq;
	irq_hw_number_t vpe_db_lpi;
	bool resident;
	bool ready;
	union {
		struct {
			int vpe_proxy_event;
			bool idai;
		};
		struct {
			struct fwnode_handle___138 *fwnode;
			struct irq_domain___21 *sgi_domain;
			struct {
				u8 priority;
				bool enabled;
				bool group;
			} sgi_config[16];
			atomic_t vmapp_count;
		};
	};
	raw_spinlock_t vpe_lock;
	u16 col_idx;
	u16 vpe_id;
	bool pending_last;
};

struct its_vlpi_map___3 {
	struct its_vm___8 *vm;
	struct its_vpe___8 *vpe;
	u32 vintid;
	u8 properties;
	bool db_enabled;
};

struct its_cmd_info___2 {
	enum its_vcpu_info_cmd_type cmd_type;
	union {
		struct its_vlpi_map___3 *map;
		u8 config;
		bool req_db;
		struct {
			bool g0en;
			bool g1en;
		};
		struct {
			u8 priority;
			bool group;
		};
	};
};

struct pci_dev___4;

struct pci_ops___4;

struct pci_bus___4 {
	struct list_head node;
	struct pci_bus___4 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___4 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___4 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___136 *bridge;
	struct device___136 dev;
	struct bin_attribute___164 *legacy_io;
	struct bin_attribute___164 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_slot___4 {
	struct pci_bus___4 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___164 kobj;
};

struct pci_driver___4;

struct pci_dev___4 {
	struct list_head bus_list;
	struct pci_bus___4 *bus;
	struct pci_bus___4 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___4 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___4 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___4 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___136 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___164 *res_attr[17];
	struct bin_attribute___164 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___164 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___4 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___4;

struct pci_driver___4 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___4 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___4 *);
	int (*suspend)(struct pci_dev___4 *, pm_message_t);
	int (*resume)(struct pci_dev___4 *);
	void (*shutdown)(struct pci_dev___4 *);
	int (*sriov_configure)(struct pci_dev___4 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___4 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___4 *);
	const struct pci_error_handlers___4 *err_handler;
	const struct attribute_group___164 **groups;
	const struct attribute_group___164 **dev_groups;
	struct device_driver___136 driver;
	struct pci_dynids dynids;
};

struct pci_ops___4 {
	int (*add_bus)(struct pci_bus___4 *);
	void (*remove_bus)(struct pci_bus___4 *);
	void * (*map_bus)(struct pci_bus___4 *, unsigned int, int);
	int (*read)(struct pci_bus___4 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___4 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___4 {
	pci_ers_result_t (*error_detected)(struct pci_dev___4 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___4 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___4 *);
	void (*reset_prepare)(struct pci_dev___4 *);
	void (*reset_done)(struct pci_dev___4 *);
	void (*resume)(struct pci_dev___4 *);
};

enum device_link_state {
	DL_STATE_NONE = 0,
	DL_STATE_DORMANT = 0,
	DL_STATE_AVAILABLE = 1,
	DL_STATE_CONSUMER_PROBE = 2,
	DL_STATE_ACTIVE = 3,
	DL_STATE_SUPPLIER_UNBIND = 4,
};

struct device_link {
	struct device___136 *supplier;
	struct list_head s_node;
	struct device___136 *consumer;
	struct list_head c_node;
	struct device___136 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fsl_mc_obj_desc {
	char type[16];
	int id;
	u16 vendor;
	u16 ver_major;
	u16 ver_minor;
	u8 irq_count;
	u8 region_count;
	u32 state;
	char label[16];
	u16 flags;
};

struct fsl_mc_io;

struct fsl_mc_device_irq;

struct fsl_mc_resource;

struct fsl_mc_device {
	struct device___136 dev;
	u64 dma_mask;
	u16 flags;
	u32 icid;
	u16 mc_handle;
	struct fsl_mc_io *mc_io;
	struct fsl_mc_obj_desc obj_desc;
	struct resource *regions;
	struct fsl_mc_device_irq **irqs;
	struct fsl_mc_resource *resource;
	struct device_link *consumer_link;
	char *driver_override;
};

enum fsl_mc_pool_type {
	FSL_MC_POOL_DPMCP = 0,
	FSL_MC_POOL_DPBP = 1,
	FSL_MC_POOL_DPCON = 2,
	FSL_MC_POOL_IRQ = 3,
	FSL_MC_NUM_POOL_TYPES = 4,
};

struct fsl_mc_resource_pool;

struct fsl_mc_resource {
	enum fsl_mc_pool_type type;
	s32 id;
	void *data;
	struct fsl_mc_resource_pool *parent_pool;
	struct list_head node;
};

struct fsl_mc_device_irq {
	struct msi_desc___5 *msi_desc;
	struct fsl_mc_device *mc_dev;
	u8 dev_irq_index;
	struct fsl_mc_resource resource;
};

struct fsl_mc_io {
	struct device___136 *dev;
	u16 flags;
	u32 portal_size;
	phys_addr_t portal_phys_addr;
	void *portal_virt_addr;
	struct fsl_mc_device *dpmcp_dev;
	union {
		struct mutex mutex;
		raw_spinlock_t spinlock;
	};
};

struct partition_desc___2 {
	int nr_parts;
	struct partition_affinity *parts;
	struct irq_domain___18 *domain;
	struct irq_desc___20 *chained_desc;
	long unsigned int *bitmap;
	struct irq_domain_ops___18 ops;
};

struct acpi_device___2;

struct acpi_hotplug_profile___2 {
	struct kobject___164 kobj;
	int (*scan_dependent)(struct acpi_device___2 *);
	void (*notify_online)(struct acpi_device___2 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___2 {
	void (*func)(struct acpi_device_wakeup_context___2 *);
	struct device___136 *dev;
};

struct acpi_device_wakeup___2 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___2 context;
	struct wakeup_source___136 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___2;

struct acpi_hotplug_context___2;

struct acpi_driver___2;

struct acpi_device___2 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___136 fwnode;
	struct acpi_device___2 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___2 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___2 *handler;
	struct acpi_hotplug_context___2 *hp;
	struct acpi_driver___2 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___136 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___2 *);
};

struct acpi_scan_handler___2 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___2 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___2 *);
	void (*bind)(struct device___136 *);
	void (*unbind)(struct device___136 *);
	struct acpi_hotplug_profile___2 hotplug;
};

struct acpi_hotplug_context___2 {
	struct acpi_device___2 *self;
	int (*notify)(struct acpi_device___2 *, u32);
	void (*uevent)(struct acpi_device___2 *, u32);
	void (*fixup)(struct acpi_device___2 *);
};

typedef int (*acpi_op_add___2)(struct acpi_device___2 *);

typedef int (*acpi_op_remove___2)(struct acpi_device___2 *);

typedef void (*acpi_op_notify___2)(struct acpi_device___2 *, u32);

struct acpi_device_ops___2 {
	acpi_op_add___2 add;
	acpi_op_remove___2 remove;
	acpi_op_notify___2 notify;
};

struct acpi_driver___2 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___2 ops;
	struct device_driver___136 drv;
	struct module___162 *owner;
};

typedef void (*irq_write_msi_msg_t)(struct msi_desc___5 *, struct msi_msg *);

struct mbigen_device {
	struct platform_device *pdev;
	void *base;
};

struct platform_device___5 {
	const char *name;
	int id;
	bool id_auto;
	struct device___138 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___3 {
	int (*probe)(struct platform_device___5 *);
	int (*remove)(struct platform_device___5 *);
	void (*shutdown)(struct platform_device___5 *);
	int (*suspend)(struct platform_device___5 *, pm_message_t);
	int (*resume)(struct platform_device___5 *);
	struct device_driver___138 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct irqc_priv;

struct irqc_irq {
	int hw_irq;
	int requested_irq;
	struct irqc_priv *p;
};

struct irqc_priv {
	void *iomem;
	void *cpu_int_base;
	struct irqc_irq irq[32];
	unsigned int number_of_irqs;
	struct device___138 *dev;
	struct irq_chip_generic___20 *gc;
	struct irq_domain___20 *irq_domain;
	atomic_t wakeup_path;
};

typedef int (*of_init_fn_2___4)(struct device_node___40 *, struct device_node___40 *);

struct xintc_irq_chip {
	void *base;
	struct irq_domain___20 *root_domain;
	u32 intr_mask;
	u32 nr_irq;
};

typedef int (*of_init_fn_2___5)(struct device_node___38 *, struct device_node___38 *);

struct bcm7038_l1_cpu;

struct bcm7038_l1_chip {
	raw_spinlock_t lock;
	unsigned int n_words;
	struct irq_domain___18 *domain;
	struct bcm7038_l1_cpu *cpus[256];
	struct list_head list;
	u32 wake_mask[8];
	u32 irq_fwd_mask[8];
	u8 affinity[256];
};

struct bcm7038_l1_cpu {
	void *map_base;
	u32 mask_cache[0];
};

struct brcmstb_intc_init_params {
	irq_flow_handler_t___20 handler;
	int cpu_status;
	int cpu_clear;
	int cpu_mask_status;
	int cpu_mask_set;
	int cpu_mask_clear;
};

struct brcmstb_l2_intc_data {
	struct irq_domain___18 *domain;
	struct irq_chip_generic___18 *gc;
	int status_offset;
	int mask_offset;
	bool can_wake;
	u32 saved_mask;
};

struct mtk_sysirq_chip_data {
	raw_spinlock_t lock;
	u32 nr_intpol_bases;
	void **intpol_bases;
	u32 *intpol_words;
	u8 *intpol_idx;
	u16 *which_word;
};

struct mtk_cirq_chip_data {
	void *base;
	unsigned int ext_irq_start;
	unsigned int ext_irq_end;
	struct irq_domain___18 *domain;
};

struct gpcv2_irqchip_data {
	struct raw_spinlock rlock;
	void *gpc_base;
	u32 wakeup_sources[4];
	u32 saved_irq_mask[4];
	u32 cpu2wakeup;
};

struct fwnode_operations___139;

struct device___139;

struct fwnode_handle___139 {
	struct fwnode_handle___139 *secondary;
	const struct fwnode_operations___139 *ops;
	struct device___139 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___139;

struct fwnode_endpoint___139;

struct fwnode_operations___139 {
	struct fwnode_handle___139 * (*get)(struct fwnode_handle___139 *);
	void (*put)(struct fwnode_handle___139 *);
	bool (*device_is_available)(const struct fwnode_handle___139 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___139 *, const struct device___139 *);
	bool (*property_present)(const struct fwnode_handle___139 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___139 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___139 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___139 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*get_parent)(const struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*get_next_child_node)(const struct fwnode_handle___139 *, struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*get_named_child_node)(const struct fwnode_handle___139 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___139 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___139 *);
	struct fwnode_handle___139 * (*graph_get_next_endpoint)(const struct fwnode_handle___139 *, struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*graph_get_remote_endpoint)(const struct fwnode_handle___139 *);
	struct fwnode_handle___139 * (*graph_get_port_parent)(struct fwnode_handle___139 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___139 *, struct fwnode_endpoint___139 *);
	int (*add_links)(struct fwnode_handle___139 *);
};

struct wakeup_source___139;

struct dev_pm_info___139 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___139 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___139 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___139;

struct bus_type___139;

struct device_driver___139;

struct dev_pm_domain___139;

struct irq_domain___22;

struct device_node___41;

struct class___139;

struct device___139 {
	struct kobject___41 kobj;
	struct device___139 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___139 *type;
	struct bus_type___139 *bus;
	struct device_driver___139 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___139 power;
	struct dev_pm_domain___139 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___22 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___41 *of_node;
	struct fwnode_handle___139 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___139 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___139 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___139 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___139 *local_fwnode;
};

struct fwnode_reference_args___139 {
	struct fwnode_handle___139 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_desc___24;

typedef void (*irq_flow_handler_t___24)(struct irq_desc___24 *);

struct msi_desc___9;

struct irq_common_data___9 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___9 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___23;

struct irq_data___23 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___23 *chip;
	struct irq_domain___22 *domain;
	struct irq_data___23 *parent_data;
	void *chip_data;
};

struct irq_desc___24 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___23 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___24 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___41 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_desc___9 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___139 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___9 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___23 {
	struct device___139 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___23 *);
	void (*irq_shutdown)(struct irq_data___23 *);
	void (*irq_enable)(struct irq_data___23 *);
	void (*irq_disable)(struct irq_data___23 *);
	void (*irq_ack)(struct irq_data___23 *);
	void (*irq_mask)(struct irq_data___23 *);
	void (*irq_mask_ack)(struct irq_data___23 *);
	void (*irq_unmask)(struct irq_data___23 *);
	void (*irq_eoi)(struct irq_data___23 *);
	int (*irq_set_affinity)(struct irq_data___23 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___23 *);
	int (*irq_set_type)(struct irq_data___23 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___23 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___23 *);
	void (*irq_bus_sync_unlock)(struct irq_data___23 *);
	void (*irq_cpu_online)(struct irq_data___23 *);
	void (*irq_cpu_offline)(struct irq_data___23 *);
	void (*irq_suspend)(struct irq_data___23 *);
	void (*irq_resume)(struct irq_data___23 *);
	void (*irq_pm_shutdown)(struct irq_data___23 *);
	void (*irq_calc_mask)(struct irq_data___23 *);
	void (*irq_print_chip)(struct irq_data___23 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___23 *);
	void (*irq_release_resources)(struct irq_data___23 *);
	void (*irq_compose_msi_msg)(struct irq_data___23 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___23 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___23 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___23 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___23 *, void *);
	void (*ipi_send_single)(struct irq_data___23 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___23 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___23 *);
	void (*irq_nmi_teardown)(struct irq_data___23 *);
	long unsigned int flags;
};

struct irq_domain_ops___22;

struct irq_domain_chip_generic___22;

struct irq_domain___22 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___22 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___139 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___22 *gc;
	struct irq_domain___22 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___23 *revmap[0];
};

struct irq_chip_type___22 {
	struct irq_chip___23 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___24 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___22 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___22 *);
	void (*resume)(struct irq_chip_generic___22 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___22 *domain;
	struct list_head list;
	struct irq_chip_type___22 chip_types[0];
};

struct irq_domain_chip_generic___22 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___22 *gc[0];
};

struct device_node___41 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___139 fwnode;
	struct property___19 *properties;
	struct property___19 *deadprops;
	struct device_node___41 *parent;
	struct device_node___41 *child;
	struct device_node___41 *sibling;
	struct kobject___41 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___20 {
	struct fwnode_handle___139 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___22 {
	int (*match)(struct irq_domain___22 *, struct device_node___41 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___22 *, struct irq_fwspec___20 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___22 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___22 *, unsigned int);
	int (*xlate)(struct irq_domain___22 *, struct device_node___41 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___22 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___22 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___22 *, struct irq_data___23 *, bool);
	void (*deactivate)(struct irq_domain___22 *, struct irq_data___23 *);
	int (*translate)(struct irq_domain___22 *, struct irq_fwspec___20 *, long unsigned int *, unsigned int *);
};

struct msi_alloc_info___5 {
	struct msi_desc___9 *desc;
	irq_hw_number_t hwirq;
	long unsigned int flags;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___5 msi_alloc_info_t___5;

struct msi_domain_info___5;

struct msi_domain_ops___5 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___5 *, msi_alloc_info_t___5 *);
	int (*msi_init)(struct irq_domain___22 *, struct msi_domain_info___5 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___5 *);
	void (*msi_free)(struct irq_domain___22 *, struct msi_domain_info___5 *, unsigned int);
	int (*msi_check)(struct irq_domain___22 *, struct msi_domain_info___5 *, struct device___139 *);
	int (*msi_prepare)(struct irq_domain___22 *, struct device___139 *, int, msi_alloc_info_t___5 *);
	void (*msi_finish)(msi_alloc_info_t___5 *, int);
	void (*set_desc)(msi_alloc_info_t___5 *, struct msi_desc___9 *);
	int (*handle_error)(struct irq_domain___22 *, struct msi_desc___9 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___22 *, struct device___139 *, int);
	void (*domain_free_irqs)(struct irq_domain___22 *, struct device___139 *);
};

struct msi_domain_info___5 {
	u32 flags;
	struct msi_domain_ops___5 *ops;
	struct irq_chip___23 *chip;
	void *chip_data;
	irq_flow_handler_t___24 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

struct dev_pm_ops___139 {
	int (*prepare)(struct device___139 *);
	void (*complete)(struct device___139 *);
	int (*suspend)(struct device___139 *);
	int (*resume)(struct device___139 *);
	int (*freeze)(struct device___139 *);
	int (*thaw)(struct device___139 *);
	int (*poweroff)(struct device___139 *);
	int (*restore)(struct device___139 *);
	int (*suspend_late)(struct device___139 *);
	int (*resume_early)(struct device___139 *);
	int (*freeze_late)(struct device___139 *);
	int (*thaw_early)(struct device___139 *);
	int (*poweroff_late)(struct device___139 *);
	int (*restore_early)(struct device___139 *);
	int (*suspend_noirq)(struct device___139 *);
	int (*resume_noirq)(struct device___139 *);
	int (*freeze_noirq)(struct device___139 *);
	int (*thaw_noirq)(struct device___139 *);
	int (*poweroff_noirq)(struct device___139 *);
	int (*restore_noirq)(struct device___139 *);
	int (*runtime_suspend)(struct device___139 *);
	int (*runtime_resume)(struct device___139 *);
	int (*runtime_idle)(struct device___139 *);
};

struct wakeup_source___139 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___139 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___139 {
	struct dev_pm_ops___139 ops;
	int (*start)(struct device___139 *);
	void (*detach)(struct device___139 *, bool);
	int (*activate)(struct device___139 *);
	void (*sync)(struct device___139 *);
	void (*dismiss)(struct device___139 *);
};

struct bus_type___139 {
	const char *name;
	const char *dev_name;
	struct device___139 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___139 *, struct device_driver___139 *);
	int (*uevent)(struct device___139 *, struct kobj_uevent_env *);
	int (*probe)(struct device___139 *);
	void (*sync_state)(struct device___139 *);
	void (*remove)(struct device___139 *);
	void (*shutdown)(struct device___139 *);
	int (*online)(struct device___139 *);
	int (*offline)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	int (*num_vf)(struct device___139 *);
	int (*dma_configure)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___139 {
	const char *name;
	struct bus_type___139 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___139 *);
	void (*sync_state)(struct device___139 *);
	int (*remove)(struct device___139 *);
	void (*shutdown)(struct device___139 *);
	int (*suspend)(struct device___139 *, pm_message_t);
	int (*resume)(struct device___139 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___139 *pm;
	void (*coredump)(struct device___139 *);
	struct driver_private *p;
};

struct device_type___139 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___139 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___139 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___139 *);
	const struct dev_pm_ops___139 *pm;
};

struct class___139 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___139 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___139 *, umode_t *);
	void (*class_release)(struct class___139 *);
	void (*dev_release)(struct device___139 *);
	int (*shutdown_pre)(struct device___139 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___139 *);
	void (*get_ownership)(struct device___139 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___139 *pm;
	struct subsys_private *p;
};

struct platform_device___6 {
	const char *name;
	int id;
	bool id_auto;
	struct device___139 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___4 {
	int (*probe)(struct platform_device___6 *);
	int (*remove)(struct platform_device___6 *);
	void (*shutdown)(struct platform_device___6 *);
	int (*suspend)(struct platform_device___6 *, pm_message_t);
	int (*resume)(struct platform_device___6 *);
	struct device_driver___139 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct mvebu_gicp_spi_range {
	unsigned int start;
	unsigned int count;
};

struct mvebu_gicp {
	struct mvebu_gicp_spi_range *spi_ranges;
	unsigned int spi_ranges_cnt;
	unsigned int spi_cnt;
	long unsigned int *spi_bitmap;
	spinlock_t spi_lock;
	struct resource *res;
	struct device___139 *dev;
};

struct mvebu_icu_subset_data {
	unsigned int icu_group;
	unsigned int offset_set_ah;
	unsigned int offset_set_al;
	unsigned int offset_clr_ah;
	unsigned int offset_clr_al;
};

struct mvebu_icu {
	void *base;
	struct device___136 *dev;
};

struct mvebu_icu_msi_data {
	struct mvebu_icu *icu;
	atomic_t initialized;
	const struct mvebu_icu_subset_data *subset_data;
};

struct mvebu_icu_irq_data {
	struct mvebu_icu *icu;
	unsigned int icu_group;
	unsigned int type;
};

struct odmi_data {
	struct resource res;
	void *base;
	unsigned int spi_base;
};

struct mvebu_pic {
	void *base;
	u32 parent_irq;
	struct irq_domain___18 *domain;
	struct irq_chip___19 irq_chip;
};

struct mvebu_sei_interrupt_range {
	u32 first;
	u32 size;
};

struct mvebu_sei_caps {
	struct mvebu_sei_interrupt_range ap_range;
	struct mvebu_sei_interrupt_range cp_range;
};

struct mvebu_sei {
	struct device___136 *dev;
	void *base;
	struct resource *res;
	struct irq_domain___18 *sei_domain;
	struct irq_domain___18 *ap_domain;
	struct irq_domain___18 *cp_domain;
	const struct mvebu_sei_caps *caps;
	struct mutex cp_msi_lock;
	long unsigned int cp_msi_bitmap[1];
	raw_spinlock_t mask_lock;
};

struct regmap;

struct ls_extirq_data {
	struct regmap *syscon;
	u32 intpcr;
	bool is_ls1021a_or_ls1043a;
	u32 nirq;
	struct irq_fwspec___17 map[12];
};

struct platform_device___7 {
	const char *name;
	int id;
	bool id_auto;
	struct device___137 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___5 {
	int (*probe)(struct platform_device___7 *);
	int (*remove)(struct platform_device___7 *);
	void (*shutdown)(struct platform_device___7 *);
	int (*suspend)(struct platform_device___7 *, pm_message_t);
	int (*resume)(struct platform_device___7 *);
	struct device_driver___137 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct ls_scfg_msi_cfg {
	u32 ibs_shift;
	u32 msir_irqs;
	u32 msir_base;
};

struct ls_scfg_msi;

struct ls_scfg_msir {
	struct ls_scfg_msi *msi_data;
	unsigned int index;
	unsigned int gic_irq;
	unsigned int bit_start;
	unsigned int bit_end;
	unsigned int srs;
	void *reg;
};

struct ls_scfg_msi {
	spinlock_t lock;
	struct platform_device___7 *pdev;
	struct irq_domain___19 *parent;
	struct irq_domain___19 *msi_domain;
	void *regs;
	phys_addr_t msiir_addr;
	struct ls_scfg_msi_cfg *cfg;
	u32 msir_num;
	struct ls_scfg_msir *msir;
	u32 irqs_num;
	long unsigned int *used;
};

struct acpi_resource_irq {
	u8 descriptor_length;
	u8 triggering;
	u8 polarity;
	u8 shareable;
	u8 wake_capable;
	u8 interrupt_count;
	u8 interrupts[1];
};

struct acpi_resource_dma {
	u8 type;
	u8 bus_master;
	u8 transfer;
	u8 channel_count;
	u8 channels[1];
};

struct acpi_resource_start_dependent {
	u8 descriptor_length;
	u8 compatibility_priority;
	u8 performance_robustness;
};

struct acpi_resource_io {
	u8 io_decode;
	u8 alignment;
	u8 address_length;
	u16 minimum;
	u16 maximum;
} __attribute__((packed));

struct acpi_resource_fixed_io {
	u16 address;
	u8 address_length;
} __attribute__((packed));

struct acpi_resource_fixed_dma {
	u16 request_lines;
	u16 channels;
	u8 width;
} __attribute__((packed));

struct acpi_resource_vendor {
	u16 byte_length;
	u8 byte_data[1];
} __attribute__((packed));

struct acpi_resource_vendor_typed {
	u16 byte_length;
	u8 uuid_subtype;
	u8 uuid[16];
	u8 byte_data[1];
};

struct acpi_resource_end_tag {
	u8 checksum;
};

struct acpi_resource_memory24 {
	u8 write_protect;
	u16 minimum;
	u16 maximum;
	u16 alignment;
	u16 address_length;
} __attribute__((packed));

struct acpi_resource_memory32 {
	u8 write_protect;
	u32 minimum;
	u32 maximum;
	u32 alignment;
	u32 address_length;
} __attribute__((packed));

struct acpi_resource_fixed_memory32 {
	u8 write_protect;
	u32 address;
	u32 address_length;
} __attribute__((packed));

struct acpi_memory_attribute {
	u8 write_protect;
	u8 caching;
	u8 range_type;
	u8 translation;
};

struct acpi_io_attribute {
	u8 range_type;
	u8 translation;
	u8 translation_type;
	u8 reserved1;
};

union acpi_resource_attribute {
	struct acpi_memory_attribute mem;
	struct acpi_io_attribute io;
	u8 type_specific;
};

struct acpi_resource_label {
	u16 string_length;
	char *string_ptr;
} __attribute__((packed));

struct acpi_resource_source {
	u8 index;
	u16 string_length;
	char *string_ptr;
} __attribute__((packed));

struct acpi_address16_attribute {
	u16 granularity;
	u16 minimum;
	u16 maximum;
	u16 translation_offset;
	u16 address_length;
};

struct acpi_address32_attribute {
	u32 granularity;
	u32 minimum;
	u32 maximum;
	u32 translation_offset;
	u32 address_length;
};

struct acpi_address64_attribute {
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
};

struct acpi_resource_address {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
};

struct acpi_resource_address16 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	struct acpi_address16_attribute address;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_address32 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	struct acpi_address32_attribute address;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_address64 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	struct acpi_address64_attribute address;
	struct acpi_resource_source resource_source;
} __attribute__((packed));

struct acpi_resource_extended_address64 {
	u8 resource_type;
	u8 producer_consumer;
	u8 decode;
	u8 min_address_fixed;
	u8 max_address_fixed;
	union acpi_resource_attribute info;
	u8 revision_ID;
	struct acpi_address64_attribute address;
	u64 type_specific;
} __attribute__((packed));

struct acpi_resource_extended_irq {
	u8 producer_consumer;
	u8 triggering;
	u8 polarity;
	u8 shareable;
	u8 wake_capable;
	u8 interrupt_count;
	struct acpi_resource_source resource_source;
	u32 interrupts[1];
} __attribute__((packed));

struct acpi_resource_generic_register {
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_resource_gpio {
	u8 revision_id;
	u8 connection_type;
	u8 producer_consumer;
	u8 pin_config;
	u8 shareable;
	u8 wake_capable;
	u8 io_restriction;
	u8 triggering;
	u8 polarity;
	u16 drive_strength;
	u16 debounce_timeout;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_common_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_i2c_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 access_mode;
	u16 slave_address;
	u32 connection_speed;
} __attribute__((packed));

struct acpi_resource_spi_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 wire_mode;
	u8 device_polarity;
	u8 data_bit_length;
	u8 clock_phase;
	u8 clock_polarity;
	u16 device_selection;
	u32 connection_speed;
} __attribute__((packed));

struct acpi_resource_uart_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 endian;
	u8 data_bits;
	u8 stop_bits;
	u8 flow_control;
	u8 parity;
	u8 lines_enabled;
	u16 rx_fifo_size;
	u16 tx_fifo_size;
	u32 default_baud_rate;
} __attribute__((packed));

struct acpi_resource_csi2_serialbus {
	u8 revision_id;
	u8 type;
	u8 producer_consumer;
	u8 slave_mode;
	u8 connection_sharing;
	u8 type_revision_id;
	u16 type_data_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u8 *vendor_data;
	u8 local_port_instance;
	u8 phy_type;
} __attribute__((packed));

struct acpi_resource_pin_function {
	u8 revision_id;
	u8 pin_config;
	u8 shareable;
	u16 function_number;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_config {
	u8 revision_id;
	u8 producer_consumer;
	u8 shareable;
	u8 pin_config_type;
	u32 pin_config_value;
	u16 pin_table_length;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	u16 *pin_table;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_group {
	u8 revision_id;
	u8 producer_consumer;
	u16 pin_table_length;
	u16 vendor_length;
	u16 *pin_table;
	struct acpi_resource_label resource_label;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_group_function {
	u8 revision_id;
	u8 producer_consumer;
	u8 shareable;
	u16 function_number;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	struct acpi_resource_label resource_source_label;
	u8 *vendor_data;
} __attribute__((packed));

struct acpi_resource_pin_group_config {
	u8 revision_id;
	u8 producer_consumer;
	u8 shareable;
	u8 pin_config_type;
	u32 pin_config_value;
	u16 vendor_length;
	struct acpi_resource_source resource_source;
	struct acpi_resource_label resource_source_label;
	u8 *vendor_data;
} __attribute__((packed));

union acpi_resource_data {
	struct acpi_resource_irq irq;
	struct acpi_resource_dma dma;
	struct acpi_resource_start_dependent start_dpf;
	struct acpi_resource_io io;
	struct acpi_resource_fixed_io fixed_io;
	struct acpi_resource_fixed_dma fixed_dma;
	struct acpi_resource_vendor vendor;
	struct acpi_resource_vendor_typed vendor_typed;
	struct acpi_resource_end_tag end_tag;
	struct acpi_resource_memory24 memory24;
	struct acpi_resource_memory32 memory32;
	struct acpi_resource_fixed_memory32 fixed_memory32;
	struct acpi_resource_address16 address16;
	struct acpi_resource_address32 address32;
	struct acpi_resource_address64 address64;
	struct acpi_resource_extended_address64 ext_address64;
	struct acpi_resource_extended_irq extended_irq;
	struct acpi_resource_generic_register generic_reg;
	struct acpi_resource_gpio gpio;
	struct acpi_resource_i2c_serialbus i2c_serial_bus;
	struct acpi_resource_spi_serialbus spi_serial_bus;
	struct acpi_resource_uart_serialbus uart_serial_bus;
	struct acpi_resource_csi2_serialbus csi2_serial_bus;
	struct acpi_resource_common_serialbus common_serial_bus;
	struct acpi_resource_pin_function pin_function;
	struct acpi_resource_pin_config pin_config;
	struct acpi_resource_pin_group pin_group;
	struct acpi_resource_pin_group_function pin_group_function;
	struct acpi_resource_pin_group_config pin_group_config;
	struct acpi_resource_address address;
};

struct acpi_resource {
	u32 type;
	u32 length;
	union acpi_resource_data data;
} __attribute__((packed));

typedef acpi_status (*acpi_walk_resource_callback)(struct acpi_resource *, void *);

struct combiner_reg {
	void *addr;
	long unsigned int enabled;
};

struct combiner {
	struct irq_domain___18 *domain;
	int parent_irq;
	u32 nirqs;
	u32 nregs;
	struct combiner_reg regs[0];
};

struct get_registers_context {
	struct device___136 *dev;
	struct combiner *combiner;
	int err;
};

struct exiu_irq_data {
	void *base;
	u32 spi_base;
};

struct meson_gpio_irq_controller;

struct irq_ctl_ops {
	void (*gpio_irq_sel_pin)(struct meson_gpio_irq_controller *, unsigned int, long unsigned int);
	void (*gpio_irq_init)(struct meson_gpio_irq_controller *);
};

struct meson_gpio_irq_params;

struct meson_gpio_irq_controller {
	const struct meson_gpio_irq_params *params;
	void *base;
	u32 channel_irqs[8];
	long unsigned int channel_map[1];
	spinlock_t lock;
};

struct meson_gpio_irq_params {
	unsigned int nr_hwirq;
	bool support_edge_both;
	unsigned int edge_both_offset;
	unsigned int edge_single_offset;
	unsigned int pol_low_offset;
	unsigned int pin_sel_mask;
	struct irq_ctl_ops ops;
};

struct pdc_pin_region {
	u32 pin_base;
	u32 parent_base;
	u32 cnt;
};

enum pdc_irq_config_bits {
	PDC_LEVEL_LOW = 0,
	PDC_EDGE_FALLING = 2,
	PDC_LEVEL_HIGH = 4,
	PDC_EDGE_RISING = 6,
	PDC_EDGE_DUAL = 7,
};

struct platform_driver___6 {
	int (*probe)(struct platform_device___4 *);
	int (*remove)(struct platform_device___4 *);
	void (*shutdown)(struct platform_device___4 *);
	int (*suspend)(struct platform_device___4 *, pm_message_t);
	int (*resume)(struct platform_device___4 *);
	struct device_driver___38 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct irqsteer_data {
	void *regs;
	struct clk *ipg_clk;
	int irq[8];
	int irq_count;
	raw_spinlock_t lock;
	int reg_num;
	int channel;
	struct irq_domain___13 *domain;
	u32 *saved_reg;
};

struct intmux_irqchip_data {
	struct irq_chip___13 chip;
	u32 saved_reg;
	int chanidx;
	int irq;
	struct irq_domain___13 *domain;
};

struct intmux_data {
	raw_spinlock_t lock;
	void *regs;
	struct clk *ipg_clk;
	int channum;
	struct intmux_irqchip_data irqchip_data[0];
};

struct ti_sci_version_info {
	u8 abi_major;
	u8 abi_minor;
	u16 firmware_revision;
	char firmware_description[32];
};

struct ti_sci_handle;

struct ti_sci_core_ops {
	int (*reboot_device)(const struct ti_sci_handle *);
};

struct ti_sci_dev_ops {
	int (*get_device)(const struct ti_sci_handle *, u32);
	int (*get_device_exclusive)(const struct ti_sci_handle *, u32);
	int (*idle_device)(const struct ti_sci_handle *, u32);
	int (*idle_device_exclusive)(const struct ti_sci_handle *, u32);
	int (*put_device)(const struct ti_sci_handle *, u32);
	int (*is_valid)(const struct ti_sci_handle *, u32);
	int (*get_context_loss_count)(const struct ti_sci_handle *, u32, u32 *);
	int (*is_idle)(const struct ti_sci_handle *, u32, bool *);
	int (*is_stop)(const struct ti_sci_handle *, u32, bool *, bool *);
	int (*is_on)(const struct ti_sci_handle *, u32, bool *, bool *);
	int (*is_transitioning)(const struct ti_sci_handle *, u32, bool *);
	int (*set_device_resets)(const struct ti_sci_handle *, u32, u32);
	int (*get_device_resets)(const struct ti_sci_handle *, u32, u32 *);
};

struct ti_sci_clk_ops {
	int (*get_clock)(const struct ti_sci_handle *, u32, u32, bool, bool, bool);
	int (*idle_clock)(const struct ti_sci_handle *, u32, u32);
	int (*put_clock)(const struct ti_sci_handle *, u32, u32);
	int (*is_auto)(const struct ti_sci_handle *, u32, u32, bool *);
	int (*is_on)(const struct ti_sci_handle *, u32, u32, bool *, bool *);
	int (*is_off)(const struct ti_sci_handle *, u32, u32, bool *, bool *);
	int (*set_parent)(const struct ti_sci_handle *, u32, u32, u32);
	int (*get_parent)(const struct ti_sci_handle *, u32, u32, u32 *);
	int (*get_num_parents)(const struct ti_sci_handle *, u32, u32, u32 *);
	int (*get_best_match_freq)(const struct ti_sci_handle *, u32, u32, u64, u64, u64, u64 *);
	int (*set_freq)(const struct ti_sci_handle *, u32, u32, u64, u64, u64);
	int (*get_freq)(const struct ti_sci_handle *, u32, u32, u64 *);
};

struct ti_sci_resource_desc;

struct ti_sci_rm_core_ops {
	int (*get_range)(const struct ti_sci_handle *, u32, u8, struct ti_sci_resource_desc *);
	int (*get_range_from_shost)(const struct ti_sci_handle *, u32, u8, u8, struct ti_sci_resource_desc *);
};

struct ti_sci_rm_irq_ops {
	int (*set_irq)(const struct ti_sci_handle *, u16, u16, u16, u16);
	int (*set_event_map)(const struct ti_sci_handle *, u16, u16, u16, u16, u16, u8);
	int (*free_irq)(const struct ti_sci_handle *, u16, u16, u16, u16);
	int (*free_event_map)(const struct ti_sci_handle *, u16, u16, u16, u16, u16, u8);
};

struct ti_sci_msg_rm_ring_cfg;

struct ti_sci_rm_ringacc_ops {
	int (*set_cfg)(const struct ti_sci_handle *, const struct ti_sci_msg_rm_ring_cfg *);
};

struct ti_sci_rm_psil_ops {
	int (*pair)(const struct ti_sci_handle *, u32, u32, u32);
	int (*unpair)(const struct ti_sci_handle *, u32, u32, u32);
};

struct ti_sci_msg_rm_udmap_tx_ch_cfg;

struct ti_sci_msg_rm_udmap_rx_ch_cfg;

struct ti_sci_msg_rm_udmap_flow_cfg;

struct ti_sci_rm_udmap_ops {
	int (*tx_ch_cfg)(const struct ti_sci_handle *, const struct ti_sci_msg_rm_udmap_tx_ch_cfg *);
	int (*rx_ch_cfg)(const struct ti_sci_handle *, const struct ti_sci_msg_rm_udmap_rx_ch_cfg *);
	int (*rx_flow_cfg)(const struct ti_sci_handle *, const struct ti_sci_msg_rm_udmap_flow_cfg *);
};

struct ti_sci_proc_ops {
	int (*request)(const struct ti_sci_handle *, u8);
	int (*release)(const struct ti_sci_handle *, u8);
	int (*handover)(const struct ti_sci_handle *, u8, u8);
	int (*set_config)(const struct ti_sci_handle *, u8, u64, u32, u32);
	int (*set_control)(const struct ti_sci_handle *, u8, u32, u32);
	int (*get_status)(const struct ti_sci_handle *, u8, u64 *, u32 *, u32 *, u32 *);
};

struct ti_sci_ops {
	struct ti_sci_core_ops core_ops;
	struct ti_sci_dev_ops dev_ops;
	struct ti_sci_clk_ops clk_ops;
	struct ti_sci_rm_core_ops rm_core_ops;
	struct ti_sci_rm_irq_ops rm_irq_ops;
	struct ti_sci_rm_ringacc_ops rm_ring_ops;
	struct ti_sci_rm_psil_ops rm_psil_ops;
	struct ti_sci_rm_udmap_ops rm_udmap_ops;
	struct ti_sci_proc_ops proc_ops;
};

struct ti_sci_handle {
	struct ti_sci_version_info version;
	struct ti_sci_ops ops;
};

struct ti_sci_resource_desc {
	u16 start;
	u16 num;
	u16 start_sec;
	u16 num_sec;
	long unsigned int *res_map;
};

struct ti_sci_msg_rm_ring_cfg {
	u32 valid_params;
	u16 nav_id;
	u16 index;
	u32 addr_lo;
	u32 addr_hi;
	u32 count;
	u8 mode;
	u8 size;
	u8 order_id;
	u16 virtid;
	u8 asel;
};

struct ti_sci_msg_rm_udmap_tx_ch_cfg {
	u32 valid_params;
	u16 nav_id;
	u16 index;
	u8 tx_pause_on_err;
	u8 tx_filt_einfo;
	u8 tx_filt_pswords;
	u8 tx_atype;
	u8 tx_chan_type;
	u8 tx_supr_tdpkt;
	u16 tx_fetch_size;
	u8 tx_credit_count;
	u16 txcq_qnum;
	u8 tx_priority;
	u8 tx_qos;
	u8 tx_orderid;
	u16 fdepth;
	u8 tx_sched_priority;
	u8 tx_burst_size;
	u8 tx_tdtype;
	u8 extended_ch_type;
};

struct ti_sci_msg_rm_udmap_rx_ch_cfg {
	u32 valid_params;
	u16 nav_id;
	u16 index;
	u16 rx_fetch_size;
	u16 rxcq_qnum;
	u8 rx_priority;
	u8 rx_qos;
	u8 rx_orderid;
	u8 rx_sched_priority;
	u16 flowid_start;
	u16 flowid_cnt;
	u8 rx_pause_on_err;
	u8 rx_atype;
	u8 rx_chan_type;
	u8 rx_ignore_short;
	u8 rx_ignore_long;
	u8 rx_burst_size;
};

struct ti_sci_msg_rm_udmap_flow_cfg {
	u32 valid_params;
	u16 nav_id;
	u16 flow_index;
	u8 rx_einfo_present;
	u8 rx_psinfo_present;
	u8 rx_error_handling;
	u8 rx_desc_type;
	u16 rx_sop_offset;
	u16 rx_dest_qnum;
	u8 rx_src_tag_hi;
	u8 rx_src_tag_lo;
	u8 rx_dest_tag_hi;
	u8 rx_dest_tag_lo;
	u8 rx_src_tag_hi_sel;
	u8 rx_src_tag_lo_sel;
	u8 rx_dest_tag_hi_sel;
	u8 rx_dest_tag_lo_sel;
	u16 rx_fdq0_sz0_qnum;
	u16 rx_fdq1_qnum;
	u16 rx_fdq2_qnum;
	u16 rx_fdq3_qnum;
	u8 rx_ps_location;
};

struct ti_sci_resource {
	u16 sets;
	raw_spinlock_t lock;
	struct ti_sci_resource_desc *desc;
};

struct ti_sci_intr_irq_domain {
	const struct ti_sci_handle *sci;
	struct ti_sci_resource *out_irqs;
	struct device___136 *dev;
	u32 ti_sci_id;
	u32 type;
};

struct of_phandle_iterator {
	const char *cells_name;
	int cell_count;
	const struct device_node___38 *parent;
	const __be32 *list_end;
	const __be32 *phandle_end;
	const __be32 *cur;
	uint32_t cur_count;
	phandle phandle;
	struct device_node___38 *node;
};

struct ti_sci_inta_event_desc {
	u16 global_event;
	u32 hwirq;
	u8 vint_bit;
};

struct ti_sci_inta_vint_desc {
	struct irq_domain___18 *domain;
	struct list_head list;
	long unsigned int event_map[1];
	struct ti_sci_inta_event_desc events[64];
	unsigned int parent_virq;
	u16 vint_id;
};

struct ti_sci_inta_irq_domain {
	const struct ti_sci_handle *sci;
	struct ti_sci_resource *vint;
	struct ti_sci_resource *global_event;
	struct list_head vint_list;
	struct mutex vint_mutex;
	void *base;
	struct platform_device *pdev;
	u32 ti_sci_id;
	int unmapped_cnt;
	u16 *unmapped_dev_ids;
};

struct mst_intc_chip_data {
	raw_spinlock_t lock;
	unsigned int irq_start;
	unsigned int nr_irqs;
	void *base;
	bool no_eoi;
	struct list_head entry;
	u16 saved_polarity_conf[4];
};

struct aic_irq_chip {
	void *base;
	struct irq_domain___18 *hw_domain;
	struct irq_domain___18 *ipi_domain;
	int nr_hw;
	int ipi_hwirq;
};

struct of_dev_auxdata {
	char *compatible;
	resource_size_t phys_addr;
	char *name;
	void *platform_data;
};

struct irq_desc___25;

typedef void (*irq_flow_handler_t___25)(struct irq_desc___25 *);

struct irq_chip___24;

struct irq_domain___23;

struct irq_data___24 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___24 *chip;
	struct irq_domain___23 *domain;
	struct irq_data___24 *parent_data;
	void *chip_data;
};

struct kset___172;

struct kobj_type___172;

struct kernfs_node___172;

struct kobject___172 {
	const char *name;
	struct list_head entry;
	struct kobject___172 *parent;
	struct kset___172 *kset;
	struct kobj_type___172 *ktype;
	struct kernfs_node___172 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___16;

struct module___168;

struct irq_desc___25 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___24 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___25 handle_irq;
	struct irqaction___16 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___172 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___168 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___184;

struct super_block___184;

struct file_system_type___184 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___184 * (*mount)(struct file_system_type___184 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___184 *);
	struct module___168 *owner;
	struct file_system_type___184 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___184;

struct kiocb___184;

struct poll_table_struct___120;

struct vm_area_struct___189;

struct inode___184;

struct file_lock___184;

struct page___189;

struct seq_file___160;

struct file_operations___184 {
	struct module___168 *owner;
	loff_t (*llseek)(struct file___184 *, loff_t, int);
	ssize_t (*read)(struct file___184 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___184 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___184 *, struct iov_iter___4 *);
	ssize_t (*write_iter)(struct kiocb___184 *, struct iov_iter___4 *);
	int (*iopoll)(struct kiocb___184 *, bool);
	int (*iterate)(struct file___184 *, struct dir_context *);
	int (*iterate_shared)(struct file___184 *, struct dir_context *);
	__poll_t (*poll)(struct file___184 *, struct poll_table_struct___120 *);
	long int (*unlocked_ioctl)(struct file___184 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___184 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___184 *, struct vm_area_struct___189 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___184 *, struct file___184 *);
	int (*flush)(struct file___184 *, fl_owner_t);
	int (*release)(struct inode___184 *, struct file___184 *);
	int (*fsync)(struct file___184 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___184 *, int);
	int (*lock)(struct file___184 *, int, struct file_lock___184 *);
	ssize_t (*sendpage)(struct file___184 *, struct page___189 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___184 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___184 *, long unsigned int);
	int (*flock)(struct file___184 *, int, struct file_lock___184 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___184 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___184 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___184 *, long int, struct file_lock___184 **, void **);
	long int (*fallocate)(struct file___184 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___160 *, struct file___184 *);
	ssize_t (*copy_file_range)(struct file___184 *, loff_t, struct file___184 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___184 *, loff_t, struct file___184 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___184 *, loff_t, loff_t, int);
};

struct vmacache___189 {
	u64 seqnum;
	struct vm_area_struct___189 *vmas[4];
};

struct page_frag___189 {
	struct page___189 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___190;

struct signal_struct___185;

struct vm_struct___167;

struct task_struct___191 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___191 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___190 *mm;
	struct mm_struct___190 *active_mm;
	struct vmacache___189 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___191 *real_parent;
	struct task_struct___191 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___191 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___163 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___185 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___191 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___90 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___189 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___191 *oom_reaper_list;
	struct vm_struct___167 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___168 {
	struct kobject___172 kobj;
	struct module___168 *mod;
	struct kobject___172 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___168 {
	struct module___168 *mod;
	struct latch_tree_node node;
};

struct module_layout___168 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___168 mtn;
};

struct module_attribute___168;

struct kernel_param___168;

struct module___168 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___168 mkobj;
	struct module_attribute___168 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___172 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___168 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___168 core_layout;
	struct module_layout___168 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___189 *pgtable_t___189;

struct address_space___184;

struct dev_pagemap___179;

struct page___189 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___184 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___52 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___189 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___189 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___190 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___179 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___179;

struct vm_area_struct___189 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___189 *vm_next;
	struct vm_area_struct___189 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___190 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___179 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___184 *vm_file;
	struct file___184 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___189;

struct mm_struct___190 {
	struct {
		struct vm_area_struct___189 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___184 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___189 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___191 *owner;
		struct user_namespace *user_ns;
		struct file___184 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___184;

struct address_space___184 {
	struct inode___184 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___184 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___179;

struct dev_pagemap___179 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___179 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___184;

struct path___184 {
	struct vfsmount___184 *mnt;
	struct dentry___184 *dentry;
};

struct file___184 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___184 f_path;
	struct inode___184 *f_inode;
	const struct file_operations___184 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___163 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___184 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___179;

struct vm_operations_struct___179 {
	void (*open)(struct vm_area_struct___189 *);
	void (*close)(struct vm_area_struct___189 *);
	int (*may_split)(struct vm_area_struct___189 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___189 *);
	int (*mprotect)(struct vm_area_struct___189 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___179 *);
	vm_fault_t (*huge_fault)(struct vm_fault___179 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___179 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___189 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___179 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___179 *);
	int (*access)(struct vm_area_struct___189 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___189 *);
	int (*set_policy)(struct vm_area_struct___189 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___189 *, long unsigned int);
	struct page___189 * (*find_special_page)(struct vm_area_struct___189 *, long unsigned int);
};

struct core_thread___189 {
	struct task_struct___191 *task;
	struct core_thread___189 *next;
};

struct core_state___189 {
	atomic_t nr_threads;
	struct core_thread___189 dumper;
	struct completion startup;
};

struct vm_fault___179 {
	const struct {
		struct vm_area_struct___189 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___189 *cow_page;
	struct page___189 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___189 prealloc_pte;
};

struct kernfs_root___172;

struct kernfs_elem_dir___172 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___172 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___172;

struct kernfs_root___172 {
	struct kernfs_node___172 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___172 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___172 {
	struct kernfs_node___172 *target_kn;
};

struct kernfs_ops___172;

struct kernfs_elem_attr___172 {
	const struct kernfs_ops___172 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___172 *notify_next;
};

struct kernfs_node___172 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___172 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___172 dir;
		struct kernfs_elem_symlink___172 symlink;
		struct kernfs_elem_attr___172 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___172;

struct kernfs_ops___172 {
	int (*open)(struct kernfs_open_file___172 *);
	void (*release)(struct kernfs_open_file___172 *);
	int (*seq_show)(struct seq_file___160 *, void *);
	void * (*seq_start)(struct seq_file___160 *, loff_t *);
	void * (*seq_next)(struct seq_file___160 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___160 *, void *);
	ssize_t (*read)(struct kernfs_open_file___172 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___172 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___172 *, struct poll_table_struct___120 *);
	int (*mmap)(struct kernfs_open_file___172 *, struct vm_area_struct___189 *);
};

struct kernfs_syscall_ops___172 {
	int (*show_options)(struct seq_file___160 *, struct kernfs_root___172 *);
	int (*mkdir)(struct kernfs_node___172 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___172 *);
	int (*rename)(struct kernfs_node___172 *, struct kernfs_node___172 *, const char *);
	int (*show_path)(struct seq_file___160 *, struct kernfs_node___172 *, struct kernfs_root___172 *);
};

struct seq_operations___160;

struct seq_file___160 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___160 *op;
	int poll_event;
	const struct file___184 *file;
	void *private;
};

struct kernfs_open_file___172 {
	struct kernfs_node___172 *kn;
	struct file___184 *file;
	struct seq_file___160 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___179 *vm_ops;
};

typedef void (*poll_queue_proc___125)(struct file___184 *, wait_queue_head_t *, struct poll_table_struct___120 *);

struct poll_table_struct___120 {
	poll_queue_proc___125 _qproc;
	__poll_t _key;
};

struct tty_struct___14;

struct signal_struct___185 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___191 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___191 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___163 *pids[4];
	struct pid___163 *tty_old_pgrp;
	int leader;
	struct tty_struct___14 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___190 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct vm_struct___167 {
	struct vm_struct___167 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___189 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___172;

struct attribute_group___172 {
	const char *name;
	umode_t (*is_visible)(struct kobject___172 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___172 *, struct bin_attribute___172 *, int);
	struct attribute **attrs;
	struct bin_attribute___172 **bin_attrs;
};

struct bin_attribute___172 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___184 * (*f_mapping)();
	ssize_t (*read)(struct file___184 *, struct kobject___172 *, struct bin_attribute___172 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___184 *, struct kobject___172 *, struct bin_attribute___172 *, char *, loff_t, size_t);
	int (*mmap)(struct file___184 *, struct kobject___172 *, struct bin_attribute___172 *, struct vm_area_struct___189 *);
};

struct sysfs_ops___172 {
	ssize_t (*show)(struct kobject___172 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___172 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___172;

struct kset___172 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___172 kobj;
	const struct kset_uevent_ops___172 *uevent_ops;
};

struct kobj_type___172 {
	void (*release)(struct kobject___172 *);
	const struct sysfs_ops___172 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___172 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___172 *);
	const void * (*namespace)(struct kobject___172 *);
	void (*get_ownership)(struct kobject___172 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___172 {
	int (* const filter)(struct kset___172 *, struct kobject___172 *);
	const char * (* const name)(struct kset___172 *, struct kobject___172 *);
	int (* const uevent)(struct kset___172 *, struct kobject___172 *, struct kobj_uevent_env *);
};

struct fwnode_operations___140;

struct device___140;

struct fwnode_handle___140 {
	struct fwnode_handle___140 *secondary;
	const struct fwnode_operations___140 *ops;
	struct device___140 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___140;

struct fwnode_endpoint___140;

struct fwnode_operations___140 {
	struct fwnode_handle___140 * (*get)(struct fwnode_handle___140 *);
	void (*put)(struct fwnode_handle___140 *);
	bool (*device_is_available)(const struct fwnode_handle___140 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___140 *, const struct device___140 *);
	bool (*property_present)(const struct fwnode_handle___140 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___140 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___140 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___140 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*get_parent)(const struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*get_next_child_node)(const struct fwnode_handle___140 *, struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*get_named_child_node)(const struct fwnode_handle___140 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___140 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___140 *);
	struct fwnode_handle___140 * (*graph_get_next_endpoint)(const struct fwnode_handle___140 *, struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*graph_get_remote_endpoint)(const struct fwnode_handle___140 *);
	struct fwnode_handle___140 * (*graph_get_port_parent)(struct fwnode_handle___140 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___140 *, struct fwnode_endpoint___140 *);
	int (*add_links)(struct fwnode_handle___140 *);
};

struct wakeup_source___140;

struct dev_pm_info___140 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___140 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___140 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___140;

struct bus_type___140;

struct device_driver___140;

struct dev_pm_domain___140;

struct device_node___42;

struct class___140;

struct device___140 {
	struct kobject___172 kobj;
	struct device___140 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___140 *type;
	struct bus_type___140 *bus;
	struct device_driver___140 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___140 power;
	struct dev_pm_domain___140 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___23 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___42 *of_node;
	struct fwnode_handle___140 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___140 *class;
	const struct attribute_group___172 **groups;
	void (*release)(struct device___140 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___140 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___140 *local_fwnode;
};

struct fwnode_reference_args___140 {
	struct fwnode_handle___140 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___34 {
	char *name;
	int length;
	void *value;
	struct property___34 *next;
	long unsigned int _flags;
	struct bin_attribute___172 attr;
};

struct device_node___42 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___140 fwnode;
	struct property___34 *properties;
	struct property___34 *deadprops;
	struct device_node___42 *parent;
	struct device_node___42 *child;
	struct device_node___42 *sibling;
	struct kobject___172 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___21 {
	struct fwnode_handle___140 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___23 {
	int (*match)(struct irq_domain___23 *, struct device_node___42 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___23 *, struct irq_fwspec___21 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___23 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___23 *, unsigned int);
	int (*xlate)(struct irq_domain___23 *, struct device_node___42 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___23 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___23 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___23 *, struct irq_data___24 *, bool);
	void (*deactivate)(struct irq_domain___23 *, struct irq_data___24 *);
	int (*translate)(struct irq_domain___23 *, struct irq_fwspec___21 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___23;

struct irq_domain___23 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___23 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___140 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___23 *gc;
	struct irq_domain___23 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___24 *revmap[0];
};

struct irq_chip_generic___23;

struct irq_domain_chip_generic___23 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___23 *gc[0];
};

struct dev_pm_ops___140 {
	int (*prepare)(struct device___140 *);
	void (*complete)(struct device___140 *);
	int (*suspend)(struct device___140 *);
	int (*resume)(struct device___140 *);
	int (*freeze)(struct device___140 *);
	int (*thaw)(struct device___140 *);
	int (*poweroff)(struct device___140 *);
	int (*restore)(struct device___140 *);
	int (*suspend_late)(struct device___140 *);
	int (*resume_early)(struct device___140 *);
	int (*freeze_late)(struct device___140 *);
	int (*thaw_early)(struct device___140 *);
	int (*poweroff_late)(struct device___140 *);
	int (*restore_early)(struct device___140 *);
	int (*suspend_noirq)(struct device___140 *);
	int (*resume_noirq)(struct device___140 *);
	int (*freeze_noirq)(struct device___140 *);
	int (*thaw_noirq)(struct device___140 *);
	int (*poweroff_noirq)(struct device___140 *);
	int (*restore_noirq)(struct device___140 *);
	int (*runtime_suspend)(struct device___140 *);
	int (*runtime_resume)(struct device___140 *);
	int (*runtime_idle)(struct device___140 *);
};

struct wakeup_source___140 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___140 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___140 {
	struct dev_pm_ops___140 ops;
	int (*start)(struct device___140 *);
	void (*detach)(struct device___140 *, bool);
	int (*activate)(struct device___140 *);
	void (*sync)(struct device___140 *);
	void (*dismiss)(struct device___140 *);
};

struct bus_type___140 {
	const char *name;
	const char *dev_name;
	struct device___140 *dev_root;
	const struct attribute_group___172 **bus_groups;
	const struct attribute_group___172 **dev_groups;
	const struct attribute_group___172 **drv_groups;
	int (*match)(struct device___140 *, struct device_driver___140 *);
	int (*uevent)(struct device___140 *, struct kobj_uevent_env *);
	int (*probe)(struct device___140 *);
	void (*sync_state)(struct device___140 *);
	void (*remove)(struct device___140 *);
	void (*shutdown)(struct device___140 *);
	int (*online)(struct device___140 *);
	int (*offline)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	int (*num_vf)(struct device___140 *);
	int (*dma_configure)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___140 {
	const char *name;
	struct bus_type___140 *bus;
	struct module___168 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___140 *);
	void (*sync_state)(struct device___140 *);
	int (*remove)(struct device___140 *);
	void (*shutdown)(struct device___140 *);
	int (*suspend)(struct device___140 *, pm_message_t);
	int (*resume)(struct device___140 *);
	const struct attribute_group___172 **groups;
	const struct attribute_group___172 **dev_groups;
	const struct dev_pm_ops___140 *pm;
	void (*coredump)(struct device___140 *);
	struct driver_private *p;
};

struct device_type___140 {
	const char *name;
	const struct attribute_group___172 **groups;
	int (*uevent)(struct device___140 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___140 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___140 *);
	const struct dev_pm_ops___140 *pm;
};

struct class___140 {
	const char *name;
	struct module___168 *owner;
	const struct attribute_group___172 **class_groups;
	const struct attribute_group___172 **dev_groups;
	struct kobject___172 *dev_kobj;
	int (*dev_uevent)(struct device___140 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___140 *, umode_t *);
	void (*class_release)(struct class___140 *);
	void (*dev_release)(struct device___140 *);
	int (*shutdown_pre)(struct device___140 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___140 *);
	void (*get_ownership)(struct device___140 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___140 *pm;
	struct subsys_private *p;
};

struct dentry_operations___184;

struct dentry___184 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___184 *d_parent;
	struct qstr d_name;
	struct inode___184 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___184 *d_op;
	struct super_block___184 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___184;

struct cdev___35;

struct inode___184 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___184 *i_op;
	struct super_block___184 *i_sb;
	struct address_space___184 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___184 *i_fop;
		void (*free_inode)(struct inode___184 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___184 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___35 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___184 {
	int (*d_revalidate)(struct dentry___184 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___184 *, unsigned int);
	int (*d_hash)(const struct dentry___184 *, struct qstr *);
	int (*d_compare)(const struct dentry___184 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___184 *);
	int (*d_init)(struct dentry___184 *);
	void (*d_release)(struct dentry___184 *);
	void (*d_prune)(struct dentry___184 *);
	void (*d_iput)(struct dentry___184 *, struct inode___184 *);
	char * (*d_dname)(struct dentry___184 *, char *, int);
	struct vfsmount___184 * (*d_automount)(struct path___184 *);
	int (*d_manage)(const struct path___184 *, bool);
	struct dentry___184 * (*d_real)(struct dentry___184 *, const struct inode___184 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___184;

struct mem_dqinfo___184 {
	struct quota_format_type___184 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___184;

struct quota_info___184 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___184 *files[3];
	struct mem_dqinfo___184 info[3];
	const struct quota_format_ops___184 *ops[3];
};

struct rcuwait___185 {
	struct task_struct___191 *task;
};

struct percpu_rw_semaphore___185 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___185 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___184 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___185 rw_sem[3];
};

struct super_operations___184;

struct dquot_operations___184;

struct quotactl_ops___184;

struct super_block___184 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___184 *s_type;
	const struct super_operations___184 *s_op;
	const struct dquot_operations___184 *dq_op;
	const struct quotactl_ops___184 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___184 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___184 s_dquot;
	struct sb_writers___184 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___184 *s_d_op;
	int cleancache_poolid;
	struct shrinker___74 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___184 {
	struct dentry___184 *mnt_root;
	struct super_block___184 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct tty_driver___15;

struct tty_operations___15;

struct tty_ldisc___14;

struct fasync_struct___184;

struct tty_port___15;

struct tty_struct___14 {
	int magic;
	struct kref kref;
	struct device___140 *dev;
	struct tty_driver___15 *driver;
	const struct tty_operations___15 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___14 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___147 *pgrp;
		struct pid___147 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___14 *link;
	struct fasync_struct___184 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___15 *port;
};

struct kiocb___184 {
	struct file___184 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___184 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___83 *ki_waitq;
	};
};

struct iattr___184 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___184 *ia_file;
};

struct dquot___184 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___184 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___184 {
	int qf_fmt_id;
	const struct quota_format_ops___184 *qf_ops;
	struct module___168 *qf_owner;
	struct quota_format_type___184 *qf_next;
};

struct quota_format_ops___184 {
	int (*check_quota_file)(struct super_block___184 *, int);
	int (*read_file_info)(struct super_block___184 *, int);
	int (*write_file_info)(struct super_block___184 *, int);
	int (*free_file_info)(struct super_block___184 *, int);
	int (*read_dqblk)(struct dquot___184 *);
	int (*commit_dqblk)(struct dquot___184 *);
	int (*release_dqblk)(struct dquot___184 *);
	int (*get_next_id)(struct super_block___184 *, struct kqid *);
};

struct dquot_operations___184 {
	int (*write_dquot)(struct dquot___184 *);
	struct dquot___184 * (*alloc_dquot)(struct super_block___184 *, int);
	void (*destroy_dquot)(struct dquot___184 *);
	int (*acquire_dquot)(struct dquot___184 *);
	int (*release_dquot)(struct dquot___184 *);
	int (*mark_dirty)(struct dquot___184 *);
	int (*write_info)(struct super_block___184 *, int);
	qsize_t * (*get_reserved_space)(struct inode___184 *);
	int (*get_projid)(struct inode___184 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___184 *, qsize_t *);
	int (*get_next_id)(struct super_block___184 *, struct kqid *);
};

struct quotactl_ops___184 {
	int (*quota_on)(struct super_block___184 *, int, int, const struct path___184 *);
	int (*quota_off)(struct super_block___184 *, int);
	int (*quota_enable)(struct super_block___184 *, unsigned int);
	int (*quota_disable)(struct super_block___184 *, unsigned int);
	int (*quota_sync)(struct super_block___184 *, int);
	int (*set_info)(struct super_block___184 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___184 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___184 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___184 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___184 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___184 *, unsigned int);
};

struct address_space_operations___184 {
	int (*writepage)(struct page___189 *, struct writeback_control___3 *);
	int (*readpage)(struct file___184 *, struct page___189 *);
	int (*writepages)(struct address_space___184 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___189 *);
	int (*readpages)(struct file___184 *, struct address_space___184 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___184 *, struct address_space___184 *, loff_t, unsigned int, unsigned int, struct page___189 **, void **);
	int (*write_end)(struct file___184 *, struct address_space___184 *, loff_t, unsigned int, unsigned int, struct page___189 *, void *);
	sector_t (*bmap)(struct address_space___184 *, sector_t);
	void (*invalidatepage)(struct page___189 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___189 *, gfp_t);
	void (*freepage)(struct page___189 *);
	ssize_t (*direct_IO)(struct kiocb___184 *, struct iov_iter___4 *);
	int (*migratepage)(struct address_space___184 *, struct page___189 *, struct page___189 *, enum migrate_mode);
	bool (*isolate_page)(struct page___189 *, isolate_mode_t);
	void (*putback_page)(struct page___189 *);
	int (*launder_page)(struct page___189 *);
	int (*is_partially_uptodate)(struct page___189 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___189 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___184 *, struct page___189 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___184 *, sector_t *);
	void (*swap_deactivate)(struct file___184 *);
};

struct cdev___35 {
	struct kobject___172 kobj;
	struct module___168 *owner;
	const struct file_operations___184 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___184 {
	struct dentry___184 * (*lookup)(struct inode___184 *, struct dentry___184 *, unsigned int);
	const char * (*get_link)(struct dentry___184 *, struct inode___184 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___184 *, int);
	struct posix_acl * (*get_acl)(struct inode___184 *, int, bool);
	int (*readlink)(struct dentry___184 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___184 *, struct dentry___184 *, umode_t, bool);
	int (*link)(struct dentry___184 *, struct inode___184 *, struct dentry___184 *);
	int (*unlink)(struct inode___184 *, struct dentry___184 *);
	int (*symlink)(struct user_namespace *, struct inode___184 *, struct dentry___184 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___184 *, struct dentry___184 *, umode_t);
	int (*rmdir)(struct inode___184 *, struct dentry___184 *);
	int (*mknod)(struct user_namespace *, struct inode___184 *, struct dentry___184 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___184 *, struct dentry___184 *, struct inode___184 *, struct dentry___184 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___184 *, struct iattr___184 *);
	int (*getattr)(struct user_namespace *, const struct path___184 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___184 *, char *, size_t);
	int (*fiemap)(struct inode___184 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___184 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___184 *, struct dentry___184 *, struct file___184 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___184 *, struct dentry___184 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___184 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___184 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___184 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___184 {
	void (*fl_copy_lock)(struct file_lock___184 *, struct file_lock___184 *);
	void (*fl_release_private)(struct file_lock___184 *);
};

struct lock_manager_operations___184;

struct file_lock___184 {
	struct file_lock___184 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___184 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___184 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___184 *fl_ops;
	const struct lock_manager_operations___184 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___184 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___184 *);
	int (*lm_grant)(struct file_lock___184 *, int);
	bool (*lm_break)(struct file_lock___184 *);
	int (*lm_change)(struct file_lock___184 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___184 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___184 *);
};

struct fasync_struct___184 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___184 *fa_next;
	struct file___184 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___184 {
	struct inode___184 * (*alloc_inode)(struct super_block___184 *);
	void (*destroy_inode)(struct inode___184 *);
	void (*free_inode)(struct inode___184 *);
	void (*dirty_inode)(struct inode___184 *, int);
	int (*write_inode)(struct inode___184 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___184 *);
	void (*evict_inode)(struct inode___184 *);
	void (*put_super)(struct super_block___184 *);
	int (*sync_fs)(struct super_block___184 *, int);
	int (*freeze_super)(struct super_block___184 *);
	int (*freeze_fs)(struct super_block___184 *);
	int (*thaw_super)(struct super_block___184 *);
	int (*unfreeze_fs)(struct super_block___184 *);
	int (*statfs)(struct dentry___184 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___184 *, int *, char *);
	void (*umount_begin)(struct super_block___184 *);
	int (*show_options)(struct seq_file___160 *, struct dentry___184 *);
	int (*show_devname)(struct seq_file___160 *, struct dentry___184 *);
	int (*show_path)(struct seq_file___160 *, struct dentry___184 *);
	int (*show_stats)(struct seq_file___160 *, struct dentry___184 *);
	ssize_t (*quota_read)(struct super_block___184 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___184 *, int, const char *, size_t, loff_t);
	struct dquot___184 ** (*get_dquots)(struct inode___184 *);
	long int (*nr_cached_objects)(struct super_block___184 *, struct shrink_control___74 *);
	long int (*free_cached_objects)(struct super_block___184 *, struct shrink_control___74 *);
	struct file___184 * (*real_loop)(struct file___184 *);
};

struct kernel_param_ops___168 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___168 *);
	int (*get)(char *, const struct kernel_param___168 *);
	void (*free)(void *);
};

struct kparam_array___168;

struct kernel_param___168 {
	const char *name;
	struct module___168 *mod;
	const struct kernel_param_ops___168 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___168 *arr;
	};
};

struct kparam_array___168 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___168 *ops;
	void *elem;
};

struct module_attribute___168 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___168 *, struct module_kobject___168 *, char *);
	ssize_t (*store)(struct module_attribute___168 *, struct module_kobject___168 *, const char *, size_t);
	void (*setup)(struct module___168 *, const char *);
	int (*test)(struct module___168 *);
	void (*free)(struct module___168 *);
};

struct acpi_device___3;

struct acpi_hotplug_profile___3 {
	struct kobject___172 kobj;
	int (*scan_dependent)(struct acpi_device___3 *);
	void (*notify_online)(struct acpi_device___3 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___3 {
	void (*func)(struct acpi_device_wakeup_context___3 *);
	struct device___140 *dev;
};

struct acpi_device_wakeup___3 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___3 context;
	struct wakeup_source___140 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___3;

struct acpi_hotplug_context___3;

struct acpi_driver___3;

struct acpi_device___3 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___140 fwnode;
	struct acpi_device___3 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___3 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___3 *handler;
	struct acpi_hotplug_context___3 *hp;
	struct acpi_driver___3 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___140 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___3 *);
};

struct acpi_scan_handler___3 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___3 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___3 *);
	void (*bind)(struct device___140 *);
	void (*unbind)(struct device___140 *);
	struct acpi_hotplug_profile___3 hotplug;
};

struct acpi_hotplug_context___3 {
	struct acpi_device___3 *self;
	int (*notify)(struct acpi_device___3 *, u32);
	void (*uevent)(struct acpi_device___3 *, u32);
	void (*fixup)(struct acpi_device___3 *);
};

typedef int (*acpi_op_add___3)(struct acpi_device___3 *);

typedef int (*acpi_op_remove___3)(struct acpi_device___3 *);

typedef void (*acpi_op_notify___3)(struct acpi_device___3 *, u32);

struct acpi_device_ops___3 {
	acpi_op_add___3 add;
	acpi_op_remove___3 remove;
	acpi_op_notify___3 notify;
};

struct acpi_driver___3 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___3 ops;
	struct device_driver___140 drv;
	struct module___168 *owner;
};

struct logic_pio_hwaddr___2 {
	struct list_head list;
	struct fwnode_handle___140 *fwnode;
	resource_size_t hw_start;
	resource_size_t io_start;
	resource_size_t size;
	long unsigned int flags;
	void *hostdata;
	const struct logic_pio_host_ops *ops;
};

struct irq_chip___24 {
	struct device___140 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___24 *);
	void (*irq_shutdown)(struct irq_data___24 *);
	void (*irq_enable)(struct irq_data___24 *);
	void (*irq_disable)(struct irq_data___24 *);
	void (*irq_ack)(struct irq_data___24 *);
	void (*irq_mask)(struct irq_data___24 *);
	void (*irq_mask_ack)(struct irq_data___24 *);
	void (*irq_unmask)(struct irq_data___24 *);
	void (*irq_eoi)(struct irq_data___24 *);
	int (*irq_set_affinity)(struct irq_data___24 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___24 *);
	int (*irq_set_type)(struct irq_data___24 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___24 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___24 *);
	void (*irq_bus_sync_unlock)(struct irq_data___24 *);
	void (*irq_cpu_online)(struct irq_data___24 *);
	void (*irq_cpu_offline)(struct irq_data___24 *);
	void (*irq_suspend)(struct irq_data___24 *);
	void (*irq_resume)(struct irq_data___24 *);
	void (*irq_pm_shutdown)(struct irq_data___24 *);
	void (*irq_calc_mask)(struct irq_data___24 *);
	void (*irq_print_chip)(struct irq_data___24 *, struct seq_file___160 *);
	int (*irq_request_resources)(struct irq_data___24 *);
	void (*irq_release_resources)(struct irq_data___24 *);
	void (*irq_compose_msi_msg)(struct irq_data___24 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___24 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___24 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___24 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___24 *, void *);
	void (*ipi_send_single)(struct irq_data___24 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___24 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___24 *);
	void (*irq_nmi_teardown)(struct irq_data___24 *);
	long unsigned int flags;
};

struct irqaction___16 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___16 *next;
	irq_handler_t thread_fn;
	struct task_struct___191 *thread;
	struct irqaction___16 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___23 {
	struct irq_chip___24 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___25 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___23 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___23 *);
	void (*resume)(struct irq_chip_generic___23 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___23 *domain;
	struct list_head list;
	struct irq_chip_type___23 chip_types[0];
};

struct gpio_desc;

struct seq_operations___160 {
	void * (*start)(struct seq_file___160 *, loff_t *);
	void (*stop)(struct seq_file___160 *, void *);
	void * (*next)(struct seq_file___160 *, void *, loff_t *);
	int (*show)(struct seq_file___160 *, void *);
};

struct dev_pagemap_ops___179 {
	void (*page_free)(struct page___189 *);
	void (*kill)(struct dev_pagemap___179 *);
	void (*cleanup)(struct dev_pagemap___179 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___179 *);
};

struct console___4 {
	char name[16];
	void (*write)(struct console___4 *, const char *, unsigned int);
	int (*read)(struct console___4 *, char *, unsigned int);
	struct tty_driver___15 * (*device)(struct console___4 *, int *);
	void (*unblank)();
	int (*setup)(struct console___4 *, char *);
	int (*exit)(struct console___4 *);
	int (*match)(struct console___4 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___4 *next;
};

struct tty_driver___15 {
	int magic;
	struct kref kref;
	struct cdev___35 **cdevs;
	struct module___168 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___15 *other;
	struct tty_struct___14 **ttys;
	struct tty_port___15 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___15 *ops;
	struct list_head tty_drivers;
};

struct platform_device___8 {
	const char *name;
	int id;
	bool id_auto;
	struct device___140 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___7 {
	int (*probe)(struct platform_device___8 *);
	int (*remove)(struct platform_device___8 *);
	void (*shutdown)(struct platform_device___8 *);
	int (*suspend)(struct platform_device___8 *, pm_message_t);
	int (*resume)(struct platform_device___8 *);
	struct device_driver___140 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct circ_buf {
	char *buf;
	int head;
	int tail;
};

struct tty_operations___15 {
	struct tty_struct___14 * (*lookup)(struct tty_driver___15 *, struct file___184 *, int);
	int (*install)(struct tty_driver___15 *, struct tty_struct___14 *);
	void (*remove)(struct tty_driver___15 *, struct tty_struct___14 *);
	int (*open)(struct tty_struct___14 *, struct file___184 *);
	void (*close)(struct tty_struct___14 *, struct file___184 *);
	void (*shutdown)(struct tty_struct___14 *);
	void (*cleanup)(struct tty_struct___14 *);
	int (*write)(struct tty_struct___14 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___14 *, unsigned char);
	void (*flush_chars)(struct tty_struct___14 *);
	unsigned int (*write_room)(struct tty_struct___14 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___14 *);
	int (*ioctl)(struct tty_struct___14 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___14 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___14 *, struct ktermios *);
	void (*throttle)(struct tty_struct___14 *);
	void (*unthrottle)(struct tty_struct___14 *);
	void (*stop)(struct tty_struct___14 *);
	void (*start)(struct tty_struct___14 *);
	void (*hangup)(struct tty_struct___14 *);
	int (*break_ctl)(struct tty_struct___14 *, int);
	void (*flush_buffer)(struct tty_struct___14 *);
	void (*set_ldisc)(struct tty_struct___14 *);
	void (*wait_until_sent)(struct tty_struct___14 *, int);
	void (*send_xchar)(struct tty_struct___14 *, char);
	int (*tiocmget)(struct tty_struct___14 *);
	int (*tiocmset)(struct tty_struct___14 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___14 *, struct winsize *);
	int (*get_icount)(struct tty_struct___14 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___14 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___14 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___14 *, struct seq_file___160 *);
	int (*poll_init)(struct tty_driver___15 *, int, char *);
	int (*poll_get_char)(struct tty_driver___15 *, int);
	void (*poll_put_char)(struct tty_driver___15 *, int, char);
	int (*proc_show)(struct seq_file___160 *, void *);
};

struct tty_port_operations___14;

struct tty_port_client_operations___14;

struct tty_port___15 {
	struct tty_bufhead buf;
	struct tty_struct___14 *tty;
	struct tty_struct___14 *itty;
	const struct tty_port_operations___14 *ops;
	const struct tty_port_client_operations___14 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___14 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___14 *);
	void (*close)(struct tty_struct___14 *);
	void (*flush_buffer)(struct tty_struct___14 *);
	ssize_t (*read)(struct tty_struct___14 *, struct file___184 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___14 *, struct file___184 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___14 *, struct file___184 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___14 *, struct file___184 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___14 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___14 *, struct file___184 *, struct poll_table_struct___120 *);
	int (*hangup)(struct tty_struct___14 *);
	void (*receive_buf)(struct tty_struct___14 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___14 *);
	void (*dcd_change)(struct tty_struct___14 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___14 *, const unsigned char *, const char *, int);
	struct module___168 *owner;
};

struct tty_ldisc___14 {
	struct tty_ldisc_ops___14 *ops;
	struct tty_struct___14 *tty;
};

struct tty_port_operations___14 {
	int (*carrier_raised)(struct tty_port___15 *);
	void (*dtr_rts)(struct tty_port___15 *, int);
	void (*shutdown)(struct tty_port___15 *);
	int (*activate)(struct tty_port___15 *, struct tty_struct___14 *);
	void (*destruct)(struct tty_port___15 *);
};

struct tty_port_client_operations___14 {
	int (*receive_buf)(struct tty_port___15 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___15 *);
};

struct serial_rs485 {
	__u32 flags;
	__u32 delay_rts_before_send;
	__u32 delay_rts_after_send;
	__u32 padding[5];
};

struct serial_iso7816 {
	__u32 flags;
	__u32 tg;
	__u32 sc_fi;
	__u32 sc_di;
	__u32 clk;
	__u32 reserved[5];
};

struct uart_port;

struct uart_ops {
	unsigned int (*tx_empty)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*stop_tx)(struct uart_port *);
	void (*start_tx)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	void (*send_xchar)(struct uart_port *, char);
	void (*stop_rx)(struct uart_port *);
	void (*enable_ms)(struct uart_port *);
	void (*break_ctl)(struct uart_port *, int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*flush_buffer)(struct uart_port *);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port *);
	void (*release_port)(struct uart_port *);
	int (*request_port)(struct uart_port *);
	void (*config_port)(struct uart_port *, int);
	int (*verify_port)(struct uart_port *, struct serial_struct *);
	int (*ioctl)(struct uart_port *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port *);
	void (*poll_put_char)(struct uart_port *, unsigned char);
	int (*poll_get_char)(struct uart_port *);
};

struct uart_icount {
	__u32 cts;
	__u32 dsr;
	__u32 rng;
	__u32 dcd;
	__u32 rx;
	__u32 tx;
	__u32 frame;
	__u32 overrun;
	__u32 parity;
	__u32 brk;
	__u32 buf_overrun;
};

typedef unsigned int upf_t;

typedef unsigned int upstat_t;

struct uart_state;

struct uart_port {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port *, int);
	void (*serial_out)(struct uart_port *, int, int);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port *);
	void (*set_mctrl)(struct uart_port *, unsigned int);
	unsigned int (*get_divisor)(struct uart_port *, unsigned int, unsigned int *);
	void (*set_divisor)(struct uart_port *, unsigned int, unsigned int, unsigned int);
	int (*startup)(struct uart_port *);
	void (*shutdown)(struct uart_port *);
	void (*throttle)(struct uart_port *);
	void (*unthrottle)(struct uart_port *);
	int (*handle_irq)(struct uart_port *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port *);
	int (*rs485_config)(struct uart_port *, struct serial_rs485 *);
	int (*iso7816_config)(struct uart_port *, struct serial_iso7816 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state *state;
	struct uart_icount icount;
	struct console___4 *cons;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___140 *dev;
	long unsigned int sysrq;
	unsigned int sysrq_ch;
	unsigned char has_sysrq;
	unsigned char sysrq_seq;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char console_reinit;
	const char *name;
	struct attribute_group___172 *attr_group;
	const struct attribute_group___172 **tty_groups;
	struct serial_rs485 rs485;
	struct gpio_desc *rs485_term_gpio;
	struct serial_iso7816 iso7816;
	void *private_data;
};

enum uart_pm_state {
	UART_PM_STATE_ON = 0,
	UART_PM_STATE_OFF = 3,
	UART_PM_STATE_UNDEFINED = 4,
};

struct uart_state {
	struct tty_port___15 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port *uart_port;
};

struct plat_serial8250_port {
	long unsigned int iobase;
	void *membase;
	resource_size_t mapbase;
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	void *private_data;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char hub6;
	unsigned char has_sysrq;
	upf_t flags;
	unsigned int type;
	unsigned int (*serial_in)(struct uart_port *, int);
	void (*serial_out)(struct uart_port *, int, int);
	void (*set_termios)(struct uart_port *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port *);
	int (*handle_irq)(struct uart_port *);
	void (*pm)(struct uart_port *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port *);
};

struct lpc_cycle_para {
	unsigned int opflags;
	unsigned int csize;
};

struct hisi_lpc_dev {
	spinlock_t cycle_lock;
	void *membase;
	struct logic_pio_hwaddr___2 *io_host;
};

struct hisi_lpc_acpi_cell {
	const char *hid;
	const char *name;
	void *pdata;
	size_t pdata_size;
};

enum {
	ARB_TIMER = 0,
	ARB_BP_CAP_CLR = 1,
	ARB_BP_CAP_HI_ADDR = 2,
	ARB_BP_CAP_ADDR = 3,
	ARB_BP_CAP_STATUS = 4,
	ARB_BP_CAP_MASTER = 5,
	ARB_ERR_CAP_CLR = 6,
	ARB_ERR_CAP_HI_ADDR = 7,
	ARB_ERR_CAP_ADDR = 8,
	ARB_ERR_CAP_STATUS = 9,
	ARB_ERR_CAP_MASTER = 10,
};

struct brcmstb_gisb_arb_device {
	void *base;
	const int *gisb_offsets;
	bool big_endian;
	struct mutex lock;
	struct list_head next;
	u32 valid_mask;
	const char *master_names[32];
	u32 saved_timeout;
};

struct bus_attribute {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___138 *, char *);
	ssize_t (*store)(struct bus_type___138 *, const char *, size_t);
};

struct device_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct device___138 *, struct device_attribute___10 *, char *);
	ssize_t (*store)(struct device___138 *, struct device_attribute___10 *, const char *, size_t);
};

struct device_link___2 {
	struct device___138 *supplier;
	struct list_head s_node;
	struct device___138 *consumer;
	struct list_head c_node;
	struct device___138 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fsl_mc_device_id {
	__u16 vendor;
	const char obj_type[16];
};

enum dev_dma_attr {
	DEV_DMA_NOT_SUPPORTED = 0,
	DEV_DMA_NON_COHERENT = 1,
	DEV_DMA_COHERENT = 2,
};

struct fsl_mc_command {
	__le64 header;
	__le64 params[7];
};

struct fsl_mc_device___2;

struct fsl_mc_driver {
	struct device_driver___138 driver;
	const struct fsl_mc_device_id *match_id_table;
	int (*probe)(struct fsl_mc_device___2 *);
	int (*remove)(struct fsl_mc_device___2 *);
	void (*shutdown)(struct fsl_mc_device___2 *);
	int (*suspend)(struct fsl_mc_device___2 *, pm_message_t);
	int (*resume)(struct fsl_mc_device___2 *);
};

struct fsl_mc_io___2;

struct fsl_mc_device_irq___2;

struct fsl_mc_device___2 {
	struct device___138 dev;
	u64 dma_mask;
	u16 flags;
	u32 icid;
	u16 mc_handle;
	struct fsl_mc_io___2 *mc_io;
	struct fsl_mc_obj_desc obj_desc;
	struct resource *regions;
	struct fsl_mc_device_irq___2 **irqs;
	struct fsl_mc_resource *resource;
	struct device_link___2 *consumer_link;
	char *driver_override;
};

struct fsl_mc_bus;

struct fsl_mc_resource_pool {
	enum fsl_mc_pool_type type;
	int max_count;
	int free_count;
	struct mutex mutex;
	struct list_head free_list;
	struct fsl_mc_bus *mc_bus;
};

struct fsl_mc_device_irq___2 {
	struct msi_desc___7 *msi_desc;
	struct fsl_mc_device___2 *mc_dev;
	u8 dev_irq_index;
	struct fsl_mc_resource resource;
};

struct fsl_mc_io___2 {
	struct device___138 *dev;
	u16 flags;
	u32 portal_size;
	phys_addr_t portal_phys_addr;
	void *portal_virt_addr;
	struct fsl_mc_device___2 *dpmcp_dev;
	union {
		struct mutex mutex;
		raw_spinlock_t spinlock;
	};
};

struct mc_cmd_header {
	u8 src_id;
	u8 flags_hw;
	u8 status;
	u8 flags_sw;
	__le16 token;
	__le16 cmd_id;
};

enum mc_cmd_status {
	MC_CMD_STATUS_OK = 0,
	MC_CMD_STATUS_READY = 1,
	MC_CMD_STATUS_AUTH_ERR = 3,
	MC_CMD_STATUS_NO_PRIVILEGE = 4,
	MC_CMD_STATUS_DMA_ERR = 5,
	MC_CMD_STATUS_CONFIG_ERR = 6,
	MC_CMD_STATUS_TIMEOUT = 7,
	MC_CMD_STATUS_NO_RESOURCE = 8,
	MC_CMD_STATUS_NO_MEMORY = 9,
	MC_CMD_STATUS_BUSY = 10,
	MC_CMD_STATUS_UNSUPPORTED_OP = 11,
	MC_CMD_STATUS_INVALID_STATE = 12,
};

struct fsl_mc_version {
	u32 major;
	u32 minor;
	u32 revision;
};

struct miscdevice___4 {
	int minor;
	const char *name;
	const struct file_operations___184 *fops;
	struct list_head list;
	struct device___138 *parent;
	struct device___138 *this_device;
	const struct attribute_group___172 **groups;
	const char *nodename;
	umode_t mode;
};

struct dpmng_rsp_get_version {
	__le32 revision;
	__le32 version_major;
	__le32 version_minor;
};

struct dprc_attributes {
	int container_id;
	u32 icid;
	int portal_id;
	u64 options;
};

enum dprc_region_type {
	DPRC_REGION_TYPE_MC_PORTAL = 0,
	DPRC_REGION_TYPE_QBMAN_PORTAL = 1,
	DPRC_REGION_TYPE_QBMAN_MEM_BACKED_PORTAL = 2,
};

struct dprc_region_desc {
	u32 base_offset;
	u32 size;
	u32 flags;
	enum dprc_region_type type;
	u64 base_address;
};

struct dprc_endpoint {
	char type[16];
	int id;
	u16 if_id;
};

struct fsl_mc_uapi {
	struct miscdevice___4 misc;
	struct device___138 *device;
	struct mutex mutex;
	u32 local_instance_in_use;
	struct fsl_mc_io___2 *static_mc_io;
};

struct fsl_mc_bus {
	struct fsl_mc_device___2 mc_dev;
	struct fsl_mc_resource_pool resource_pools[4];
	struct fsl_mc_device_irq___2 *irq_resources;
	struct mutex scan_mutex;
	struct dprc_attributes dprc_attr;
	struct fsl_mc_uapi uapi_misc;
	int irq_enabled;
};

struct fsl_mc_addr_translation_range;

struct fsl_mc {
	struct fsl_mc_device___2 *root_mc_bus_dev;
	u8 num_translation_ranges;
	struct fsl_mc_addr_translation_range *translation_ranges;
	void *fsl_mc_regs;
};

struct fsl_mc_addr_translation_range {
	enum dprc_region_type mc_region_type;
	u64 start_mc_offset;
	u64 end_mc_offset;
	phys_addr_t start_phys_addr;
};

struct file_operations___185;

struct device_link___3 {
	struct device___39 *supplier;
	struct list_head s_node;
	struct device___39 *consumer;
	struct list_head c_node;
	struct device___39 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fsl_mc_io___3;

struct fsl_mc_device_irq___3;

struct fsl_mc_resource___2;

struct fsl_mc_device___3 {
	struct device___39 dev;
	u64 dma_mask;
	u16 flags;
	u32 icid;
	u16 mc_handle;
	struct fsl_mc_io___3 *mc_io;
	struct fsl_mc_obj_desc obj_desc;
	struct resource *regions;
	struct fsl_mc_device_irq___3 **irqs;
	struct fsl_mc_resource___2 *resource;
	struct device_link___3 *consumer_link;
	char *driver_override;
};

struct fsl_mc_resource_pool___2;

struct fsl_mc_resource___2 {
	enum fsl_mc_pool_type type;
	s32 id;
	void *data;
	struct fsl_mc_resource_pool___2 *parent_pool;
	struct list_head node;
};

struct fsl_mc_bus___2;

struct fsl_mc_resource_pool___2 {
	enum fsl_mc_pool_type type;
	int max_count;
	int free_count;
	struct mutex mutex;
	struct list_head free_list;
	struct fsl_mc_bus___2 *mc_bus;
};

struct fsl_mc_device_irq___3 {
	struct msi_desc *msi_desc;
	struct fsl_mc_device___3 *mc_dev;
	u8 dev_irq_index;
	struct fsl_mc_resource___2 resource;
};

struct fsl_mc_io___3 {
	struct device___39 *dev;
	u16 flags;
	u32 portal_size;
	phys_addr_t portal_phys_addr;
	void *portal_virt_addr;
	struct fsl_mc_device___3 *dpmcp_dev;
	union {
		struct mutex mutex;
		raw_spinlock_t spinlock;
	};
};

struct miscdevice___5 {
	int minor;
	const char *name;
	const struct file_operations___185 *fops;
	struct list_head list;
	struct device___39 *parent;
	struct device___39 *this_device;
	const struct attribute_group___42 **groups;
	const char *nodename;
	umode_t mode;
};

struct fsl_mc_uapi___2 {
	struct miscdevice___5 misc;
	struct device___39 *device;
	struct mutex mutex;
	u32 local_instance_in_use;
	struct fsl_mc_io___3 *static_mc_io;
};

struct fsl_mc_bus___2 {
	struct fsl_mc_device___3 mc_dev;
	struct fsl_mc_resource_pool___2 resource_pools[4];
	struct fsl_mc_device_irq___3 *irq_resources;
	struct mutex scan_mutex;
	struct dprc_attributes dprc_attr;
	struct fsl_mc_uapi___2 uapi_misc;
	int irq_enabled;
};

struct device_link___4 {
	struct device___139 *supplier;
	struct list_head s_node;
	struct device___139 *consumer;
	struct list_head c_node;
	struct device___139 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fsl_mc_io___4;

struct fsl_mc_device_irq___4;

struct fsl_mc_resource___3;

struct fsl_mc_device___4 {
	struct device___139 dev;
	u64 dma_mask;
	u16 flags;
	u32 icid;
	u16 mc_handle;
	struct fsl_mc_io___4 *mc_io;
	struct fsl_mc_obj_desc obj_desc;
	struct resource *regions;
	struct fsl_mc_device_irq___4 **irqs;
	struct fsl_mc_resource___3 *resource;
	struct device_link___4 *consumer_link;
	char *driver_override;
};

struct fsl_mc_resource_pool___3;

struct fsl_mc_resource___3 {
	enum fsl_mc_pool_type type;
	s32 id;
	void *data;
	struct fsl_mc_resource_pool___3 *parent_pool;
	struct list_head node;
};

struct fsl_mc_bus___3;

struct fsl_mc_resource_pool___3 {
	enum fsl_mc_pool_type type;
	int max_count;
	int free_count;
	struct mutex mutex;
	struct list_head free_list;
	struct fsl_mc_bus___3 *mc_bus;
};

struct fsl_mc_device_irq___4 {
	struct msi_desc *msi_desc;
	struct fsl_mc_device___4 *mc_dev;
	u8 dev_irq_index;
	struct fsl_mc_resource___3 resource;
};

struct fsl_mc_io___4 {
	struct device___139 *dev;
	u16 flags;
	u32 portal_size;
	phys_addr_t portal_phys_addr;
	void *portal_virt_addr;
	struct fsl_mc_device___4 *dpmcp_dev;
	union {
		struct mutex mutex;
		raw_spinlock_t spinlock;
	};
};

struct miscdevice___6 {
	int minor;
	const char *name;
	const struct file_operations___185 *fops;
	struct list_head list;
	struct device___139 *parent;
	struct device___139 *this_device;
	const struct attribute_group___41 **groups;
	const char *nodename;
	umode_t mode;
};

struct fsl_mc_uapi___3 {
	struct miscdevice___6 misc;
	struct device___139 *device;
	struct mutex mutex;
	u32 local_instance_in_use;
	struct fsl_mc_io___4 *static_mc_io;
};

struct fsl_mc_bus___3 {
	struct fsl_mc_device___4 mc_dev;
	struct fsl_mc_resource_pool___3 resource_pools[4];
	struct fsl_mc_device_irq___4 *irq_resources;
	struct mutex scan_mutex;
	struct dprc_attributes dprc_attr;
	struct fsl_mc_uapi___3 uapi_misc;
	int irq_enabled;
};

struct dpbp_attr {
	int id;
	u16 bpid;
};

struct dpbp_cmd_open {
	__le32 dpbp_id;
};

struct dpbp_rsp_get_attributes {
	__le16 pad;
	__le16 bpid;
	__le32 id;
	__le16 version_major;
	__le16 version_minor;
};

struct dpcon_attr {
	int id;
	u16 qbman_ch_id;
	u8 num_priorities;
};

struct dpcon_notification_cfg {
	int dpio_id;
	u8 priority;
	u64 user_ctx;
};

struct dpcon_cmd_open {
	__le32 dpcon_id;
};

struct dpcon_rsp_get_attr {
	__le32 id;
	__le16 qbman_ch_id;
	u8 num_priorities;
	u8 pad;
};

struct dpcon_cmd_set_notification {
	__le32 dpio_id;
	u8 priority;
	u8 pad[3];
	__le64 user_ctx;
};

struct mc_rsp_create {
	__le32 object_id;
};

struct mc_rsp_api_ver {
	__le16 major_ver;
	__le16 minor_ver;
};

struct dprc_cmd_open {
	__le32 container_id;
};

struct dprc_cmd_reset_container {
	__le32 child_container_id;
	__le32 options;
};

struct dprc_cmd_set_irq {
	__le32 irq_val;
	u8 irq_index;
	u8 pad[3];
	__le64 irq_addr;
	__le32 irq_num;
};

struct dprc_cmd_set_irq_enable {
	u8 enable;
	u8 pad[3];
	u8 irq_index;
};

struct dprc_cmd_set_irq_mask {
	__le32 mask;
	u8 irq_index;
};

struct dprc_cmd_get_irq_status {
	__le32 status;
	u8 irq_index;
};

struct dprc_rsp_get_irq_status {
	__le32 status;
};

struct dprc_cmd_clear_irq_status {
	__le32 status;
	u8 irq_index;
};

struct dprc_rsp_get_attributes {
	__le32 container_id;
	__le32 icid;
	__le32 options;
	__le32 portal_id;
};

struct dprc_rsp_get_obj_count {
	__le32 pad;
	__le32 obj_count;
};

struct dprc_cmd_get_obj {
	__le32 obj_index;
};

struct dprc_rsp_get_obj {
	__le32 pad0;
	__le32 id;
	__le16 vendor;
	u8 irq_count;
	u8 region_count;
	__le32 state;
	__le16 version_major;
	__le16 version_minor;
	__le16 flags;
	__le16 pad1;
	u8 type[16];
	u8 label[16];
};

struct dprc_cmd_get_obj_region {
	__le32 obj_id;
	__le16 pad0;
	u8 region_index;
	u8 pad1;
	__le64 pad2[2];
	u8 obj_type[16];
};

struct dprc_rsp_get_obj_region {
	__le64 pad0;
	__le64 base_offset;
	__le32 size;
	u8 type;
	u8 pad2[3];
	__le32 flags;
	__le32 pad3;
	__le64 base_addr;
};

struct dprc_cmd_set_obj_irq {
	__le32 irq_val;
	u8 irq_index;
	u8 pad[3];
	__le64 irq_addr;
	__le32 irq_num;
	__le32 obj_id;
	u8 obj_type[16];
};

struct dprc_cmd_get_connection {
	__le32 ep1_id;
	__le16 ep1_interface_id;
	u8 pad[2];
	u8 ep1_type[16];
};

struct dprc_rsp_get_connection {
	__le64 pad[3];
	__le32 ep2_id;
	__le16 ep2_interface_id;
	__le16 pad1;
	u8 ep2_type[16];
	__le32 state;
};

struct dprc_irq_cfg {
	phys_addr_t paddr;
	u32 val;
	int irq_num;
};

struct fsl_mc_child_objs {
	int child_count;
	struct fsl_mc_obj_desc *child_array;
};

enum device_link_state___2 {
	DL_STATE_NONE___2 = 4294967295,
	DL_STATE_DORMANT___2 = 0,
	DL_STATE_AVAILABLE___2 = 1,
	DL_STATE_CONSUMER_PROBE___2 = 2,
	DL_STATE_ACTIVE___2 = 3,
	DL_STATE_SUPPLIER_UNBIND___2 = 4,
};

struct device_link___5 {
	struct device___136 *supplier;
	struct list_head s_node;
	struct device___136 *consumer;
	struct list_head c_node;
	struct device___136 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fsl_mc_io___5;

struct fsl_mc_device_irq___5;

struct fsl_mc_resource___4;

struct fsl_mc_device___5 {
	struct device___136 dev;
	u64 dma_mask;
	u16 flags;
	u32 icid;
	u16 mc_handle;
	struct fsl_mc_io___5 *mc_io;
	struct fsl_mc_obj_desc obj_desc;
	struct resource *regions;
	struct fsl_mc_device_irq___5 **irqs;
	struct fsl_mc_resource___4 *resource;
	struct device_link___5 *consumer_link;
	char *driver_override;
};

struct fsl_mc_resource_pool___4;

struct fsl_mc_resource___4 {
	enum fsl_mc_pool_type type;
	s32 id;
	void *data;
	struct fsl_mc_resource_pool___4 *parent_pool;
	struct list_head node;
};

struct fsl_mc_bus___4;

struct fsl_mc_resource_pool___4 {
	enum fsl_mc_pool_type type;
	int max_count;
	int free_count;
	struct mutex mutex;
	struct list_head free_list;
	struct fsl_mc_bus___4 *mc_bus;
};

struct fsl_mc_device_irq___5 {
	struct msi_desc___5 *msi_desc;
	struct fsl_mc_device___5 *mc_dev;
	u8 dev_irq_index;
	struct fsl_mc_resource___4 resource;
};

struct fsl_mc_io___5 {
	struct device___136 *dev;
	u16 flags;
	u32 portal_size;
	phys_addr_t portal_phys_addr;
	void *portal_virt_addr;
	struct fsl_mc_device___5 *dpmcp_dev;
	union {
		struct mutex mutex;
		raw_spinlock_t spinlock;
	};
};

struct miscdevice___7 {
	int minor;
	const char *name;
	const struct file_operations___177 *fops;
	struct list_head list;
	struct device___136 *parent;
	struct device___136 *this_device;
	const struct attribute_group___164 **groups;
	const char *nodename;
	umode_t mode;
};

struct fsl_mc_uapi___4 {
	struct miscdevice___7 misc;
	struct device___136 *device;
	struct mutex mutex;
	u32 local_instance_in_use;
	struct fsl_mc_io___5 *static_mc_io;
};

struct fsl_mc_bus___4 {
	struct fsl_mc_device___5 mc_dev;
	struct fsl_mc_resource_pool___4 resource_pools[4];
	struct fsl_mc_device_irq___5 *irq_resources;
	struct mutex scan_mutex;
	struct dprc_attributes dprc_attr;
	struct fsl_mc_uapi___4 uapi_misc;
	int irq_enabled;
};

struct device_link___6 {
	struct device___139 *supplier;
	struct list_head s_node;
	struct device___139 *consumer;
	struct list_head c_node;
	struct device___139 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fsl_mc_io___6;

struct fsl_mc_device_irq___6;

struct fsl_mc_resource___5;

struct fsl_mc_device___6 {
	struct device___139 dev;
	u64 dma_mask;
	u16 flags;
	u32 icid;
	u16 mc_handle;
	struct fsl_mc_io___6 *mc_io;
	struct fsl_mc_obj_desc obj_desc;
	struct resource *regions;
	struct fsl_mc_device_irq___6 **irqs;
	struct fsl_mc_resource___5 *resource;
	struct device_link___6 *consumer_link;
	char *driver_override;
};

struct fsl_mc_resource_pool___5;

struct fsl_mc_resource___5 {
	enum fsl_mc_pool_type type;
	s32 id;
	void *data;
	struct fsl_mc_resource_pool___5 *parent_pool;
	struct list_head node;
};

struct fsl_mc_bus___5;

struct fsl_mc_resource_pool___5 {
	enum fsl_mc_pool_type type;
	int max_count;
	int free_count;
	struct mutex mutex;
	struct list_head free_list;
	struct fsl_mc_bus___5 *mc_bus;
};

struct fsl_mc_device_irq___6 {
	struct msi_desc *msi_desc;
	struct fsl_mc_device___6 *mc_dev;
	u8 dev_irq_index;
	struct fsl_mc_resource___5 resource;
};

struct fsl_mc_io___6 {
	struct device___139 *dev;
	u16 flags;
	u32 portal_size;
	phys_addr_t portal_phys_addr;
	void *portal_virt_addr;
	struct fsl_mc_device___6 *dpmcp_dev;
	union {
		struct mutex mutex;
		raw_spinlock_t spinlock;
	};
};

struct dpmcp_cmd_open {
	__le32 dpmcp_id;
};

struct fsl_mc_uapi___5 {
	struct miscdevice___6 misc;
	struct device___139 *device;
	struct mutex mutex;
	u32 local_instance_in_use;
	struct fsl_mc_io___6 *static_mc_io;
};

struct fsl_mc_bus___5 {
	struct fsl_mc_device___6 mc_dev;
	struct fsl_mc_resource_pool___5 resource_pools[4];
	struct fsl_mc_device_irq___6 *irq_resources;
	struct mutex scan_mutex;
	struct dprc_attributes dprc_attr;
	struct fsl_mc_uapi___5 uapi_misc;
	int irq_enabled;
};

struct uapi_priv_data {
	struct fsl_mc_uapi *uapi;
	struct fsl_mc_io___2 *mc_io;
};

struct fsl_mc_cmd_desc {
	u16 cmdid_value;
	u16 cmdid_mask;
	int size;
	bool token;
	int flags;
};

enum fsl_mc_cmd_index {
	DPDBG_DUMP = 0,
	DPDBG_SET = 1,
	DPRC_GET_CONTAINER_ID = 2,
	DPRC_CREATE_CONT = 3,
	DPRC_DESTROY_CONT = 4,
	DPRC_ASSIGN = 5,
	DPRC_UNASSIGN = 6,
	DPRC_GET_OBJ_COUNT = 7,
	DPRC_GET_OBJ = 8,
	DPRC_GET_RES_COUNT = 9,
	DPRC_GET_RES_IDS = 10,
	DPRC_SET_OBJ_LABEL = 11,
	DPRC_SET_LOCKED = 12,
	DPRC_CONNECT = 13,
	DPRC_DISCONNECT = 14,
	DPRC_GET_POOL = 15,
	DPRC_GET_POOL_COUNT = 16,
	DPRC_GET_CONNECTION = 17,
	DPCI_GET_LINK_STATE = 18,
	DPCI_GET_PEER_ATTR = 19,
	DPAIOP_GET_SL_VERSION = 20,
	DPAIOP_GET_STATE = 21,
	DPMNG_GET_VERSION = 22,
	DPSECI_GET_TX_QUEUE = 23,
	DPMAC_GET_COUNTER = 24,
	DPMAC_GET_MAC_ADDR = 25,
	DPNI_SET_PRIM_MAC = 26,
	DPNI_GET_PRIM_MAC = 27,
	DPNI_GET_STATISTICS = 28,
	DPNI_GET_LINK_STATE = 29,
	DPNI_GET_MAX_FRAME_LENGTH = 30,
	DPSW_GET_TAILDROP = 31,
	DPSW_SET_TAILDROP = 32,
	DPSW_IF_GET_COUNTER = 33,
	DPSW_IF_GET_MAX_FRAME_LENGTH = 34,
	DPDMUX_GET_COUNTER = 35,
	DPDMUX_IF_GET_MAX_FRAME_LENGTH = 36,
	GET_ATTR = 37,
	GET_IRQ_MASK = 38,
	GET_IRQ_STATUS = 39,
	CLOSE = 40,
	OPEN = 41,
	GET_API_VERSION = 42,
	DESTROY = 43,
	CREATE = 44,
};

struct imx_weim_devtype {
	unsigned int cs_count;
	unsigned int cs_regs_count;
	unsigned int cs_stride;
	unsigned int wcr_offset;
	unsigned int wcr_bcm;
};

struct cs_timing {
	bool is_applied;
	u32 regs[6];
};

struct cs_timing_state {
	struct cs_timing cs[6];
};

struct cs_data {
	u32 enable_mask;
	u16 slow_cfg;
	u16 fast_cfg;
};

struct ebi2_xmem_prop {
	const char *prop;
	u32 max;
	bool slowreg;
	u16 shift;
};

typedef void (*dr_release_t___8)(struct device___140 *, void *);

enum regcache_type {
	REGCACHE_NONE = 0,
	REGCACHE_RBTREE = 1,
	REGCACHE_COMPRESSED = 2,
	REGCACHE_FLAT = 3,
};

struct reg_default {
	unsigned int reg;
	unsigned int def;
};

enum regmap_endian {
	REGMAP_ENDIAN_DEFAULT = 0,
	REGMAP_ENDIAN_BIG = 1,
	REGMAP_ENDIAN_LITTLE = 2,
	REGMAP_ENDIAN_NATIVE = 3,
};

struct regmap_range {
	unsigned int range_min;
	unsigned int range_max;
};

struct regmap_access_table {
	const struct regmap_range *yes_ranges;
	unsigned int n_yes_ranges;
	const struct regmap_range *no_ranges;
	unsigned int n_no_ranges;
};

typedef void (*regmap_lock)(void *);

typedef void (*regmap_unlock)(void *);

struct regmap_range_cfg;

struct regmap_config {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___140 *, unsigned int);
	bool (*readable_reg)(struct device___140 *, unsigned int);
	bool (*volatile_reg)(struct device___140 *, unsigned int);
	bool (*precious_reg)(struct device___140 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___140 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___140 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct regmap_range_cfg {
	const char *name;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

typedef int (*regmap_hw_write)(void *, const void *, size_t);

typedef int (*regmap_hw_gather_write)(void *, const void *, size_t, const void *, size_t);

struct regmap_async;

typedef int (*regmap_hw_async_write)(void *, const void *, size_t, const void *, size_t, struct regmap_async *);

typedef int (*regmap_hw_read)(void *, const void *, size_t, void *, size_t);

typedef int (*regmap_hw_reg_read)(void *, unsigned int, unsigned int *);

typedef int (*regmap_hw_reg_write)(void *, unsigned int, unsigned int);

typedef int (*regmap_hw_reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);

typedef struct regmap_async * (*regmap_hw_async_alloc)();

typedef void (*regmap_hw_free_context)(void *);

struct regmap_bus {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
	bool free_on_exit;
};

struct vexpress_syscfg {
	struct device___140 *dev;
	void *base;
	struct list_head funcs;
};

struct vexpress_syscfg_func {
	struct list_head list;
	struct vexpress_syscfg *syscfg;
	struct regmap *regmap;
	int num_templates;
	u32 template[0];
};

struct vexpress_config_bridge_ops {
	struct regmap * (*regmap_init)(struct device___140 *, void *);
	void (*regmap_exit)(struct regmap *, void *);
};

struct vexpress_config_bridge {
	struct vexpress_config_bridge_ops *ops;
	void *context;
};

struct class_dev_iter___2 {
	struct klist_iter ki;
	const struct device_type___22 *type;
};

typedef void (*dr_release_t___9)(struct device___22 *, void *);

typedef int (*dr_match_t___7)(struct device___22 *, void *, void *);

struct device_link___7 {
	struct device___22 *supplier;
	struct list_head s_node;
	struct device___22 *consumer;
	struct list_head c_node;
	struct device___22 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct of_phandle_args___8 {
	struct device_node___15 *np;
	int args_count;
	uint32_t args[16];
};

struct phy_configure_opts_dp {
	unsigned int link_rate;
	unsigned int lanes;
	unsigned int voltage[4];
	unsigned int pre[4];
	u8 ssc: 1;
	u8 set_rate: 1;
	u8 set_lanes: 1;
	u8 set_voltages: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct phy_configure_opts_mipi_dphy {
	unsigned int clk_miss;
	unsigned int clk_post;
	unsigned int clk_pre;
	unsigned int clk_prepare;
	unsigned int clk_settle;
	unsigned int clk_term_en;
	unsigned int clk_trail;
	unsigned int clk_zero;
	unsigned int d_term_en;
	unsigned int eot;
	unsigned int hs_exit;
	unsigned int hs_prepare;
	unsigned int hs_settle;
	unsigned int hs_skip;
	unsigned int hs_trail;
	unsigned int hs_zero;
	unsigned int init;
	unsigned int lpx;
	unsigned int ta_get;
	unsigned int ta_go;
	unsigned int ta_sure;
	unsigned int wakeup;
	long unsigned int hs_clk_rate;
	long unsigned int lp_clk_rate;
	unsigned char lanes;
};

enum phy_mode {
	PHY_MODE_INVALID = 0,
	PHY_MODE_USB_HOST = 1,
	PHY_MODE_USB_HOST_LS = 2,
	PHY_MODE_USB_HOST_FS = 3,
	PHY_MODE_USB_HOST_HS = 4,
	PHY_MODE_USB_HOST_SS = 5,
	PHY_MODE_USB_DEVICE = 6,
	PHY_MODE_USB_DEVICE_LS = 7,
	PHY_MODE_USB_DEVICE_FS = 8,
	PHY_MODE_USB_DEVICE_HS = 9,
	PHY_MODE_USB_DEVICE_SS = 10,
	PHY_MODE_USB_OTG = 11,
	PHY_MODE_UFS_HS_A = 12,
	PHY_MODE_UFS_HS_B = 13,
	PHY_MODE_PCIE = 14,
	PHY_MODE_ETHERNET = 15,
	PHY_MODE_MIPI_DPHY = 16,
	PHY_MODE_SATA = 17,
	PHY_MODE_LVDS = 18,
	PHY_MODE_DP = 19,
};

enum phy_media {
	PHY_MEDIA_DEFAULT = 0,
	PHY_MEDIA_SR = 1,
	PHY_MEDIA_DAC = 2,
};

union phy_configure_opts {
	struct phy_configure_opts_mipi_dphy mipi_dphy;
	struct phy_configure_opts_dp dp;
};

struct phy;

struct phy_ops {
	int (*init)(struct phy *);
	int (*exit)(struct phy *);
	int (*power_on)(struct phy *);
	int (*power_off)(struct phy *);
	int (*set_mode)(struct phy *, enum phy_mode, int);
	int (*set_media)(struct phy *, enum phy_media);
	int (*set_speed)(struct phy *, int);
	int (*configure)(struct phy *, union phy_configure_opts *);
	int (*validate)(struct phy *, enum phy_mode, int, union phy_configure_opts *);
	int (*reset)(struct phy *);
	int (*calibrate)(struct phy *);
	void (*release)(struct phy *);
	struct module___26 *owner;
};

struct phy_attrs {
	u32 bus_width;
	u32 max_link_rate;
	enum phy_mode mode;
};

struct regulator;

struct phy {
	struct device___22 dev;
	int id;
	const struct phy_ops *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct phy_provider {
	struct device___22 *dev;
	struct device_node___15 *children;
	struct module___26 *owner;
	struct list_head list;
	struct phy * (*of_xlate)(struct device___22 *, struct of_phandle_args___8 *);
};

struct phy_lookup {
	struct list_head node;
	const char *dev_id;
	const char *con_id;
	struct phy *phy;
};

struct module_version_attribute___4 {
	struct module_attribute___24 mattr;
	const char *module_name;
	const char *version;
};

struct platform_device___9 {
	const char *name;
	int id;
	bool id_auto;
	struct device___22 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___8 {
	int (*probe)(struct platform_device___9 *);
	int (*remove)(struct platform_device___9 *);
	void (*shutdown)(struct platform_device___9 *);
	int (*suspend)(struct platform_device___9 *, pm_message_t);
	int (*resume)(struct platform_device___9 *);
	struct device_driver___22 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum cmu_type_t {
	REF_CMU = 0,
	PHY_CMU = 1,
};

enum clk_type_t {
	CLK_EXT_DIFF = 0,
	CLK_INT_DIFF = 1,
	CLK_INT_SING = 2,
};

enum xgene_phy_mode {
	MODE_SATA = 0,
	MODE_SGMII = 1,
	MODE_PCIE = 2,
	MODE_USB = 3,
	MODE_XFI = 4,
	MODE_MAX___2 = 5,
};

struct xgene_sata_override_param {
	u32 speed[2];
	u32 txspeed[3];
	u32 txboostgain[6];
	u32 txeyetuning[6];
	u32 txeyedirection[6];
	u32 txamplitude[6];
	u32 txprecursor_cn1[6];
	u32 txprecursor_cn2[6];
	u32 txpostcursor_cp1[6];
};

struct xgene_phy_ctx {
	struct device___22 *dev;
	struct phy *phy;
	enum xgene_phy_mode mode;
	enum clk_type_t clk_type;
	void *sds_base;
	struct clk *clk;
	struct xgene_sata_override_param sata_param;
};

struct of_phandle_args___9 {
	struct device_node___25 *np;
	int args_count;
	uint32_t args[16];
};

struct phy_configure_opts_dp___2 {
	unsigned int link_rate;
	unsigned int lanes;
	unsigned int voltage[4];
	unsigned int pre[4];
	u8 ssc: 1;
	u8 set_rate;
	u8 set_lanes;
	u8 set_voltages;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union phy_configure_opts___2 {
	struct phy_configure_opts_mipi_dphy mipi_dphy;
	struct phy_configure_opts_dp___2 dp;
};

struct phy___2;

struct phy_ops___2 {
	int (*init)(struct phy___2 *);
	int (*exit)(struct phy___2 *);
	int (*power_on)(struct phy___2 *);
	int (*power_off)(struct phy___2 *);
	int (*set_mode)(struct phy___2 *, enum phy_mode, int);
	int (*set_media)(struct phy___2 *, enum phy_media);
	int (*set_speed)(struct phy___2 *, int);
	int (*configure)(struct phy___2 *, union phy_configure_opts___2 *);
	int (*validate)(struct phy___2 *, enum phy_mode, int, union phy_configure_opts___2 *);
	int (*reset)(struct phy___2 *);
	int (*calibrate)(struct phy___2 *);
	void (*release)(struct phy___2 *);
	struct module___43 *owner;
};

struct phy___2 {
	struct device___40 dev;
	int id;
	const struct phy_ops___2 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct phy_provider___2 {
	struct device___40 *dev;
	struct device_node___25 *children;
	struct module___43 *owner;
	struct list_head list;
	struct phy___2 * (*of_xlate)(struct device___40 *, struct of_phandle_args___9 *);
};

struct regmap_config___2 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___40 *, unsigned int);
	bool (*readable_reg)(struct device___40 *, unsigned int);
	bool (*volatile_reg)(struct device___40 *, unsigned int);
	bool (*precious_reg)(struct device___40 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___40 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___40 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct reset_control;

struct platform_device___10 {
	const char *name;
	int id;
	bool id_auto;
	struct device___40 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___9 {
	int (*probe)(struct platform_device___10 *);
	int (*remove)(struct platform_device___10 *);
	void (*shutdown)(struct platform_device___10 *);
	int (*suspend)(struct platform_device___10 *, pm_message_t);
	int (*resume)(struct platform_device___10 *);
	struct device_driver___40 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct phy_axg_pcie_priv {
	struct phy___2 *phy;
	struct phy___2 *analog;
	struct regmap *regmap;
	struct reset_control *reset;
};

struct phy_axg_mipi_pcie_analog_priv {
	struct phy___2 *phy;
	struct regmap *regmap;
	bool dsi_configured;
	bool dsi_enabled;
	bool powered;
	struct phy_configure_opts_mipi_dphy config;
};

struct dentry___185;

struct super_block___185;

struct module___169;

struct file_system_type___185 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___185 * (*mount)(struct file_system_type___185 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___185 *);
	struct module___169 *owner;
	struct file_system_type___185 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___185;

struct kiocb___185;

struct iov_iter___109;

struct vm_area_struct___190;

struct inode___185;

struct file_lock___185;

struct page___190;

struct pipe_inode_info___63;

struct seq_file___161;

struct file_operations___186 {
	struct module___169 *owner;
	loff_t (*llseek)(struct file___185 *, loff_t, int);
	ssize_t (*read)(struct file___185 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___185 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___185 *, struct iov_iter___109 *);
	ssize_t (*write_iter)(struct kiocb___185 *, struct iov_iter___109 *);
	int (*iopoll)(struct kiocb___185 *, bool);
	int (*iterate)(struct file___185 *, struct dir_context *);
	int (*iterate_shared)(struct file___185 *, struct dir_context *);
	__poll_t (*poll)(struct file___185 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___185 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___185 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___185 *, struct vm_area_struct___190 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___185 *, struct file___185 *);
	int (*flush)(struct file___185 *, fl_owner_t);
	int (*release)(struct inode___185 *, struct file___185 *);
	int (*fsync)(struct file___185 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___185 *, int);
	int (*lock)(struct file___185 *, int, struct file_lock___185 *);
	ssize_t (*sendpage)(struct file___185 *, struct page___190 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___185 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___185 *, long unsigned int);
	int (*flock)(struct file___185 *, int, struct file_lock___185 *);
	ssize_t (*splice_write)(struct pipe_inode_info___63 *, struct file___185 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___185 *, loff_t *, struct pipe_inode_info___63 *, size_t, unsigned int);
	int (*setlease)(struct file___185 *, long int, struct file_lock___185 **, void **);
	long int (*fallocate)(struct file___185 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___161 *, struct file___185 *);
	ssize_t (*copy_file_range)(struct file___185 *, loff_t, struct file___185 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___185 *, loff_t, struct file___185 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___185 *, loff_t, loff_t, int);
};

struct vmacache___190 {
	u64 seqnum;
	struct vm_area_struct___190 *vmas[4];
};

struct page_frag___190 {
	struct page___190 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___191;

struct pid___164;

struct nsproxy___173;

struct signal_struct___186;

struct bio_list___91;

struct backing_dev_info___84;

struct io_context___91;

struct css_set___125;

struct mem_cgroup___75;

struct request_queue___91;

struct vm_struct___168;

struct task_struct___192 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___192 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___191 *mm;
	struct mm_struct___191 *active_mm;
	struct vmacache___190 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___192 *real_parent;
	struct task_struct___192 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___192 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___164 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___173 *nsproxy;
	struct signal_struct___186 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___192 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___91 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___84 *backing_dev_info;
	struct io_context___91 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___125 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___63 *splice_pipe;
	struct page_frag___190 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___75 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___75 *active_memcg;
	struct request_queue___91 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___192 *oom_reaper_list;
	struct vm_struct___168 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___173;

struct kobj_type___173;

struct kernfs_node___173;

struct kobject___173 {
	const char *name;
	struct list_head entry;
	struct kobject___173 *parent;
	struct kset___173 *kset;
	struct kobj_type___173 *ktype;
	struct kernfs_node___173 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___169 {
	struct kobject___173 kobj;
	struct module___169 *mod;
	struct kobject___173 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___169 {
	struct module___169 *mod;
	struct latch_tree_node node;
};

struct module_layout___169 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___169 mtn;
};

struct module_attribute___169;

struct kernel_param___169;

struct module___169 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___169 mkobj;
	struct module_attribute___169 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___173 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___169 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___169 core_layout;
	struct module_layout___169 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___164;

struct upid___164 {
	int nr;
	struct pid_namespace___164 *ns;
};

struct pid_namespace___164 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___192 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___164 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___164 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___164 numbers[1];
};

typedef struct page___190 *pgtable_t___190;

struct address_space___185;

struct page_pool___53;

struct dev_pagemap___180;

struct page___190 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___185 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___190 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___190 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___191 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___180 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___180;

struct vm_area_struct___190 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___190 *vm_next;
	struct vm_area_struct___190 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___191 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___180 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___185 *vm_file;
	struct file___185 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___186 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___192 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___192 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___164 *pids[4];
	struct pid___164 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___191 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___190;

struct mm_struct___191 {
	struct {
		struct vm_area_struct___190 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___185 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___190 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___192 *owner;
		struct user_namespace___25 *user_ns;
		struct file___185 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___125;

struct nsproxy___173 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___164 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___125 *cgroup_ns;
};

struct bio___91;

struct bio_list___91 {
	struct bio___91 *head;
	struct bio___91 *tail;
};

struct cgroup_subsys_state___125;

struct bdi_writeback___84 {
	struct backing_dev_info___84 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___125 *memcg_css;
	struct cgroup_subsys_state___125 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___141;

struct backing_dev_info___84 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___84 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___141 *dev;
	char dev_name[64];
	struct device___141 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___185 *debug_dir;
};

struct io_cq___91;

struct io_context___91 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___91 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___125;

struct css_set___125 {
	struct cgroup_subsys_state___125 *subsys[14];
	refcount_t refcount;
	struct css_set___125 *dom_cset;
	struct cgroup___125 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___125 *mg_src_cgrp;
	struct cgroup___125 *mg_dst_cgrp;
	struct css_set___125 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___185;

struct pipe_buffer___63;

struct pipe_inode_info___63 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___190 *tmp_page;
	struct fasync_struct___185 *fasync_readers;
	struct fasync_struct___185 *fasync_writers;
	struct pipe_buffer___63 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___125;

struct cgroup_subsys_state___125 {
	struct cgroup___125 *cgroup;
	struct cgroup_subsys___125 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___125 *parent;
};

struct cgroup_file___125 {
	struct kernfs_node___173 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___75;

struct mem_cgroup_per_node___75;

struct mem_cgroup___75 {
	struct cgroup_subsys_state___125 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___125 events_file;
	struct cgroup_file___125 events_local_file;
	struct cgroup_file___125 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___75 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___192 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___75 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___91;

struct blk_integrity___91 {
	const struct blk_integrity_profile___91 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___91 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___91 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___91;

struct elevator_queue___91;

struct blk_mq_ops___88;

struct blk_mq_hw_ctx___88;

struct gendisk___92;

struct blkcg_gq___86;

struct blk_mq_tag_set___88;

struct request_queue___91 {
	struct request___91 *last_merge;
	struct elevator_queue___91 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___88 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___88 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___92 *disk;
	struct kobject___173 kobj;
	struct kobject___173 *mq_kobj;
	struct blk_integrity___91 integrity;
	struct device___141 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___86 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___88 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___91 bio_split;
	struct dentry___185 *debugfs_dir;
	struct dentry___185 *sched_debugfs_dir;
	struct dentry___185 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___168 {
	struct vm_struct___168 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___190 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___185;

struct address_space___185 {
	struct inode___185 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___185 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___53 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___141 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___53 {
	u32 count;
	struct page___190 *cache[128];
};

struct page_pool___53 {
	struct page_pool_params___53 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___190 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___53 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___180;

struct dev_pagemap___180 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___180 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___185;

struct path___185 {
	struct vfsmount___185 *mnt;
	struct dentry___185 *dentry;
};

struct fown_struct___164 {
	rwlock_t lock;
	struct pid___164 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___185 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___185 f_path;
	struct inode___185 *f_inode;
	const struct file_operations___186 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___164 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___185 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___180;

struct vm_operations_struct___180 {
	void (*open)(struct vm_area_struct___190 *);
	void (*close)(struct vm_area_struct___190 *);
	int (*may_split)(struct vm_area_struct___190 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___190 *);
	int (*mprotect)(struct vm_area_struct___190 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___180 *);
	vm_fault_t (*huge_fault)(struct vm_fault___180 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___180 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___190 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___180 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___180 *);
	int (*access)(struct vm_area_struct___190 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___190 *);
	int (*set_policy)(struct vm_area_struct___190 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___190 *, long unsigned int);
	struct page___190 * (*find_special_page)(struct vm_area_struct___190 *, long unsigned int);
};

struct core_thread___190 {
	struct task_struct___192 *task;
	struct core_thread___190 *next;
};

struct core_state___190 {
	atomic_t nr_threads;
	struct core_thread___190 dumper;
	struct completion startup;
};

struct vm_fault___180 {
	const struct {
		struct vm_area_struct___190 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___190 *cow_page;
	struct page___190 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___190 prealloc_pte;
};

struct pglist_data___82;

struct lruvec___82 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___82 *pgdat;
};

struct zone___82 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___82 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___82 {
	struct zone___82 *zone;
	int zone_idx;
};

struct zonelist___82 {
	struct zoneref___82 _zonerefs[321];
};

struct pglist_data___82 {
	struct zone___82 node_zones[5];
	struct zonelist___82 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___192 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___192 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___82 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___173;

struct kernfs_elem_dir___173 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___173 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___173;

struct kernfs_root___173 {
	struct kernfs_node___173 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___173 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___173 {
	struct kernfs_node___173 *target_kn;
};

struct kernfs_ops___173;

struct kernfs_elem_attr___173 {
	const struct kernfs_ops___173 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___173 *notify_next;
};

struct kernfs_node___173 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___173 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___173 dir;
		struct kernfs_elem_symlink___173 symlink;
		struct kernfs_elem_attr___173 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___173;

struct kernfs_ops___173 {
	int (*open)(struct kernfs_open_file___173 *);
	void (*release)(struct kernfs_open_file___173 *);
	int (*seq_show)(struct seq_file___161 *, void *);
	void * (*seq_start)(struct seq_file___161 *, loff_t *);
	void * (*seq_next)(struct seq_file___161 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___161 *, void *);
	ssize_t (*read)(struct kernfs_open_file___173 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___173 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___173 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___173 *, struct vm_area_struct___190 *);
};

struct kernfs_syscall_ops___173 {
	int (*show_options)(struct seq_file___161 *, struct kernfs_root___173 *);
	int (*mkdir)(struct kernfs_node___173 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___173 *);
	int (*rename)(struct kernfs_node___173 *, struct kernfs_node___173 *, const char *);
	int (*show_path)(struct seq_file___161 *, struct kernfs_node___173 *, struct kernfs_root___173 *);
};

struct seq_operations___161;

struct seq_file___161 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___161 *op;
	int poll_event;
	const struct file___185 *file;
	void *private;
};

struct kernfs_open_file___173 {
	struct kernfs_node___173 *kn;
	struct file___185 *file;
	struct seq_file___161 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___180 *vm_ops;
};

struct bin_attribute___173;

struct attribute_group___173 {
	const char *name;
	umode_t (*is_visible)(struct kobject___173 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___173 *, struct bin_attribute___173 *, int);
	struct attribute **attrs;
	struct bin_attribute___173 **bin_attrs;
};

struct bin_attribute___173 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___185 * (*f_mapping)();
	ssize_t (*read)(struct file___185 *, struct kobject___173 *, struct bin_attribute___173 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___185 *, struct kobject___173 *, struct bin_attribute___173 *, char *, loff_t, size_t);
	int (*mmap)(struct file___185 *, struct kobject___173 *, struct bin_attribute___173 *, struct vm_area_struct___190 *);
};

struct sysfs_ops___173 {
	ssize_t (*show)(struct kobject___173 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___173 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___173;

struct kset___173 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___173 kobj;
	const struct kset_uevent_ops___173 *uevent_ops;
};

struct kobj_type___173 {
	void (*release)(struct kobject___173 *);
	const struct sysfs_ops___173 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___173 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___173 *);
	const void * (*namespace)(struct kobject___173 *);
	void (*get_ownership)(struct kobject___173 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___173 {
	int (* const filter)(struct kset___173 *, struct kobject___173 *);
	const char * (* const name)(struct kset___173 *, struct kobject___173 *);
	int (* const uevent)(struct kset___173 *, struct kobject___173 *, struct kobj_uevent_env *);
};

struct wakeup_source___141;

struct dev_pm_info___141 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___141 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___141 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___141;

struct bus_type___141;

struct device_driver___141;

struct dev_pm_domain___141;

struct device_node___43;

struct fwnode_handle___141;

struct class___141;

struct device___141 {
	struct kobject___173 kobj;
	struct device___141 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___141 *type;
	struct bus_type___141 *bus;
	struct device_driver___141 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___141 power;
	struct dev_pm_domain___141 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___43 *of_node;
	struct fwnode_handle___141 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___141 *class;
	const struct attribute_group___173 **groups;
	void (*release)(struct device___141 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___141 {
	int (*prepare)(struct device___141 *);
	void (*complete)(struct device___141 *);
	int (*suspend)(struct device___141 *);
	int (*resume)(struct device___141 *);
	int (*freeze)(struct device___141 *);
	int (*thaw)(struct device___141 *);
	int (*poweroff)(struct device___141 *);
	int (*restore)(struct device___141 *);
	int (*suspend_late)(struct device___141 *);
	int (*resume_early)(struct device___141 *);
	int (*freeze_late)(struct device___141 *);
	int (*thaw_early)(struct device___141 *);
	int (*poweroff_late)(struct device___141 *);
	int (*restore_early)(struct device___141 *);
	int (*suspend_noirq)(struct device___141 *);
	int (*resume_noirq)(struct device___141 *);
	int (*freeze_noirq)(struct device___141 *);
	int (*thaw_noirq)(struct device___141 *);
	int (*poweroff_noirq)(struct device___141 *);
	int (*restore_noirq)(struct device___141 *);
	int (*runtime_suspend)(struct device___141 *);
	int (*runtime_resume)(struct device___141 *);
	int (*runtime_idle)(struct device___141 *);
};

struct wakeup_source___141 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___141 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___141 {
	struct dev_pm_ops___141 ops;
	int (*start)(struct device___141 *);
	void (*detach)(struct device___141 *, bool);
	int (*activate)(struct device___141 *);
	void (*sync)(struct device___141 *);
	void (*dismiss)(struct device___141 *);
};

struct bus_type___141 {
	const char *name;
	const char *dev_name;
	struct device___141 *dev_root;
	const struct attribute_group___173 **bus_groups;
	const struct attribute_group___173 **dev_groups;
	const struct attribute_group___173 **drv_groups;
	int (*match)(struct device___141 *, struct device_driver___141 *);
	int (*uevent)(struct device___141 *, struct kobj_uevent_env *);
	int (*probe)(struct device___141 *);
	void (*sync_state)(struct device___141 *);
	void (*remove)(struct device___141 *);
	void (*shutdown)(struct device___141 *);
	int (*online)(struct device___141 *);
	int (*offline)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	int (*num_vf)(struct device___141 *);
	int (*dma_configure)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___141 {
	const char *name;
	struct bus_type___141 *bus;
	struct module___169 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___141 *);
	void (*sync_state)(struct device___141 *);
	int (*remove)(struct device___141 *);
	void (*shutdown)(struct device___141 *);
	int (*suspend)(struct device___141 *, pm_message_t);
	int (*resume)(struct device___141 *);
	const struct attribute_group___173 **groups;
	const struct attribute_group___173 **dev_groups;
	const struct dev_pm_ops___141 *pm;
	void (*coredump)(struct device___141 *);
	struct driver_private *p;
};

struct device_type___141 {
	const char *name;
	const struct attribute_group___173 **groups;
	int (*uevent)(struct device___141 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___141 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___141 *);
	const struct dev_pm_ops___141 *pm;
};

struct class___141 {
	const char *name;
	struct module___169 *owner;
	const struct attribute_group___173 **class_groups;
	const struct attribute_group___173 **dev_groups;
	struct kobject___173 *dev_kobj;
	int (*dev_uevent)(struct device___141 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___141 *, umode_t *);
	void (*class_release)(struct class___141 *);
	void (*dev_release)(struct device___141 *);
	int (*shutdown_pre)(struct device___141 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___141 *);
	void (*get_ownership)(struct device___141 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___141 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___141;

struct fwnode_handle___141 {
	struct fwnode_handle___141 *secondary;
	const struct fwnode_operations___141 *ops;
	struct device___141 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___35;

struct device_node___43 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___141 fwnode;
	struct property___35 *properties;
	struct property___35 *deadprops;
	struct device_node___43 *parent;
	struct device_node___43 *child;
	struct device_node___43 *sibling;
	struct kobject___173 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___185;

struct dentry___185 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___185 *d_parent;
	struct qstr d_name;
	struct inode___185 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___185 *d_op;
	struct super_block___185 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___185;

struct inode___185 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___185 *i_op;
	struct super_block___185 *i_sb;
	struct address_space___185 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___84 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___186 *i_fop;
		void (*free_inode)(struct inode___185 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___185 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___63 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___185 {
	int (*d_revalidate)(struct dentry___185 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___185 *, unsigned int);
	int (*d_hash)(const struct dentry___185 *, struct qstr *);
	int (*d_compare)(const struct dentry___185 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___185 *);
	int (*d_init)(struct dentry___185 *);
	void (*d_release)(struct dentry___185 *);
	void (*d_prune)(struct dentry___185 *);
	void (*d_iput)(struct dentry___185 *, struct inode___185 *);
	char * (*d_dname)(struct dentry___185 *, char *, int);
	struct vfsmount___185 * (*d_automount)(struct path___185 *);
	int (*d_manage)(const struct path___185 *, bool);
	struct dentry___185 * (*d_real)(struct dentry___185 *, const struct inode___185 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___185;

struct mem_dqinfo___185 {
	struct quota_format_type___185 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___185;

struct quota_info___185 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___185 *files[3];
	struct mem_dqinfo___185 info[3];
	const struct quota_format_ops___185 *ops[3];
};

struct rcuwait___186 {
	struct task_struct___192 *task;
};

struct percpu_rw_semaphore___186 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___186 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___185 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___186 rw_sem[3];
};

struct shrink_control___75;

struct shrinker___75 {
	long unsigned int (*count_objects)(struct shrinker___75 *, struct shrink_control___75 *);
	long unsigned int (*scan_objects)(struct shrinker___75 *, struct shrink_control___75 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___185;

struct dquot_operations___185;

struct quotactl_ops___185;

struct block_device___92;

struct super_block___185 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___185 *s_type;
	const struct super_operations___185 *s_op;
	const struct dquot_operations___185 *dq_op;
	const struct quotactl_ops___185 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___185 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___92 *s_bdev;
	struct backing_dev_info___84 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___185 s_dquot;
	struct sb_writers___185 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___185 *s_d_op;
	int cleancache_poolid;
	struct shrinker___75 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___185 {
	struct dentry___185 *mnt_root;
	struct super_block___185 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___75 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___75 *memcg;
};

struct psi_group___125 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___192 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___125;

struct cgroup_rstat_cpu___125;

struct cgroup___125 {
	struct cgroup_subsys_state___125 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___173 *kn;
	struct cgroup_file___125 procs_file;
	struct cgroup_file___125 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___125 *subsys[14];
	struct cgroup_root___125 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___125 *dom_cgrp;
	struct cgroup___125 *old_dom_cgrp;
	struct cgroup_rstat_cpu___125 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___125 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___91 {
	struct request_queue___91 *q;
	struct io_context___91 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___84;

struct kiocb___185 {
	struct file___185 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___185 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___84 *ki_waitq;
	};
};

struct iattr___185 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___185 *ia_file;
};

struct dquot___185 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___185 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___185 {
	int qf_fmt_id;
	const struct quota_format_ops___185 *qf_ops;
	struct module___169 *qf_owner;
	struct quota_format_type___185 *qf_next;
};

struct quota_format_ops___185 {
	int (*check_quota_file)(struct super_block___185 *, int);
	int (*read_file_info)(struct super_block___185 *, int);
	int (*write_file_info)(struct super_block___185 *, int);
	int (*free_file_info)(struct super_block___185 *, int);
	int (*read_dqblk)(struct dquot___185 *);
	int (*commit_dqblk)(struct dquot___185 *);
	int (*release_dqblk)(struct dquot___185 *);
	int (*get_next_id)(struct super_block___185 *, struct kqid *);
};

struct dquot_operations___185 {
	int (*write_dquot)(struct dquot___185 *);
	struct dquot___185 * (*alloc_dquot)(struct super_block___185 *, int);
	void (*destroy_dquot)(struct dquot___185 *);
	int (*acquire_dquot)(struct dquot___185 *);
	int (*release_dquot)(struct dquot___185 *);
	int (*mark_dirty)(struct dquot___185 *);
	int (*write_info)(struct super_block___185 *, int);
	qsize_t * (*get_reserved_space)(struct inode___185 *);
	int (*get_projid)(struct inode___185 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___185 *, qsize_t *);
	int (*get_next_id)(struct super_block___185 *, struct kqid *);
};

struct quotactl_ops___185 {
	int (*quota_on)(struct super_block___185 *, int, int, const struct path___185 *);
	int (*quota_off)(struct super_block___185 *, int);
	int (*quota_enable)(struct super_block___185 *, unsigned int);
	int (*quota_disable)(struct super_block___185 *, unsigned int);
	int (*quota_sync)(struct super_block___185 *, int);
	int (*set_info)(struct super_block___185 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___185 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___185 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___185 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___185 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___185 *, unsigned int);
};

struct wait_page_queue___84 {
	struct page___190 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___84;

struct readahead_control___84;

struct swap_info_struct___43;

struct address_space_operations___185 {
	int (*writepage)(struct page___190 *, struct writeback_control___84 *);
	int (*readpage)(struct file___185 *, struct page___190 *);
	int (*writepages)(struct address_space___185 *, struct writeback_control___84 *);
	int (*set_page_dirty)(struct page___190 *);
	int (*readpages)(struct file___185 *, struct address_space___185 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___84 *);
	int (*write_begin)(struct file___185 *, struct address_space___185 *, loff_t, unsigned int, unsigned int, struct page___190 **, void **);
	int (*write_end)(struct file___185 *, struct address_space___185 *, loff_t, unsigned int, unsigned int, struct page___190 *, void *);
	sector_t (*bmap)(struct address_space___185 *, sector_t);
	void (*invalidatepage)(struct page___190 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___190 *, gfp_t);
	void (*freepage)(struct page___190 *);
	ssize_t (*direct_IO)(struct kiocb___185 *, struct iov_iter___109 *);
	int (*migratepage)(struct address_space___185 *, struct page___190 *, struct page___190 *, enum migrate_mode);
	bool (*isolate_page)(struct page___190 *, isolate_mode_t);
	void (*putback_page)(struct page___190 *);
	int (*launder_page)(struct page___190 *);
	int (*is_partially_uptodate)(struct page___190 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___190 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___185 *, struct page___190 *);
	int (*swap_activate)(struct swap_info_struct___43 *, struct file___185 *, sector_t *);
	void (*swap_deactivate)(struct file___185 *);
};

struct writeback_control___84 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___84 *wb;
	struct inode___185 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___84 {
	struct file___185 *file;
	struct address_space___185 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___107;

struct iov_iter___109 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___107 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___63 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___43 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___92 *bdev;
	struct file___185 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___185 {
	struct dentry___185 * (*lookup)(struct inode___185 *, struct dentry___185 *, unsigned int);
	const char * (*get_link)(struct dentry___185 *, struct inode___185 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___185 *, int);
	struct posix_acl * (*get_acl)(struct inode___185 *, int, bool);
	int (*readlink)(struct dentry___185 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___185 *, struct dentry___185 *, umode_t, bool);
	int (*link)(struct dentry___185 *, struct inode___185 *, struct dentry___185 *);
	int (*unlink)(struct inode___185 *, struct dentry___185 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___185 *, struct dentry___185 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___185 *, struct dentry___185 *, umode_t);
	int (*rmdir)(struct inode___185 *, struct dentry___185 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___185 *, struct dentry___185 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___185 *, struct dentry___185 *, struct inode___185 *, struct dentry___185 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___185 *, struct iattr___185 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___185 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___185 *, char *, size_t);
	int (*fiemap)(struct inode___185 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___185 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___185 *, struct dentry___185 *, struct file___185 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___185 *, struct dentry___185 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___185 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___185 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___185 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___185 {
	void (*fl_copy_lock)(struct file_lock___185 *, struct file_lock___185 *);
	void (*fl_release_private)(struct file_lock___185 *);
};

struct lock_manager_operations___185;

struct file_lock___185 {
	struct file_lock___185 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___185 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___185 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___185 *fl_ops;
	const struct lock_manager_operations___185 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___185 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___185 *);
	int (*lm_grant)(struct file_lock___185 *, int);
	bool (*lm_break)(struct file_lock___185 *);
	int (*lm_change)(struct file_lock___185 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___185 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___185 *);
};

struct fasync_struct___185 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___185 *fa_next;
	struct file___185 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___185 {
	struct inode___185 * (*alloc_inode)(struct super_block___185 *);
	void (*destroy_inode)(struct inode___185 *);
	void (*free_inode)(struct inode___185 *);
	void (*dirty_inode)(struct inode___185 *, int);
	int (*write_inode)(struct inode___185 *, struct writeback_control___84 *);
	int (*drop_inode)(struct inode___185 *);
	void (*evict_inode)(struct inode___185 *);
	void (*put_super)(struct super_block___185 *);
	int (*sync_fs)(struct super_block___185 *, int);
	int (*freeze_super)(struct super_block___185 *);
	int (*freeze_fs)(struct super_block___185 *);
	int (*thaw_super)(struct super_block___185 *);
	int (*unfreeze_fs)(struct super_block___185 *);
	int (*statfs)(struct dentry___185 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___185 *, int *, char *);
	void (*umount_begin)(struct super_block___185 *);
	int (*show_options)(struct seq_file___161 *, struct dentry___185 *);
	int (*show_devname)(struct seq_file___161 *, struct dentry___185 *);
	int (*show_path)(struct seq_file___161 *, struct dentry___185 *);
	int (*show_stats)(struct seq_file___161 *, struct dentry___185 *);
	ssize_t (*quota_read)(struct super_block___185 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___185 *, int, const char *, size_t, loff_t);
	struct dquot___185 ** (*get_dquots)(struct inode___185 *);
	long int (*nr_cached_objects)(struct super_block___185 *, struct shrink_control___75 *);
	long int (*free_cached_objects)(struct super_block___185 *, struct shrink_control___75 *);
	struct file___185 * (*real_loop)(struct file___185 *);
};

struct block_device___92 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___185 *bd_inode;
	struct super_block___185 *bd_super;
	void *bd_claiming;
	struct device___141 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___173 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___92 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___185 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___91(struct bio___91 *);

struct bio_vec___107 {
	struct page___190 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___91;

struct bio___91 {
	struct bio___91 *bi_next;
	struct block_device___92 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___91 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___86 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___91 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___107 *bi_io_vec;
	struct bio_set___91 *bi_pool;
	struct bio_vec___107 bi_inline_vecs[0];
};

struct kernel_param_ops___169 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___169 *);
	int (*get)(char *, const struct kernel_param___169 *);
	void (*free)(void *);
};

struct kparam_array___169;

struct kernel_param___169 {
	const char *name;
	struct module___169 *mod;
	const struct kernel_param_ops___169 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___169 *arr;
	};
};

struct kparam_array___169 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___169 *ops;
	void *elem;
};

struct module_attribute___169 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___169 *, struct module_kobject___169 *, char *);
	ssize_t (*store)(struct module_attribute___169 *, struct module_kobject___169 *, const char *, size_t);
	void (*setup)(struct module___169 *, const char *);
	int (*test)(struct module___169 *);
	void (*free)(struct module___169 *);
};

struct dev_pagemap_ops___180 {
	void (*page_free)(struct page___190 *);
	void (*kill)(struct dev_pagemap___180 *);
	void (*cleanup)(struct dev_pagemap___180 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___180 *);
};

struct fwnode_reference_args___141;

struct fwnode_endpoint___141;

struct fwnode_operations___141 {
	struct fwnode_handle___141 * (*get)(struct fwnode_handle___141 *);
	void (*put)(struct fwnode_handle___141 *);
	bool (*device_is_available)(const struct fwnode_handle___141 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___141 *, const struct device___141 *);
	bool (*property_present)(const struct fwnode_handle___141 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___141 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___141 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___141 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*get_parent)(const struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*get_next_child_node)(const struct fwnode_handle___141 *, struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*get_named_child_node)(const struct fwnode_handle___141 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___141 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___141 *);
	struct fwnode_handle___141 * (*graph_get_next_endpoint)(const struct fwnode_handle___141 *, struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*graph_get_remote_endpoint)(const struct fwnode_handle___141 *);
	struct fwnode_handle___141 * (*graph_get_port_parent)(struct fwnode_handle___141 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___141 *, struct fwnode_endpoint___141 *);
	int (*add_links)(struct fwnode_handle___141 *);
};

struct fwnode_endpoint___141 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___141 *local_fwnode;
};

struct fwnode_reference_args___141 {
	struct fwnode_handle___141 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___125 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___125 *root_cset;
};

struct pipe_buf_operations___63;

struct pipe_buffer___63 {
	struct page___190 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___63 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___63 {
	int (*confirm)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
	void (*release)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
	bool (*try_steal)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
	bool (*get)(struct pipe_inode_info___63 *, struct pipe_buffer___63 *);
};

struct mii_bus;

struct mdio_device {
	struct device___141 dev;
	struct mii_bus *bus;
	char modalias[32];
	int (*bus_match)(struct device___141 *, struct device_driver___141 *);
	void (*device_free)(struct mdio_device *);
	void (*device_remove)(struct mdio_device *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct mdio_bus_stats {
	u64_stats_t transfers;
	u64_stats_t errors;
	u64_stats_t writes;
	u64_stats_t reads;
	struct u64_stats_sync syncp;
};

struct phy_package_shared;

struct mii_bus {
	struct module___169 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus *, int, int);
	int (*write)(struct mii_bus *, int, int, u16);
	int (*reset)(struct mii_bus *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___141 *parent;
	enum {
		MDIOBUS_ALLOCATED = 1,
		MDIOBUS_REGISTERED = 2,
		MDIOBUS_UNREGISTERED = 3,
		MDIOBUS_RELEASED = 4,
	} state;
	struct device___141 dev;
	struct mdio_device *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP = 0,
		MDIOBUS_C22 = 1,
		MDIOBUS_C45 = 2,
		MDIOBUS_C22_C45 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common {
	struct device_driver___141 driver;
	int flags;
};

struct mdio_driver {
	struct mdio_driver_common mdiodrv;
	int (*probe)(struct mdio_device *);
	void (*remove)(struct mdio_device *);
	void (*shutdown)(struct mdio_device *);
};

struct phy_package_shared {
	int addr;
	refcount_t refcnt;
	long unsigned int flags;
	size_t priv_size;
	void *priv;
};

struct property___35 {
	char *name;
	int length;
	void *value;
	struct property___35 *next;
	long unsigned int _flags;
	struct bin_attribute___173 attr;
};

struct of_phandle_args___10 {
	struct device_node___43 *np;
	int args_count;
	uint32_t args[16];
};

struct seq_operations___161 {
	void * (*start)(struct seq_file___161 *, loff_t *);
	void (*stop)(struct seq_file___161 *, void *);
	void * (*next)(struct seq_file___161 *, void *, loff_t *);
	int (*show)(struct seq_file___161 *, void *);
};

struct cftype___125;

struct cgroup_subsys___125 {
	struct cgroup_subsys_state___125 * (*css_alloc)(struct cgroup_subsys_state___125 *);
	int (*css_online)(struct cgroup_subsys_state___125 *);
	void (*css_offline)(struct cgroup_subsys_state___125 *);
	void (*css_released)(struct cgroup_subsys_state___125 *);
	void (*css_free)(struct cgroup_subsys_state___125 *);
	void (*css_reset)(struct cgroup_subsys_state___125 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___125 *, int);
	int (*css_extra_stat_show)(struct seq_file___161 *, struct cgroup_subsys_state___125 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___192 *, struct css_set___125 *);
	void (*cancel_fork)(struct task_struct___192 *, struct css_set___125 *);
	void (*fork)(struct task_struct___192 *);
	void (*exit)(struct task_struct___192 *);
	void (*release)(struct task_struct___192 *);
	void (*bind)(struct cgroup_subsys_state___125 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___125 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___125 *dfl_cftypes;
	struct cftype___125 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___125 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___125 *updated_children;
	struct cgroup___125 *updated_next;
};

struct cgroup_root___125 {
	struct kernfs_root___173 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___125 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___125 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___125 *ss;
	struct list_head node;
	struct kernfs_ops___173 *kf_ops;
	int (*open)(struct kernfs_open_file___173 *);
	void (*release)(struct kernfs_open_file___173 *);
	u64 (*read_u64)(struct cgroup_subsys_state___125 *, struct cftype___125 *);
	s64 (*read_s64)(struct cgroup_subsys_state___125 *, struct cftype___125 *);
	int (*seq_show)(struct seq_file___161 *, void *);
	void * (*seq_start)(struct seq_file___161 *, loff_t *);
	void * (*seq_next)(struct seq_file___161 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___161 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___125 *, struct cftype___125 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___125 *, struct cftype___125 *, s64);
	ssize_t (*write)(struct kernfs_open_file___173 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___173 *, struct poll_table_struct___5 *);
};

struct block_device_operations___91;

struct gendisk___92 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___92 *part0;
	const struct block_device_operations___91 *fops;
	struct request_queue___91 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___84 *bdi;
	struct kobject___173 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___173 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___91 {
	struct bio___91 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___107 *bip_vec;
	struct bio_vec___107 bip_inline_vecs[0];
};

struct blkcg___86;

struct blkg_policy_data___86;

struct blkcg_gq___86 {
	struct request_queue___91 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___86 *blkcg;
	struct blkcg_gq___86 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___86 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___91 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___91(struct request___91 *);

typedef void integrity_complete_fn___91(struct request___91 *, unsigned int);

struct blk_integrity_profile___91 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___91 *prepare_fn;
	integrity_complete_fn___91 *complete_fn;
	const char *name;
};

struct block_device_operations___91 {
	blk_qc_t (*submit_bio)(struct bio___91 *);
	int (*open)(struct block_device___92 *, fmode_t);
	void (*release)(struct gendisk___92 *, fmode_t);
	int (*rw_page)(struct block_device___92 *, sector_t, struct page___190 *, unsigned int);
	int (*ioctl)(struct block_device___92 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___92 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___92 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___92 *);
	int (*getgeo)(struct block_device___92 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___92 *, bool);
	void (*swap_slot_free_notify)(struct block_device___92 *, long unsigned int);
	int (*report_zones)(struct gendisk___92 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___92 *, umode_t *);
	struct module___169 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___92 *, sector_t *);
};

typedef void rq_end_io_fn___91(struct request___91 *, blk_status_t);

struct request___91 {
	struct request_queue___91 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___88 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___91 *bio;
	struct bio___91 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___107 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___91 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___91 *saved_end_io;
		} flush;
	};
	struct gendisk___92 *rq_disk;
	struct block_device___92 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___91 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___88 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___91 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___173 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___185 *debugfs_dir;
	struct dentry___185 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___91;

struct elevator_mq_ops___91 {
	int (*init_sched)(struct request_queue___91 *, struct elevator_type___91 *);
	void (*exit_sched)(struct elevator_queue___91 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___88 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___88 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___88 *);
	bool (*allow_merge)(struct request_queue___91 *, struct request___91 *, struct bio___91 *);
	bool (*bio_merge)(struct request_queue___91 *, struct bio___91 *, unsigned int);
	int (*request_merge)(struct request_queue___91 *, struct request___91 **, struct bio___91 *);
	void (*request_merged)(struct request_queue___91 *, struct request___91 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___91 *, struct request___91 *, struct request___91 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___91 *);
	void (*finish_request)(struct request___91 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___88 *, struct list_head *, bool);
	struct request___91 * (*dispatch_request)(struct blk_mq_hw_ctx___88 *);
	bool (*has_work)(struct blk_mq_hw_ctx___88 *);
	void (*completed_request)(struct request___91 *, u64);
	void (*requeue_request)(struct request___91 *);
	struct request___91 * (*former_request)(struct request_queue___91 *, struct request___91 *);
	struct request___91 * (*next_request)(struct request_queue___91 *, struct request___91 *);
	void (*init_icq)(struct io_cq___91 *);
	void (*exit_icq)(struct io_cq___91 *);
};

struct elv_fs_entry___91;

struct elevator_type___91 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___91 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___91 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___169 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___91 {
	struct elevator_type___91 *type;
	void *elevator_data;
	struct kobject___173 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___91 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___91 *, char *);
	ssize_t (*store)(struct elevator_queue___91 *, const char *, size_t);
};

struct blk_mq_queue_data___88;

struct blk_mq_ops___88 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___88 *, const struct blk_mq_queue_data___88 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___88 *);
	int (*get_budget)(struct request_queue___91 *);
	void (*put_budget)(struct request_queue___91 *, int);
	void (*set_rq_budget_token)(struct request___91 *, int);
	int (*get_rq_budget_token)(struct request___91 *);
	enum blk_eh_timer_return (*timeout)(struct request___91 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___88 *);
	void (*complete)(struct request___91 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___88 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___88 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___88 *, struct request___91 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___88 *, struct request___91 *, unsigned int);
	void (*initialize_rq_fn)(struct request___91 *);
	void (*cleanup_rq)(struct request___91 *);
	bool (*busy)(struct request_queue___91 *);
	int (*map_queues)(struct blk_mq_tag_set___88 *);
	void (*show_rq)(struct seq_file___161 *, struct request___91 *);
};

struct blk_mq_tag_set___88 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___88 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___88 {
	struct request___91 *rq;
	bool last;
};

struct blkcg_policy_data___86;

struct blkcg___86 {
	struct cgroup_subsys_state___125 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___86 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___86 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___86 {
	struct blkcg___86 *blkcg;
	int plid;
};

struct blkg_policy_data___86 {
	struct blkcg_gq___86 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___75 {
	struct mem_cgroup___75 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___75 {
	struct lruvec___82 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___75 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___75 *memcg;
};

struct obj_cgroup___75 {
	struct percpu_ref refcnt;
	struct mem_cgroup___75 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct phy___3;

struct phy_ops___3 {
	int (*init)(struct phy___3 *);
	int (*exit)(struct phy___3 *);
	int (*power_on)(struct phy___3 *);
	int (*power_off)(struct phy___3 *);
	int (*set_mode)(struct phy___3 *, enum phy_mode, int);
	int (*set_media)(struct phy___3 *, enum phy_media);
	int (*set_speed)(struct phy___3 *, int);
	int (*configure)(struct phy___3 *, union phy_configure_opts___2 *);
	int (*validate)(struct phy___3 *, enum phy_mode, int, union phy_configure_opts___2 *);
	int (*reset)(struct phy___3 *);
	int (*calibrate)(struct phy___3 *);
	void (*release)(struct phy___3 *);
	struct module___169 *owner;
};

struct phy___3 {
	struct device___141 dev;
	int id;
	const struct phy_ops___3 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct phy_provider___3 {
	struct device___141 *dev;
	struct device_node___43 *children;
	struct module___169 *owner;
	struct list_head list;
	struct phy___3 * (*of_xlate)(struct device___141 *, struct of_phandle_args___10 *);
};

enum brcm_sata_phy_version {
	BRCM_SATA_PHY_STB_16NM = 0,
	BRCM_SATA_PHY_STB_28NM = 1,
	BRCM_SATA_PHY_STB_40NM = 2,
	BRCM_SATA_PHY_IPROC_NS2 = 3,
	BRCM_SATA_PHY_IPROC_NSP = 4,
	BRCM_SATA_PHY_IPROC_SR = 5,
	BRCM_SATA_PHY_DSL_28NM = 6,
};

enum brcm_sata_phy_rxaeq_mode {
	RXAEQ_MODE_OFF = 0,
	RXAEQ_MODE_AUTO = 1,
	RXAEQ_MODE_MANUAL = 2,
};

struct brcm_sata_phy;

struct brcm_sata_port {
	int portnum;
	struct phy *phy;
	struct brcm_sata_phy *phy_priv;
	bool ssc_en;
	enum brcm_sata_phy_rxaeq_mode rxaeq_mode;
	u32 rxaeq_val;
	u32 tx_amplitude_val;
};

struct brcm_sata_phy {
	struct device___22 *dev;
	void *phy_base;
	void *ctrl_base;
	enum brcm_sata_phy_version version;
	struct brcm_sata_port phys[2];
};

enum sata_phy_regs {
	BLOCK0_REG_BANK = 0,
	BLOCK0_XGXSSTATUS = 129,
	BLOCK0_XGXSSTATUS_PLL_LOCK = 4096,
	BLOCK0_SPARE = 141,
	BLOCK0_SPARE_OOB_CLK_SEL_MASK = 3,
	BLOCK0_SPARE_OOB_CLK_SEL_REFBY2 = 1,
	BLOCK1_REG_BANK = 16,
	BLOCK1_TEST_TX = 131,
	BLOCK1_TEST_TX_AMP_SHIFT = 12,
	PLL_REG_BANK_0 = 80,
	PLL_REG_BANK_0_PLLCONTROL_0 = 129,
	PLLCONTROL_0_FREQ_DET_RESTART = 8192,
	PLLCONTROL_0_FREQ_MONITOR = 4096,
	PLLCONTROL_0_SEQ_START = 32768,
	PLL_CAP_CHARGE_TIME = 131,
	PLL_VCO_CAL_THRESH = 132,
	PLL_CAP_CONTROL = 133,
	PLL_FREQ_DET_TIME = 134,
	PLL_ACTRL2 = 139,
	PLL_ACTRL2_SELDIV_MASK = 31,
	PLL_ACTRL2_SELDIV_SHIFT = 9,
	PLL_ACTRL6 = 134,
	PLL1_REG_BANK = 96,
	PLL1_ACTRL2 = 130,
	PLL1_ACTRL3 = 131,
	PLL1_ACTRL4 = 132,
	PLL1_ACTRL5 = 133,
	PLL1_ACTRL6 = 134,
	PLL1_ACTRL7 = 135,
	PLL1_ACTRL8 = 136,
	TX_REG_BANK = 112,
	TX_ACTRL0 = 128,
	TX_ACTRL0_TXPOL_FLIP = 64,
	TX_ACTRL5 = 133,
	TX_ACTRL5_SSC_EN = 2048,
	AEQRX_REG_BANK_0 = 208,
	AEQ_CONTROL1 = 129,
	AEQ_CONTROL1_ENABLE = 4,
	AEQ_CONTROL1_FREEZE = 8,
	AEQ_FRC_EQ = 131,
	AEQ_FRC_EQ_FORCE = 1,
	AEQ_FRC_EQ_FORCE_VAL = 2,
	AEQ_RFZ_FRC_VAL = 256,
	AEQRX_REG_BANK_1 = 224,
	AEQRX_SLCAL0_CTRL0 = 130,
	AEQRX_SLCAL1_CTRL0 = 134,
	OOB_REG_BANK = 336,
	OOB1_REG_BANK = 352,
	OOB_CTRL1 = 128,
	OOB_CTRL1_BURST_MAX_MASK = 15,
	OOB_CTRL1_BURST_MAX_SHIFT = 12,
	OOB_CTRL1_BURST_MIN_MASK = 15,
	OOB_CTRL1_BURST_MIN_SHIFT = 8,
	OOB_CTRL1_WAKE_IDLE_MAX_MASK = 15,
	OOB_CTRL1_WAKE_IDLE_MAX_SHIFT = 4,
	OOB_CTRL1_WAKE_IDLE_MIN_MASK = 15,
	OOB_CTRL1_WAKE_IDLE_MIN_SHIFT = 0,
	OOB_CTRL2 = 129,
	OOB_CTRL2_SEL_ENA_SHIFT = 15,
	OOB_CTRL2_SEL_ENA_RC_SHIFT = 14,
	OOB_CTRL2_RESET_IDLE_MAX_MASK = 63,
	OOB_CTRL2_RESET_IDLE_MAX_SHIFT = 8,
	OOB_CTRL2_BURST_CNT_MASK = 3,
	OOB_CTRL2_BURST_CNT_SHIFT = 6,
	OOB_CTRL2_RESET_IDLE_MIN_MASK = 63,
	OOB_CTRL2_RESET_IDLE_MIN_SHIFT = 0,
	TXPMD_REG_BANK = 416,
	TXPMD_CONTROL1 = 129,
	TXPMD_CONTROL1_TX_SSC_EN_FRC = 1,
	TXPMD_CONTROL1_TX_SSC_EN_FRC_VAL = 2,
	TXPMD_TX_FREQ_CTRL_CONTROL1 = 130,
	TXPMD_TX_FREQ_CTRL_CONTROL2 = 131,
	TXPMD_TX_FREQ_CTRL_CONTROL2_FMIN_MASK = 1023,
	TXPMD_TX_FREQ_CTRL_CONTROL3 = 132,
	TXPMD_TX_FREQ_CTRL_CONTROL3_FMAX_MASK = 1023,
	RXPMD_REG_BANK = 448,
	RXPMD_RX_CDR_CONTROL1 = 129,
	RXPMD_RX_PPM_VAL_MASK = 511,
	RXPMD_RXPMD_EN_FRC = 4096,
	RXPMD_RXPMD_EN_FRC_VAL = 8192,
	RXPMD_RX_CDR_CDR_PROP_BW = 130,
	RXPMD_G_CDR_PROP_BW_MASK = 7,
	RXPMD_G1_CDR_PROP_BW_SHIFT = 0,
	RXPMD_G2_CDR_PROP_BW_SHIFT = 3,
	RXPMD_G3_CDR_PROB_BW_SHIFT = 6,
	RXPMD_RX_CDR_CDR_ACQ_INTEG_BW = 131,
	RXPMD_G_CDR_ACQ_INT_BW_MASK = 7,
	RXPMD_G1_CDR_ACQ_INT_BW_SHIFT = 0,
	RXPMD_G2_CDR_ACQ_INT_BW_SHIFT = 3,
	RXPMD_G3_CDR_ACQ_INT_BW_SHIFT = 6,
	RXPMD_RX_CDR_CDR_LOCK_INTEG_BW = 132,
	RXPMD_G_CDR_LOCK_INT_BW_MASK = 7,
	RXPMD_G1_CDR_LOCK_INT_BW_SHIFT = 0,
	RXPMD_G2_CDR_LOCK_INT_BW_SHIFT = 3,
	RXPMD_G3_CDR_LOCK_INT_BW_SHIFT = 6,
	RXPMD_RX_FREQ_MON_CONTROL1 = 135,
	RXPMD_MON_CORRECT_EN = 256,
	RXPMD_MON_MARGIN_VAL_MASK = 255,
};

enum sata_phy_ctrl_regs {
	PHY_CTRL_1 = 0,
	PHY_CTRL_1_RESET = 1,
};

typedef int (*dr_match_t___8)(struct device___140 *, void *, void *);

struct pinctrl;

struct pinctrl_state;

struct dev_pin_info {
	struct pinctrl *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct device_link___8 {
	struct device___140 *supplier;
	struct list_head s_node;
	struct device___140 *consumer;
	struct list_head c_node;
	struct device___140 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct pinctrl {
	struct list_head node;
	struct device___140 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct pinctrl_state {
	struct list_head node;
	const char *name;
	struct list_head settings;
};

struct pinctrl_pin_desc {
	unsigned int number;
	const char *name;
	void *drv_data;
};

struct gpio_chip;

struct pinctrl_gpio_range {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	unsigned int npins;
	const unsigned int *pins;
	struct gpio_chip *gc;
};

struct gpio_irq_chip {
	struct irq_chip___24 *chip;
	struct irq_domain___23 *domain;
	const struct irq_domain_ops___23 *domain_ops;
	struct fwnode_handle___140 *fwnode;
	struct irq_domain___23 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip *, unsigned int);
	struct irq_domain_ops___23 child_irq_domain_ops;
	irq_flow_handler_t___25 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___25 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip *);
	void (*init_valid_mask)(struct gpio_chip *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___24 *);
	void (*irq_disable)(struct irq_data___24 *);
	void (*irq_unmask)(struct irq_data___24 *);
	void (*irq_mask)(struct irq_data___24 *);
};

struct gpio_device;

struct gpio_chip {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___140 *parent;
	struct module___168 *owner;
	int (*request)(struct gpio_chip *, unsigned int);
	void (*free)(struct gpio_chip *, unsigned int);
	int (*get_direction)(struct gpio_chip *, unsigned int);
	int (*direction_input)(struct gpio_chip *, unsigned int);
	int (*direction_output)(struct gpio_chip *, unsigned int, int);
	int (*get)(struct gpio_chip *, unsigned int);
	int (*get_multiple)(struct gpio_chip *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip *, unsigned int);
	void (*dbg_show)(struct seq_file___160 *, struct gpio_chip *);
	int (*init_valid_mask)(struct gpio_chip *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip irq;
	long unsigned int *valid_mask;
	struct device_node___42 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip *, const struct of_phandle_args___7 *, u32 *);
};

struct pinctrl_dev;

struct pinctrl_map;

struct pinctrl_ops {
	int (*get_groups_count)(struct pinctrl_dev *);
	const char * (*get_group_name)(struct pinctrl_dev *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev *, struct seq_file___160 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev *, struct device_node___42 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc;

struct pinctrl_dev {
	struct list_head node;
	struct pinctrl_desc *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___140 *dev;
	struct module___168 *owner;
	void *driver_data;
	struct pinctrl *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___184 *device_root;
};

enum pinctrl_map_type {
	PIN_MAP_TYPE_INVALID = 0,
	PIN_MAP_TYPE_DUMMY_STATE = 1,
	PIN_MAP_TYPE_MUX_GROUP = 2,
	PIN_MAP_TYPE_CONFIGS_PIN = 3,
	PIN_MAP_TYPE_CONFIGS_GROUP = 4,
};

struct pinctrl_map_mux {
	const char *group;
	const char *function;
};

struct pinctrl_map_configs {
	const char *group_or_pin;
	long unsigned int *configs;
	unsigned int num_configs;
};

struct pinctrl_map {
	const char *dev_name;
	const char *name;
	enum pinctrl_map_type type;
	const char *ctrl_dev_name;
	union {
		struct pinctrl_map_mux mux;
		struct pinctrl_map_configs configs;
	} data;
};

struct pinmux_ops;

struct pinconf_ops;

struct pinconf_generic_params;

struct pin_config_item;

struct pinctrl_desc {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops *confops;
	struct module___168 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinmux_ops {
	int (*request)(struct pinctrl_dev *, unsigned int);
	int (*free)(struct pinctrl_dev *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev *);
	const char * (*get_function_name)(struct pinctrl_dev *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev *, struct pinctrl_gpio_range *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev *, struct pinctrl_gpio_range *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev *, struct pinctrl_gpio_range *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev *, struct seq_file___160 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev *, struct seq_file___160 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev *, struct seq_file___160 *, long unsigned int);
};

enum pin_config_param {
	PIN_CONFIG_BIAS_BUS_HOLD = 0,
	PIN_CONFIG_BIAS_DISABLE = 1,
	PIN_CONFIG_BIAS_HIGH_IMPEDANCE = 2,
	PIN_CONFIG_BIAS_PULL_DOWN = 3,
	PIN_CONFIG_BIAS_PULL_PIN_DEFAULT = 4,
	PIN_CONFIG_BIAS_PULL_UP = 5,
	PIN_CONFIG_DRIVE_OPEN_DRAIN = 6,
	PIN_CONFIG_DRIVE_OPEN_SOURCE = 7,
	PIN_CONFIG_DRIVE_PUSH_PULL = 8,
	PIN_CONFIG_DRIVE_STRENGTH = 9,
	PIN_CONFIG_DRIVE_STRENGTH_UA = 10,
	PIN_CONFIG_INPUT_DEBOUNCE = 11,
	PIN_CONFIG_INPUT_ENABLE = 12,
	PIN_CONFIG_INPUT_SCHMITT = 13,
	PIN_CONFIG_INPUT_SCHMITT_ENABLE = 14,
	PIN_CONFIG_MODE_LOW_POWER = 15,
	PIN_CONFIG_MODE_PWM = 16,
	PIN_CONFIG_OUTPUT = 17,
	PIN_CONFIG_OUTPUT_ENABLE = 18,
	PIN_CONFIG_PERSIST_STATE = 19,
	PIN_CONFIG_POWER_SOURCE = 20,
	PIN_CONFIG_SKEW_DELAY = 21,
	PIN_CONFIG_SLEEP_HARDWARE_STATE = 22,
	PIN_CONFIG_SLEW_RATE = 23,
	PIN_CONFIG_END = 127,
	PIN_CONFIG_MAX = 255,
};

struct pinconf_generic_params {
	const char * const property;
	enum pin_config_param param;
	u32 default_value;
};

struct pin_config_item {
	const enum pin_config_param param;
	const char * const display;
	const char * const format;
	bool has_arg;
};

struct gpio_desc___2;

struct gpio_device {
	int id;
	struct device___140 dev;
	struct cdev___35 chrdev;
	struct device___140 *mockdev;
	struct module___168 *owner;
	struct gpio_chip *chip;
	struct gpio_desc___2 *descs;
	int base;
	u16 ngpio;
	const char *label;
	void *data;
	struct list_head list;
	struct blocking_notifier_head notifier;
	struct list_head pin_ranges;
};

struct gpio_desc___2 {
	struct gpio_device *gdev;
	long unsigned int flags;
	const char *label;
	const char *name;
	struct device_node___42 *hog;
	unsigned int debounce_period_us;
};

struct pinctrl_setting_mux {
	unsigned int group;
	unsigned int func;
};

struct pinctrl_setting_configs {
	unsigned int group_or_pin;
	long unsigned int *configs;
	unsigned int num_configs;
};

struct pinctrl_setting {
	struct list_head node;
	enum pinctrl_map_type type;
	struct pinctrl_dev *pctldev;
	const char *dev_name;
	union {
		struct pinctrl_setting_mux mux;
		struct pinctrl_setting_configs configs;
	} data;
};

struct pin_desc {
	struct pinctrl_dev *pctldev;
	const char *name;
	bool dynamic_name;
	void *drv_data;
	unsigned int mux_usecount;
	const char *mux_owner;
	const struct pinctrl_setting_mux *mux_setting;
	const char *gpio_owner;
};

struct pinctrl_maps {
	struct list_head node;
	const struct pinctrl_map *maps;
	unsigned int num_maps;
};

struct group_desc {
	const char *name;
	int *pins;
	int num_pins;
	void *data;
};

struct pctldev;

struct wakeup_source___142;

struct device___142;

struct dev_pm_info___142 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___142 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___142 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___142;

struct bus_type___142;

struct device_driver___142;

struct dev_pm_domain___142;

struct dev_pin_info___2;

struct device_node___44;

struct fwnode_handle___142;

struct class___142;

struct device___142 {
	struct kobject___173 kobj;
	struct device___142 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___142 *type;
	struct bus_type___142 *bus;
	struct device_driver___142 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___142 power;
	struct dev_pm_domain___142 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info___2 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___44 *of_node;
	struct fwnode_handle___142 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___142 *class;
	const struct attribute_group___173 **groups;
	void (*release)(struct device___142 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___142 {
	int (*prepare)(struct device___142 *);
	void (*complete)(struct device___142 *);
	int (*suspend)(struct device___142 *);
	int (*resume)(struct device___142 *);
	int (*freeze)(struct device___142 *);
	int (*thaw)(struct device___142 *);
	int (*poweroff)(struct device___142 *);
	int (*restore)(struct device___142 *);
	int (*suspend_late)(struct device___142 *);
	int (*resume_early)(struct device___142 *);
	int (*freeze_late)(struct device___142 *);
	int (*thaw_early)(struct device___142 *);
	int (*poweroff_late)(struct device___142 *);
	int (*restore_early)(struct device___142 *);
	int (*suspend_noirq)(struct device___142 *);
	int (*resume_noirq)(struct device___142 *);
	int (*freeze_noirq)(struct device___142 *);
	int (*thaw_noirq)(struct device___142 *);
	int (*poweroff_noirq)(struct device___142 *);
	int (*restore_noirq)(struct device___142 *);
	int (*runtime_suspend)(struct device___142 *);
	int (*runtime_resume)(struct device___142 *);
	int (*runtime_idle)(struct device___142 *);
};

struct wakeup_source___142 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___142 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___142 {
	struct dev_pm_ops___142 ops;
	int (*start)(struct device___142 *);
	void (*detach)(struct device___142 *, bool);
	int (*activate)(struct device___142 *);
	void (*sync)(struct device___142 *);
	void (*dismiss)(struct device___142 *);
};

struct bus_type___142 {
	const char *name;
	const char *dev_name;
	struct device___142 *dev_root;
	const struct attribute_group___173 **bus_groups;
	const struct attribute_group___173 **dev_groups;
	const struct attribute_group___173 **drv_groups;
	int (*match)(struct device___142 *, struct device_driver___142 *);
	int (*uevent)(struct device___142 *, struct kobj_uevent_env *);
	int (*probe)(struct device___142 *);
	void (*sync_state)(struct device___142 *);
	void (*remove)(struct device___142 *);
	void (*shutdown)(struct device___142 *);
	int (*online)(struct device___142 *);
	int (*offline)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	int (*num_vf)(struct device___142 *);
	int (*dma_configure)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___142 {
	const char *name;
	struct bus_type___142 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___142 *);
	void (*sync_state)(struct device___142 *);
	int (*remove)(struct device___142 *);
	void (*shutdown)(struct device___142 *);
	int (*suspend)(struct device___142 *, pm_message_t);
	int (*resume)(struct device___142 *);
	const struct attribute_group___173 **groups;
	const struct attribute_group___173 **dev_groups;
	const struct dev_pm_ops___142 *pm;
	void (*coredump)(struct device___142 *);
	struct driver_private *p;
};

struct device_type___142 {
	const char *name;
	const struct attribute_group___173 **groups;
	int (*uevent)(struct device___142 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___142 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___142 *);
	const struct dev_pm_ops___142 *pm;
};

struct class___142 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___173 **class_groups;
	const struct attribute_group___173 **dev_groups;
	struct kobject___173 *dev_kobj;
	int (*dev_uevent)(struct device___142 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___142 *, umode_t *);
	void (*class_release)(struct class___142 *);
	void (*dev_release)(struct device___142 *);
	int (*shutdown_pre)(struct device___142 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___142 *);
	void (*get_ownership)(struct device___142 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___142 *pm;
	struct subsys_private *p;
};

struct pinctrl___2;

struct dev_pin_info___2 {
	struct pinctrl___2 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct fwnode_operations___142;

struct fwnode_handle___142 {
	struct fwnode_handle___142 *secondary;
	const struct fwnode_operations___142 *ops;
	struct device___142 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___44 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___142 fwnode;
	struct property___35 *properties;
	struct property___35 *deadprops;
	struct device_node___44 *parent;
	struct device_node___44 *child;
	struct device_node___44 *sibling;
	struct kobject___173 kobj;
	long unsigned int _flags;
	void *data;
};

struct pinctrl___2 {
	struct list_head node;
	struct device___142 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct pinctrl_dev___2;

struct pinctrl_ops___2 {
	int (*get_groups_count)(struct pinctrl_dev___2 *);
	const char * (*get_group_name)(struct pinctrl_dev___2 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___2 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___161 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___2 *, struct device_node___44 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___2 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___2;

struct pinctrl_dev___2 {
	struct list_head node;
	struct pinctrl_desc___2 *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___142 *dev;
	struct module___8 *owner;
	void *driver_data;
	struct pinctrl___2 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___185 *device_root;
};

struct pinconf_ops___2;

struct pinctrl_desc___2 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___2 *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops___2 *confops;
	struct module___8 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinconf_ops___2 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___2 *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___161 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___161 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___2 *, struct seq_file___161 *, long unsigned int);
};

struct fwnode_reference_args___142;

struct fwnode_endpoint___142;

struct fwnode_operations___142 {
	struct fwnode_handle___142 * (*get)(struct fwnode_handle___142 *);
	void (*put)(struct fwnode_handle___142 *);
	bool (*device_is_available)(const struct fwnode_handle___142 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___142 *, const struct device___142 *);
	bool (*property_present)(const struct fwnode_handle___142 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___142 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___142 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___142 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*get_parent)(const struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*get_next_child_node)(const struct fwnode_handle___142 *, struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*get_named_child_node)(const struct fwnode_handle___142 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___142 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___142 *);
	struct fwnode_handle___142 * (*graph_get_next_endpoint)(const struct fwnode_handle___142 *, struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*graph_get_remote_endpoint)(const struct fwnode_handle___142 *);
	struct fwnode_handle___142 * (*graph_get_port_parent)(struct fwnode_handle___142 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___142 *, struct fwnode_endpoint___142 *);
	int (*add_links)(struct fwnode_handle___142 *);
};

struct fwnode_endpoint___142 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___142 *local_fwnode;
};

struct fwnode_reference_args___142 {
	struct fwnode_handle___142 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct function_desc {
	const char *name;
	const char **group_names;
	int num_group_names;
	void *data;
};

struct pinctrl_dt_map {
	struct list_head node;
	struct pinctrl_dev *pctldev;
	struct pinctrl_map *map;
	unsigned int num_maps;
};

struct pinctrl_dev___3;

struct pinctrl_ops___3 {
	int (*get_groups_count)(struct pinctrl_dev___3 *);
	const char * (*get_group_name)(struct pinctrl_dev___3 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___3 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___160 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___3 *, struct device_node___42 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___3 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___3;

struct pinctrl_dev___3 {
	struct list_head node;
	struct pinctrl_desc___3 *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___140 *dev;
	struct module___168 *owner;
	void *driver_data;
	struct pinctrl *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___184 *device_root;
};

struct pinmux_ops___2;

struct pinconf_ops___3;

struct pinctrl_desc___3 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___3 *pctlops;
	const struct pinmux_ops___2 *pmxops;
	const struct pinconf_ops___3 *confops;
	struct module___168 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinmux_ops___2 {
	int (*request)(struct pinctrl_dev___3 *, unsigned int);
	int (*free)(struct pinctrl_dev___3 *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev___3 *);
	const char * (*get_function_name)(struct pinctrl_dev___3 *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev___3 *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev___3 *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev___3 *, struct pinctrl_gpio_range *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev___3 *, struct pinctrl_gpio_range *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev___3 *, struct pinctrl_gpio_range *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops___3 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___3 *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___160 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___160 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___3 *, struct seq_file___160 *, long unsigned int);
};

struct regmap_irq_chip_data;

struct as3722 {
	struct device___140 *dev;
	struct regmap *regmap;
	int chip_irq;
	long unsigned int irq_flags;
	bool en_intern_int_pullup;
	bool en_intern_i2c_pullup;
	bool en_ac_ok_pwr_on;
	struct regmap_irq_chip_data *irq_data;
};

struct as3722_pin_function {
	const char *name;
	const char * const *groups;
	unsigned int ngroups;
	int mux_option;
};

struct as3722_gpio_pin_control {
	unsigned int mode_prop;
	int io_function;
};

struct as3722_pingroup {
	const char *name;
	const unsigned int pins[1];
	unsigned int npins;
};

struct as3722_pctrl_info {
	struct device___140 *dev;
	struct pinctrl_dev___3 *pctl;
	struct as3722 *as3722;
	struct gpio_chip gpio_chip;
	int pins_current_opt[8];
	const struct as3722_pin_function *functions;
	unsigned int num_functions;
	const struct as3722_pingroup *pin_groups;
	int num_pin_groups;
	const struct pinctrl_pin_desc *pins;
	unsigned int num_pins;
	struct as3722_gpio_pin_control gpio_control[8];
};

enum as3722_pinmux_option {
	AS3722_PINMUX_GPIO = 0,
	AS3722_PINMUX_INTERRUPT_OUT = 1,
	AS3722_PINMUX_VSUB_VBAT_UNDEB_LOW_OUT = 2,
	AS3722_PINMUX_GPIO_INTERRUPT = 3,
	AS3722_PINMUX_PWM_INPUT = 4,
	AS3722_PINMUX_VOLTAGE_IN_STBY = 5,
	AS3722_PINMUX_OC_PG_SD0 = 6,
	AS3722_PINMUX_PG_OUT = 7,
	AS3722_PINMUX_CLK32K_OUT = 8,
	AS3722_PINMUX_WATCHDOG_INPUT = 9,
	AS3722_PINMUX_SOFT_RESET_IN = 11,
	AS3722_PINMUX_PWM_OUTPUT = 12,
	AS3722_PINMUX_VSUB_VBAT_LOW_DEB_OUT = 13,
	AS3722_PINMUX_OC_PG_SD6 = 14,
};

struct fwnode_operations___143;

struct device___143;

struct fwnode_handle___143 {
	struct fwnode_handle___143 *secondary;
	const struct fwnode_operations___143 *ops;
	struct device___143 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___143;

struct fwnode_endpoint___143;

struct fwnode_operations___143 {
	struct fwnode_handle___143 * (*get)(struct fwnode_handle___143 *);
	void (*put)(struct fwnode_handle___143 *);
	bool (*device_is_available)(const struct fwnode_handle___143 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___143 *, const struct device___143 *);
	bool (*property_present)(const struct fwnode_handle___143 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___143 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___143 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___143 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*get_parent)(const struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*get_next_child_node)(const struct fwnode_handle___143 *, struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*get_named_child_node)(const struct fwnode_handle___143 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___143 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___143 *);
	struct fwnode_handle___143 * (*graph_get_next_endpoint)(const struct fwnode_handle___143 *, struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*graph_get_remote_endpoint)(const struct fwnode_handle___143 *);
	struct fwnode_handle___143 * (*graph_get_port_parent)(struct fwnode_handle___143 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___143 *, struct fwnode_endpoint___143 *);
	int (*add_links)(struct fwnode_handle___143 *);
};

struct wakeup_source___143;

struct dev_pm_info___143 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___143 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___143 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___143;

struct bus_type___143;

struct device_driver___143;

struct dev_pm_domain___143;

struct irq_domain___24;

struct dev_pin_info___3;

struct device_node___45;

struct class___143;

struct device___143 {
	struct kobject___172 kobj;
	struct device___143 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___143 *type;
	struct bus_type___143 *bus;
	struct device_driver___143 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___143 power;
	struct dev_pm_domain___143 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___24 *msi_domain;
	struct dev_pin_info___3 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___45 *of_node;
	struct fwnode_handle___143 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___143 *class;
	const struct attribute_group___172 **groups;
	void (*release)(struct device___143 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___143 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___143 *local_fwnode;
};

struct fwnode_reference_args___143 {
	struct fwnode_handle___143 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___143 {
	int (*prepare)(struct device___143 *);
	void (*complete)(struct device___143 *);
	int (*suspend)(struct device___143 *);
	int (*resume)(struct device___143 *);
	int (*freeze)(struct device___143 *);
	int (*thaw)(struct device___143 *);
	int (*poweroff)(struct device___143 *);
	int (*restore)(struct device___143 *);
	int (*suspend_late)(struct device___143 *);
	int (*resume_early)(struct device___143 *);
	int (*freeze_late)(struct device___143 *);
	int (*thaw_early)(struct device___143 *);
	int (*poweroff_late)(struct device___143 *);
	int (*restore_early)(struct device___143 *);
	int (*suspend_noirq)(struct device___143 *);
	int (*resume_noirq)(struct device___143 *);
	int (*freeze_noirq)(struct device___143 *);
	int (*thaw_noirq)(struct device___143 *);
	int (*poweroff_noirq)(struct device___143 *);
	int (*restore_noirq)(struct device___143 *);
	int (*runtime_suspend)(struct device___143 *);
	int (*runtime_resume)(struct device___143 *);
	int (*runtime_idle)(struct device___143 *);
};

struct wakeup_source___143 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___143 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___143 {
	struct dev_pm_ops___143 ops;
	int (*start)(struct device___143 *);
	void (*detach)(struct device___143 *, bool);
	int (*activate)(struct device___143 *);
	void (*sync)(struct device___143 *);
	void (*dismiss)(struct device___143 *);
};

struct bus_type___143 {
	const char *name;
	const char *dev_name;
	struct device___143 *dev_root;
	const struct attribute_group___172 **bus_groups;
	const struct attribute_group___172 **dev_groups;
	const struct attribute_group___172 **drv_groups;
	int (*match)(struct device___143 *, struct device_driver___143 *);
	int (*uevent)(struct device___143 *, struct kobj_uevent_env *);
	int (*probe)(struct device___143 *);
	void (*sync_state)(struct device___143 *);
	void (*remove)(struct device___143 *);
	void (*shutdown)(struct device___143 *);
	int (*online)(struct device___143 *);
	int (*offline)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	int (*num_vf)(struct device___143 *);
	int (*dma_configure)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___143 {
	const char *name;
	struct bus_type___143 *bus;
	struct module___168 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___143 *);
	void (*sync_state)(struct device___143 *);
	int (*remove)(struct device___143 *);
	void (*shutdown)(struct device___143 *);
	int (*suspend)(struct device___143 *, pm_message_t);
	int (*resume)(struct device___143 *);
	const struct attribute_group___172 **groups;
	const struct attribute_group___172 **dev_groups;
	const struct dev_pm_ops___143 *pm;
	void (*coredump)(struct device___143 *);
	struct driver_private *p;
};

struct device_type___143 {
	const char *name;
	const struct attribute_group___172 **groups;
	int (*uevent)(struct device___143 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___143 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___143 *);
	const struct dev_pm_ops___143 *pm;
};

struct class___143 {
	const char *name;
	struct module___168 *owner;
	const struct attribute_group___172 **class_groups;
	const struct attribute_group___172 **dev_groups;
	struct kobject___172 *dev_kobj;
	int (*dev_uevent)(struct device___143 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___143 *, umode_t *);
	void (*class_release)(struct class___143 *);
	void (*dev_release)(struct device___143 *);
	int (*shutdown_pre)(struct device___143 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___143 *);
	void (*get_ownership)(struct device___143 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___143 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___24;

struct irq_domain_chip_generic___24;

struct irq_data___25;

struct irq_domain___24 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___24 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___143 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___24 *gc;
	struct irq_domain___24 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___25 *revmap[0];
};

struct pinctrl___3;

struct dev_pin_info___3 {
	struct pinctrl___3 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct device_node___45 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___143 fwnode;
	struct property___34 *properties;
	struct property___34 *deadprops;
	struct device_node___45 *parent;
	struct device_node___45 *child;
	struct device_node___45 *sibling;
	struct kobject___172 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___26;

typedef void (*irq_flow_handler_t___26)(struct irq_desc___26 *);

struct irq_chip___25;

struct irq_data___25 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___25 *chip;
	struct irq_domain___24 *domain;
	struct irq_data___25 *parent_data;
	void *chip_data;
};

struct irq_desc___26 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___25 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___26 handle_irq;
	struct irqaction___16 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___172 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___168 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___25 {
	struct device___143 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___25 *);
	void (*irq_shutdown)(struct irq_data___25 *);
	void (*irq_enable)(struct irq_data___25 *);
	void (*irq_disable)(struct irq_data___25 *);
	void (*irq_ack)(struct irq_data___25 *);
	void (*irq_mask)(struct irq_data___25 *);
	void (*irq_mask_ack)(struct irq_data___25 *);
	void (*irq_unmask)(struct irq_data___25 *);
	void (*irq_eoi)(struct irq_data___25 *);
	int (*irq_set_affinity)(struct irq_data___25 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___25 *);
	int (*irq_set_type)(struct irq_data___25 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___25 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___25 *);
	void (*irq_bus_sync_unlock)(struct irq_data___25 *);
	void (*irq_cpu_online)(struct irq_data___25 *);
	void (*irq_cpu_offline)(struct irq_data___25 *);
	void (*irq_suspend)(struct irq_data___25 *);
	void (*irq_resume)(struct irq_data___25 *);
	void (*irq_pm_shutdown)(struct irq_data___25 *);
	void (*irq_calc_mask)(struct irq_data___25 *);
	void (*irq_print_chip)(struct irq_data___25 *, struct seq_file___160 *);
	int (*irq_request_resources)(struct irq_data___25 *);
	void (*irq_release_resources)(struct irq_data___25 *);
	void (*irq_compose_msi_msg)(struct irq_data___25 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___25 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___25 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___25 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___25 *, void *);
	void (*ipi_send_single)(struct irq_data___25 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___25 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___25 *);
	void (*irq_nmi_teardown)(struct irq_data___25 *);
	long unsigned int flags;
};

struct irq_chip_type___24 {
	struct irq_chip___25 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___26 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___24 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___24 *);
	void (*resume)(struct irq_chip_generic___24 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___24 *domain;
	struct list_head list;
	struct irq_chip_type___24 chip_types[0];
};

struct irq_domain_chip_generic___24 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___24 *gc[0];
};

struct of_phandle_args___11 {
	struct device_node___45 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___22 {
	struct fwnode_handle___143 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___24 {
	int (*match)(struct irq_domain___24 *, struct device_node___45 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___24 *, struct irq_fwspec___22 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___24 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___24 *, unsigned int);
	int (*xlate)(struct irq_domain___24 *, struct device_node___45 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___24 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___24 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___24 *, struct irq_data___25 *, bool);
	void (*deactivate)(struct irq_domain___24 *, struct irq_data___25 *);
	int (*translate)(struct irq_domain___24 *, struct irq_fwspec___22 *, long unsigned int *, unsigned int *);
};

struct pinctrl___3 {
	struct list_head node;
	struct device___143 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct gpio_chip___2;

struct gpio_irq_chip___2 {
	struct irq_chip___25 *chip;
	struct irq_domain___24 *domain;
	const struct irq_domain_ops___24 *domain_ops;
	struct fwnode_handle___143 *fwnode;
	struct irq_domain___24 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___2 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___2 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___2 *, unsigned int);
	struct irq_domain_ops___24 child_irq_domain_ops;
	irq_flow_handler_t___26 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___26 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___2 *);
	void (*init_valid_mask)(struct gpio_chip___2 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___25 *);
	void (*irq_disable)(struct irq_data___25 *);
	void (*irq_unmask)(struct irq_data___25 *);
	void (*irq_mask)(struct irq_data___25 *);
};

struct gpio_chip___2 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___143 *parent;
	struct module___168 *owner;
	int (*request)(struct gpio_chip___2 *, unsigned int);
	void (*free)(struct gpio_chip___2 *, unsigned int);
	int (*get_direction)(struct gpio_chip___2 *, unsigned int);
	int (*direction_input)(struct gpio_chip___2 *, unsigned int);
	int (*direction_output)(struct gpio_chip___2 *, unsigned int, int);
	int (*get)(struct gpio_chip___2 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___2 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___2 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___2 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___2 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___2 *, unsigned int);
	void (*dbg_show)(struct seq_file___160 *, struct gpio_chip___2 *);
	int (*init_valid_mask)(struct gpio_chip___2 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___2 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___2 irq;
	long unsigned int *valid_mask;
	struct device_node___45 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___2 *, const struct of_phandle_args___11 *, u32 *);
};

struct pinctrl_dev___4;

struct pinctrl_ops___4 {
	int (*get_groups_count)(struct pinctrl_dev___4 *);
	const char * (*get_group_name)(struct pinctrl_dev___4 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___4 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___160 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___4 *, struct device_node___45 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___4 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___4;

struct pinctrl_dev___4 {
	struct list_head node;
	struct pinctrl_desc___4 *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___143 *dev;
	struct module___168 *owner;
	void *driver_data;
	struct pinctrl___3 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___184 *device_root;
};

struct pinconf_ops___4;

struct pinctrl_desc___4 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___4 *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops___4 *confops;
	struct module___168 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinconf_ops___4 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___160 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___160 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___160 *, long unsigned int);
};

struct platform_device___11 {
	const char *name;
	int id;
	bool id_auto;
	struct device___143 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___10 {
	int (*probe)(struct platform_device___11 *);
	int (*remove)(struct platform_device___11 *);
	void (*shutdown)(struct platform_device___11 *);
	int (*suspend)(struct platform_device___11 *, pm_message_t);
	int (*resume)(struct platform_device___11 *);
	struct device_driver___143 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct pin_desc___2 {
	struct pinctrl_dev___4 *pctldev;
	const char *name;
	bool dynamic_name;
	void *drv_data;
	unsigned int mux_usecount;
	const char *mux_owner;
	const struct pinctrl_setting_mux *mux_setting;
	const char *gpio_owner;
};

struct amd_pingroup {
	const char *name;
	const unsigned int *pins;
	unsigned int npins;
};

struct amd_gpio {
	raw_spinlock_t lock;
	void *base;
	const struct amd_pingroup *groups;
	u32 ngroups;
	struct pinctrl_dev___4 *pctrl;
	struct gpio_chip___2 gc;
	unsigned int hwbank_num;
	struct resource *res;
	struct platform_device___11 *pdev;
	u32 *saved_regs;
	int irq;
};

struct platform_device___12 {
	const char *name;
	int id;
	bool id_auto;
	struct device___142 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___11 {
	int (*probe)(struct platform_device___12 *);
	int (*remove)(struct platform_device___12 *);
	void (*shutdown)(struct platform_device___12 *);
	int (*suspend)(struct platform_device___12 *, pm_message_t);
	int (*resume)(struct platform_device___12 *);
	struct device_driver___142 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct pinctrl_dev___5;

struct pinctrl_ops___5 {
	int (*get_groups_count)(struct pinctrl_dev___5 *);
	const char * (*get_group_name)(struct pinctrl_dev___5 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___5 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___161 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___5 *, struct device_node___44 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___5 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___5;

struct pinctrl_dev___5 {
	struct list_head node;
	struct pinctrl_desc___5 *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___142 *dev;
	struct module___8 *owner;
	void *driver_data;
	struct pinctrl___2 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___185 *device_root;
};

struct pinmux_ops___3;

struct pinconf_ops___5;

struct pinctrl_desc___5 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___5 *pctlops;
	const struct pinmux_ops___3 *pmxops;
	const struct pinconf_ops___5 *confops;
	struct module___8 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinmux_ops___3 {
	int (*request)(struct pinctrl_dev___5 *, unsigned int);
	int (*free)(struct pinctrl_dev___5 *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev___5 *);
	const char * (*get_function_name)(struct pinctrl_dev___5 *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev___5 *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev___5 *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev___5 *, struct pinctrl_gpio_range *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev___5 *, struct pinctrl_gpio_range *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev___5 *, struct pinctrl_gpio_range *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops___5 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___5 *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___161 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___161 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___5 *, struct seq_file___161 *, long unsigned int);
};

struct bm1880_pctrl_group;

struct bm1880_pinmux_function;

struct bm1880_pinconf_data;

struct bm1880_pinctrl {
	void *base;
	struct pinctrl_dev___5 *pctrldev;
	const struct bm1880_pctrl_group *groups;
	unsigned int ngroups;
	const struct bm1880_pinmux_function *funcs;
	unsigned int nfuncs;
	const struct bm1880_pinconf_data *pinconf;
};

struct bm1880_pctrl_group {
	const char *name;
	const unsigned int *pins;
	const unsigned int npins;
};

struct bm1880_pinmux_function {
	const char *name;
	const char * const *groups;
	unsigned int ngroups;
	u32 mux_val;
	u32 mux;
	u8 mux_shift;
};

struct bm1880_pinconf_data {
	u32 drv_bits;
};

enum bm1880_pinmux_functions {
	F_nand = 0,
	F_spi = 1,
	F_emmc = 2,
	F_sdio = 3,
	F_eth0 = 4,
	F_pwm0 = 5,
	F_pwm1 = 6,
	F_pwm2 = 7,
	F_pwm3 = 8,
	F_pwm4 = 9,
	F_pwm5 = 10,
	F_pwm6 = 11,
	F_pwm7 = 12,
	F_pwm8 = 13,
	F_pwm9 = 14,
	F_pwm10 = 15,
	F_pwm11 = 16,
	F_pwm12 = 17,
	F_pwm13 = 18,
	F_pwm14 = 19,
	F_pwm15 = 20,
	F_pwm16 = 21,
	F_pwm17 = 22,
	F_pwm18 = 23,
	F_pwm19 = 24,
	F_pwm20 = 25,
	F_pwm21 = 26,
	F_pwm22 = 27,
	F_pwm23 = 28,
	F_pwm24 = 29,
	F_pwm25 = 30,
	F_pwm26 = 31,
	F_pwm27 = 32,
	F_pwm28 = 33,
	F_pwm29 = 34,
	F_pwm30 = 35,
	F_pwm31 = 36,
	F_pwm32 = 37,
	F_pwm33 = 38,
	F_pwm34 = 39,
	F_pwm35 = 40,
	F_pwm36 = 41,
	F_pwm37 = 42,
	F_i2c0 = 43,
	F_i2c1 = 44,
	F_i2c2 = 45,
	F_i2c3 = 46,
	F_i2c4 = 47,
	F_uart0 = 48,
	F_uart1 = 49,
	F_uart2 = 50,
	F_uart3 = 51,
	F_uart4 = 52,
	F_uart5 = 53,
	F_uart6 = 54,
	F_uart7 = 55,
	F_uart8 = 56,
	F_uart9 = 57,
	F_uart10 = 58,
	F_uart11 = 59,
	F_uart12 = 60,
	F_uart13 = 61,
	F_uart14 = 62,
	F_uart15 = 63,
	F_gpio0 = 64,
	F_gpio1 = 65,
	F_gpio2 = 66,
	F_gpio3 = 67,
	F_gpio4 = 68,
	F_gpio5 = 69,
	F_gpio6 = 70,
	F_gpio7 = 71,
	F_gpio8 = 72,
	F_gpio9 = 73,
	F_gpio10 = 74,
	F_gpio11 = 75,
	F_gpio12 = 76,
	F_gpio13 = 77,
	F_gpio14 = 78,
	F_gpio15 = 79,
	F_gpio16 = 80,
	F_gpio17 = 81,
	F_gpio18 = 82,
	F_gpio19 = 83,
	F_gpio20 = 84,
	F_gpio21 = 85,
	F_gpio22 = 86,
	F_gpio23 = 87,
	F_gpio24 = 88,
	F_gpio25 = 89,
	F_gpio26 = 90,
	F_gpio27 = 91,
	F_gpio28 = 92,
	F_gpio29 = 93,
	F_gpio30 = 94,
	F_gpio31 = 95,
	F_gpio32 = 96,
	F_gpio33 = 97,
	F_gpio34 = 98,
	F_gpio35 = 99,
	F_gpio36 = 100,
	F_gpio37 = 101,
	F_gpio38 = 102,
	F_gpio39 = 103,
	F_gpio40 = 104,
	F_gpio41 = 105,
	F_gpio42 = 106,
	F_gpio43 = 107,
	F_gpio44 = 108,
	F_gpio45 = 109,
	F_gpio46 = 110,
	F_gpio47 = 111,
	F_gpio48 = 112,
	F_gpio49 = 113,
	F_gpio50 = 114,
	F_gpio51 = 115,
	F_gpio52 = 116,
	F_gpio53 = 117,
	F_gpio54 = 118,
	F_gpio55 = 119,
	F_gpio56 = 120,
	F_gpio57 = 121,
	F_gpio58 = 122,
	F_gpio59 = 123,
	F_gpio60 = 124,
	F_gpio61 = 125,
	F_gpio62 = 126,
	F_gpio63 = 127,
	F_gpio64 = 128,
	F_gpio65 = 129,
	F_gpio66 = 130,
	F_gpio67 = 131,
	F_eth1 = 132,
	F_i2s0 = 133,
	F_i2s0_mclkin = 134,
	F_i2s1 = 135,
	F_i2s1_mclkin = 136,
	F_spi0 = 137,
	F_max = 138,
};

struct regmap_config___3 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___143 *, unsigned int);
	bool (*readable_reg)(struct device___143 *, unsigned int);
	bool (*volatile_reg)(struct device___143 *, unsigned int);
	bool (*precious_reg)(struct device___143 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___143 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___143 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct meson_pmx_group {
	const char *name;
	const unsigned int *pins;
	unsigned int num_pins;
	const void *data;
};

struct meson_pmx_func {
	const char *name;
	const char * const *groups;
	unsigned int num_groups;
};

struct meson_reg_desc {
	unsigned int reg;
	unsigned int bit;
};

enum meson_reg_type {
	REG_PULLEN = 0,
	REG_PULL = 1,
	REG_DIR = 2,
	REG_OUT = 3,
	REG_IN = 4,
	REG_DS = 5,
	NUM_REG = 6,
};

enum meson_pinconf_drv {
	MESON_PINCONF_DRV_500UA = 0,
	MESON_PINCONF_DRV_2500UA = 1,
	MESON_PINCONF_DRV_3000UA = 2,
	MESON_PINCONF_DRV_4000UA = 3,
};

struct meson_bank {
	const char *name;
	unsigned int first;
	unsigned int last;
	int irq_first;
	int irq_last;
	struct meson_reg_desc regs[6];
};

struct meson_pinctrl;

struct meson_pinctrl_data {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	struct meson_pmx_group *groups;
	struct meson_pmx_func *funcs;
	unsigned int num_pins;
	unsigned int num_groups;
	unsigned int num_funcs;
	struct meson_bank *banks;
	unsigned int num_banks;
	const struct pinmux_ops___2 *pmx_ops;
	void *pmx_data;
	int (*parse_dt)(struct meson_pinctrl *);
};

struct meson_pinctrl {
	struct device___143 *dev;
	struct pinctrl_dev___3 *pcdev;
	struct pinctrl_desc___3 desc;
	struct meson_pinctrl_data *data;
	struct regmap *reg_mux;
	struct regmap *reg_pullen;
	struct regmap *reg_pull;
	struct regmap *reg_gpio;
	struct regmap *reg_ds;
	struct gpio_chip chip;
	struct device_node___45 *of_node;
};

struct meson8_pmx_data {
	bool is_gpio;
	unsigned int reg;
	unsigned int bit;
};

struct gpio_chip___3;

struct gpio_irq_chip___3 {
	struct irq_chip___3 *chip;
	struct irq_domain___2 *domain;
	const struct irq_domain_ops___3 *domain_ops;
	struct fwnode_handle___7 *fwnode;
	struct irq_domain___2 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___3 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___3 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___3 *, unsigned int);
	struct irq_domain_ops___3 child_irq_domain_ops;
	irq_flow_handler_t___3 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___3 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___3 *);
	void (*init_valid_mask)(struct gpio_chip___3 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___3 *);
	void (*irq_disable)(struct irq_data___3 *);
	void (*irq_unmask)(struct irq_data___3 *);
	void (*irq_mask)(struct irq_data___3 *);
};

struct gpio_chip___3 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___141 *parent;
	struct module___169 *owner;
	int (*request)(struct gpio_chip___3 *, unsigned int);
	void (*free)(struct gpio_chip___3 *, unsigned int);
	int (*get_direction)(struct gpio_chip___3 *, unsigned int);
	int (*direction_input)(struct gpio_chip___3 *, unsigned int);
	int (*direction_output)(struct gpio_chip___3 *, unsigned int, int);
	int (*get)(struct gpio_chip___3 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___3 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___3 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___3 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___3 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___3 *, unsigned int);
	void (*dbg_show)(struct seq_file___161 *, struct gpio_chip___3 *);
	int (*init_valid_mask)(struct gpio_chip___3 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___3 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___3 irq;
	long unsigned int *valid_mask;
	struct device_node___2 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___3 *, const struct of_phandle_args___10 *, u32 *);
};

struct pinctrl_ops___6 {
	int (*get_groups_count)(struct pinctrl_dev___4 *);
	const char * (*get_group_name)(struct pinctrl_dev___4 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___4 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___4 *, struct seq_file___161 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___4 *, struct device_node___2 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___4 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___6 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___6 *pctlops;
	const struct pinmux_ops *pmxops;
	const struct pinconf_ops___4 *confops;
	struct module___169 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct meson_pinctrl___2;

struct meson_pinctrl_data___2 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	struct meson_pmx_group *groups;
	struct meson_pmx_func *funcs;
	unsigned int num_pins;
	unsigned int num_groups;
	unsigned int num_funcs;
	struct meson_bank *banks;
	unsigned int num_banks;
	const struct pinmux_ops *pmx_ops;
	void *pmx_data;
	int (*parse_dt)(struct meson_pinctrl___2 *);
};

struct meson_pinctrl___2 {
	struct device___141 *dev;
	struct pinctrl_dev___4 *pcdev;
	struct pinctrl_desc___6 desc;
	struct meson_pinctrl_data___2 *data;
	struct regmap *reg_mux;
	struct regmap *reg_pullen;
	struct regmap *reg_pull;
	struct regmap *reg_gpio;
	struct regmap *reg_ds;
	struct gpio_chip___3 chip;
	struct device_node___2 *of_node;
};

struct meson_pmx_bank {
	const char *name;
	unsigned int first;
	unsigned int last;
	unsigned int reg;
	unsigned int offset;
};

struct meson_axg_pmx_data {
	struct meson_pmx_bank *pmx_banks;
	unsigned int num_pmx_banks;
};

struct meson_pmx_axg_data {
	unsigned int func;
};

struct dentry___186;

struct super_block___186;

struct module___170;

struct file_system_type___186 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___186 * (*mount)(struct file_system_type___186 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___186 *);
	struct module___170 *owner;
	struct file_system_type___186 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___186;

struct kiocb___186;

struct iov_iter___110;

struct vm_area_struct___191;

struct inode___186;

struct file_lock___186;

struct page___191;

struct seq_file___162;

struct file_operations___187 {
	struct module___170 *owner;
	loff_t (*llseek)(struct file___186 *, loff_t, int);
	ssize_t (*read)(struct file___186 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___186 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___186 *, struct iov_iter___110 *);
	ssize_t (*write_iter)(struct kiocb___186 *, struct iov_iter___110 *);
	int (*iopoll)(struct kiocb___186 *, bool);
	int (*iterate)(struct file___186 *, struct dir_context *);
	int (*iterate_shared)(struct file___186 *, struct dir_context *);
	__poll_t (*poll)(struct file___186 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___186 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___186 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___186 *, struct vm_area_struct___191 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___186 *, struct file___186 *);
	int (*flush)(struct file___186 *, fl_owner_t);
	int (*release)(struct inode___186 *, struct file___186 *);
	int (*fsync)(struct file___186 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___186 *, int);
	int (*lock)(struct file___186 *, int, struct file_lock___186 *);
	ssize_t (*sendpage)(struct file___186 *, struct page___191 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___186 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___186 *, long unsigned int);
	int (*flock)(struct file___186 *, int, struct file_lock___186 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___186 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___186 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___186 *, long int, struct file_lock___186 **, void **);
	long int (*fallocate)(struct file___186 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___162 *, struct file___186 *);
	ssize_t (*copy_file_range)(struct file___186 *, loff_t, struct file___186 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___186 *, loff_t, struct file___186 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___186 *, loff_t, loff_t, int);
};

struct vmacache___191 {
	u64 seqnum;
	struct vm_area_struct___191 *vmas[4];
};

struct page_frag___191 {
	struct page___191 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___192;

struct pid___165;

struct nsproxy___174;

struct signal_struct___187;

struct bio_list___92;

struct backing_dev_info___85;

struct io_context___92;

struct css_set___126;

struct mem_cgroup___76;

struct request_queue___92;

struct vm_struct___169;

struct task_struct___193 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___193 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___192 *mm;
	struct mm_struct___192 *active_mm;
	struct vmacache___191 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___193 *real_parent;
	struct task_struct___193 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___193 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___165 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___174 *nsproxy;
	struct signal_struct___187 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___193 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___92 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___85 *backing_dev_info;
	struct io_context___92 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___126 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___191 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___76 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___76 *active_memcg;
	struct request_queue___92 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___193 *oom_reaper_list;
	struct vm_struct___169 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___174;

struct kobj_type___174;

struct kernfs_node___174;

struct kobject___174 {
	const char *name;
	struct list_head entry;
	struct kobject___174 *parent;
	struct kset___174 *kset;
	struct kobj_type___174 *ktype;
	struct kernfs_node___174 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___170 {
	struct kobject___174 kobj;
	struct module___170 *mod;
	struct kobject___174 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___170 {
	struct module___170 *mod;
	struct latch_tree_node node;
};

struct module_layout___170 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___170 mtn;
};

struct module_attribute___170;

struct kernel_param___170;

struct module___170 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___170 mkobj;
	struct module_attribute___170 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___174 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___170 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___170 core_layout;
	struct module_layout___170 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___165;

struct upid___165 {
	int nr;
	struct pid_namespace___165 *ns;
};

struct pid_namespace___165 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___193 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___165 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___165 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___165 numbers[1];
};

typedef struct page___191 *pgtable_t___191;

struct address_space___186;

struct dev_pagemap___181;

struct page___191 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___186 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___191 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___191 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___192 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___181 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ww_acquire_ctx___4;

struct ww_mutex___2 {
	struct mutex base;
	struct ww_acquire_ctx___4 *ctx;
};

struct ww_acquire_ctx___4 {
	struct task_struct___193 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct vm_operations_struct___181;

struct vm_area_struct___191 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___191 *vm_next;
	struct vm_area_struct___191 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___192 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___181 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___186 *vm_file;
	struct file___186 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___187 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___193 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___193 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___165 *pids[4];
	struct pid___165 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___192 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___191;

struct mm_struct___192 {
	struct {
		struct vm_area_struct___191 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___186 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___191 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___193 *owner;
		struct user_namespace___25 *user_ns;
		struct file___186 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___126;

struct nsproxy___174 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___165 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___126 *cgroup_ns;
};

struct bio___92;

struct bio_list___92 {
	struct bio___92 *head;
	struct bio___92 *tail;
};

struct cgroup_subsys_state___126;

struct bdi_writeback___85 {
	struct backing_dev_info___85 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___126 *memcg_css;
	struct cgroup_subsys_state___126 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___144;

struct backing_dev_info___85 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___85 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___144 *dev;
	char dev_name[64];
	struct device___144 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___186 *debug_dir;
};

struct io_cq___92;

struct io_context___92 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___92 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___126;

struct css_set___126 {
	struct cgroup_subsys_state___126 *subsys[14];
	refcount_t refcount;
	struct css_set___126 *dom_cset;
	struct cgroup___126 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___126 *mg_src_cgrp;
	struct cgroup___126 *mg_dst_cgrp;
	struct css_set___126 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___126;

struct cgroup_subsys_state___126 {
	struct cgroup___126 *cgroup;
	struct cgroup_subsys___126 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___126 *parent;
};

struct cgroup_file___126 {
	struct kernfs_node___174 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___76;

struct mem_cgroup_per_node___76;

struct mem_cgroup___76 {
	struct cgroup_subsys_state___126 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___126 events_file;
	struct cgroup_file___126 events_local_file;
	struct cgroup_file___126 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___76 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___193 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___76 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___92;

struct blk_integrity___92 {
	const struct blk_integrity_profile___92 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___92 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___92 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___92;

struct elevator_queue___92;

struct blk_mq_ops___89;

struct blk_mq_hw_ctx___89;

struct gendisk___93;

struct blkcg_gq___87;

struct blk_mq_tag_set___89;

struct request_queue___92 {
	struct request___92 *last_merge;
	struct elevator_queue___92 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___89 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___89 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___93 *disk;
	struct kobject___174 kobj;
	struct kobject___174 *mq_kobj;
	struct blk_integrity___92 integrity;
	struct device___144 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___87 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___89 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___92 bio_split;
	struct dentry___186 *debugfs_dir;
	struct dentry___186 *sched_debugfs_dir;
	struct dentry___186 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___169 {
	struct vm_struct___169 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___191 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___186;

struct address_space___186 {
	struct inode___186 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___186 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___181;

struct dev_pagemap___181 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___181 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___186;

struct path___186 {
	struct vfsmount___186 *mnt;
	struct dentry___186 *dentry;
};

struct fown_struct___165 {
	rwlock_t lock;
	struct pid___165 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___186 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___186 f_path;
	struct inode___186 *f_inode;
	const struct file_operations___187 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___165 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___186 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___181;

struct vm_operations_struct___181 {
	void (*open)(struct vm_area_struct___191 *);
	void (*close)(struct vm_area_struct___191 *);
	int (*may_split)(struct vm_area_struct___191 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___191 *);
	int (*mprotect)(struct vm_area_struct___191 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___181 *);
	vm_fault_t (*huge_fault)(struct vm_fault___181 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___181 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___191 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___181 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___181 *);
	int (*access)(struct vm_area_struct___191 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___191 *);
	int (*set_policy)(struct vm_area_struct___191 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___191 *, long unsigned int);
	struct page___191 * (*find_special_page)(struct vm_area_struct___191 *, long unsigned int);
};

struct core_thread___191 {
	struct task_struct___193 *task;
	struct core_thread___191 *next;
};

struct core_state___191 {
	atomic_t nr_threads;
	struct core_thread___191 dumper;
	struct completion startup;
};

struct vm_fault___181 {
	const struct {
		struct vm_area_struct___191 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___191 *cow_page;
	struct page___191 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___191 prealloc_pte;
};

struct pglist_data___83;

struct lruvec___83 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___83 *pgdat;
};

struct zone___83 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___83 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___83 {
	struct zone___83 *zone;
	int zone_idx;
};

struct zonelist___83 {
	struct zoneref___83 _zonerefs[321];
};

struct pglist_data___83 {
	struct zone___83 node_zones[5];
	struct zonelist___83 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___193 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___193 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___83 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___186;

struct dentry___186 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___186 *d_parent;
	struct qstr d_name;
	struct inode___186 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___186 *d_op;
	struct super_block___186 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___186;

struct inode___186 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___186 *i_op;
	struct super_block___186 *i_sb;
	struct address_space___186 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___85 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___187 *i_fop;
		void (*free_inode)(struct inode___186 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___186 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___63 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___186 {
	int (*d_revalidate)(struct dentry___186 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___186 *, unsigned int);
	int (*d_hash)(const struct dentry___186 *, struct qstr *);
	int (*d_compare)(const struct dentry___186 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___186 *);
	int (*d_init)(struct dentry___186 *);
	void (*d_release)(struct dentry___186 *);
	void (*d_prune)(struct dentry___186 *);
	void (*d_iput)(struct dentry___186 *, struct inode___186 *);
	char * (*d_dname)(struct dentry___186 *, char *, int);
	struct vfsmount___186 * (*d_automount)(struct path___186 *);
	int (*d_manage)(const struct path___186 *, bool);
	struct dentry___186 * (*d_real)(struct dentry___186 *, const struct inode___186 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___186;

struct mem_dqinfo___186 {
	struct quota_format_type___186 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___186;

struct quota_info___186 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___186 *files[3];
	struct mem_dqinfo___186 info[3];
	const struct quota_format_ops___186 *ops[3];
};

struct rcuwait___187 {
	struct task_struct___193 *task;
};

struct percpu_rw_semaphore___187 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___187 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___186 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___187 rw_sem[3];
};

struct shrink_control___76;

struct shrinker___76 {
	long unsigned int (*count_objects)(struct shrinker___76 *, struct shrink_control___76 *);
	long unsigned int (*scan_objects)(struct shrinker___76 *, struct shrink_control___76 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___186;

struct dquot_operations___186;

struct quotactl_ops___186;

struct block_device___93;

struct super_block___186 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___186 *s_type;
	const struct super_operations___186 *s_op;
	const struct dquot_operations___186 *dq_op;
	const struct quotactl_ops___186 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___186 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___93 *s_bdev;
	struct backing_dev_info___85 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___186 s_dquot;
	struct sb_writers___186 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___186 *s_d_op;
	int cleancache_poolid;
	struct shrinker___76 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___186 {
	struct dentry___186 *mnt_root;
	struct super_block___186 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___76 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___76 *memcg;
};

struct psi_group___126 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___193 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___126;

struct cgroup_rstat_cpu___126;

struct cgroup___126 {
	struct cgroup_subsys_state___126 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___174 *kn;
	struct cgroup_file___126 procs_file;
	struct cgroup_file___126 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___126 *subsys[14];
	struct cgroup_root___126 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___126 *dom_cgrp;
	struct cgroup___126 *old_dom_cgrp;
	struct cgroup_rstat_cpu___126 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___126 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___92 {
	struct request_queue___92 *q;
	struct io_context___92 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___85;

struct kiocb___186 {
	struct file___186 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___186 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___85 *ki_waitq;
	};
};

struct iattr___186 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___186 *ia_file;
};

struct dquot___186 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___186 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___186 {
	int qf_fmt_id;
	const struct quota_format_ops___186 *qf_ops;
	struct module___170 *qf_owner;
	struct quota_format_type___186 *qf_next;
};

struct quota_format_ops___186 {
	int (*check_quota_file)(struct super_block___186 *, int);
	int (*read_file_info)(struct super_block___186 *, int);
	int (*write_file_info)(struct super_block___186 *, int);
	int (*free_file_info)(struct super_block___186 *, int);
	int (*read_dqblk)(struct dquot___186 *);
	int (*commit_dqblk)(struct dquot___186 *);
	int (*release_dqblk)(struct dquot___186 *);
	int (*get_next_id)(struct super_block___186 *, struct kqid *);
};

struct dquot_operations___186 {
	int (*write_dquot)(struct dquot___186 *);
	struct dquot___186 * (*alloc_dquot)(struct super_block___186 *, int);
	void (*destroy_dquot)(struct dquot___186 *);
	int (*acquire_dquot)(struct dquot___186 *);
	int (*release_dquot)(struct dquot___186 *);
	int (*mark_dirty)(struct dquot___186 *);
	int (*write_info)(struct super_block___186 *, int);
	qsize_t * (*get_reserved_space)(struct inode___186 *);
	int (*get_projid)(struct inode___186 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___186 *, qsize_t *);
	int (*get_next_id)(struct super_block___186 *, struct kqid *);
};

struct quotactl_ops___186 {
	int (*quota_on)(struct super_block___186 *, int, int, const struct path___186 *);
	int (*quota_off)(struct super_block___186 *, int);
	int (*quota_enable)(struct super_block___186 *, unsigned int);
	int (*quota_disable)(struct super_block___186 *, unsigned int);
	int (*quota_sync)(struct super_block___186 *, int);
	int (*set_info)(struct super_block___186 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___186 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___186 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___186 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___186 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___186 *, unsigned int);
};

struct wait_page_queue___85 {
	struct page___191 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___85;

struct readahead_control___85;

struct swap_info_struct___44;

struct address_space_operations___186 {
	int (*writepage)(struct page___191 *, struct writeback_control___85 *);
	int (*readpage)(struct file___186 *, struct page___191 *);
	int (*writepages)(struct address_space___186 *, struct writeback_control___85 *);
	int (*set_page_dirty)(struct page___191 *);
	int (*readpages)(struct file___186 *, struct address_space___186 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___85 *);
	int (*write_begin)(struct file___186 *, struct address_space___186 *, loff_t, unsigned int, unsigned int, struct page___191 **, void **);
	int (*write_end)(struct file___186 *, struct address_space___186 *, loff_t, unsigned int, unsigned int, struct page___191 *, void *);
	sector_t (*bmap)(struct address_space___186 *, sector_t);
	void (*invalidatepage)(struct page___191 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___191 *, gfp_t);
	void (*freepage)(struct page___191 *);
	ssize_t (*direct_IO)(struct kiocb___186 *, struct iov_iter___110 *);
	int (*migratepage)(struct address_space___186 *, struct page___191 *, struct page___191 *, enum migrate_mode);
	bool (*isolate_page)(struct page___191 *, isolate_mode_t);
	void (*putback_page)(struct page___191 *);
	int (*launder_page)(struct page___191 *);
	int (*is_partially_uptodate)(struct page___191 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___191 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___186 *, struct page___191 *);
	int (*swap_activate)(struct swap_info_struct___44 *, struct file___186 *, sector_t *);
	void (*swap_deactivate)(struct file___186 *);
};

struct writeback_control___85 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___85 *wb;
	struct inode___186 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___85 {
	struct file___186 *file;
	struct address_space___186 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___108;

struct iov_iter___110 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___108 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___44 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___93 *bdev;
	struct file___186 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___186 {
	struct dentry___186 * (*lookup)(struct inode___186 *, struct dentry___186 *, unsigned int);
	const char * (*get_link)(struct dentry___186 *, struct inode___186 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___186 *, int);
	struct posix_acl * (*get_acl)(struct inode___186 *, int, bool);
	int (*readlink)(struct dentry___186 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___186 *, struct dentry___186 *, umode_t, bool);
	int (*link)(struct dentry___186 *, struct inode___186 *, struct dentry___186 *);
	int (*unlink)(struct inode___186 *, struct dentry___186 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___186 *, struct dentry___186 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___186 *, struct dentry___186 *, umode_t);
	int (*rmdir)(struct inode___186 *, struct dentry___186 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___186 *, struct dentry___186 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___186 *, struct dentry___186 *, struct inode___186 *, struct dentry___186 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___186 *, struct iattr___186 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___186 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___186 *, char *, size_t);
	int (*fiemap)(struct inode___186 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___186 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___186 *, struct dentry___186 *, struct file___186 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___186 *, struct dentry___186 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___186 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___186 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___186 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___186 {
	void (*fl_copy_lock)(struct file_lock___186 *, struct file_lock___186 *);
	void (*fl_release_private)(struct file_lock___186 *);
};

struct fasync_struct___186;

struct lock_manager_operations___186;

struct file_lock___186 {
	struct file_lock___186 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___186 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___186 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___186 *fl_ops;
	const struct lock_manager_operations___186 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___186 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___186 *);
	int (*lm_grant)(struct file_lock___186 *, int);
	bool (*lm_break)(struct file_lock___186 *);
	int (*lm_change)(struct file_lock___186 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___186 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___186 *);
};

struct fasync_struct___186 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___186 *fa_next;
	struct file___186 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___186 {
	struct inode___186 * (*alloc_inode)(struct super_block___186 *);
	void (*destroy_inode)(struct inode___186 *);
	void (*free_inode)(struct inode___186 *);
	void (*dirty_inode)(struct inode___186 *, int);
	int (*write_inode)(struct inode___186 *, struct writeback_control___85 *);
	int (*drop_inode)(struct inode___186 *);
	void (*evict_inode)(struct inode___186 *);
	void (*put_super)(struct super_block___186 *);
	int (*sync_fs)(struct super_block___186 *, int);
	int (*freeze_super)(struct super_block___186 *);
	int (*freeze_fs)(struct super_block___186 *);
	int (*thaw_super)(struct super_block___186 *);
	int (*unfreeze_fs)(struct super_block___186 *);
	int (*statfs)(struct dentry___186 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___186 *, int *, char *);
	void (*umount_begin)(struct super_block___186 *);
	int (*show_options)(struct seq_file___162 *, struct dentry___186 *);
	int (*show_devname)(struct seq_file___162 *, struct dentry___186 *);
	int (*show_path)(struct seq_file___162 *, struct dentry___186 *);
	int (*show_stats)(struct seq_file___162 *, struct dentry___186 *);
	ssize_t (*quota_read)(struct super_block___186 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___186 *, int, const char *, size_t, loff_t);
	struct dquot___186 ** (*get_dquots)(struct inode___186 *);
	long int (*nr_cached_objects)(struct super_block___186 *, struct shrink_control___76 *);
	long int (*free_cached_objects)(struct super_block___186 *, struct shrink_control___76 *);
	struct file___186 * (*real_loop)(struct file___186 *);
};

struct wakeup_source___144;

struct dev_pm_info___144 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___144 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___144 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___144;

struct bus_type___144;

struct device_driver___144;

struct dev_pm_domain___144;

struct irq_domain___25;

struct dev_pin_info___4;

struct device_node___46;

struct fwnode_handle___144;

struct class___144;

struct attribute_group___174;

struct device___144 {
	struct kobject___174 kobj;
	struct device___144 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___144 *type;
	struct bus_type___144 *bus;
	struct device_driver___144 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___144 power;
	struct dev_pm_domain___144 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___25 *msi_domain;
	struct dev_pin_info___4 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___46 *of_node;
	struct fwnode_handle___144 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___144 *class;
	const struct attribute_group___174 **groups;
	void (*release)(struct device___144 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___93 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___186 *bd_inode;
	struct super_block___186 *bd_super;
	void *bd_claiming;
	struct device___144 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___174 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___93 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___186 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___162;

struct seq_file___162 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___162 *op;
	int poll_event;
	const struct file___186 *file;
	void *private;
};

typedef void bio_end_io_t___92(struct bio___92 *);

struct bio_vec___108 {
	struct page___191 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___92;

struct bio___92 {
	struct bio___92 *bi_next;
	struct block_device___93 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___92 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___87 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___92 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___108 *bi_io_vec;
	struct bio_set___92 *bi_pool;
	struct bio_vec___108 bi_inline_vecs[0];
};

struct kernfs_root___174;

struct kernfs_elem_dir___174 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___174 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___174;

struct kernfs_root___174 {
	struct kernfs_node___174 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___174 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___174 {
	struct kernfs_node___174 *target_kn;
};

struct kernfs_ops___174;

struct kernfs_elem_attr___174 {
	const struct kernfs_ops___174 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___174 *notify_next;
};

struct kernfs_node___174 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___174 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___174 dir;
		struct kernfs_elem_symlink___174 symlink;
		struct kernfs_elem_attr___174 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___174;

struct kernfs_ops___174 {
	int (*open)(struct kernfs_open_file___174 *);
	void (*release)(struct kernfs_open_file___174 *);
	int (*seq_show)(struct seq_file___162 *, void *);
	void * (*seq_start)(struct seq_file___162 *, loff_t *);
	void * (*seq_next)(struct seq_file___162 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___162 *, void *);
	ssize_t (*read)(struct kernfs_open_file___174 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___174 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___174 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___174 *, struct vm_area_struct___191 *);
};

struct kernfs_syscall_ops___174 {
	int (*show_options)(struct seq_file___162 *, struct kernfs_root___174 *);
	int (*mkdir)(struct kernfs_node___174 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___174 *);
	int (*rename)(struct kernfs_node___174 *, struct kernfs_node___174 *, const char *);
	int (*show_path)(struct seq_file___162 *, struct kernfs_node___174 *, struct kernfs_root___174 *);
};

struct kernfs_open_file___174 {
	struct kernfs_node___174 *kn;
	struct file___186 *file;
	struct seq_file___162 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___181 *vm_ops;
};

struct bin_attribute___174;

struct attribute_group___174 {
	const char *name;
	umode_t (*is_visible)(struct kobject___174 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___174 *, struct bin_attribute___174 *, int);
	struct attribute **attrs;
	struct bin_attribute___174 **bin_attrs;
};

struct bin_attribute___174 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___186 * (*f_mapping)();
	ssize_t (*read)(struct file___186 *, struct kobject___174 *, struct bin_attribute___174 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___186 *, struct kobject___174 *, struct bin_attribute___174 *, char *, loff_t, size_t);
	int (*mmap)(struct file___186 *, struct kobject___174 *, struct bin_attribute___174 *, struct vm_area_struct___191 *);
};

struct sysfs_ops___174 {
	ssize_t (*show)(struct kobject___174 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___174 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___174;

struct kset___174 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___174 kobj;
	const struct kset_uevent_ops___174 *uevent_ops;
};

struct kobj_type___174 {
	void (*release)(struct kobject___174 *);
	const struct sysfs_ops___174 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___174 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___174 *);
	const void * (*namespace)(struct kobject___174 *);
	void (*get_ownership)(struct kobject___174 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___174 {
	int (* const filter)(struct kset___174 *, struct kobject___174 *);
	const char * (* const name)(struct kset___174 *, struct kobject___174 *);
	int (* const uevent)(struct kset___174 *, struct kobject___174 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___170 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___170 *);
	int (*get)(char *, const struct kernel_param___170 *);
	void (*free)(void *);
};

struct kparam_array___170;

struct kernel_param___170 {
	const char *name;
	struct module___170 *mod;
	const struct kernel_param_ops___170 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___170 *arr;
	};
};

struct kparam_array___170 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___170 *ops;
	void *elem;
};

struct module_attribute___170 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___170 *, struct module_kobject___170 *, char *);
	ssize_t (*store)(struct module_attribute___170 *, struct module_kobject___170 *, const char *, size_t);
	void (*setup)(struct module___170 *, const char *);
	int (*test)(struct module___170 *);
	void (*free)(struct module___170 *);
};

struct fwnode_operations___144;

struct fwnode_handle___144 {
	struct fwnode_handle___144 *secondary;
	const struct fwnode_operations___144 *ops;
	struct device___144 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___144;

struct fwnode_endpoint___144;

struct fwnode_operations___144 {
	struct fwnode_handle___144 * (*get)(struct fwnode_handle___144 *);
	void (*put)(struct fwnode_handle___144 *);
	bool (*device_is_available)(const struct fwnode_handle___144 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___144 *, const struct device___144 *);
	bool (*property_present)(const struct fwnode_handle___144 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___144 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___144 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___144 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*get_parent)(const struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*get_next_child_node)(const struct fwnode_handle___144 *, struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*get_named_child_node)(const struct fwnode_handle___144 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___144 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___144 *);
	struct fwnode_handle___144 * (*graph_get_next_endpoint)(const struct fwnode_handle___144 *, struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*graph_get_remote_endpoint)(const struct fwnode_handle___144 *);
	struct fwnode_handle___144 * (*graph_get_port_parent)(struct fwnode_handle___144 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___144 *, struct fwnode_endpoint___144 *);
	int (*add_links)(struct fwnode_handle___144 *);
};

struct fwnode_endpoint___144 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___144 *local_fwnode;
};

struct fwnode_reference_args___144 {
	struct fwnode_handle___144 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___36 {
	char *name;
	int length;
	void *value;
	struct property___36 *next;
	long unsigned int _flags;
	struct bin_attribute___174 attr;
};

struct device_node___46 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___144 fwnode;
	struct property___36 *properties;
	struct property___36 *deadprops;
	struct device_node___46 *parent;
	struct device_node___46 *child;
	struct device_node___46 *sibling;
	struct kobject___174 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___12 {
	struct device_node___46 *np;
	int args_count;
	uint32_t args[16];
};

struct dev_pm_ops___144 {
	int (*prepare)(struct device___144 *);
	void (*complete)(struct device___144 *);
	int (*suspend)(struct device___144 *);
	int (*resume)(struct device___144 *);
	int (*freeze)(struct device___144 *);
	int (*thaw)(struct device___144 *);
	int (*poweroff)(struct device___144 *);
	int (*restore)(struct device___144 *);
	int (*suspend_late)(struct device___144 *);
	int (*resume_early)(struct device___144 *);
	int (*freeze_late)(struct device___144 *);
	int (*thaw_early)(struct device___144 *);
	int (*poweroff_late)(struct device___144 *);
	int (*restore_early)(struct device___144 *);
	int (*suspend_noirq)(struct device___144 *);
	int (*resume_noirq)(struct device___144 *);
	int (*freeze_noirq)(struct device___144 *);
	int (*thaw_noirq)(struct device___144 *);
	int (*poweroff_noirq)(struct device___144 *);
	int (*restore_noirq)(struct device___144 *);
	int (*runtime_suspend)(struct device___144 *);
	int (*runtime_resume)(struct device___144 *);
	int (*runtime_idle)(struct device___144 *);
};

struct wakeup_source___144 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___144 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___144 {
	struct dev_pm_ops___144 ops;
	int (*start)(struct device___144 *);
	void (*detach)(struct device___144 *, bool);
	int (*activate)(struct device___144 *);
	void (*sync)(struct device___144 *);
	void (*dismiss)(struct device___144 *);
};

struct bus_type___144 {
	const char *name;
	const char *dev_name;
	struct device___144 *dev_root;
	const struct attribute_group___174 **bus_groups;
	const struct attribute_group___174 **dev_groups;
	const struct attribute_group___174 **drv_groups;
	int (*match)(struct device___144 *, struct device_driver___144 *);
	int (*uevent)(struct device___144 *, struct kobj_uevent_env *);
	int (*probe)(struct device___144 *);
	void (*sync_state)(struct device___144 *);
	void (*remove)(struct device___144 *);
	void (*shutdown)(struct device___144 *);
	int (*online)(struct device___144 *);
	int (*offline)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	int (*num_vf)(struct device___144 *);
	int (*dma_configure)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___144 {
	const char *name;
	struct bus_type___144 *bus;
	struct module___170 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___144 *);
	void (*sync_state)(struct device___144 *);
	int (*remove)(struct device___144 *);
	void (*shutdown)(struct device___144 *);
	int (*suspend)(struct device___144 *, pm_message_t);
	int (*resume)(struct device___144 *);
	const struct attribute_group___174 **groups;
	const struct attribute_group___174 **dev_groups;
	const struct dev_pm_ops___144 *pm;
	void (*coredump)(struct device___144 *);
	struct driver_private *p;
};

struct device_type___144 {
	const char *name;
	const struct attribute_group___174 **groups;
	int (*uevent)(struct device___144 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___144 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___144 *);
	const struct dev_pm_ops___144 *pm;
};

struct class___144 {
	const char *name;
	struct module___170 *owner;
	const struct attribute_group___174 **class_groups;
	const struct attribute_group___174 **dev_groups;
	struct kobject___174 *dev_kobj;
	int (*dev_uevent)(struct device___144 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___144 *, umode_t *);
	void (*class_release)(struct class___144 *);
	void (*dev_release)(struct device___144 *);
	int (*shutdown_pre)(struct device___144 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___144 *);
	void (*get_ownership)(struct device___144 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___144 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___25;

struct irq_domain_chip_generic___25;

struct irq_data___26;

struct irq_domain___25 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___25 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___144 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___25 *gc;
	struct irq_domain___25 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___26 *revmap[0];
};

struct pinctrl___4;

struct dev_pin_info___4 {
	struct pinctrl___4 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct seq_operations___162 {
	void * (*start)(struct seq_file___162 *, loff_t *);
	void (*stop)(struct seq_file___162 *, void *);
	void * (*next)(struct seq_file___162 *, void *, loff_t *);
	int (*show)(struct seq_file___162 *, void *);
};

struct cgroup_namespace___126 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___126 *root_cset;
};

struct irq_desc___27;

typedef void (*irq_flow_handler_t___27)(struct irq_desc___27 *);

struct irq_chip___26;

struct irq_data___26 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___26 *chip;
	struct irq_domain___25 *domain;
	struct irq_data___26 *parent_data;
	void *chip_data;
};

struct irqaction___17;

struct irq_desc___27 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___26 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___27 handle_irq;
	struct irqaction___17 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___174 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___170 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___26 {
	struct device___144 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___26 *);
	void (*irq_shutdown)(struct irq_data___26 *);
	void (*irq_enable)(struct irq_data___26 *);
	void (*irq_disable)(struct irq_data___26 *);
	void (*irq_ack)(struct irq_data___26 *);
	void (*irq_mask)(struct irq_data___26 *);
	void (*irq_mask_ack)(struct irq_data___26 *);
	void (*irq_unmask)(struct irq_data___26 *);
	void (*irq_eoi)(struct irq_data___26 *);
	int (*irq_set_affinity)(struct irq_data___26 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___26 *);
	int (*irq_set_type)(struct irq_data___26 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___26 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___26 *);
	void (*irq_bus_sync_unlock)(struct irq_data___26 *);
	void (*irq_cpu_online)(struct irq_data___26 *);
	void (*irq_cpu_offline)(struct irq_data___26 *);
	void (*irq_suspend)(struct irq_data___26 *);
	void (*irq_resume)(struct irq_data___26 *);
	void (*irq_pm_shutdown)(struct irq_data___26 *);
	void (*irq_calc_mask)(struct irq_data___26 *);
	void (*irq_print_chip)(struct irq_data___26 *, struct seq_file___162 *);
	int (*irq_request_resources)(struct irq_data___26 *);
	void (*irq_release_resources)(struct irq_data___26 *);
	void (*irq_compose_msi_msg)(struct irq_data___26 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___26 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___26 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___26 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___26 *, void *);
	void (*ipi_send_single)(struct irq_data___26 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___26 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___26 *);
	void (*irq_nmi_teardown)(struct irq_data___26 *);
	long unsigned int flags;
};

struct irqaction___17 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___17 *next;
	irq_handler_t thread_fn;
	struct task_struct___193 *thread;
	struct irqaction___17 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___25 {
	struct irq_chip___26 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___27 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___25 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___25 *);
	void (*resume)(struct irq_chip_generic___25 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___25 *domain;
	struct list_head list;
	struct irq_chip_type___25 chip_types[0];
};

struct irq_domain_chip_generic___25 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___25 *gc[0];
};

struct dev_pagemap_ops___181 {
	void (*page_free)(struct page___191 *);
	void (*kill)(struct dev_pagemap___181 *);
	void (*cleanup)(struct dev_pagemap___181 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___181 *);
};

struct cftype___126;

struct cgroup_subsys___126 {
	struct cgroup_subsys_state___126 * (*css_alloc)(struct cgroup_subsys_state___126 *);
	int (*css_online)(struct cgroup_subsys_state___126 *);
	void (*css_offline)(struct cgroup_subsys_state___126 *);
	void (*css_released)(struct cgroup_subsys_state___126 *);
	void (*css_free)(struct cgroup_subsys_state___126 *);
	void (*css_reset)(struct cgroup_subsys_state___126 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___126 *, int);
	int (*css_extra_stat_show)(struct seq_file___162 *, struct cgroup_subsys_state___126 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___193 *, struct css_set___126 *);
	void (*cancel_fork)(struct task_struct___193 *, struct css_set___126 *);
	void (*fork)(struct task_struct___193 *);
	void (*exit)(struct task_struct___193 *);
	void (*release)(struct task_struct___193 *);
	void (*bind)(struct cgroup_subsys_state___126 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___126 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___126 *dfl_cftypes;
	struct cftype___126 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___126 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___126 *updated_children;
	struct cgroup___126 *updated_next;
};

struct cgroup_root___126 {
	struct kernfs_root___174 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___126 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___126 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___126 *ss;
	struct list_head node;
	struct kernfs_ops___174 *kf_ops;
	int (*open)(struct kernfs_open_file___174 *);
	void (*release)(struct kernfs_open_file___174 *);
	u64 (*read_u64)(struct cgroup_subsys_state___126 *, struct cftype___126 *);
	s64 (*read_s64)(struct cgroup_subsys_state___126 *, struct cftype___126 *);
	int (*seq_show)(struct seq_file___162 *, void *);
	void * (*seq_start)(struct seq_file___162 *, loff_t *);
	void * (*seq_next)(struct seq_file___162 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___162 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___126 *, struct cftype___126 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___126 *, struct cftype___126 *, s64);
	ssize_t (*write)(struct kernfs_open_file___174 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___174 *, struct poll_table_struct___5 *);
};

struct block_device_operations___92;

struct gendisk___93 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___93 *part0;
	const struct block_device_operations___92 *fops;
	struct request_queue___92 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___85 *bdi;
	struct kobject___174 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___174 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___92 {
	struct bio___92 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___108 *bip_vec;
	struct bio_vec___108 bip_inline_vecs[0];
};

struct blkcg___87;

struct blkg_policy_data___87;

struct blkcg_gq___87 {
	struct request_queue___92 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___87 *blkcg;
	struct blkcg_gq___87 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___87 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___92 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___92(struct request___92 *);

typedef void integrity_complete_fn___92(struct request___92 *, unsigned int);

struct blk_integrity_profile___92 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___92 *prepare_fn;
	integrity_complete_fn___92 *complete_fn;
	const char *name;
};

struct block_device_operations___92 {
	blk_qc_t (*submit_bio)(struct bio___92 *);
	int (*open)(struct block_device___93 *, fmode_t);
	void (*release)(struct gendisk___93 *, fmode_t);
	int (*rw_page)(struct block_device___93 *, sector_t, struct page___191 *, unsigned int);
	int (*ioctl)(struct block_device___93 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___93 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___93 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___93 *);
	int (*getgeo)(struct block_device___93 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___93 *, bool);
	void (*swap_slot_free_notify)(struct block_device___93 *, long unsigned int);
	int (*report_zones)(struct gendisk___93 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___93 *, umode_t *);
	struct module___170 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___93 *, sector_t *);
};

typedef void rq_end_io_fn___92(struct request___92 *, blk_status_t);

struct request___92 {
	struct request_queue___92 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___89 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___92 *bio;
	struct bio___92 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___108 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___92 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___92 *saved_end_io;
		} flush;
	};
	struct gendisk___93 *rq_disk;
	struct block_device___93 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___92 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___89 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___92 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___174 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___186 *debugfs_dir;
	struct dentry___186 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___92;

struct elevator_mq_ops___92 {
	int (*init_sched)(struct request_queue___92 *, struct elevator_type___92 *);
	void (*exit_sched)(struct elevator_queue___92 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___89 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___89 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___89 *);
	bool (*allow_merge)(struct request_queue___92 *, struct request___92 *, struct bio___92 *);
	bool (*bio_merge)(struct request_queue___92 *, struct bio___92 *, unsigned int);
	int (*request_merge)(struct request_queue___92 *, struct request___92 **, struct bio___92 *);
	void (*request_merged)(struct request_queue___92 *, struct request___92 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___92 *, struct request___92 *, struct request___92 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___92 *);
	void (*finish_request)(struct request___92 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___89 *, struct list_head *, bool);
	struct request___92 * (*dispatch_request)(struct blk_mq_hw_ctx___89 *);
	bool (*has_work)(struct blk_mq_hw_ctx___89 *);
	void (*completed_request)(struct request___92 *, u64);
	void (*requeue_request)(struct request___92 *);
	struct request___92 * (*former_request)(struct request_queue___92 *, struct request___92 *);
	struct request___92 * (*next_request)(struct request_queue___92 *, struct request___92 *);
	void (*init_icq)(struct io_cq___92 *);
	void (*exit_icq)(struct io_cq___92 *);
};

struct elv_fs_entry___92;

struct elevator_type___92 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___92 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___92 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___170 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___92 {
	struct elevator_type___92 *type;
	void *elevator_data;
	struct kobject___174 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___92 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___92 *, char *);
	ssize_t (*store)(struct elevator_queue___92 *, const char *, size_t);
};

struct blk_mq_queue_data___89;

struct blk_mq_ops___89 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___89 *, const struct blk_mq_queue_data___89 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___89 *);
	int (*get_budget)(struct request_queue___92 *);
	void (*put_budget)(struct request_queue___92 *, int);
	void (*set_rq_budget_token)(struct request___92 *, int);
	int (*get_rq_budget_token)(struct request___92 *);
	enum blk_eh_timer_return (*timeout)(struct request___92 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___89 *);
	void (*complete)(struct request___92 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___89 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___89 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___89 *, struct request___92 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___89 *, struct request___92 *, unsigned int);
	void (*initialize_rq_fn)(struct request___92 *);
	void (*cleanup_rq)(struct request___92 *);
	bool (*busy)(struct request_queue___92 *);
	int (*map_queues)(struct blk_mq_tag_set___89 *);
	void (*show_rq)(struct seq_file___162 *, struct request___92 *);
};

struct blk_mq_tag_set___89 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___89 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___89 {
	struct request___92 *rq;
	bool last;
};

struct blkcg_policy_data___87;

struct blkcg___87 {
	struct cgroup_subsys_state___126 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___87 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___87 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___87 {
	struct blkcg___87 *blkcg;
	int plid;
};

struct blkg_policy_data___87 {
	struct blkcg_gq___87 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___76 {
	struct mem_cgroup___76 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___76 {
	struct lruvec___83 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___76 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___76 *memcg;
};

struct obj_cgroup___76 {
	struct percpu_ref refcnt;
	struct mem_cgroup___76 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct extcon_dev;

struct regulator_dev;

struct regulator_ops {
	int (*list_voltage)(struct regulator_dev *, unsigned int);
	int (*set_voltage)(struct regulator_dev *, int, int, unsigned int *);
	int (*map_voltage)(struct regulator_dev *, int, int);
	int (*set_voltage_sel)(struct regulator_dev *, unsigned int);
	int (*get_voltage)(struct regulator_dev *);
	int (*get_voltage_sel)(struct regulator_dev *);
	int (*set_current_limit)(struct regulator_dev *, int, int);
	int (*get_current_limit)(struct regulator_dev *);
	int (*set_input_current_limit)(struct regulator_dev *, int);
	int (*set_over_current_protection)(struct regulator_dev *, int, int, bool);
	int (*set_over_voltage_protection)(struct regulator_dev *, int, int, bool);
	int (*set_under_voltage_protection)(struct regulator_dev *, int, int, bool);
	int (*set_thermal_protection)(struct regulator_dev *, int, int, bool);
	int (*set_active_discharge)(struct regulator_dev *, bool);
	int (*enable)(struct regulator_dev *);
	int (*disable)(struct regulator_dev *);
	int (*is_enabled)(struct regulator_dev *);
	int (*set_mode)(struct regulator_dev *, unsigned int);
	unsigned int (*get_mode)(struct regulator_dev *);
	int (*get_error_flags)(struct regulator_dev *, unsigned int *);
	int (*enable_time)(struct regulator_dev *);
	int (*set_ramp_delay)(struct regulator_dev *, int);
	int (*set_voltage_time)(struct regulator_dev *, int, int);
	int (*set_voltage_time_sel)(struct regulator_dev *, unsigned int, unsigned int);
	int (*set_soft_start)(struct regulator_dev *);
	int (*get_status)(struct regulator_dev *);
	unsigned int (*get_optimum_mode)(struct regulator_dev *, int, int, int);
	int (*set_load)(struct regulator_dev *, int);
	int (*set_bypass)(struct regulator_dev *, bool);
	int (*get_bypass)(struct regulator_dev *, bool *);
	int (*set_suspend_voltage)(struct regulator_dev *, int);
	int (*set_suspend_enable)(struct regulator_dev *);
	int (*set_suspend_disable)(struct regulator_dev *);
	int (*set_suspend_mode)(struct regulator_dev *, unsigned int);
	int (*resume)(struct regulator_dev *);
	int (*set_pull_down)(struct regulator_dev *);
};

struct regulator_coupler;

struct coupling_desc {
	struct regulator_dev **coupled_rdevs;
	struct regulator_coupler *coupler;
	int n_resolved;
	int n_coupled;
};

struct regulator_desc;

struct regulation_constraints;

struct regulator_enable_gpio;

struct regulator_dev {
	const struct regulator_desc *desc;
	int exclusive;
	u32 use_count;
	u32 open_count;
	u32 bypass_count;
	struct list_head list;
	struct list_head consumer_list;
	struct coupling_desc coupling_desc;
	struct blocking_notifier_head notifier;
	struct ww_mutex___2 mutex;
	struct task_struct___193 *mutex_owner;
	int ref_cnt;
	struct module___170 *owner;
	struct device___144 dev;
	struct regulation_constraints *constraints;
	struct regulator *supply;
	const char *supply_name;
	struct regmap *regmap;
	struct delayed_work disable_work;
	void *reg_data;
	struct dentry___186 *debugfs;
	struct regulator_enable_gpio *ena_pin;
	unsigned int ena_gpio_state: 1;
	unsigned int is_switch: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	ktime_t last_off;
	int cached_err;
	bool use_cached_err;
	spinlock_t err_lock;
};

enum regulator_type {
	REGULATOR_VOLTAGE = 0,
	REGULATOR_CURRENT = 1,
};

struct regulator_config;

struct regulator_desc {
	const char *name;
	const char *supply_name;
	const char *of_match;
	bool of_match_full_name;
	const char *regulators_node;
	int (*of_parse_cb)(struct device_node___46 *, const struct regulator_desc *, struct regulator_config *);
	int id;
	unsigned int continuous_voltage_range: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int n_voltages;
	unsigned int n_current_limits;
	const struct regulator_ops *ops;
	int irq;
	enum regulator_type type;
	struct module___170 *owner;
	unsigned int min_uV;
	unsigned int uV_step;
	unsigned int linear_min_sel;
	int fixed_uV;
	unsigned int ramp_delay;
	int min_dropout_uV;
	const struct linear_range *linear_ranges;
	const unsigned int *linear_range_selectors;
	int n_linear_ranges;
	const unsigned int *volt_table;
	const unsigned int *curr_table;
	unsigned int vsel_range_reg;
	unsigned int vsel_range_mask;
	unsigned int vsel_reg;
	unsigned int vsel_mask;
	unsigned int vsel_step;
	unsigned int csel_reg;
	unsigned int csel_mask;
	unsigned int apply_reg;
	unsigned int apply_bit;
	unsigned int enable_reg;
	unsigned int enable_mask;
	unsigned int enable_val;
	unsigned int disable_val;
	bool enable_is_inverted;
	unsigned int bypass_reg;
	unsigned int bypass_mask;
	unsigned int bypass_val_on;
	unsigned int bypass_val_off;
	unsigned int active_discharge_on;
	unsigned int active_discharge_off;
	unsigned int active_discharge_mask;
	unsigned int active_discharge_reg;
	unsigned int soft_start_reg;
	unsigned int soft_start_mask;
	unsigned int soft_start_val_on;
	unsigned int pull_down_reg;
	unsigned int pull_down_mask;
	unsigned int pull_down_val_on;
	unsigned int ramp_reg;
	unsigned int ramp_mask;
	const unsigned int *ramp_delay_table;
	unsigned int n_ramp_values;
	unsigned int enable_time;
	unsigned int off_on_delay;
	unsigned int poll_enabled_time;
	unsigned int (*of_map_mode)(unsigned int);
};

struct regulator_init_data;

struct regulator_config {
	struct device___144 *dev;
	const struct regulator_init_data *init_data;
	void *driver_data;
	struct device_node___46 *of_node;
	struct regmap *regmap;
	struct gpio_desc *ena_gpiod;
};

struct regulator_state {
	int uV;
	int min_uV;
	int max_uV;
	unsigned int mode;
	int enabled;
	bool changeable;
};

struct notification_limit {
	int prot;
	int err;
	int warn;
};

struct regulation_constraints {
	const char *name;
	int min_uV;
	int max_uV;
	int uV_offset;
	int min_uA;
	int max_uA;
	int ilim_uA;
	int system_load;
	u32 *max_spread;
	int max_uV_step;
	unsigned int valid_modes_mask;
	unsigned int valid_ops_mask;
	int input_uV;
	struct regulator_state state_disk;
	struct regulator_state state_mem;
	struct regulator_state state_standby;
	struct notification_limit over_curr_limits;
	struct notification_limit over_voltage_limits;
	struct notification_limit under_voltage_limits;
	struct notification_limit temp_limits;
	suspend_state_t initial_state;
	unsigned int initial_mode;
	unsigned int ramp_delay;
	unsigned int settling_time;
	unsigned int settling_time_up;
	unsigned int settling_time_down;
	unsigned int enable_time;
	unsigned int active_discharge;
	unsigned int always_on;
	unsigned int boot_on;
	unsigned int apply_uV;
	unsigned int ramp_disable;
	unsigned int soft_start;
	unsigned int pull_down;
	unsigned int over_current_protection;
	unsigned int over_current_detection;
	unsigned int over_voltage_detection;
	unsigned int under_voltage_detection;
	unsigned int over_temp_detection;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct regulator_consumer_supply;

struct regulator_init_data {
	const char *supply_regulator;
	struct regulation_constraints constraints;
	int num_consumer_supplies;
	struct regulator_consumer_supply *consumer_supplies;
	int (*regulator_init)(void *);
	void *driver_data;
};

struct irq_fwspec___23 {
	struct fwnode_handle___144 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___25 {
	int (*match)(struct irq_domain___25 *, struct device_node___46 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___25 *, struct irq_fwspec___23 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___25 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___25 *, unsigned int);
	int (*xlate)(struct irq_domain___25 *, struct device_node___46 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___25 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___25 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___25 *, struct irq_data___26 *, bool);
	void (*deactivate)(struct irq_domain___25 *, struct irq_data___26 *);
	int (*translate)(struct irq_domain___25 *, struct irq_fwspec___23 *, long unsigned int *, unsigned int *);
};

struct pinctrl___4 {
	struct list_head node;
	struct device___144 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct gpio_chip___4;

struct pinctrl_gpio_range___2 {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	unsigned int npins;
	const unsigned int *pins;
	struct gpio_chip___4 *gc;
};

struct gpio_irq_chip___4 {
	struct irq_chip___26 *chip;
	struct irq_domain___25 *domain;
	const struct irq_domain_ops___25 *domain_ops;
	struct fwnode_handle___144 *fwnode;
	struct irq_domain___25 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___4 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___4 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___4 *, unsigned int);
	struct irq_domain_ops___25 child_irq_domain_ops;
	irq_flow_handler_t___27 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___27 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___4 *);
	void (*init_valid_mask)(struct gpio_chip___4 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___26 *);
	void (*irq_disable)(struct irq_data___26 *);
	void (*irq_unmask)(struct irq_data___26 *);
	void (*irq_mask)(struct irq_data___26 *);
};

struct gpio_chip___4 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___144 *parent;
	struct module___170 *owner;
	int (*request)(struct gpio_chip___4 *, unsigned int);
	void (*free)(struct gpio_chip___4 *, unsigned int);
	int (*get_direction)(struct gpio_chip___4 *, unsigned int);
	int (*direction_input)(struct gpio_chip___4 *, unsigned int);
	int (*direction_output)(struct gpio_chip___4 *, unsigned int, int);
	int (*get)(struct gpio_chip___4 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___4 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___4 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___4 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___4 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___4 *, unsigned int);
	void (*dbg_show)(struct seq_file___162 *, struct gpio_chip___4 *);
	int (*init_valid_mask)(struct gpio_chip___4 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___4 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___4 irq;
	long unsigned int *valid_mask;
	struct device_node___46 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___4 *, const struct of_phandle_args___12 *, u32 *);
};

struct pinctrl_dev___6;

struct pinctrl_ops___7 {
	int (*get_groups_count)(struct pinctrl_dev___6 *);
	const char * (*get_group_name)(struct pinctrl_dev___6 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___6 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___6 *, struct seq_file___162 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___6 *, struct device_node___46 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___6 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___7;

struct pinctrl_dev___6 {
	struct list_head node;
	struct pinctrl_desc___7 *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___144 *dev;
	struct module___170 *owner;
	void *driver_data;
	struct pinctrl___4 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___186 *device_root;
};

struct pinmux_ops___4;

struct pinconf_ops___6;

struct pinctrl_desc___7 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___7 *pctlops;
	const struct pinmux_ops___4 *pmxops;
	const struct pinconf_ops___6 *confops;
	struct module___170 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinmux_ops___4 {
	int (*request)(struct pinctrl_dev___6 *, unsigned int);
	int (*free)(struct pinctrl_dev___6 *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev___6 *);
	const char * (*get_function_name)(struct pinctrl_dev___6 *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev___6 *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev___6 *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev___6 *, struct pinctrl_gpio_range___2 *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev___6 *, struct pinctrl_gpio_range___2 *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev___6 *, struct pinctrl_gpio_range___2 *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops___6 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___6 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___6 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___6 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___6 *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev___6 *, struct seq_file___162 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___6 *, struct seq_file___162 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___6 *, struct seq_file___162 *, long unsigned int);
};

enum palmas_usb_state {
	PALMAS_USB_STATE_DISCONNECT = 0,
	PALMAS_USB_STATE_VBUS = 1,
	PALMAS_USB_STATE_ID = 2,
};

struct i2c_client;

struct palmas_gpadc;

struct palmas_pmic_driver_data;

struct palmas_pmic;

struct palmas_resource;

struct palmas_usb;

struct palmas {
	struct device___144 *dev;
	struct i2c_client *i2c_clients[3];
	struct regmap *regmap[3];
	int id;
	unsigned int features;
	int irq;
	u32 irq_mask;
	struct mutex irq_lock;
	struct regmap_irq_chip_data *irq_data;
	struct palmas_pmic_driver_data *pmic_ddata;
	struct palmas_pmic *pmic;
	struct palmas_gpadc *gpadc;
	struct palmas_resource *resource;
	struct palmas_usb *usb;
	u8 gpio_muxed;
	u8 led_muxed;
	u8 pwm_muxed;
};

struct of_regulator_match;

struct palmas_regs_info;

struct palmas_sleep_requestor_info;

struct palmas_pmic_platform_data;

struct palmas_pmic_driver_data {
	int smps_start;
	int smps_end;
	int ldo_begin;
	int ldo_end;
	int max_reg;
	bool has_regen3;
	struct palmas_regs_info *palmas_regs_info;
	struct of_regulator_match *palmas_matches;
	struct palmas_sleep_requestor_info *sleep_req_info;
	int (*smps_register)(struct palmas_pmic *, struct palmas_pmic_driver_data *, struct palmas_pmic_platform_data *, const char *, struct regulator_config);
	int (*ldo_register)(struct palmas_pmic *, struct palmas_pmic_driver_data *, struct palmas_pmic_platform_data *, const char *, struct regulator_config);
};

struct palmas_pmic {
	struct palmas *palmas;
	struct device___144 *dev;
	struct regulator_desc desc[27];
	struct mutex mutex;
	int smps123;
	int smps457;
	int smps12;
	int range[10];
	unsigned int ramp_delay[10];
	unsigned int current_reg_mode[10];
};

struct palmas_resource {
	struct palmas *palmas;
	struct device___144 *dev;
};

struct palmas_usb {
	struct palmas *palmas;
	struct device___144 *dev;
	struct extcon_dev *edev;
	int id_otg_irq;
	int id_irq;
	int vbus_otg_irq;
	int vbus_irq;
	int gpio_id_irq;
	int gpio_vbus_irq;
	struct gpio_desc *id_gpiod;
	struct gpio_desc *vbus_gpiod;
	long unsigned int sw_debounce_jiffies;
	struct delayed_work wq_detectid;
	enum palmas_usb_state linkstat;
	int wakeup;
	bool enable_vbus_detection;
	bool enable_id_detection;
	bool enable_gpio_id_detection;
	bool enable_gpio_vbus_detection;
};

struct palmas_sleep_requestor_info {
	int id;
	int reg_offset;
	int bit_pos;
};

struct palmas_regs_info {
	char *name;
	char *sname;
	u8 vsel_addr;
	u8 ctrl_addr;
	u8 tstep_addr;
	int sleep_id;
};

struct palmas_reg_init;

struct palmas_pmic_platform_data {
	struct regulator_init_data *reg_data[27];
	struct palmas_reg_init *reg_init[27];
	int ldo6_vibrator;
	bool enable_ldo8_tracking;
};

struct palmas_reg_init {
	int warm_reset;
	int roof_floor;
	int mode_sleep;
	u8 vsel;
};

enum palmas_regulators {
	PALMAS_REG_SMPS12 = 0,
	PALMAS_REG_SMPS123 = 1,
	PALMAS_REG_SMPS3 = 2,
	PALMAS_REG_SMPS45 = 3,
	PALMAS_REG_SMPS457 = 4,
	PALMAS_REG_SMPS6 = 5,
	PALMAS_REG_SMPS7 = 6,
	PALMAS_REG_SMPS8 = 7,
	PALMAS_REG_SMPS9 = 8,
	PALMAS_REG_SMPS10_OUT2 = 9,
	PALMAS_REG_SMPS10_OUT1 = 10,
	PALMAS_REG_LDO1 = 11,
	PALMAS_REG_LDO2 = 12,
	PALMAS_REG_LDO3 = 13,
	PALMAS_REG_LDO4 = 14,
	PALMAS_REG_LDO5 = 15,
	PALMAS_REG_LDO6 = 16,
	PALMAS_REG_LDO7 = 17,
	PALMAS_REG_LDO8 = 18,
	PALMAS_REG_LDO9 = 19,
	PALMAS_REG_LDOLN = 20,
	PALMAS_REG_LDOUSB = 21,
	PALMAS_REG_REGEN1 = 22,
	PALMAS_REG_REGEN2 = 23,
	PALMAS_REG_REGEN3 = 24,
	PALMAS_REG_SYSEN1 = 25,
	PALMAS_REG_SYSEN2 = 26,
	PALMAS_NUM_REGS = 27,
};

struct platform_device___13 {
	const char *name;
	int id;
	bool id_auto;
	struct device___144 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___12 {
	int (*probe)(struct platform_device___13 *);
	int (*remove)(struct platform_device___13 *);
	void (*shutdown)(struct platform_device___13 *);
	int (*suspend)(struct platform_device___13 *, pm_message_t);
	int (*resume)(struct platform_device___13 *);
	struct device_driver___144 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct palmas_pin_function {
	const char *name;
	const char * const *groups;
	unsigned int ngroups;
};

struct palmas_pingroup;

struct palmas_pctrl_chip_info {
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctl;
	struct palmas *palmas;
	int pins_current_opt[26];
	const struct palmas_pin_function *functions;
	unsigned int num_functions;
	const struct palmas_pingroup *pin_groups;
	int num_pin_groups;
	const struct pinctrl_pin_desc *pins;
	unsigned int num_pins;
};

struct palmas_pin_info;

struct palmas_pingroup {
	const char *name;
	const unsigned int pins[1];
	unsigned int npins;
	unsigned int mux_reg_base;
	unsigned int mux_reg_add;
	unsigned int mux_reg_mask;
	unsigned int mux_bit_shift;
	const struct palmas_pin_info *opt[4];
};

enum palmas_pinmux {
	PALMAS_PINMUX_OPTION0 = 0,
	PALMAS_PINMUX_OPTION1 = 1,
	PALMAS_PINMUX_OPTION2 = 2,
	PALMAS_PINMUX_OPTION3 = 3,
	PALMAS_PINMUX_GPIO = 4,
	PALMAS_PINMUX_LED = 5,
	PALMAS_PINMUX_PWM = 6,
	PALMAS_PINMUX_REGEN = 7,
	PALMAS_PINMUX_SYSEN = 8,
	PALMAS_PINMUX_CLK32KGAUDIO = 9,
	PALMAS_PINMUX_ID = 10,
	PALMAS_PINMUX_VBUS_DET = 11,
	PALMAS_PINMUX_CHRG_DET = 12,
	PALMAS_PINMUX_VAC = 13,
	PALMAS_PINMUX_VACOK = 14,
	PALMAS_PINMUX_POWERGOOD = 15,
	PALMAS_PINMUX_USB_PSEL = 16,
	PALMAS_PINMUX_MSECURE = 17,
	PALMAS_PINMUX_PWRHOLD = 18,
	PALMAS_PINMUX_INT = 19,
	PALMAS_PINMUX_NRESWARM = 20,
	PALMAS_PINMUX_SIMRSTO = 21,
	PALMAS_PINMUX_SIMRSTI = 22,
	PALMAS_PINMUX_LOW_VBAT = 23,
	PALMAS_PINMUX_WIRELESS_CHRG1 = 24,
	PALMAS_PINMUX_RCM = 25,
	PALMAS_PINMUX_PWRDOWN = 26,
	PALMAS_PINMUX_GPADC_START = 27,
	PALMAS_PINMUX_RESET_IN = 28,
	PALMAS_PINMUX_NSLEEP = 29,
	PALMAS_PINMUX_ENABLE = 30,
	PALMAS_PINMUX_NA = 65535,
};

struct palmas_pins_pullup_dn_info {
	int pullup_dn_reg_base;
	int pullup_dn_reg_add;
	int pullup_dn_mask;
	int normal_val;
	int pull_up_val;
	int pull_dn_val;
};

struct palmas_pins_od_info {
	int od_reg_base;
	int od_reg_add;
	int od_mask;
	int od_enable;
	int od_disable;
};

struct palmas_pin_info {
	enum palmas_pinmux mux_opt;
	const struct palmas_pins_pullup_dn_info *pud_info;
	const struct palmas_pins_od_info *od_info;
};

struct palmas_pinctrl_data {
	const struct palmas_pingroup *pin_groups;
	int num_pin_groups;
};

enum rockchip_pinctrl_type {
	PX30 = 0,
	RV1108 = 1,
	RK2928 = 2,
	RK3066B = 3,
	RK3128 = 4,
	RK3188 = 5,
	RK3288 = 6,
	RK3308 = 7,
	RK3368 = 8,
	RK3399 = 9,
	RK3568 = 10,
};

struct rockchip_gpio_regs {
	u32 port_dr;
	u32 port_ddr;
	u32 int_en;
	u32 int_mask;
	u32 int_type;
	u32 int_polarity;
	u32 int_bothedge;
	u32 int_status;
	u32 int_rawstatus;
	u32 debounce;
	u32 dbclk_div_en;
	u32 dbclk_div_con;
	u32 port_eoi;
	u32 ext_port;
	u32 version_id;
};

struct rockchip_iomux {
	int type;
	int offset;
};

enum rockchip_pin_drv_type {
	DRV_TYPE_IO_DEFAULT = 0,
	DRV_TYPE_IO_1V8_OR_3V0 = 1,
	DRV_TYPE_IO_1V8_ONLY = 2,
	DRV_TYPE_IO_1V8_3V0_AUTO = 3,
	DRV_TYPE_IO_3V3_ONLY = 4,
	DRV_TYPE_MAX = 5,
};

enum rockchip_pin_pull_type {
	PULL_TYPE_IO_DEFAULT = 0,
	PULL_TYPE_IO_1V8_ONLY = 1,
	PULL_TYPE_MAX = 2,
};

struct rockchip_drv {
	enum rockchip_pin_drv_type drv_type;
	int offset;
};

struct rockchip_pinctrl;

struct rockchip_pin_bank {
	struct device___144 *dev;
	void *reg_base;
	struct regmap *regmap_pull;
	struct clk *clk;
	struct clk *db_clk;
	int irq;
	u32 saved_masks;
	u32 pin_base;
	u8 nr_pins;
	char *name;
	u8 bank_num;
	struct rockchip_iomux iomux[4];
	struct rockchip_drv drv[4];
	enum rockchip_pin_pull_type pull_type[4];
	bool valid;
	struct device_node___46 *of_node;
	struct rockchip_pinctrl *drvdata;
	struct irq_domain___25 *domain;
	struct gpio_chip___4 gpio_chip;
	struct pinctrl_gpio_range___2 grange;
	raw_spinlock_t slock;
	const struct rockchip_gpio_regs *gpio_regs;
	u32 gpio_type;
	u32 toggle_edge_mode;
	u32 recalced_mask;
	u32 route_mask;
	struct list_head deferred_output;
	struct mutex deferred_lock;
};

struct rockchip_pin_ctrl;

struct rockchip_pin_group;

struct rockchip_pmx_func;

struct rockchip_pinctrl {
	struct regmap *regmap_base;
	int reg_size;
	struct regmap *regmap_pull;
	struct regmap *regmap_pmu;
	struct device___144 *dev;
	struct rockchip_pin_ctrl *ctrl;
	struct pinctrl_desc___7 pctl;
	struct pinctrl_dev___6 *pctl_dev;
	struct rockchip_pin_group *groups;
	unsigned int ngroups;
	struct rockchip_pmx_func *functions;
	unsigned int nfunctions;
};

struct rockchip_mux_recalced_data {
	u8 num;
	u8 pin;
	u32 reg;
	u8 bit;
	u8 mask;
};

enum rockchip_mux_route_location {
	ROCKCHIP_ROUTE_SAME = 0,
	ROCKCHIP_ROUTE_PMU = 1,
	ROCKCHIP_ROUTE_GRF = 2,
};

struct rockchip_mux_route_data {
	u8 bank_num;
	u8 pin;
	u8 func;
	enum rockchip_mux_route_location route_location;
	u32 route_offset;
	u32 route_val;
};

struct rockchip_pin_ctrl {
	struct rockchip_pin_bank *pin_banks;
	u32 nr_banks;
	u32 nr_pins;
	char *label;
	enum rockchip_pinctrl_type type;
	int grf_mux_offset;
	int pmu_mux_offset;
	int grf_drv_offset;
	int pmu_drv_offset;
	struct rockchip_mux_recalced_data *iomux_recalced;
	u32 niomux_recalced;
	struct rockchip_mux_route_data *iomux_routes;
	u32 niomux_routes;
	void (*pull_calc_reg)(struct rockchip_pin_bank *, int, struct regmap **, int *, u8 *);
	void (*drv_calc_reg)(struct rockchip_pin_bank *, int, struct regmap **, int *, u8 *);
	int (*schmitt_calc_reg)(struct rockchip_pin_bank *, int, struct regmap **, int *, u8 *);
};

struct rockchip_pin_config {
	unsigned int func;
	long unsigned int *configs;
	unsigned int nconfigs;
};

struct rockchip_pin_output_deferred {
	struct list_head head;
	unsigned int pin;
	u32 arg;
};

struct rockchip_pin_group {
	const char *name;
	unsigned int npins;
	unsigned int *pins;
	struct rockchip_pin_config *data;
};

struct rockchip_pmx_func {
	const char *name;
	const char **groups;
	u8 ngroups;
};

struct pcs_pdata {
	int irq;
	void (*rearm)();
};

struct pin_desc___3 {
	struct pinctrl_dev___6 *pctldev;
	const char *name;
	bool dynamic_name;
	void *drv_data;
	unsigned int mux_usecount;
	const char *mux_owner;
	const struct pinctrl_setting_mux *mux_setting;
	const char *gpio_owner;
};

struct pcs_func_vals {
	void *reg;
	unsigned int val;
	unsigned int mask;
};

struct pcs_conf_vals {
	enum pin_config_param param;
	unsigned int val;
	unsigned int enable;
	unsigned int disable;
	unsigned int mask;
};

struct pcs_conf_type {
	const char *name;
	enum pin_config_param param;
};

struct pcs_function {
	const char *name;
	struct pcs_func_vals *vals;
	unsigned int nvals;
	const char **pgnames;
	int npgnames;
	struct pcs_conf_vals *conf;
	int nconfs;
	struct list_head node;
};

struct pcs_gpiofunc_range {
	unsigned int offset;
	unsigned int npins;
	unsigned int gpiofunc;
	struct list_head node;
};

struct pcs_data {
	struct pinctrl_pin_desc *pa;
	int cur;
};

struct pcs_soc_data {
	unsigned int flags;
	int irq;
	unsigned int irq_enable_mask;
	unsigned int irq_status_mask;
	void (*rearm)();
};

struct pcs_device {
	struct resource *res;
	void *base;
	void *saved_vals;
	unsigned int size;
	struct device___144 *dev;
	struct device_node___46 *np;
	struct pinctrl_dev___6 *pctl;
	unsigned int flags;
	struct property___36 *missing_nr_pinctrl_cells;
	struct pcs_soc_data socdata;
	raw_spinlock_t lock;
	struct mutex mutex;
	unsigned int width;
	unsigned int fmask;
	unsigned int fshift;
	unsigned int foff;
	unsigned int fmax;
	bool bits_per_mux;
	unsigned int bits_per_pin;
	struct pcs_data pins;
	struct list_head gpiofuncs;
	struct list_head irqs;
	struct irq_chip___26 chip;
	struct irq_domain___25 *domain;
	struct pinctrl_desc___7 desc;
	unsigned int (*read)(void *);
	void (*write)(unsigned int, void *);
};

struct pcs_interrupt {
	void *reg;
	irq_hw_number_t hwirq;
	unsigned int irq;
	struct list_head node;
};

struct dentry___187;

struct super_block___187;

struct module___171;

struct file_system_type___187 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___187 * (*mount)(struct file_system_type___187 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___187 *);
	struct module___171 *owner;
	struct file_system_type___187 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___187;

struct kiocb___187;

struct iov_iter___111;

struct poll_table_struct___121;

struct vm_area_struct___192;

struct inode___187;

struct file_lock___187;

struct page___192;

struct seq_file___163;

struct file_operations___188 {
	struct module___171 *owner;
	loff_t (*llseek)(struct file___187 *, loff_t, int);
	ssize_t (*read)(struct file___187 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___187 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___187 *, struct iov_iter___111 *);
	ssize_t (*write_iter)(struct kiocb___187 *, struct iov_iter___111 *);
	int (*iopoll)(struct kiocb___187 *, bool);
	int (*iterate)(struct file___187 *, struct dir_context *);
	int (*iterate_shared)(struct file___187 *, struct dir_context *);
	__poll_t (*poll)(struct file___187 *, struct poll_table_struct___121 *);
	long int (*unlocked_ioctl)(struct file___187 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___187 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___187 *, struct vm_area_struct___192 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___187 *, struct file___187 *);
	int (*flush)(struct file___187 *, fl_owner_t);
	int (*release)(struct inode___187 *, struct file___187 *);
	int (*fsync)(struct file___187 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___187 *, int);
	int (*lock)(struct file___187 *, int, struct file_lock___187 *);
	ssize_t (*sendpage)(struct file___187 *, struct page___192 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___187 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___187 *, long unsigned int);
	int (*flock)(struct file___187 *, int, struct file_lock___187 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___187 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___187 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___187 *, long int, struct file_lock___187 **, void **);
	long int (*fallocate)(struct file___187 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___163 *, struct file___187 *);
	ssize_t (*copy_file_range)(struct file___187 *, loff_t, struct file___187 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___187 *, loff_t, struct file___187 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___187 *, loff_t, loff_t, int);
};

struct vmacache___192 {
	u64 seqnum;
	struct vm_area_struct___192 *vmas[4];
};

struct page_frag___192 {
	struct page___192 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___193;

struct pid___166;

struct nsproxy___175;

struct signal_struct___188;

struct bio_list___93;

struct backing_dev_info___86;

struct io_context___93;

struct css_set___127;

struct mem_cgroup___77;

struct request_queue___93;

struct vm_struct___170;

struct task_struct___194 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___194 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___193 *mm;
	struct mm_struct___193 *active_mm;
	struct vmacache___192 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___194 *real_parent;
	struct task_struct___194 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___194 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___166 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___175 *nsproxy;
	struct signal_struct___188 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___194 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___93 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___86 *backing_dev_info;
	struct io_context___93 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___127 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___192 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___77 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___77 *active_memcg;
	struct request_queue___93 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___194 *oom_reaper_list;
	struct vm_struct___170 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___175;

struct kobj_type___175;

struct kernfs_node___175;

struct kobject___175 {
	const char *name;
	struct list_head entry;
	struct kobject___175 *parent;
	struct kset___175 *kset;
	struct kobj_type___175 *ktype;
	struct kernfs_node___175 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___171 {
	struct kobject___175 kobj;
	struct module___171 *mod;
	struct kobject___175 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___171 {
	struct module___171 *mod;
	struct latch_tree_node node;
};

struct module_layout___171 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___171 mtn;
};

struct module_attribute___171;

struct kernel_param___171;

struct module___171 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___171 mkobj;
	struct module_attribute___171 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___175 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___171 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___171 core_layout;
	struct module_layout___171 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___166;

struct upid___166 {
	int nr;
	struct pid_namespace___166 *ns;
};

struct pid_namespace___166 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___194 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___166 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___166 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___166 numbers[1];
};

typedef struct page___192 *pgtable_t___192;

struct address_space___187;

struct dev_pagemap___182;

struct page___192 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___187 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___192 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___192 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___193 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___182 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct rt_mutex_base___4 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___194 *owner;
};

struct rt_mutex___3 {
	struct rt_mutex_base___4 rtmutex;
};

struct vm_operations_struct___182;

struct vm_area_struct___192 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___192 *vm_next;
	struct vm_area_struct___192 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___193 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___182 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___187 *vm_file;
	struct file___187 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___188 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___194 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___194 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___166 *pids[4];
	struct pid___166 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___193 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___192;

struct mm_struct___193 {
	struct {
		struct vm_area_struct___192 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___187 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___192 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___194 *owner;
		struct user_namespace___25 *user_ns;
		struct file___187 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___127;

struct nsproxy___175 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___166 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___127 *cgroup_ns;
};

struct bio___93;

struct bio_list___93 {
	struct bio___93 *head;
	struct bio___93 *tail;
};

struct cgroup_subsys_state___127;

struct bdi_writeback___86 {
	struct backing_dev_info___86 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___127 *memcg_css;
	struct cgroup_subsys_state___127 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___145;

struct backing_dev_info___86 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___86 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___145 *dev;
	char dev_name[64];
	struct device___145 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___187 *debug_dir;
};

struct io_cq___93;

struct io_context___93 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___93 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___127;

struct css_set___127 {
	struct cgroup_subsys_state___127 *subsys[14];
	refcount_t refcount;
	struct css_set___127 *dom_cset;
	struct cgroup___127 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___127 *mg_src_cgrp;
	struct cgroup___127 *mg_dst_cgrp;
	struct css_set___127 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___127;

struct cgroup_subsys_state___127 {
	struct cgroup___127 *cgroup;
	struct cgroup_subsys___127 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___127 *parent;
};

struct cgroup_file___127 {
	struct kernfs_node___175 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___77;

struct mem_cgroup_per_node___77;

struct mem_cgroup___77 {
	struct cgroup_subsys_state___127 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___127 events_file;
	struct cgroup_file___127 events_local_file;
	struct cgroup_file___127 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___77 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___194 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___77 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___93;

struct blk_integrity___93 {
	const struct blk_integrity_profile___93 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___93 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___93 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___93;

struct elevator_queue___93;

struct blk_mq_ops___90;

struct blk_mq_hw_ctx___90;

struct gendisk___94;

struct blkcg_gq___88;

struct blk_mq_tag_set___90;

struct request_queue___93 {
	struct request___93 *last_merge;
	struct elevator_queue___93 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___90 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___90 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___94 *disk;
	struct kobject___175 kobj;
	struct kobject___175 *mq_kobj;
	struct blk_integrity___93 integrity;
	struct device___145 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___88 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___90 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___93 bio_split;
	struct dentry___187 *debugfs_dir;
	struct dentry___187 *sched_debugfs_dir;
	struct dentry___187 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___170 {
	struct vm_struct___170 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___192 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___187;

struct address_space___187 {
	struct inode___187 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___187 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___182;

struct dev_pagemap___182 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___182 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___187;

struct path___187 {
	struct vfsmount___187 *mnt;
	struct dentry___187 *dentry;
};

struct fown_struct___166 {
	rwlock_t lock;
	struct pid___166 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___187 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___187 f_path;
	struct inode___187 *f_inode;
	const struct file_operations___188 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___166 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___187 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___182;

struct vm_operations_struct___182 {
	void (*open)(struct vm_area_struct___192 *);
	void (*close)(struct vm_area_struct___192 *);
	int (*may_split)(struct vm_area_struct___192 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___192 *);
	int (*mprotect)(struct vm_area_struct___192 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___182 *);
	vm_fault_t (*huge_fault)(struct vm_fault___182 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___182 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___192 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___182 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___182 *);
	int (*access)(struct vm_area_struct___192 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___192 *);
	int (*set_policy)(struct vm_area_struct___192 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___192 *, long unsigned int);
	struct page___192 * (*find_special_page)(struct vm_area_struct___192 *, long unsigned int);
};

struct core_thread___192 {
	struct task_struct___194 *task;
	struct core_thread___192 *next;
};

struct core_state___192 {
	atomic_t nr_threads;
	struct core_thread___192 dumper;
	struct completion startup;
};

struct vm_fault___182 {
	const struct {
		struct vm_area_struct___192 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___192 *cow_page;
	struct page___192 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___192 prealloc_pte;
};

struct fwnode_operations___145;

struct fwnode_handle___145 {
	struct fwnode_handle___145 *secondary;
	const struct fwnode_operations___145 *ops;
	struct device___145 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___145;

struct fwnode_endpoint___145;

struct fwnode_operations___145 {
	struct fwnode_handle___145 * (*get)(struct fwnode_handle___145 *);
	void (*put)(struct fwnode_handle___145 *);
	bool (*device_is_available)(const struct fwnode_handle___145 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___145 *, const struct device___145 *);
	bool (*property_present)(const struct fwnode_handle___145 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___145 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___145 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___145 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*get_parent)(const struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*get_next_child_node)(const struct fwnode_handle___145 *, struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*get_named_child_node)(const struct fwnode_handle___145 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___145 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___145 *);
	struct fwnode_handle___145 * (*graph_get_next_endpoint)(const struct fwnode_handle___145 *, struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*graph_get_remote_endpoint)(const struct fwnode_handle___145 *);
	struct fwnode_handle___145 * (*graph_get_port_parent)(struct fwnode_handle___145 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___145 *, struct fwnode_endpoint___145 *);
	int (*add_links)(struct fwnode_handle___145 *);
};

struct wakeup_source___145;

struct dev_pm_info___145 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___145 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___145 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___145;

struct bus_type___145;

struct device_driver___145;

struct dev_pm_domain___145;

struct irq_domain___26;

struct dev_pin_info___5;

struct device_node___47;

struct class___145;

struct attribute_group___175;

struct device___145 {
	struct kobject___175 kobj;
	struct device___145 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___145 *type;
	struct bus_type___145 *bus;
	struct device_driver___145 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___145 power;
	struct dev_pm_domain___145 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___26 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___47 *of_node;
	struct fwnode_handle___145 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___145 *class;
	const struct attribute_group___175 **groups;
	void (*release)(struct device___145 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___145 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___145 *local_fwnode;
};

struct fwnode_reference_args___145 {
	struct fwnode_handle___145 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct regmap_config___4 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___145 *, unsigned int);
	bool (*readable_reg)(struct device___145 *, unsigned int);
	bool (*volatile_reg)(struct device___145 *, unsigned int);
	bool (*precious_reg)(struct device___145 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___145 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___145 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct irq_desc___28;

typedef void (*irq_flow_handler_t___28)(struct irq_desc___28 *);

struct irq_chip___27;

struct irq_data___27 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___27 *chip;
	struct irq_domain___26 *domain;
	struct irq_data___27 *parent_data;
	void *chip_data;
};

struct irqaction___18;

struct irq_desc___28 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___27 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___28 handle_irq;
	struct irqaction___18 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___175 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___171 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pglist_data___84;

struct lruvec___84 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___84 *pgdat;
};

struct zone___84 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___84 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___84 {
	struct zone___84 *zone;
	int zone_idx;
};

struct zonelist___84 {
	struct zoneref___84 _zonerefs[321];
};

struct pglist_data___84 {
	struct zone___84 node_zones[5];
	struct zonelist___84 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___194 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___194 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___84 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___175;

struct kernfs_elem_dir___175 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___175 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___175;

struct kernfs_root___175 {
	struct kernfs_node___175 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___175 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___175 {
	struct kernfs_node___175 *target_kn;
};

struct kernfs_ops___175;

struct kernfs_elem_attr___175 {
	const struct kernfs_ops___175 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___175 *notify_next;
};

struct kernfs_node___175 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___175 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___175 dir;
		struct kernfs_elem_symlink___175 symlink;
		struct kernfs_elem_attr___175 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___175;

struct kernfs_ops___175 {
	int (*open)(struct kernfs_open_file___175 *);
	void (*release)(struct kernfs_open_file___175 *);
	int (*seq_show)(struct seq_file___163 *, void *);
	void * (*seq_start)(struct seq_file___163 *, loff_t *);
	void * (*seq_next)(struct seq_file___163 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___163 *, void *);
	ssize_t (*read)(struct kernfs_open_file___175 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___175 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___175 *, struct poll_table_struct___121 *);
	int (*mmap)(struct kernfs_open_file___175 *, struct vm_area_struct___192 *);
};

struct kernfs_syscall_ops___175 {
	int (*show_options)(struct seq_file___163 *, struct kernfs_root___175 *);
	int (*mkdir)(struct kernfs_node___175 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___175 *);
	int (*rename)(struct kernfs_node___175 *, struct kernfs_node___175 *, const char *);
	int (*show_path)(struct seq_file___163 *, struct kernfs_node___175 *, struct kernfs_root___175 *);
};

struct seq_operations___163;

struct seq_file___163 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___163 *op;
	int poll_event;
	const struct file___187 *file;
	void *private;
};

struct kernfs_open_file___175 {
	struct kernfs_node___175 *kn;
	struct file___187 *file;
	struct seq_file___163 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___182 *vm_ops;
};

typedef void (*poll_queue_proc___126)(struct file___187 *, wait_queue_head_t *, struct poll_table_struct___121 *);

struct poll_table_struct___121 {
	poll_queue_proc___126 _qproc;
	__poll_t _key;
};

struct bin_attribute___175;

struct attribute_group___175 {
	const char *name;
	umode_t (*is_visible)(struct kobject___175 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___175 *, struct bin_attribute___175 *, int);
	struct attribute **attrs;
	struct bin_attribute___175 **bin_attrs;
};

struct bin_attribute___175 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___187 * (*f_mapping)();
	ssize_t (*read)(struct file___187 *, struct kobject___175 *, struct bin_attribute___175 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___187 *, struct kobject___175 *, struct bin_attribute___175 *, char *, loff_t, size_t);
	int (*mmap)(struct file___187 *, struct kobject___175 *, struct bin_attribute___175 *, struct vm_area_struct___192 *);
};

struct sysfs_ops___175 {
	ssize_t (*show)(struct kobject___175 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___175 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___175;

struct kset___175 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___175 kobj;
	const struct kset_uevent_ops___175 *uevent_ops;
};

struct kobj_type___175 {
	void (*release)(struct kobject___175 *);
	const struct sysfs_ops___175 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___175 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___175 *);
	const void * (*namespace)(struct kobject___175 *);
	void (*get_ownership)(struct kobject___175 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___175 {
	int (* const filter)(struct kset___175 *, struct kobject___175 *);
	const char * (* const name)(struct kset___175 *, struct kobject___175 *);
	int (* const uevent)(struct kset___175 *, struct kobject___175 *, struct kobj_uevent_env *);
};

struct i2c_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

struct software_node {
	const char *name;
	const struct software_node *parent;
	const struct property_entry *properties;
};

struct property___37 {
	char *name;
	int length;
	void *value;
	struct property___37 *next;
	long unsigned int _flags;
	struct bin_attribute___175 attr;
};

struct device_node___47 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___145 fwnode;
	struct property___37 *properties;
	struct property___37 *deadprops;
	struct device_node___47 *parent;
	struct device_node___47 *child;
	struct device_node___47 *sibling;
	struct kobject___175 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___13 {
	struct device_node___47 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___24 {
	struct fwnode_handle___145 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___26 {
	int (*match)(struct irq_domain___26 *, struct device_node___47 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___26 *, struct irq_fwspec___24 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___26 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___26 *, unsigned int);
	int (*xlate)(struct irq_domain___26 *, struct device_node___47 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___26 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___26 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___26 *, struct irq_data___27 *, bool);
	void (*deactivate)(struct irq_domain___26 *, struct irq_data___27 *);
	int (*translate)(struct irq_domain___26 *, struct irq_fwspec___24 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___26;

struct irq_domain___26 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___26 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___145 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___26 *gc;
	struct irq_domain___26 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___27 *revmap[0];
};

struct irq_chip_generic___26;

struct irq_domain_chip_generic___26 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___26 *gc[0];
};

struct dev_pm_ops___145 {
	int (*prepare)(struct device___145 *);
	void (*complete)(struct device___145 *);
	int (*suspend)(struct device___145 *);
	int (*resume)(struct device___145 *);
	int (*freeze)(struct device___145 *);
	int (*thaw)(struct device___145 *);
	int (*poweroff)(struct device___145 *);
	int (*restore)(struct device___145 *);
	int (*suspend_late)(struct device___145 *);
	int (*resume_early)(struct device___145 *);
	int (*freeze_late)(struct device___145 *);
	int (*thaw_early)(struct device___145 *);
	int (*poweroff_late)(struct device___145 *);
	int (*restore_early)(struct device___145 *);
	int (*suspend_noirq)(struct device___145 *);
	int (*resume_noirq)(struct device___145 *);
	int (*freeze_noirq)(struct device___145 *);
	int (*thaw_noirq)(struct device___145 *);
	int (*poweroff_noirq)(struct device___145 *);
	int (*restore_noirq)(struct device___145 *);
	int (*runtime_suspend)(struct device___145 *);
	int (*runtime_resume)(struct device___145 *);
	int (*runtime_idle)(struct device___145 *);
};

struct wakeup_source___145 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___145 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___145 {
	struct dev_pm_ops___145 ops;
	int (*start)(struct device___145 *);
	void (*detach)(struct device___145 *, bool);
	int (*activate)(struct device___145 *);
	void (*sync)(struct device___145 *);
	void (*dismiss)(struct device___145 *);
};

struct bus_type___145 {
	const char *name;
	const char *dev_name;
	struct device___145 *dev_root;
	const struct attribute_group___175 **bus_groups;
	const struct attribute_group___175 **dev_groups;
	const struct attribute_group___175 **drv_groups;
	int (*match)(struct device___145 *, struct device_driver___145 *);
	int (*uevent)(struct device___145 *, struct kobj_uevent_env *);
	int (*probe)(struct device___145 *);
	void (*sync_state)(struct device___145 *);
	void (*remove)(struct device___145 *);
	void (*shutdown)(struct device___145 *);
	int (*online)(struct device___145 *);
	int (*offline)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	int (*num_vf)(struct device___145 *);
	int (*dma_configure)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___145 {
	const char *name;
	struct bus_type___145 *bus;
	struct module___171 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___145 *);
	void (*sync_state)(struct device___145 *);
	int (*remove)(struct device___145 *);
	void (*shutdown)(struct device___145 *);
	int (*suspend)(struct device___145 *, pm_message_t);
	int (*resume)(struct device___145 *);
	const struct attribute_group___175 **groups;
	const struct attribute_group___175 **dev_groups;
	const struct dev_pm_ops___145 *pm;
	void (*coredump)(struct device___145 *);
	struct driver_private *p;
};

struct device_type___145 {
	const char *name;
	const struct attribute_group___175 **groups;
	int (*uevent)(struct device___145 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___145 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___145 *);
	const struct dev_pm_ops___145 *pm;
};

struct class___145 {
	const char *name;
	struct module___171 *owner;
	const struct attribute_group___175 **class_groups;
	const struct attribute_group___175 **dev_groups;
	struct kobject___175 *dev_kobj;
	int (*dev_uevent)(struct device___145 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___145 *, umode_t *);
	void (*class_release)(struct class___145 *);
	void (*dev_release)(struct device___145 *);
	int (*shutdown_pre)(struct device___145 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___145 *);
	void (*get_ownership)(struct device___145 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___145 *pm;
	struct subsys_private *p;
};

struct pinctrl___5;

struct dev_pin_info___5 {
	struct pinctrl___5 *p;
	struct pinctrl_state *default_state;
	struct pinctrl_state *init_state;
	struct pinctrl_state *sleep_state;
	struct pinctrl_state *idle_state;
};

struct dentry_operations___187;

struct dentry___187 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___187 *d_parent;
	struct qstr d_name;
	struct inode___187 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___187 *d_op;
	struct super_block___187 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___187;

struct cdev___36;

struct inode___187 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___187 *i_op;
	struct super_block___187 *i_sb;
	struct address_space___187 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___86 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___188 *i_fop;
		void (*free_inode)(struct inode___187 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___187 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___36 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___187 {
	int (*d_revalidate)(struct dentry___187 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___187 *, unsigned int);
	int (*d_hash)(const struct dentry___187 *, struct qstr *);
	int (*d_compare)(const struct dentry___187 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___187 *);
	int (*d_init)(struct dentry___187 *);
	void (*d_release)(struct dentry___187 *);
	void (*d_prune)(struct dentry___187 *);
	void (*d_iput)(struct dentry___187 *, struct inode___187 *);
	char * (*d_dname)(struct dentry___187 *, char *, int);
	struct vfsmount___187 * (*d_automount)(struct path___187 *);
	int (*d_manage)(const struct path___187 *, bool);
	struct dentry___187 * (*d_real)(struct dentry___187 *, const struct inode___187 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___187;

struct mem_dqinfo___187 {
	struct quota_format_type___187 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___187;

struct quota_info___187 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___187 *files[3];
	struct mem_dqinfo___187 info[3];
	const struct quota_format_ops___187 *ops[3];
};

struct rcuwait___188 {
	struct task_struct___194 *task;
};

struct percpu_rw_semaphore___188 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___188 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___187 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___188 rw_sem[3];
};

struct shrink_control___77;

struct shrinker___77 {
	long unsigned int (*count_objects)(struct shrinker___77 *, struct shrink_control___77 *);
	long unsigned int (*scan_objects)(struct shrinker___77 *, struct shrink_control___77 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___187;

struct dquot_operations___187;

struct quotactl_ops___187;

struct block_device___94;

struct super_block___187 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___187 *s_type;
	const struct super_operations___187 *s_op;
	const struct dquot_operations___187 *dq_op;
	const struct quotactl_ops___187 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___187 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___94 *s_bdev;
	struct backing_dev_info___86 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___187 s_dquot;
	struct sb_writers___187 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___187 *s_d_op;
	int cleancache_poolid;
	struct shrinker___77 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___187 {
	struct dentry___187 *mnt_root;
	struct super_block___187 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___77 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___77 *memcg;
};

struct psi_group___127 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___194 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___127;

struct cgroup_rstat_cpu___127;

struct cgroup___127 {
	struct cgroup_subsys_state___127 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___175 *kn;
	struct cgroup_file___127 procs_file;
	struct cgroup_file___127 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___127 *subsys[14];
	struct cgroup_root___127 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___127 *dom_cgrp;
	struct cgroup___127 *old_dom_cgrp;
	struct cgroup_rstat_cpu___127 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___127 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___93 {
	struct request_queue___93 *q;
	struct io_context___93 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___86;

struct kiocb___187 {
	struct file___187 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___187 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___86 *ki_waitq;
	};
};

struct iattr___187 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___187 *ia_file;
};

struct dquot___187 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___187 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___187 {
	int qf_fmt_id;
	const struct quota_format_ops___187 *qf_ops;
	struct module___171 *qf_owner;
	struct quota_format_type___187 *qf_next;
};

struct quota_format_ops___187 {
	int (*check_quota_file)(struct super_block___187 *, int);
	int (*read_file_info)(struct super_block___187 *, int);
	int (*write_file_info)(struct super_block___187 *, int);
	int (*free_file_info)(struct super_block___187 *, int);
	int (*read_dqblk)(struct dquot___187 *);
	int (*commit_dqblk)(struct dquot___187 *);
	int (*release_dqblk)(struct dquot___187 *);
	int (*get_next_id)(struct super_block___187 *, struct kqid *);
};

struct dquot_operations___187 {
	int (*write_dquot)(struct dquot___187 *);
	struct dquot___187 * (*alloc_dquot)(struct super_block___187 *, int);
	void (*destroy_dquot)(struct dquot___187 *);
	int (*acquire_dquot)(struct dquot___187 *);
	int (*release_dquot)(struct dquot___187 *);
	int (*mark_dirty)(struct dquot___187 *);
	int (*write_info)(struct super_block___187 *, int);
	qsize_t * (*get_reserved_space)(struct inode___187 *);
	int (*get_projid)(struct inode___187 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___187 *, qsize_t *);
	int (*get_next_id)(struct super_block___187 *, struct kqid *);
};

struct quotactl_ops___187 {
	int (*quota_on)(struct super_block___187 *, int, int, const struct path___187 *);
	int (*quota_off)(struct super_block___187 *, int);
	int (*quota_enable)(struct super_block___187 *, unsigned int);
	int (*quota_disable)(struct super_block___187 *, unsigned int);
	int (*quota_sync)(struct super_block___187 *, int);
	int (*set_info)(struct super_block___187 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___187 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___187 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___187 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___187 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___187 *, unsigned int);
};

struct wait_page_queue___86 {
	struct page___192 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___86;

struct readahead_control___86;

struct swap_info_struct___45;

struct address_space_operations___187 {
	int (*writepage)(struct page___192 *, struct writeback_control___86 *);
	int (*readpage)(struct file___187 *, struct page___192 *);
	int (*writepages)(struct address_space___187 *, struct writeback_control___86 *);
	int (*set_page_dirty)(struct page___192 *);
	int (*readpages)(struct file___187 *, struct address_space___187 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___86 *);
	int (*write_begin)(struct file___187 *, struct address_space___187 *, loff_t, unsigned int, unsigned int, struct page___192 **, void **);
	int (*write_end)(struct file___187 *, struct address_space___187 *, loff_t, unsigned int, unsigned int, struct page___192 *, void *);
	sector_t (*bmap)(struct address_space___187 *, sector_t);
	void (*invalidatepage)(struct page___192 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___192 *, gfp_t);
	void (*freepage)(struct page___192 *);
	ssize_t (*direct_IO)(struct kiocb___187 *, struct iov_iter___111 *);
	int (*migratepage)(struct address_space___187 *, struct page___192 *, struct page___192 *, enum migrate_mode);
	bool (*isolate_page)(struct page___192 *, isolate_mode_t);
	void (*putback_page)(struct page___192 *);
	int (*launder_page)(struct page___192 *);
	int (*is_partially_uptodate)(struct page___192 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___192 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___187 *, struct page___192 *);
	int (*swap_activate)(struct swap_info_struct___45 *, struct file___187 *, sector_t *);
	void (*swap_deactivate)(struct file___187 *);
};

struct writeback_control___86 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___86 *wb;
	struct inode___187 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___86 {
	struct file___187 *file;
	struct address_space___187 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___109;

struct iov_iter___111 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___109 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___45 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___94 *bdev;
	struct file___187 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___36 {
	struct kobject___175 kobj;
	struct module___171 *owner;
	const struct file_operations___188 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___187 {
	struct dentry___187 * (*lookup)(struct inode___187 *, struct dentry___187 *, unsigned int);
	const char * (*get_link)(struct dentry___187 *, struct inode___187 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___187 *, int);
	struct posix_acl * (*get_acl)(struct inode___187 *, int, bool);
	int (*readlink)(struct dentry___187 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___187 *, struct dentry___187 *, umode_t, bool);
	int (*link)(struct dentry___187 *, struct inode___187 *, struct dentry___187 *);
	int (*unlink)(struct inode___187 *, struct dentry___187 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___187 *, struct dentry___187 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___187 *, struct dentry___187 *, umode_t);
	int (*rmdir)(struct inode___187 *, struct dentry___187 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___187 *, struct dentry___187 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___187 *, struct dentry___187 *, struct inode___187 *, struct dentry___187 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___187 *, struct iattr___187 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___187 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___187 *, char *, size_t);
	int (*fiemap)(struct inode___187 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___187 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___187 *, struct dentry___187 *, struct file___187 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___187 *, struct dentry___187 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___187 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___187 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___187 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___187 {
	void (*fl_copy_lock)(struct file_lock___187 *, struct file_lock___187 *);
	void (*fl_release_private)(struct file_lock___187 *);
};

struct fasync_struct___187;

struct lock_manager_operations___187;

struct file_lock___187 {
	struct file_lock___187 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___187 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___187 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___187 *fl_ops;
	const struct lock_manager_operations___187 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___187 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___187 *);
	int (*lm_grant)(struct file_lock___187 *, int);
	bool (*lm_break)(struct file_lock___187 *);
	int (*lm_change)(struct file_lock___187 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___187 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___187 *);
};

struct fasync_struct___187 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___187 *fa_next;
	struct file___187 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___187 {
	struct inode___187 * (*alloc_inode)(struct super_block___187 *);
	void (*destroy_inode)(struct inode___187 *);
	void (*free_inode)(struct inode___187 *);
	void (*dirty_inode)(struct inode___187 *, int);
	int (*write_inode)(struct inode___187 *, struct writeback_control___86 *);
	int (*drop_inode)(struct inode___187 *);
	void (*evict_inode)(struct inode___187 *);
	void (*put_super)(struct super_block___187 *);
	int (*sync_fs)(struct super_block___187 *, int);
	int (*freeze_super)(struct super_block___187 *);
	int (*freeze_fs)(struct super_block___187 *);
	int (*thaw_super)(struct super_block___187 *);
	int (*unfreeze_fs)(struct super_block___187 *);
	int (*statfs)(struct dentry___187 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___187 *, int *, char *);
	void (*umount_begin)(struct super_block___187 *);
	int (*show_options)(struct seq_file___163 *, struct dentry___187 *);
	int (*show_devname)(struct seq_file___163 *, struct dentry___187 *);
	int (*show_path)(struct seq_file___163 *, struct dentry___187 *);
	int (*show_stats)(struct seq_file___163 *, struct dentry___187 *);
	ssize_t (*quota_read)(struct super_block___187 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___187 *, int, const char *, size_t, loff_t);
	struct dquot___187 ** (*get_dquots)(struct inode___187 *);
	long int (*nr_cached_objects)(struct super_block___187 *, struct shrink_control___77 *);
	long int (*free_cached_objects)(struct super_block___187 *, struct shrink_control___77 *);
	struct file___187 * (*real_loop)(struct file___187 *);
};

struct block_device___94 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___187 *bd_inode;
	struct super_block___187 *bd_super;
	void *bd_claiming;
	struct device___145 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___175 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___94 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___187 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___93(struct bio___93 *);

struct bio_vec___109 {
	struct page___192 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___93;

struct bio___93 {
	struct bio___93 *bi_next;
	struct block_device___94 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___93 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___88 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___93 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___109 *bi_io_vec;
	struct bio_set___93 *bi_pool;
	struct bio_vec___109 bi_inline_vecs[0];
};

struct kernel_param_ops___171 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___171 *);
	int (*get)(char *, const struct kernel_param___171 *);
	void (*free)(void *);
};

struct kparam_array___171;

struct kernel_param___171 {
	const char *name;
	struct module___171 *mod;
	const struct kernel_param_ops___171 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___171 *arr;
	};
};

struct kparam_array___171 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___171 *ops;
	void *elem;
};

struct module_attribute___171 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___171 *, struct module_kobject___171 *, char *);
	ssize_t (*store)(struct module_attribute___171 *, struct module_kobject___171 *, const char *, size_t);
	void (*setup)(struct module___171 *, const char *);
	int (*test)(struct module___171 *);
	void (*free)(struct module___171 *);
};

struct irq_chip___27 {
	struct device___145 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___27 *);
	void (*irq_shutdown)(struct irq_data___27 *);
	void (*irq_enable)(struct irq_data___27 *);
	void (*irq_disable)(struct irq_data___27 *);
	void (*irq_ack)(struct irq_data___27 *);
	void (*irq_mask)(struct irq_data___27 *);
	void (*irq_mask_ack)(struct irq_data___27 *);
	void (*irq_unmask)(struct irq_data___27 *);
	void (*irq_eoi)(struct irq_data___27 *);
	int (*irq_set_affinity)(struct irq_data___27 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___27 *);
	int (*irq_set_type)(struct irq_data___27 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___27 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___27 *);
	void (*irq_bus_sync_unlock)(struct irq_data___27 *);
	void (*irq_cpu_online)(struct irq_data___27 *);
	void (*irq_cpu_offline)(struct irq_data___27 *);
	void (*irq_suspend)(struct irq_data___27 *);
	void (*irq_resume)(struct irq_data___27 *);
	void (*irq_pm_shutdown)(struct irq_data___27 *);
	void (*irq_calc_mask)(struct irq_data___27 *);
	void (*irq_print_chip)(struct irq_data___27 *, struct seq_file___163 *);
	int (*irq_request_resources)(struct irq_data___27 *);
	void (*irq_release_resources)(struct irq_data___27 *);
	void (*irq_compose_msi_msg)(struct irq_data___27 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___27 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___27 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___27 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___27 *, void *);
	void (*ipi_send_single)(struct irq_data___27 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___27 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___27 *);
	void (*irq_nmi_teardown)(struct irq_data___27 *);
	long unsigned int flags;
};

struct irqaction___18 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___18 *next;
	irq_handler_t thread_fn;
	struct task_struct___194 *thread;
	struct irqaction___18 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___26 {
	struct irq_chip___27 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___28 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___26 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___26 *);
	void (*resume)(struct irq_chip_generic___26 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___26 *domain;
	struct list_head list;
	struct irq_chip_type___26 chip_types[0];
};

struct seq_operations___163 {
	void * (*start)(struct seq_file___163 *, loff_t *);
	void (*stop)(struct seq_file___163 *, void *);
	void * (*next)(struct seq_file___163 *, void *, loff_t *);
	int (*show)(struct seq_file___163 *, void *);
};

struct dev_pagemap_ops___182 {
	void (*page_free)(struct page___192 *);
	void (*kill)(struct dev_pagemap___182 *);
	void (*cleanup)(struct dev_pagemap___182 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___182 *);
};

struct cgroup_namespace___127 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___127 *root_cset;
};

struct cftype___127;

struct cgroup_subsys___127 {
	struct cgroup_subsys_state___127 * (*css_alloc)(struct cgroup_subsys_state___127 *);
	int (*css_online)(struct cgroup_subsys_state___127 *);
	void (*css_offline)(struct cgroup_subsys_state___127 *);
	void (*css_released)(struct cgroup_subsys_state___127 *);
	void (*css_free)(struct cgroup_subsys_state___127 *);
	void (*css_reset)(struct cgroup_subsys_state___127 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___127 *, int);
	int (*css_extra_stat_show)(struct seq_file___163 *, struct cgroup_subsys_state___127 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___194 *, struct css_set___127 *);
	void (*cancel_fork)(struct task_struct___194 *, struct css_set___127 *);
	void (*fork)(struct task_struct___194 *);
	void (*exit)(struct task_struct___194 *);
	void (*release)(struct task_struct___194 *);
	void (*bind)(struct cgroup_subsys_state___127 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___127 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___127 *dfl_cftypes;
	struct cftype___127 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___127 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___127 *updated_children;
	struct cgroup___127 *updated_next;
};

struct cgroup_root___127 {
	struct kernfs_root___175 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___127 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___127 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___127 *ss;
	struct list_head node;
	struct kernfs_ops___175 *kf_ops;
	int (*open)(struct kernfs_open_file___175 *);
	void (*release)(struct kernfs_open_file___175 *);
	u64 (*read_u64)(struct cgroup_subsys_state___127 *, struct cftype___127 *);
	s64 (*read_s64)(struct cgroup_subsys_state___127 *, struct cftype___127 *);
	int (*seq_show)(struct seq_file___163 *, void *);
	void * (*seq_start)(struct seq_file___163 *, loff_t *);
	void * (*seq_next)(struct seq_file___163 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___163 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___127 *, struct cftype___127 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___127 *, struct cftype___127 *, s64);
	ssize_t (*write)(struct kernfs_open_file___175 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___175 *, struct poll_table_struct___121 *);
};

struct block_device_operations___93;

struct gendisk___94 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___94 *part0;
	const struct block_device_operations___93 *fops;
	struct request_queue___93 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___86 *bdi;
	struct kobject___175 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___175 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___93 {
	struct bio___93 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___109 *bip_vec;
	struct bio_vec___109 bip_inline_vecs[0];
};

struct blkcg___88;

struct blkg_policy_data___88;

struct blkcg_gq___88 {
	struct request_queue___93 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___88 *blkcg;
	struct blkcg_gq___88 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___88 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___93 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___93(struct request___93 *);

typedef void integrity_complete_fn___93(struct request___93 *, unsigned int);

struct blk_integrity_profile___93 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___93 *prepare_fn;
	integrity_complete_fn___93 *complete_fn;
	const char *name;
};

struct block_device_operations___93 {
	blk_qc_t (*submit_bio)(struct bio___93 *);
	int (*open)(struct block_device___94 *, fmode_t);
	void (*release)(struct gendisk___94 *, fmode_t);
	int (*rw_page)(struct block_device___94 *, sector_t, struct page___192 *, unsigned int);
	int (*ioctl)(struct block_device___94 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___94 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___94 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___94 *);
	int (*getgeo)(struct block_device___94 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___94 *, bool);
	void (*swap_slot_free_notify)(struct block_device___94 *, long unsigned int);
	int (*report_zones)(struct gendisk___94 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___94 *, umode_t *);
	struct module___171 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___94 *, sector_t *);
};

typedef void rq_end_io_fn___93(struct request___93 *, blk_status_t);

struct request___93 {
	struct request_queue___93 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___90 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___93 *bio;
	struct bio___93 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___109 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___93 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___93 *saved_end_io;
		} flush;
	};
	struct gendisk___94 *rq_disk;
	struct block_device___94 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___93 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___90 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___93 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___175 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___187 *debugfs_dir;
	struct dentry___187 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___93;

struct elevator_mq_ops___93 {
	int (*init_sched)(struct request_queue___93 *, struct elevator_type___93 *);
	void (*exit_sched)(struct elevator_queue___93 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___90 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___90 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___90 *);
	bool (*allow_merge)(struct request_queue___93 *, struct request___93 *, struct bio___93 *);
	bool (*bio_merge)(struct request_queue___93 *, struct bio___93 *, unsigned int);
	int (*request_merge)(struct request_queue___93 *, struct request___93 **, struct bio___93 *);
	void (*request_merged)(struct request_queue___93 *, struct request___93 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___93 *, struct request___93 *, struct request___93 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___93 *);
	void (*finish_request)(struct request___93 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___90 *, struct list_head *, bool);
	struct request___93 * (*dispatch_request)(struct blk_mq_hw_ctx___90 *);
	bool (*has_work)(struct blk_mq_hw_ctx___90 *);
	void (*completed_request)(struct request___93 *, u64);
	void (*requeue_request)(struct request___93 *);
	struct request___93 * (*former_request)(struct request_queue___93 *, struct request___93 *);
	struct request___93 * (*next_request)(struct request_queue___93 *, struct request___93 *);
	void (*init_icq)(struct io_cq___93 *);
	void (*exit_icq)(struct io_cq___93 *);
};

struct elv_fs_entry___93;

struct elevator_type___93 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___93 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___93 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___171 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___93 {
	struct elevator_type___93 *type;
	void *elevator_data;
	struct kobject___175 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___93 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___93 *, char *);
	ssize_t (*store)(struct elevator_queue___93 *, const char *, size_t);
};

struct blk_mq_queue_data___90;

struct blk_mq_ops___90 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___90 *, const struct blk_mq_queue_data___90 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___90 *);
	int (*get_budget)(struct request_queue___93 *);
	void (*put_budget)(struct request_queue___93 *, int);
	void (*set_rq_budget_token)(struct request___93 *, int);
	int (*get_rq_budget_token)(struct request___93 *);
	enum blk_eh_timer_return (*timeout)(struct request___93 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___90 *);
	void (*complete)(struct request___93 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___90 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___90 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___90 *, struct request___93 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___90 *, struct request___93 *, unsigned int);
	void (*initialize_rq_fn)(struct request___93 *);
	void (*cleanup_rq)(struct request___93 *);
	bool (*busy)(struct request_queue___93 *);
	int (*map_queues)(struct blk_mq_tag_set___90 *);
	void (*show_rq)(struct seq_file___163 *, struct request___93 *);
};

struct blk_mq_tag_set___90 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___90 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___90 {
	struct request___93 *rq;
	bool last;
};

struct blkcg_policy_data___88;

struct blkcg___88 {
	struct cgroup_subsys_state___127 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___88 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___88 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___88 {
	struct blkcg___88 *blkcg;
	int plid;
};

struct blkg_policy_data___88 {
	struct blkcg_gq___88 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___77 {
	struct mem_cgroup___77 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___77 {
	struct lruvec___84 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___77 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___77 *memcg;
};

struct obj_cgroup___77 {
	struct percpu_ref refcnt;
	struct mem_cgroup___77 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct i2c_msg {
	__u16 addr;
	__u16 flags;
	__u16 len;
	__u8 *buf;
};

union i2c_smbus_data {
	__u8 byte;
	__u16 word;
	__u8 block[34];
};

enum i2c_slave_event {
	I2C_SLAVE_READ_REQUESTED = 0,
	I2C_SLAVE_WRITE_REQUESTED = 1,
	I2C_SLAVE_READ_PROCESSED = 2,
	I2C_SLAVE_WRITE_RECEIVED = 3,
	I2C_SLAVE_STOP = 4,
};

struct i2c_client___2;

typedef int (*i2c_slave_cb_t)(struct i2c_client___2 *, enum i2c_slave_event, u8 *);

struct i2c_adapter;

struct i2c_client___2 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter *adapter;
	struct device___145 dev;
	int init_irq;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t slave_cb;
	void *devres_group_id;
};

enum i2c_alert_protocol {
	I2C_PROTOCOL_SMBUS_ALERT = 0,
	I2C_PROTOCOL_SMBUS_HOST_NOTIFY = 1,
};

struct i2c_board_info;

struct i2c_driver {
	unsigned int class;
	int (*probe)(struct i2c_client___2 *, const struct i2c_device_id *);
	int (*remove)(struct i2c_client___2 *);
	int (*probe_new)(struct i2c_client___2 *);
	void (*shutdown)(struct i2c_client___2 *);
	void (*alert)(struct i2c_client___2 *, enum i2c_alert_protocol, unsigned int);
	int (*command)(struct i2c_client___2 *, unsigned int, void *);
	struct device_driver___145 driver;
	const struct i2c_device_id *id_table;
	int (*detect)(struct i2c_client___2 *, struct i2c_board_info *);
	const short unsigned int *address_list;
	struct list_head clients;
};

struct i2c_board_info {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	const char *dev_name;
	void *platform_data;
	struct device_node___47 *of_node;
	struct fwnode_handle___145 *fwnode;
	const struct software_node *swnode;
	const struct resource *resources;
	unsigned int num_resources;
	int irq;
};

struct i2c_algorithm;

struct i2c_lock_operations;

struct i2c_bus_recovery_info;

struct i2c_adapter_quirks;

struct i2c_adapter {
	struct module___171 *owner;
	unsigned int class;
	const struct i2c_algorithm *algo;
	void *algo_data;
	const struct i2c_lock_operations *lock_ops;
	struct rt_mutex___3 bus_lock;
	struct rt_mutex___3 mux_lock;
	int timeout;
	int retries;
	struct device___145 dev;
	long unsigned int locked_flags;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___26 *host_notify_domain;
	struct regulator *bus_regulator;
};

struct i2c_algorithm {
	int (*master_xfer)(struct i2c_adapter *, struct i2c_msg *, int);
	int (*master_xfer_atomic)(struct i2c_adapter *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	int (*smbus_xfer_atomic)(struct i2c_adapter *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter *);
	int (*reg_slave)(struct i2c_client___2 *);
	int (*unreg_slave)(struct i2c_client___2 *);
};

struct i2c_lock_operations {
	void (*lock_bus)(struct i2c_adapter *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter *, unsigned int);
};

struct i2c_bus_recovery_info {
	int (*recover_bus)(struct i2c_adapter *);
	int (*get_scl)(struct i2c_adapter *);
	void (*set_scl)(struct i2c_adapter *, int);
	int (*get_sda)(struct i2c_adapter *);
	void (*set_sda)(struct i2c_adapter *, int);
	int (*get_bus_free)(struct i2c_adapter *);
	void (*prepare_recovery)(struct i2c_adapter *);
	void (*unprepare_recovery)(struct i2c_adapter *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
	struct pinctrl___5 *pinctrl;
	struct pinctrl_state *pins_default;
	struct pinctrl_state *pins_gpio;
};

struct pinctrl___5 {
	struct list_head node;
	struct device___145 *dev;
	struct list_head states;
	struct pinctrl_state *state;
	struct list_head dt_maps;
	struct kref users;
};

struct i2c_adapter_quirks {
	u64 flags;
	int max_num_msgs;
	u16 max_write_len;
	u16 max_read_len;
	u16 max_comb_1st_msg_len;
	u16 max_comb_2nd_msg_len;
};

struct gpio_chip___5;

struct pinctrl_gpio_range___3 {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	unsigned int npins;
	const unsigned int *pins;
	struct gpio_chip___5 *gc;
};

struct gpio_irq_chip___5 {
	struct irq_chip___27 *chip;
	struct irq_domain___26 *domain;
	const struct irq_domain_ops___26 *domain_ops;
	struct fwnode_handle___145 *fwnode;
	struct irq_domain___26 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___5 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___5 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___5 *, unsigned int);
	struct irq_domain_ops___26 child_irq_domain_ops;
	irq_flow_handler_t___28 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___28 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___5 *);
	void (*init_valid_mask)(struct gpio_chip___5 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___27 *);
	void (*irq_disable)(struct irq_data___27 *);
	void (*irq_unmask)(struct irq_data___27 *);
	void (*irq_mask)(struct irq_data___27 *);
};

struct gpio_chip___5 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___145 *parent;
	struct module___171 *owner;
	int (*request)(struct gpio_chip___5 *, unsigned int);
	void (*free)(struct gpio_chip___5 *, unsigned int);
	int (*get_direction)(struct gpio_chip___5 *, unsigned int);
	int (*direction_input)(struct gpio_chip___5 *, unsigned int);
	int (*direction_output)(struct gpio_chip___5 *, unsigned int, int);
	int (*get)(struct gpio_chip___5 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___5 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___5 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___5 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___5 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___5 *, unsigned int);
	void (*dbg_show)(struct seq_file___163 *, struct gpio_chip___5 *);
	int (*init_valid_mask)(struct gpio_chip___5 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___5 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___5 irq;
	long unsigned int *valid_mask;
	struct device_node___47 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___5 *, const struct of_phandle_args___13 *, u32 *);
};

struct pinctrl_dev___7;

struct pinctrl_ops___8 {
	int (*get_groups_count)(struct pinctrl_dev___7 *);
	const char * (*get_group_name)(struct pinctrl_dev___7 *, unsigned int);
	int (*get_group_pins)(struct pinctrl_dev___7 *, unsigned int, const unsigned int **, unsigned int *);
	void (*pin_dbg_show)(struct pinctrl_dev___7 *, struct seq_file___163 *, unsigned int);
	int (*dt_node_to_map)(struct pinctrl_dev___7 *, struct device_node___47 *, struct pinctrl_map **, unsigned int *);
	void (*dt_free_map)(struct pinctrl_dev___7 *, struct pinctrl_map *, unsigned int);
};

struct pinctrl_desc___8;

struct pinctrl_dev___7 {
	struct list_head node;
	struct pinctrl_desc___8 *desc;
	struct xarray pin_desc_tree;
	struct xarray pin_group_tree;
	unsigned int num_groups;
	struct xarray pin_function_tree;
	unsigned int num_functions;
	struct list_head gpio_ranges;
	struct device___145 *dev;
	struct module___171 *owner;
	void *driver_data;
	struct pinctrl___5 *p;
	struct pinctrl_state *hog_default;
	struct pinctrl_state *hog_sleep;
	struct mutex mutex;
	struct dentry___187 *device_root;
};

struct pinmux_ops___5;

struct pinconf_ops___7;

struct pinctrl_desc___8 {
	const char *name;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct pinctrl_ops___8 *pctlops;
	const struct pinmux_ops___5 *pmxops;
	const struct pinconf_ops___7 *confops;
	struct module___171 *owner;
	unsigned int num_custom_params;
	const struct pinconf_generic_params *custom_params;
	const struct pin_config_item *custom_conf_items;
	bool link_consumers;
};

struct pinmux_ops___5 {
	int (*request)(struct pinctrl_dev___7 *, unsigned int);
	int (*free)(struct pinctrl_dev___7 *, unsigned int);
	int (*get_functions_count)(struct pinctrl_dev___7 *);
	const char * (*get_function_name)(struct pinctrl_dev___7 *, unsigned int);
	int (*get_function_groups)(struct pinctrl_dev___7 *, unsigned int, const char * const **, unsigned int *);
	int (*set_mux)(struct pinctrl_dev___7 *, unsigned int, unsigned int);
	int (*gpio_request_enable)(struct pinctrl_dev___7 *, struct pinctrl_gpio_range___3 *, unsigned int);
	void (*gpio_disable_free)(struct pinctrl_dev___7 *, struct pinctrl_gpio_range___3 *, unsigned int);
	int (*gpio_set_direction)(struct pinctrl_dev___7 *, struct pinctrl_gpio_range___3 *, unsigned int, bool);
	bool strict;
};

struct pinconf_ops___7 {
	bool is_generic;
	int (*pin_config_get)(struct pinctrl_dev___7 *, unsigned int, long unsigned int *);
	int (*pin_config_set)(struct pinctrl_dev___7 *, unsigned int, long unsigned int *, unsigned int);
	int (*pin_config_group_get)(struct pinctrl_dev___7 *, unsigned int, long unsigned int *);
	int (*pin_config_group_set)(struct pinctrl_dev___7 *, unsigned int, long unsigned int *, unsigned int);
	void (*pin_config_dbg_show)(struct pinctrl_dev___7 *, struct seq_file___163 *, unsigned int);
	void (*pin_config_group_dbg_show)(struct pinctrl_dev___7 *, struct seq_file___163 *, unsigned int);
	void (*pin_config_config_dbg_show)(struct pinctrl_dev___7 *, struct seq_file___163 *, long unsigned int);
};

enum {
	SX150X_123 = 0,
	SX150X_456 = 1,
	SX150X_789 = 2,
};

enum {
	SX150X_789_REG_MISC_AUTOCLEAR_OFF = 1,
	SX150X_MAX_REGISTER = 173,
	SX150X_IRQ_TYPE_EDGE_RISING = 1,
	SX150X_IRQ_TYPE_EDGE_FALLING = 2,
	SX150X_789_RESET_KEY1 = 18,
	SX150X_789_RESET_KEY2 = 52,
};

struct sx150x_123_pri {
	u8 reg_pld_mode;
	u8 reg_pld_table0;
	u8 reg_pld_table1;
	u8 reg_pld_table2;
	u8 reg_pld_table3;
	u8 reg_pld_table4;
	u8 reg_advanced;
};

struct sx150x_456_pri {
	u8 reg_pld_mode;
	u8 reg_pld_table0;
	u8 reg_pld_table1;
	u8 reg_pld_table2;
	u8 reg_pld_table3;
	u8 reg_pld_table4;
	u8 reg_advanced;
};

struct sx150x_789_pri {
	u8 reg_drain;
	u8 reg_polarity;
	u8 reg_clock;
	u8 reg_misc;
	u8 reg_reset;
	u8 ngpios;
};

struct sx150x_device_data {
	u8 model;
	u8 reg_pullup;
	u8 reg_pulldn;
	u8 reg_dir;
	u8 reg_data;
	u8 reg_irq_mask;
	u8 reg_irq_src;
	u8 reg_sense;
	u8 ngpios;
	union {
		struct sx150x_123_pri x123;
		struct sx150x_456_pri x456;
		struct sx150x_789_pri x789;
	} pri;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
};

struct sx150x_pinctrl {
	struct device___145 *dev;
	struct i2c_client___2 *client;
	struct pinctrl_dev___7 *pctldev;
	struct pinctrl_desc___8 pinctrl_desc;
	struct gpio_chip___5 gpio;
	struct irq_chip___27 irq_chip;
	struct regmap *regmap;
	struct {
		u32 sense;
		u32 masked;
	} irq;
	struct mutex lock;
	const struct sx150x_device_data *data;
};

struct tegra_pinctrl_soc_data;

struct tegra_pmx {
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctl;
	const struct tegra_pinctrl_soc_data *soc;
	const char **group_pins;
	int nbanks;
	void **regs;
	u32 *backup_regs;
};

struct tegra_function;

struct tegra_pingroup;

struct tegra_pinctrl_soc_data {
	unsigned int ngpios;
	const char *gpio_compatible;
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	struct tegra_function *functions;
	unsigned int nfunctions;
	const struct tegra_pingroup *groups;
	unsigned int ngroups;
	bool hsm_in_mux;
	bool schmitt_in_mux;
	bool drvtype_in_mux;
	bool sfsel_in_mux;
};

enum tegra_pinconf_param {
	TEGRA_PINCONF_PARAM_PULL = 0,
	TEGRA_PINCONF_PARAM_TRISTATE = 1,
	TEGRA_PINCONF_PARAM_ENABLE_INPUT = 2,
	TEGRA_PINCONF_PARAM_OPEN_DRAIN = 3,
	TEGRA_PINCONF_PARAM_LOCK = 4,
	TEGRA_PINCONF_PARAM_IORESET = 5,
	TEGRA_PINCONF_PARAM_RCV_SEL = 6,
	TEGRA_PINCONF_PARAM_HIGH_SPEED_MODE = 7,
	TEGRA_PINCONF_PARAM_SCHMITT = 8,
	TEGRA_PINCONF_PARAM_LOW_POWER_MODE = 9,
	TEGRA_PINCONF_PARAM_DRIVE_DOWN_STRENGTH = 10,
	TEGRA_PINCONF_PARAM_DRIVE_UP_STRENGTH = 11,
	TEGRA_PINCONF_PARAM_SLEW_RATE_FALLING = 12,
	TEGRA_PINCONF_PARAM_SLEW_RATE_RISING = 13,
	TEGRA_PINCONF_PARAM_DRIVE_TYPE = 14,
};

struct tegra_function {
	const char *name;
	const char **groups;
	unsigned int ngroups;
};

struct tegra_pingroup {
	const char *name;
	const unsigned int *pins;
	u8 npins;
	u8 funcs[4];
	s32 mux_reg;
	s32 pupd_reg;
	s32 tri_reg;
	s32 drv_reg;
	u32 mux_bank: 2;
	u32 pupd_bank: 2;
	u32 tri_bank: 2;
	u32 drv_bank: 2;
	s32 mux_bit: 6;
	s32 pupd_bit: 6;
	s32 tri_bit: 6;
	s32 einput_bit: 6;
	s32 odrain_bit: 6;
	s32 lock_bit: 6;
	s32 ioreset_bit: 6;
	s32 rcv_sel_bit: 6;
	s32 hsm_bit: 6;
	s32 sfsel_bit: 6;
	s32 schmitt_bit: 6;
	s32 lpmd_bit: 6;
	s32 drvdn_bit: 6;
	s32 drvup_bit: 6;
	s32 slwr_bit: 6;
	s32 slwf_bit: 6;
	s32 drvtype_bit: 6;
	s32 drvdn_width: 6;
	s32 drvup_width: 6;
	s32 slwr_width: 6;
	s32 slwf_width: 6;
	long: 26;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 parked_bitmask;
};

struct cfg_param {
	const char *property;
	enum tegra_pinconf_param param;
};

enum tegra_mux {
	TEGRA_MUX_BLINK = 0,
	TEGRA_MUX_CCLA = 1,
	TEGRA_MUX_CEC = 2,
	TEGRA_MUX_CLDVFS = 3,
	TEGRA_MUX_CLK = 4,
	TEGRA_MUX_CLK12 = 5,
	TEGRA_MUX_CPU = 6,
	TEGRA_MUX_CSI = 7,
	TEGRA_MUX_DAP = 8,
	TEGRA_MUX_DAP1 = 9,
	TEGRA_MUX_DAP2 = 10,
	TEGRA_MUX_DEV3 = 11,
	TEGRA_MUX_DISPLAYA = 12,
	TEGRA_MUX_DISPLAYA_ALT = 13,
	TEGRA_MUX_DISPLAYB = 14,
	TEGRA_MUX_DP = 15,
	TEGRA_MUX_DSI_B = 16,
	TEGRA_MUX_DTV = 17,
	TEGRA_MUX_EXTPERIPH1 = 18,
	TEGRA_MUX_EXTPERIPH2 = 19,
	TEGRA_MUX_EXTPERIPH3 = 20,
	TEGRA_MUX_GMI = 21,
	TEGRA_MUX_GMI_ALT = 22,
	TEGRA_MUX_HDA = 23,
	TEGRA_MUX_HSI = 24,
	TEGRA_MUX_I2C1 = 25,
	TEGRA_MUX_I2C2 = 26,
	TEGRA_MUX_I2C3 = 27,
	TEGRA_MUX_I2C4 = 28,
	TEGRA_MUX_I2CPWR = 29,
	TEGRA_MUX_I2S0 = 30,
	TEGRA_MUX_I2S1 = 31,
	TEGRA_MUX_I2S2 = 32,
	TEGRA_MUX_I2S3 = 33,
	TEGRA_MUX_I2S4 = 34,
	TEGRA_MUX_IRDA = 35,
	TEGRA_MUX_KBC = 36,
	TEGRA_MUX_OWR = 37,
	TEGRA_MUX_PE = 38,
	TEGRA_MUX_PE0 = 39,
	TEGRA_MUX_PE1 = 40,
	TEGRA_MUX_PMI = 41,
	TEGRA_MUX_PWM0 = 42,
	TEGRA_MUX_PWM1 = 43,
	TEGRA_MUX_PWM2 = 44,
	TEGRA_MUX_PWM3 = 45,
	TEGRA_MUX_PWRON = 46,
	TEGRA_MUX_RESET_OUT_N = 47,
	TEGRA_MUX_RSVD1 = 48,
	TEGRA_MUX_RSVD2 = 49,
	TEGRA_MUX_RSVD3 = 50,
	TEGRA_MUX_RSVD4 = 51,
	TEGRA_MUX_RTCK = 52,
	TEGRA_MUX_SATA = 53,
	TEGRA_MUX_SDMMC1 = 54,
	TEGRA_MUX_SDMMC2 = 55,
	TEGRA_MUX_SDMMC3 = 56,
	TEGRA_MUX_SDMMC4 = 57,
	TEGRA_MUX_SOC = 58,
	TEGRA_MUX_SPDIF = 59,
	TEGRA_MUX_SPI1 = 60,
	TEGRA_MUX_SPI2 = 61,
	TEGRA_MUX_SPI3 = 62,
	TEGRA_MUX_SPI4 = 63,
	TEGRA_MUX_SPI5 = 64,
	TEGRA_MUX_SPI6 = 65,
	TEGRA_MUX_SYS = 66,
	TEGRA_MUX_TMDS = 67,
	TEGRA_MUX_TRACE = 68,
	TEGRA_MUX_UARTA = 69,
	TEGRA_MUX_UARTB = 70,
	TEGRA_MUX_UARTC = 71,
	TEGRA_MUX_UARTD = 72,
	TEGRA_MUX_ULPI = 73,
	TEGRA_MUX_USB = 74,
	TEGRA_MUX_VGP1 = 75,
	TEGRA_MUX_VGP2 = 76,
	TEGRA_MUX_VGP3 = 77,
	TEGRA_MUX_VGP4 = 78,
	TEGRA_MUX_VGP5 = 79,
	TEGRA_MUX_VGP6 = 80,
	TEGRA_MUX_VI = 81,
	TEGRA_MUX_VI_ALT1 = 82,
	TEGRA_MUX_VI_ALT3 = 83,
	TEGRA_MUX_VIMCLK2 = 84,
	TEGRA_MUX_VIMCLK2_ALT = 85,
};

enum tegra_mux___2 {
	TEGRA_MUX_AUD = 0,
	TEGRA_MUX_BCL = 1,
	TEGRA_MUX_BLINK___2 = 2,
	TEGRA_MUX_CCLA___2 = 3,
	TEGRA_MUX_CEC___2 = 4,
	TEGRA_MUX_CLDVFS___2 = 5,
	TEGRA_MUX_CLK___2 = 6,
	TEGRA_MUX_CORE = 7,
	TEGRA_MUX_CPU___2 = 8,
	TEGRA_MUX_DISPLAYA___2 = 9,
	TEGRA_MUX_DISPLAYB___2 = 10,
	TEGRA_MUX_DMIC1 = 11,
	TEGRA_MUX_DMIC2 = 12,
	TEGRA_MUX_DMIC3 = 13,
	TEGRA_MUX_DP___2 = 14,
	TEGRA_MUX_DTV___2 = 15,
	TEGRA_MUX_EXTPERIPH3___2 = 16,
	TEGRA_MUX_I2C1___2 = 17,
	TEGRA_MUX_I2C2___2 = 18,
	TEGRA_MUX_I2C3___2 = 19,
	TEGRA_MUX_I2CPMU = 20,
	TEGRA_MUX_I2CVI = 21,
	TEGRA_MUX_I2S1___2 = 22,
	TEGRA_MUX_I2S2___2 = 23,
	TEGRA_MUX_I2S3___2 = 24,
	TEGRA_MUX_I2S4A = 25,
	TEGRA_MUX_I2S4B = 26,
	TEGRA_MUX_I2S5A = 27,
	TEGRA_MUX_I2S5B = 28,
	TEGRA_MUX_IQC0 = 29,
	TEGRA_MUX_IQC1 = 30,
	TEGRA_MUX_JTAG = 31,
	TEGRA_MUX_PE___2 = 32,
	TEGRA_MUX_PE0___2 = 33,
	TEGRA_MUX_PE1___2 = 34,
	TEGRA_MUX_PMI___2 = 35,
	TEGRA_MUX_PWM0___2 = 36,
	TEGRA_MUX_PWM1___2 = 37,
	TEGRA_MUX_PWM2___2 = 38,
	TEGRA_MUX_PWM3___2 = 39,
	TEGRA_MUX_QSPI = 40,
	TEGRA_MUX_RSVD0 = 41,
	TEGRA_MUX_RSVD1___2 = 42,
	TEGRA_MUX_RSVD2___2 = 43,
	TEGRA_MUX_RSVD3___2 = 44,
	TEGRA_MUX_SATA___2 = 45,
	TEGRA_MUX_SDMMC1___2 = 46,
	TEGRA_MUX_SDMMC3___2 = 47,
	TEGRA_MUX_SHUTDOWN = 48,
	TEGRA_MUX_SOC___2 = 49,
	TEGRA_MUX_SOR0 = 50,
	TEGRA_MUX_SOR1 = 51,
	TEGRA_MUX_SPDIF___2 = 52,
	TEGRA_MUX_SPI1___2 = 53,
	TEGRA_MUX_SPI2___2 = 54,
	TEGRA_MUX_SPI3___2 = 55,
	TEGRA_MUX_SPI4___2 = 56,
	TEGRA_MUX_SYS___2 = 57,
	TEGRA_MUX_TOUCH = 58,
	TEGRA_MUX_UART = 59,
	TEGRA_MUX_UARTA___2 = 60,
	TEGRA_MUX_UARTB___2 = 61,
	TEGRA_MUX_UARTC___2 = 62,
	TEGRA_MUX_UARTD___2 = 63,
	TEGRA_MUX_USB___2 = 64,
	TEGRA_MUX_VGP1___2 = 65,
	TEGRA_MUX_VGP2___2 = 66,
	TEGRA_MUX_VGP3___2 = 67,
	TEGRA_MUX_VGP4___2 = 68,
	TEGRA_MUX_VGP5___2 = 69,
	TEGRA_MUX_VGP6___2 = 70,
	TEGRA_MUX_VIMCLK = 71,
	TEGRA_MUX_VIMCLK2___2 = 72,
};

enum pin_id {
	TEGRA_PIN_PEX_L5_CLKREQ_N_PGG0 = 0,
	TEGRA_PIN_PEX_L5_RST_N_PGG1 = 1,
};

enum tegra_mux_dt {
	TEGRA_MUX_RSVD0___2 = 0,
	TEGRA_MUX_RSVD1___3 = 1,
	TEGRA_MUX_RSVD2___3 = 2,
	TEGRA_MUX_RSVD3___3 = 3,
	TEGRA_MUX_PE5 = 4,
};

struct phy___4;

struct phy_ops___4 {
	int (*init)(struct phy___4 *);
	int (*exit)(struct phy___4 *);
	int (*power_on)(struct phy___4 *);
	int (*power_off)(struct phy___4 *);
	int (*set_mode)(struct phy___4 *, enum phy_mode, int);
	int (*set_media)(struct phy___4 *, enum phy_media);
	int (*set_speed)(struct phy___4 *, int);
	int (*configure)(struct phy___4 *, union phy_configure_opts___2 *);
	int (*validate)(struct phy___4 *, enum phy_mode, int, union phy_configure_opts___2 *);
	int (*reset)(struct phy___4 *);
	int (*calibrate)(struct phy___4 *);
	void (*release)(struct phy___4 *);
	struct module___171 *owner;
};

struct phy___4 {
	struct device___145 dev;
	int id;
	const struct phy_ops___4 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct phy_provider___4 {
	struct device___145 *dev;
	struct device_node___47 *children;
	struct module___171 *owner;
	struct list_head list;
	struct phy___4 * (*of_xlate)(struct device___145 *, struct of_phandle_args___13 *);
};

struct platform_device___14 {
	const char *name;
	int id;
	bool id_auto;
	struct device___145 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct tegra_xusb_padctl_function {
	const char *name;
	const char * const *groups;
	unsigned int num_groups;
};

struct tegra_xusb_padctl_lane;

struct tegra_xusb_padctl_soc {
	const struct pinctrl_pin_desc *pins;
	unsigned int num_pins;
	const struct tegra_xusb_padctl_function *functions;
	unsigned int num_functions;
	const struct tegra_xusb_padctl_lane *lanes;
	unsigned int num_lanes;
};

struct tegra_xusb_padctl_lane {
	const char *name;
	unsigned int offset;
	unsigned int shift;
	unsigned int mask;
	unsigned int iddq;
	const unsigned int *funcs;
	unsigned int num_funcs;
};

struct tegra_xusb_padctl {
	struct device___145 *dev;
	void *regs;
	struct mutex lock;
	struct reset_control *rst;
	const struct tegra_xusb_padctl_soc *soc;
	struct pinctrl_dev___7 *pinctrl;
	struct pinctrl_desc___8 desc;
	struct phy_provider___4 *provider;
	struct phy___4 *phys[2];
	unsigned int enable;
};

enum tegra_xusb_padctl_param {
	TEGRA_XUSB_PADCTL_IDDQ = 0,
};

struct tegra_xusb_padctl_property {
	const char *name;
	enum tegra_xusb_padctl_param param;
};

enum tegra124_function {
	TEGRA124_FUNC_SNPS = 0,
	TEGRA124_FUNC_XUSB = 1,
	TEGRA124_FUNC_UART = 2,
	TEGRA124_FUNC_PCIE = 3,
	TEGRA124_FUNC_USB3 = 4,
	TEGRA124_FUNC_SATA = 5,
	TEGRA124_FUNC_RSVD = 6,
};

struct regmap_config___5 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___144 *, unsigned int);
	bool (*readable_reg)(struct device___144 *, unsigned int);
	bool (*volatile_reg)(struct device___144 *, unsigned int);
	bool (*precious_reg)(struct device___144 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___144 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___144 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

enum {
	PINCONF_BIAS = 0,
	PINCONF_SCHMITT = 1,
	PINCONF_DRIVE_STRENGTH = 2,
};

enum {
	FUNC_NONE = 0,
	FUNC_GPIO = 1,
	FUNC_IRQ0 = 2,
	FUNC_IRQ0_IN = 3,
	FUNC_IRQ0_OUT = 4,
	FUNC_IRQ1 = 5,
	FUNC_IRQ1_IN = 6,
	FUNC_IRQ1_OUT = 7,
	FUNC_EXT_IRQ = 8,
	FUNC_MIIM = 9,
	FUNC_PHY_LED = 10,
	FUNC_PCI_WAKE = 11,
	FUNC_MD = 12,
	FUNC_PTP0 = 13,
	FUNC_PTP1 = 14,
	FUNC_PTP2 = 15,
	FUNC_PTP3 = 16,
	FUNC_PWM = 17,
	FUNC_RECO_CLK = 18,
	FUNC_SFP = 19,
	FUNC_SG0 = 20,
	FUNC_SG1 = 21,
	FUNC_SG2 = 22,
	FUNC_SI = 23,
	FUNC_SI2 = 24,
	FUNC_TACHO = 25,
	FUNC_TWI = 26,
	FUNC_TWI2 = 27,
	FUNC_TWI3 = 28,
	FUNC_TWI_SCL_M = 29,
	FUNC_UART = 30,
	FUNC_UART2 = 31,
	FUNC_UART3 = 32,
	FUNC_PLL_STAT = 33,
	FUNC_EMMC = 34,
	FUNC_REF_CLK = 35,
	FUNC_RCVRD_CLK = 36,
	FUNC_MAX = 37,
};

struct ocelot_pmx_func {
	const char **groups;
	unsigned int ngroups;
};

struct ocelot_pin_caps {
	unsigned int pin;
	unsigned char functions[4];
};

struct ocelot_pinctrl {
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctl;
	struct gpio_chip___4 gpio_chip;
	struct regmap *map;
	void *pincfg;
	struct pinctrl_desc___7 *desc;
	struct ocelot_pmx_func func[37];
	u8 stride;
};

struct platform_driver___13 {
	int (*probe)(struct platform_device___14 *);
	int (*remove)(struct platform_device___14 *);
	void (*shutdown)(struct platform_device___14 *);
	int (*suspend)(struct platform_device___14 *, pm_message_t);
	int (*resume)(struct platform_device___14 *);
	struct device_driver___145 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum {
	REG_INPUT_DATA = 0,
	REG_PORT_CONFIG = 1,
	REG_PORT_ENABLE = 2,
	REG_SIO_CONFIG = 3,
	REG_SIO_CLOCK = 4,
	REG_INT_POLARITY = 5,
	REG_INT_TRIGGER = 6,
	REG_INT_ACK = 7,
	REG_INT_ENABLE = 8,
	REG_INT_IDENT = 9,
	MAXREG = 10,
};

enum {
	SGPIO_ARCH_LUTON = 0,
	SGPIO_ARCH_OCELOT = 1,
	SGPIO_ARCH_SPARX5 = 2,
};

enum {
	SGPIO_FLAGS_HAS_IRQ = 1,
};

struct sgpio_properties {
	int arch;
	int flags;
	u8 regoff[10];
};

struct sgpio_priv;

struct sgpio_bank {
	struct sgpio_priv *priv;
	bool is_input;
	struct gpio_chip___5 gpio;
	struct pinctrl_desc___8 pctl_desc;
};

struct sgpio_priv {
	struct device___145 *dev;
	struct sgpio_bank in;
	struct sgpio_bank out;
	u32 bitcount;
	u32 ports;
	u32 clock;
	u32 *regs;
	const struct sgpio_properties *properties;
	spinlock_t lock;
};

struct sgpio_port_addr {
	u8 port;
	u8 bit;
};

enum owl_pinconf_drv {
	OWL_PINCONF_DRV_2MA = 0,
	OWL_PINCONF_DRV_4MA = 1,
	OWL_PINCONF_DRV_8MA = 2,
	OWL_PINCONF_DRV_12MA = 3,
};

struct owl_pullctl {
	int reg;
	unsigned int shift;
	unsigned int width;
};

struct owl_st {
	int reg;
	unsigned int shift;
	unsigned int width;
};

struct owl_pingroup {
	const char *name;
	unsigned int *pads;
	unsigned int npads;
	unsigned int *funcs;
	unsigned int nfuncs;
	int mfpctl_reg;
	unsigned int mfpctl_shift;
	unsigned int mfpctl_width;
	int drv_reg;
	unsigned int drv_shift;
	unsigned int drv_width;
	int sr_reg;
	unsigned int sr_shift;
	unsigned int sr_width;
};

struct owl_padinfo {
	int pad;
	struct owl_pullctl *pullctl;
	struct owl_st *st;
};

struct owl_pinmux_func {
	const char *name;
	const char * const *groups;
	unsigned int ngroups;
};

struct owl_gpio_port {
	unsigned int offset;
	unsigned int pins;
	unsigned int outen;
	unsigned int inen;
	unsigned int dat;
	unsigned int intc_ctl;
	unsigned int intc_pd;
	unsigned int intc_msk;
	unsigned int intc_type;
	u8 shared_ctl_offset;
};

struct owl_pinctrl_soc_data {
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct owl_pinmux_func *functions;
	unsigned int nfunctions;
	const struct owl_pingroup *groups;
	unsigned int ngroups;
	const struct owl_padinfo *padinfo;
	unsigned int ngpios;
	const struct owl_gpio_port *ports;
	unsigned int nports;
	int (*padctl_val2arg)(const struct owl_padinfo *, unsigned int, u32 *);
	int (*padctl_arg2val)(const struct owl_padinfo *, unsigned int, u32 *);
};

struct owl_pinctrl {
	struct device___145 *dev;
	struct pinctrl_dev___7 *pctrldev;
	struct gpio_chip___5 chip;
	raw_spinlock_t lock;
	struct clk *clk;
	const struct owl_pinctrl_soc_data *soc;
	void *base;
	struct irq_chip___27 irq_chip;
	unsigned int num_irq;
	unsigned int *irq;
};

enum s700_pinmux_functions {
	S700_MUX_NOR = 0,
	S700_MUX_ETH_RGMII = 1,
	S700_MUX_ETH_SGMII = 2,
	S700_MUX_SPI0 = 3,
	S700_MUX_SPI1 = 4,
	S700_MUX_SPI2 = 5,
	S700_MUX_SPI3 = 6,
	S700_MUX_SENS0 = 7,
	S700_MUX_SENS1 = 8,
	S700_MUX_UART0 = 9,
	S700_MUX_UART1 = 10,
	S700_MUX_UART2 = 11,
	S700_MUX_UART3 = 12,
	S700_MUX_UART4 = 13,
	S700_MUX_UART5 = 14,
	S700_MUX_UART6 = 15,
	S700_MUX_I2S0 = 16,
	S700_MUX_I2S1 = 17,
	S700_MUX_PCM1 = 18,
	S700_MUX_PCM0 = 19,
	S700_MUX_KS = 20,
	S700_MUX_JTAG = 21,
	S700_MUX_PWM0 = 22,
	S700_MUX_PWM1 = 23,
	S700_MUX_PWM2 = 24,
	S700_MUX_PWM3 = 25,
	S700_MUX_PWM4 = 26,
	S700_MUX_PWM5 = 27,
	S700_MUX_P0 = 28,
	S700_MUX_SD0 = 29,
	S700_MUX_SD1 = 30,
	S700_MUX_SD2 = 31,
	S700_MUX_I2C0 = 32,
	S700_MUX_I2C1 = 33,
	S700_MUX_I2C2 = 34,
	S700_MUX_I2C3 = 35,
	S700_MUX_DSI = 36,
	S700_MUX_LVDS = 37,
	S700_MUX_USB30 = 38,
	S700_MUX_CLKO_25M = 39,
	S700_MUX_MIPI_CSI = 40,
	S700_MUX_NAND = 41,
	S700_MUX_SPDIF = 42,
	S700_MUX_SIRQ0 = 43,
	S700_MUX_SIRQ1 = 44,
	S700_MUX_SIRQ2 = 45,
	S700_MUX_BT = 46,
	S700_MUX_LCD0 = 47,
	S700_MUX_RESERVED = 48,
};

enum s700_pinconf_pull {
	OWL_PINCONF_PULL_DOWN = 0,
	OWL_PINCONF_PULL_UP = 1,
};

enum s900_pinmux_functions {
	S900_MUX_ERAM = 0,
	S900_MUX_ETH_RMII = 1,
	S900_MUX_ETH_SMII = 2,
	S900_MUX_SPI0 = 3,
	S900_MUX_SPI1 = 4,
	S900_MUX_SPI2 = 5,
	S900_MUX_SPI3 = 6,
	S900_MUX_SENS0 = 7,
	S900_MUX_UART0 = 8,
	S900_MUX_UART1 = 9,
	S900_MUX_UART2 = 10,
	S900_MUX_UART3 = 11,
	S900_MUX_UART4 = 12,
	S900_MUX_UART5 = 13,
	S900_MUX_UART6 = 14,
	S900_MUX_I2S0 = 15,
	S900_MUX_I2S1 = 16,
	S900_MUX_PCM0 = 17,
	S900_MUX_PCM1 = 18,
	S900_MUX_JTAG = 19,
	S900_MUX_PWM0 = 20,
	S900_MUX_PWM1 = 21,
	S900_MUX_PWM2 = 22,
	S900_MUX_PWM3 = 23,
	S900_MUX_PWM4 = 24,
	S900_MUX_PWM5 = 25,
	S900_MUX_SD0 = 26,
	S900_MUX_SD1 = 27,
	S900_MUX_SD2 = 28,
	S900_MUX_SD3 = 29,
	S900_MUX_I2C0 = 30,
	S900_MUX_I2C1 = 31,
	S900_MUX_I2C2 = 32,
	S900_MUX_I2C3 = 33,
	S900_MUX_I2C4 = 34,
	S900_MUX_I2C5 = 35,
	S900_MUX_LVDS = 36,
	S900_MUX_USB20 = 37,
	S900_MUX_USB30 = 38,
	S900_MUX_GPU = 39,
	S900_MUX_MIPI_CSI0 = 40,
	S900_MUX_MIPI_CSI1 = 41,
	S900_MUX_MIPI_DSI = 42,
	S900_MUX_NAND0 = 43,
	S900_MUX_NAND1 = 44,
	S900_MUX_SPDIF = 45,
	S900_MUX_SIRQ0 = 46,
	S900_MUX_SIRQ1 = 47,
	S900_MUX_SIRQ2 = 48,
	S900_MUX_AUX_START = 49,
	S900_MUX_MAX = 50,
	S900_MUX_RESERVED = 51,
};

enum s900_pinconf_pull {
	OWL_PINCONF_PULL_HIZ = 0,
	OWL_PINCONF_PULL_DOWN___2 = 1,
	OWL_PINCONF_PULL_UP___2 = 2,
	OWL_PINCONF_PULL_HOLD = 3,
};

struct bcm2835_pinctrl {
	struct device___144 *dev;
	void *base;
	int *wake_irq;
	long unsigned int enabled_irq_map[2];
	unsigned int irq_type[58];
	struct pinctrl_dev___4 *pctl_dev;
	struct gpio_chip___4 gpio_chip;
	struct pinctrl_desc___7 pctl_desc;
	struct pinctrl_gpio_range___2 gpio_range;
	raw_spinlock_t irq_lock[2];
};

enum bcm2835_fsel {
	BCM2835_FSEL_COUNT = 8,
	BCM2835_FSEL_MASK = 7,
};

struct bcm_plat_data {
	const struct gpio_chip___4 *gpio_chip;
	const struct pinctrl_desc___7 *pctl_desc;
	const struct pinctrl_gpio_range___2 *gpio_range;
};

enum iproc_pinconf_param {
	IPROC_PINCONF_DRIVE_STRENGTH = 0,
	IPROC_PINCONF_BIAS_DISABLE = 1,
	IPROC_PINCONF_BIAS_PULL_UP = 2,
	IPROC_PINCONF_BIAS_PULL_DOWN = 3,
	IPROC_PINCON_MAX = 4,
};

enum iproc_pinconf_ctrl_type {
	IOCTRL_TYPE_AON = 1,
	IOCTRL_TYPE_CDRU = 2,
	IOCTRL_TYPE_INVALID = 3,
};

struct iproc_gpio {
	struct device___144 *dev;
	void *base;
	void *io_ctrl;
	enum iproc_pinconf_ctrl_type io_ctrl_type;
	raw_spinlock_t lock;
	struct irq_chip___26 irqchip;
	struct gpio_chip___4 gc;
	unsigned int num_banks;
	bool pinmux_is_supported;
	enum pin_config_param *pinconf_disable;
	unsigned int nr_pinconf_disable;
	struct pinctrl_dev___4 *pctl;
	struct pinctrl_desc___7 pctldesc;
};

struct ns2_mux {
	unsigned int base;
	unsigned int offset;
	unsigned int shift;
	unsigned int mask;
	unsigned int alt;
};

struct ns2_mux_log {
	struct ns2_mux mux;
	bool is_configured;
};

struct ns2_pin_group {
	const char *name;
	const unsigned int *pins;
	const unsigned int num_pins;
	const struct ns2_mux mux;
};

struct ns2_pin_function {
	const char *name;
	const char * const *groups;
	const unsigned int num_groups;
};

struct ns2_pinctrl {
	struct pinctrl_dev___6 *pctl;
	struct device___144 *dev;
	void *base0;
	void *base1;
	void *pinconf_base;
	const struct ns2_pin_group *groups;
	unsigned int num_groups;
	const struct ns2_pin_function *functions;
	unsigned int num_functions;
	struct ns2_mux_log *mux_log;
	spinlock_t lock;
};

struct ns2_pinconf {
	unsigned int base;
	unsigned int offset;
	unsigned int src_shift;
	unsigned int input_en;
	unsigned int pull_shift;
	unsigned int drive_shift;
};

struct ns2_pin {
	unsigned int pin;
	char *name;
	struct ns2_pinconf pin_conf;
};

struct berlin_desc_function {
	const char *name;
	u8 muxval;
};

struct berlin_desc_group {
	const char *name;
	u8 offset;
	u8 bit_width;
	u8 lsb;
	struct berlin_desc_function *functions;
};

struct berlin_pinctrl_desc {
	const struct berlin_desc_group *groups;
	unsigned int ngroups;
};

struct berlin_pinctrl_function {
	const char *name;
	const char **groups;
	unsigned int ngroups;
};

struct berlin_pinctrl {
	struct regmap *regmap;
	struct device___145 *dev;
	const struct berlin_pinctrl_desc *desc;
	struct berlin_pinctrl_function *functions;
	unsigned int nfunctions;
	struct pinctrl_dev___7 *pctrl_dev;
};

struct regmap_config___6 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___139 *, unsigned int);
	bool (*readable_reg)(struct device___139 *, unsigned int);
	bool (*volatile_reg)(struct device___139 *, unsigned int);
	bool (*precious_reg)(struct device___139 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___139 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___139 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct imx_pin_mmio {
	unsigned int mux_mode;
	u16 input_reg;
	unsigned int input_val;
	long unsigned int config;
};

struct imx_pin_scu {
	unsigned int mux_mode;
	long unsigned int config;
};

struct imx_pin {
	unsigned int pin;
	union {
		struct imx_pin_mmio mmio;
		struct imx_pin_scu scu;
	} conf;
};

struct imx_pin_reg {
	s16 mux_reg;
	s16 conf_reg;
};

struct imx_cfg_params_decode {
	enum pin_config_param param;
	u32 mask;
	u8 shift;
	bool invert;
};

struct imx_pinctrl_soc_info;

struct imx_pinctrl {
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctl;
	void *base;
	void *input_sel_base;
	const struct imx_pinctrl_soc_info *info;
	struct imx_pin_reg *pin_regs;
	unsigned int group_index;
	struct mutex mutex;
};

struct imx_pinctrl_soc_info {
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	unsigned int flags;
	const char *gpr_compatible;
	unsigned int mux_mask;
	u8 mux_shift;
	bool generic_pinconf;
	const struct pinconf_generic_params *custom_params;
	unsigned int num_custom_params;
	const struct imx_cfg_params_decode *decodes;
	unsigned int num_decodes;
	void (*fixup)(long unsigned int *, unsigned int, u32 *);
	int (*gpio_set_direction)(struct pinctrl_dev___6 *, struct pinctrl_gpio_range___2 *, unsigned int, bool);
	int (*imx_pinconf_get)(struct pinctrl_dev___6 *, unsigned int, long unsigned int *);
	int (*imx_pinconf_set)(struct pinctrl_dev___6 *, unsigned int, long unsigned int *, unsigned int);
	void (*imx_pinctrl_parse_pin)(struct imx_pinctrl *, unsigned int *, struct imx_pin *, const __be32 **);
};

enum imx_sc_rpc_svc {
	IMX_SC_RPC_SVC_UNKNOWN = 0,
	IMX_SC_RPC_SVC_RETURN = 1,
	IMX_SC_RPC_SVC_PM = 2,
	IMX_SC_RPC_SVC_RM = 3,
	IMX_SC_RPC_SVC_TIMER = 5,
	IMX_SC_RPC_SVC_PAD = 6,
	IMX_SC_RPC_SVC_MISC = 7,
	IMX_SC_RPC_SVC_IRQ = 8,
};

struct imx_sc_rpc_msg {
	uint8_t ver;
	uint8_t size;
	uint8_t svc;
	uint8_t func;
};

enum pad_func_e {
	IMX_SC_PAD_FUNC_SET = 15,
	IMX_SC_PAD_FUNC_GET = 16,
};

struct imx_sc_msg_req_pad_set {
	struct imx_sc_rpc_msg hdr;
	u32 val;
	u16 pad;
};

struct imx_sc_msg_req_pad_get {
	struct imx_sc_rpc_msg hdr;
	u16 pad;
	short: 16;
};

struct imx_sc_msg_resp_pad_get {
	struct imx_sc_rpc_msg hdr;
	u32 val;
};

struct imx_sc_ipc;

struct imx_pinctrl_soc_info___2;

struct imx_pinctrl___2 {
	struct device___145 *dev;
	struct pinctrl_dev___4 *pctl;
	void *base;
	void *input_sel_base;
	const struct imx_pinctrl_soc_info___2 *info;
	struct imx_pin_reg *pin_regs;
	unsigned int group_index;
	struct mutex mutex;
};

struct imx_pinctrl_soc_info___2 {
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	unsigned int flags;
	const char *gpr_compatible;
	unsigned int mux_mask;
	u8 mux_shift;
	bool generic_pinconf;
	const struct pinconf_generic_params *custom_params;
	unsigned int num_custom_params;
	const struct imx_cfg_params_decode *decodes;
	unsigned int num_decodes;
	void (*fixup)(long unsigned int *, unsigned int, u32 *);
	int (*gpio_set_direction)(struct pinctrl_dev___4 *, struct pinctrl_gpio_range___3 *, unsigned int, bool);
	int (*imx_pinconf_get)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *);
	int (*imx_pinconf_set)(struct pinctrl_dev___4 *, unsigned int, long unsigned int *, unsigned int);
	void (*imx_pinctrl_parse_pin)(struct imx_pinctrl___2 *, unsigned int *, struct imx_pin *, const __be32 **);
};

enum imx8mm_pads {
	MX8MM_PAD_RESERVE0 = 0,
	MX8MM_PAD_RESERVE1 = 1,
	MX8MM_PAD_RESERVE2 = 2,
	MX8MM_PAD_RESERVE3 = 3,
	MX8MM_PAD_RESERVE4 = 4,
	MX8MM_PAD_RESERVE5 = 5,
	MX8MM_PAD_RESERVE6 = 6,
	MX8MM_PAD_RESERVE7 = 7,
	MX8MM_PAD_RESERVE8 = 8,
	MX8MM_PAD_RESERVE9 = 9,
	MX8MM_IOMUXC_GPIO1_IO00 = 10,
	MX8MM_IOMUXC_GPIO1_IO01 = 11,
	MX8MM_IOMUXC_GPIO1_IO02 = 12,
	MX8MM_IOMUXC_GPIO1_IO03 = 13,
	MX8MM_IOMUXC_GPIO1_IO04 = 14,
	MX8MM_IOMUXC_GPIO1_IO05 = 15,
	MX8MM_IOMUXC_GPIO1_IO06 = 16,
	MX8MM_IOMUXC_GPIO1_IO07 = 17,
	MX8MM_IOMUXC_GPIO1_IO08 = 18,
	MX8MM_IOMUXC_GPIO1_IO09 = 19,
	MX8MM_IOMUXC_GPIO1_IO10 = 20,
	MX8MM_IOMUXC_GPIO1_IO11 = 21,
	MX8MM_IOMUXC_GPIO1_IO12 = 22,
	MX8MM_IOMUXC_GPIO1_IO13 = 23,
	MX8MM_IOMUXC_GPIO1_IO14 = 24,
	MX8MM_IOMUXC_GPIO1_IO15 = 25,
	MX8MM_IOMUXC_ENET_MDC = 26,
	MX8MM_IOMUXC_ENET_MDIO = 27,
	MX8MM_IOMUXC_ENET_TD3 = 28,
	MX8MM_IOMUXC_ENET_TD2 = 29,
	MX8MM_IOMUXC_ENET_TD1 = 30,
	MX8MM_IOMUXC_ENET_TD0 = 31,
	MX8MM_IOMUXC_ENET_TX_CTL = 32,
	MX8MM_IOMUXC_ENET_TXC = 33,
	MX8MM_IOMUXC_ENET_RX_CTL = 34,
	MX8MM_IOMUXC_ENET_RXC = 35,
	MX8MM_IOMUXC_ENET_RD0 = 36,
	MX8MM_IOMUXC_ENET_RD1 = 37,
	MX8MM_IOMUXC_ENET_RD2 = 38,
	MX8MM_IOMUXC_ENET_RD3 = 39,
	MX8MM_IOMUXC_SD1_CLK = 40,
	MX8MM_IOMUXC_SD1_CMD = 41,
	MX8MM_IOMUXC_SD1_DATA0 = 42,
	MX8MM_IOMUXC_SD1_DATA1 = 43,
	MX8MM_IOMUXC_SD1_DATA2 = 44,
	MX8MM_IOMUXC_SD1_DATA3 = 45,
	MX8MM_IOMUXC_SD1_DATA4 = 46,
	MX8MM_IOMUXC_SD1_DATA5 = 47,
	MX8MM_IOMUXC_SD1_DATA6 = 48,
	MX8MM_IOMUXC_SD1_DATA7 = 49,
	MX8MM_IOMUXC_SD1_RESET_B = 50,
	MX8MM_IOMUXC_SD1_STROBE = 51,
	MX8MM_IOMUXC_SD2_CD_B = 52,
	MX8MM_IOMUXC_SD2_CLK = 53,
	MX8MM_IOMUXC_SD2_CMD = 54,
	MX8MM_IOMUXC_SD2_DATA0 = 55,
	MX8MM_IOMUXC_SD2_DATA1 = 56,
	MX8MM_IOMUXC_SD2_DATA2 = 57,
	MX8MM_IOMUXC_SD2_DATA3 = 58,
	MX8MM_IOMUXC_SD2_RESET_B = 59,
	MX8MM_IOMUXC_SD2_WP = 60,
	MX8MM_IOMUXC_NAND_ALE = 61,
	MX8MM_IOMUXC_NAND_CE0 = 62,
	MX8MM_IOMUXC_NAND_CE1 = 63,
	MX8MM_IOMUXC_NAND_CE2 = 64,
	MX8MM_IOMUXC_NAND_CE3 = 65,
	MX8MM_IOMUXC_NAND_CLE = 66,
	MX8MM_IOMUXC_NAND_DATA00 = 67,
	MX8MM_IOMUXC_NAND_DATA01 = 68,
	MX8MM_IOMUXC_NAND_DATA02 = 69,
	MX8MM_IOMUXC_NAND_DATA03 = 70,
	MX8MM_IOMUXC_NAND_DATA04 = 71,
	MX8MM_IOMUXC_NAND_DATA05 = 72,
	MX8MM_IOMUXC_NAND_DATA06 = 73,
	MX8MM_IOMUXC_NAND_DATA07 = 74,
	MX8MM_IOMUXC_NAND_DQS = 75,
	MX8MM_IOMUXC_NAND_RE_B = 76,
	MX8MM_IOMUXC_NAND_READY_B = 77,
	MX8MM_IOMUXC_NAND_WE_B = 78,
	MX8MM_IOMUXC_NAND_WP_B = 79,
	MX8MM_IOMUXC_SAI5_RXFS = 80,
	MX8MM_IOMUXC_SAI5_RXC = 81,
	MX8MM_IOMUXC_SAI5_RXD0 = 82,
	MX8MM_IOMUXC_SAI5_RXD1 = 83,
	MX8MM_IOMUXC_SAI5_RXD2 = 84,
	MX8MM_IOMUXC_SAI5_RXD3 = 85,
	MX8MM_IOMUXC_SAI5_MCLK = 86,
	MX8MM_IOMUXC_SAI1_RXFS = 87,
	MX8MM_IOMUXC_SAI1_RXC = 88,
	MX8MM_IOMUXC_SAI1_RXD0 = 89,
	MX8MM_IOMUXC_SAI1_RXD1 = 90,
	MX8MM_IOMUXC_SAI1_RXD2 = 91,
	MX8MM_IOMUXC_SAI1_RXD3 = 92,
	MX8MM_IOMUXC_SAI1_RXD4 = 93,
	MX8MM_IOMUXC_SAI1_RXD5 = 94,
	MX8MM_IOMUXC_SAI1_RXD6 = 95,
	MX8MM_IOMUXC_SAI1_RXD7 = 96,
	MX8MM_IOMUXC_SAI1_TXFS = 97,
	MX8MM_IOMUXC_SAI1_TXC = 98,
	MX8MM_IOMUXC_SAI1_TXD0 = 99,
	MX8MM_IOMUXC_SAI1_TXD1 = 100,
	MX8MM_IOMUXC_SAI1_TXD2 = 101,
	MX8MM_IOMUXC_SAI1_TXD3 = 102,
	MX8MM_IOMUXC_SAI1_TXD4 = 103,
	MX8MM_IOMUXC_SAI1_TXD5 = 104,
	MX8MM_IOMUXC_SAI1_TXD6 = 105,
	MX8MM_IOMUXC_SAI1_TXD7 = 106,
	MX8MM_IOMUXC_SAI1_MCLK = 107,
	MX8MM_IOMUXC_SAI2_RXFS = 108,
	MX8MM_IOMUXC_SAI2_RXC = 109,
	MX8MM_IOMUXC_SAI2_RXD0 = 110,
	MX8MM_IOMUXC_SAI2_TXFS = 111,
	MX8MM_IOMUXC_SAI2_TXC = 112,
	MX8MM_IOMUXC_SAI2_TXD0 = 113,
	MX8MM_IOMUXC_SAI2_MCLK = 114,
	MX8MM_IOMUXC_SAI3_RXFS = 115,
	MX8MM_IOMUXC_SAI3_RXC = 116,
	MX8MM_IOMUXC_SAI3_RXD = 117,
	MX8MM_IOMUXC_SAI3_TXFS = 118,
	MX8MM_IOMUXC_SAI3_TXC = 119,
	MX8MM_IOMUXC_SAI3_TXD = 120,
	MX8MM_IOMUXC_SAI3_MCLK = 121,
	MX8MM_IOMUXC_SPDIF_TX = 122,
	MX8MM_IOMUXC_SPDIF_RX = 123,
	MX8MM_IOMUXC_SPDIF_EXT_CLK = 124,
	MX8MM_IOMUXC_ECSPI1_SCLK = 125,
	MX8MM_IOMUXC_ECSPI1_MOSI = 126,
	MX8MM_IOMUXC_ECSPI1_MISO = 127,
	MX8MM_IOMUXC_ECSPI1_SS0 = 128,
	MX8MM_IOMUXC_ECSPI2_SCLK = 129,
	MX8MM_IOMUXC_ECSPI2_MOSI = 130,
	MX8MM_IOMUXC_ECSPI2_MISO = 131,
	MX8MM_IOMUXC_ECSPI2_SS0 = 132,
	MX8MM_IOMUXC_I2C1_SCL = 133,
	MX8MM_IOMUXC_I2C1_SDA = 134,
	MX8MM_IOMUXC_I2C2_SCL = 135,
	MX8MM_IOMUXC_I2C2_SDA = 136,
	MX8MM_IOMUXC_I2C3_SCL = 137,
	MX8MM_IOMUXC_I2C3_SDA = 138,
	MX8MM_IOMUXC_I2C4_SCL = 139,
	MX8MM_IOMUXC_I2C4_SDA = 140,
	MX8MM_IOMUXC_UART1_RXD = 141,
	MX8MM_IOMUXC_UART1_TXD = 142,
	MX8MM_IOMUXC_UART2_RXD = 143,
	MX8MM_IOMUXC_UART2_TXD = 144,
	MX8MM_IOMUXC_UART3_RXD = 145,
	MX8MM_IOMUXC_UART3_TXD = 146,
	MX8MM_IOMUXC_UART4_RXD = 147,
	MX8MM_IOMUXC_UART4_TXD = 148,
};

enum imx8mn_pads {
	MX8MN_PAD_RESERVE0 = 0,
	MX8MN_PAD_RESERVE1 = 1,
	MX8MN_PAD_RESERVE2 = 2,
	MX8MN_PAD_RESERVE3 = 3,
	MX8MN_PAD_RESERVE4 = 4,
	MX8MN_PAD_RESERVE5 = 5,
	MX8MN_PAD_RESERVE6 = 6,
	MX8MN_PAD_RESERVE7 = 7,
	MX8MN_IOMUXC_BOOT_MODE2 = 8,
	MX8MN_IOMUXC_BOOT_MODE3 = 9,
	MX8MN_IOMUXC_GPIO1_IO00 = 10,
	MX8MN_IOMUXC_GPIO1_IO01 = 11,
	MX8MN_IOMUXC_GPIO1_IO02 = 12,
	MX8MN_IOMUXC_GPIO1_IO03 = 13,
	MX8MN_IOMUXC_GPIO1_IO04 = 14,
	MX8MN_IOMUXC_GPIO1_IO05 = 15,
	MX8MN_IOMUXC_GPIO1_IO06 = 16,
	MX8MN_IOMUXC_GPIO1_IO07 = 17,
	MX8MN_IOMUXC_GPIO1_IO08 = 18,
	MX8MN_IOMUXC_GPIO1_IO09 = 19,
	MX8MN_IOMUXC_GPIO1_IO10 = 20,
	MX8MN_IOMUXC_GPIO1_IO11 = 21,
	MX8MN_IOMUXC_GPIO1_IO12 = 22,
	MX8MN_IOMUXC_GPIO1_IO13 = 23,
	MX8MN_IOMUXC_GPIO1_IO14 = 24,
	MX8MN_IOMUXC_GPIO1_IO15 = 25,
	MX8MN_IOMUXC_ENET_MDC = 26,
	MX8MN_IOMUXC_ENET_MDIO = 27,
	MX8MN_IOMUXC_ENET_TD3 = 28,
	MX8MN_IOMUXC_ENET_TD2 = 29,
	MX8MN_IOMUXC_ENET_TD1 = 30,
	MX8MN_IOMUXC_ENET_TD0 = 31,
	MX8MN_IOMUXC_ENET_TX_CTL = 32,
	MX8MN_IOMUXC_ENET_TXC = 33,
	MX8MN_IOMUXC_ENET_RX_CTL = 34,
	MX8MN_IOMUXC_ENET_RXC = 35,
	MX8MN_IOMUXC_ENET_RD0 = 36,
	MX8MN_IOMUXC_ENET_RD1 = 37,
	MX8MN_IOMUXC_ENET_RD2 = 38,
	MX8MN_IOMUXC_ENET_RD3 = 39,
	MX8MN_IOMUXC_SD1_CLK = 40,
	MX8MN_IOMUXC_SD1_CMD = 41,
	MX8MN_IOMUXC_SD1_DATA0 = 42,
	MX8MN_IOMUXC_SD1_DATA1 = 43,
	MX8MN_IOMUXC_SD1_DATA2 = 44,
	MX8MN_IOMUXC_SD1_DATA3 = 45,
	MX8MN_IOMUXC_SD1_DATA4 = 46,
	MX8MN_IOMUXC_SD1_DATA5 = 47,
	MX8MN_IOMUXC_SD1_DATA6 = 48,
	MX8MN_IOMUXC_SD1_DATA7 = 49,
	MX8MN_IOMUXC_SD1_RESET_B = 50,
	MX8MN_IOMUXC_SD1_STROBE = 51,
	MX8MN_IOMUXC_SD2_CD_B = 52,
	MX8MN_IOMUXC_SD2_CLK = 53,
	MX8MN_IOMUXC_SD2_CMD = 54,
	MX8MN_IOMUXC_SD2_DATA0 = 55,
	MX8MN_IOMUXC_SD2_DATA1 = 56,
	MX8MN_IOMUXC_SD2_DATA2 = 57,
	MX8MN_IOMUXC_SD2_DATA3 = 58,
	MX8MN_IOMUXC_SD2_RESET_B = 59,
	MX8MN_IOMUXC_SD2_WP = 60,
	MX8MN_IOMUXC_NAND_ALE = 61,
	MX8MN_IOMUXC_NAND_CE0 = 62,
	MX8MN_IOMUXC_NAND_CE1 = 63,
	MX8MN_IOMUXC_NAND_CE2 = 64,
	MX8MN_IOMUXC_NAND_CE3 = 65,
	MX8MN_IOMUXC_NAND_CLE = 66,
	MX8MN_IOMUXC_NAND_DATA00 = 67,
	MX8MN_IOMUXC_NAND_DATA01 = 68,
	MX8MN_IOMUXC_NAND_DATA02 = 69,
	MX8MN_IOMUXC_NAND_DATA03 = 70,
	MX8MN_IOMUXC_NAND_DATA04 = 71,
	MX8MN_IOMUXC_NAND_DATA05 = 72,
	MX8MN_IOMUXC_NAND_DATA06 = 73,
	MX8MN_IOMUXC_NAND_DATA07 = 74,
	MX8MN_IOMUXC_NAND_DQS = 75,
	MX8MN_IOMUXC_NAND_RE_B = 76,
	MX8MN_IOMUXC_NAND_READY_B = 77,
	MX8MN_IOMUXC_NAND_WE_B = 78,
	MX8MN_IOMUXC_NAND_WP_B = 79,
	MX8MN_IOMUXC_SAI5_RXFS = 80,
	MX8MN_IOMUXC_SAI5_RXC = 81,
	MX8MN_IOMUXC_SAI5_RXD0 = 82,
	MX8MN_IOMUXC_SAI5_RXD1 = 83,
	MX8MN_IOMUXC_SAI5_RXD2 = 84,
	MX8MN_IOMUXC_SAI5_RXD3 = 85,
	MX8MN_IOMUXC_SAI5_MCLK = 86,
	MX8MN_IOMUXC_SAI1_RXFS = 87,
	MX8MN_IOMUXC_SAI1_RXC = 88,
	MX8MN_IOMUXC_SAI1_RXD0 = 89,
	MX8MN_IOMUXC_SAI1_RXD1 = 90,
	MX8MN_IOMUXC_SAI1_RXD2 = 91,
	MX8MN_IOMUXC_SAI1_RXD3 = 92,
	MX8MN_IOMUXC_SAI1_RXD4 = 93,
	MX8MN_IOMUXC_SAI1_RXD5 = 94,
	MX8MN_IOMUXC_SAI1_RXD6 = 95,
	MX8MN_IOMUXC_SAI1_RXD7 = 96,
	MX8MN_IOMUXC_SAI1_TXFS = 97,
	MX8MN_IOMUXC_SAI1_TXC = 98,
	MX8MN_IOMUXC_SAI1_TXD0 = 99,
	MX8MN_IOMUXC_SAI1_TXD1 = 100,
	MX8MN_IOMUXC_SAI1_TXD2 = 101,
	MX8MN_IOMUXC_SAI1_TXD3 = 102,
	MX8MN_IOMUXC_SAI1_TXD4 = 103,
	MX8MN_IOMUXC_SAI1_TXD5 = 104,
	MX8MN_IOMUXC_SAI1_TXD6 = 105,
	MX8MN_IOMUXC_SAI1_TXD7 = 106,
	MX8MN_IOMUXC_SAI1_MCLK = 107,
	MX8MN_IOMUXC_SAI2_RXFS = 108,
	MX8MN_IOMUXC_SAI2_RXC = 109,
	MX8MN_IOMUXC_SAI2_RXD0 = 110,
	MX8MN_IOMUXC_SAI2_TXFS = 111,
	MX8MN_IOMUXC_SAI2_TXC = 112,
	MX8MN_IOMUXC_SAI2_TXD0 = 113,
	MX8MN_IOMUXC_SAI2_MCLK = 114,
	MX8MN_IOMUXC_SAI3_RXFS = 115,
	MX8MN_IOMUXC_SAI3_RXC = 116,
	MX8MN_IOMUXC_SAI3_RXD = 117,
	MX8MN_IOMUXC_SAI3_TXFS = 118,
	MX8MN_IOMUXC_SAI3_TXC = 119,
	MX8MN_IOMUXC_SAI3_TXD = 120,
	MX8MN_IOMUXC_SAI3_MCLK = 121,
	MX8MN_IOMUXC_SPDIF_TX = 122,
	MX8MN_IOMUXC_SPDIF_RX = 123,
	MX8MN_IOMUXC_SPDIF_EXT_CLK = 124,
	MX8MN_IOMUXC_ECSPI1_SCLK = 125,
	MX8MN_IOMUXC_ECSPI1_MOSI = 126,
	MX8MN_IOMUXC_ECSPI1_MISO = 127,
	MX8MN_IOMUXC_ECSPI1_SS0 = 128,
	MX8MN_IOMUXC_ECSPI2_SCLK = 129,
	MX8MN_IOMUXC_ECSPI2_MOSI = 130,
	MX8MN_IOMUXC_ECSPI2_MISO = 131,
	MX8MN_IOMUXC_ECSPI2_SS0 = 132,
	MX8MN_IOMUXC_I2C1_SCL = 133,
	MX8MN_IOMUXC_I2C1_SDA = 134,
	MX8MN_IOMUXC_I2C2_SCL = 135,
	MX8MN_IOMUXC_I2C2_SDA = 136,
	MX8MN_IOMUXC_I2C3_SCL = 137,
	MX8MN_IOMUXC_I2C3_SDA = 138,
	MX8MN_IOMUXC_I2C4_SCL = 139,
	MX8MN_IOMUXC_I2C4_SDA = 140,
	MX8MN_IOMUXC_UART1_RXD = 141,
	MX8MN_IOMUXC_UART1_TXD = 142,
	MX8MN_IOMUXC_UART2_RXD = 143,
	MX8MN_IOMUXC_UART2_TXD = 144,
	MX8MN_IOMUXC_UART3_RXD = 145,
	MX8MN_IOMUXC_UART3_TXD = 146,
	MX8MN_IOMUXC_UART4_RXD = 147,
	MX8MN_IOMUXC_UART4_TXD = 148,
};

enum imx8mp_pads {
	MX8MP_IOMUXC_RESERVE0 = 0,
	MX8MP_IOMUXC_RESERVE1 = 1,
	MX8MP_IOMUXC_RESERVE2 = 2,
	MX8MP_IOMUXC_RESERVE3 = 3,
	MX8MP_IOMUXC_RESERVE4 = 4,
	MX8MP_IOMUXC_GPIO1_IO00 = 5,
	MX8MP_IOMUXC_GPIO1_IO01 = 6,
	MX8MP_IOMUXC_GPIO1_IO02 = 7,
	MX8MP_IOMUXC_GPIO1_IO03 = 8,
	MX8MP_IOMUXC_GPIO1_IO04 = 9,
	MX8MP_IOMUXC_GPIO1_IO05 = 10,
	MX8MP_IOMUXC_GPIO1_IO06 = 11,
	MX8MP_IOMUXC_GPIO1_IO07 = 12,
	MX8MP_IOMUXC_GPIO1_IO08 = 13,
	MX8MP_IOMUXC_GPIO1_IO09 = 14,
	MX8MP_IOMUXC_GPIO1_IO10 = 15,
	MX8MP_IOMUXC_GPIO1_IO11 = 16,
	MX8MP_IOMUXC_GPIO1_IO12 = 17,
	MX8MP_IOMUXC_GPIO1_IO13 = 18,
	MX8MP_IOMUXC_GPIO1_IO14 = 19,
	MX8MP_IOMUXC_GPIO1_IO15 = 20,
	MX8MP_IOMUXC_ENET_MDC = 21,
	MX8MP_IOMUXC_ENET_MDIO = 22,
	MX8MP_IOMUXC_ENET_TD3 = 23,
	MX8MP_IOMUXC_ENET_TD2 = 24,
	MX8MP_IOMUXC_ENET_TD1 = 25,
	MX8MP_IOMUXC_ENET_TD0 = 26,
	MX8MP_IOMUXC_ENET_TX_CTL = 27,
	MX8MP_IOMUXC_ENET_TXC = 28,
	MX8MP_IOMUXC_ENET_RX_CTL = 29,
	MX8MP_IOMUXC_ENET_RXC = 30,
	MX8MP_IOMUXC_ENET_RD0 = 31,
	MX8MP_IOMUXC_ENET_RD1 = 32,
	MX8MP_IOMUXC_ENET_RD2 = 33,
	MX8MP_IOMUXC_ENET_RD3 = 34,
	MX8MP_IOMUXC_SD1_CLK = 35,
	MX8MP_IOMUXC_SD1_CMD = 36,
	MX8MP_IOMUXC_SD1_DATA0 = 37,
	MX8MP_IOMUXC_SD1_DATA1 = 38,
	MX8MP_IOMUXC_SD1_DATA2 = 39,
	MX8MP_IOMUXC_SD1_DATA3 = 40,
	MX8MP_IOMUXC_SD1_DATA4 = 41,
	MX8MP_IOMUXC_SD1_DATA5 = 42,
	MX8MP_IOMUXC_SD1_DATA6 = 43,
	MX8MP_IOMUXC_SD1_DATA7 = 44,
	MX8MP_IOMUXC_SD1_RESET_B = 45,
	MX8MP_IOMUXC_SD1_STROBE = 46,
	MX8MP_IOMUXC_SD2_CD_B = 47,
	MX8MP_IOMUXC_SD2_CLK = 48,
	MX8MP_IOMUXC_SD2_CMD = 49,
	MX8MP_IOMUXC_SD2_DATA0 = 50,
	MX8MP_IOMUXC_SD2_DATA1 = 51,
	MX8MP_IOMUXC_SD2_DATA2 = 52,
	MX8MP_IOMUXC_SD2_DATA3 = 53,
	MX8MP_IOMUXC_SD2_RESET_B = 54,
	MX8MP_IOMUXC_SD2_WP = 55,
	MX8MP_IOMUXC_NAND_ALE = 56,
	MX8MP_IOMUXC_NAND_CE0_B = 57,
	MX8MP_IOMUXC_NAND_CE1_B = 58,
	MX8MP_IOMUXC_NAND_CE2_B = 59,
	MX8MP_IOMUXC_NAND_CE3_B = 60,
	MX8MP_IOMUXC_NAND_CLE = 61,
	MX8MP_IOMUXC_NAND_DATA00 = 62,
	MX8MP_IOMUXC_NAND_DATA01 = 63,
	MX8MP_IOMUXC_NAND_DATA02 = 64,
	MX8MP_IOMUXC_NAND_DATA03 = 65,
	MX8MP_IOMUXC_NAND_DATA04 = 66,
	MX8MP_IOMUXC_NAND_DATA05 = 67,
	MX8MP_IOMUXC_NAND_DATA06 = 68,
	MX8MP_IOMUXC_NAND_DATA07 = 69,
	MX8MP_IOMUXC_NAND_DQS = 70,
	MX8MP_IOMUXC_NAND_RE_B = 71,
	MX8MP_IOMUXC_NAND_READY_B = 72,
	MX8MP_IOMUXC_NAND_WE_B = 73,
	MX8MP_IOMUXC_NAND_WP_B = 74,
	MX8MP_IOMUXC_SAI5_RXFS = 75,
	MX8MP_IOMUXC_SAI5_RXC = 76,
	MX8MP_IOMUXC_SAI5_RXD0 = 77,
	MX8MP_IOMUXC_SAI5_RXD1 = 78,
	MX8MP_IOMUXC_SAI5_RXD2 = 79,
	MX8MP_IOMUXC_SAI5_RXD3 = 80,
	MX8MP_IOMUXC_SAI5_MCLK = 81,
	MX8MP_IOMUXC_SAI1_RXFS = 82,
	MX8MP_IOMUXC_SAI1_RXC = 83,
	MX8MP_IOMUXC_SAI1_RXD0 = 84,
	MX8MP_IOMUXC_SAI1_RXD1 = 85,
	MX8MP_IOMUXC_SAI1_RXD2 = 86,
	MX8MP_IOMUXC_SAI1_RXD3 = 87,
	MX8MP_IOMUXC_SAI1_RXD4 = 88,
	MX8MP_IOMUXC_SAI1_RXD5 = 89,
	MX8MP_IOMUXC_SAI1_RXD6 = 90,
	MX8MP_IOMUXC_SAI1_RXD7 = 91,
	MX8MP_IOMUXC_SAI1_TXFS = 92,
	MX8MP_IOMUXC_SAI1_TXC = 93,
	MX8MP_IOMUXC_SAI1_TXD0 = 94,
	MX8MP_IOMUXC_SAI1_TXD1 = 95,
	MX8MP_IOMUXC_SAI1_TXD2 = 96,
	MX8MP_IOMUXC_SAI1_TXD3 = 97,
	MX8MP_IOMUXC_SAI1_TXD4 = 98,
	MX8MP_IOMUXC_SAI1_TXD5 = 99,
	MX8MP_IOMUXC_SAI1_TXD6 = 100,
	MX8MP_IOMUXC_SAI1_TXD7 = 101,
	MX8MP_IOMUXC_SAI1_MCLK = 102,
	MX8MP_IOMUXC_SAI2_RXFS = 103,
	MX8MP_IOMUXC_SAI2_RXC = 104,
	MX8MP_IOMUXC_SAI2_RXD0 = 105,
	MX8MP_IOMUXC_SAI2_TXFS = 106,
	MX8MP_IOMUXC_SAI2_TXC = 107,
	MX8MP_IOMUXC_SAI2_TXD0 = 108,
	MX8MP_IOMUXC_SAI2_MCLK = 109,
	MX8MP_IOMUXC_SAI3_RXFS = 110,
	MX8MP_IOMUXC_SAI3_RXC = 111,
	MX8MP_IOMUXC_SAI3_RXD = 112,
	MX8MP_IOMUXC_SAI3_TXFS = 113,
	MX8MP_IOMUXC_SAI3_TXC = 114,
	MX8MP_IOMUXC_SAI3_TXD = 115,
	MX8MP_IOMUXC_SAI3_MCLK = 116,
	MX8MP_IOMUXC_SPDIF_TX = 117,
	MX8MP_IOMUXC_SPDIF_RX = 118,
	MX8MP_IOMUXC_SPDIF_EXT_CLK = 119,
	MX8MP_IOMUXC_ECSPI1_SCLK = 120,
	MX8MP_IOMUXC_ECSPI1_MOSI = 121,
	MX8MP_IOMUXC_ECSPI1_MISO = 122,
	MX8MP_IOMUXC_ECSPI1_SS0 = 123,
	MX8MP_IOMUXC_ECSPI2_SCLK = 124,
	MX8MP_IOMUXC_ECSPI2_MOSI = 125,
	MX8MP_IOMUXC_ECSPI2_MISO = 126,
	MX8MP_IOMUXC_ECSPI2_SS0 = 127,
	MX8MP_IOMUXC_I2C1_SCL = 128,
	MX8MP_IOMUXC_I2C1_SDA = 129,
	MX8MP_IOMUXC_I2C2_SCL = 130,
	MX8MP_IOMUXC_I2C2_SDA = 131,
	MX8MP_IOMUXC_I2C3_SCL = 132,
	MX8MP_IOMUXC_I2C3_SDA = 133,
	MX8MP_IOMUXC_I2C4_SCL = 134,
	MX8MP_IOMUXC_I2C4_SDA = 135,
	MX8MP_IOMUXC_UART1_RXD = 136,
	MX8MP_IOMUXC_UART1_TXD = 137,
	MX8MP_IOMUXC_UART2_RXD = 138,
	MX8MP_IOMUXC_UART2_TXD = 139,
	MX8MP_IOMUXC_UART3_RXD = 140,
	MX8MP_IOMUXC_UART3_TXD = 141,
	MX8MP_IOMUXC_UART4_RXD = 142,
	MX8MP_IOMUXC_UART4_TXD = 143,
	MX8MP_IOMUXC_HDMI_DDC_SCL = 144,
	MX8MP_IOMUXC_HDMI_DDC_SDA = 145,
	MX8MP_IOMUXC_HDMI_CEC = 146,
	MX8MP_IOMUXC_HDMI_HPD = 147,
};

enum imx8mq_pads {
	MX8MQ_PAD_RESERVE0 = 0,
	MX8MQ_PAD_RESERVE1 = 1,
	MX8MQ_PAD_RESERVE2 = 2,
	MX8MQ_PAD_RESERVE3 = 3,
	MX8MQ_PAD_RESERVE4 = 4,
	MX8MQ_IOMUXC_PMIC_STBY_REQ_CCMSRCGPCMIX = 5,
	MX8MQ_IOMUXC_PMIC_ON_REQ_SNVSMIX = 6,
	MX8MQ_IOMUXC_ONOFF_SNVSMIX = 7,
	MX8MQ_IOMUXC_POR_B_SNVSMIX = 8,
	MX8MQ_IOMUXC_RTC_RESET_B_SNVSMIX = 9,
	MX8MQ_IOMUXC_GPIO1_IO00 = 10,
	MX8MQ_IOMUXC_GPIO1_IO01 = 11,
	MX8MQ_IOMUXC_GPIO1_IO02 = 12,
	MX8MQ_IOMUXC_GPIO1_IO03 = 13,
	MX8MQ_IOMUXC_GPIO1_IO04 = 14,
	MX8MQ_IOMUXC_GPIO1_IO05 = 15,
	MX8MQ_IOMUXC_GPIO1_IO06 = 16,
	MX8MQ_IOMUXC_GPIO1_IO07 = 17,
	MX8MQ_IOMUXC_GPIO1_IO08 = 18,
	MX8MQ_IOMUXC_GPIO1_IO09 = 19,
	MX8MQ_IOMUXC_GPIO1_IO10 = 20,
	MX8MQ_IOMUXC_GPIO1_IO11 = 21,
	MX8MQ_IOMUXC_GPIO1_IO12 = 22,
	MX8MQ_IOMUXC_GPIO1_IO13 = 23,
	MX8MQ_IOMUXC_GPIO1_IO14 = 24,
	MX8MQ_IOMUXC_GPIO1_IO15 = 25,
	MX8MQ_IOMUXC_ENET_MDC = 26,
	MX8MQ_IOMUXC_ENET_MDIO = 27,
	MX8MQ_IOMUXC_ENET_TD3 = 28,
	MX8MQ_IOMUXC_ENET_TD2 = 29,
	MX8MQ_IOMUXC_ENET_TD1 = 30,
	MX8MQ_IOMUXC_ENET_TD0 = 31,
	MX8MQ_IOMUXC_ENET_TX_CTL = 32,
	MX8MQ_IOMUXC_ENET_TXC = 33,
	MX8MQ_IOMUXC_ENET_RX_CTL = 34,
	MX8MQ_IOMUXC_ENET_RXC = 35,
	MX8MQ_IOMUXC_ENET_RD0 = 36,
	MX8MQ_IOMUXC_ENET_RD1 = 37,
	MX8MQ_IOMUXC_ENET_RD2 = 38,
	MX8MQ_IOMUXC_ENET_RD3 = 39,
	MX8MQ_IOMUXC_SD1_CLK = 40,
	MX8MQ_IOMUXC_SD1_CMD = 41,
	MX8MQ_IOMUXC_SD1_DATA0 = 42,
	MX8MQ_IOMUXC_SD1_DATA1 = 43,
	MX8MQ_IOMUXC_SD1_DATA2 = 44,
	MX8MQ_IOMUXC_SD1_DATA3 = 45,
	MX8MQ_IOMUXC_SD1_DATA4 = 46,
	MX8MQ_IOMUXC_SD1_DATA5 = 47,
	MX8MQ_IOMUXC_SD1_DATA6 = 48,
	MX8MQ_IOMUXC_SD1_DATA7 = 49,
	MX8MQ_IOMUXC_SD1_RESET_B = 50,
	MX8MQ_IOMUXC_SD1_STROBE = 51,
	MX8MQ_IOMUXC_SD2_CD_B = 52,
	MX8MQ_IOMUXC_SD2_CLK = 53,
	MX8MQ_IOMUXC_SD2_CMD = 54,
	MX8MQ_IOMUXC_SD2_DATA0 = 55,
	MX8MQ_IOMUXC_SD2_DATA1 = 56,
	MX8MQ_IOMUXC_SD2_DATA2 = 57,
	MX8MQ_IOMUXC_SD2_DATA3 = 58,
	MX8MQ_IOMUXC_SD2_RESET_B = 59,
	MX8MQ_IOMUXC_SD2_WP = 60,
	MX8MQ_IOMUXC_NAND_ALE = 61,
	MX8MQ_IOMUXC_NAND_CE0_B = 62,
	MX8MQ_IOMUXC_NAND_CE1_B = 63,
	MX8MQ_IOMUXC_NAND_CE2_B = 64,
	MX8MQ_IOMUXC_NAND_CE3_B = 65,
	MX8MQ_IOMUXC_NAND_CLE = 66,
	MX8MQ_IOMUXC_NAND_DATA00 = 67,
	MX8MQ_IOMUXC_NAND_DATA01 = 68,
	MX8MQ_IOMUXC_NAND_DATA02 = 69,
	MX8MQ_IOMUXC_NAND_DATA03 = 70,
	MX8MQ_IOMUXC_NAND_DATA04 = 71,
	MX8MQ_IOMUXC_NAND_DATA05 = 72,
	MX8MQ_IOMUXC_NAND_DATA06 = 73,
	MX8MQ_IOMUXC_NAND_DATA07 = 74,
	MX8MQ_IOMUXC_NAND_DQS = 75,
	MX8MQ_IOMUXC_NAND_RE_B = 76,
	MX8MQ_IOMUXC_NAND_READY_B = 77,
	MX8MQ_IOMUXC_NAND_WE_B = 78,
	MX8MQ_IOMUXC_NAND_WP_B = 79,
	MX8MQ_IOMUXC_SAI5_RXFS = 80,
	MX8MQ_IOMUXC_SAI5_RXC = 81,
	MX8MQ_IOMUXC_SAI5_RXD0 = 82,
	MX8MQ_IOMUXC_SAI5_RXD1 = 83,
	MX8MQ_IOMUXC_SAI5_RXD2 = 84,
	MX8MQ_IOMUXC_SAI5_RXD3 = 85,
	MX8MQ_IOMUXC_SAI5_MCLK = 86,
	MX8MQ_IOMUXC_SAI1_RXFS = 87,
	MX8MQ_IOMUXC_SAI1_RXC = 88,
	MX8MQ_IOMUXC_SAI1_RXD0 = 89,
	MX8MQ_IOMUXC_SAI1_RXD1 = 90,
	MX8MQ_IOMUXC_SAI1_RXD2 = 91,
	MX8MQ_IOMUXC_SAI1_RXD3 = 92,
	MX8MQ_IOMUXC_SAI1_RXD4 = 93,
	MX8MQ_IOMUXC_SAI1_RXD5 = 94,
	MX8MQ_IOMUXC_SAI1_RXD6 = 95,
	MX8MQ_IOMUXC_SAI1_RXD7 = 96,
	MX8MQ_IOMUXC_SAI1_TXFS = 97,
	MX8MQ_IOMUXC_SAI1_TXC = 98,
	MX8MQ_IOMUXC_SAI1_TXD0 = 99,
	MX8MQ_IOMUXC_SAI1_TXD1 = 100,
	MX8MQ_IOMUXC_SAI1_TXD2 = 101,
	MX8MQ_IOMUXC_SAI1_TXD3 = 102,
	MX8MQ_IOMUXC_SAI1_TXD4 = 103,
	MX8MQ_IOMUXC_SAI1_TXD5 = 104,
	MX8MQ_IOMUXC_SAI1_TXD6 = 105,
	MX8MQ_IOMUXC_SAI1_TXD7 = 106,
	MX8MQ_IOMUXC_SAI1_MCLK = 107,
	MX8MQ_IOMUXC_SAI2_RXFS = 108,
	MX8MQ_IOMUXC_SAI2_RXC = 109,
	MX8MQ_IOMUXC_SAI2_RXD0 = 110,
	MX8MQ_IOMUXC_SAI2_TXFS = 111,
	MX8MQ_IOMUXC_SAI2_TXC = 112,
	MX8MQ_IOMUXC_SAI2_TXD0 = 113,
	MX8MQ_IOMUXC_SAI2_MCLK = 114,
	MX8MQ_IOMUXC_SAI3_RXFS = 115,
	MX8MQ_IOMUXC_SAI3_RXC = 116,
	MX8MQ_IOMUXC_SAI3_RXD = 117,
	MX8MQ_IOMUXC_SAI3_TXFS = 118,
	MX8MQ_IOMUXC_SAI3_TXC = 119,
	MX8MQ_IOMUXC_SAI3_TXD = 120,
	MX8MQ_IOMUXC_SAI3_MCLK = 121,
	MX8MQ_IOMUXC_SPDIF_TX = 122,
	MX8MQ_IOMUXC_SPDIF_RX = 123,
	MX8MQ_IOMUXC_SPDIF_EXT_CLK = 124,
	MX8MQ_IOMUXC_ECSPI1_SCLK = 125,
	MX8MQ_IOMUXC_ECSPI1_MOSI = 126,
	MX8MQ_IOMUXC_ECSPI1_MISO = 127,
	MX8MQ_IOMUXC_ECSPI1_SS0 = 128,
	MX8MQ_IOMUXC_ECSPI2_SCLK = 129,
	MX8MQ_IOMUXC_ECSPI2_MOSI = 130,
	MX8MQ_IOMUXC_ECSPI2_MISO = 131,
	MX8MQ_IOMUXC_ECSPI2_SS0 = 132,
	MX8MQ_IOMUXC_I2C1_SCL = 133,
	MX8MQ_IOMUXC_I2C1_SDA = 134,
	MX8MQ_IOMUXC_I2C2_SCL = 135,
	MX8MQ_IOMUXC_I2C2_SDA = 136,
	MX8MQ_IOMUXC_I2C3_SCL = 137,
	MX8MQ_IOMUXC_I2C3_SDA = 138,
	MX8MQ_IOMUXC_I2C4_SCL = 139,
	MX8MQ_IOMUXC_I2C4_SDA = 140,
	MX8MQ_IOMUXC_UART1_RXD = 141,
	MX8MQ_IOMUXC_UART1_TXD = 142,
	MX8MQ_IOMUXC_UART2_RXD = 143,
	MX8MQ_IOMUXC_UART2_TXD = 144,
	MX8MQ_IOMUXC_UART3_RXD = 145,
	MX8MQ_IOMUXC_UART3_TXD = 146,
	MX8MQ_IOMUXC_UART4_RXD = 147,
	MX8MQ_IOMUXC_UART4_TXD = 148,
};

struct mvebu_mpp_ctrl_data {
	union {
		void *base;
		struct {
			struct regmap *map;
			u32 offset;
		} regmap;
	};
};

struct mvebu_mpp_ctrl {
	const char *name;
	u8 pid;
	u8 npins;
	unsigned int *pins;
	int (*mpp_get)(struct mvebu_mpp_ctrl_data *, unsigned int, long unsigned int *);
	int (*mpp_set)(struct mvebu_mpp_ctrl_data *, unsigned int, long unsigned int);
	int (*mpp_gpio_req)(struct mvebu_mpp_ctrl_data *, unsigned int);
	int (*mpp_gpio_dir)(struct mvebu_mpp_ctrl_data *, unsigned int, bool);
};

struct mvebu_mpp_ctrl_setting {
	u8 val;
	const char *name;
	const char *subname;
	u8 variant;
	u8 flags;
};

struct mvebu_mpp_mode {
	u8 pid;
	struct mvebu_mpp_ctrl_setting *settings;
};

struct mvebu_pinctrl_soc_info {
	u8 variant;
	const struct mvebu_mpp_ctrl *controls;
	struct mvebu_mpp_ctrl_data *control_data;
	int ncontrols;
	struct mvebu_mpp_mode *modes;
	int nmodes;
	struct pinctrl_gpio_range___3 *gpioranges;
	int ngpioranges;
};

struct mvebu_pinctrl_function {
	const char *name;
	const char **groups;
	unsigned int num_groups;
};

struct mvebu_pinctrl_group {
	const char *name;
	const struct mvebu_mpp_ctrl *ctrl;
	struct mvebu_mpp_ctrl_data *data;
	struct mvebu_mpp_ctrl_setting *settings;
	unsigned int num_settings;
	unsigned int gid;
	unsigned int *pins;
	unsigned int npins;
};

struct mvebu_pinctrl {
	struct device___145 *dev;
	struct pinctrl_dev___4 *pctldev;
	struct pinctrl_desc___8 desc;
	struct mvebu_pinctrl_group *groups;
	unsigned int num_groups;
	struct mvebu_pinctrl_function *functions;
	unsigned int num_functions;
	u8 variant;
};

enum {
	V_ARMADA_7K = 1,
	V_ARMADA_8K_CPM = 2,
	V_ARMADA_8K_CPS = 4,
	V_CP115_STANDALONE = 8,
	V_ARMADA_7K_8K_CPM = 3,
	V_ARMADA_7K_8K_CPS = 5,
};

struct armada_37xx_pin_group {
	const char *name;
	unsigned int start_pin;
	unsigned int npins;
	u32 reg_mask;
	u32 val[3];
	unsigned int extra_pin;
	unsigned int extra_npins;
	const char *funcs[3];
	unsigned int *pins;
};

struct armada_37xx_pin_data {
	u8 nr_pins;
	char *name;
	struct armada_37xx_pin_group *groups;
	int ngroups;
};

struct armada_37xx_pmx_func {
	const char *name;
	const char **groups;
	unsigned int ngroups;
};

struct armada_37xx_pm_state {
	u32 out_en_l;
	u32 out_en_h;
	u32 out_val_l;
	u32 out_val_h;
	u32 irq_en_l;
	u32 irq_en_h;
	u32 irq_pol_l;
	u32 irq_pol_h;
	u32 selection;
};

struct armada_37xx_pinctrl {
	struct regmap *regmap;
	void *base;
	const struct armada_37xx_pin_data *data;
	struct device___144 *dev;
	struct gpio_chip___4 gpio_chip;
	struct irq_chip___26 irq_chip;
	spinlock_t irq_lock;
	struct pinctrl_desc___7 pctl;
	struct pinctrl_dev___4 *pctl_dev;
	struct armada_37xx_pin_group *groups;
	unsigned int ngroups;
	struct armada_37xx_pmx_func *funcs;
	unsigned int nfuncs;
	struct armada_37xx_pm_state pm;
};

struct msm_function {
	const char *name;
	const char * const *groups;
	unsigned int ngroups;
};

struct msm_pingroup {
	const char *name;
	const unsigned int *pins;
	unsigned int npins;
	unsigned int *funcs;
	unsigned int nfuncs;
	u32 ctl_reg;
	u32 io_reg;
	u32 intr_cfg_reg;
	u32 intr_status_reg;
	u32 intr_target_reg;
	unsigned int tile: 2;
	unsigned int mux_bit: 5;
	unsigned int pull_bit: 5;
	unsigned int drv_bit: 5;
	unsigned int od_bit: 5;
	unsigned int oe_bit: 5;
	unsigned int in_bit: 5;
	unsigned int out_bit: 5;
	unsigned int intr_enable_bit: 5;
	unsigned int intr_status_bit: 5;
	unsigned int intr_ack_high: 1;
	unsigned int intr_target_bit: 5;
	unsigned int intr_target_kpss_val: 5;
	unsigned int intr_raw_status_bit: 5;
	unsigned int intr_polarity_bit: 5;
	unsigned int intr_detection_bit: 5;
	unsigned int intr_detection_width: 5;
	long: 59;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msm_gpio_wakeirq_map {
	unsigned int gpio;
	unsigned int wakeirq;
};

struct msm_pinctrl_soc_data {
	const struct pinctrl_pin_desc *pins;
	unsigned int npins;
	const struct msm_function *functions;
	unsigned int nfunctions;
	const struct msm_pingroup *groups;
	unsigned int ngroups;
	unsigned int ngpios;
	bool pull_no_keeper;
	const char * const *tiles;
	unsigned int ntiles;
	const int *reserved_gpios;
	const struct msm_gpio_wakeirq_map *wakeirq_map;
	unsigned int nwakeirq_map;
	bool wakeirq_dual_edge_errata;
	unsigned int gpio_func;
};

struct msm_pinctrl {
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctrl;
	struct gpio_chip___4 chip;
	struct pinctrl_desc___7 desc;
	struct notifier_block restart_nb;
	struct irq_chip___26 irq_chip;
	int irq;
	bool intr_target_use_scm;
	raw_spinlock_t lock;
	long unsigned int dual_edge_irqs[5];
	long unsigned int enabled_irqs[5];
	long unsigned int skip_wake_irqs[5];
	long unsigned int disabled_for_mux[5];
	const struct msm_pinctrl_soc_data *soc;
	void *regs[4];
	u32 phys_base[4];
};

struct platform_device___15 {
	const char *name;
	int id;
	bool id_auto;
	struct device___39 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___14 {
	int (*probe)(struct platform_device___15 *);
	int (*remove)(struct platform_device___15 *);
	void (*shutdown)(struct platform_device___15 *);
	int (*suspend)(struct platform_device___15 *, pm_message_t);
	int (*resume)(struct platform_device___15 *);
	struct device_driver___39 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct soc_device_attribute {
	const char *machine;
	const char *family;
	const char *revision;
	const char *serial_number;
	const char *soc_id;
	const void *data;
	const struct attribute_group___42 *custom_attr_group;
};

enum {
	PINMUX_TYPE_NONE = 0,
	PINMUX_TYPE_FUNCTION = 1,
	PINMUX_TYPE_GPIO = 2,
	PINMUX_TYPE_OUTPUT = 3,
	PINMUX_TYPE_INPUT = 4,
};

struct sh_pfc_pin {
	const char *name;
	unsigned int configs;
	u16 pin;
	u16 enum_id;
};

struct sh_pfc_pin_group {
	const char *name;
	const unsigned int *pins;
	const unsigned int *mux;
	unsigned int nr_pins;
};

struct sh_pfc_function {
	const char *name;
	const char * const *groups;
	unsigned int nr_groups;
};

struct pinmux_cfg_reg {
	u32 reg;
	u8 reg_width;
	u8 field_width;
	const u16 *enum_ids;
	const u8 *var_field_width;
};

struct pinmux_drive_reg_field {
	u16 pin;
	u8 offset;
	u8 size;
};

struct pinmux_drive_reg {
	u32 reg;
	const struct pinmux_drive_reg_field fields[8];
};

struct pinmux_bias_reg {
	u32 puen;
	u32 pud;
	const u16 pins[32];
};

struct pinmux_ioctrl_reg {
	u32 reg;
};

struct pinmux_data_reg {
	u32 reg;
	u8 reg_width;
	const u16 *enum_ids;
};

struct pinmux_range {
	u16 begin;
	u16 end;
	u16 force;
};

struct sh_pfc_window {
	phys_addr_t phys;
	void *virt;
	long unsigned int size;
};

struct sh_pfc_chip;

struct sh_pfc_soc_info;

struct sh_pfc_pin_range;

struct sh_pfc {
	struct device___39 *dev;
	const struct sh_pfc_soc_info *info;
	spinlock_t lock;
	unsigned int num_windows;
	struct sh_pfc_window *windows;
	unsigned int num_irqs;
	unsigned int *irqs;
	struct sh_pfc_pin_range *ranges;
	unsigned int nr_ranges;
	unsigned int nr_gpio_pins;
	struct sh_pfc_chip *gpio;
	u32 *saved_regs;
};

struct sh_pfc_soc_operations;

struct sh_pfc_soc_info {
	const char *name;
	const struct sh_pfc_soc_operations *ops;
	struct pinmux_range function;
	const struct sh_pfc_pin *pins;
	unsigned int nr_pins;
	const struct sh_pfc_pin_group *groups;
	unsigned int nr_groups;
	const struct sh_pfc_function *functions;
	unsigned int nr_functions;
	const struct pinmux_cfg_reg *cfg_regs;
	const struct pinmux_drive_reg *drive_regs;
	const struct pinmux_bias_reg *bias_regs;
	const struct pinmux_ioctrl_reg *ioctrl_regs;
	const struct pinmux_data_reg *data_regs;
	const u16 *pinmux_data;
	unsigned int pinmux_data_size;
	u32 unlock_reg;
};

struct sh_pfc_pin_range {
	u16 start;
	u16 end;
};

struct sh_pfc_soc_operations {
	int (*init)(struct sh_pfc *);
	unsigned int (*get_bias)(struct sh_pfc *, unsigned int);
	void (*set_bias)(struct sh_pfc *, unsigned int, unsigned int);
	int (*pin_to_pocctrl)(struct sh_pfc *, unsigned int, u32 *);
	void * (*pin_to_portcr)(struct sh_pfc *, unsigned int);
};

struct sh_pfc_soc_info___2;

struct sh_pfc___2 {
	struct device___144 *dev;
	const struct sh_pfc_soc_info___2 *info;
	spinlock_t lock;
	unsigned int num_windows;
	struct sh_pfc_window *windows;
	unsigned int num_irqs;
	unsigned int *irqs;
	struct sh_pfc_pin_range *ranges;
	unsigned int nr_ranges;
	unsigned int nr_gpio_pins;
	struct sh_pfc_chip *gpio;
	u32 *saved_regs;
};

struct sh_pfc_soc_operations___2;

struct sh_pfc_soc_info___2 {
	const char *name;
	const struct sh_pfc_soc_operations___2 *ops;
	struct pinmux_range function;
	const struct sh_pfc_pin *pins;
	unsigned int nr_pins;
	const struct sh_pfc_pin_group *groups;
	unsigned int nr_groups;
	const struct sh_pfc_function *functions;
	unsigned int nr_functions;
	const struct pinmux_cfg_reg *cfg_regs;
	const struct pinmux_drive_reg *drive_regs;
	const struct pinmux_bias_reg *bias_regs;
	const struct pinmux_ioctrl_reg *ioctrl_regs;
	const struct pinmux_data_reg *data_regs;
	const u16 *pinmux_data;
	unsigned int pinmux_data_size;
	u32 unlock_reg;
};

struct sh_pfc_soc_operations___2 {
	int (*init)(struct sh_pfc___2 *);
	unsigned int (*get_bias)(struct sh_pfc___2 *, unsigned int);
	void (*set_bias)(struct sh_pfc___2 *, unsigned int, unsigned int);
	int (*pin_to_pocctrl)(struct sh_pfc___2 *, unsigned int, u32 *);
	void * (*pin_to_portcr)(struct sh_pfc___2 *, unsigned int);
};

struct sh_pfc_pin_config {
	u16 gpio_enabled: 1;
	u16 mux_mark: 15;
};

struct sh_pfc_pinctrl {
	struct pinctrl_dev___6 *pctl;
	struct pinctrl_desc___7 pctl_desc;
	struct sh_pfc___2 *pfc;
	struct pinctrl_pin_desc *pins;
	struct sh_pfc_pin_config *configs;
	const char *func_prop_name;
	const char *groups_prop_name;
	const char *pins_prop_name;
};

union vin_data16 {
	unsigned int data16[16];
	unsigned int data12[12];
	unsigned int data10[10];
	unsigned int data8[8];
};

union vin_data {
	unsigned int data24[24];
	unsigned int data20[20];
	unsigned int data16[16];
	unsigned int data12[12];
	unsigned int data10[10];
	unsigned int data8[8];
	unsigned int data4[4];
};

struct sh_pfc_soc_info___3;

struct sh_pfc___3 {
	struct device___139 *dev;
	const struct sh_pfc_soc_info___3 *info;
	spinlock_t lock;
	unsigned int num_windows;
	struct sh_pfc_window *windows;
	unsigned int num_irqs;
	unsigned int *irqs;
	struct sh_pfc_pin_range *ranges;
	unsigned int nr_ranges;
	unsigned int nr_gpio_pins;
	struct sh_pfc_chip *gpio;
	u32 *saved_regs;
};

struct sh_pfc_soc_operations___3;

struct sh_pfc_soc_info___3 {
	const char *name;
	const struct sh_pfc_soc_operations___3 *ops;
	struct pinmux_range function;
	const struct sh_pfc_pin *pins;
	unsigned int nr_pins;
	const struct sh_pfc_pin_group *groups;
	unsigned int nr_groups;
	const struct sh_pfc_function *functions;
	unsigned int nr_functions;
	const struct pinmux_cfg_reg *cfg_regs;
	const struct pinmux_drive_reg *drive_regs;
	const struct pinmux_bias_reg *bias_regs;
	const struct pinmux_ioctrl_reg *ioctrl_regs;
	const struct pinmux_data_reg *data_regs;
	const u16 *pinmux_data;
	unsigned int pinmux_data_size;
	u32 unlock_reg;
};

struct sh_pfc_soc_operations___3 {
	int (*init)(struct sh_pfc___3 *);
	unsigned int (*get_bias)(struct sh_pfc___3 *, unsigned int);
	void (*set_bias)(struct sh_pfc___3 *, unsigned int, unsigned int);
	int (*pin_to_pocctrl)(struct sh_pfc___3 *, unsigned int, u32 *);
	void * (*pin_to_portcr)(struct sh_pfc___3 *, unsigned int);
};

enum {
	PINMUX_RESERVED = 0,
	PINMUX_DATA_BEGIN = 1,
	GP_0_0_DATA = 2,
	GP_0_1_DATA = 3,
	GP_0_2_DATA = 4,
	GP_0_3_DATA = 5,
	GP_0_4_DATA = 6,
	GP_0_5_DATA = 7,
	GP_0_6_DATA = 8,
	GP_0_7_DATA = 9,
	GP_0_8_DATA = 10,
	GP_0_9_DATA = 11,
	GP_0_10_DATA = 12,
	GP_0_11_DATA = 13,
	GP_0_12_DATA = 14,
	GP_0_13_DATA = 15,
	GP_0_14_DATA = 16,
	GP_0_15_DATA = 17,
	GP_1_0_DATA = 18,
	GP_1_1_DATA = 19,
	GP_1_2_DATA = 20,
	GP_1_3_DATA = 21,
	GP_1_4_DATA = 22,
	GP_1_5_DATA = 23,
	GP_1_6_DATA = 24,
	GP_1_7_DATA = 25,
	GP_1_8_DATA = 26,
	GP_1_9_DATA = 27,
	GP_1_10_DATA = 28,
	GP_1_11_DATA = 29,
	GP_1_12_DATA = 30,
	GP_1_13_DATA = 31,
	GP_1_14_DATA = 32,
	GP_1_15_DATA = 33,
	GP_1_16_DATA = 34,
	GP_1_17_DATA = 35,
	GP_1_18_DATA = 36,
	GP_1_19_DATA = 37,
	GP_1_20_DATA = 38,
	GP_1_21_DATA = 39,
	GP_1_22_DATA = 40,
	GP_1_23_DATA = 41,
	GP_1_24_DATA = 42,
	GP_1_25_DATA = 43,
	GP_1_26_DATA = 44,
	GP_1_27_DATA = 45,
	GP_1_28_DATA = 46,
	GP_2_0_DATA = 47,
	GP_2_1_DATA = 48,
	GP_2_2_DATA = 49,
	GP_2_3_DATA = 50,
	GP_2_4_DATA = 51,
	GP_2_5_DATA = 52,
	GP_2_6_DATA = 53,
	GP_2_7_DATA = 54,
	GP_2_8_DATA = 55,
	GP_2_9_DATA = 56,
	GP_2_10_DATA = 57,
	GP_2_11_DATA = 58,
	GP_2_12_DATA = 59,
	GP_2_13_DATA = 60,
	GP_2_14_DATA = 61,
	GP_3_0_DATA = 62,
	GP_3_1_DATA = 63,
	GP_3_2_DATA = 64,
	GP_3_3_DATA = 65,
	GP_3_4_DATA = 66,
	GP_3_5_DATA = 67,
	GP_3_6_DATA = 68,
	GP_3_7_DATA = 69,
	GP_3_8_DATA = 70,
	GP_3_9_DATA = 71,
	GP_3_10_DATA = 72,
	GP_3_11_DATA = 73,
	GP_3_12_DATA = 74,
	GP_3_13_DATA = 75,
	GP_3_14_DATA = 76,
	GP_3_15_DATA = 77,
	GP_4_0_DATA = 78,
	GP_4_1_DATA = 79,
	GP_4_2_DATA = 80,
	GP_4_3_DATA = 81,
	GP_4_4_DATA = 82,
	GP_4_5_DATA = 83,
	GP_4_6_DATA = 84,
	GP_4_7_DATA = 85,
	GP_4_8_DATA = 86,
	GP_4_9_DATA = 87,
	GP_4_10_DATA = 88,
	GP_4_11_DATA = 89,
	GP_4_12_DATA = 90,
	GP_4_13_DATA = 91,
	GP_4_14_DATA = 92,
	GP_4_15_DATA = 93,
	GP_4_16_DATA = 94,
	GP_4_17_DATA = 95,
	GP_5_0_DATA = 96,
	GP_5_1_DATA = 97,
	GP_5_2_DATA = 98,
	GP_5_3_DATA = 99,
	GP_5_4_DATA = 100,
	GP_5_5_DATA = 101,
	GP_5_6_DATA = 102,
	GP_5_7_DATA = 103,
	GP_5_8_DATA = 104,
	GP_5_9_DATA = 105,
	GP_5_10_DATA = 106,
	GP_5_11_DATA = 107,
	GP_5_12_DATA = 108,
	GP_5_13_DATA = 109,
	GP_5_14_DATA = 110,
	GP_5_15_DATA = 111,
	GP_5_16_DATA = 112,
	GP_5_17_DATA = 113,
	GP_5_18_DATA = 114,
	GP_5_19_DATA = 115,
	GP_5_20_DATA = 116,
	GP_5_21_DATA = 117,
	GP_5_22_DATA = 118,
	GP_5_23_DATA = 119,
	GP_5_24_DATA = 120,
	GP_5_25_DATA = 121,
	GP_6_0_DATA = 122,
	GP_6_1_DATA = 123,
	GP_6_2_DATA = 124,
	GP_6_3_DATA = 125,
	GP_6_4_DATA = 126,
	GP_6_5_DATA = 127,
	GP_6_6_DATA = 128,
	GP_6_7_DATA = 129,
	GP_6_8_DATA = 130,
	GP_6_9_DATA = 131,
	GP_6_10_DATA = 132,
	GP_6_11_DATA = 133,
	GP_6_12_DATA = 134,
	GP_6_13_DATA = 135,
	GP_6_14_DATA = 136,
	GP_6_15_DATA = 137,
	GP_6_16_DATA = 138,
	GP_6_17_DATA = 139,
	GP_6_18_DATA = 140,
	GP_6_19_DATA = 141,
	GP_6_20_DATA = 142,
	GP_6_21_DATA = 143,
	GP_6_22_DATA = 144,
	GP_6_23_DATA = 145,
	GP_6_24_DATA = 146,
	GP_6_25_DATA = 147,
	GP_6_26_DATA = 148,
	GP_6_27_DATA = 149,
	GP_6_28_DATA = 150,
	GP_6_29_DATA = 151,
	GP_6_30_DATA = 152,
	GP_6_31_DATA = 153,
	GP_7_0_DATA = 154,
	GP_7_1_DATA = 155,
	GP_7_2_DATA = 156,
	GP_7_3_DATA = 157,
	PINMUX_DATA_END = 158,
	PINMUX_FUNCTION_BEGIN = 159,
	GP_0_0_FN = 160,
	GP_0_1_FN = 161,
	GP_0_2_FN = 162,
	GP_0_3_FN = 163,
	GP_0_4_FN = 164,
	GP_0_5_FN = 165,
	GP_0_6_FN = 166,
	GP_0_7_FN = 167,
	GP_0_8_FN = 168,
	GP_0_9_FN = 169,
	GP_0_10_FN = 170,
	GP_0_11_FN = 171,
	GP_0_12_FN = 172,
	GP_0_13_FN = 173,
	GP_0_14_FN = 174,
	GP_0_15_FN = 175,
	GP_1_0_FN = 176,
	GP_1_1_FN = 177,
	GP_1_2_FN = 178,
	GP_1_3_FN = 179,
	GP_1_4_FN = 180,
	GP_1_5_FN = 181,
	GP_1_6_FN = 182,
	GP_1_7_FN = 183,
	GP_1_8_FN = 184,
	GP_1_9_FN = 185,
	GP_1_10_FN = 186,
	GP_1_11_FN = 187,
	GP_1_12_FN = 188,
	GP_1_13_FN = 189,
	GP_1_14_FN = 190,
	GP_1_15_FN = 191,
	GP_1_16_FN = 192,
	GP_1_17_FN = 193,
	GP_1_18_FN = 194,
	GP_1_19_FN = 195,
	GP_1_20_FN = 196,
	GP_1_21_FN = 197,
	GP_1_22_FN = 198,
	GP_1_23_FN = 199,
	GP_1_24_FN = 200,
	GP_1_25_FN = 201,
	GP_1_26_FN = 202,
	GP_1_27_FN = 203,
	GP_1_28_FN = 204,
	GP_2_0_FN = 205,
	GP_2_1_FN = 206,
	GP_2_2_FN = 207,
	GP_2_3_FN = 208,
	GP_2_4_FN = 209,
	GP_2_5_FN = 210,
	GP_2_6_FN = 211,
	GP_2_7_FN = 212,
	GP_2_8_FN = 213,
	GP_2_9_FN = 214,
	GP_2_10_FN = 215,
	GP_2_11_FN = 216,
	GP_2_12_FN = 217,
	GP_2_13_FN = 218,
	GP_2_14_FN = 219,
	GP_3_0_FN = 220,
	GP_3_1_FN = 221,
	GP_3_2_FN = 222,
	GP_3_3_FN = 223,
	GP_3_4_FN = 224,
	GP_3_5_FN = 225,
	GP_3_6_FN = 226,
	GP_3_7_FN = 227,
	GP_3_8_FN = 228,
	GP_3_9_FN = 229,
	GP_3_10_FN = 230,
	GP_3_11_FN = 231,
	GP_3_12_FN = 232,
	GP_3_13_FN = 233,
	GP_3_14_FN = 234,
	GP_3_15_FN = 235,
	GP_4_0_FN = 236,
	GP_4_1_FN = 237,
	GP_4_2_FN = 238,
	GP_4_3_FN = 239,
	GP_4_4_FN = 240,
	GP_4_5_FN = 241,
	GP_4_6_FN = 242,
	GP_4_7_FN = 243,
	GP_4_8_FN = 244,
	GP_4_9_FN = 245,
	GP_4_10_FN = 246,
	GP_4_11_FN = 247,
	GP_4_12_FN = 248,
	GP_4_13_FN = 249,
	GP_4_14_FN = 250,
	GP_4_15_FN = 251,
	GP_4_16_FN = 252,
	GP_4_17_FN = 253,
	GP_5_0_FN = 254,
	GP_5_1_FN = 255,
	GP_5_2_FN = 256,
	GP_5_3_FN = 257,
	GP_5_4_FN = 258,
	GP_5_5_FN = 259,
	GP_5_6_FN = 260,
	GP_5_7_FN = 261,
	GP_5_8_FN = 262,
	GP_5_9_FN = 263,
	GP_5_10_FN = 264,
	GP_5_11_FN = 265,
	GP_5_12_FN = 266,
	GP_5_13_FN = 267,
	GP_5_14_FN = 268,
	GP_5_15_FN = 269,
	GP_5_16_FN = 270,
	GP_5_17_FN = 271,
	GP_5_18_FN = 272,
	GP_5_19_FN = 273,
	GP_5_20_FN = 274,
	GP_5_21_FN = 275,
	GP_5_22_FN = 276,
	GP_5_23_FN = 277,
	GP_5_24_FN = 278,
	GP_5_25_FN = 279,
	GP_6_0_FN = 280,
	GP_6_1_FN = 281,
	GP_6_2_FN = 282,
	GP_6_3_FN = 283,
	GP_6_4_FN = 284,
	GP_6_5_FN = 285,
	GP_6_6_FN = 286,
	GP_6_7_FN = 287,
	GP_6_8_FN = 288,
	GP_6_9_FN = 289,
	GP_6_10_FN = 290,
	GP_6_11_FN = 291,
	GP_6_12_FN = 292,
	GP_6_13_FN = 293,
	GP_6_14_FN = 294,
	GP_6_15_FN = 295,
	GP_6_16_FN = 296,
	GP_6_17_FN = 297,
	GP_6_18_FN = 298,
	GP_6_19_FN = 299,
	GP_6_20_FN = 300,
	GP_6_21_FN = 301,
	GP_6_22_FN = 302,
	GP_6_23_FN = 303,
	GP_6_24_FN = 304,
	GP_6_25_FN = 305,
	GP_6_26_FN = 306,
	GP_6_27_FN = 307,
	GP_6_28_FN = 308,
	GP_6_29_FN = 309,
	GP_6_30_FN = 310,
	GP_6_31_FN = 311,
	GP_7_0_FN = 312,
	GP_7_1_FN = 313,
	GP_7_2_FN = 314,
	GP_7_3_FN = 315,
	FN_CLKOUT = 316,
	FN_MSIOF0_RXD = 317,
	FN_MSIOF0_TXD = 318,
	FN_MSIOF0_SCK = 319,
	FN_SSI_SDATA5 = 320,
	FN_SSI_WS5 = 321,
	FN_SSI_SCK5 = 322,
	FN_GP7_03 = 323,
	FN_GP7_02 = 324,
	FN_AVS2 = 325,
	FN_AVS1 = 326,
	FN_IP0_3_0 = 327,
	FN_AVB_MDC = 328,
	FN_MSIOF2_SS2_C = 329,
	FN_IP1_3_0 = 330,
	FN_IRQ2 = 331,
	FN_QCPV_QDE = 332,
	FN_DU_EXODDF_DU_ODDF_DISP_CDE = 333,
	FN_VI4_DATA2_B = 334,
	FN_MSIOF3_SYNC_E = 335,
	FN_PWM3_B = 336,
	FN_IP2_3_0 = 337,
	FN_A1 = 338,
	FN_LCDOUT17 = 339,
	FN_MSIOF3_TXD_B = 340,
	FN_VI4_DATA9 = 341,
	FN_DU_DB1 = 342,
	FN_PWM4_A = 343,
	FN_IP3_3_0 = 344,
	FN_A9 = 345,
	FN_MSIOF2_SCK_A = 346,
	FN_CTS4_N_B = 347,
	FN_VI5_VSYNC_N = 348,
	FN_IP0_7_4 = 349,
	FN_AVB_MAGIC = 350,
	FN_MSIOF2_SS1_C = 351,
	FN_SCK4_A = 352,
	FN_IP1_7_4 = 353,
	FN_IRQ3 = 354,
	FN_QSTVB_QVE = 355,
	FN_DU_DOTCLKOUT1 = 356,
	FN_VI4_DATA3_B = 357,
	FN_MSIOF3_SCK_E = 358,
	FN_PWM4_B = 359,
	FN_IP2_7_4 = 360,
	FN_A2 = 361,
	FN_LCDOUT18 = 362,
	FN_MSIOF3_SCK_B = 363,
	FN_VI4_DATA10 = 364,
	FN_DU_DB2 = 365,
	FN_PWM5_A = 366,
	FN_IP3_7_4 = 367,
	FN_A10 = 368,
	FN_MSIOF2_RXD_A = 369,
	FN_RTS4_N_B = 370,
	FN_VI5_HSYNC_N = 371,
	FN_IP0_11_8 = 372,
	FN_AVB_PHY_INT = 373,
	FN_MSIOF2_SYNC_C = 374,
	FN_RX4_A = 375,
	FN_IP1_11_8 = 376,
	FN_IRQ4 = 377,
	FN_QSTH_QHS = 378,
	FN_DU_EXHSYNC_DU_HSYNC = 379,
	FN_VI4_DATA4_B = 380,
	FN_MSIOF3_RXD_E = 381,
	FN_PWM5_B = 382,
	FN_IP2_11_8 = 383,
	FN_A3 = 384,
	FN_LCDOUT19 = 385,
	FN_MSIOF3_RXD_B = 386,
	FN_VI4_DATA11 = 387,
	FN_DU_DB3 = 388,
	FN_PWM6_A = 389,
	FN_IP3_11_8 = 390,
	FN_A11 = 391,
	FN_TX3_B = 392,
	FN_MSIOF2_TXD_A = 393,
	FN_HTX4_B = 394,
	FN_HSCK4 = 395,
	FN_VI5_FIELD = 396,
	FN_SCL6_A = 397,
	FN_AVB_AVTP_CAPTURE_B = 398,
	FN_PWM2_B = 399,
	FN_IP0_15_12 = 400,
	FN_AVB_LINK = 401,
	FN_MSIOF2_SCK_C = 402,
	FN_TX4_A = 403,
	FN_IP1_15_12 = 404,
	FN_IRQ5 = 405,
	FN_QSTB_QHE = 406,
	FN_DU_EXVSYNC_DU_VSYNC = 407,
	FN_VI4_DATA5_B = 408,
	FN_MSIOF3_TXD_E = 409,
	FN_PWM6_B = 410,
	FN_IP2_15_12 = 411,
	FN_A4 = 412,
	FN_LCDOUT20 = 413,
	FN_MSIOF3_SS1_B = 414,
	FN_VI4_DATA12 = 415,
	FN_VI5_DATA12 = 416,
	FN_DU_DB4 = 417,
	FN_IP3_15_12 = 418,
	FN_A12 = 419,
	FN_LCDOUT12 = 420,
	FN_MSIOF3_SCK_C = 421,
	FN_HRX4_A = 422,
	FN_VI5_DATA8 = 423,
	FN_DU_DG4 = 424,
	FN_IP0_19_16 = 425,
	FN_AVB_AVTP_MATCH_A = 426,
	FN_MSIOF2_RXD_C = 427,
	FN_CTS4_N_A = 428,
	FN_IP1_19_16 = 429,
	FN_PWM0 = 430,
	FN_AVB_AVTP_PPS = 431,
	FN_VI4_DATA6_B = 432,
	FN_IECLK_B = 433,
	FN_IP2_19_16 = 434,
	FN_A5 = 435,
	FN_LCDOUT21 = 436,
	FN_MSIOF3_SS2_B = 437,
	FN_SCK4_B = 438,
	FN_VI4_DATA13 = 439,
	FN_VI5_DATA13 = 440,
	FN_DU_DB5 = 441,
	FN_IP3_19_16 = 442,
	FN_A13 = 443,
	FN_LCDOUT13 = 444,
	FN_MSIOF3_SYNC_C = 445,
	FN_HTX4_A = 446,
	FN_VI5_DATA9 = 447,
	FN_DU_DG5 = 448,
	FN_IP0_23_20 = 449,
	FN_AVB_AVTP_CAPTURE_A = 450,
	FN_MSIOF2_TXD_C = 451,
	FN_RTS4_N_A = 452,
	FN_IP1_23_20 = 453,
	FN_PWM1_A = 454,
	FN_HRX3_D = 455,
	FN_VI4_DATA7_B = 456,
	FN_IERX_B = 457,
	FN_IP2_23_20 = 458,
	FN_A6 = 459,
	FN_LCDOUT22 = 460,
	FN_MSIOF2_SS1_A = 461,
	FN_RX4_B = 462,
	FN_VI4_DATA14 = 463,
	FN_VI5_DATA14 = 464,
	FN_DU_DB6 = 465,
	FN_IP3_23_20 = 466,
	FN_A14 = 467,
	FN_LCDOUT14 = 468,
	FN_MSIOF3_RXD_C = 469,
	FN_HCTS4_N = 470,
	FN_VI5_DATA10 = 471,
	FN_DU_DG6 = 472,
	FN_IP0_27_24 = 473,
	FN_IRQ0 = 474,
	FN_QPOLB = 475,
	FN_DU_CDE = 476,
	FN_VI4_DATA0_B = 477,
	FN_CAN0_TX_B = 478,
	FN_CANFD0_TX_B = 479,
	FN_MSIOF3_SS2_E = 480,
	FN_IP1_27_24 = 481,
	FN_PWM2_A = 482,
	FN_HTX3_D = 483,
	FN_IETX_B = 484,
	FN_IP2_27_24 = 485,
	FN_A7 = 486,
	FN_LCDOUT23 = 487,
	FN_MSIOF2_SS2_A = 488,
	FN_TX4_B = 489,
	FN_VI4_DATA15 = 490,
	FN_VI5_DATA15 = 491,
	FN_DU_DB7 = 492,
	FN_IP3_27_24 = 493,
	FN_A15 = 494,
	FN_LCDOUT15 = 495,
	FN_MSIOF3_TXD_C = 496,
	FN_HRTS4_N = 497,
	FN_VI5_DATA11 = 498,
	FN_DU_DG7 = 499,
	FN_IP0_31_28 = 500,
	FN_IRQ1 = 501,
	FN_QPOLA = 502,
	FN_DU_DISP = 503,
	FN_VI4_DATA1_B = 504,
	FN_CAN0_RX_B = 505,
	FN_CANFD0_RX_B = 506,
	FN_MSIOF3_SS1_E = 507,
	FN_IP1_31_28 = 508,
	FN_A0 = 509,
	FN_LCDOUT16 = 510,
	FN_MSIOF3_SYNC_B = 511,
	FN_VI4_DATA8 = 512,
	FN_DU_DB0 = 513,
	FN_PWM3_A = 514,
	FN_IP2_31_28 = 515,
	FN_A8 = 516,
	FN_RX3_B = 517,
	FN_MSIOF2_SYNC_A = 518,
	FN_HRX4_B = 519,
	FN_SDA6_A = 520,
	FN_AVB_AVTP_MATCH_B = 521,
	FN_PWM1_B = 522,
	FN_IP3_31_28 = 523,
	FN_A16 = 524,
	FN_LCDOUT8 = 525,
	FN_VI4_FIELD = 526,
	FN_DU_DG0 = 527,
	FN_IP4_3_0 = 528,
	FN_A17 = 529,
	FN_LCDOUT9 = 530,
	FN_VI4_VSYNC_N = 531,
	FN_DU_DG1 = 532,
	FN_IP5_3_0 = 533,
	FN_WE0_N = 534,
	FN_MSIOF3_TXD_D = 535,
	FN_CTS3_N = 536,
	FN_HCTS3_N = 537,
	FN_SCL6_B = 538,
	FN_CAN_CLK = 539,
	FN_IECLK_A = 540,
	FN_IP6_3_0 = 541,
	FN_D5 = 542,
	FN_MSIOF2_SYNC_B = 543,
	FN_VI4_DATA21 = 544,
	FN_VI5_DATA5 = 545,
	FN_IP7_3_0 = 546,
	FN_D13 = 547,
	FN_LCDOUT5 = 548,
	FN_MSIOF2_SS2_D = 549,
	FN_TX4_C = 550,
	FN_VI4_DATA5_A = 551,
	FN_DU_DR5 = 552,
	FN_IP4_7_4 = 553,
	FN_A18 = 554,
	FN_LCDOUT10 = 555,
	FN_VI4_HSYNC_N = 556,
	FN_DU_DG2 = 557,
	FN_IP5_7_4 = 558,
	FN_WE1_N = 559,
	FN_MSIOF3_SS1_D = 560,
	FN_RTS3_N = 561,
	FN_HRTS3_N = 562,
	FN_SDA6_B = 563,
	FN_CAN1_RX = 564,
	FN_CANFD1_RX = 565,
	FN_IERX_A = 566,
	FN_IP6_7_4 = 567,
	FN_D6 = 568,
	FN_MSIOF2_RXD_B = 569,
	FN_VI4_DATA22 = 570,
	FN_VI5_DATA6 = 571,
	FN_IP7_7_4 = 572,
	FN_D14 = 573,
	FN_LCDOUT6 = 574,
	FN_MSIOF3_SS1_A = 575,
	FN_HRX3_C = 576,
	FN_VI4_DATA6_A = 577,
	FN_DU_DR6 = 578,
	FN_SCL6_C = 579,
	FN_IP4_11_8 = 580,
	FN_A19 = 581,
	FN_LCDOUT11 = 582,
	FN_VI4_CLKENB = 583,
	FN_DU_DG3 = 584,
	FN_IP5_11_8 = 585,
	FN_EX_WAIT0_A = 586,
	FN_QCLK = 587,
	FN_VI4_CLK = 588,
	FN_DU_DOTCLKOUT0 = 589,
	FN_IP6_11_8 = 590,
	FN_D7 = 591,
	FN_MSIOF2_TXD_B = 592,
	FN_VI4_DATA23 = 593,
	FN_VI5_DATA7 = 594,
	FN_IP7_11_8 = 595,
	FN_D15 = 596,
	FN_LCDOUT7 = 597,
	FN_MSIOF3_SS2_A = 598,
	FN_HTX3_C = 599,
	FN_VI4_DATA7_A = 600,
	FN_DU_DR7 = 601,
	FN_SDA6_C = 602,
	FN_IP4_15_12 = 603,
	FN_CS0_N = 604,
	FN_VI5_CLKENB = 605,
	FN_IP5_15_12 = 606,
	FN_D0 = 607,
	FN_MSIOF2_SS1_B = 608,
	FN_MSIOF3_SCK_A = 609,
	FN_VI4_DATA16 = 610,
	FN_VI5_DATA0 = 611,
	FN_IP6_15_12 = 612,
	FN_D8 = 613,
	FN_LCDOUT0 = 614,
	FN_MSIOF2_SCK_D = 615,
	FN_SCK4_C = 616,
	FN_VI4_DATA0_A = 617,
	FN_DU_DR0 = 618,
	FN_IP4_19_16 = 619,
	FN_CS1_N = 620,
	FN_VI5_CLK = 621,
	FN_EX_WAIT0_B = 622,
	FN_IP5_19_16 = 623,
	FN_D1 = 624,
	FN_MSIOF2_SS2_B = 625,
	FN_MSIOF3_SYNC_A = 626,
	FN_VI4_DATA17 = 627,
	FN_VI5_DATA1 = 628,
	FN_IP6_19_16 = 629,
	FN_D9 = 630,
	FN_LCDOUT1 = 631,
	FN_MSIOF2_SYNC_D = 632,
	FN_VI4_DATA1_A = 633,
	FN_DU_DR1 = 634,
	FN_IP7_19_16 = 635,
	FN_SD0_CLK = 636,
	FN_MSIOF1_SCK_E = 637,
	FN_STP_OPWM_0_B = 638,
	FN_IP4_23_20 = 639,
	FN_BS_N = 640,
	FN_QSTVA_QVS = 641,
	FN_MSIOF3_SCK_D = 642,
	FN_SCK3 = 643,
	FN_HSCK3 = 644,
	FN_CAN1_TX = 645,
	FN_CANFD1_TX = 646,
	FN_IETX_A = 647,
	FN_IP5_23_20 = 648,
	FN_D2 = 649,
	FN_MSIOF3_RXD_A = 650,
	FN_VI4_DATA18 = 651,
	FN_VI5_DATA2 = 652,
	FN_IP6_23_20 = 653,
	FN_D10 = 654,
	FN_LCDOUT2 = 655,
	FN_MSIOF2_RXD_D = 656,
	FN_HRX3_B = 657,
	FN_VI4_DATA2_A = 658,
	FN_CTS4_N_C = 659,
	FN_DU_DR2 = 660,
	FN_IP7_23_20 = 661,
	FN_SD0_CMD = 662,
	FN_MSIOF1_SYNC_E = 663,
	FN_STP_IVCXO27_0_B = 664,
	FN_IP4_27_24 = 665,
	FN_RD_N = 666,
	FN_MSIOF3_SYNC_D = 667,
	FN_RX3_A = 668,
	FN_HRX3_A = 669,
	FN_CAN0_TX_A = 670,
	FN_CANFD0_TX_A = 671,
	FN_IP5_27_24 = 672,
	FN_D3 = 673,
	FN_MSIOF3_TXD_A = 674,
	FN_VI4_DATA19 = 675,
	FN_VI5_DATA3 = 676,
	FN_IP6_27_24 = 677,
	FN_D11 = 678,
	FN_LCDOUT3 = 679,
	FN_MSIOF2_TXD_D = 680,
	FN_HTX3_B = 681,
	FN_VI4_DATA3_A = 682,
	FN_RTS4_N_C = 683,
	FN_DU_DR3 = 684,
	FN_IP7_27_24 = 685,
	FN_SD0_DAT0 = 686,
	FN_MSIOF1_RXD_E = 687,
	FN_TS_SCK0_B = 688,
	FN_STP_ISCLK_0_B = 689,
	FN_IP4_31_28 = 690,
	FN_RD_WR_N = 691,
	FN_MSIOF3_RXD_D = 692,
	FN_TX3_A = 693,
	FN_HTX3_A = 694,
	FN_CAN0_RX_A = 695,
	FN_CANFD0_RX_A = 696,
	FN_IP5_31_28 = 697,
	FN_D4 = 698,
	FN_MSIOF2_SCK_B = 699,
	FN_VI4_DATA20 = 700,
	FN_VI5_DATA4 = 701,
	FN_IP6_31_28 = 702,
	FN_D12 = 703,
	FN_LCDOUT4 = 704,
	FN_MSIOF2_SS1_D = 705,
	FN_RX4_C = 706,
	FN_VI4_DATA4_A = 707,
	FN_DU_DR4 = 708,
	FN_IP7_31_28 = 709,
	FN_SD0_DAT1 = 710,
	FN_MSIOF1_TXD_E = 711,
	FN_TS_SPSYNC0_B = 712,
	FN_STP_ISSYNC_0_B = 713,
	FN_IP8_3_0 = 714,
	FN_SD0_DAT2 = 715,
	FN_MSIOF1_SS1_E = 716,
	FN_TS_SDAT0_B = 717,
	FN_STP_ISD_0_B = 718,
	FN_IP9_3_0 = 719,
	FN_SD2_CLK = 720,
	FN_NFDATA8 = 721,
	FN_IP10_3_0 = 722,
	FN_SD3_CMD = 723,
	FN_NFRE_N = 724,
	FN_IP11_3_0 = 725,
	FN_SD3_DAT7 = 726,
	FN_SD3_WP = 727,
	FN_NFDATA7 = 728,
	FN_IP8_7_4 = 729,
	FN_SD0_DAT3 = 730,
	FN_MSIOF1_SS2_E = 731,
	FN_TS_SDEN0_B = 732,
	FN_STP_ISEN_0_B = 733,
	FN_IP9_7_4 = 734,
	FN_SD2_CMD = 735,
	FN_NFDATA9 = 736,
	FN_IP10_7_4 = 737,
	FN_SD3_DAT0 = 738,
	FN_NFDATA0 = 739,
	FN_IP11_7_4 = 740,
	FN_SD3_DS = 741,
	FN_NFCLE = 742,
	FN_IP8_11_8 = 743,
	FN_SD1_CLK = 744,
	FN_MSIOF1_SCK_G = 745,
	FN_SIM0_CLK_A = 746,
	FN_IP9_11_8 = 747,
	FN_SD2_DAT0 = 748,
	FN_NFDATA10 = 749,
	FN_IP10_11_8 = 750,
	FN_SD3_DAT1 = 751,
	FN_NFDATA1 = 752,
	FN_IP11_11_8 = 753,
	FN_SD0_CD = 754,
	FN_NFDATA14_A = 755,
	FN_SCL2_B = 756,
	FN_SIM0_RST_A = 757,
	FN_IP8_15_12 = 758,
	FN_SD1_CMD = 759,
	FN_MSIOF1_SYNC_G = 760,
	FN_NFCE_N_B = 761,
	FN_SIM0_D_A = 762,
	FN_STP_IVCXO27_1_B = 763,
	FN_IP9_15_12 = 764,
	FN_SD2_DAT1 = 765,
	FN_NFDATA11 = 766,
	FN_IP10_15_12 = 767,
	FN_SD3_DAT2 = 768,
	FN_NFDATA2 = 769,
	FN_IP11_15_12 = 770,
	FN_SD0_WP = 771,
	FN_NFDATA15_A = 772,
	FN_SDA2_B = 773,
	FN_IP8_19_16 = 774,
	FN_SD1_DAT0 = 775,
	FN_SD2_DAT4 = 776,
	FN_MSIOF1_RXD_G = 777,
	FN_NFWP_N_B = 778,
	FN_TS_SCK1_B = 779,
	FN_STP_ISCLK_1_B = 780,
	FN_IP9_19_16 = 781,
	FN_SD2_DAT2 = 782,
	FN_NFDATA12 = 783,
	FN_IP10_19_16 = 784,
	FN_SD3_DAT3 = 785,
	FN_NFDATA3 = 786,
	FN_IP11_19_16 = 787,
	FN_SD1_CD = 788,
	FN_NFRB_N_A = 789,
	FN_SIM0_CLK_B = 790,
	FN_IP8_23_20 = 791,
	FN_SD1_DAT1 = 792,
	FN_SD2_DAT5 = 793,
	FN_MSIOF1_TXD_G = 794,
	FN_NFDATA14_B = 795,
	FN_TS_SPSYNC1_B = 796,
	FN_STP_ISSYNC_1_B = 797,
	FN_IP9_23_20 = 798,
	FN_SD2_DAT3 = 799,
	FN_NFDATA13 = 800,
	FN_IP10_23_20 = 801,
	FN_SD3_DAT4 = 802,
	FN_SD2_CD_A = 803,
	FN_NFDATA4 = 804,
	FN_IP11_23_20 = 805,
	FN_SD1_WP = 806,
	FN_NFCE_N_A = 807,
	FN_SIM0_D_B = 808,
	FN_IP8_27_24 = 809,
	FN_SD1_DAT2 = 810,
	FN_SD2_DAT6 = 811,
	FN_MSIOF1_SS1_G = 812,
	FN_NFDATA15_B = 813,
	FN_TS_SDAT1_B = 814,
	FN_STP_ISD_1_B = 815,
	FN_IP9_27_24 = 816,
	FN_SD2_DS = 817,
	FN_NFALE = 818,
	FN_IP10_27_24 = 819,
	FN_SD3_DAT5 = 820,
	FN_SD2_WP_A = 821,
	FN_NFDATA5 = 822,
	FN_IP11_27_24 = 823,
	FN_SCK0 = 824,
	FN_HSCK1_B = 825,
	FN_MSIOF1_SS2_B = 826,
	FN_AUDIO_CLKC_B = 827,
	FN_SDA2_A = 828,
	FN_SIM0_RST_B = 829,
	FN_STP_OPWM_0_C = 830,
	FN_RIF0_CLK_B = 831,
	FN_ADICHS2 = 832,
	FN_SCK5_B = 833,
	FN_IP8_31_28 = 834,
	FN_SD1_DAT3 = 835,
	FN_SD2_DAT7 = 836,
	FN_MSIOF1_SS2_G = 837,
	FN_NFRB_N_B = 838,
	FN_TS_SDEN1_B = 839,
	FN_STP_ISEN_1_B = 840,
	FN_IP9_31_28 = 841,
	FN_SD3_CLK = 842,
	FN_NFWE_N = 843,
	FN_IP10_31_28 = 844,
	FN_SD3_DAT6 = 845,
	FN_SD3_CD = 846,
	FN_NFDATA6 = 847,
	FN_IP11_31_28 = 848,
	FN_RX0 = 849,
	FN_HRX1_B = 850,
	FN_TS_SCK0_C = 851,
	FN_STP_ISCLK_0_C = 852,
	FN_RIF0_D0_B = 853,
	FN_IP12_3_0 = 854,
	FN_TX0 = 855,
	FN_HTX1_B = 856,
	FN_TS_SPSYNC0_C = 857,
	FN_STP_ISSYNC_0_C = 858,
	FN_RIF0_D1_B = 859,
	FN_IP13_3_0 = 860,
	FN_TX2_A = 861,
	FN_SD2_CD_B = 862,
	FN_SCL1_A = 863,
	FN_FMCLK_A = 864,
	FN_RIF1_D1_C = 865,
	FN_FSO_CFE_0_N = 866,
	FN_IP14_3_0 = 867,
	FN_MSIOF0_SS1 = 868,
	FN_RX5_A = 869,
	FN_NFWP_N_A = 870,
	FN_AUDIO_CLKA_C = 871,
	FN_SSI_SCK2_A = 872,
	FN_STP_IVCXO27_0_C = 873,
	FN_AUDIO_CLKOUT3_A = 874,
	FN_TCLK1_B = 875,
	FN_IP15_3_0 = 876,
	FN_SSI_SDATA1_A = 877,
	FN_IP12_7_4 = 878,
	FN_CTS0_N = 879,
	FN_HCTS1_N_B = 880,
	FN_MSIOF1_SYNC_B = 881,
	FN_TS_SPSYNC1_C = 882,
	FN_STP_ISSYNC_1_C = 883,
	FN_RIF1_SYNC_B = 884,
	FN_AUDIO_CLKOUT_C = 885,
	FN_ADICS_SAMP = 886,
	FN_IP13_7_4 = 887,
	FN_RX2_A = 888,
	FN_SD2_WP_B = 889,
	FN_SDA1_A = 890,
	FN_FMIN_A = 891,
	FN_RIF1_SYNC_C = 892,
	FN_FSO_CFE_1_N = 893,
	FN_IP14_7_4 = 894,
	FN_MSIOF0_SS2 = 895,
	FN_TX5_A = 896,
	FN_MSIOF1_SS2_D = 897,
	FN_AUDIO_CLKC_A = 898,
	FN_SSI_WS2_A = 899,
	FN_STP_OPWM_0_D = 900,
	FN_AUDIO_CLKOUT_D = 901,
	FN_SPEEDIN_B = 902,
	FN_IP15_7_4 = 903,
	FN_SSI_SDATA2_A = 904,
	FN_SSI_SCK1_B = 905,
	FN_IP12_11_8 = 906,
	FN_RTS0_N = 907,
	FN_HRTS1_N_B = 908,
	FN_MSIOF1_SS1_B = 909,
	FN_AUDIO_CLKA_B = 910,
	FN_SCL2_A = 911,
	FN_STP_IVCXO27_1_C = 912,
	FN_RIF0_SYNC_B = 913,
	FN_ADICHS1 = 914,
	FN_IP13_11_8 = 915,
	FN_HSCK0 = 916,
	FN_MSIOF1_SCK_D = 917,
	FN_AUDIO_CLKB_A = 918,
	FN_SSI_SDATA1_B = 919,
	FN_TS_SCK0_D = 920,
	FN_STP_ISCLK_0_D = 921,
	FN_RIF0_CLK_C = 922,
	FN_RX5_B = 923,
	FN_IP14_11_8 = 924,
	FN_MLB_CLK = 925,
	FN_MSIOF1_SCK_F = 926,
	FN_SCL1_B = 927,
	FN_IP15_11_8 = 928,
	FN_SSI_SCK349 = 929,
	FN_MSIOF1_SS1_A = 930,
	FN_STP_OPWM_0_A = 931,
	FN_IP12_15_12 = 932,
	FN_RX1_A = 933,
	FN_HRX1_A = 934,
	FN_TS_SDAT0_C = 935,
	FN_STP_ISD_0_C = 936,
	FN_RIF1_CLK_C = 937,
	FN_IP13_15_12 = 938,
	FN_HRX0 = 939,
	FN_MSIOF1_RXD_D = 940,
	FN_SSI_SDATA2_B = 941,
	FN_TS_SDEN0_D = 942,
	FN_STP_ISEN_0_D = 943,
	FN_RIF0_D0_C = 944,
	FN_IP14_15_12 = 945,
	FN_MLB_SIG = 946,
	FN_RX1_B = 947,
	FN_MSIOF1_SYNC_F = 948,
	FN_SDA1_B = 949,
	FN_IP15_15_12 = 950,
	FN_SSI_WS349 = 951,
	FN_HCTS2_N_A = 952,
	FN_MSIOF1_SS2_A = 953,
	FN_STP_IVCXO27_0_A = 954,
	FN_IP12_19_16 = 955,
	FN_TX1_A = 956,
	FN_HTX1_A = 957,
	FN_TS_SDEN0_C = 958,
	FN_STP_ISEN_0_C = 959,
	FN_RIF1_D0_C = 960,
	FN_IP13_19_16 = 961,
	FN_HTX0 = 962,
	FN_MSIOF1_TXD_D = 963,
	FN_SSI_SDATA9_B = 964,
	FN_TS_SDAT0_D = 965,
	FN_STP_ISD_0_D = 966,
	FN_RIF0_D1_C = 967,
	FN_IP14_19_16 = 968,
	FN_MLB_DAT = 969,
	FN_TX1_B = 970,
	FN_MSIOF1_RXD_F = 971,
	FN_IP15_19_16 = 972,
	FN_SSI_SDATA3 = 973,
	FN_HRTS2_N_A = 974,
	FN_MSIOF1_TXD_A = 975,
	FN_TS_SCK0_A = 976,
	FN_STP_ISCLK_0_A = 977,
	FN_RIF0_D1_A = 978,
	FN_RIF2_D0_A = 979,
	FN_IP12_23_20 = 980,
	FN_CTS1_N = 981,
	FN_HCTS1_N_A = 982,
	FN_MSIOF1_RXD_B = 983,
	FN_TS_SDEN1_C = 984,
	FN_STP_ISEN_1_C = 985,
	FN_RIF1_D0_B = 986,
	FN_ADIDATA = 987,
	FN_IP13_23_20 = 988,
	FN_HCTS0_N = 989,
	FN_RX2_B = 990,
	FN_MSIOF1_SYNC_D = 991,
	FN_SSI_SCK9_A = 992,
	FN_TS_SPSYNC0_D = 993,
	FN_STP_ISSYNC_0_D = 994,
	FN_RIF0_SYNC_C = 995,
	FN_AUDIO_CLKOUT1_A = 996,
	FN_IP14_23_20 = 997,
	FN_SSI_SCK01239 = 998,
	FN_MSIOF1_TXD_F = 999,
	FN_IP15_23_20 = 1000,
	FN_SSI_SCK4 = 1001,
	FN_HRX2_A = 1002,
	FN_MSIOF1_SCK_A = 1003,
	FN_TS_SDAT0_A = 1004,
	FN_STP_ISD_0_A = 1005,
	FN_RIF0_CLK_A = 1006,
	FN_RIF2_CLK_A = 1007,
	FN_IP12_27_24 = 1008,
	FN_RTS1_N = 1009,
	FN_HRTS1_N_A = 1010,
	FN_MSIOF1_TXD_B = 1011,
	FN_TS_SDAT1_C = 1012,
	FN_STP_ISD_1_C = 1013,
	FN_RIF1_D1_B = 1014,
	FN_ADICHS0 = 1015,
	FN_IP13_27_24 = 1016,
	FN_HRTS0_N = 1017,
	FN_TX2_B = 1018,
	FN_MSIOF1_SS1_D = 1019,
	FN_SSI_WS9_A = 1020,
	FN_STP_IVCXO27_0_D = 1021,
	FN_BPFCLK_A = 1022,
	FN_AUDIO_CLKOUT2_A = 1023,
	FN_IP14_27_24 = 1024,
	FN_SSI_WS01239 = 1025,
	FN_MSIOF1_SS1_F = 1026,
	FN_IP15_27_24 = 1027,
	FN_SSI_WS4 = 1028,
	FN_HTX2_A = 1029,
	FN_MSIOF1_SYNC_A = 1030,
	FN_TS_SDEN0_A = 1031,
	FN_STP_ISEN_0_A = 1032,
	FN_RIF0_SYNC_A = 1033,
	FN_RIF2_SYNC_A = 1034,
	FN_IP12_31_28 = 1035,
	FN_SCK2 = 1036,
	FN_SCIF_CLK_B = 1037,
	FN_MSIOF1_SCK_B = 1038,
	FN_TS_SCK1_C = 1039,
	FN_STP_ISCLK_1_C = 1040,
	FN_RIF1_CLK_B = 1041,
	FN_ADICLK = 1042,
	FN_IP13_31_28 = 1043,
	FN_MSIOF0_SYNC = 1044,
	FN_AUDIO_CLKOUT_A = 1045,
	FN_TX5_B = 1046,
	FN_BPFCLK_D = 1047,
	FN_IP14_31_28 = 1048,
	FN_SSI_SDATA0 = 1049,
	FN_MSIOF1_SS2_F = 1050,
	FN_IP15_31_28 = 1051,
	FN_SSI_SDATA4 = 1052,
	FN_HSCK2_A = 1053,
	FN_MSIOF1_RXD_A = 1054,
	FN_TS_SPSYNC0_A = 1055,
	FN_STP_ISSYNC_0_A = 1056,
	FN_RIF0_D0_A = 1057,
	FN_RIF2_D1_A = 1058,
	FN_IP16_3_0 = 1059,
	FN_SSI_SCK6 = 1060,
	FN_SIM0_RST_D = 1061,
	FN_IP17_3_0 = 1062,
	FN_AUDIO_CLKA_A = 1063,
	FN_IP18_3_0 = 1064,
	FN_GP6_30 = 1065,
	FN_AUDIO_CLKOUT2_B = 1066,
	FN_SSI_SCK9_B = 1067,
	FN_TS_SDEN0_E = 1068,
	FN_STP_ISEN_0_E = 1069,
	FN_RIF2_D0_B = 1070,
	FN_TPU0TO2 = 1071,
	FN_FMCLK_C = 1072,
	FN_FMCLK_D = 1073,
	FN_IP16_7_4 = 1074,
	FN_SSI_WS6 = 1075,
	FN_SIM0_D_D = 1076,
	FN_IP17_7_4 = 1077,
	FN_AUDIO_CLKB_B = 1078,
	FN_SCIF_CLK_A = 1079,
	FN_STP_IVCXO27_1_D = 1080,
	FN_REMOCON_A = 1081,
	FN_TCLK1_A = 1082,
	FN_IP18_7_4 = 1083,
	FN_GP6_31 = 1084,
	FN_AUDIO_CLKOUT3_B = 1085,
	FN_SSI_WS9_B = 1086,
	FN_TS_SPSYNC0_E = 1087,
	FN_STP_ISSYNC_0_E = 1088,
	FN_RIF2_D1_B = 1089,
	FN_TPU0TO3 = 1090,
	FN_FMIN_C = 1091,
	FN_FMIN_D = 1092,
	FN_IP16_11_8 = 1093,
	FN_SSI_SDATA6 = 1094,
	FN_SIM0_CLK_D = 1095,
	FN_IP17_11_8 = 1096,
	FN_USB0_PWEN = 1097,
	FN_SIM0_RST_C = 1098,
	FN_TS_SCK1_D = 1099,
	FN_STP_ISCLK_1_D = 1100,
	FN_BPFCLK_B = 1101,
	FN_RIF3_CLK_B = 1102,
	FN_HSCK2_C = 1103,
	FN_IP16_15_12 = 1104,
	FN_SSI_SCK78 = 1105,
	FN_HRX2_B = 1106,
	FN_MSIOF1_SCK_C = 1107,
	FN_TS_SCK1_A = 1108,
	FN_STP_ISCLK_1_A = 1109,
	FN_RIF1_CLK_A = 1110,
	FN_RIF3_CLK_A = 1111,
	FN_IP17_15_12 = 1112,
	FN_USB0_OVC = 1113,
	FN_SIM0_D_C = 1114,
	FN_TS_SDAT1_D = 1115,
	FN_STP_ISD_1_D = 1116,
	FN_RIF3_SYNC_B = 1117,
	FN_HRX2_C = 1118,
	FN_IP16_19_16 = 1119,
	FN_SSI_WS78 = 1120,
	FN_HTX2_B = 1121,
	FN_MSIOF1_SYNC_C = 1122,
	FN_TS_SDAT1_A = 1123,
	FN_STP_ISD_1_A = 1124,
	FN_RIF1_SYNC_A = 1125,
	FN_RIF3_SYNC_A = 1126,
	FN_IP17_19_16 = 1127,
	FN_USB1_PWEN = 1128,
	FN_SIM0_CLK_C = 1129,
	FN_SSI_SCK1_A = 1130,
	FN_TS_SCK0_E = 1131,
	FN_STP_ISCLK_0_E = 1132,
	FN_FMCLK_B = 1133,
	FN_RIF2_CLK_B = 1134,
	FN_SPEEDIN_A = 1135,
	FN_HTX2_C = 1136,
	FN_IP16_23_20 = 1137,
	FN_SSI_SDATA7 = 1138,
	FN_HCTS2_N_B = 1139,
	FN_MSIOF1_RXD_C = 1140,
	FN_TS_SDEN1_A = 1141,
	FN_STP_ISEN_1_A = 1142,
	FN_RIF1_D0_A = 1143,
	FN_RIF3_D0_A = 1144,
	FN_TCLK2_A = 1145,
	FN_IP17_23_20 = 1146,
	FN_USB1_OVC = 1147,
	FN_MSIOF1_SS2_C = 1148,
	FN_SSI_WS1_A = 1149,
	FN_TS_SDAT0_E = 1150,
	FN_STP_ISD_0_E = 1151,
	FN_FMIN_B = 1152,
	FN_RIF2_SYNC_B = 1153,
	FN_REMOCON_B = 1154,
	FN_HCTS2_N_C = 1155,
	FN_IP16_27_24 = 1156,
	FN_SSI_SDATA8 = 1157,
	FN_HRTS2_N_B = 1158,
	FN_MSIOF1_TXD_C = 1159,
	FN_TS_SPSYNC1_A = 1160,
	FN_STP_ISSYNC_1_A = 1161,
	FN_RIF1_D1_A = 1162,
	FN_RIF3_D1_A = 1163,
	FN_IP17_27_24 = 1164,
	FN_USB30_PWEN = 1165,
	FN_AUDIO_CLKOUT_B = 1166,
	FN_SSI_SCK2_B = 1167,
	FN_TS_SDEN1_D = 1168,
	FN_STP_ISEN_1_D = 1169,
	FN_STP_OPWM_0_E = 1170,
	FN_RIF3_D0_B = 1171,
	FN_TCLK2_B = 1172,
	FN_TPU0TO0 = 1173,
	FN_BPFCLK_C = 1174,
	FN_HRTS2_N_C = 1175,
	FN_IP16_31_28 = 1176,
	FN_SSI_SDATA9_A = 1177,
	FN_HSCK2_B = 1178,
	FN_MSIOF1_SS1_C = 1179,
	FN_HSCK1_A = 1180,
	FN_SSI_WS1_B = 1181,
	FN_SCK1 = 1182,
	FN_STP_IVCXO27_1_A = 1183,
	FN_SCK5_A = 1184,
	FN_IP17_31_28 = 1185,
	FN_USB30_OVC = 1186,
	FN_AUDIO_CLKOUT1_B = 1187,
	FN_SSI_WS2_B = 1188,
	FN_TS_SPSYNC1_D = 1189,
	FN_STP_ISSYNC_1_D = 1190,
	FN_STP_IVCXO27_0_E = 1191,
	FN_RIF3_D1_B = 1192,
	FN_FSO_TOE_N = 1193,
	FN_TPU0TO1 = 1194,
	FN_SEL_MSIOF3_0 = 1195,
	FN_SEL_MSIOF3_1 = 1196,
	FN_SEL_MSIOF3_2 = 1197,
	FN_SEL_MSIOF3_3 = 1198,
	FN_SEL_MSIOF3_4 = 1199,
	FN_SEL_TSIF1_0 = 1200,
	FN_SEL_TSIF1_1 = 1201,
	FN_SEL_TSIF1_2 = 1202,
	FN_SEL_TSIF1_3 = 1203,
	FN_I2C_SEL_5_0 = 1204,
	FN_I2C_SEL_5_1 = 1205,
	FN_I2C_SEL_3_0 = 1206,
	FN_I2C_SEL_3_1 = 1207,
	FN_SEL_TSIF0_0 = 1208,
	FN_SEL_TSIF0_1 = 1209,
	FN_SEL_TSIF0_2 = 1210,
	FN_SEL_TSIF0_3 = 1211,
	FN_SEL_TSIF0_4 = 1212,
	FN_I2C_SEL_0_0 = 1213,
	FN_I2C_SEL_0_1 = 1214,
	FN_SEL_MSIOF2_0 = 1215,
	FN_SEL_MSIOF2_1 = 1216,
	FN_SEL_MSIOF2_2 = 1217,
	FN_SEL_MSIOF2_3 = 1218,
	FN_SEL_FM_0 = 1219,
	FN_SEL_FM_1 = 1220,
	FN_SEL_FM_2 = 1221,
	FN_SEL_FM_3 = 1222,
	FN_SEL_MSIOF1_0 = 1223,
	FN_SEL_MSIOF1_1 = 1224,
	FN_SEL_MSIOF1_2 = 1225,
	FN_SEL_MSIOF1_3 = 1226,
	FN_SEL_MSIOF1_4 = 1227,
	FN_SEL_MSIOF1_5 = 1228,
	FN_SEL_MSIOF1_6 = 1229,
	FN_SEL_TIMER_TMU_0 = 1230,
	FN_SEL_TIMER_TMU_1 = 1231,
	FN_SEL_SCIF5_0 = 1232,
	FN_SEL_SCIF5_1 = 1233,
	FN_SEL_SSP1_1_0 = 1234,
	FN_SEL_SSP1_1_1 = 1235,
	FN_SEL_SSP1_1_2 = 1236,
	FN_SEL_SSP1_1_3 = 1237,
	FN_SEL_I2C6_0 = 1238,
	FN_SEL_I2C6_1 = 1239,
	FN_SEL_I2C6_2 = 1240,
	FN_SEL_LBSC_0 = 1241,
	FN_SEL_LBSC_1 = 1242,
	FN_SEL_SSP1_0_0 = 1243,
	FN_SEL_SSP1_0_1 = 1244,
	FN_SEL_SSP1_0_2 = 1245,
	FN_SEL_SSP1_0_3 = 1246,
	FN_SEL_SSP1_0_4 = 1247,
	FN_SEL_IEBUS_0 = 1248,
	FN_SEL_IEBUS_1 = 1249,
	FN_SEL_NDF_0 = 1250,
	FN_SEL_NDF_1 = 1251,
	FN_SEL_I2C2_0 = 1252,
	FN_SEL_I2C2_1 = 1253,
	FN_SEL_SSI2_0 = 1254,
	FN_SEL_SSI2_1 = 1255,
	FN_SEL_I2C1_0 = 1256,
	FN_SEL_I2C1_1 = 1257,
	FN_SEL_SSI1_0 = 1258,
	FN_SEL_SSI1_1 = 1259,
	FN_SEL_SSI9_0 = 1260,
	FN_SEL_SSI9_1 = 1261,
	FN_SEL_HSCIF4_0 = 1262,
	FN_SEL_HSCIF4_1 = 1263,
	FN_SEL_SPEED_PULSE_0 = 1264,
	FN_SEL_SPEED_PULSE_1 = 1265,
	FN_SEL_TIMER_TMU2_0 = 1266,
	FN_SEL_TIMER_TMU2_1 = 1267,
	FN_SEL_HSCIF3_0 = 1268,
	FN_SEL_HSCIF3_1 = 1269,
	FN_SEL_HSCIF3_2 = 1270,
	FN_SEL_HSCIF3_3 = 1271,
	FN_SEL_SIMCARD_0 = 1272,
	FN_SEL_SIMCARD_1 = 1273,
	FN_SEL_SIMCARD_2 = 1274,
	FN_SEL_SIMCARD_3 = 1275,
	FN_SEL_ADGB_0 = 1276,
	FN_SEL_ADGB_1 = 1277,
	FN_SEL_ADGC_0 = 1278,
	FN_SEL_ADGC_1 = 1279,
	FN_SEL_HSCIF1_0 = 1280,
	FN_SEL_HSCIF1_1 = 1281,
	FN_SEL_SDHI2_0 = 1282,
	FN_SEL_SDHI2_1 = 1283,
	FN_SEL_SCIF4_0 = 1284,
	FN_SEL_SCIF4_1 = 1285,
	FN_SEL_SCIF4_2 = 1286,
	FN_SEL_HSCIF2_0 = 1287,
	FN_SEL_HSCIF2_1 = 1288,
	FN_SEL_HSCIF2_2 = 1289,
	FN_SEL_SCIF3_0 = 1290,
	FN_SEL_SCIF3_1 = 1291,
	FN_SEL_ETHERAVB_0 = 1292,
	FN_SEL_ETHERAVB_1 = 1293,
	FN_SEL_SCIF2_0 = 1294,
	FN_SEL_SCIF2_1 = 1295,
	FN_SEL_DRIF3_0 = 1296,
	FN_SEL_DRIF3_1 = 1297,
	FN_SEL_SCIF1_0 = 1298,
	FN_SEL_SCIF1_1 = 1299,
	FN_SEL_DRIF2_0 = 1300,
	FN_SEL_DRIF2_1 = 1301,
	FN_SEL_SCIF_0 = 1302,
	FN_SEL_SCIF_1 = 1303,
	FN_SEL_DRIF1_0 = 1304,
	FN_SEL_DRIF1_1 = 1305,
	FN_SEL_DRIF1_2 = 1306,
	FN_SEL_REMOCON_0 = 1307,
	FN_SEL_REMOCON_1 = 1308,
	FN_SEL_DRIF0_0 = 1309,
	FN_SEL_DRIF0_1 = 1310,
	FN_SEL_DRIF0_2 = 1311,
	FN_SEL_RCAN0_0 = 1312,
	FN_SEL_RCAN0_1 = 1313,
	FN_SEL_CANFD0_0 = 1314,
	FN_SEL_CANFD0_1 = 1315,
	FN_SEL_PWM6_0 = 1316,
	FN_SEL_PWM6_1 = 1317,
	FN_SEL_ADGA_0 = 1318,
	FN_SEL_ADGA_1 = 1319,
	FN_SEL_ADGA_2 = 1320,
	FN_SEL_ADGA_3 = 1321,
	FN_SEL_PWM5_0 = 1322,
	FN_SEL_PWM5_1 = 1323,
	FN_SEL_PWM4_0 = 1324,
	FN_SEL_PWM4_1 = 1325,
	FN_SEL_PWM3_0 = 1326,
	FN_SEL_PWM3_1 = 1327,
	FN_SEL_PWM2_0 = 1328,
	FN_SEL_PWM2_1 = 1329,
	FN_SEL_PWM1_0 = 1330,
	FN_SEL_PWM1_1 = 1331,
	FN_SEL_VIN4_0 = 1332,
	FN_SEL_VIN4_1 = 1333,
	PINMUX_FUNCTION_END = 1334,
	PINMUX_MARK_BEGIN = 1335,
	CLKOUT_MARK = 1336,
	MSIOF0_RXD_MARK = 1337,
	MSIOF0_TXD_MARK = 1338,
	MSIOF0_SCK_MARK = 1339,
	SSI_SDATA5_MARK = 1340,
	SSI_WS5_MARK = 1341,
	SSI_SCK5_MARK = 1342,
	GP7_03_MARK = 1343,
	GP7_02_MARK = 1344,
	AVS2_MARK = 1345,
	AVS1_MARK = 1346,
	IP0_3_0_MARK = 1347,
	AVB_MDC_MARK = 1348,
	MSIOF2_SS2_C_MARK = 1349,
	IP1_3_0_MARK = 1350,
	IRQ2_MARK = 1351,
	QCPV_QDE_MARK = 1352,
	DU_EXODDF_DU_ODDF_DISP_CDE_MARK = 1353,
	VI4_DATA2_B_MARK = 1354,
	MSIOF3_SYNC_E_MARK = 1355,
	PWM3_B_MARK = 1356,
	IP2_3_0_MARK = 1357,
	A1_MARK = 1358,
	LCDOUT17_MARK = 1359,
	MSIOF3_TXD_B_MARK = 1360,
	VI4_DATA9_MARK = 1361,
	DU_DB1_MARK = 1362,
	PWM4_A_MARK = 1363,
	IP3_3_0_MARK = 1364,
	A9_MARK = 1365,
	MSIOF2_SCK_A_MARK = 1366,
	CTS4_N_B_MARK = 1367,
	VI5_VSYNC_N_MARK = 1368,
	IP0_7_4_MARK = 1369,
	AVB_MAGIC_MARK = 1370,
	MSIOF2_SS1_C_MARK = 1371,
	SCK4_A_MARK = 1372,
	IP1_7_4_MARK = 1373,
	IRQ3_MARK = 1374,
	QSTVB_QVE_MARK = 1375,
	DU_DOTCLKOUT1_MARK = 1376,
	VI4_DATA3_B_MARK = 1377,
	MSIOF3_SCK_E_MARK = 1378,
	PWM4_B_MARK = 1379,
	IP2_7_4_MARK = 1380,
	A2_MARK = 1381,
	LCDOUT18_MARK = 1382,
	MSIOF3_SCK_B_MARK = 1383,
	VI4_DATA10_MARK = 1384,
	DU_DB2_MARK = 1385,
	PWM5_A_MARK = 1386,
	IP3_7_4_MARK = 1387,
	A10_MARK = 1388,
	MSIOF2_RXD_A_MARK = 1389,
	RTS4_N_B_MARK = 1390,
	VI5_HSYNC_N_MARK = 1391,
	IP0_11_8_MARK = 1392,
	AVB_PHY_INT_MARK = 1393,
	MSIOF2_SYNC_C_MARK = 1394,
	RX4_A_MARK = 1395,
	IP1_11_8_MARK = 1396,
	IRQ4_MARK = 1397,
	QSTH_QHS_MARK = 1398,
	DU_EXHSYNC_DU_HSYNC_MARK = 1399,
	VI4_DATA4_B_MARK = 1400,
	MSIOF3_RXD_E_MARK = 1401,
	PWM5_B_MARK = 1402,
	IP2_11_8_MARK = 1403,
	A3_MARK = 1404,
	LCDOUT19_MARK = 1405,
	MSIOF3_RXD_B_MARK = 1406,
	VI4_DATA11_MARK = 1407,
	DU_DB3_MARK = 1408,
	PWM6_A_MARK = 1409,
	IP3_11_8_MARK = 1410,
	A11_MARK = 1411,
	TX3_B_MARK = 1412,
	MSIOF2_TXD_A_MARK = 1413,
	HTX4_B_MARK = 1414,
	HSCK4_MARK = 1415,
	VI5_FIELD_MARK = 1416,
	SCL6_A_MARK = 1417,
	AVB_AVTP_CAPTURE_B_MARK = 1418,
	PWM2_B_MARK = 1419,
	IP0_15_12_MARK = 1420,
	AVB_LINK_MARK = 1421,
	MSIOF2_SCK_C_MARK = 1422,
	TX4_A_MARK = 1423,
	IP1_15_12_MARK = 1424,
	IRQ5_MARK = 1425,
	QSTB_QHE_MARK = 1426,
	DU_EXVSYNC_DU_VSYNC_MARK = 1427,
	VI4_DATA5_B_MARK = 1428,
	MSIOF3_TXD_E_MARK = 1429,
	PWM6_B_MARK = 1430,
	IP2_15_12_MARK = 1431,
	A4_MARK = 1432,
	LCDOUT20_MARK = 1433,
	MSIOF3_SS1_B_MARK = 1434,
	VI4_DATA12_MARK = 1435,
	VI5_DATA12_MARK = 1436,
	DU_DB4_MARK = 1437,
	IP3_15_12_MARK = 1438,
	A12_MARK = 1439,
	LCDOUT12_MARK = 1440,
	MSIOF3_SCK_C_MARK = 1441,
	HRX4_A_MARK = 1442,
	VI5_DATA8_MARK = 1443,
	DU_DG4_MARK = 1444,
	IP0_19_16_MARK = 1445,
	AVB_AVTP_MATCH_A_MARK = 1446,
	MSIOF2_RXD_C_MARK = 1447,
	CTS4_N_A_MARK = 1448,
	IP1_19_16_MARK = 1449,
	PWM0_MARK = 1450,
	AVB_AVTP_PPS_MARK = 1451,
	VI4_DATA6_B_MARK = 1452,
	IECLK_B_MARK = 1453,
	IP2_19_16_MARK = 1454,
	A5_MARK = 1455,
	LCDOUT21_MARK = 1456,
	MSIOF3_SS2_B_MARK = 1457,
	SCK4_B_MARK = 1458,
	VI4_DATA13_MARK = 1459,
	VI5_DATA13_MARK = 1460,
	DU_DB5_MARK = 1461,
	IP3_19_16_MARK = 1462,
	A13_MARK = 1463,
	LCDOUT13_MARK = 1464,
	MSIOF3_SYNC_C_MARK = 1465,
	HTX4_A_MARK = 1466,
	VI5_DATA9_MARK = 1467,
	DU_DG5_MARK = 1468,
	IP0_23_20_MARK = 1469,
	AVB_AVTP_CAPTURE_A_MARK = 1470,
	MSIOF2_TXD_C_MARK = 1471,
	RTS4_N_A_MARK = 1472,
	IP1_23_20_MARK = 1473,
	PWM1_A_MARK = 1474,
	HRX3_D_MARK = 1475,
	VI4_DATA7_B_MARK = 1476,
	IERX_B_MARK = 1477,
	IP2_23_20_MARK = 1478,
	A6_MARK = 1479,
	LCDOUT22_MARK = 1480,
	MSIOF2_SS1_A_MARK = 1481,
	RX4_B_MARK = 1482,
	VI4_DATA14_MARK = 1483,
	VI5_DATA14_MARK = 1484,
	DU_DB6_MARK = 1485,
	IP3_23_20_MARK = 1486,
	A14_MARK = 1487,
	LCDOUT14_MARK = 1488,
	MSIOF3_RXD_C_MARK = 1489,
	HCTS4_N_MARK = 1490,
	VI5_DATA10_MARK = 1491,
	DU_DG6_MARK = 1492,
	IP0_27_24_MARK = 1493,
	IRQ0_MARK = 1494,
	QPOLB_MARK = 1495,
	DU_CDE_MARK = 1496,
	VI4_DATA0_B_MARK = 1497,
	CAN0_TX_B_MARK = 1498,
	CANFD0_TX_B_MARK = 1499,
	MSIOF3_SS2_E_MARK = 1500,
	IP1_27_24_MARK = 1501,
	PWM2_A_MARK = 1502,
	HTX3_D_MARK = 1503,
	IETX_B_MARK = 1504,
	IP2_27_24_MARK = 1505,
	A7_MARK = 1506,
	LCDOUT23_MARK = 1507,
	MSIOF2_SS2_A_MARK = 1508,
	TX4_B_MARK = 1509,
	VI4_DATA15_MARK = 1510,
	VI5_DATA15_MARK = 1511,
	DU_DB7_MARK = 1512,
	IP3_27_24_MARK = 1513,
	A15_MARK = 1514,
	LCDOUT15_MARK = 1515,
	MSIOF3_TXD_C_MARK = 1516,
	HRTS4_N_MARK = 1517,
	VI5_DATA11_MARK = 1518,
	DU_DG7_MARK = 1519,
	IP0_31_28_MARK = 1520,
	IRQ1_MARK = 1521,
	QPOLA_MARK = 1522,
	DU_DISP_MARK = 1523,
	VI4_DATA1_B_MARK = 1524,
	CAN0_RX_B_MARK = 1525,
	CANFD0_RX_B_MARK = 1526,
	MSIOF3_SS1_E_MARK = 1527,
	IP1_31_28_MARK = 1528,
	A0_MARK = 1529,
	LCDOUT16_MARK = 1530,
	MSIOF3_SYNC_B_MARK = 1531,
	VI4_DATA8_MARK = 1532,
	DU_DB0_MARK = 1533,
	PWM3_A_MARK = 1534,
	IP2_31_28_MARK = 1535,
	A8_MARK = 1536,
	RX3_B_MARK = 1537,
	MSIOF2_SYNC_A_MARK = 1538,
	HRX4_B_MARK = 1539,
	SDA6_A_MARK = 1540,
	AVB_AVTP_MATCH_B_MARK = 1541,
	PWM1_B_MARK = 1542,
	IP3_31_28_MARK = 1543,
	A16_MARK = 1544,
	LCDOUT8_MARK = 1545,
	VI4_FIELD_MARK = 1546,
	DU_DG0_MARK = 1547,
	IP4_3_0_MARK = 1548,
	A17_MARK = 1549,
	LCDOUT9_MARK = 1550,
	VI4_VSYNC_N_MARK = 1551,
	DU_DG1_MARK = 1552,
	IP5_3_0_MARK = 1553,
	WE0_N_MARK = 1554,
	MSIOF3_TXD_D_MARK = 1555,
	CTS3_N_MARK = 1556,
	HCTS3_N_MARK = 1557,
	SCL6_B_MARK = 1558,
	CAN_CLK_MARK = 1559,
	IECLK_A_MARK = 1560,
	IP6_3_0_MARK = 1561,
	D5_MARK = 1562,
	MSIOF2_SYNC_B_MARK = 1563,
	VI4_DATA21_MARK = 1564,
	VI5_DATA5_MARK = 1565,
	IP7_3_0_MARK = 1566,
	D13_MARK = 1567,
	LCDOUT5_MARK = 1568,
	MSIOF2_SS2_D_MARK = 1569,
	TX4_C_MARK = 1570,
	VI4_DATA5_A_MARK = 1571,
	DU_DR5_MARK = 1572,
	IP4_7_4_MARK = 1573,
	A18_MARK = 1574,
	LCDOUT10_MARK = 1575,
	VI4_HSYNC_N_MARK = 1576,
	DU_DG2_MARK = 1577,
	IP5_7_4_MARK = 1578,
	WE1_N_MARK = 1579,
	MSIOF3_SS1_D_MARK = 1580,
	RTS3_N_MARK = 1581,
	HRTS3_N_MARK = 1582,
	SDA6_B_MARK = 1583,
	CAN1_RX_MARK = 1584,
	CANFD1_RX_MARK = 1585,
	IERX_A_MARK = 1586,
	IP6_7_4_MARK = 1587,
	D6_MARK = 1588,
	MSIOF2_RXD_B_MARK = 1589,
	VI4_DATA22_MARK = 1590,
	VI5_DATA6_MARK = 1591,
	IP7_7_4_MARK = 1592,
	D14_MARK = 1593,
	LCDOUT6_MARK = 1594,
	MSIOF3_SS1_A_MARK = 1595,
	HRX3_C_MARK = 1596,
	VI4_DATA6_A_MARK = 1597,
	DU_DR6_MARK = 1598,
	SCL6_C_MARK = 1599,
	IP4_11_8_MARK = 1600,
	A19_MARK = 1601,
	LCDOUT11_MARK = 1602,
	VI4_CLKENB_MARK = 1603,
	DU_DG3_MARK = 1604,
	IP5_11_8_MARK = 1605,
	EX_WAIT0_A_MARK = 1606,
	QCLK_MARK = 1607,
	VI4_CLK_MARK = 1608,
	DU_DOTCLKOUT0_MARK = 1609,
	IP6_11_8_MARK = 1610,
	D7_MARK = 1611,
	MSIOF2_TXD_B_MARK = 1612,
	VI4_DATA23_MARK = 1613,
	VI5_DATA7_MARK = 1614,
	IP7_11_8_MARK = 1615,
	D15_MARK = 1616,
	LCDOUT7_MARK = 1617,
	MSIOF3_SS2_A_MARK = 1618,
	HTX3_C_MARK = 1619,
	VI4_DATA7_A_MARK = 1620,
	DU_DR7_MARK = 1621,
	SDA6_C_MARK = 1622,
	IP4_15_12_MARK = 1623,
	CS0_N_MARK = 1624,
	VI5_CLKENB_MARK = 1625,
	IP5_15_12_MARK = 1626,
	D0_MARK = 1627,
	MSIOF2_SS1_B_MARK = 1628,
	MSIOF3_SCK_A_MARK = 1629,
	VI4_DATA16_MARK = 1630,
	VI5_DATA0_MARK = 1631,
	IP6_15_12_MARK = 1632,
	D8_MARK = 1633,
	LCDOUT0_MARK = 1634,
	MSIOF2_SCK_D_MARK = 1635,
	SCK4_C_MARK = 1636,
	VI4_DATA0_A_MARK = 1637,
	DU_DR0_MARK = 1638,
	IP4_19_16_MARK = 1639,
	CS1_N_MARK = 1640,
	VI5_CLK_MARK = 1641,
	EX_WAIT0_B_MARK = 1642,
	IP5_19_16_MARK = 1643,
	D1_MARK = 1644,
	MSIOF2_SS2_B_MARK = 1645,
	MSIOF3_SYNC_A_MARK = 1646,
	VI4_DATA17_MARK = 1647,
	VI5_DATA1_MARK = 1648,
	IP6_19_16_MARK = 1649,
	D9_MARK = 1650,
	LCDOUT1_MARK = 1651,
	MSIOF2_SYNC_D_MARK = 1652,
	VI4_DATA1_A_MARK = 1653,
	DU_DR1_MARK = 1654,
	IP7_19_16_MARK = 1655,
	SD0_CLK_MARK = 1656,
	MSIOF1_SCK_E_MARK = 1657,
	STP_OPWM_0_B_MARK = 1658,
	IP4_23_20_MARK = 1659,
	BS_N_MARK = 1660,
	QSTVA_QVS_MARK = 1661,
	MSIOF3_SCK_D_MARK = 1662,
	SCK3_MARK = 1663,
	HSCK3_MARK = 1664,
	CAN1_TX_MARK = 1665,
	CANFD1_TX_MARK = 1666,
	IETX_A_MARK = 1667,
	IP5_23_20_MARK = 1668,
	D2_MARK = 1669,
	MSIOF3_RXD_A_MARK = 1670,
	VI4_DATA18_MARK = 1671,
	VI5_DATA2_MARK = 1672,
	IP6_23_20_MARK = 1673,
	D10_MARK = 1674,
	LCDOUT2_MARK = 1675,
	MSIOF2_RXD_D_MARK = 1676,
	HRX3_B_MARK = 1677,
	VI4_DATA2_A_MARK = 1678,
	CTS4_N_C_MARK = 1679,
	DU_DR2_MARK = 1680,
	IP7_23_20_MARK = 1681,
	SD0_CMD_MARK = 1682,
	MSIOF1_SYNC_E_MARK = 1683,
	STP_IVCXO27_0_B_MARK = 1684,
	IP4_27_24_MARK = 1685,
	RD_N_MARK = 1686,
	MSIOF3_SYNC_D_MARK = 1687,
	RX3_A_MARK = 1688,
	HRX3_A_MARK = 1689,
	CAN0_TX_A_MARK = 1690,
	CANFD0_TX_A_MARK = 1691,
	IP5_27_24_MARK = 1692,
	D3_MARK = 1693,
	MSIOF3_TXD_A_MARK = 1694,
	VI4_DATA19_MARK = 1695,
	VI5_DATA3_MARK = 1696,
	IP6_27_24_MARK = 1697,
	D11_MARK = 1698,
	LCDOUT3_MARK = 1699,
	MSIOF2_TXD_D_MARK = 1700,
	HTX3_B_MARK = 1701,
	VI4_DATA3_A_MARK = 1702,
	RTS4_N_C_MARK = 1703,
	DU_DR3_MARK = 1704,
	IP7_27_24_MARK = 1705,
	SD0_DAT0_MARK = 1706,
	MSIOF1_RXD_E_MARK = 1707,
	TS_SCK0_B_MARK = 1708,
	STP_ISCLK_0_B_MARK = 1709,
	IP4_31_28_MARK = 1710,
	RD_WR_N_MARK = 1711,
	MSIOF3_RXD_D_MARK = 1712,
	TX3_A_MARK = 1713,
	HTX3_A_MARK = 1714,
	CAN0_RX_A_MARK = 1715,
	CANFD0_RX_A_MARK = 1716,
	IP5_31_28_MARK = 1717,
	D4_MARK = 1718,
	MSIOF2_SCK_B_MARK = 1719,
	VI4_DATA20_MARK = 1720,
	VI5_DATA4_MARK = 1721,
	IP6_31_28_MARK = 1722,
	D12_MARK = 1723,
	LCDOUT4_MARK = 1724,
	MSIOF2_SS1_D_MARK = 1725,
	RX4_C_MARK = 1726,
	VI4_DATA4_A_MARK = 1727,
	DU_DR4_MARK = 1728,
	IP7_31_28_MARK = 1729,
	SD0_DAT1_MARK = 1730,
	MSIOF1_TXD_E_MARK = 1731,
	TS_SPSYNC0_B_MARK = 1732,
	STP_ISSYNC_0_B_MARK = 1733,
	IP8_3_0_MARK = 1734,
	SD0_DAT2_MARK = 1735,
	MSIOF1_SS1_E_MARK = 1736,
	TS_SDAT0_B_MARK = 1737,
	STP_ISD_0_B_MARK = 1738,
	IP9_3_0_MARK = 1739,
	SD2_CLK_MARK = 1740,
	NFDATA8_MARK = 1741,
	IP10_3_0_MARK = 1742,
	SD3_CMD_MARK = 1743,
	NFRE_N_MARK = 1744,
	IP11_3_0_MARK = 1745,
	SD3_DAT7_MARK = 1746,
	SD3_WP_MARK = 1747,
	NFDATA7_MARK = 1748,
	IP8_7_4_MARK = 1749,
	SD0_DAT3_MARK = 1750,
	MSIOF1_SS2_E_MARK = 1751,
	TS_SDEN0_B_MARK = 1752,
	STP_ISEN_0_B_MARK = 1753,
	IP9_7_4_MARK = 1754,
	SD2_CMD_MARK = 1755,
	NFDATA9_MARK = 1756,
	IP10_7_4_MARK = 1757,
	SD3_DAT0_MARK = 1758,
	NFDATA0_MARK = 1759,
	IP11_7_4_MARK = 1760,
	SD3_DS_MARK = 1761,
	NFCLE_MARK = 1762,
	IP8_11_8_MARK = 1763,
	SD1_CLK_MARK = 1764,
	MSIOF1_SCK_G_MARK = 1765,
	SIM0_CLK_A_MARK = 1766,
	IP9_11_8_MARK = 1767,
	SD2_DAT0_MARK = 1768,
	NFDATA10_MARK = 1769,
	IP10_11_8_MARK = 1770,
	SD3_DAT1_MARK = 1771,
	NFDATA1_MARK = 1772,
	IP11_11_8_MARK = 1773,
	SD0_CD_MARK = 1774,
	NFDATA14_A_MARK = 1775,
	SCL2_B_MARK = 1776,
	SIM0_RST_A_MARK = 1777,
	IP8_15_12_MARK = 1778,
	SD1_CMD_MARK = 1779,
	MSIOF1_SYNC_G_MARK = 1780,
	NFCE_N_B_MARK = 1781,
	SIM0_D_A_MARK = 1782,
	STP_IVCXO27_1_B_MARK = 1783,
	IP9_15_12_MARK = 1784,
	SD2_DAT1_MARK = 1785,
	NFDATA11_MARK = 1786,
	IP10_15_12_MARK = 1787,
	SD3_DAT2_MARK = 1788,
	NFDATA2_MARK = 1789,
	IP11_15_12_MARK = 1790,
	SD0_WP_MARK = 1791,
	NFDATA15_A_MARK = 1792,
	SDA2_B_MARK = 1793,
	IP8_19_16_MARK = 1794,
	SD1_DAT0_MARK = 1795,
	SD2_DAT4_MARK = 1796,
	MSIOF1_RXD_G_MARK = 1797,
	NFWP_N_B_MARK = 1798,
	TS_SCK1_B_MARK = 1799,
	STP_ISCLK_1_B_MARK = 1800,
	IP9_19_16_MARK = 1801,
	SD2_DAT2_MARK = 1802,
	NFDATA12_MARK = 1803,
	IP10_19_16_MARK = 1804,
	SD3_DAT3_MARK = 1805,
	NFDATA3_MARK = 1806,
	IP11_19_16_MARK = 1807,
	SD1_CD_MARK = 1808,
	NFRB_N_A_MARK = 1809,
	SIM0_CLK_B_MARK = 1810,
	IP8_23_20_MARK = 1811,
	SD1_DAT1_MARK = 1812,
	SD2_DAT5_MARK = 1813,
	MSIOF1_TXD_G_MARK = 1814,
	NFDATA14_B_MARK = 1815,
	TS_SPSYNC1_B_MARK = 1816,
	STP_ISSYNC_1_B_MARK = 1817,
	IP9_23_20_MARK = 1818,
	SD2_DAT3_MARK = 1819,
	NFDATA13_MARK = 1820,
	IP10_23_20_MARK = 1821,
	SD3_DAT4_MARK = 1822,
	SD2_CD_A_MARK = 1823,
	NFDATA4_MARK = 1824,
	IP11_23_20_MARK = 1825,
	SD1_WP_MARK = 1826,
	NFCE_N_A_MARK = 1827,
	SIM0_D_B_MARK = 1828,
	IP8_27_24_MARK = 1829,
	SD1_DAT2_MARK = 1830,
	SD2_DAT6_MARK = 1831,
	MSIOF1_SS1_G_MARK = 1832,
	NFDATA15_B_MARK = 1833,
	TS_SDAT1_B_MARK = 1834,
	STP_ISD_1_B_MARK = 1835,
	IP9_27_24_MARK = 1836,
	SD2_DS_MARK = 1837,
	NFALE_MARK = 1838,
	IP10_27_24_MARK = 1839,
	SD3_DAT5_MARK = 1840,
	SD2_WP_A_MARK = 1841,
	NFDATA5_MARK = 1842,
	IP11_27_24_MARK = 1843,
	SCK0_MARK = 1844,
	HSCK1_B_MARK = 1845,
	MSIOF1_SS2_B_MARK = 1846,
	AUDIO_CLKC_B_MARK = 1847,
	SDA2_A_MARK = 1848,
	SIM0_RST_B_MARK = 1849,
	STP_OPWM_0_C_MARK = 1850,
	RIF0_CLK_B_MARK = 1851,
	ADICHS2_MARK = 1852,
	SCK5_B_MARK = 1853,
	IP8_31_28_MARK = 1854,
	SD1_DAT3_MARK = 1855,
	SD2_DAT7_MARK = 1856,
	MSIOF1_SS2_G_MARK = 1857,
	NFRB_N_B_MARK = 1858,
	TS_SDEN1_B_MARK = 1859,
	STP_ISEN_1_B_MARK = 1860,
	IP9_31_28_MARK = 1861,
	SD3_CLK_MARK = 1862,
	NFWE_N_MARK = 1863,
	IP10_31_28_MARK = 1864,
	SD3_DAT6_MARK = 1865,
	SD3_CD_MARK = 1866,
	NFDATA6_MARK = 1867,
	IP11_31_28_MARK = 1868,
	RX0_MARK = 1869,
	HRX1_B_MARK = 1870,
	TS_SCK0_C_MARK = 1871,
	STP_ISCLK_0_C_MARK = 1872,
	RIF0_D0_B_MARK = 1873,
	IP12_3_0_MARK = 1874,
	TX0_MARK = 1875,
	HTX1_B_MARK = 1876,
	TS_SPSYNC0_C_MARK = 1877,
	STP_ISSYNC_0_C_MARK = 1878,
	RIF0_D1_B_MARK = 1879,
	IP13_3_0_MARK = 1880,
	TX2_A_MARK = 1881,
	SD2_CD_B_MARK = 1882,
	SCL1_A_MARK = 1883,
	FMCLK_A_MARK = 1884,
	RIF1_D1_C_MARK = 1885,
	FSO_CFE_0_N_MARK = 1886,
	IP14_3_0_MARK = 1887,
	MSIOF0_SS1_MARK = 1888,
	RX5_A_MARK = 1889,
	NFWP_N_A_MARK = 1890,
	AUDIO_CLKA_C_MARK = 1891,
	SSI_SCK2_A_MARK = 1892,
	STP_IVCXO27_0_C_MARK = 1893,
	AUDIO_CLKOUT3_A_MARK = 1894,
	TCLK1_B_MARK = 1895,
	IP15_3_0_MARK = 1896,
	SSI_SDATA1_A_MARK = 1897,
	IP12_7_4_MARK = 1898,
	CTS0_N_MARK = 1899,
	HCTS1_N_B_MARK = 1900,
	MSIOF1_SYNC_B_MARK = 1901,
	TS_SPSYNC1_C_MARK = 1902,
	STP_ISSYNC_1_C_MARK = 1903,
	RIF1_SYNC_B_MARK = 1904,
	AUDIO_CLKOUT_C_MARK = 1905,
	ADICS_SAMP_MARK = 1906,
	IP13_7_4_MARK = 1907,
	RX2_A_MARK = 1908,
	SD2_WP_B_MARK = 1909,
	SDA1_A_MARK = 1910,
	FMIN_A_MARK = 1911,
	RIF1_SYNC_C_MARK = 1912,
	FSO_CFE_1_N_MARK = 1913,
	IP14_7_4_MARK = 1914,
	MSIOF0_SS2_MARK = 1915,
	TX5_A_MARK = 1916,
	MSIOF1_SS2_D_MARK = 1917,
	AUDIO_CLKC_A_MARK = 1918,
	SSI_WS2_A_MARK = 1919,
	STP_OPWM_0_D_MARK = 1920,
	AUDIO_CLKOUT_D_MARK = 1921,
	SPEEDIN_B_MARK = 1922,
	IP15_7_4_MARK = 1923,
	SSI_SDATA2_A_MARK = 1924,
	SSI_SCK1_B_MARK = 1925,
	IP12_11_8_MARK = 1926,
	RTS0_N_MARK = 1927,
	HRTS1_N_B_MARK = 1928,
	MSIOF1_SS1_B_MARK = 1929,
	AUDIO_CLKA_B_MARK = 1930,
	SCL2_A_MARK = 1931,
	STP_IVCXO27_1_C_MARK = 1932,
	RIF0_SYNC_B_MARK = 1933,
	ADICHS1_MARK = 1934,
	IP13_11_8_MARK = 1935,
	HSCK0_MARK = 1936,
	MSIOF1_SCK_D_MARK = 1937,
	AUDIO_CLKB_A_MARK = 1938,
	SSI_SDATA1_B_MARK = 1939,
	TS_SCK0_D_MARK = 1940,
	STP_ISCLK_0_D_MARK = 1941,
	RIF0_CLK_C_MARK = 1942,
	RX5_B_MARK = 1943,
	IP14_11_8_MARK = 1944,
	MLB_CLK_MARK = 1945,
	MSIOF1_SCK_F_MARK = 1946,
	SCL1_B_MARK = 1947,
	IP15_11_8_MARK = 1948,
	SSI_SCK349_MARK = 1949,
	MSIOF1_SS1_A_MARK = 1950,
	STP_OPWM_0_A_MARK = 1951,
	IP12_15_12_MARK = 1952,
	RX1_A_MARK = 1953,
	HRX1_A_MARK = 1954,
	TS_SDAT0_C_MARK = 1955,
	STP_ISD_0_C_MARK = 1956,
	RIF1_CLK_C_MARK = 1957,
	IP13_15_12_MARK = 1958,
	HRX0_MARK = 1959,
	MSIOF1_RXD_D_MARK = 1960,
	SSI_SDATA2_B_MARK = 1961,
	TS_SDEN0_D_MARK = 1962,
	STP_ISEN_0_D_MARK = 1963,
	RIF0_D0_C_MARK = 1964,
	IP14_15_12_MARK = 1965,
	MLB_SIG_MARK = 1966,
	RX1_B_MARK = 1967,
	MSIOF1_SYNC_F_MARK = 1968,
	SDA1_B_MARK = 1969,
	IP15_15_12_MARK = 1970,
	SSI_WS349_MARK = 1971,
	HCTS2_N_A_MARK = 1972,
	MSIOF1_SS2_A_MARK = 1973,
	STP_IVCXO27_0_A_MARK = 1974,
	IP12_19_16_MARK = 1975,
	TX1_A_MARK = 1976,
	HTX1_A_MARK = 1977,
	TS_SDEN0_C_MARK = 1978,
	STP_ISEN_0_C_MARK = 1979,
	RIF1_D0_C_MARK = 1980,
	IP13_19_16_MARK = 1981,
	HTX0_MARK = 1982,
	MSIOF1_TXD_D_MARK = 1983,
	SSI_SDATA9_B_MARK = 1984,
	TS_SDAT0_D_MARK = 1985,
	STP_ISD_0_D_MARK = 1986,
	RIF0_D1_C_MARK = 1987,
	IP14_19_16_MARK = 1988,
	MLB_DAT_MARK = 1989,
	TX1_B_MARK = 1990,
	MSIOF1_RXD_F_MARK = 1991,
	IP15_19_16_MARK = 1992,
	SSI_SDATA3_MARK = 1993,
	HRTS2_N_A_MARK = 1994,
	MSIOF1_TXD_A_MARK = 1995,
	TS_SCK0_A_MARK = 1996,
	STP_ISCLK_0_A_MARK = 1997,
	RIF0_D1_A_MARK = 1998,
	RIF2_D0_A_MARK = 1999,
	IP12_23_20_MARK = 2000,
	CTS1_N_MARK = 2001,
	HCTS1_N_A_MARK = 2002,
	MSIOF1_RXD_B_MARK = 2003,
	TS_SDEN1_C_MARK = 2004,
	STP_ISEN_1_C_MARK = 2005,
	RIF1_D0_B_MARK = 2006,
	ADIDATA_MARK = 2007,
	IP13_23_20_MARK = 2008,
	HCTS0_N_MARK = 2009,
	RX2_B_MARK = 2010,
	MSIOF1_SYNC_D_MARK = 2011,
	SSI_SCK9_A_MARK = 2012,
	TS_SPSYNC0_D_MARK = 2013,
	STP_ISSYNC_0_D_MARK = 2014,
	RIF0_SYNC_C_MARK = 2015,
	AUDIO_CLKOUT1_A_MARK = 2016,
	IP14_23_20_MARK = 2017,
	SSI_SCK01239_MARK = 2018,
	MSIOF1_TXD_F_MARK = 2019,
	IP15_23_20_MARK = 2020,
	SSI_SCK4_MARK = 2021,
	HRX2_A_MARK = 2022,
	MSIOF1_SCK_A_MARK = 2023,
	TS_SDAT0_A_MARK = 2024,
	STP_ISD_0_A_MARK = 2025,
	RIF0_CLK_A_MARK = 2026,
	RIF2_CLK_A_MARK = 2027,
	IP12_27_24_MARK = 2028,
	RTS1_N_MARK = 2029,
	HRTS1_N_A_MARK = 2030,
	MSIOF1_TXD_B_MARK = 2031,
	TS_SDAT1_C_MARK = 2032,
	STP_ISD_1_C_MARK = 2033,
	RIF1_D1_B_MARK = 2034,
	ADICHS0_MARK = 2035,
	IP13_27_24_MARK = 2036,
	HRTS0_N_MARK = 2037,
	TX2_B_MARK = 2038,
	MSIOF1_SS1_D_MARK = 2039,
	SSI_WS9_A_MARK = 2040,
	STP_IVCXO27_0_D_MARK = 2041,
	BPFCLK_A_MARK = 2042,
	AUDIO_CLKOUT2_A_MARK = 2043,
	IP14_27_24_MARK = 2044,
	SSI_WS01239_MARK = 2045,
	MSIOF1_SS1_F_MARK = 2046,
	IP15_27_24_MARK = 2047,
	SSI_WS4_MARK = 2048,
	HTX2_A_MARK = 2049,
	MSIOF1_SYNC_A_MARK = 2050,
	TS_SDEN0_A_MARK = 2051,
	STP_ISEN_0_A_MARK = 2052,
	RIF0_SYNC_A_MARK = 2053,
	RIF2_SYNC_A_MARK = 2054,
	IP12_31_28_MARK = 2055,
	SCK2_MARK = 2056,
	SCIF_CLK_B_MARK = 2057,
	MSIOF1_SCK_B_MARK = 2058,
	TS_SCK1_C_MARK = 2059,
	STP_ISCLK_1_C_MARK = 2060,
	RIF1_CLK_B_MARK = 2061,
	ADICLK_MARK = 2062,
	IP13_31_28_MARK = 2063,
	MSIOF0_SYNC_MARK = 2064,
	AUDIO_CLKOUT_A_MARK = 2065,
	TX5_B_MARK = 2066,
	BPFCLK_D_MARK = 2067,
	IP14_31_28_MARK = 2068,
	SSI_SDATA0_MARK = 2069,
	MSIOF1_SS2_F_MARK = 2070,
	IP15_31_28_MARK = 2071,
	SSI_SDATA4_MARK = 2072,
	HSCK2_A_MARK = 2073,
	MSIOF1_RXD_A_MARK = 2074,
	TS_SPSYNC0_A_MARK = 2075,
	STP_ISSYNC_0_A_MARK = 2076,
	RIF0_D0_A_MARK = 2077,
	RIF2_D1_A_MARK = 2078,
	IP16_3_0_MARK = 2079,
	SSI_SCK6_MARK = 2080,
	SIM0_RST_D_MARK = 2081,
	IP17_3_0_MARK = 2082,
	AUDIO_CLKA_A_MARK = 2083,
	IP18_3_0_MARK = 2084,
	GP6_30_MARK = 2085,
	AUDIO_CLKOUT2_B_MARK = 2086,
	SSI_SCK9_B_MARK = 2087,
	TS_SDEN0_E_MARK = 2088,
	STP_ISEN_0_E_MARK = 2089,
	RIF2_D0_B_MARK = 2090,
	TPU0TO2_MARK = 2091,
	FMCLK_C_MARK = 2092,
	FMCLK_D_MARK = 2093,
	IP16_7_4_MARK = 2094,
	SSI_WS6_MARK = 2095,
	SIM0_D_D_MARK = 2096,
	IP17_7_4_MARK = 2097,
	AUDIO_CLKB_B_MARK = 2098,
	SCIF_CLK_A_MARK = 2099,
	STP_IVCXO27_1_D_MARK = 2100,
	REMOCON_A_MARK = 2101,
	TCLK1_A_MARK = 2102,
	IP18_7_4_MARK = 2103,
	GP6_31_MARK = 2104,
	AUDIO_CLKOUT3_B_MARK = 2105,
	SSI_WS9_B_MARK = 2106,
	TS_SPSYNC0_E_MARK = 2107,
	STP_ISSYNC_0_E_MARK = 2108,
	RIF2_D1_B_MARK = 2109,
	TPU0TO3_MARK = 2110,
	FMIN_C_MARK = 2111,
	FMIN_D_MARK = 2112,
	IP16_11_8_MARK = 2113,
	SSI_SDATA6_MARK = 2114,
	SIM0_CLK_D_MARK = 2115,
	IP17_11_8_MARK = 2116,
	USB0_PWEN_MARK = 2117,
	SIM0_RST_C_MARK = 2118,
	TS_SCK1_D_MARK = 2119,
	STP_ISCLK_1_D_MARK = 2120,
	BPFCLK_B_MARK = 2121,
	RIF3_CLK_B_MARK = 2122,
	HSCK2_C_MARK = 2123,
	IP16_15_12_MARK = 2124,
	SSI_SCK78_MARK = 2125,
	HRX2_B_MARK = 2126,
	MSIOF1_SCK_C_MARK = 2127,
	TS_SCK1_A_MARK = 2128,
	STP_ISCLK_1_A_MARK = 2129,
	RIF1_CLK_A_MARK = 2130,
	RIF3_CLK_A_MARK = 2131,
	IP17_15_12_MARK = 2132,
	USB0_OVC_MARK = 2133,
	SIM0_D_C_MARK = 2134,
	TS_SDAT1_D_MARK = 2135,
	STP_ISD_1_D_MARK = 2136,
	RIF3_SYNC_B_MARK = 2137,
	HRX2_C_MARK = 2138,
	IP16_19_16_MARK = 2139,
	SSI_WS78_MARK = 2140,
	HTX2_B_MARK = 2141,
	MSIOF1_SYNC_C_MARK = 2142,
	TS_SDAT1_A_MARK = 2143,
	STP_ISD_1_A_MARK = 2144,
	RIF1_SYNC_A_MARK = 2145,
	RIF3_SYNC_A_MARK = 2146,
	IP17_19_16_MARK = 2147,
	USB1_PWEN_MARK = 2148,
	SIM0_CLK_C_MARK = 2149,
	SSI_SCK1_A_MARK = 2150,
	TS_SCK0_E_MARK = 2151,
	STP_ISCLK_0_E_MARK = 2152,
	FMCLK_B_MARK = 2153,
	RIF2_CLK_B_MARK = 2154,
	SPEEDIN_A_MARK = 2155,
	HTX2_C_MARK = 2156,
	IP16_23_20_MARK = 2157,
	SSI_SDATA7_MARK = 2158,
	HCTS2_N_B_MARK = 2159,
	MSIOF1_RXD_C_MARK = 2160,
	TS_SDEN1_A_MARK = 2161,
	STP_ISEN_1_A_MARK = 2162,
	RIF1_D0_A_MARK = 2163,
	RIF3_D0_A_MARK = 2164,
	TCLK2_A_MARK = 2165,
	IP17_23_20_MARK = 2166,
	USB1_OVC_MARK = 2167,
	MSIOF1_SS2_C_MARK = 2168,
	SSI_WS1_A_MARK = 2169,
	TS_SDAT0_E_MARK = 2170,
	STP_ISD_0_E_MARK = 2171,
	FMIN_B_MARK = 2172,
	RIF2_SYNC_B_MARK = 2173,
	REMOCON_B_MARK = 2174,
	HCTS2_N_C_MARK = 2175,
	IP16_27_24_MARK = 2176,
	SSI_SDATA8_MARK = 2177,
	HRTS2_N_B_MARK = 2178,
	MSIOF1_TXD_C_MARK = 2179,
	TS_SPSYNC1_A_MARK = 2180,
	STP_ISSYNC_1_A_MARK = 2181,
	RIF1_D1_A_MARK = 2182,
	RIF3_D1_A_MARK = 2183,
	IP17_27_24_MARK = 2184,
	USB30_PWEN_MARK = 2185,
	AUDIO_CLKOUT_B_MARK = 2186,
	SSI_SCK2_B_MARK = 2187,
	TS_SDEN1_D_MARK = 2188,
	STP_ISEN_1_D_MARK = 2189,
	STP_OPWM_0_E_MARK = 2190,
	RIF3_D0_B_MARK = 2191,
	TCLK2_B_MARK = 2192,
	TPU0TO0_MARK = 2193,
	BPFCLK_C_MARK = 2194,
	HRTS2_N_C_MARK = 2195,
	IP16_31_28_MARK = 2196,
	SSI_SDATA9_A_MARK = 2197,
	HSCK2_B_MARK = 2198,
	MSIOF1_SS1_C_MARK = 2199,
	HSCK1_A_MARK = 2200,
	SSI_WS1_B_MARK = 2201,
	SCK1_MARK = 2202,
	STP_IVCXO27_1_A_MARK = 2203,
	SCK5_A_MARK = 2204,
	IP17_31_28_MARK = 2205,
	USB30_OVC_MARK = 2206,
	AUDIO_CLKOUT1_B_MARK = 2207,
	SSI_WS2_B_MARK = 2208,
	TS_SPSYNC1_D_MARK = 2209,
	STP_ISSYNC_1_D_MARK = 2210,
	STP_IVCXO27_0_E_MARK = 2211,
	RIF3_D1_B_MARK = 2212,
	FSO_TOE_N_MARK = 2213,
	TPU0TO1_MARK = 2214,
	SEL_MSIOF3_0_MARK = 2215,
	SEL_MSIOF3_1_MARK = 2216,
	SEL_MSIOF3_2_MARK = 2217,
	SEL_MSIOF3_3_MARK = 2218,
	SEL_MSIOF3_4_MARK = 2219,
	SEL_TSIF1_0_MARK = 2220,
	SEL_TSIF1_1_MARK = 2221,
	SEL_TSIF1_2_MARK = 2222,
	SEL_TSIF1_3_MARK = 2223,
	I2C_SEL_5_0_MARK = 2224,
	I2C_SEL_5_1_MARK = 2225,
	I2C_SEL_3_0_MARK = 2226,
	I2C_SEL_3_1_MARK = 2227,
	SEL_TSIF0_0_MARK = 2228,
	SEL_TSIF0_1_MARK = 2229,
	SEL_TSIF0_2_MARK = 2230,
	SEL_TSIF0_3_MARK = 2231,
	SEL_TSIF0_4_MARK = 2232,
	I2C_SEL_0_0_MARK = 2233,
	I2C_SEL_0_1_MARK = 2234,
	SEL_MSIOF2_0_MARK = 2235,
	SEL_MSIOF2_1_MARK = 2236,
	SEL_MSIOF2_2_MARK = 2237,
	SEL_MSIOF2_3_MARK = 2238,
	SEL_FM_0_MARK = 2239,
	SEL_FM_1_MARK = 2240,
	SEL_FM_2_MARK = 2241,
	SEL_FM_3_MARK = 2242,
	SEL_MSIOF1_0_MARK = 2243,
	SEL_MSIOF1_1_MARK = 2244,
	SEL_MSIOF1_2_MARK = 2245,
	SEL_MSIOF1_3_MARK = 2246,
	SEL_MSIOF1_4_MARK = 2247,
	SEL_MSIOF1_5_MARK = 2248,
	SEL_MSIOF1_6_MARK = 2249,
	SEL_TIMER_TMU_0_MARK = 2250,
	SEL_TIMER_TMU_1_MARK = 2251,
	SEL_SCIF5_0_MARK = 2252,
	SEL_SCIF5_1_MARK = 2253,
	SEL_SSP1_1_0_MARK = 2254,
	SEL_SSP1_1_1_MARK = 2255,
	SEL_SSP1_1_2_MARK = 2256,
	SEL_SSP1_1_3_MARK = 2257,
	SEL_I2C6_0_MARK = 2258,
	SEL_I2C6_1_MARK = 2259,
	SEL_I2C6_2_MARK = 2260,
	SEL_LBSC_0_MARK = 2261,
	SEL_LBSC_1_MARK = 2262,
	SEL_SSP1_0_0_MARK = 2263,
	SEL_SSP1_0_1_MARK = 2264,
	SEL_SSP1_0_2_MARK = 2265,
	SEL_SSP1_0_3_MARK = 2266,
	SEL_SSP1_0_4_MARK = 2267,
	SEL_IEBUS_0_MARK = 2268,
	SEL_IEBUS_1_MARK = 2269,
	SEL_NDF_0_MARK = 2270,
	SEL_NDF_1_MARK = 2271,
	SEL_I2C2_0_MARK = 2272,
	SEL_I2C2_1_MARK = 2273,
	SEL_SSI2_0_MARK = 2274,
	SEL_SSI2_1_MARK = 2275,
	SEL_I2C1_0_MARK = 2276,
	SEL_I2C1_1_MARK = 2277,
	SEL_SSI1_0_MARK = 2278,
	SEL_SSI1_1_MARK = 2279,
	SEL_SSI9_0_MARK = 2280,
	SEL_SSI9_1_MARK = 2281,
	SEL_HSCIF4_0_MARK = 2282,
	SEL_HSCIF4_1_MARK = 2283,
	SEL_SPEED_PULSE_0_MARK = 2284,
	SEL_SPEED_PULSE_1_MARK = 2285,
	SEL_TIMER_TMU2_0_MARK = 2286,
	SEL_TIMER_TMU2_1_MARK = 2287,
	SEL_HSCIF3_0_MARK = 2288,
	SEL_HSCIF3_1_MARK = 2289,
	SEL_HSCIF3_2_MARK = 2290,
	SEL_HSCIF3_3_MARK = 2291,
	SEL_SIMCARD_0_MARK = 2292,
	SEL_SIMCARD_1_MARK = 2293,
	SEL_SIMCARD_2_MARK = 2294,
	SEL_SIMCARD_3_MARK = 2295,
	SEL_ADGB_0_MARK = 2296,
	SEL_ADGB_1_MARK = 2297,
	SEL_ADGC_0_MARK = 2298,
	SEL_ADGC_1_MARK = 2299,
	SEL_HSCIF1_0_MARK = 2300,
	SEL_HSCIF1_1_MARK = 2301,
	SEL_SDHI2_0_MARK = 2302,
	SEL_SDHI2_1_MARK = 2303,
	SEL_SCIF4_0_MARK = 2304,
	SEL_SCIF4_1_MARK = 2305,
	SEL_SCIF4_2_MARK = 2306,
	SEL_HSCIF2_0_MARK = 2307,
	SEL_HSCIF2_1_MARK = 2308,
	SEL_HSCIF2_2_MARK = 2309,
	SEL_SCIF3_0_MARK = 2310,
	SEL_SCIF3_1_MARK = 2311,
	SEL_ETHERAVB_0_MARK = 2312,
	SEL_ETHERAVB_1_MARK = 2313,
	SEL_SCIF2_0_MARK = 2314,
	SEL_SCIF2_1_MARK = 2315,
	SEL_DRIF3_0_MARK = 2316,
	SEL_DRIF3_1_MARK = 2317,
	SEL_SCIF1_0_MARK = 2318,
	SEL_SCIF1_1_MARK = 2319,
	SEL_DRIF2_0_MARK = 2320,
	SEL_DRIF2_1_MARK = 2321,
	SEL_SCIF_0_MARK = 2322,
	SEL_SCIF_1_MARK = 2323,
	SEL_DRIF1_0_MARK = 2324,
	SEL_DRIF1_1_MARK = 2325,
	SEL_DRIF1_2_MARK = 2326,
	SEL_REMOCON_0_MARK = 2327,
	SEL_REMOCON_1_MARK = 2328,
	SEL_DRIF0_0_MARK = 2329,
	SEL_DRIF0_1_MARK = 2330,
	SEL_DRIF0_2_MARK = 2331,
	SEL_RCAN0_0_MARK = 2332,
	SEL_RCAN0_1_MARK = 2333,
	SEL_CANFD0_0_MARK = 2334,
	SEL_CANFD0_1_MARK = 2335,
	SEL_PWM6_0_MARK = 2336,
	SEL_PWM6_1_MARK = 2337,
	SEL_ADGA_0_MARK = 2338,
	SEL_ADGA_1_MARK = 2339,
	SEL_ADGA_2_MARK = 2340,
	SEL_ADGA_3_MARK = 2341,
	SEL_PWM5_0_MARK = 2342,
	SEL_PWM5_1_MARK = 2343,
	SEL_PWM4_0_MARK = 2344,
	SEL_PWM4_1_MARK = 2345,
	SEL_PWM3_0_MARK = 2346,
	SEL_PWM3_1_MARK = 2347,
	SEL_PWM2_0_MARK = 2348,
	SEL_PWM2_1_MARK = 2349,
	SEL_PWM1_0_MARK = 2350,
	SEL_PWM1_1_MARK = 2351,
	SEL_VIN4_0_MARK = 2352,
	SEL_VIN4_1_MARK = 2353,
	QSPI0_SPCLK_MARK = 2354,
	QSPI0_SSL_MARK = 2355,
	QSPI0_MOSI_IO0_MARK = 2356,
	QSPI0_MISO_IO1_MARK = 2357,
	QSPI0_IO2_MARK = 2358,
	QSPI0_IO3_MARK = 2359,
	QSPI1_SPCLK_MARK = 2360,
	QSPI1_SSL_MARK = 2361,
	QSPI1_MOSI_IO0_MARK = 2362,
	QSPI1_MISO_IO1_MARK = 2363,
	QSPI1_IO2_MARK = 2364,
	QSPI1_IO3_MARK = 2365,
	RPC_INT_MARK = 2366,
	RPC_WP_MARK = 2367,
	RPC_RESET_MARK = 2368,
	AVB_TX_CTL_MARK = 2369,
	AVB_TXC_MARK = 2370,
	AVB_TD0_MARK = 2371,
	AVB_TD1_MARK = 2372,
	AVB_TD2_MARK = 2373,
	AVB_TD3_MARK = 2374,
	AVB_RX_CTL_MARK = 2375,
	AVB_RXC_MARK = 2376,
	AVB_RD0_MARK = 2377,
	AVB_RD1_MARK = 2378,
	AVB_RD2_MARK = 2379,
	AVB_RD3_MARK = 2380,
	AVB_TXCREFCLK_MARK = 2381,
	AVB_MDIO_MARK = 2382,
	PRESETOUT_MARK = 2383,
	DU_DOTCLKIN0_MARK = 2384,
	DU_DOTCLKIN1_MARK = 2385,
	DU_DOTCLKIN2_MARK = 2386,
	TMS_MARK = 2387,
	TDO_MARK = 2388,
	ASEBRK_MARK = 2389,
	MLB_REF_MARK = 2390,
	TDI_MARK = 2391,
	TCK_MARK = 2392,
	TRST_MARK = 2393,
	EXTALR_MARK = 2394,
	SCL0_MARK = 2395,
	SDA0_MARK = 2396,
	SCL3_MARK = 2397,
	SDA3_MARK = 2398,
	SCL5_MARK = 2399,
	SDA5_MARK = 2400,
	PINMUX_MARK_END = 2401,
};

enum {
	GP_LAST = 227,
	PIN_ASEBRK = 228,
	PIN_AVB_MDIO = 229,
	PIN_AVB_RD0 = 230,
	PIN_AVB_RD1 = 231,
	PIN_AVB_RD2 = 232,
	PIN_AVB_RD3 = 233,
	PIN_AVB_RXC = 234,
	PIN_AVB_RX_CTL = 235,
	PIN_AVB_TD0 = 236,
	PIN_AVB_TD1 = 237,
	PIN_AVB_TD2 = 238,
	PIN_AVB_TD3 = 239,
	PIN_AVB_TXC = 240,
	PIN_AVB_TXCREFCLK = 241,
	PIN_AVB_TX_CTL = 242,
	PIN_DU_DOTCLKIN0 = 243,
	PIN_DU_DOTCLKIN1 = 244,
	PIN_DU_DOTCLKIN2 = 245,
	PIN_EXTALR = 246,
	PIN_FSCLKST = 247,
	PIN_MLB_REF = 248,
	PIN_PRESETOUT_N = 249,
	PIN_QSPI0_IO2 = 250,
	PIN_QSPI0_IO3 = 251,
	PIN_QSPI0_MISO_IO1 = 252,
	PIN_QSPI0_MOSI_IO0 = 253,
	PIN_QSPI0_SPCLK = 254,
	PIN_QSPI0_SSL = 255,
	PIN_QSPI1_IO2 = 256,
	PIN_QSPI1_IO3 = 257,
	PIN_QSPI1_MISO_IO1 = 258,
	PIN_QSPI1_MOSI_IO0 = 259,
	PIN_QSPI1_SPCLK = 260,
	PIN_QSPI1_SSL = 261,
	PIN_PRESET_N = 262,
	PIN_RPC_INT_N = 263,
	PIN_RPC_RESET_N = 264,
	PIN_RPC_WP_N = 265,
	PIN_TCK = 266,
	PIN_TDI = 267,
	PIN_TDO = 268,
	PIN_TMS = 269,
	PIN_TRST_N = 270,
};

enum ioctrl_regs {
	POCCTRL = 0,
	TDSELCTRL = 1,
};

enum {
	PINMUX_RESERVED___2 = 0,
	PINMUX_DATA_BEGIN___2 = 1,
	GP_0_0_DATA___2 = 2,
	GP_0_1_DATA___2 = 3,
	GP_0_2_DATA___2 = 4,
	GP_0_3_DATA___2 = 5,
	GP_0_4_DATA___2 = 6,
	GP_0_5_DATA___2 = 7,
	GP_0_6_DATA___2 = 8,
	GP_0_7_DATA___2 = 9,
	GP_0_8_DATA___2 = 10,
	GP_0_9_DATA___2 = 11,
	GP_0_10_DATA___2 = 12,
	GP_0_11_DATA___2 = 13,
	GP_0_12_DATA___2 = 14,
	GP_0_13_DATA___2 = 15,
	GP_0_14_DATA___2 = 16,
	GP_0_15_DATA___2 = 17,
	GP_1_0_DATA___2 = 18,
	GP_1_1_DATA___2 = 19,
	GP_1_2_DATA___2 = 20,
	GP_1_3_DATA___2 = 21,
	GP_1_4_DATA___2 = 22,
	GP_1_5_DATA___2 = 23,
	GP_1_6_DATA___2 = 24,
	GP_1_7_DATA___2 = 25,
	GP_1_8_DATA___2 = 26,
	GP_1_9_DATA___2 = 27,
	GP_1_10_DATA___2 = 28,
	GP_1_11_DATA___2 = 29,
	GP_1_12_DATA___2 = 30,
	GP_1_13_DATA___2 = 31,
	GP_1_14_DATA___2 = 32,
	GP_1_15_DATA___2 = 33,
	GP_1_16_DATA___2 = 34,
	GP_1_17_DATA___2 = 35,
	GP_1_18_DATA___2 = 36,
	GP_1_19_DATA___2 = 37,
	GP_1_20_DATA___2 = 38,
	GP_1_21_DATA___2 = 39,
	GP_1_22_DATA___2 = 40,
	GP_1_23_DATA___2 = 41,
	GP_1_24_DATA___2 = 42,
	GP_1_25_DATA___2 = 43,
	GP_1_26_DATA___2 = 44,
	GP_1_27_DATA___2 = 45,
	GP_1_28_DATA___2 = 46,
	GP_2_0_DATA___2 = 47,
	GP_2_1_DATA___2 = 48,
	GP_2_2_DATA___2 = 49,
	GP_2_3_DATA___2 = 50,
	GP_2_4_DATA___2 = 51,
	GP_2_5_DATA___2 = 52,
	GP_2_6_DATA___2 = 53,
	GP_2_7_DATA___2 = 54,
	GP_2_8_DATA___2 = 55,
	GP_2_9_DATA___2 = 56,
	GP_2_10_DATA___2 = 57,
	GP_2_11_DATA___2 = 58,
	GP_2_12_DATA___2 = 59,
	GP_2_13_DATA___2 = 60,
	GP_2_14_DATA___2 = 61,
	GP_3_0_DATA___2 = 62,
	GP_3_1_DATA___2 = 63,
	GP_3_2_DATA___2 = 64,
	GP_3_3_DATA___2 = 65,
	GP_3_4_DATA___2 = 66,
	GP_3_5_DATA___2 = 67,
	GP_3_6_DATA___2 = 68,
	GP_3_7_DATA___2 = 69,
	GP_3_8_DATA___2 = 70,
	GP_3_9_DATA___2 = 71,
	GP_3_10_DATA___2 = 72,
	GP_3_11_DATA___2 = 73,
	GP_3_12_DATA___2 = 74,
	GP_3_13_DATA___2 = 75,
	GP_3_14_DATA___2 = 76,
	GP_3_15_DATA___2 = 77,
	GP_4_0_DATA___2 = 78,
	GP_4_1_DATA___2 = 79,
	GP_4_2_DATA___2 = 80,
	GP_4_3_DATA___2 = 81,
	GP_4_4_DATA___2 = 82,
	GP_4_5_DATA___2 = 83,
	GP_4_6_DATA___2 = 84,
	GP_4_7_DATA___2 = 85,
	GP_4_8_DATA___2 = 86,
	GP_4_9_DATA___2 = 87,
	GP_4_10_DATA___2 = 88,
	GP_4_11_DATA___2 = 89,
	GP_4_12_DATA___2 = 90,
	GP_4_13_DATA___2 = 91,
	GP_4_14_DATA___2 = 92,
	GP_4_15_DATA___2 = 93,
	GP_4_16_DATA___2 = 94,
	GP_4_17_DATA___2 = 95,
	GP_5_0_DATA___2 = 96,
	GP_5_1_DATA___2 = 97,
	GP_5_2_DATA___2 = 98,
	GP_5_3_DATA___2 = 99,
	GP_5_4_DATA___2 = 100,
	GP_5_5_DATA___2 = 101,
	GP_5_6_DATA___2 = 102,
	GP_5_7_DATA___2 = 103,
	GP_5_8_DATA___2 = 104,
	GP_5_9_DATA___2 = 105,
	GP_5_10_DATA___2 = 106,
	GP_5_11_DATA___2 = 107,
	GP_5_12_DATA___2 = 108,
	GP_5_13_DATA___2 = 109,
	GP_5_14_DATA___2 = 110,
	GP_5_15_DATA___2 = 111,
	GP_5_16_DATA___2 = 112,
	GP_5_17_DATA___2 = 113,
	GP_5_18_DATA___2 = 114,
	GP_5_19_DATA___2 = 115,
	GP_5_20_DATA___2 = 116,
	GP_5_21_DATA___2 = 117,
	GP_5_22_DATA___2 = 118,
	GP_5_23_DATA___2 = 119,
	GP_5_24_DATA___2 = 120,
	GP_5_25_DATA___2 = 121,
	GP_6_0_DATA___2 = 122,
	GP_6_1_DATA___2 = 123,
	GP_6_2_DATA___2 = 124,
	GP_6_3_DATA___2 = 125,
	GP_6_4_DATA___2 = 126,
	GP_6_5_DATA___2 = 127,
	GP_6_6_DATA___2 = 128,
	GP_6_7_DATA___2 = 129,
	GP_6_8_DATA___2 = 130,
	GP_6_9_DATA___2 = 131,
	GP_6_10_DATA___2 = 132,
	GP_6_11_DATA___2 = 133,
	GP_6_12_DATA___2 = 134,
	GP_6_13_DATA___2 = 135,
	GP_6_14_DATA___2 = 136,
	GP_6_15_DATA___2 = 137,
	GP_6_16_DATA___2 = 138,
	GP_6_17_DATA___2 = 139,
	GP_6_18_DATA___2 = 140,
	GP_6_19_DATA___2 = 141,
	GP_6_20_DATA___2 = 142,
	GP_6_21_DATA___2 = 143,
	GP_6_22_DATA___2 = 144,
	GP_6_23_DATA___2 = 145,
	GP_6_24_DATA___2 = 146,
	GP_6_25_DATA___2 = 147,
	GP_6_26_DATA___2 = 148,
	GP_6_27_DATA___2 = 149,
	GP_6_28_DATA___2 = 150,
	GP_6_29_DATA___2 = 151,
	GP_6_30_DATA___2 = 152,
	GP_6_31_DATA___2 = 153,
	GP_7_0_DATA___2 = 154,
	GP_7_1_DATA___2 = 155,
	GP_7_2_DATA___2 = 156,
	GP_7_3_DATA___2 = 157,
	PINMUX_DATA_END___2 = 158,
	PINMUX_FUNCTION_BEGIN___2 = 159,
	GP_0_0_FN___2 = 160,
	GP_0_1_FN___2 = 161,
	GP_0_2_FN___2 = 162,
	GP_0_3_FN___2 = 163,
	GP_0_4_FN___2 = 164,
	GP_0_5_FN___2 = 165,
	GP_0_6_FN___2 = 166,
	GP_0_7_FN___2 = 167,
	GP_0_8_FN___2 = 168,
	GP_0_9_FN___2 = 169,
	GP_0_10_FN___2 = 170,
	GP_0_11_FN___2 = 171,
	GP_0_12_FN___2 = 172,
	GP_0_13_FN___2 = 173,
	GP_0_14_FN___2 = 174,
	GP_0_15_FN___2 = 175,
	GP_1_0_FN___2 = 176,
	GP_1_1_FN___2 = 177,
	GP_1_2_FN___2 = 178,
	GP_1_3_FN___2 = 179,
	GP_1_4_FN___2 = 180,
	GP_1_5_FN___2 = 181,
	GP_1_6_FN___2 = 182,
	GP_1_7_FN___2 = 183,
	GP_1_8_FN___2 = 184,
	GP_1_9_FN___2 = 185,
	GP_1_10_FN___2 = 186,
	GP_1_11_FN___2 = 187,
	GP_1_12_FN___2 = 188,
	GP_1_13_FN___2 = 189,
	GP_1_14_FN___2 = 190,
	GP_1_15_FN___2 = 191,
	GP_1_16_FN___2 = 192,
	GP_1_17_FN___2 = 193,
	GP_1_18_FN___2 = 194,
	GP_1_19_FN___2 = 195,
	GP_1_20_FN___2 = 196,
	GP_1_21_FN___2 = 197,
	GP_1_22_FN___2 = 198,
	GP_1_23_FN___2 = 199,
	GP_1_24_FN___2 = 200,
	GP_1_25_FN___2 = 201,
	GP_1_26_FN___2 = 202,
	GP_1_27_FN___2 = 203,
	GP_1_28_FN___2 = 204,
	GP_2_0_FN___2 = 205,
	GP_2_1_FN___2 = 206,
	GP_2_2_FN___2 = 207,
	GP_2_3_FN___2 = 208,
	GP_2_4_FN___2 = 209,
	GP_2_5_FN___2 = 210,
	GP_2_6_FN___2 = 211,
	GP_2_7_FN___2 = 212,
	GP_2_8_FN___2 = 213,
	GP_2_9_FN___2 = 214,
	GP_2_10_FN___2 = 215,
	GP_2_11_FN___2 = 216,
	GP_2_12_FN___2 = 217,
	GP_2_13_FN___2 = 218,
	GP_2_14_FN___2 = 219,
	GP_3_0_FN___2 = 220,
	GP_3_1_FN___2 = 221,
	GP_3_2_FN___2 = 222,
	GP_3_3_FN___2 = 223,
	GP_3_4_FN___2 = 224,
	GP_3_5_FN___2 = 225,
	GP_3_6_FN___2 = 226,
	GP_3_7_FN___2 = 227,
	GP_3_8_FN___2 = 228,
	GP_3_9_FN___2 = 229,
	GP_3_10_FN___2 = 230,
	GP_3_11_FN___2 = 231,
	GP_3_12_FN___2 = 232,
	GP_3_13_FN___2 = 233,
	GP_3_14_FN___2 = 234,
	GP_3_15_FN___2 = 235,
	GP_4_0_FN___2 = 236,
	GP_4_1_FN___2 = 237,
	GP_4_2_FN___2 = 238,
	GP_4_3_FN___2 = 239,
	GP_4_4_FN___2 = 240,
	GP_4_5_FN___2 = 241,
	GP_4_6_FN___2 = 242,
	GP_4_7_FN___2 = 243,
	GP_4_8_FN___2 = 244,
	GP_4_9_FN___2 = 245,
	GP_4_10_FN___2 = 246,
	GP_4_11_FN___2 = 247,
	GP_4_12_FN___2 = 248,
	GP_4_13_FN___2 = 249,
	GP_4_14_FN___2 = 250,
	GP_4_15_FN___2 = 251,
	GP_4_16_FN___2 = 252,
	GP_4_17_FN___2 = 253,
	GP_5_0_FN___2 = 254,
	GP_5_1_FN___2 = 255,
	GP_5_2_FN___2 = 256,
	GP_5_3_FN___2 = 257,
	GP_5_4_FN___2 = 258,
	GP_5_5_FN___2 = 259,
	GP_5_6_FN___2 = 260,
	GP_5_7_FN___2 = 261,
	GP_5_8_FN___2 = 262,
	GP_5_9_FN___2 = 263,
	GP_5_10_FN___2 = 264,
	GP_5_11_FN___2 = 265,
	GP_5_12_FN___2 = 266,
	GP_5_13_FN___2 = 267,
	GP_5_14_FN___2 = 268,
	GP_5_15_FN___2 = 269,
	GP_5_16_FN___2 = 270,
	GP_5_17_FN___2 = 271,
	GP_5_18_FN___2 = 272,
	GP_5_19_FN___2 = 273,
	GP_5_20_FN___2 = 274,
	GP_5_21_FN___2 = 275,
	GP_5_22_FN___2 = 276,
	GP_5_23_FN___2 = 277,
	GP_5_24_FN___2 = 278,
	GP_5_25_FN___2 = 279,
	GP_6_0_FN___2 = 280,
	GP_6_1_FN___2 = 281,
	GP_6_2_FN___2 = 282,
	GP_6_3_FN___2 = 283,
	GP_6_4_FN___2 = 284,
	GP_6_5_FN___2 = 285,
	GP_6_6_FN___2 = 286,
	GP_6_7_FN___2 = 287,
	GP_6_8_FN___2 = 288,
	GP_6_9_FN___2 = 289,
	GP_6_10_FN___2 = 290,
	GP_6_11_FN___2 = 291,
	GP_6_12_FN___2 = 292,
	GP_6_13_FN___2 = 293,
	GP_6_14_FN___2 = 294,
	GP_6_15_FN___2 = 295,
	GP_6_16_FN___2 = 296,
	GP_6_17_FN___2 = 297,
	GP_6_18_FN___2 = 298,
	GP_6_19_FN___2 = 299,
	GP_6_20_FN___2 = 300,
	GP_6_21_FN___2 = 301,
	GP_6_22_FN___2 = 302,
	GP_6_23_FN___2 = 303,
	GP_6_24_FN___2 = 304,
	GP_6_25_FN___2 = 305,
	GP_6_26_FN___2 = 306,
	GP_6_27_FN___2 = 307,
	GP_6_28_FN___2 = 308,
	GP_6_29_FN___2 = 309,
	GP_6_30_FN___2 = 310,
	GP_6_31_FN___2 = 311,
	GP_7_0_FN___2 = 312,
	GP_7_1_FN___2 = 313,
	GP_7_2_FN___2 = 314,
	GP_7_3_FN___2 = 315,
	FN_CLKOUT___2 = 316,
	FN_MSIOF0_RXD___2 = 317,
	FN_MSIOF0_TXD___2 = 318,
	FN_MSIOF0_SCK___2 = 319,
	FN_SSI_SDATA5___2 = 320,
	FN_SSI_WS5___2 = 321,
	FN_SSI_SCK5___2 = 322,
	FN_GP7_03___2 = 323,
	FN_GP7_02___2 = 324,
	FN_AVS2___2 = 325,
	FN_AVS1___2 = 326,
	FN_IP0_3_0___2 = 327,
	FN_AVB_MDC___2 = 328,
	FN_MSIOF2_SS2_C___2 = 329,
	FN_IP1_3_0___2 = 330,
	FN_IRQ2___2 = 331,
	FN_QCPV_QDE___2 = 332,
	FN_DU_EXODDF_DU_ODDF_DISP_CDE___2 = 333,
	FN_VI4_DATA2_B___2 = 334,
	FN_MSIOF3_SYNC_E___2 = 335,
	FN_PWM3_B___2 = 336,
	FN_IP2_3_0___2 = 337,
	FN_A1___2 = 338,
	FN_LCDOUT17___2 = 339,
	FN_MSIOF3_TXD_B___2 = 340,
	FN_VI4_DATA9___2 = 341,
	FN_DU_DB1___2 = 342,
	FN_PWM4_A___2 = 343,
	FN_IP3_3_0___2 = 344,
	FN_A9___2 = 345,
	FN_MSIOF2_SCK_A___2 = 346,
	FN_CTS4_N_B___2 = 347,
	FN_VI5_VSYNC_N___2 = 348,
	FN_IP0_7_4___2 = 349,
	FN_AVB_MAGIC___2 = 350,
	FN_MSIOF2_SS1_C___2 = 351,
	FN_SCK4_A___2 = 352,
	FN_IP1_7_4___2 = 353,
	FN_IRQ3___2 = 354,
	FN_QSTVB_QVE___2 = 355,
	FN_DU_DOTCLKOUT1___2 = 356,
	FN_VI4_DATA3_B___2 = 357,
	FN_MSIOF3_SCK_E___2 = 358,
	FN_PWM4_B___2 = 359,
	FN_IP2_7_4___2 = 360,
	FN_A2___2 = 361,
	FN_LCDOUT18___2 = 362,
	FN_MSIOF3_SCK_B___2 = 363,
	FN_VI4_DATA10___2 = 364,
	FN_DU_DB2___2 = 365,
	FN_PWM5_A___2 = 366,
	FN_IP3_7_4___2 = 367,
	FN_A10___2 = 368,
	FN_MSIOF2_RXD_A___2 = 369,
	FN_RTS4_N_B___2 = 370,
	FN_VI5_HSYNC_N___2 = 371,
	FN_IP0_11_8___2 = 372,
	FN_AVB_PHY_INT___2 = 373,
	FN_MSIOF2_SYNC_C___2 = 374,
	FN_RX4_A___2 = 375,
	FN_IP1_11_8___2 = 376,
	FN_IRQ4___2 = 377,
	FN_QSTH_QHS___2 = 378,
	FN_DU_EXHSYNC_DU_HSYNC___2 = 379,
	FN_VI4_DATA4_B___2 = 380,
	FN_MSIOF3_RXD_E___2 = 381,
	FN_PWM5_B___2 = 382,
	FN_IP2_11_8___2 = 383,
	FN_A3___2 = 384,
	FN_LCDOUT19___2 = 385,
	FN_MSIOF3_RXD_B___2 = 386,
	FN_VI4_DATA11___2 = 387,
	FN_DU_DB3___2 = 388,
	FN_PWM6_A___2 = 389,
	FN_IP3_11_8___2 = 390,
	FN_A11___2 = 391,
	FN_TX3_B___2 = 392,
	FN_MSIOF2_TXD_A___2 = 393,
	FN_HTX4_B___2 = 394,
	FN_HSCK4___2 = 395,
	FN_VI5_FIELD___2 = 396,
	FN_SCL6_A___2 = 397,
	FN_AVB_AVTP_CAPTURE_B___2 = 398,
	FN_PWM2_B___2 = 399,
	FN_IP0_15_12___2 = 400,
	FN_AVB_LINK___2 = 401,
	FN_MSIOF2_SCK_C___2 = 402,
	FN_TX4_A___2 = 403,
	FN_IP1_15_12___2 = 404,
	FN_IRQ5___2 = 405,
	FN_QSTB_QHE___2 = 406,
	FN_DU_EXVSYNC_DU_VSYNC___2 = 407,
	FN_VI4_DATA5_B___2 = 408,
	FN_FSCLKST2_N_B = 409,
	FN_MSIOF3_TXD_E___2 = 410,
	FN_PWM6_B___2 = 411,
	FN_IP2_15_12___2 = 412,
	FN_A4___2 = 413,
	FN_LCDOUT20___2 = 414,
	FN_MSIOF3_SS1_B___2 = 415,
	FN_VI4_DATA12___2 = 416,
	FN_VI5_DATA12___2 = 417,
	FN_DU_DB4___2 = 418,
	FN_IP3_15_12___2 = 419,
	FN_A12___2 = 420,
	FN_LCDOUT12___2 = 421,
	FN_MSIOF3_SCK_C___2 = 422,
	FN_HRX4_A___2 = 423,
	FN_VI5_DATA8___2 = 424,
	FN_DU_DG4___2 = 425,
	FN_IP0_19_16___2 = 426,
	FN_AVB_AVTP_MATCH_A___2 = 427,
	FN_MSIOF2_RXD_C___2 = 428,
	FN_CTS4_N_A___2 = 429,
	FN_FSCLKST2_N_A = 430,
	FN_IP1_19_16___2 = 431,
	FN_PWM0___2 = 432,
	FN_AVB_AVTP_PPS___2 = 433,
	FN_VI4_DATA6_B___2 = 434,
	FN_IECLK_B___2 = 435,
	FN_IP2_19_16___2 = 436,
	FN_A5___2 = 437,
	FN_LCDOUT21___2 = 438,
	FN_MSIOF3_SS2_B___2 = 439,
	FN_SCK4_B___2 = 440,
	FN_VI4_DATA13___2 = 441,
	FN_VI5_DATA13___2 = 442,
	FN_DU_DB5___2 = 443,
	FN_IP3_19_16___2 = 444,
	FN_A13___2 = 445,
	FN_LCDOUT13___2 = 446,
	FN_MSIOF3_SYNC_C___2 = 447,
	FN_HTX4_A___2 = 448,
	FN_VI5_DATA9___2 = 449,
	FN_DU_DG5___2 = 450,
	FN_IP0_23_20___2 = 451,
	FN_AVB_AVTP_CAPTURE_A___2 = 452,
	FN_MSIOF2_TXD_C___2 = 453,
	FN_RTS4_N_A___2 = 454,
	FN_IP1_23_20___2 = 455,
	FN_PWM1_A___2 = 456,
	FN_HRX3_D___2 = 457,
	FN_VI4_DATA7_B___2 = 458,
	FN_IERX_B___2 = 459,
	FN_IP2_23_20___2 = 460,
	FN_A6___2 = 461,
	FN_LCDOUT22___2 = 462,
	FN_MSIOF2_SS1_A___2 = 463,
	FN_RX4_B___2 = 464,
	FN_VI4_DATA14___2 = 465,
	FN_VI5_DATA14___2 = 466,
	FN_DU_DB6___2 = 467,
	FN_IP3_23_20___2 = 468,
	FN_A14___2 = 469,
	FN_LCDOUT14___2 = 470,
	FN_MSIOF3_RXD_C___2 = 471,
	FN_HCTS4_N___2 = 472,
	FN_VI5_DATA10___2 = 473,
	FN_DU_DG6___2 = 474,
	FN_IP0_27_24___2 = 475,
	FN_IRQ0___2 = 476,
	FN_QPOLB___2 = 477,
	FN_DU_CDE___2 = 478,
	FN_VI4_DATA0_B___2 = 479,
	FN_CAN0_TX_B___2 = 480,
	FN_CANFD0_TX_B___2 = 481,
	FN_MSIOF3_SS2_E___2 = 482,
	FN_IP1_27_24___2 = 483,
	FN_PWM2_A___2 = 484,
	FN_HTX3_D___2 = 485,
	FN_IETX_B___2 = 486,
	FN_IP2_27_24___2 = 487,
	FN_A7___2 = 488,
	FN_LCDOUT23___2 = 489,
	FN_MSIOF2_SS2_A___2 = 490,
	FN_TX4_B___2 = 491,
	FN_VI4_DATA15___2 = 492,
	FN_VI5_DATA15___2 = 493,
	FN_DU_DB7___2 = 494,
	FN_IP3_27_24___2 = 495,
	FN_A15___2 = 496,
	FN_LCDOUT15___2 = 497,
	FN_MSIOF3_TXD_C___2 = 498,
	FN_HRTS4_N___2 = 499,
	FN_VI5_DATA11___2 = 500,
	FN_DU_DG7___2 = 501,
	FN_IP0_31_28___2 = 502,
	FN_IRQ1___2 = 503,
	FN_QPOLA___2 = 504,
	FN_DU_DISP___2 = 505,
	FN_VI4_DATA1_B___2 = 506,
	FN_CAN0_RX_B___2 = 507,
	FN_CANFD0_RX_B___2 = 508,
	FN_MSIOF3_SS1_E___2 = 509,
	FN_IP1_31_28___2 = 510,
	FN_A0___2 = 511,
	FN_LCDOUT16___2 = 512,
	FN_MSIOF3_SYNC_B___2 = 513,
	FN_VI4_DATA8___2 = 514,
	FN_DU_DB0___2 = 515,
	FN_PWM3_A___2 = 516,
	FN_IP2_31_28___2 = 517,
	FN_A8___2 = 518,
	FN_RX3_B___2 = 519,
	FN_MSIOF2_SYNC_A___2 = 520,
	FN_HRX4_B___2 = 521,
	FN_SDA6_A___2 = 522,
	FN_AVB_AVTP_MATCH_B___2 = 523,
	FN_PWM1_B___2 = 524,
	FN_IP3_31_28___2 = 525,
	FN_A16___2 = 526,
	FN_LCDOUT8___2 = 527,
	FN_VI4_FIELD___2 = 528,
	FN_DU_DG0___2 = 529,
	FN_IP4_3_0___2 = 530,
	FN_A17___2 = 531,
	FN_LCDOUT9___2 = 532,
	FN_VI4_VSYNC_N___2 = 533,
	FN_DU_DG1___2 = 534,
	FN_IP5_3_0___2 = 535,
	FN_WE0_N___2 = 536,
	FN_MSIOF3_TXD_D___2 = 537,
	FN_CTS3_N___2 = 538,
	FN_HCTS3_N___2 = 539,
	FN_SCL6_B___2 = 540,
	FN_CAN_CLK___2 = 541,
	FN_IECLK_A___2 = 542,
	FN_IP6_3_0___2 = 543,
	FN_D5___2 = 544,
	FN_MSIOF2_SYNC_B___2 = 545,
	FN_VI4_DATA21___2 = 546,
	FN_VI5_DATA5___2 = 547,
	FN_IP7_3_0___2 = 548,
	FN_D13___2 = 549,
	FN_LCDOUT5___2 = 550,
	FN_MSIOF2_SS2_D___2 = 551,
	FN_TX4_C___2 = 552,
	FN_VI4_DATA5_A___2 = 553,
	FN_DU_DR5___2 = 554,
	FN_IP4_7_4___2 = 555,
	FN_A18___2 = 556,
	FN_LCDOUT10___2 = 557,
	FN_VI4_HSYNC_N___2 = 558,
	FN_DU_DG2___2 = 559,
	FN_IP5_7_4___2 = 560,
	FN_WE1_N___2 = 561,
	FN_MSIOF3_SS1_D___2 = 562,
	FN_RTS3_N___2 = 563,
	FN_HRTS3_N___2 = 564,
	FN_SDA6_B___2 = 565,
	FN_CAN1_RX___2 = 566,
	FN_CANFD1_RX___2 = 567,
	FN_IERX_A___2 = 568,
	FN_IP6_7_4___2 = 569,
	FN_D6___2 = 570,
	FN_MSIOF2_RXD_B___2 = 571,
	FN_VI4_DATA22___2 = 572,
	FN_VI5_DATA6___2 = 573,
	FN_IP7_7_4___2 = 574,
	FN_D14___2 = 575,
	FN_LCDOUT6___2 = 576,
	FN_MSIOF3_SS1_A___2 = 577,
	FN_HRX3_C___2 = 578,
	FN_VI4_DATA6_A___2 = 579,
	FN_DU_DR6___2 = 580,
	FN_SCL6_C___2 = 581,
	FN_IP4_11_8___2 = 582,
	FN_A19___2 = 583,
	FN_LCDOUT11___2 = 584,
	FN_VI4_CLKENB___2 = 585,
	FN_DU_DG3___2 = 586,
	FN_IP5_11_8___2 = 587,
	FN_EX_WAIT0_A___2 = 588,
	FN_QCLK___2 = 589,
	FN_VI4_CLK___2 = 590,
	FN_DU_DOTCLKOUT0___2 = 591,
	FN_IP6_11_8___2 = 592,
	FN_D7___2 = 593,
	FN_MSIOF2_TXD_B___2 = 594,
	FN_VI4_DATA23___2 = 595,
	FN_VI5_DATA7___2 = 596,
	FN_IP7_11_8___2 = 597,
	FN_D15___2 = 598,
	FN_LCDOUT7___2 = 599,
	FN_MSIOF3_SS2_A___2 = 600,
	FN_HTX3_C___2 = 601,
	FN_VI4_DATA7_A___2 = 602,
	FN_DU_DR7___2 = 603,
	FN_SDA6_C___2 = 604,
	FN_IP4_15_12___2 = 605,
	FN_CS0_N___2 = 606,
	FN_VI5_CLKENB___2 = 607,
	FN_IP5_15_12___2 = 608,
	FN_D0___2 = 609,
	FN_MSIOF2_SS1_B___2 = 610,
	FN_MSIOF3_SCK_A___2 = 611,
	FN_VI4_DATA16___2 = 612,
	FN_VI5_DATA0___2 = 613,
	FN_IP6_15_12___2 = 614,
	FN_D8___2 = 615,
	FN_LCDOUT0___2 = 616,
	FN_MSIOF2_SCK_D___2 = 617,
	FN_SCK4_C___2 = 618,
	FN_VI4_DATA0_A___2 = 619,
	FN_DU_DR0___2 = 620,
	FN_IP4_19_16___2 = 621,
	FN_CS1_N___2 = 622,
	FN_VI5_CLK___2 = 623,
	FN_EX_WAIT0_B___2 = 624,
	FN_IP5_19_16___2 = 625,
	FN_D1___2 = 626,
	FN_MSIOF2_SS2_B___2 = 627,
	FN_MSIOF3_SYNC_A___2 = 628,
	FN_VI4_DATA17___2 = 629,
	FN_VI5_DATA1___2 = 630,
	FN_IP6_19_16___2 = 631,
	FN_D9___2 = 632,
	FN_LCDOUT1___2 = 633,
	FN_MSIOF2_SYNC_D___2 = 634,
	FN_VI4_DATA1_A___2 = 635,
	FN_DU_DR1___2 = 636,
	FN_IP7_19_16___2 = 637,
	FN_SD0_CLK___2 = 638,
	FN_MSIOF1_SCK_E___2 = 639,
	FN_STP_OPWM_0_B___2 = 640,
	FN_IP4_23_20___2 = 641,
	FN_BS_N___2 = 642,
	FN_QSTVA_QVS___2 = 643,
	FN_MSIOF3_SCK_D___2 = 644,
	FN_SCK3___2 = 645,
	FN_HSCK3___2 = 646,
	FN_CAN1_TX___2 = 647,
	FN_CANFD1_TX___2 = 648,
	FN_IETX_A___2 = 649,
	FN_IP5_23_20___2 = 650,
	FN_D2___2 = 651,
	FN_MSIOF3_RXD_A___2 = 652,
	FN_VI4_DATA18___2 = 653,
	FN_VI5_DATA2___2 = 654,
	FN_IP6_23_20___2 = 655,
	FN_D10___2 = 656,
	FN_LCDOUT2___2 = 657,
	FN_MSIOF2_RXD_D___2 = 658,
	FN_HRX3_B___2 = 659,
	FN_VI4_DATA2_A___2 = 660,
	FN_CTS4_N_C___2 = 661,
	FN_DU_DR2___2 = 662,
	FN_IP7_23_20___2 = 663,
	FN_SD0_CMD___2 = 664,
	FN_MSIOF1_SYNC_E___2 = 665,
	FN_STP_IVCXO27_0_B___2 = 666,
	FN_IP4_27_24___2 = 667,
	FN_RD_N___2 = 668,
	FN_MSIOF3_SYNC_D___2 = 669,
	FN_RX3_A___2 = 670,
	FN_HRX3_A___2 = 671,
	FN_CAN0_TX_A___2 = 672,
	FN_CANFD0_TX_A___2 = 673,
	FN_IP5_27_24___2 = 674,
	FN_D3___2 = 675,
	FN_MSIOF3_TXD_A___2 = 676,
	FN_VI4_DATA19___2 = 677,
	FN_VI5_DATA3___2 = 678,
	FN_IP6_27_24___2 = 679,
	FN_D11___2 = 680,
	FN_LCDOUT3___2 = 681,
	FN_MSIOF2_TXD_D___2 = 682,
	FN_HTX3_B___2 = 683,
	FN_VI4_DATA3_A___2 = 684,
	FN_RTS4_N_C___2 = 685,
	FN_DU_DR3___2 = 686,
	FN_IP7_27_24___2 = 687,
	FN_SD0_DAT0___2 = 688,
	FN_MSIOF1_RXD_E___2 = 689,
	FN_TS_SCK0_B___2 = 690,
	FN_STP_ISCLK_0_B___2 = 691,
	FN_IP4_31_28___2 = 692,
	FN_RD_WR_N___2 = 693,
	FN_MSIOF3_RXD_D___2 = 694,
	FN_TX3_A___2 = 695,
	FN_HTX3_A___2 = 696,
	FN_CAN0_RX_A___2 = 697,
	FN_CANFD0_RX_A___2 = 698,
	FN_IP5_31_28___2 = 699,
	FN_D4___2 = 700,
	FN_MSIOF2_SCK_B___2 = 701,
	FN_VI4_DATA20___2 = 702,
	FN_VI5_DATA4___2 = 703,
	FN_IP6_31_28___2 = 704,
	FN_D12___2 = 705,
	FN_LCDOUT4___2 = 706,
	FN_MSIOF2_SS1_D___2 = 707,
	FN_RX4_C___2 = 708,
	FN_VI4_DATA4_A___2 = 709,
	FN_DU_DR4___2 = 710,
	FN_IP7_31_28___2 = 711,
	FN_SD0_DAT1___2 = 712,
	FN_MSIOF1_TXD_E___2 = 713,
	FN_TS_SPSYNC0_B___2 = 714,
	FN_STP_ISSYNC_0_B___2 = 715,
	FN_IP8_3_0___2 = 716,
	FN_SD0_DAT2___2 = 717,
	FN_MSIOF1_SS1_E___2 = 718,
	FN_TS_SDAT0_B___2 = 719,
	FN_STP_ISD_0_B___2 = 720,
	FN_IP9_3_0___2 = 721,
	FN_SD2_CLK___2 = 722,
	FN_NFDATA8___2 = 723,
	FN_IP10_3_0___2 = 724,
	FN_SD3_CMD___2 = 725,
	FN_NFRE_N___2 = 726,
	FN_IP11_3_0___2 = 727,
	FN_SD3_DAT7___2 = 728,
	FN_SD3_WP___2 = 729,
	FN_NFDATA7___2 = 730,
	FN_IP8_7_4___2 = 731,
	FN_SD0_DAT3___2 = 732,
	FN_MSIOF1_SS2_E___2 = 733,
	FN_TS_SDEN0_B___2 = 734,
	FN_STP_ISEN_0_B___2 = 735,
	FN_IP9_7_4___2 = 736,
	FN_SD2_CMD___2 = 737,
	FN_NFDATA9___2 = 738,
	FN_IP10_7_4___2 = 739,
	FN_SD3_DAT0___2 = 740,
	FN_NFDATA0___2 = 741,
	FN_IP11_7_4___2 = 742,
	FN_SD3_DS___2 = 743,
	FN_NFCLE___2 = 744,
	FN_IP8_11_8___2 = 745,
	FN_SD1_CLK___2 = 746,
	FN_MSIOF1_SCK_G___2 = 747,
	FN_SIM0_CLK_A___2 = 748,
	FN_IP9_11_8___2 = 749,
	FN_SD2_DAT0___2 = 750,
	FN_NFDATA10___2 = 751,
	FN_IP10_11_8___2 = 752,
	FN_SD3_DAT1___2 = 753,
	FN_NFDATA1___2 = 754,
	FN_IP11_11_8___2 = 755,
	FN_SD0_CD___2 = 756,
	FN_NFDATA14_A___2 = 757,
	FN_SCL2_B___2 = 758,
	FN_SIM0_RST_A___2 = 759,
	FN_IP8_15_12___2 = 760,
	FN_SD1_CMD___2 = 761,
	FN_MSIOF1_SYNC_G___2 = 762,
	FN_NFCE_N_B___2 = 763,
	FN_SIM0_D_A___2 = 764,
	FN_STP_IVCXO27_1_B___2 = 765,
	FN_IP9_15_12___2 = 766,
	FN_SD2_DAT1___2 = 767,
	FN_NFDATA11___2 = 768,
	FN_IP10_15_12___2 = 769,
	FN_SD3_DAT2___2 = 770,
	FN_NFDATA2___2 = 771,
	FN_IP11_15_12___2 = 772,
	FN_SD0_WP___2 = 773,
	FN_NFDATA15_A___2 = 774,
	FN_SDA2_B___2 = 775,
	FN_IP8_19_16___2 = 776,
	FN_SD1_DAT0___2 = 777,
	FN_SD2_DAT4___2 = 778,
	FN_MSIOF1_RXD_G___2 = 779,
	FN_NFWP_N_B___2 = 780,
	FN_TS_SCK1_B___2 = 781,
	FN_STP_ISCLK_1_B___2 = 782,
	FN_IP9_19_16___2 = 783,
	FN_SD2_DAT2___2 = 784,
	FN_NFDATA12___2 = 785,
	FN_IP10_19_16___2 = 786,
	FN_SD3_DAT3___2 = 787,
	FN_NFDATA3___2 = 788,
	FN_IP11_19_16___2 = 789,
	FN_SD1_CD___2 = 790,
	FN_NFRB_N_A___2 = 791,
	FN_SIM0_CLK_B___2 = 792,
	FN_IP8_23_20___2 = 793,
	FN_SD1_DAT1___2 = 794,
	FN_SD2_DAT5___2 = 795,
	FN_MSIOF1_TXD_G___2 = 796,
	FN_NFDATA14_B___2 = 797,
	FN_TS_SPSYNC1_B___2 = 798,
	FN_STP_ISSYNC_1_B___2 = 799,
	FN_IP9_23_20___2 = 800,
	FN_SD2_DAT3___2 = 801,
	FN_NFDATA13___2 = 802,
	FN_IP10_23_20___2 = 803,
	FN_SD3_DAT4___2 = 804,
	FN_SD2_CD_A___2 = 805,
	FN_NFDATA4___2 = 806,
	FN_IP11_23_20___2 = 807,
	FN_SD1_WP___2 = 808,
	FN_NFCE_N_A___2 = 809,
	FN_SIM0_D_B___2 = 810,
	FN_IP8_27_24___2 = 811,
	FN_SD1_DAT2___2 = 812,
	FN_SD2_DAT6___2 = 813,
	FN_MSIOF1_SS1_G___2 = 814,
	FN_NFDATA15_B___2 = 815,
	FN_TS_SDAT1_B___2 = 816,
	FN_STP_ISD_1_B___2 = 817,
	FN_IP9_27_24___2 = 818,
	FN_SD2_DS___2 = 819,
	FN_NFALE___2 = 820,
	FN_SATA_DEVSLP_B = 821,
	FN_IP10_27_24___2 = 822,
	FN_SD3_DAT5___2 = 823,
	FN_SD2_WP_A___2 = 824,
	FN_NFDATA5___2 = 825,
	FN_IP11_27_24___2 = 826,
	FN_SCK0___2 = 827,
	FN_HSCK1_B___2 = 828,
	FN_MSIOF1_SS2_B___2 = 829,
	FN_AUDIO_CLKC_B___2 = 830,
	FN_SDA2_A___2 = 831,
	FN_SIM0_RST_B___2 = 832,
	FN_STP_OPWM_0_C___2 = 833,
	FN_RIF0_CLK_B___2 = 834,
	FN_ADICHS2___2 = 835,
	FN_SCK5_B___2 = 836,
	FN_IP8_31_28___2 = 837,
	FN_SD1_DAT3___2 = 838,
	FN_SD2_DAT7___2 = 839,
	FN_MSIOF1_SS2_G___2 = 840,
	FN_NFRB_N_B___2 = 841,
	FN_TS_SDEN1_B___2 = 842,
	FN_STP_ISEN_1_B___2 = 843,
	FN_IP9_31_28___2 = 844,
	FN_SD3_CLK___2 = 845,
	FN_NFWE_N___2 = 846,
	FN_IP10_31_28___2 = 847,
	FN_SD3_DAT6___2 = 848,
	FN_SD3_CD___2 = 849,
	FN_NFDATA6___2 = 850,
	FN_IP11_31_28___2 = 851,
	FN_RX0___2 = 852,
	FN_HRX1_B___2 = 853,
	FN_TS_SCK0_C___2 = 854,
	FN_STP_ISCLK_0_C___2 = 855,
	FN_RIF0_D0_B___2 = 856,
	FN_IP12_3_0___2 = 857,
	FN_TX0___2 = 858,
	FN_HTX1_B___2 = 859,
	FN_TS_SPSYNC0_C___2 = 860,
	FN_STP_ISSYNC_0_C___2 = 861,
	FN_RIF0_D1_B___2 = 862,
	FN_IP13_3_0___2 = 863,
	FN_TX2_A___2 = 864,
	FN_SD2_CD_B___2 = 865,
	FN_SCL1_A___2 = 866,
	FN_FMCLK_A___2 = 867,
	FN_RIF1_D1_C___2 = 868,
	FN_FSO_CFE_0_N___2 = 869,
	FN_IP14_3_0___2 = 870,
	FN_MSIOF0_SS1___2 = 871,
	FN_RX5_A___2 = 872,
	FN_NFWP_N_A___2 = 873,
	FN_AUDIO_CLKA_C___2 = 874,
	FN_SSI_SCK2_A___2 = 875,
	FN_STP_IVCXO27_0_C___2 = 876,
	FN_AUDIO_CLKOUT3_A___2 = 877,
	FN_TCLK1_B___2 = 878,
	FN_IP15_3_0___2 = 879,
	FN_SSI_SDATA1_A___2 = 880,
	FN_IP12_7_4___2 = 881,
	FN_CTS0_N___2 = 882,
	FN_HCTS1_N_B___2 = 883,
	FN_MSIOF1_SYNC_B___2 = 884,
	FN_TS_SPSYNC1_C___2 = 885,
	FN_STP_ISSYNC_1_C___2 = 886,
	FN_RIF1_SYNC_B___2 = 887,
	FN_AUDIO_CLKOUT_C___2 = 888,
	FN_ADICS_SAMP___2 = 889,
	FN_IP13_7_4___2 = 890,
	FN_RX2_A___2 = 891,
	FN_SD2_WP_B___2 = 892,
	FN_SDA1_A___2 = 893,
	FN_FMIN_A___2 = 894,
	FN_RIF1_SYNC_C___2 = 895,
	FN_FSO_CFE_1_N___2 = 896,
	FN_IP14_7_4___2 = 897,
	FN_MSIOF0_SS2___2 = 898,
	FN_TX5_A___2 = 899,
	FN_MSIOF1_SS2_D___2 = 900,
	FN_AUDIO_CLKC_A___2 = 901,
	FN_SSI_WS2_A___2 = 902,
	FN_STP_OPWM_0_D___2 = 903,
	FN_AUDIO_CLKOUT_D___2 = 904,
	FN_SPEEDIN_B___2 = 905,
	FN_IP15_7_4___2 = 906,
	FN_SSI_SDATA2_A___2 = 907,
	FN_SSI_SCK1_B___2 = 908,
	FN_IP12_11_8___2 = 909,
	FN_RTS0_N___2 = 910,
	FN_HRTS1_N_B___2 = 911,
	FN_MSIOF1_SS1_B___2 = 912,
	FN_AUDIO_CLKA_B___2 = 913,
	FN_SCL2_A___2 = 914,
	FN_STP_IVCXO27_1_C___2 = 915,
	FN_RIF0_SYNC_B___2 = 916,
	FN_ADICHS1___2 = 917,
	FN_IP13_11_8___2 = 918,
	FN_HSCK0___2 = 919,
	FN_MSIOF1_SCK_D___2 = 920,
	FN_AUDIO_CLKB_A___2 = 921,
	FN_SSI_SDATA1_B___2 = 922,
	FN_TS_SCK0_D___2 = 923,
	FN_STP_ISCLK_0_D___2 = 924,
	FN_RIF0_CLK_C___2 = 925,
	FN_RX5_B___2 = 926,
	FN_IP14_11_8___2 = 927,
	FN_MLB_CLK___2 = 928,
	FN_MSIOF1_SCK_F___2 = 929,
	FN_SCL1_B___2 = 930,
	FN_IP15_11_8___2 = 931,
	FN_SSI_SCK349___2 = 932,
	FN_MSIOF1_SS1_A___2 = 933,
	FN_STP_OPWM_0_A___2 = 934,
	FN_IP12_15_12___2 = 935,
	FN_RX1_A___2 = 936,
	FN_HRX1_A___2 = 937,
	FN_TS_SDAT0_C___2 = 938,
	FN_STP_ISD_0_C___2 = 939,
	FN_RIF1_CLK_C___2 = 940,
	FN_IP13_15_12___2 = 941,
	FN_HRX0___2 = 942,
	FN_MSIOF1_RXD_D___2 = 943,
	FN_SSI_SDATA2_B___2 = 944,
	FN_TS_SDEN0_D___2 = 945,
	FN_STP_ISEN_0_D___2 = 946,
	FN_RIF0_D0_C___2 = 947,
	FN_IP14_15_12___2 = 948,
	FN_MLB_SIG___2 = 949,
	FN_RX1_B___2 = 950,
	FN_MSIOF1_SYNC_F___2 = 951,
	FN_SDA1_B___2 = 952,
	FN_IP15_15_12___2 = 953,
	FN_SSI_WS349___2 = 954,
	FN_HCTS2_N_A___2 = 955,
	FN_MSIOF1_SS2_A___2 = 956,
	FN_STP_IVCXO27_0_A___2 = 957,
	FN_IP12_19_16___2 = 958,
	FN_TX1_A___2 = 959,
	FN_HTX1_A___2 = 960,
	FN_TS_SDEN0_C___2 = 961,
	FN_STP_ISEN_0_C___2 = 962,
	FN_RIF1_D0_C___2 = 963,
	FN_IP13_19_16___2 = 964,
	FN_HTX0___2 = 965,
	FN_MSIOF1_TXD_D___2 = 966,
	FN_SSI_SDATA9_B___2 = 967,
	FN_TS_SDAT0_D___2 = 968,
	FN_STP_ISD_0_D___2 = 969,
	FN_RIF0_D1_C___2 = 970,
	FN_IP14_19_16___2 = 971,
	FN_MLB_DAT___2 = 972,
	FN_TX1_B___2 = 973,
	FN_MSIOF1_RXD_F___2 = 974,
	FN_IP15_19_16___2 = 975,
	FN_SSI_SDATA3___2 = 976,
	FN_HRTS2_N_A___2 = 977,
	FN_MSIOF1_TXD_A___2 = 978,
	FN_TS_SCK0_A___2 = 979,
	FN_STP_ISCLK_0_A___2 = 980,
	FN_RIF0_D1_A___2 = 981,
	FN_RIF2_D0_A___2 = 982,
	FN_IP12_23_20___2 = 983,
	FN_CTS1_N___2 = 984,
	FN_HCTS1_N_A___2 = 985,
	FN_MSIOF1_RXD_B___2 = 986,
	FN_TS_SDEN1_C___2 = 987,
	FN_STP_ISEN_1_C___2 = 988,
	FN_RIF1_D0_B___2 = 989,
	FN_ADIDATA___2 = 990,
	FN_IP13_23_20___2 = 991,
	FN_HCTS0_N___2 = 992,
	FN_RX2_B___2 = 993,
	FN_MSIOF1_SYNC_D___2 = 994,
	FN_SSI_SCK9_A___2 = 995,
	FN_TS_SPSYNC0_D___2 = 996,
	FN_STP_ISSYNC_0_D___2 = 997,
	FN_RIF0_SYNC_C___2 = 998,
	FN_AUDIO_CLKOUT1_A___2 = 999,
	FN_IP14_23_20___2 = 1000,
	FN_SSI_SCK01239___2 = 1001,
	FN_MSIOF1_TXD_F___2 = 1002,
	FN_IP15_23_20___2 = 1003,
	FN_SSI_SCK4___2 = 1004,
	FN_HRX2_A___2 = 1005,
	FN_MSIOF1_SCK_A___2 = 1006,
	FN_TS_SDAT0_A___2 = 1007,
	FN_STP_ISD_0_A___2 = 1008,
	FN_RIF0_CLK_A___2 = 1009,
	FN_RIF2_CLK_A___2 = 1010,
	FN_IP12_27_24___2 = 1011,
	FN_RTS1_N___2 = 1012,
	FN_HRTS1_N_A___2 = 1013,
	FN_MSIOF1_TXD_B___2 = 1014,
	FN_TS_SDAT1_C___2 = 1015,
	FN_STP_ISD_1_C___2 = 1016,
	FN_RIF1_D1_B___2 = 1017,
	FN_ADICHS0___2 = 1018,
	FN_IP13_27_24___2 = 1019,
	FN_HRTS0_N___2 = 1020,
	FN_TX2_B___2 = 1021,
	FN_MSIOF1_SS1_D___2 = 1022,
	FN_SSI_WS9_A___2 = 1023,
	FN_STP_IVCXO27_0_D___2 = 1024,
	FN_BPFCLK_A___2 = 1025,
	FN_AUDIO_CLKOUT2_A___2 = 1026,
	FN_IP14_27_24___2 = 1027,
	FN_SSI_WS01239___2 = 1028,
	FN_MSIOF1_SS1_F___2 = 1029,
	FN_IP15_27_24___2 = 1030,
	FN_SSI_WS4___2 = 1031,
	FN_HTX2_A___2 = 1032,
	FN_MSIOF1_SYNC_A___2 = 1033,
	FN_TS_SDEN0_A___2 = 1034,
	FN_STP_ISEN_0_A___2 = 1035,
	FN_RIF0_SYNC_A___2 = 1036,
	FN_RIF2_SYNC_A___2 = 1037,
	FN_IP12_31_28___2 = 1038,
	FN_SCK2___2 = 1039,
	FN_SCIF_CLK_B___2 = 1040,
	FN_MSIOF1_SCK_B___2 = 1041,
	FN_TS_SCK1_C___2 = 1042,
	FN_STP_ISCLK_1_C___2 = 1043,
	FN_RIF1_CLK_B___2 = 1044,
	FN_ADICLK___2 = 1045,
	FN_IP13_31_28___2 = 1046,
	FN_MSIOF0_SYNC___2 = 1047,
	FN_AUDIO_CLKOUT_A___2 = 1048,
	FN_TX5_B___2 = 1049,
	FN_BPFCLK_D___2 = 1050,
	FN_IP14_31_28___2 = 1051,
	FN_SSI_SDATA0___2 = 1052,
	FN_MSIOF1_SS2_F___2 = 1053,
	FN_IP15_31_28___2 = 1054,
	FN_SSI_SDATA4___2 = 1055,
	FN_HSCK2_A___2 = 1056,
	FN_MSIOF1_RXD_A___2 = 1057,
	FN_TS_SPSYNC0_A___2 = 1058,
	FN_STP_ISSYNC_0_A___2 = 1059,
	FN_RIF0_D0_A___2 = 1060,
	FN_RIF2_D1_A___2 = 1061,
	FN_IP16_3_0___2 = 1062,
	FN_SSI_SCK6___2 = 1063,
	FN_SIM0_RST_D___2 = 1064,
	FN_IP17_3_0___2 = 1065,
	FN_AUDIO_CLKA_A___2 = 1066,
	FN_IP18_3_0___2 = 1067,
	FN_GP6_30___2 = 1068,
	FN_AUDIO_CLKOUT2_B___2 = 1069,
	FN_SSI_SCK9_B___2 = 1070,
	FN_TS_SDEN0_E___2 = 1071,
	FN_STP_ISEN_0_E___2 = 1072,
	FN_RIF2_D0_B___2 = 1073,
	FN_TPU0TO2___2 = 1074,
	FN_FMCLK_C___2 = 1075,
	FN_FMCLK_D___2 = 1076,
	FN_IP16_7_4___2 = 1077,
	FN_SSI_WS6___2 = 1078,
	FN_SIM0_D_D___2 = 1079,
	FN_IP17_7_4___2 = 1080,
	FN_AUDIO_CLKB_B___2 = 1081,
	FN_SCIF_CLK_A___2 = 1082,
	FN_STP_IVCXO27_1_D___2 = 1083,
	FN_REMOCON_A___2 = 1084,
	FN_TCLK1_A___2 = 1085,
	FN_IP18_7_4___2 = 1086,
	FN_GP6_31___2 = 1087,
	FN_AUDIO_CLKOUT3_B___2 = 1088,
	FN_SSI_WS9_B___2 = 1089,
	FN_TS_SPSYNC0_E___2 = 1090,
	FN_STP_ISSYNC_0_E___2 = 1091,
	FN_RIF2_D1_B___2 = 1092,
	FN_TPU0TO3___2 = 1093,
	FN_FMIN_C___2 = 1094,
	FN_FMIN_D___2 = 1095,
	FN_IP16_11_8___2 = 1096,
	FN_SSI_SDATA6___2 = 1097,
	FN_SIM0_CLK_D___2 = 1098,
	FN_SATA_DEVSLP_A = 1099,
	FN_IP17_11_8___2 = 1100,
	FN_USB0_PWEN___2 = 1101,
	FN_SIM0_RST_C___2 = 1102,
	FN_TS_SCK1_D___2 = 1103,
	FN_STP_ISCLK_1_D___2 = 1104,
	FN_BPFCLK_B___2 = 1105,
	FN_RIF3_CLK_B___2 = 1106,
	FN_HSCK2_C___2 = 1107,
	FN_IP16_15_12___2 = 1108,
	FN_SSI_SCK78___2 = 1109,
	FN_HRX2_B___2 = 1110,
	FN_MSIOF1_SCK_C___2 = 1111,
	FN_TS_SCK1_A___2 = 1112,
	FN_STP_ISCLK_1_A___2 = 1113,
	FN_RIF1_CLK_A___2 = 1114,
	FN_RIF3_CLK_A___2 = 1115,
	FN_IP17_15_12___2 = 1116,
	FN_USB0_OVC___2 = 1117,
	FN_SIM0_D_C___2 = 1118,
	FN_TS_SDAT1_D___2 = 1119,
	FN_STP_ISD_1_D___2 = 1120,
	FN_RIF3_SYNC_B___2 = 1121,
	FN_HRX2_C___2 = 1122,
	FN_IP16_19_16___2 = 1123,
	FN_SSI_WS78___2 = 1124,
	FN_HTX2_B___2 = 1125,
	FN_MSIOF1_SYNC_C___2 = 1126,
	FN_TS_SDAT1_A___2 = 1127,
	FN_STP_ISD_1_A___2 = 1128,
	FN_RIF1_SYNC_A___2 = 1129,
	FN_RIF3_SYNC_A___2 = 1130,
	FN_IP17_19_16___2 = 1131,
	FN_USB1_PWEN___2 = 1132,
	FN_SIM0_CLK_C___2 = 1133,
	FN_SSI_SCK1_A___2 = 1134,
	FN_TS_SCK0_E___2 = 1135,
	FN_STP_ISCLK_0_E___2 = 1136,
	FN_FMCLK_B___2 = 1137,
	FN_RIF2_CLK_B___2 = 1138,
	FN_SPEEDIN_A___2 = 1139,
	FN_HTX2_C___2 = 1140,
	FN_IP16_23_20___2 = 1141,
	FN_SSI_SDATA7___2 = 1142,
	FN_HCTS2_N_B___2 = 1143,
	FN_MSIOF1_RXD_C___2 = 1144,
	FN_TS_SDEN1_A___2 = 1145,
	FN_STP_ISEN_1_A___2 = 1146,
	FN_RIF1_D0_A___2 = 1147,
	FN_RIF3_D0_A___2 = 1148,
	FN_TCLK2_A___2 = 1149,
	FN_IP17_23_20___2 = 1150,
	FN_USB1_OVC___2 = 1151,
	FN_MSIOF1_SS2_C___2 = 1152,
	FN_SSI_WS1_A___2 = 1153,
	FN_TS_SDAT0_E___2 = 1154,
	FN_STP_ISD_0_E___2 = 1155,
	FN_FMIN_B___2 = 1156,
	FN_RIF2_SYNC_B___2 = 1157,
	FN_REMOCON_B___2 = 1158,
	FN_HCTS2_N_C___2 = 1159,
	FN_IP16_27_24___2 = 1160,
	FN_SSI_SDATA8___2 = 1161,
	FN_HRTS2_N_B___2 = 1162,
	FN_MSIOF1_TXD_C___2 = 1163,
	FN_TS_SPSYNC1_A___2 = 1164,
	FN_STP_ISSYNC_1_A___2 = 1165,
	FN_RIF1_D1_A___2 = 1166,
	FN_RIF3_D1_A___2 = 1167,
	FN_IP17_27_24___2 = 1168,
	FN_USB30_PWEN___2 = 1169,
	FN_AUDIO_CLKOUT_B___2 = 1170,
	FN_SSI_SCK2_B___2 = 1171,
	FN_TS_SDEN1_D___2 = 1172,
	FN_STP_ISEN_1_D___2 = 1173,
	FN_STP_OPWM_0_E___2 = 1174,
	FN_RIF3_D0_B___2 = 1175,
	FN_TCLK2_B___2 = 1176,
	FN_TPU0TO0___2 = 1177,
	FN_BPFCLK_C___2 = 1178,
	FN_HRTS2_N_C___2 = 1179,
	FN_IP16_31_28___2 = 1180,
	FN_SSI_SDATA9_A___2 = 1181,
	FN_HSCK2_B___2 = 1182,
	FN_MSIOF1_SS1_C___2 = 1183,
	FN_HSCK1_A___2 = 1184,
	FN_SSI_WS1_B___2 = 1185,
	FN_SCK1___2 = 1186,
	FN_STP_IVCXO27_1_A___2 = 1187,
	FN_SCK5_A___2 = 1188,
	FN_IP17_31_28___2 = 1189,
	FN_USB30_OVC___2 = 1190,
	FN_AUDIO_CLKOUT1_B___2 = 1191,
	FN_SSI_WS2_B___2 = 1192,
	FN_TS_SPSYNC1_D___2 = 1193,
	FN_STP_ISSYNC_1_D___2 = 1194,
	FN_STP_IVCXO27_0_E___2 = 1195,
	FN_RIF3_D1_B___2 = 1196,
	FN_FSO_TOE_N___2 = 1197,
	FN_TPU0TO1___2 = 1198,
	FN_SEL_MSIOF3_0___2 = 1199,
	FN_SEL_MSIOF3_1___2 = 1200,
	FN_SEL_MSIOF3_2___2 = 1201,
	FN_SEL_MSIOF3_3___2 = 1202,
	FN_SEL_MSIOF3_4___2 = 1203,
	FN_SEL_TSIF1_0___2 = 1204,
	FN_SEL_TSIF1_1___2 = 1205,
	FN_SEL_TSIF1_2___2 = 1206,
	FN_SEL_TSIF1_3___2 = 1207,
	FN_I2C_SEL_5_0___2 = 1208,
	FN_I2C_SEL_5_1___2 = 1209,
	FN_I2C_SEL_3_0___2 = 1210,
	FN_I2C_SEL_3_1___2 = 1211,
	FN_SEL_TSIF0_0___2 = 1212,
	FN_SEL_TSIF0_1___2 = 1213,
	FN_SEL_TSIF0_2___2 = 1214,
	FN_SEL_TSIF0_3___2 = 1215,
	FN_SEL_TSIF0_4___2 = 1216,
	FN_I2C_SEL_0_0___2 = 1217,
	FN_I2C_SEL_0_1___2 = 1218,
	FN_SEL_MSIOF2_0___2 = 1219,
	FN_SEL_MSIOF2_1___2 = 1220,
	FN_SEL_MSIOF2_2___2 = 1221,
	FN_SEL_MSIOF2_3___2 = 1222,
	FN_SEL_FM_0___2 = 1223,
	FN_SEL_FM_1___2 = 1224,
	FN_SEL_FM_2___2 = 1225,
	FN_SEL_FM_3___2 = 1226,
	FN_SEL_MSIOF1_0___2 = 1227,
	FN_SEL_MSIOF1_1___2 = 1228,
	FN_SEL_MSIOF1_2___2 = 1229,
	FN_SEL_MSIOF1_3___2 = 1230,
	FN_SEL_MSIOF1_4___2 = 1231,
	FN_SEL_MSIOF1_5___2 = 1232,
	FN_SEL_MSIOF1_6___2 = 1233,
	FN_SEL_TIMER_TMU_0___2 = 1234,
	FN_SEL_TIMER_TMU_1___2 = 1235,
	FN_SEL_SCIF5_0___2 = 1236,
	FN_SEL_SCIF5_1___2 = 1237,
	FN_SEL_SSP1_1_0___2 = 1238,
	FN_SEL_SSP1_1_1___2 = 1239,
	FN_SEL_SSP1_1_2___2 = 1240,
	FN_SEL_SSP1_1_3___2 = 1241,
	FN_SEL_I2C6_0___2 = 1242,
	FN_SEL_I2C6_1___2 = 1243,
	FN_SEL_I2C6_2___2 = 1244,
	FN_SEL_LBSC_0___2 = 1245,
	FN_SEL_LBSC_1___2 = 1246,
	FN_SEL_SSP1_0_0___2 = 1247,
	FN_SEL_SSP1_0_1___2 = 1248,
	FN_SEL_SSP1_0_2___2 = 1249,
	FN_SEL_SSP1_0_3___2 = 1250,
	FN_SEL_SSP1_0_4___2 = 1251,
	FN_SEL_IEBUS_0___2 = 1252,
	FN_SEL_IEBUS_1___2 = 1253,
	FN_SEL_NDF_0___2 = 1254,
	FN_SEL_NDF_1___2 = 1255,
	FN_SEL_I2C2_0___2 = 1256,
	FN_SEL_I2C2_1___2 = 1257,
	FN_SEL_SSI2_0___2 = 1258,
	FN_SEL_SSI2_1___2 = 1259,
	FN_SEL_I2C1_0___2 = 1260,
	FN_SEL_I2C1_1___2 = 1261,
	FN_SEL_SSI1_0___2 = 1262,
	FN_SEL_SSI1_1___2 = 1263,
	FN_SEL_SSI9_0___2 = 1264,
	FN_SEL_SSI9_1___2 = 1265,
	FN_SEL_HSCIF4_0___2 = 1266,
	FN_SEL_HSCIF4_1___2 = 1267,
	FN_SEL_SPEED_PULSE_0___2 = 1268,
	FN_SEL_SPEED_PULSE_1___2 = 1269,
	FN_SEL_TIMER_TMU2_0___2 = 1270,
	FN_SEL_TIMER_TMU2_1___2 = 1271,
	FN_SEL_HSCIF3_0___2 = 1272,
	FN_SEL_HSCIF3_1___2 = 1273,
	FN_SEL_HSCIF3_2___2 = 1274,
	FN_SEL_HSCIF3_3___2 = 1275,
	FN_SEL_SIMCARD_0___2 = 1276,
	FN_SEL_SIMCARD_1___2 = 1277,
	FN_SEL_SIMCARD_2___2 = 1278,
	FN_SEL_SIMCARD_3___2 = 1279,
	FN_SEL_ADGB_0___2 = 1280,
	FN_SEL_ADGB_1___2 = 1281,
	FN_SEL_ADGC_0___2 = 1282,
	FN_SEL_ADGC_1___2 = 1283,
	FN_SEL_HSCIF1_0___2 = 1284,
	FN_SEL_HSCIF1_1___2 = 1285,
	FN_SEL_SDHI2_0___2 = 1286,
	FN_SEL_SDHI2_1___2 = 1287,
	FN_SEL_SCIF4_0___2 = 1288,
	FN_SEL_SCIF4_1___2 = 1289,
	FN_SEL_SCIF4_2___2 = 1290,
	FN_SEL_HSCIF2_0___2 = 1291,
	FN_SEL_HSCIF2_1___2 = 1292,
	FN_SEL_HSCIF2_2___2 = 1293,
	FN_SEL_SCIF3_0___2 = 1294,
	FN_SEL_SCIF3_1___2 = 1295,
	FN_SEL_ETHERAVB_0___2 = 1296,
	FN_SEL_ETHERAVB_1___2 = 1297,
	FN_SEL_SCIF2_0___2 = 1298,
	FN_SEL_SCIF2_1___2 = 1299,
	FN_SEL_DRIF3_0___2 = 1300,
	FN_SEL_DRIF3_1___2 = 1301,
	FN_SEL_SCIF1_0___2 = 1302,
	FN_SEL_SCIF1_1___2 = 1303,
	FN_SEL_DRIF2_0___2 = 1304,
	FN_SEL_DRIF2_1___2 = 1305,
	FN_SEL_SCIF_0___2 = 1306,
	FN_SEL_SCIF_1___2 = 1307,
	FN_SEL_DRIF1_0___2 = 1308,
	FN_SEL_DRIF1_1___2 = 1309,
	FN_SEL_DRIF1_2___2 = 1310,
	FN_SEL_REMOCON_0___2 = 1311,
	FN_SEL_REMOCON_1___2 = 1312,
	FN_SEL_DRIF0_0___2 = 1313,
	FN_SEL_DRIF0_1___2 = 1314,
	FN_SEL_DRIF0_2___2 = 1315,
	FN_SEL_RCAN0_0___2 = 1316,
	FN_SEL_RCAN0_1___2 = 1317,
	FN_SEL_CANFD0_0___2 = 1318,
	FN_SEL_CANFD0_1___2 = 1319,
	FN_SEL_PWM6_0___2 = 1320,
	FN_SEL_PWM6_1___2 = 1321,
	FN_SEL_ADGA_0___2 = 1322,
	FN_SEL_ADGA_1___2 = 1323,
	FN_SEL_ADGA_2___2 = 1324,
	FN_SEL_ADGA_3___2 = 1325,
	FN_SEL_PWM5_0___2 = 1326,
	FN_SEL_PWM5_1___2 = 1327,
	FN_SEL_PWM4_0___2 = 1328,
	FN_SEL_PWM4_1___2 = 1329,
	FN_SEL_PWM3_0___2 = 1330,
	FN_SEL_PWM3_1___2 = 1331,
	FN_SEL_PWM2_0___2 = 1332,
	FN_SEL_PWM2_1___2 = 1333,
	FN_SEL_PWM1_0___2 = 1334,
	FN_SEL_PWM1_1___2 = 1335,
	FN_SEL_VIN4_0___2 = 1336,
	FN_SEL_VIN4_1___2 = 1337,
	PINMUX_FUNCTION_END___2 = 1338,
	PINMUX_MARK_BEGIN___2 = 1339,
	CLKOUT_MARK___2 = 1340,
	MSIOF0_RXD_MARK___2 = 1341,
	MSIOF0_TXD_MARK___2 = 1342,
	MSIOF0_SCK_MARK___2 = 1343,
	SSI_SDATA5_MARK___2 = 1344,
	SSI_WS5_MARK___2 = 1345,
	SSI_SCK5_MARK___2 = 1346,
	GP7_03_MARK___2 = 1347,
	GP7_02_MARK___2 = 1348,
	AVS2_MARK___2 = 1349,
	AVS1_MARK___2 = 1350,
	IP0_3_0_MARK___2 = 1351,
	AVB_MDC_MARK___2 = 1352,
	MSIOF2_SS2_C_MARK___2 = 1353,
	IP1_3_0_MARK___2 = 1354,
	IRQ2_MARK___2 = 1355,
	QCPV_QDE_MARK___2 = 1356,
	DU_EXODDF_DU_ODDF_DISP_CDE_MARK___2 = 1357,
	VI4_DATA2_B_MARK___2 = 1358,
	MSIOF3_SYNC_E_MARK___2 = 1359,
	PWM3_B_MARK___2 = 1360,
	IP2_3_0_MARK___2 = 1361,
	A1_MARK___2 = 1362,
	LCDOUT17_MARK___2 = 1363,
	MSIOF3_TXD_B_MARK___2 = 1364,
	VI4_DATA9_MARK___2 = 1365,
	DU_DB1_MARK___2 = 1366,
	PWM4_A_MARK___2 = 1367,
	IP3_3_0_MARK___2 = 1368,
	A9_MARK___2 = 1369,
	MSIOF2_SCK_A_MARK___2 = 1370,
	CTS4_N_B_MARK___2 = 1371,
	VI5_VSYNC_N_MARK___2 = 1372,
	IP0_7_4_MARK___2 = 1373,
	AVB_MAGIC_MARK___2 = 1374,
	MSIOF2_SS1_C_MARK___2 = 1375,
	SCK4_A_MARK___2 = 1376,
	IP1_7_4_MARK___2 = 1377,
	IRQ3_MARK___2 = 1378,
	QSTVB_QVE_MARK___2 = 1379,
	DU_DOTCLKOUT1_MARK___2 = 1380,
	VI4_DATA3_B_MARK___2 = 1381,
	MSIOF3_SCK_E_MARK___2 = 1382,
	PWM4_B_MARK___2 = 1383,
	IP2_7_4_MARK___2 = 1384,
	A2_MARK___2 = 1385,
	LCDOUT18_MARK___2 = 1386,
	MSIOF3_SCK_B_MARK___2 = 1387,
	VI4_DATA10_MARK___2 = 1388,
	DU_DB2_MARK___2 = 1389,
	PWM5_A_MARK___2 = 1390,
	IP3_7_4_MARK___2 = 1391,
	A10_MARK___2 = 1392,
	MSIOF2_RXD_A_MARK___2 = 1393,
	RTS4_N_B_MARK___2 = 1394,
	VI5_HSYNC_N_MARK___2 = 1395,
	IP0_11_8_MARK___2 = 1396,
	AVB_PHY_INT_MARK___2 = 1397,
	MSIOF2_SYNC_C_MARK___2 = 1398,
	RX4_A_MARK___2 = 1399,
	IP1_11_8_MARK___2 = 1400,
	IRQ4_MARK___2 = 1401,
	QSTH_QHS_MARK___2 = 1402,
	DU_EXHSYNC_DU_HSYNC_MARK___2 = 1403,
	VI4_DATA4_B_MARK___2 = 1404,
	MSIOF3_RXD_E_MARK___2 = 1405,
	PWM5_B_MARK___2 = 1406,
	IP2_11_8_MARK___2 = 1407,
	A3_MARK___2 = 1408,
	LCDOUT19_MARK___2 = 1409,
	MSIOF3_RXD_B_MARK___2 = 1410,
	VI4_DATA11_MARK___2 = 1411,
	DU_DB3_MARK___2 = 1412,
	PWM6_A_MARK___2 = 1413,
	IP3_11_8_MARK___2 = 1414,
	A11_MARK___2 = 1415,
	TX3_B_MARK___2 = 1416,
	MSIOF2_TXD_A_MARK___2 = 1417,
	HTX4_B_MARK___2 = 1418,
	HSCK4_MARK___2 = 1419,
	VI5_FIELD_MARK___2 = 1420,
	SCL6_A_MARK___2 = 1421,
	AVB_AVTP_CAPTURE_B_MARK___2 = 1422,
	PWM2_B_MARK___2 = 1423,
	IP0_15_12_MARK___2 = 1424,
	AVB_LINK_MARK___2 = 1425,
	MSIOF2_SCK_C_MARK___2 = 1426,
	TX4_A_MARK___2 = 1427,
	IP1_15_12_MARK___2 = 1428,
	IRQ5_MARK___2 = 1429,
	QSTB_QHE_MARK___2 = 1430,
	DU_EXVSYNC_DU_VSYNC_MARK___2 = 1431,
	VI4_DATA5_B_MARK___2 = 1432,
	FSCLKST2_N_B_MARK = 1433,
	MSIOF3_TXD_E_MARK___2 = 1434,
	PWM6_B_MARK___2 = 1435,
	IP2_15_12_MARK___2 = 1436,
	A4_MARK___2 = 1437,
	LCDOUT20_MARK___2 = 1438,
	MSIOF3_SS1_B_MARK___2 = 1439,
	VI4_DATA12_MARK___2 = 1440,
	VI5_DATA12_MARK___2 = 1441,
	DU_DB4_MARK___2 = 1442,
	IP3_15_12_MARK___2 = 1443,
	A12_MARK___2 = 1444,
	LCDOUT12_MARK___2 = 1445,
	MSIOF3_SCK_C_MARK___2 = 1446,
	HRX4_A_MARK___2 = 1447,
	VI5_DATA8_MARK___2 = 1448,
	DU_DG4_MARK___2 = 1449,
	IP0_19_16_MARK___2 = 1450,
	AVB_AVTP_MATCH_A_MARK___2 = 1451,
	MSIOF2_RXD_C_MARK___2 = 1452,
	CTS4_N_A_MARK___2 = 1453,
	FSCLKST2_N_A_MARK = 1454,
	IP1_19_16_MARK___2 = 1455,
	PWM0_MARK___2 = 1456,
	AVB_AVTP_PPS_MARK___2 = 1457,
	VI4_DATA6_B_MARK___2 = 1458,
	IECLK_B_MARK___2 = 1459,
	IP2_19_16_MARK___2 = 1460,
	A5_MARK___2 = 1461,
	LCDOUT21_MARK___2 = 1462,
	MSIOF3_SS2_B_MARK___2 = 1463,
	SCK4_B_MARK___2 = 1464,
	VI4_DATA13_MARK___2 = 1465,
	VI5_DATA13_MARK___2 = 1466,
	DU_DB5_MARK___2 = 1467,
	IP3_19_16_MARK___2 = 1468,
	A13_MARK___2 = 1469,
	LCDOUT13_MARK___2 = 1470,
	MSIOF3_SYNC_C_MARK___2 = 1471,
	HTX4_A_MARK___2 = 1472,
	VI5_DATA9_MARK___2 = 1473,
	DU_DG5_MARK___2 = 1474,
	IP0_23_20_MARK___2 = 1475,
	AVB_AVTP_CAPTURE_A_MARK___2 = 1476,
	MSIOF2_TXD_C_MARK___2 = 1477,
	RTS4_N_A_MARK___2 = 1478,
	IP1_23_20_MARK___2 = 1479,
	PWM1_A_MARK___2 = 1480,
	HRX3_D_MARK___2 = 1481,
	VI4_DATA7_B_MARK___2 = 1482,
	IERX_B_MARK___2 = 1483,
	IP2_23_20_MARK___2 = 1484,
	A6_MARK___2 = 1485,
	LCDOUT22_MARK___2 = 1486,
	MSIOF2_SS1_A_MARK___2 = 1487,
	RX4_B_MARK___2 = 1488,
	VI4_DATA14_MARK___2 = 1489,
	VI5_DATA14_MARK___2 = 1490,
	DU_DB6_MARK___2 = 1491,
	IP3_23_20_MARK___2 = 1492,
	A14_MARK___2 = 1493,
	LCDOUT14_MARK___2 = 1494,
	MSIOF3_RXD_C_MARK___2 = 1495,
	HCTS4_N_MARK___2 = 1496,
	VI5_DATA10_MARK___2 = 1497,
	DU_DG6_MARK___2 = 1498,
	IP0_27_24_MARK___2 = 1499,
	IRQ0_MARK___2 = 1500,
	QPOLB_MARK___2 = 1501,
	DU_CDE_MARK___2 = 1502,
	VI4_DATA0_B_MARK___2 = 1503,
	CAN0_TX_B_MARK___2 = 1504,
	CANFD0_TX_B_MARK___2 = 1505,
	MSIOF3_SS2_E_MARK___2 = 1506,
	IP1_27_24_MARK___2 = 1507,
	PWM2_A_MARK___2 = 1508,
	HTX3_D_MARK___2 = 1509,
	IETX_B_MARK___2 = 1510,
	IP2_27_24_MARK___2 = 1511,
	A7_MARK___2 = 1512,
	LCDOUT23_MARK___2 = 1513,
	MSIOF2_SS2_A_MARK___2 = 1514,
	TX4_B_MARK___2 = 1515,
	VI4_DATA15_MARK___2 = 1516,
	VI5_DATA15_MARK___2 = 1517,
	DU_DB7_MARK___2 = 1518,
	IP3_27_24_MARK___2 = 1519,
	A15_MARK___2 = 1520,
	LCDOUT15_MARK___2 = 1521,
	MSIOF3_TXD_C_MARK___2 = 1522,
	HRTS4_N_MARK___2 = 1523,
	VI5_DATA11_MARK___2 = 1524,
	DU_DG7_MARK___2 = 1525,
	IP0_31_28_MARK___2 = 1526,
	IRQ1_MARK___2 = 1527,
	QPOLA_MARK___2 = 1528,
	DU_DISP_MARK___2 = 1529,
	VI4_DATA1_B_MARK___2 = 1530,
	CAN0_RX_B_MARK___2 = 1531,
	CANFD0_RX_B_MARK___2 = 1532,
	MSIOF3_SS1_E_MARK___2 = 1533,
	IP1_31_28_MARK___2 = 1534,
	A0_MARK___2 = 1535,
	LCDOUT16_MARK___2 = 1536,
	MSIOF3_SYNC_B_MARK___2 = 1537,
	VI4_DATA8_MARK___2 = 1538,
	DU_DB0_MARK___2 = 1539,
	PWM3_A_MARK___2 = 1540,
	IP2_31_28_MARK___2 = 1541,
	A8_MARK___2 = 1542,
	RX3_B_MARK___2 = 1543,
	MSIOF2_SYNC_A_MARK___2 = 1544,
	HRX4_B_MARK___2 = 1545,
	SDA6_A_MARK___2 = 1546,
	AVB_AVTP_MATCH_B_MARK___2 = 1547,
	PWM1_B_MARK___2 = 1548,
	IP3_31_28_MARK___2 = 1549,
	A16_MARK___2 = 1550,
	LCDOUT8_MARK___2 = 1551,
	VI4_FIELD_MARK___2 = 1552,
	DU_DG0_MARK___2 = 1553,
	IP4_3_0_MARK___2 = 1554,
	A17_MARK___2 = 1555,
	LCDOUT9_MARK___2 = 1556,
	VI4_VSYNC_N_MARK___2 = 1557,
	DU_DG1_MARK___2 = 1558,
	IP5_3_0_MARK___2 = 1559,
	WE0_N_MARK___2 = 1560,
	MSIOF3_TXD_D_MARK___2 = 1561,
	CTS3_N_MARK___2 = 1562,
	HCTS3_N_MARK___2 = 1563,
	SCL6_B_MARK___2 = 1564,
	CAN_CLK_MARK___2 = 1565,
	IECLK_A_MARK___2 = 1566,
	IP6_3_0_MARK___2 = 1567,
	D5_MARK___2 = 1568,
	MSIOF2_SYNC_B_MARK___2 = 1569,
	VI4_DATA21_MARK___2 = 1570,
	VI5_DATA5_MARK___2 = 1571,
	IP7_3_0_MARK___2 = 1572,
	D13_MARK___2 = 1573,
	LCDOUT5_MARK___2 = 1574,
	MSIOF2_SS2_D_MARK___2 = 1575,
	TX4_C_MARK___2 = 1576,
	VI4_DATA5_A_MARK___2 = 1577,
	DU_DR5_MARK___2 = 1578,
	IP4_7_4_MARK___2 = 1579,
	A18_MARK___2 = 1580,
	LCDOUT10_MARK___2 = 1581,
	VI4_HSYNC_N_MARK___2 = 1582,
	DU_DG2_MARK___2 = 1583,
	IP5_7_4_MARK___2 = 1584,
	WE1_N_MARK___2 = 1585,
	MSIOF3_SS1_D_MARK___2 = 1586,
	RTS3_N_MARK___2 = 1587,
	HRTS3_N_MARK___2 = 1588,
	SDA6_B_MARK___2 = 1589,
	CAN1_RX_MARK___2 = 1590,
	CANFD1_RX_MARK___2 = 1591,
	IERX_A_MARK___2 = 1592,
	IP6_7_4_MARK___2 = 1593,
	D6_MARK___2 = 1594,
	MSIOF2_RXD_B_MARK___2 = 1595,
	VI4_DATA22_MARK___2 = 1596,
	VI5_DATA6_MARK___2 = 1597,
	IP7_7_4_MARK___2 = 1598,
	D14_MARK___2 = 1599,
	LCDOUT6_MARK___2 = 1600,
	MSIOF3_SS1_A_MARK___2 = 1601,
	HRX3_C_MARK___2 = 1602,
	VI4_DATA6_A_MARK___2 = 1603,
	DU_DR6_MARK___2 = 1604,
	SCL6_C_MARK___2 = 1605,
	IP4_11_8_MARK___2 = 1606,
	A19_MARK___2 = 1607,
	LCDOUT11_MARK___2 = 1608,
	VI4_CLKENB_MARK___2 = 1609,
	DU_DG3_MARK___2 = 1610,
	IP5_11_8_MARK___2 = 1611,
	EX_WAIT0_A_MARK___2 = 1612,
	QCLK_MARK___2 = 1613,
	VI4_CLK_MARK___2 = 1614,
	DU_DOTCLKOUT0_MARK___2 = 1615,
	IP6_11_8_MARK___2 = 1616,
	D7_MARK___2 = 1617,
	MSIOF2_TXD_B_MARK___2 = 1618,
	VI4_DATA23_MARK___2 = 1619,
	VI5_DATA7_MARK___2 = 1620,
	IP7_11_8_MARK___2 = 1621,
	D15_MARK___2 = 1622,
	LCDOUT7_MARK___2 = 1623,
	MSIOF3_SS2_A_MARK___2 = 1624,
	HTX3_C_MARK___2 = 1625,
	VI4_DATA7_A_MARK___2 = 1626,
	DU_DR7_MARK___2 = 1627,
	SDA6_C_MARK___2 = 1628,
	IP4_15_12_MARK___2 = 1629,
	CS0_N_MARK___2 = 1630,
	VI5_CLKENB_MARK___2 = 1631,
	IP5_15_12_MARK___2 = 1632,
	D0_MARK___2 = 1633,
	MSIOF2_SS1_B_MARK___2 = 1634,
	MSIOF3_SCK_A_MARK___2 = 1635,
	VI4_DATA16_MARK___2 = 1636,
	VI5_DATA0_MARK___2 = 1637,
	IP6_15_12_MARK___2 = 1638,
	D8_MARK___2 = 1639,
	LCDOUT0_MARK___2 = 1640,
	MSIOF2_SCK_D_MARK___2 = 1641,
	SCK4_C_MARK___2 = 1642,
	VI4_DATA0_A_MARK___2 = 1643,
	DU_DR0_MARK___2 = 1644,
	IP4_19_16_MARK___2 = 1645,
	CS1_N_MARK___2 = 1646,
	VI5_CLK_MARK___2 = 1647,
	EX_WAIT0_B_MARK___2 = 1648,
	IP5_19_16_MARK___2 = 1649,
	D1_MARK___2 = 1650,
	MSIOF2_SS2_B_MARK___2 = 1651,
	MSIOF3_SYNC_A_MARK___2 = 1652,
	VI4_DATA17_MARK___2 = 1653,
	VI5_DATA1_MARK___2 = 1654,
	IP6_19_16_MARK___2 = 1655,
	D9_MARK___2 = 1656,
	LCDOUT1_MARK___2 = 1657,
	MSIOF2_SYNC_D_MARK___2 = 1658,
	VI4_DATA1_A_MARK___2 = 1659,
	DU_DR1_MARK___2 = 1660,
	IP7_19_16_MARK___2 = 1661,
	SD0_CLK_MARK___2 = 1662,
	MSIOF1_SCK_E_MARK___2 = 1663,
	STP_OPWM_0_B_MARK___2 = 1664,
	IP4_23_20_MARK___2 = 1665,
	BS_N_MARK___2 = 1666,
	QSTVA_QVS_MARK___2 = 1667,
	MSIOF3_SCK_D_MARK___2 = 1668,
	SCK3_MARK___2 = 1669,
	HSCK3_MARK___2 = 1670,
	CAN1_TX_MARK___2 = 1671,
	CANFD1_TX_MARK___2 = 1672,
	IETX_A_MARK___2 = 1673,
	IP5_23_20_MARK___2 = 1674,
	D2_MARK___2 = 1675,
	MSIOF3_RXD_A_MARK___2 = 1676,
	VI4_DATA18_MARK___2 = 1677,
	VI5_DATA2_MARK___2 = 1678,
	IP6_23_20_MARK___2 = 1679,
	D10_MARK___2 = 1680,
	LCDOUT2_MARK___2 = 1681,
	MSIOF2_RXD_D_MARK___2 = 1682,
	HRX3_B_MARK___2 = 1683,
	VI4_DATA2_A_MARK___2 = 1684,
	CTS4_N_C_MARK___2 = 1685,
	DU_DR2_MARK___2 = 1686,
	IP7_23_20_MARK___2 = 1687,
	SD0_CMD_MARK___2 = 1688,
	MSIOF1_SYNC_E_MARK___2 = 1689,
	STP_IVCXO27_0_B_MARK___2 = 1690,
	IP4_27_24_MARK___2 = 1691,
	RD_N_MARK___2 = 1692,
	MSIOF3_SYNC_D_MARK___2 = 1693,
	RX3_A_MARK___2 = 1694,
	HRX3_A_MARK___2 = 1695,
	CAN0_TX_A_MARK___2 = 1696,
	CANFD0_TX_A_MARK___2 = 1697,
	IP5_27_24_MARK___2 = 1698,
	D3_MARK___2 = 1699,
	MSIOF3_TXD_A_MARK___2 = 1700,
	VI4_DATA19_MARK___2 = 1701,
	VI5_DATA3_MARK___2 = 1702,
	IP6_27_24_MARK___2 = 1703,
	D11_MARK___2 = 1704,
	LCDOUT3_MARK___2 = 1705,
	MSIOF2_TXD_D_MARK___2 = 1706,
	HTX3_B_MARK___2 = 1707,
	VI4_DATA3_A_MARK___2 = 1708,
	RTS4_N_C_MARK___2 = 1709,
	DU_DR3_MARK___2 = 1710,
	IP7_27_24_MARK___2 = 1711,
	SD0_DAT0_MARK___2 = 1712,
	MSIOF1_RXD_E_MARK___2 = 1713,
	TS_SCK0_B_MARK___2 = 1714,
	STP_ISCLK_0_B_MARK___2 = 1715,
	IP4_31_28_MARK___2 = 1716,
	RD_WR_N_MARK___2 = 1717,
	MSIOF3_RXD_D_MARK___2 = 1718,
	TX3_A_MARK___2 = 1719,
	HTX3_A_MARK___2 = 1720,
	CAN0_RX_A_MARK___2 = 1721,
	CANFD0_RX_A_MARK___2 = 1722,
	IP5_31_28_MARK___2 = 1723,
	D4_MARK___2 = 1724,
	MSIOF2_SCK_B_MARK___2 = 1725,
	VI4_DATA20_MARK___2 = 1726,
	VI5_DATA4_MARK___2 = 1727,
	IP6_31_28_MARK___2 = 1728,
	D12_MARK___2 = 1729,
	LCDOUT4_MARK___2 = 1730,
	MSIOF2_SS1_D_MARK___2 = 1731,
	RX4_C_MARK___2 = 1732,
	VI4_DATA4_A_MARK___2 = 1733,
	DU_DR4_MARK___2 = 1734,
	IP7_31_28_MARK___2 = 1735,
	SD0_DAT1_MARK___2 = 1736,
	MSIOF1_TXD_E_MARK___2 = 1737,
	TS_SPSYNC0_B_MARK___2 = 1738,
	STP_ISSYNC_0_B_MARK___2 = 1739,
	IP8_3_0_MARK___2 = 1740,
	SD0_DAT2_MARK___2 = 1741,
	MSIOF1_SS1_E_MARK___2 = 1742,
	TS_SDAT0_B_MARK___2 = 1743,
	STP_ISD_0_B_MARK___2 = 1744,
	IP9_3_0_MARK___2 = 1745,
	SD2_CLK_MARK___2 = 1746,
	NFDATA8_MARK___2 = 1747,
	IP10_3_0_MARK___2 = 1748,
	SD3_CMD_MARK___2 = 1749,
	NFRE_N_MARK___2 = 1750,
	IP11_3_0_MARK___2 = 1751,
	SD3_DAT7_MARK___2 = 1752,
	SD3_WP_MARK___2 = 1753,
	NFDATA7_MARK___2 = 1754,
	IP8_7_4_MARK___2 = 1755,
	SD0_DAT3_MARK___2 = 1756,
	MSIOF1_SS2_E_MARK___2 = 1757,
	TS_SDEN0_B_MARK___2 = 1758,
	STP_ISEN_0_B_MARK___2 = 1759,
	IP9_7_4_MARK___2 = 1760,
	SD2_CMD_MARK___2 = 1761,
	NFDATA9_MARK___2 = 1762,
	IP10_7_4_MARK___2 = 1763,
	SD3_DAT0_MARK___2 = 1764,
	NFDATA0_MARK___2 = 1765,
	IP11_7_4_MARK___2 = 1766,
	SD3_DS_MARK___2 = 1767,
	NFCLE_MARK___2 = 1768,
	IP8_11_8_MARK___2 = 1769,
	SD1_CLK_MARK___2 = 1770,
	MSIOF1_SCK_G_MARK___2 = 1771,
	SIM0_CLK_A_MARK___2 = 1772,
	IP9_11_8_MARK___2 = 1773,
	SD2_DAT0_MARK___2 = 1774,
	NFDATA10_MARK___2 = 1775,
	IP10_11_8_MARK___2 = 1776,
	SD3_DAT1_MARK___2 = 1777,
	NFDATA1_MARK___2 = 1778,
	IP11_11_8_MARK___2 = 1779,
	SD0_CD_MARK___2 = 1780,
	NFDATA14_A_MARK___2 = 1781,
	SCL2_B_MARK___2 = 1782,
	SIM0_RST_A_MARK___2 = 1783,
	IP8_15_12_MARK___2 = 1784,
	SD1_CMD_MARK___2 = 1785,
	MSIOF1_SYNC_G_MARK___2 = 1786,
	NFCE_N_B_MARK___2 = 1787,
	SIM0_D_A_MARK___2 = 1788,
	STP_IVCXO27_1_B_MARK___2 = 1789,
	IP9_15_12_MARK___2 = 1790,
	SD2_DAT1_MARK___2 = 1791,
	NFDATA11_MARK___2 = 1792,
	IP10_15_12_MARK___2 = 1793,
	SD3_DAT2_MARK___2 = 1794,
	NFDATA2_MARK___2 = 1795,
	IP11_15_12_MARK___2 = 1796,
	SD0_WP_MARK___2 = 1797,
	NFDATA15_A_MARK___2 = 1798,
	SDA2_B_MARK___2 = 1799,
	IP8_19_16_MARK___2 = 1800,
	SD1_DAT0_MARK___2 = 1801,
	SD2_DAT4_MARK___2 = 1802,
	MSIOF1_RXD_G_MARK___2 = 1803,
	NFWP_N_B_MARK___2 = 1804,
	TS_SCK1_B_MARK___2 = 1805,
	STP_ISCLK_1_B_MARK___2 = 1806,
	IP9_19_16_MARK___2 = 1807,
	SD2_DAT2_MARK___2 = 1808,
	NFDATA12_MARK___2 = 1809,
	IP10_19_16_MARK___2 = 1810,
	SD3_DAT3_MARK___2 = 1811,
	NFDATA3_MARK___2 = 1812,
	IP11_19_16_MARK___2 = 1813,
	SD1_CD_MARK___2 = 1814,
	NFRB_N_A_MARK___2 = 1815,
	SIM0_CLK_B_MARK___2 = 1816,
	IP8_23_20_MARK___2 = 1817,
	SD1_DAT1_MARK___2 = 1818,
	SD2_DAT5_MARK___2 = 1819,
	MSIOF1_TXD_G_MARK___2 = 1820,
	NFDATA14_B_MARK___2 = 1821,
	TS_SPSYNC1_B_MARK___2 = 1822,
	STP_ISSYNC_1_B_MARK___2 = 1823,
	IP9_23_20_MARK___2 = 1824,
	SD2_DAT3_MARK___2 = 1825,
	NFDATA13_MARK___2 = 1826,
	IP10_23_20_MARK___2 = 1827,
	SD3_DAT4_MARK___2 = 1828,
	SD2_CD_A_MARK___2 = 1829,
	NFDATA4_MARK___2 = 1830,
	IP11_23_20_MARK___2 = 1831,
	SD1_WP_MARK___2 = 1832,
	NFCE_N_A_MARK___2 = 1833,
	SIM0_D_B_MARK___2 = 1834,
	IP8_27_24_MARK___2 = 1835,
	SD1_DAT2_MARK___2 = 1836,
	SD2_DAT6_MARK___2 = 1837,
	MSIOF1_SS1_G_MARK___2 = 1838,
	NFDATA15_B_MARK___2 = 1839,
	TS_SDAT1_B_MARK___2 = 1840,
	STP_ISD_1_B_MARK___2 = 1841,
	IP9_27_24_MARK___2 = 1842,
	SD2_DS_MARK___2 = 1843,
	NFALE_MARK___2 = 1844,
	SATA_DEVSLP_B_MARK = 1845,
	IP10_27_24_MARK___2 = 1846,
	SD3_DAT5_MARK___2 = 1847,
	SD2_WP_A_MARK___2 = 1848,
	NFDATA5_MARK___2 = 1849,
	IP11_27_24_MARK___2 = 1850,
	SCK0_MARK___2 = 1851,
	HSCK1_B_MARK___2 = 1852,
	MSIOF1_SS2_B_MARK___2 = 1853,
	AUDIO_CLKC_B_MARK___2 = 1854,
	SDA2_A_MARK___2 = 1855,
	SIM0_RST_B_MARK___2 = 1856,
	STP_OPWM_0_C_MARK___2 = 1857,
	RIF0_CLK_B_MARK___2 = 1858,
	ADICHS2_MARK___2 = 1859,
	SCK5_B_MARK___2 = 1860,
	IP8_31_28_MARK___2 = 1861,
	SD1_DAT3_MARK___2 = 1862,
	SD2_DAT7_MARK___2 = 1863,
	MSIOF1_SS2_G_MARK___2 = 1864,
	NFRB_N_B_MARK___2 = 1865,
	TS_SDEN1_B_MARK___2 = 1866,
	STP_ISEN_1_B_MARK___2 = 1867,
	IP9_31_28_MARK___2 = 1868,
	SD3_CLK_MARK___2 = 1869,
	NFWE_N_MARK___2 = 1870,
	IP10_31_28_MARK___2 = 1871,
	SD3_DAT6_MARK___2 = 1872,
	SD3_CD_MARK___2 = 1873,
	NFDATA6_MARK___2 = 1874,
	IP11_31_28_MARK___2 = 1875,
	RX0_MARK___2 = 1876,
	HRX1_B_MARK___2 = 1877,
	TS_SCK0_C_MARK___2 = 1878,
	STP_ISCLK_0_C_MARK___2 = 1879,
	RIF0_D0_B_MARK___2 = 1880,
	IP12_3_0_MARK___2 = 1881,
	TX0_MARK___2 = 1882,
	HTX1_B_MARK___2 = 1883,
	TS_SPSYNC0_C_MARK___2 = 1884,
	STP_ISSYNC_0_C_MARK___2 = 1885,
	RIF0_D1_B_MARK___2 = 1886,
	IP13_3_0_MARK___2 = 1887,
	TX2_A_MARK___2 = 1888,
	SD2_CD_B_MARK___2 = 1889,
	SCL1_A_MARK___2 = 1890,
	FMCLK_A_MARK___2 = 1891,
	RIF1_D1_C_MARK___2 = 1892,
	FSO_CFE_0_N_MARK___2 = 1893,
	IP14_3_0_MARK___2 = 1894,
	MSIOF0_SS1_MARK___2 = 1895,
	RX5_A_MARK___2 = 1896,
	NFWP_N_A_MARK___2 = 1897,
	AUDIO_CLKA_C_MARK___2 = 1898,
	SSI_SCK2_A_MARK___2 = 1899,
	STP_IVCXO27_0_C_MARK___2 = 1900,
	AUDIO_CLKOUT3_A_MARK___2 = 1901,
	TCLK1_B_MARK___2 = 1902,
	IP15_3_0_MARK___2 = 1903,
	SSI_SDATA1_A_MARK___2 = 1904,
	IP12_7_4_MARK___2 = 1905,
	CTS0_N_MARK___2 = 1906,
	HCTS1_N_B_MARK___2 = 1907,
	MSIOF1_SYNC_B_MARK___2 = 1908,
	TS_SPSYNC1_C_MARK___2 = 1909,
	STP_ISSYNC_1_C_MARK___2 = 1910,
	RIF1_SYNC_B_MARK___2 = 1911,
	AUDIO_CLKOUT_C_MARK___2 = 1912,
	ADICS_SAMP_MARK___2 = 1913,
	IP13_7_4_MARK___2 = 1914,
	RX2_A_MARK___2 = 1915,
	SD2_WP_B_MARK___2 = 1916,
	SDA1_A_MARK___2 = 1917,
	FMIN_A_MARK___2 = 1918,
	RIF1_SYNC_C_MARK___2 = 1919,
	FSO_CFE_1_N_MARK___2 = 1920,
	IP14_7_4_MARK___2 = 1921,
	MSIOF0_SS2_MARK___2 = 1922,
	TX5_A_MARK___2 = 1923,
	MSIOF1_SS2_D_MARK___2 = 1924,
	AUDIO_CLKC_A_MARK___2 = 1925,
	SSI_WS2_A_MARK___2 = 1926,
	STP_OPWM_0_D_MARK___2 = 1927,
	AUDIO_CLKOUT_D_MARK___2 = 1928,
	SPEEDIN_B_MARK___2 = 1929,
	IP15_7_4_MARK___2 = 1930,
	SSI_SDATA2_A_MARK___2 = 1931,
	SSI_SCK1_B_MARK___2 = 1932,
	IP12_11_8_MARK___2 = 1933,
	RTS0_N_MARK___2 = 1934,
	HRTS1_N_B_MARK___2 = 1935,
	MSIOF1_SS1_B_MARK___2 = 1936,
	AUDIO_CLKA_B_MARK___2 = 1937,
	SCL2_A_MARK___2 = 1938,
	STP_IVCXO27_1_C_MARK___2 = 1939,
	RIF0_SYNC_B_MARK___2 = 1940,
	ADICHS1_MARK___2 = 1941,
	IP13_11_8_MARK___2 = 1942,
	HSCK0_MARK___2 = 1943,
	MSIOF1_SCK_D_MARK___2 = 1944,
	AUDIO_CLKB_A_MARK___2 = 1945,
	SSI_SDATA1_B_MARK___2 = 1946,
	TS_SCK0_D_MARK___2 = 1947,
	STP_ISCLK_0_D_MARK___2 = 1948,
	RIF0_CLK_C_MARK___2 = 1949,
	RX5_B_MARK___2 = 1950,
	IP14_11_8_MARK___2 = 1951,
	MLB_CLK_MARK___2 = 1952,
	MSIOF1_SCK_F_MARK___2 = 1953,
	SCL1_B_MARK___2 = 1954,
	IP15_11_8_MARK___2 = 1955,
	SSI_SCK349_MARK___2 = 1956,
	MSIOF1_SS1_A_MARK___2 = 1957,
	STP_OPWM_0_A_MARK___2 = 1958,
	IP12_15_12_MARK___2 = 1959,
	RX1_A_MARK___2 = 1960,
	HRX1_A_MARK___2 = 1961,
	TS_SDAT0_C_MARK___2 = 1962,
	STP_ISD_0_C_MARK___2 = 1963,
	RIF1_CLK_C_MARK___2 = 1964,
	IP13_15_12_MARK___2 = 1965,
	HRX0_MARK___2 = 1966,
	MSIOF1_RXD_D_MARK___2 = 1967,
	SSI_SDATA2_B_MARK___2 = 1968,
	TS_SDEN0_D_MARK___2 = 1969,
	STP_ISEN_0_D_MARK___2 = 1970,
	RIF0_D0_C_MARK___2 = 1971,
	IP14_15_12_MARK___2 = 1972,
	MLB_SIG_MARK___2 = 1973,
	RX1_B_MARK___2 = 1974,
	MSIOF1_SYNC_F_MARK___2 = 1975,
	SDA1_B_MARK___2 = 1976,
	IP15_15_12_MARK___2 = 1977,
	SSI_WS349_MARK___2 = 1978,
	HCTS2_N_A_MARK___2 = 1979,
	MSIOF1_SS2_A_MARK___2 = 1980,
	STP_IVCXO27_0_A_MARK___2 = 1981,
	IP12_19_16_MARK___2 = 1982,
	TX1_A_MARK___2 = 1983,
	HTX1_A_MARK___2 = 1984,
	TS_SDEN0_C_MARK___2 = 1985,
	STP_ISEN_0_C_MARK___2 = 1986,
	RIF1_D0_C_MARK___2 = 1987,
	IP13_19_16_MARK___2 = 1988,
	HTX0_MARK___2 = 1989,
	MSIOF1_TXD_D_MARK___2 = 1990,
	SSI_SDATA9_B_MARK___2 = 1991,
	TS_SDAT0_D_MARK___2 = 1992,
	STP_ISD_0_D_MARK___2 = 1993,
	RIF0_D1_C_MARK___2 = 1994,
	IP14_19_16_MARK___2 = 1995,
	MLB_DAT_MARK___2 = 1996,
	TX1_B_MARK___2 = 1997,
	MSIOF1_RXD_F_MARK___2 = 1998,
	IP15_19_16_MARK___2 = 1999,
	SSI_SDATA3_MARK___2 = 2000,
	HRTS2_N_A_MARK___2 = 2001,
	MSIOF1_TXD_A_MARK___2 = 2002,
	TS_SCK0_A_MARK___2 = 2003,
	STP_ISCLK_0_A_MARK___2 = 2004,
	RIF0_D1_A_MARK___2 = 2005,
	RIF2_D0_A_MARK___2 = 2006,
	IP12_23_20_MARK___2 = 2007,
	CTS1_N_MARK___2 = 2008,
	HCTS1_N_A_MARK___2 = 2009,
	MSIOF1_RXD_B_MARK___2 = 2010,
	TS_SDEN1_C_MARK___2 = 2011,
	STP_ISEN_1_C_MARK___2 = 2012,
	RIF1_D0_B_MARK___2 = 2013,
	ADIDATA_MARK___2 = 2014,
	IP13_23_20_MARK___2 = 2015,
	HCTS0_N_MARK___2 = 2016,
	RX2_B_MARK___2 = 2017,
	MSIOF1_SYNC_D_MARK___2 = 2018,
	SSI_SCK9_A_MARK___2 = 2019,
	TS_SPSYNC0_D_MARK___2 = 2020,
	STP_ISSYNC_0_D_MARK___2 = 2021,
	RIF0_SYNC_C_MARK___2 = 2022,
	AUDIO_CLKOUT1_A_MARK___2 = 2023,
	IP14_23_20_MARK___2 = 2024,
	SSI_SCK01239_MARK___2 = 2025,
	MSIOF1_TXD_F_MARK___2 = 2026,
	IP15_23_20_MARK___2 = 2027,
	SSI_SCK4_MARK___2 = 2028,
	HRX2_A_MARK___2 = 2029,
	MSIOF1_SCK_A_MARK___2 = 2030,
	TS_SDAT0_A_MARK___2 = 2031,
	STP_ISD_0_A_MARK___2 = 2032,
	RIF0_CLK_A_MARK___2 = 2033,
	RIF2_CLK_A_MARK___2 = 2034,
	IP12_27_24_MARK___2 = 2035,
	RTS1_N_MARK___2 = 2036,
	HRTS1_N_A_MARK___2 = 2037,
	MSIOF1_TXD_B_MARK___2 = 2038,
	TS_SDAT1_C_MARK___2 = 2039,
	STP_ISD_1_C_MARK___2 = 2040,
	RIF1_D1_B_MARK___2 = 2041,
	ADICHS0_MARK___2 = 2042,
	IP13_27_24_MARK___2 = 2043,
	HRTS0_N_MARK___2 = 2044,
	TX2_B_MARK___2 = 2045,
	MSIOF1_SS1_D_MARK___2 = 2046,
	SSI_WS9_A_MARK___2 = 2047,
	STP_IVCXO27_0_D_MARK___2 = 2048,
	BPFCLK_A_MARK___2 = 2049,
	AUDIO_CLKOUT2_A_MARK___2 = 2050,
	IP14_27_24_MARK___2 = 2051,
	SSI_WS01239_MARK___2 = 2052,
	MSIOF1_SS1_F_MARK___2 = 2053,
	IP15_27_24_MARK___2 = 2054,
	SSI_WS4_MARK___2 = 2055,
	HTX2_A_MARK___2 = 2056,
	MSIOF1_SYNC_A_MARK___2 = 2057,
	TS_SDEN0_A_MARK___2 = 2058,
	STP_ISEN_0_A_MARK___2 = 2059,
	RIF0_SYNC_A_MARK___2 = 2060,
	RIF2_SYNC_A_MARK___2 = 2061,
	IP12_31_28_MARK___2 = 2062,
	SCK2_MARK___2 = 2063,
	SCIF_CLK_B_MARK___2 = 2064,
	MSIOF1_SCK_B_MARK___2 = 2065,
	TS_SCK1_C_MARK___2 = 2066,
	STP_ISCLK_1_C_MARK___2 = 2067,
	RIF1_CLK_B_MARK___2 = 2068,
	ADICLK_MARK___2 = 2069,
	IP13_31_28_MARK___2 = 2070,
	MSIOF0_SYNC_MARK___2 = 2071,
	AUDIO_CLKOUT_A_MARK___2 = 2072,
	TX5_B_MARK___2 = 2073,
	BPFCLK_D_MARK___2 = 2074,
	IP14_31_28_MARK___2 = 2075,
	SSI_SDATA0_MARK___2 = 2076,
	MSIOF1_SS2_F_MARK___2 = 2077,
	IP15_31_28_MARK___2 = 2078,
	SSI_SDATA4_MARK___2 = 2079,
	HSCK2_A_MARK___2 = 2080,
	MSIOF1_RXD_A_MARK___2 = 2081,
	TS_SPSYNC0_A_MARK___2 = 2082,
	STP_ISSYNC_0_A_MARK___2 = 2083,
	RIF0_D0_A_MARK___2 = 2084,
	RIF2_D1_A_MARK___2 = 2085,
	IP16_3_0_MARK___2 = 2086,
	SSI_SCK6_MARK___2 = 2087,
	SIM0_RST_D_MARK___2 = 2088,
	IP17_3_0_MARK___2 = 2089,
	AUDIO_CLKA_A_MARK___2 = 2090,
	IP18_3_0_MARK___2 = 2091,
	GP6_30_MARK___2 = 2092,
	AUDIO_CLKOUT2_B_MARK___2 = 2093,
	SSI_SCK9_B_MARK___2 = 2094,
	TS_SDEN0_E_MARK___2 = 2095,
	STP_ISEN_0_E_MARK___2 = 2096,
	RIF2_D0_B_MARK___2 = 2097,
	TPU0TO2_MARK___2 = 2098,
	FMCLK_C_MARK___2 = 2099,
	FMCLK_D_MARK___2 = 2100,
	IP16_7_4_MARK___2 = 2101,
	SSI_WS6_MARK___2 = 2102,
	SIM0_D_D_MARK___2 = 2103,
	IP17_7_4_MARK___2 = 2104,
	AUDIO_CLKB_B_MARK___2 = 2105,
	SCIF_CLK_A_MARK___2 = 2106,
	STP_IVCXO27_1_D_MARK___2 = 2107,
	REMOCON_A_MARK___2 = 2108,
	TCLK1_A_MARK___2 = 2109,
	IP18_7_4_MARK___2 = 2110,
	GP6_31_MARK___2 = 2111,
	AUDIO_CLKOUT3_B_MARK___2 = 2112,
	SSI_WS9_B_MARK___2 = 2113,
	TS_SPSYNC0_E_MARK___2 = 2114,
	STP_ISSYNC_0_E_MARK___2 = 2115,
	RIF2_D1_B_MARK___2 = 2116,
	TPU0TO3_MARK___2 = 2117,
	FMIN_C_MARK___2 = 2118,
	FMIN_D_MARK___2 = 2119,
	IP16_11_8_MARK___2 = 2120,
	SSI_SDATA6_MARK___2 = 2121,
	SIM0_CLK_D_MARK___2 = 2122,
	SATA_DEVSLP_A_MARK = 2123,
	IP17_11_8_MARK___2 = 2124,
	USB0_PWEN_MARK___2 = 2125,
	SIM0_RST_C_MARK___2 = 2126,
	TS_SCK1_D_MARK___2 = 2127,
	STP_ISCLK_1_D_MARK___2 = 2128,
	BPFCLK_B_MARK___2 = 2129,
	RIF3_CLK_B_MARK___2 = 2130,
	HSCK2_C_MARK___2 = 2131,
	IP16_15_12_MARK___2 = 2132,
	SSI_SCK78_MARK___2 = 2133,
	HRX2_B_MARK___2 = 2134,
	MSIOF1_SCK_C_MARK___2 = 2135,
	TS_SCK1_A_MARK___2 = 2136,
	STP_ISCLK_1_A_MARK___2 = 2137,
	RIF1_CLK_A_MARK___2 = 2138,
	RIF3_CLK_A_MARK___2 = 2139,
	IP17_15_12_MARK___2 = 2140,
	USB0_OVC_MARK___2 = 2141,
	SIM0_D_C_MARK___2 = 2142,
	TS_SDAT1_D_MARK___2 = 2143,
	STP_ISD_1_D_MARK___2 = 2144,
	RIF3_SYNC_B_MARK___2 = 2145,
	HRX2_C_MARK___2 = 2146,
	IP16_19_16_MARK___2 = 2147,
	SSI_WS78_MARK___2 = 2148,
	HTX2_B_MARK___2 = 2149,
	MSIOF1_SYNC_C_MARK___2 = 2150,
	TS_SDAT1_A_MARK___2 = 2151,
	STP_ISD_1_A_MARK___2 = 2152,
	RIF1_SYNC_A_MARK___2 = 2153,
	RIF3_SYNC_A_MARK___2 = 2154,
	IP17_19_16_MARK___2 = 2155,
	USB1_PWEN_MARK___2 = 2156,
	SIM0_CLK_C_MARK___2 = 2157,
	SSI_SCK1_A_MARK___2 = 2158,
	TS_SCK0_E_MARK___2 = 2159,
	STP_ISCLK_0_E_MARK___2 = 2160,
	FMCLK_B_MARK___2 = 2161,
	RIF2_CLK_B_MARK___2 = 2162,
	SPEEDIN_A_MARK___2 = 2163,
	HTX2_C_MARK___2 = 2164,
	IP16_23_20_MARK___2 = 2165,
	SSI_SDATA7_MARK___2 = 2166,
	HCTS2_N_B_MARK___2 = 2167,
	MSIOF1_RXD_C_MARK___2 = 2168,
	TS_SDEN1_A_MARK___2 = 2169,
	STP_ISEN_1_A_MARK___2 = 2170,
	RIF1_D0_A_MARK___2 = 2171,
	RIF3_D0_A_MARK___2 = 2172,
	TCLK2_A_MARK___2 = 2173,
	IP17_23_20_MARK___2 = 2174,
	USB1_OVC_MARK___2 = 2175,
	MSIOF1_SS2_C_MARK___2 = 2176,
	SSI_WS1_A_MARK___2 = 2177,
	TS_SDAT0_E_MARK___2 = 2178,
	STP_ISD_0_E_MARK___2 = 2179,
	FMIN_B_MARK___2 = 2180,
	RIF2_SYNC_B_MARK___2 = 2181,
	REMOCON_B_MARK___2 = 2182,
	HCTS2_N_C_MARK___2 = 2183,
	IP16_27_24_MARK___2 = 2184,
	SSI_SDATA8_MARK___2 = 2185,
	HRTS2_N_B_MARK___2 = 2186,
	MSIOF1_TXD_C_MARK___2 = 2187,
	TS_SPSYNC1_A_MARK___2 = 2188,
	STP_ISSYNC_1_A_MARK___2 = 2189,
	RIF1_D1_A_MARK___2 = 2190,
	RIF3_D1_A_MARK___2 = 2191,
	IP17_27_24_MARK___2 = 2192,
	USB30_PWEN_MARK___2 = 2193,
	AUDIO_CLKOUT_B_MARK___2 = 2194,
	SSI_SCK2_B_MARK___2 = 2195,
	TS_SDEN1_D_MARK___2 = 2196,
	STP_ISEN_1_D_MARK___2 = 2197,
	STP_OPWM_0_E_MARK___2 = 2198,
	RIF3_D0_B_MARK___2 = 2199,
	TCLK2_B_MARK___2 = 2200,
	TPU0TO0_MARK___2 = 2201,
	BPFCLK_C_MARK___2 = 2202,
	HRTS2_N_C_MARK___2 = 2203,
	IP16_31_28_MARK___2 = 2204,
	SSI_SDATA9_A_MARK___2 = 2205,
	HSCK2_B_MARK___2 = 2206,
	MSIOF1_SS1_C_MARK___2 = 2207,
	HSCK1_A_MARK___2 = 2208,
	SSI_WS1_B_MARK___2 = 2209,
	SCK1_MARK___2 = 2210,
	STP_IVCXO27_1_A_MARK___2 = 2211,
	SCK5_A_MARK___2 = 2212,
	IP17_31_28_MARK___2 = 2213,
	USB30_OVC_MARK___2 = 2214,
	AUDIO_CLKOUT1_B_MARK___2 = 2215,
	SSI_WS2_B_MARK___2 = 2216,
	TS_SPSYNC1_D_MARK___2 = 2217,
	STP_ISSYNC_1_D_MARK___2 = 2218,
	STP_IVCXO27_0_E_MARK___2 = 2219,
	RIF3_D1_B_MARK___2 = 2220,
	FSO_TOE_N_MARK___2 = 2221,
	TPU0TO1_MARK___2 = 2222,
	SEL_MSIOF3_0_MARK___2 = 2223,
	SEL_MSIOF3_1_MARK___2 = 2224,
	SEL_MSIOF3_2_MARK___2 = 2225,
	SEL_MSIOF3_3_MARK___2 = 2226,
	SEL_MSIOF3_4_MARK___2 = 2227,
	SEL_TSIF1_0_MARK___2 = 2228,
	SEL_TSIF1_1_MARK___2 = 2229,
	SEL_TSIF1_2_MARK___2 = 2230,
	SEL_TSIF1_3_MARK___2 = 2231,
	I2C_SEL_5_0_MARK___2 = 2232,
	I2C_SEL_5_1_MARK___2 = 2233,
	I2C_SEL_3_0_MARK___2 = 2234,
	I2C_SEL_3_1_MARK___2 = 2235,
	SEL_TSIF0_0_MARK___2 = 2236,
	SEL_TSIF0_1_MARK___2 = 2237,
	SEL_TSIF0_2_MARK___2 = 2238,
	SEL_TSIF0_3_MARK___2 = 2239,
	SEL_TSIF0_4_MARK___2 = 2240,
	I2C_SEL_0_0_MARK___2 = 2241,
	I2C_SEL_0_1_MARK___2 = 2242,
	SEL_MSIOF2_0_MARK___2 = 2243,
	SEL_MSIOF2_1_MARK___2 = 2244,
	SEL_MSIOF2_2_MARK___2 = 2245,
	SEL_MSIOF2_3_MARK___2 = 2246,
	SEL_FM_0_MARK___2 = 2247,
	SEL_FM_1_MARK___2 = 2248,
	SEL_FM_2_MARK___2 = 2249,
	SEL_FM_3_MARK___2 = 2250,
	SEL_MSIOF1_0_MARK___2 = 2251,
	SEL_MSIOF1_1_MARK___2 = 2252,
	SEL_MSIOF1_2_MARK___2 = 2253,
	SEL_MSIOF1_3_MARK___2 = 2254,
	SEL_MSIOF1_4_MARK___2 = 2255,
	SEL_MSIOF1_5_MARK___2 = 2256,
	SEL_MSIOF1_6_MARK___2 = 2257,
	SEL_TIMER_TMU_0_MARK___2 = 2258,
	SEL_TIMER_TMU_1_MARK___2 = 2259,
	SEL_SCIF5_0_MARK___2 = 2260,
	SEL_SCIF5_1_MARK___2 = 2261,
	SEL_SSP1_1_0_MARK___2 = 2262,
	SEL_SSP1_1_1_MARK___2 = 2263,
	SEL_SSP1_1_2_MARK___2 = 2264,
	SEL_SSP1_1_3_MARK___2 = 2265,
	SEL_I2C6_0_MARK___2 = 2266,
	SEL_I2C6_1_MARK___2 = 2267,
	SEL_I2C6_2_MARK___2 = 2268,
	SEL_LBSC_0_MARK___2 = 2269,
	SEL_LBSC_1_MARK___2 = 2270,
	SEL_SSP1_0_0_MARK___2 = 2271,
	SEL_SSP1_0_1_MARK___2 = 2272,
	SEL_SSP1_0_2_MARK___2 = 2273,
	SEL_SSP1_0_3_MARK___2 = 2274,
	SEL_SSP1_0_4_MARK___2 = 2275,
	SEL_IEBUS_0_MARK___2 = 2276,
	SEL_IEBUS_1_MARK___2 = 2277,
	SEL_NDF_0_MARK___2 = 2278,
	SEL_NDF_1_MARK___2 = 2279,
	SEL_I2C2_0_MARK___2 = 2280,
	SEL_I2C2_1_MARK___2 = 2281,
	SEL_SSI2_0_MARK___2 = 2282,
	SEL_SSI2_1_MARK___2 = 2283,
	SEL_I2C1_0_MARK___2 = 2284,
	SEL_I2C1_1_MARK___2 = 2285,
	SEL_SSI1_0_MARK___2 = 2286,
	SEL_SSI1_1_MARK___2 = 2287,
	SEL_SSI9_0_MARK___2 = 2288,
	SEL_SSI9_1_MARK___2 = 2289,
	SEL_HSCIF4_0_MARK___2 = 2290,
	SEL_HSCIF4_1_MARK___2 = 2291,
	SEL_SPEED_PULSE_0_MARK___2 = 2292,
	SEL_SPEED_PULSE_1_MARK___2 = 2293,
	SEL_TIMER_TMU2_0_MARK___2 = 2294,
	SEL_TIMER_TMU2_1_MARK___2 = 2295,
	SEL_HSCIF3_0_MARK___2 = 2296,
	SEL_HSCIF3_1_MARK___2 = 2297,
	SEL_HSCIF3_2_MARK___2 = 2298,
	SEL_HSCIF3_3_MARK___2 = 2299,
	SEL_SIMCARD_0_MARK___2 = 2300,
	SEL_SIMCARD_1_MARK___2 = 2301,
	SEL_SIMCARD_2_MARK___2 = 2302,
	SEL_SIMCARD_3_MARK___2 = 2303,
	SEL_ADGB_0_MARK___2 = 2304,
	SEL_ADGB_1_MARK___2 = 2305,
	SEL_ADGC_0_MARK___2 = 2306,
	SEL_ADGC_1_MARK___2 = 2307,
	SEL_HSCIF1_0_MARK___2 = 2308,
	SEL_HSCIF1_1_MARK___2 = 2309,
	SEL_SDHI2_0_MARK___2 = 2310,
	SEL_SDHI2_1_MARK___2 = 2311,
	SEL_SCIF4_0_MARK___2 = 2312,
	SEL_SCIF4_1_MARK___2 = 2313,
	SEL_SCIF4_2_MARK___2 = 2314,
	SEL_HSCIF2_0_MARK___2 = 2315,
	SEL_HSCIF2_1_MARK___2 = 2316,
	SEL_HSCIF2_2_MARK___2 = 2317,
	SEL_SCIF3_0_MARK___2 = 2318,
	SEL_SCIF3_1_MARK___2 = 2319,
	SEL_ETHERAVB_0_MARK___2 = 2320,
	SEL_ETHERAVB_1_MARK___2 = 2321,
	SEL_SCIF2_0_MARK___2 = 2322,
	SEL_SCIF2_1_MARK___2 = 2323,
	SEL_DRIF3_0_MARK___2 = 2324,
	SEL_DRIF3_1_MARK___2 = 2325,
	SEL_SCIF1_0_MARK___2 = 2326,
	SEL_SCIF1_1_MARK___2 = 2327,
	SEL_DRIF2_0_MARK___2 = 2328,
	SEL_DRIF2_1_MARK___2 = 2329,
	SEL_SCIF_0_MARK___2 = 2330,
	SEL_SCIF_1_MARK___2 = 2331,
	SEL_DRIF1_0_MARK___2 = 2332,
	SEL_DRIF1_1_MARK___2 = 2333,
	SEL_DRIF1_2_MARK___2 = 2334,
	SEL_REMOCON_0_MARK___2 = 2335,
	SEL_REMOCON_1_MARK___2 = 2336,
	SEL_DRIF0_0_MARK___2 = 2337,
	SEL_DRIF0_1_MARK___2 = 2338,
	SEL_DRIF0_2_MARK___2 = 2339,
	SEL_RCAN0_0_MARK___2 = 2340,
	SEL_RCAN0_1_MARK___2 = 2341,
	SEL_CANFD0_0_MARK___2 = 2342,
	SEL_CANFD0_1_MARK___2 = 2343,
	SEL_PWM6_0_MARK___2 = 2344,
	SEL_PWM6_1_MARK___2 = 2345,
	SEL_ADGA_0_MARK___2 = 2346,
	SEL_ADGA_1_MARK___2 = 2347,
	SEL_ADGA_2_MARK___2 = 2348,
	SEL_ADGA_3_MARK___2 = 2349,
	SEL_PWM5_0_MARK___2 = 2350,
	SEL_PWM5_1_MARK___2 = 2351,
	SEL_PWM4_0_MARK___2 = 2352,
	SEL_PWM4_1_MARK___2 = 2353,
	SEL_PWM3_0_MARK___2 = 2354,
	SEL_PWM3_1_MARK___2 = 2355,
	SEL_PWM2_0_MARK___2 = 2356,
	SEL_PWM2_1_MARK___2 = 2357,
	SEL_PWM1_0_MARK___2 = 2358,
	SEL_PWM1_1_MARK___2 = 2359,
	SEL_VIN4_0_MARK___2 = 2360,
	SEL_VIN4_1_MARK___2 = 2361,
	QSPI0_SPCLK_MARK___2 = 2362,
	QSPI0_SSL_MARK___2 = 2363,
	QSPI0_MOSI_IO0_MARK___2 = 2364,
	QSPI0_MISO_IO1_MARK___2 = 2365,
	QSPI0_IO2_MARK___2 = 2366,
	QSPI0_IO3_MARK___2 = 2367,
	QSPI1_SPCLK_MARK___2 = 2368,
	QSPI1_SSL_MARK___2 = 2369,
	QSPI1_MOSI_IO0_MARK___2 = 2370,
	QSPI1_MISO_IO1_MARK___2 = 2371,
	QSPI1_IO2_MARK___2 = 2372,
	QSPI1_IO3_MARK___2 = 2373,
	RPC_INT_MARK___2 = 2374,
	RPC_WP_MARK___2 = 2375,
	RPC_RESET_MARK___2 = 2376,
	AVB_TX_CTL_MARK___2 = 2377,
	AVB_TXC_MARK___2 = 2378,
	AVB_TD0_MARK___2 = 2379,
	AVB_TD1_MARK___2 = 2380,
	AVB_TD2_MARK___2 = 2381,
	AVB_TD3_MARK___2 = 2382,
	AVB_RX_CTL_MARK___2 = 2383,
	AVB_RXC_MARK___2 = 2384,
	AVB_RD0_MARK___2 = 2385,
	AVB_RD1_MARK___2 = 2386,
	AVB_RD2_MARK___2 = 2387,
	AVB_RD3_MARK___2 = 2388,
	AVB_TXCREFCLK_MARK___2 = 2389,
	AVB_MDIO_MARK___2 = 2390,
	PRESETOUT_MARK___2 = 2391,
	DU_DOTCLKIN0_MARK___2 = 2392,
	DU_DOTCLKIN1_MARK___2 = 2393,
	DU_DOTCLKIN3_MARK = 2394,
	TMS_MARK___2 = 2395,
	TDO_MARK___2 = 2396,
	ASEBRK_MARK___2 = 2397,
	MLB_REF_MARK___2 = 2398,
	TDI_MARK___2 = 2399,
	TCK_MARK___2 = 2400,
	TRST_MARK___2 = 2401,
	EXTALR_MARK___2 = 2402,
	SCL0_MARK___2 = 2403,
	SDA0_MARK___2 = 2404,
	SCL3_MARK___2 = 2405,
	SDA3_MARK___2 = 2406,
	SCL5_MARK___2 = 2407,
	SDA5_MARK___2 = 2408,
	PINMUX_MARK_END___2 = 2409,
};

enum {
	GP_LAST___2 = 227,
	PIN_ASEBRK___2 = 228,
	PIN_AVB_MDIO___2 = 229,
	PIN_AVB_RD0___2 = 230,
	PIN_AVB_RD1___2 = 231,
	PIN_AVB_RD2___2 = 232,
	PIN_AVB_RD3___2 = 233,
	PIN_AVB_RXC___2 = 234,
	PIN_AVB_RX_CTL___2 = 235,
	PIN_AVB_TD0___2 = 236,
	PIN_AVB_TD1___2 = 237,
	PIN_AVB_TD2___2 = 238,
	PIN_AVB_TD3___2 = 239,
	PIN_AVB_TXC___2 = 240,
	PIN_AVB_TXCREFCLK___2 = 241,
	PIN_AVB_TX_CTL___2 = 242,
	PIN_DU_DOTCLKIN0___2 = 243,
	PIN_DU_DOTCLKIN1___2 = 244,
	PIN_DU_DOTCLKIN3 = 245,
	PIN_EXTALR___2 = 246,
	PIN_FSCLKST___2 = 247,
	PIN_MLB_REF___2 = 248,
	PIN_PRESETOUT_N___2 = 249,
	PIN_QSPI0_IO2___2 = 250,
	PIN_QSPI0_IO3___2 = 251,
	PIN_QSPI0_MISO_IO1___2 = 252,
	PIN_QSPI0_MOSI_IO0___2 = 253,
	PIN_QSPI0_SPCLK___2 = 254,
	PIN_QSPI0_SSL___2 = 255,
	PIN_QSPI1_IO2___2 = 256,
	PIN_QSPI1_IO3___2 = 257,
	PIN_QSPI1_MISO_IO1___2 = 258,
	PIN_QSPI1_MOSI_IO0___2 = 259,
	PIN_QSPI1_SPCLK___2 = 260,
	PIN_QSPI1_SSL___2 = 261,
	PIN_RPC_INT_N___2 = 262,
	PIN_RPC_RESET_N___2 = 263,
	PIN_RPC_WP_N___2 = 264,
	PIN_TCK___2 = 265,
	PIN_TDI___2 = 266,
	PIN_TDO___2 = 267,
	PIN_TMS___2 = 268,
	PIN_TRST_N___2 = 269,
};

enum {
	PINMUX_RESERVED___3 = 0,
	PINMUX_DATA_BEGIN___3 = 1,
	GP_0_0_DATA___3 = 2,
	GP_0_1_DATA___3 = 3,
	GP_0_2_DATA___3 = 4,
	GP_0_3_DATA___3 = 5,
	GP_0_4_DATA___3 = 6,
	GP_0_5_DATA___3 = 7,
	GP_0_6_DATA___3 = 8,
	GP_0_7_DATA___3 = 9,
	GP_0_8_DATA___3 = 10,
	GP_0_9_DATA___3 = 11,
	GP_0_10_DATA___3 = 12,
	GP_0_11_DATA___3 = 13,
	GP_0_12_DATA___3 = 14,
	GP_0_13_DATA___3 = 15,
	GP_0_14_DATA___3 = 16,
	GP_0_15_DATA___3 = 17,
	GP_0_16_DATA = 18,
	GP_0_17_DATA = 19,
	GP_1_0_DATA___3 = 20,
	GP_1_1_DATA___3 = 21,
	GP_1_2_DATA___3 = 22,
	GP_1_3_DATA___3 = 23,
	GP_1_4_DATA___3 = 24,
	GP_1_5_DATA___3 = 25,
	GP_1_6_DATA___3 = 26,
	GP_1_7_DATA___3 = 27,
	GP_1_8_DATA___3 = 28,
	GP_1_9_DATA___3 = 29,
	GP_1_10_DATA___3 = 30,
	GP_1_11_DATA___3 = 31,
	GP_1_12_DATA___3 = 32,
	GP_1_13_DATA___3 = 33,
	GP_1_14_DATA___3 = 34,
	GP_1_15_DATA___3 = 35,
	GP_1_16_DATA___3 = 36,
	GP_1_17_DATA___3 = 37,
	GP_1_18_DATA___3 = 38,
	GP_1_19_DATA___3 = 39,
	GP_1_20_DATA___3 = 40,
	GP_1_21_DATA___3 = 41,
	GP_1_22_DATA___3 = 42,
	GP_2_0_DATA___3 = 43,
	GP_2_1_DATA___3 = 44,
	GP_2_2_DATA___3 = 45,
	GP_2_3_DATA___3 = 46,
	GP_2_4_DATA___3 = 47,
	GP_2_5_DATA___3 = 48,
	GP_2_6_DATA___3 = 49,
	GP_2_7_DATA___3 = 50,
	GP_2_8_DATA___3 = 51,
	GP_2_9_DATA___3 = 52,
	GP_2_10_DATA___3 = 53,
	GP_2_11_DATA___3 = 54,
	GP_2_12_DATA___3 = 55,
	GP_2_13_DATA___3 = 56,
	GP_2_14_DATA___3 = 57,
	GP_2_15_DATA = 58,
	GP_2_16_DATA = 59,
	GP_2_17_DATA = 60,
	GP_2_18_DATA = 61,
	GP_2_19_DATA = 62,
	GP_2_20_DATA = 63,
	GP_2_21_DATA = 64,
	GP_2_22_DATA = 65,
	GP_2_23_DATA = 66,
	GP_2_24_DATA = 67,
	GP_2_25_DATA = 68,
	GP_3_0_DATA___3 = 69,
	GP_3_1_DATA___3 = 70,
	GP_3_2_DATA___3 = 71,
	GP_3_3_DATA___3 = 72,
	GP_3_4_DATA___3 = 73,
	GP_3_5_DATA___3 = 74,
	GP_3_6_DATA___3 = 75,
	GP_3_7_DATA___3 = 76,
	GP_3_8_DATA___3 = 77,
	GP_3_9_DATA___3 = 78,
	GP_3_10_DATA___3 = 79,
	GP_3_11_DATA___3 = 80,
	GP_3_12_DATA___3 = 81,
	GP_3_13_DATA___3 = 82,
	GP_3_14_DATA___3 = 83,
	GP_3_15_DATA___3 = 84,
	GP_4_0_DATA___3 = 85,
	GP_4_1_DATA___3 = 86,
	GP_4_2_DATA___3 = 87,
	GP_4_3_DATA___3 = 88,
	GP_4_4_DATA___3 = 89,
	GP_4_5_DATA___3 = 90,
	GP_4_6_DATA___3 = 91,
	GP_4_7_DATA___3 = 92,
	GP_4_8_DATA___3 = 93,
	GP_4_9_DATA___3 = 94,
	GP_4_10_DATA___3 = 95,
	GP_5_0_DATA___3 = 96,
	GP_5_1_DATA___3 = 97,
	GP_5_2_DATA___3 = 98,
	GP_5_3_DATA___3 = 99,
	GP_5_4_DATA___3 = 100,
	GP_5_5_DATA___3 = 101,
	GP_5_6_DATA___3 = 102,
	GP_5_7_DATA___3 = 103,
	GP_5_8_DATA___3 = 104,
	GP_5_9_DATA___3 = 105,
	GP_5_10_DATA___3 = 106,
	GP_5_11_DATA___3 = 107,
	GP_5_12_DATA___3 = 108,
	GP_5_13_DATA___3 = 109,
	GP_5_14_DATA___3 = 110,
	GP_5_15_DATA___3 = 111,
	GP_5_16_DATA___3 = 112,
	GP_5_17_DATA___3 = 113,
	GP_5_18_DATA___3 = 114,
	GP_5_19_DATA___3 = 115,
	GP_6_0_DATA___3 = 116,
	GP_6_1_DATA___3 = 117,
	GP_6_2_DATA___3 = 118,
	GP_6_3_DATA___3 = 119,
	GP_6_4_DATA___3 = 120,
	GP_6_5_DATA___3 = 121,
	GP_6_6_DATA___3 = 122,
	GP_6_7_DATA___3 = 123,
	GP_6_8_DATA___3 = 124,
	GP_6_9_DATA___3 = 125,
	GP_6_10_DATA___3 = 126,
	GP_6_11_DATA___3 = 127,
	GP_6_12_DATA___3 = 128,
	GP_6_13_DATA___3 = 129,
	GP_6_14_DATA___3 = 130,
	GP_6_15_DATA___3 = 131,
	GP_6_16_DATA___3 = 132,
	GP_6_17_DATA___3 = 133,
	PINMUX_DATA_END___3 = 134,
	PINMUX_FUNCTION_BEGIN___3 = 135,
	GP_0_0_FN___3 = 136,
	GP_0_1_FN___3 = 137,
	GP_0_2_FN___3 = 138,
	GP_0_3_FN___3 = 139,
	GP_0_4_FN___3 = 140,
	GP_0_5_FN___3 = 141,
	GP_0_6_FN___3 = 142,
	GP_0_7_FN___3 = 143,
	GP_0_8_FN___3 = 144,
	GP_0_9_FN___3 = 145,
	GP_0_10_FN___3 = 146,
	GP_0_11_FN___3 = 147,
	GP_0_12_FN___3 = 148,
	GP_0_13_FN___3 = 149,
	GP_0_14_FN___3 = 150,
	GP_0_15_FN___3 = 151,
	GP_0_16_FN = 152,
	GP_0_17_FN = 153,
	GP_1_0_FN___3 = 154,
	GP_1_1_FN___3 = 155,
	GP_1_2_FN___3 = 156,
	GP_1_3_FN___3 = 157,
	GP_1_4_FN___3 = 158,
	GP_1_5_FN___3 = 159,
	GP_1_6_FN___3 = 160,
	GP_1_7_FN___3 = 161,
	GP_1_8_FN___3 = 162,
	GP_1_9_FN___3 = 163,
	GP_1_10_FN___3 = 164,
	GP_1_11_FN___3 = 165,
	GP_1_12_FN___3 = 166,
	GP_1_13_FN___3 = 167,
	GP_1_14_FN___3 = 168,
	GP_1_15_FN___3 = 169,
	GP_1_16_FN___3 = 170,
	GP_1_17_FN___3 = 171,
	GP_1_18_FN___3 = 172,
	GP_1_19_FN___3 = 173,
	GP_1_20_FN___3 = 174,
	GP_1_21_FN___3 = 175,
	GP_1_22_FN___3 = 176,
	GP_2_0_FN___3 = 177,
	GP_2_1_FN___3 = 178,
	GP_2_2_FN___3 = 179,
	GP_2_3_FN___3 = 180,
	GP_2_4_FN___3 = 181,
	GP_2_5_FN___3 = 182,
	GP_2_6_FN___3 = 183,
	GP_2_7_FN___3 = 184,
	GP_2_8_FN___3 = 185,
	GP_2_9_FN___3 = 186,
	GP_2_10_FN___3 = 187,
	GP_2_11_FN___3 = 188,
	GP_2_12_FN___3 = 189,
	GP_2_13_FN___3 = 190,
	GP_2_14_FN___3 = 191,
	GP_2_15_FN = 192,
	GP_2_16_FN = 193,
	GP_2_17_FN = 194,
	GP_2_18_FN = 195,
	GP_2_19_FN = 196,
	GP_2_20_FN = 197,
	GP_2_21_FN = 198,
	GP_2_22_FN = 199,
	GP_2_23_FN = 200,
	GP_2_24_FN = 201,
	GP_2_25_FN = 202,
	GP_3_0_FN___3 = 203,
	GP_3_1_FN___3 = 204,
	GP_3_2_FN___3 = 205,
	GP_3_3_FN___3 = 206,
	GP_3_4_FN___3 = 207,
	GP_3_5_FN___3 = 208,
	GP_3_6_FN___3 = 209,
	GP_3_7_FN___3 = 210,
	GP_3_8_FN___3 = 211,
	GP_3_9_FN___3 = 212,
	GP_3_10_FN___3 = 213,
	GP_3_11_FN___3 = 214,
	GP_3_12_FN___3 = 215,
	GP_3_13_FN___3 = 216,
	GP_3_14_FN___3 = 217,
	GP_3_15_FN___3 = 218,
	GP_4_0_FN___3 = 219,
	GP_4_1_FN___3 = 220,
	GP_4_2_FN___3 = 221,
	GP_4_3_FN___3 = 222,
	GP_4_4_FN___3 = 223,
	GP_4_5_FN___3 = 224,
	GP_4_6_FN___3 = 225,
	GP_4_7_FN___3 = 226,
	GP_4_8_FN___3 = 227,
	GP_4_9_FN___3 = 228,
	GP_4_10_FN___3 = 229,
	GP_5_0_FN___3 = 230,
	GP_5_1_FN___3 = 231,
	GP_5_2_FN___3 = 232,
	GP_5_3_FN___3 = 233,
	GP_5_4_FN___3 = 234,
	GP_5_5_FN___3 = 235,
	GP_5_6_FN___3 = 236,
	GP_5_7_FN___3 = 237,
	GP_5_8_FN___3 = 238,
	GP_5_9_FN___3 = 239,
	GP_5_10_FN___3 = 240,
	GP_5_11_FN___3 = 241,
	GP_5_12_FN___3 = 242,
	GP_5_13_FN___3 = 243,
	GP_5_14_FN___3 = 244,
	GP_5_15_FN___3 = 245,
	GP_5_16_FN___3 = 246,
	GP_5_17_FN___3 = 247,
	GP_5_18_FN___3 = 248,
	GP_5_19_FN___3 = 249,
	GP_6_0_FN___3 = 250,
	GP_6_1_FN___3 = 251,
	GP_6_2_FN___3 = 252,
	GP_6_3_FN___3 = 253,
	GP_6_4_FN___3 = 254,
	GP_6_5_FN___3 = 255,
	GP_6_6_FN___3 = 256,
	GP_6_7_FN___3 = 257,
	GP_6_8_FN___3 = 258,
	GP_6_9_FN___3 = 259,
	GP_6_10_FN___3 = 260,
	GP_6_11_FN___3 = 261,
	GP_6_12_FN___3 = 262,
	GP_6_13_FN___3 = 263,
	GP_6_14_FN___3 = 264,
	GP_6_15_FN___3 = 265,
	GP_6_16_FN___3 = 266,
	GP_6_17_FN___3 = 267,
	FN_AVB_PHY_INT___3 = 268,
	FN_CLKOUT___3 = 269,
	FN_AVB_RD3 = 270,
	FN_AVB_RXC = 271,
	FN_AVB_RX_CTL = 272,
	FN_QSPI0_SSL = 273,
	FN_IP0_3_0___3 = 274,
	FN_QSPI0_SPCLK = 275,
	FN_HSCK4_A = 276,
	FN_IP1_3_0___3 = 277,
	FN_QSPI1_IO2 = 278,
	FN_RIF2_D1_A___3 = 279,
	FN_HTX3_C___3 = 280,
	FN_VI4_DATA3_A___3 = 281,
	FN_IP2_3_0___3 = 282,
	FN_AVB_TXCREFCLK = 283,
	FN_IP3_3_0___3 = 284,
	FN_A1___3 = 285,
	FN_IRQ1___3 = 286,
	FN_PWM3_A___3 = 287,
	FN_DU_DOTCLKIN1 = 288,
	FN_VI5_DATA0_A = 289,
	FN_DU_DISP_CDE = 290,
	FN_SDA6_B___3 = 291,
	FN_IETX = 292,
	FN_QCPV_QDE___3 = 293,
	FN_IP0_7_4___3 = 294,
	FN_QSPI0_MOSI_IO0 = 295,
	FN_HCTS4_N_A = 296,
	FN_IP1_7_4___3 = 297,
	FN_QSPI1_IO3 = 298,
	FN_RIF3_CLK_A___3 = 299,
	FN_HRX3_C___3 = 300,
	FN_VI4_DATA4_A___3 = 301,
	FN_IP2_7_4___3 = 302,
	FN_AVB_MDIO = 303,
	FN_IP3_7_4___3 = 304,
	FN_A2___3 = 305,
	FN_IRQ2___3 = 306,
	FN_AVB_AVTP_PPS___3 = 307,
	FN_VI4_CLKENB___3 = 308,
	FN_VI5_DATA1_A = 309,
	FN_DU_DISP___3 = 310,
	FN_SCL6_B___3 = 311,
	FN_QSTVB_QVE___3 = 312,
	FN_IP0_11_8___3 = 313,
	FN_QSPI0_MISO_IO1 = 314,
	FN_HRTS4_N_A = 315,
	FN_IP1_11_8___3 = 316,
	FN_QSPI1_SSL = 317,
	FN_RIF3_SYNC_A___3 = 318,
	FN_HSCK3_C = 319,
	FN_VI4_DATA5_A___3 = 320,
	FN_IP2_11_8___3 = 321,
	FN_AVB_MDC___3 = 322,
	FN_IP3_11_8___3 = 323,
	FN_A3___3 = 324,
	FN_CTS4_N_A___3 = 325,
	FN_PWM4_A___3 = 326,
	FN_VI4_DATA12___3 = 327,
	FN_DU_DOTCLKOUT0___3 = 328,
	FN_HTX3_D___3 = 329,
	FN_IECLK = 330,
	FN_LCDOUT12___3 = 331,
	FN_IP0_15_12___3 = 332,
	FN_QSPI0_IO2 = 333,
	FN_HTX4_A___3 = 334,
	FN_IP1_15_12___3 = 335,
	FN_RPC_INT_N = 336,
	FN_RIF3_D0_A___3 = 337,
	FN_HCTS3_N_C = 338,
	FN_VI4_DATA6_A___3 = 339,
	FN_IP2_15_12___3 = 340,
	FN_BS_N___3 = 341,
	FN_PWM0_A = 342,
	FN_AVB_MAGIC___3 = 343,
	FN_VI4_CLK___3 = 344,
	FN_TX3_C = 345,
	FN_VI5_CLK_B = 346,
	FN_IP3_15_12___3 = 347,
	FN_A4___3 = 348,
	FN_RTS4_N_A___3 = 349,
	FN_MSIOF3_SYNC_B___3 = 350,
	FN_VI4_DATA8___3 = 351,
	FN_PWM2_B___3 = 352,
	FN_DU_DG4___3 = 353,
	FN_RIF2_CLK_B___3 = 354,
	FN_IP0_19_16___3 = 355,
	FN_QSPI0_IO3 = 356,
	FN_HRX4_A___3 = 357,
	FN_IP1_19_16___3 = 358,
	FN_RPC_RESET_N = 359,
	FN_RIF3_D1_A___3 = 360,
	FN_HRTS3_N_C = 361,
	FN_VI4_DATA7_A___3 = 362,
	FN_IP2_19_16___3 = 363,
	FN_RD_N___3 = 364,
	FN_PWM1_A___3 = 365,
	FN_AVB_LINK___3 = 366,
	FN_VI4_FIELD___3 = 367,
	FN_RX3_C = 368,
	FN_FSCLKST2_N_A___2 = 369,
	FN_VI5_DATA0_B = 370,
	FN_IP3_19_16___3 = 371,
	FN_A5___3 = 372,
	FN_SCK4_A___3 = 373,
	FN_MSIOF3_SCK_B___3 = 374,
	FN_VI4_DATA9___3 = 375,
	FN_PWM3_B___3 = 376,
	FN_RIF2_SYNC_B___3 = 377,
	FN_QPOLA___3 = 378,
	FN_IP0_23_20___3 = 379,
	FN_QSPI1_SPCLK = 380,
	FN_RIF2_CLK_A___3 = 381,
	FN_HSCK4_B = 382,
	FN_VI4_DATA0_A___3 = 383,
	FN_IP1_23_20___3 = 384,
	FN_AVB_RD0 = 385,
	FN_IP2_23_20___3 = 386,
	FN_RD_WR_N___3 = 387,
	FN_SCL7_A = 388,
	FN_AVB_AVTP_MATCH = 389,
	FN_VI4_VSYNC_N___3 = 390,
	FN_TX5_B___3 = 391,
	FN_SCK3_C = 392,
	FN_PWM5_A___3 = 393,
	FN_IP3_23_20___3 = 394,
	FN_A6___3 = 395,
	FN_RX4_A___3 = 396,
	FN_MSIOF3_RXD_B___3 = 397,
	FN_VI4_DATA10___3 = 398,
	FN_RIF2_D0_B___3 = 399,
	FN_IP0_27_24___3 = 400,
	FN_QSPI1_MOSI_IO0 = 401,
	FN_RIF2_SYNC_A___3 = 402,
	FN_HTX4_B___3 = 403,
	FN_VI4_DATA1_A___3 = 404,
	FN_IP1_27_24___3 = 405,
	FN_AVB_RD1 = 406,
	FN_IP2_27_24___3 = 407,
	FN_EX_WAIT0 = 408,
	FN_SDA7_A = 409,
	FN_AVB_AVTP_CAPTURE = 410,
	FN_VI4_HSYNC_N___3 = 411,
	FN_RX5_B___3 = 412,
	FN_PWM6_A___3 = 413,
	FN_IP3_27_24___3 = 414,
	FN_A7___3 = 415,
	FN_TX4_A___3 = 416,
	FN_MSIOF3_TXD_B___3 = 417,
	FN_VI4_DATA11___3 = 418,
	FN_RIF2_D1_B___3 = 419,
	FN_IP0_31_28___3 = 420,
	FN_QSPI1_MISO_IO1 = 421,
	FN_RIF2_D0_A___3 = 422,
	FN_HRX4_B___3 = 423,
	FN_VI4_DATA2_A___3 = 424,
	FN_IP1_31_28___3 = 425,
	FN_AVB_RD2 = 426,
	FN_IP2_31_28___3 = 427,
	FN_A0___3 = 428,
	FN_IRQ0___3 = 429,
	FN_PWM2_A___3 = 430,
	FN_MSIOF3_SS1_B___3 = 431,
	FN_VI5_CLK_A = 432,
	FN_DU_CDE___3 = 433,
	FN_HRX3_D___3 = 434,
	FN_IERX = 435,
	FN_QSTB_QHE___3 = 436,
	FN_IP3_31_28___3 = 437,
	FN_A8___3 = 438,
	FN_SDA6_A___3 = 439,
	FN_RX3_B___3 = 440,
	FN_HRX4_C = 441,
	FN_VI5_HSYNC_N_A = 442,
	FN_DU_HSYNC = 443,
	FN_VI4_DATA0_B___3 = 444,
	FN_QSTH_QHS___3 = 445,
	FN_IP4_3_0___3 = 446,
	FN_A9___3 = 447,
	FN_TX5_A___3 = 448,
	FN_IRQ3___3 = 449,
	FN_VI4_DATA16___3 = 450,
	FN_VI5_VSYNC_N_A = 451,
	FN_DU_DG7___3 = 452,
	FN_LCDOUT15___3 = 453,
	FN_IP5_3_0___3 = 454,
	FN_A17___3 = 455,
	FN_MSIOF1_RXD = 456,
	FN_VI4_DATA20___3 = 457,
	FN_VI5_DATA6_A = 458,
	FN_DU_DB6___3 = 459,
	FN_LCDOUT6___3 = 460,
	FN_IP6_3_0___3 = 461,
	FN_D3___3 = 462,
	FN_MSIOF3_TXD_A___3 = 463,
	FN_TX5_C = 464,
	FN_VI5_DATA15_A = 465,
	FN_DU_DR4___3 = 466,
	FN_TX4_C___3 = 467,
	FN_LCDOUT20___3 = 468,
	FN_IP7_3_0___3 = 469,
	FN_D11___3 = 470,
	FN_MSIOF2_TXD_A___3 = 471,
	FN_VI5_DATA11_A = 472,
	FN_DU_DG2___3 = 473,
	FN_RIF3_D1_B___3 = 474,
	FN_HRTS3_N_E = 475,
	FN_LCDOUT10___3 = 476,
	FN_IP4_7_4___3 = 477,
	FN_A10___3 = 478,
	FN_IRQ4___3 = 479,
	FN_MSIOF2_SYNC_B___3 = 480,
	FN_VI4_DATA13___3 = 481,
	FN_VI5_FIELD_A = 482,
	FN_DU_DG5___3 = 483,
	FN_FSCLKST2_N_B___2 = 484,
	FN_LCDOUT13___3 = 485,
	FN_IP5_7_4___3 = 486,
	FN_A18___3 = 487,
	FN_MSIOF1_TXD = 488,
	FN_VI4_DATA21___3 = 489,
	FN_VI5_DATA7_A = 490,
	FN_DU_DB0___3 = 491,
	FN_HRX4_E = 492,
	FN_LCDOUT0___3 = 493,
	FN_IP6_7_4___3 = 494,
	FN_D4___3 = 495,
	FN_CANFD1_TX___3 = 496,
	FN_HSCK3_B = 497,
	FN_CAN1_TX___3 = 498,
	FN_RTS3_N_A = 499,
	FN_MSIOF3_SS2_A___3 = 500,
	FN_VI5_DATA1_B = 501,
	FN_IP7_7_4___3 = 502,
	FN_D12___3 = 503,
	FN_CANFD0_TX = 504,
	FN_TX4_B___3 = 505,
	FN_CAN0_TX = 506,
	FN_VI5_DATA8_A = 507,
	FN_VI5_DATA3_B = 508,
	FN_IP4_11_8___3 = 509,
	FN_A11___3 = 510,
	FN_SCL6_A___3 = 511,
	FN_TX3_B___3 = 512,
	FN_HTX4_C = 513,
	FN_DU_VSYNC = 514,
	FN_VI4_DATA1_B___3 = 515,
	FN_QSTVA_QVS___3 = 516,
	FN_IP5_11_8___3 = 517,
	FN_A19___3 = 518,
	FN_MSIOF1_SCK = 519,
	FN_VI4_DATA22___3 = 520,
	FN_VI5_DATA2_A = 521,
	FN_DU_DB1___3 = 522,
	FN_HTX4_E = 523,
	FN_LCDOUT1___3 = 524,
	FN_IP6_11_8___3 = 525,
	FN_D5___3 = 526,
	FN_RX3_A___3 = 527,
	FN_HRX3_B___3 = 528,
	FN_DU_DR5___3 = 529,
	FN_VI4_DATA4_B___3 = 530,
	FN_LCDOUT21___3 = 531,
	FN_IP7_11_8___3 = 532,
	FN_D13___3 = 533,
	FN_CANFD0_RX = 534,
	FN_RX4_B___3 = 535,
	FN_CAN0_RX = 536,
	FN_VI5_DATA9_A = 537,
	FN_SCL7_B = 538,
	FN_VI5_DATA4_B = 539,
	FN_IP4_15_12___3 = 540,
	FN_A12___3 = 541,
	FN_RX5_A___3 = 542,
	FN_MSIOF2_SS2_B___3 = 543,
	FN_VI4_DATA17___3 = 544,
	FN_VI5_DATA3_A = 545,
	FN_DU_DG6___3 = 546,
	FN_LCDOUT14___3 = 547,
	FN_IP5_15_12___3 = 548,
	FN_CS0_N___3 = 549,
	FN_SCL5 = 550,
	FN_DU_DR0___3 = 551,
	FN_VI4_DATA2_B___3 = 552,
	FN_LCDOUT16___3 = 553,
	FN_IP6_15_12___3 = 554,
	FN_D6___3 = 555,
	FN_TX3_A___3 = 556,
	FN_HTX3_B___3 = 557,
	FN_DU_DR6___3 = 558,
	FN_VI4_DATA5_B___3 = 559,
	FN_LCDOUT22___3 = 560,
	FN_IP7_15_12 = 561,
	FN_D14___3 = 562,
	FN_CAN_CLK___3 = 563,
	FN_HRX3_A___3 = 564,
	FN_MSIOF2_SS2_A___3 = 565,
	FN_SDA7_B = 566,
	FN_VI5_DATA5_B = 567,
	FN_IP4_19_16___3 = 568,
	FN_A13___3 = 569,
	FN_SCK5_A___3 = 570,
	FN_MSIOF2_SCK_B___3 = 571,
	FN_VI4_DATA14___3 = 572,
	FN_HRX4_D = 573,
	FN_DU_DB2___3 = 574,
	FN_LCDOUT2___3 = 575,
	FN_IP5_19_16___3 = 576,
	FN_WE0_N___3 = 577,
	FN_SDA5 = 578,
	FN_DU_DR1___3 = 579,
	FN_VI4_DATA3_B___3 = 580,
	FN_LCDOUT17___3 = 581,
	FN_IP6_19_16___3 = 582,
	FN_D7___3 = 583,
	FN_CANFD1_RX___3 = 584,
	FN_IRQ5___3 = 585,
	FN_CAN1_RX___3 = 586,
	FN_CTS3_N_A = 587,
	FN_VI5_DATA2_B = 588,
	FN_IP7_19_16___3 = 589,
	FN_D15___3 = 590,
	FN_MSIOF2_SS1_A___3 = 591,
	FN_HTX3_A___3 = 592,
	FN_MSIOF3_SS1_A___3 = 593,
	FN_DU_DG3___3 = 594,
	FN_LCDOUT11___3 = 595,
	FN_IP4_23_20___3 = 596,
	FN_A14___3 = 597,
	FN_MSIOF1_SS1 = 598,
	FN_MSIOF2_RXD_B___3 = 599,
	FN_VI4_DATA15___3 = 600,
	FN_HTX4_D = 601,
	FN_DU_DB3___3 = 602,
	FN_LCDOUT3___3 = 603,
	FN_IP5_23_20___3 = 604,
	FN_D0___3 = 605,
	FN_MSIOF3_SCK_A___3 = 606,
	FN_DU_DR2___3 = 607,
	FN_CTS4_N_C___3 = 608,
	FN_LCDOUT18___3 = 609,
	FN_IP6_23_20___3 = 610,
	FN_D8___3 = 611,
	FN_MSIOF2_SCK_A___3 = 612,
	FN_SCK4_B___3 = 613,
	FN_VI5_DATA12_A = 614,
	FN_DU_DR7___3 = 615,
	FN_RIF3_CLK_B___3 = 616,
	FN_HCTS3_N_E = 617,
	FN_LCDOUT23___3 = 618,
	FN_IP7_23_20___3 = 619,
	FN_SCL4 = 620,
	FN_CS1_N_A26 = 621,
	FN_DU_DOTCLKIN0 = 622,
	FN_VI4_DATA6_B___3 = 623,
	FN_VI5_DATA6_B = 624,
	FN_QCLK___3 = 625,
	FN_IP4_27_24___3 = 626,
	FN_A15___3 = 627,
	FN_MSIOF1_SS2 = 628,
	FN_MSIOF2_TXD_B___3 = 629,
	FN_VI4_DATA18___3 = 630,
	FN_VI5_DATA4_A = 631,
	FN_DU_DB4___3 = 632,
	FN_LCDOUT4___3 = 633,
	FN_IP5_27_24___3 = 634,
	FN_D1___3 = 635,
	FN_MSIOF3_SYNC_A___3 = 636,
	FN_SCK3_A = 637,
	FN_VI4_DATA23___3 = 638,
	FN_VI5_CLKENB_A = 639,
	FN_DU_DB7___3 = 640,
	FN_RTS4_N_C___3 = 641,
	FN_LCDOUT7___3 = 642,
	FN_IP6_27_24___3 = 643,
	FN_D9___3 = 644,
	FN_MSIOF2_SYNC_A___3 = 645,
	FN_VI5_DATA10_A = 646,
	FN_DU_DG0___3 = 647,
	FN_RIF3_SYNC_B___3 = 648,
	FN_HRX3_E = 649,
	FN_LCDOUT8___3 = 650,
	FN_IP7_27_24___3 = 651,
	FN_SDA4 = 652,
	FN_WE1_N___3 = 653,
	FN_VI4_DATA7_B___3 = 654,
	FN_VI5_DATA7_B = 655,
	FN_QPOLB___3 = 656,
	FN_IP4_31_28___3 = 657,
	FN_A16___3 = 658,
	FN_MSIOF1_SYNC = 659,
	FN_MSIOF2_SS1_B___3 = 660,
	FN_VI4_DATA19___3 = 661,
	FN_VI5_DATA5_A = 662,
	FN_DU_DB5___3 = 663,
	FN_LCDOUT5___3 = 664,
	FN_IP5_31_28___3 = 665,
	FN_D2___3 = 666,
	FN_MSIOF3_RXD_A___3 = 667,
	FN_RX5_C = 668,
	FN_VI5_DATA14_A = 669,
	FN_DU_DR3___3 = 670,
	FN_RX4_C___3 = 671,
	FN_LCDOUT19___3 = 672,
	FN_IP6_31_28___3 = 673,
	FN_D10___3 = 674,
	FN_MSIOF2_RXD_A___3 = 675,
	FN_VI5_DATA13_A = 676,
	FN_DU_DG1___3 = 677,
	FN_RIF3_D0_B___3 = 678,
	FN_HTX3_E = 679,
	FN_LCDOUT9___3 = 680,
	FN_IP7_31_28___3 = 681,
	FN_SD0_CLK___3 = 682,
	FN_NFDATA8___3 = 683,
	FN_SCL1_C = 684,
	FN_HSCK1_B___3 = 685,
	FN_SDA2_E = 686,
	FN_FMCLK_B___3 = 687,
	FN_IP8_3_0___3 = 688,
	FN_SD0_CMD___3 = 689,
	FN_NFDATA9___3 = 690,
	FN_HRX1_B___3 = 691,
	FN_SPEEDIN_B___3 = 692,
	FN_IP9_3_0___3 = 693,
	FN_SD1_DAT1___3 = 694,
	FN_NFCE_N_B___3 = 695,
	FN_IP10_3_0___3 = 696,
	FN_SD3_DAT3___3 = 697,
	FN_NFDATA3___3 = 698,
	FN_IP11_3_0___3 = 699,
	FN_SD1_CD___3 = 700,
	FN_NFCE_N_A___3 = 701,
	FN_SSI_SCK1 = 702,
	FN_RIF0_D1_B___3 = 703,
	FN_TS_SDEN0 = 704,
	FN_IP8_7_4___3 = 705,
	FN_SD0_DAT0___3 = 706,
	FN_NFDATA10___3 = 707,
	FN_HTX1_B___3 = 708,
	FN_REMOCON_B___3 = 709,
	FN_IP9_7_4___3 = 710,
	FN_SD1_DAT2___3 = 711,
	FN_NFALE_B = 712,
	FN_IP10_7_4___3 = 713,
	FN_SD3_DAT4___3 = 714,
	FN_NFDATA4___3 = 715,
	FN_IP11_7_4___3 = 716,
	FN_SD1_WP___3 = 717,
	FN_NFWP_N_A___3 = 718,
	FN_SSI_WS1 = 719,
	FN_RIF0_SYNC_B___3 = 720,
	FN_TS_SPSYNC0 = 721,
	FN_IP8_11_8___3 = 722,
	FN_SD0_DAT1___3 = 723,
	FN_NFDATA11___3 = 724,
	FN_SDA2_C = 725,
	FN_HCTS1_N_B___3 = 726,
	FN_FMIN_B___3 = 727,
	FN_IP9_11_8___3 = 728,
	FN_SD1_DAT3___3 = 729,
	FN_NFRB_N_B___3 = 730,
	FN_IP10_11_8___3 = 731,
	FN_SD3_DAT5___3 = 732,
	FN_NFDATA5___3 = 733,
	FN_IP11_11_8___3 = 734,
	FN_RX0_A = 735,
	FN_HRX1_A___3 = 736,
	FN_SSI_SCK2_A___3 = 737,
	FN_RIF1_SYNC = 738,
	FN_TS_SCK1 = 739,
	FN_IP8_15_12___3 = 740,
	FN_SD0_DAT2___3 = 741,
	FN_NFDATA12___3 = 742,
	FN_SCL2_C = 743,
	FN_HRTS1_N_B___3 = 744,
	FN_BPFCLK_B___3 = 745,
	FN_IP9_15_12___3 = 746,
	FN_SD3_CLK___3 = 747,
	FN_NFWE_N___3 = 748,
	FN_IP10_15_12___3 = 749,
	FN_SD3_DAT6___3 = 750,
	FN_NFDATA6___3 = 751,
	FN_IP11_15_12___3 = 752,
	FN_TX0_A = 753,
	FN_HTX1_A___3 = 754,
	FN_SSI_WS2_A___3 = 755,
	FN_RIF1_D0 = 756,
	FN_TS_SDAT1 = 757,
	FN_IP8_19_16___3 = 758,
	FN_SD0_DAT3___3 = 759,
	FN_NFDATA13___3 = 760,
	FN_SDA1_C = 761,
	FN_SCL2_E = 762,
	FN_SPEEDIN_C = 763,
	FN_REMOCON_C = 764,
	FN_IP9_19_16___3 = 765,
	FN_SD3_CMD___3 = 766,
	FN_NFRE_N___3 = 767,
	FN_IP10_19_16___3 = 768,
	FN_SD3_DAT7___3 = 769,
	FN_NFDATA7___3 = 770,
	FN_IP11_19_16___3 = 771,
	FN_CTS0_N_A = 772,
	FN_NFDATA14_A___3 = 773,
	FN_AUDIO_CLKOUT_A___3 = 774,
	FN_RIF1_D1 = 775,
	FN_SCIF_CLK_A___3 = 776,
	FN_FMCLK_A___3 = 777,
	FN_IP8_23_20___3 = 778,
	FN_SD1_CLK___3 = 779,
	FN_NFDATA14_B___3 = 780,
	FN_IP9_23_20___3 = 781,
	FN_SD3_DAT0___3 = 782,
	FN_NFDATA0___3 = 783,
	FN_IP10_23_20___3 = 784,
	FN_SD3_DS___3 = 785,
	FN_NFCLE___3 = 786,
	FN_IP11_23_20___3 = 787,
	FN_RTS0_N_A = 788,
	FN_NFDATA15_A___3 = 789,
	FN_AUDIO_CLKOUT1_A___3 = 790,
	FN_RIF1_CLK = 791,
	FN_SCL2_A___3 = 792,
	FN_FMIN_A___3 = 793,
	FN_IP8_27_24___3 = 794,
	FN_SD1_CMD___3 = 795,
	FN_NFDATA15_B___3 = 796,
	FN_IP9_27_24___3 = 797,
	FN_SD3_DAT1___3 = 798,
	FN_NFDATA1___3 = 799,
	FN_IP10_27_24___3 = 800,
	FN_SD0_CD___3 = 801,
	FN_NFALE_A = 802,
	FN_SD3_CD___3 = 803,
	FN_RIF0_CLK_B___3 = 804,
	FN_SCL2_B___3 = 805,
	FN_TCLK1_A___3 = 806,
	FN_SSI_SCK2_B___3 = 807,
	FN_TS_SCK0 = 808,
	FN_IP11_27_24___3 = 809,
	FN_SCK0_A = 810,
	FN_HSCK1_A___3 = 811,
	FN_USB3HS0_ID = 812,
	FN_RTS1_N___3 = 813,
	FN_SDA2_A___3 = 814,
	FN_FMCLK_C___3 = 815,
	FN_USB0_ID = 816,
	FN_IP8_31_28___3 = 817,
	FN_SD1_DAT0___3 = 818,
	FN_NFWP_N_B___3 = 819,
	FN_IP9_31_28___3 = 820,
	FN_SD3_DAT2___3 = 821,
	FN_NFDATA2___3 = 822,
	FN_IP10_31_28___3 = 823,
	FN_SD0_WP___3 = 824,
	FN_NFRB_N_A___3 = 825,
	FN_SD3_WP___3 = 826,
	FN_RIF0_D0_B___3 = 827,
	FN_SDA2_B___3 = 828,
	FN_TCLK2_A___3 = 829,
	FN_SSI_WS2_B___3 = 830,
	FN_TS_SDAT0 = 831,
	FN_IP11_31_28___3 = 832,
	FN_RX1 = 833,
	FN_HRX2_B___3 = 834,
	FN_SSI_SCK9_B___3 = 835,
	FN_AUDIO_CLKOUT1_B___3 = 836,
	FN_IP12_3_0___3 = 837,
	FN_TX1 = 838,
	FN_HTX2_B___3 = 839,
	FN_SSI_WS9_B___3 = 840,
	FN_AUDIO_CLKOUT3_B___3 = 841,
	FN_IP13_3_0___3 = 842,
	FN_MSIOF0_SS1___3 = 843,
	FN_HRX2_A___3 = 844,
	FN_SSI_SCK4___3 = 845,
	FN_HCTS0_N_A = 846,
	FN_BPFCLK_C___3 = 847,
	FN_SPEEDIN_A___3 = 848,
	FN_IP14_3_0___3 = 849,
	FN_SSI_SDATA0___3 = 850,
	FN_IP15_3_0___3 = 851,
	FN_SSI_WS5___3 = 852,
	FN_HTX0_B = 853,
	FN_USB0_OVC_B = 854,
	FN_SDA2_D = 855,
	FN_IP12_7_4___3 = 856,
	FN_SCK2_A = 857,
	FN_HSCK0_A = 858,
	FN_AUDIO_CLKB_A___3 = 859,
	FN_CTS1_N___3 = 860,
	FN_RIF0_CLK_A___3 = 861,
	FN_REMOCON_A___3 = 862,
	FN_SCIF_CLK_B___3 = 863,
	FN_IP13_7_4___3 = 864,
	FN_MSIOF0_SS2___3 = 865,
	FN_HTX2_A___3 = 866,
	FN_SSI_WS4___3 = 867,
	FN_HRTS0_N_A = 868,
	FN_FMIN_C___3 = 869,
	FN_BPFCLK_A___3 = 870,
	FN_IP14_7_4___3 = 871,
	FN_SSI_SDATA1 = 872,
	FN_AUDIO_CLKC_B___3 = 873,
	FN_PWM0_B = 874,
	FN_IP15_7_4___3 = 875,
	FN_SSI_SDATA5___3 = 876,
	FN_HSCK0_B = 877,
	FN_AUDIO_CLKB_C = 878,
	FN_TPU0TO0___3 = 879,
	FN_IP12_11_8___3 = 880,
	FN_TX2_A___3 = 881,
	FN_HRX0_A = 882,
	FN_AUDIO_CLKOUT2_A___3 = 883,
	FN_SCL1_A___3 = 884,
	FN_FSO_CFE_0_N_A = 885,
	FN_TS_SDEN1 = 886,
	FN_IP13_11_8___3 = 887,
	FN_SSI_SDATA9 = 888,
	FN_AUDIO_CLKC_A___3 = 889,
	FN_SCK1___3 = 890,
	FN_IP14_11_8___3 = 891,
	FN_SSI_SDATA2 = 892,
	FN_AUDIO_CLKOUT2_B___3 = 893,
	FN_SSI_SCK9_A___3 = 894,
	FN_PWM1_B___3 = 895,
	FN_IP15_11_8___3 = 896,
	FN_SSI_SCK6___3 = 897,
	FN_HSCK2_A___3 = 898,
	FN_AUDIO_CLKC_C = 899,
	FN_TPU0TO1___3 = 900,
	FN_FSO_CFE_0_N_B = 901,
	FN_SIM0_RST_B___3 = 902,
	FN_IP12_15_12___3 = 903,
	FN_RX2_A___3 = 904,
	FN_HTX0_A = 905,
	FN_AUDIO_CLKOUT3_A___3 = 906,
	FN_SDA1_A___3 = 907,
	FN_FSO_CFE_1_N_A = 908,
	FN_TS_SPSYNC1 = 909,
	FN_IP13_15_12___3 = 910,
	FN_MLB_CLK___3 = 911,
	FN_RX0_B = 912,
	FN_RIF0_D0_A___3 = 913,
	FN_SCL1_B___3 = 914,
	FN_TCLK1_B___3 = 915,
	FN_SIM0_RST_A___3 = 916,
	FN_IP14_15_12___3 = 917,
	FN_SSI_SCK349___3 = 918,
	FN_PWM2_C = 919,
	FN_IP15_15_12___3 = 920,
	FN_SSI_WS6___3 = 921,
	FN_HCTS2_N_A___3 = 922,
	FN_AUDIO_CLKOUT2_C = 923,
	FN_TPU0TO2___3 = 924,
	FN_SDA1_D = 925,
	FN_FSO_CFE_1_N_B = 926,
	FN_SIM0_D_B___3 = 927,
	FN_IP12_19_16___3 = 928,
	FN_MSIOF0_SCK___3 = 929,
	FN_SSI_SCK78___3 = 930,
	FN_IP13_19_16___3 = 931,
	FN_MLB_SIG___3 = 932,
	FN_SCK0_B = 933,
	FN_RIF0_D1_A___3 = 934,
	FN_SDA1_B___3 = 935,
	FN_TCLK2_B___3 = 936,
	FN_SIM0_D_A___3 = 937,
	FN_IP14_19_16___3 = 938,
	FN_SSI_WS349___3 = 939,
	FN_PWM3_C = 940,
	FN_IP15_19_16___3 = 941,
	FN_SSI_SDATA6___3 = 942,
	FN_HRTS2_N_A___3 = 943,
	FN_AUDIO_CLKOUT3_C = 944,
	FN_TPU0TO3___3 = 945,
	FN_SCL1_D = 946,
	FN_FSO_TOE_N_B = 947,
	FN_SIM0_CLK_B___3 = 948,
	FN_IP12_23_20___3 = 949,
	FN_MSIOF0_RXD___3 = 950,
	FN_SSI_WS78___3 = 951,
	FN_TX2_B___3 = 952,
	FN_IP13_23_20___3 = 953,
	FN_MLB_DAT___3 = 954,
	FN_TX0_B = 955,
	FN_RIF0_SYNC_A___3 = 956,
	FN_SIM0_CLK_A___3 = 957,
	FN_IP14_23_20___3 = 958,
	FN_SSI_SDATA3___3 = 959,
	FN_AUDIO_CLKOUT1_C = 960,
	FN_AUDIO_CLKB_B___3 = 961,
	FN_PWM4_B___3 = 962,
	FN_IP15_23_20___3 = 963,
	FN_AUDIO_CLKA = 964,
	FN_IP12_27_24___3 = 965,
	FN_MSIOF0_TXD___3 = 966,
	FN_SSI_SDATA7___3 = 967,
	FN_RX2_B___3 = 968,
	FN_IP13_27_24___3 = 969,
	FN_SSI_SCK01239___3 = 970,
	FN_IP14_27_24___3 = 971,
	FN_SSI_SDATA4___3 = 972,
	FN_SSI_WS9_A___3 = 973,
	FN_PWM5_B___3 = 974,
	FN_IP15_27_24___3 = 975,
	FN_USB30_PWEN___3 = 976,
	FN_USB0_PWEN_A = 977,
	FN_IP12_31_28___3 = 978,
	FN_MSIOF0_SYNC___3 = 979,
	FN_AUDIO_CLKOUT_B___3 = 980,
	FN_SSI_SDATA8___3 = 981,
	FN_IP13_31_28___3 = 982,
	FN_SSI_WS01239___3 = 983,
	FN_IP14_31_28___3 = 984,
	FN_SSI_SCK5___3 = 985,
	FN_HRX0_B = 986,
	FN_USB0_PWEN_B = 987,
	FN_SCL2_D = 988,
	FN_PWM6_B___3 = 989,
	FN_IP15_31_28___3 = 990,
	FN_USB30_OVC___3 = 991,
	FN_USB0_OVC_A = 992,
	FN_FSO_TOE_N_A = 993,
	FN_SEL_SIMCARD_0___3 = 994,
	FN_SEL_SIMCARD_1___3 = 995,
	FN_SEL_ADGB_0___3 = 996,
	FN_SEL_ADGB_2 = 997,
	FN_SEL_ADGB_1___3 = 998,
	FN_SEL_SSI2_0___3 = 999,
	FN_SEL_SSI2_1___3 = 1000,
	FN_SEL_TIMER_TMU_0___3 = 1001,
	FN_SEL_TIMER_TMU_1___3 = 1002,
	FN_SEL_DRIF0_0___3 = 1003,
	FN_SEL_DRIF0_1___3 = 1004,
	FN_SEL_USB_20_CH0_0 = 1005,
	FN_SEL_USB_20_CH0_1 = 1006,
	FN_SEL_FM_0___3 = 1007,
	FN_SEL_FM_2___3 = 1008,
	FN_SEL_FM_1___3 = 1009,
	FN_SEL_DRIF2_0___3 = 1010,
	FN_SEL_DRIF2_1___3 = 1011,
	FN_SEL_FSO_0 = 1012,
	FN_SEL_FSO_1 = 1013,
	FN_SEL_DRIF3_0___3 = 1014,
	FN_SEL_DRIF3_1___3 = 1015,
	FN_SEL_HSCIF0_0 = 1016,
	FN_SEL_HSCIF0_1 = 1017,
	FN_SEL_HSCIF3_0___3 = 1018,
	FN_SEL_HSCIF3_4 = 1019,
	FN_SEL_HSCIF3_2___3 = 1020,
	FN_SEL_HSCIF3_1___3 = 1021,
	FN_SEL_HSCIF3_3___3 = 1022,
	FN_SEL_HSCIF1_0___3 = 1023,
	FN_SEL_HSCIF1_1___3 = 1024,
	FN_SEL_HSCIF2_0___3 = 1025,
	FN_SEL_HSCIF2_1___3 = 1026,
	FN_SEL_I2C1_0___3 = 1027,
	FN_SEL_I2C1_2 = 1028,
	FN_SEL_I2C1_1___3 = 1029,
	FN_SEL_I2C1_3 = 1030,
	FN_SEL_HSCIF4_0___3 = 1031,
	FN_SEL_HSCIF4_4 = 1032,
	FN_SEL_HSCIF4_2 = 1033,
	FN_SEL_HSCIF4_1___3 = 1034,
	FN_SEL_HSCIF4_3 = 1035,
	FN_SEL_I2C2_0___3 = 1036,
	FN_SEL_I2C2_4 = 1037,
	FN_SEL_I2C2_2 = 1038,
	FN_SEL_I2C2_1___3 = 1039,
	FN_SEL_I2C2_3 = 1040,
	FN_SEL_I2C6_0___3 = 1041,
	FN_SEL_I2C6_1___3 = 1042,
	FN_SEL_I2C7_0 = 1043,
	FN_SEL_I2C7_1 = 1044,
	FN_SEL_NDF_0___3 = 1045,
	FN_SEL_NDF_1___3 = 1046,
	FN_SEL_MSIOF2_0___3 = 1047,
	FN_SEL_MSIOF2_1___3 = 1048,
	FN_SEL_PWM0_0 = 1049,
	FN_SEL_PWM0_1 = 1050,
	FN_SEL_MSIOF3_0___3 = 1051,
	FN_SEL_MSIOF3_1___3 = 1052,
	FN_SEL_PWM1_0___3 = 1053,
	FN_SEL_PWM1_1___3 = 1054,
	FN_SEL_SCIF3_0___3 = 1055,
	FN_SEL_SCIF3_2 = 1056,
	FN_SEL_SCIF3_1___3 = 1057,
	FN_SEL_PWM2_0___3 = 1058,
	FN_SEL_PWM2_2 = 1059,
	FN_SEL_PWM2_1___3 = 1060,
	FN_SEL_SCIF4_0___3 = 1061,
	FN_SEL_SCIF4_2___3 = 1062,
	FN_SEL_SCIF4_1___3 = 1063,
	FN_SEL_PWM3_0___3 = 1064,
	FN_SEL_PWM3_2 = 1065,
	FN_SEL_PWM3_1___3 = 1066,
	FN_SEL_SCIF5_0___3 = 1067,
	FN_SEL_SCIF5_2 = 1068,
	FN_SEL_SCIF5_1___3 = 1069,
	FN_SEL_PWM4_0___3 = 1070,
	FN_SEL_PWM4_1___3 = 1071,
	FN_SEL_PWM5_0___3 = 1072,
	FN_SEL_PWM5_1___3 = 1073,
	FN_SEL_VIN4_0___3 = 1074,
	FN_SEL_VIN4_1___3 = 1075,
	FN_SEL_PWM6_0___3 = 1076,
	FN_SEL_PWM6_1___3 = 1077,
	FN_SEL_VIN5_0 = 1078,
	FN_SEL_VIN5_1 = 1079,
	FN_SEL_REMOCON_0___3 = 1080,
	FN_SEL_REMOCON_2 = 1081,
	FN_SEL_REMOCON_1___3 = 1082,
	FN_SEL_ADGC_0___3 = 1083,
	FN_SEL_ADGC_2 = 1084,
	FN_SEL_ADGC_1___3 = 1085,
	FN_SEL_SCIF_0___3 = 1086,
	FN_SEL_SCIF_1___3 = 1087,
	FN_SEL_SSI9_0___3 = 1088,
	FN_SEL_SSI9_1___3 = 1089,
	FN_SEL_SCIF0_0 = 1090,
	FN_SEL_SCIF0_1 = 1091,
	FN_SEL_SCIF2_0___3 = 1092,
	FN_SEL_SCIF2_1___3 = 1093,
	FN_SEL_SPEED_PULSE_IF_0 = 1094,
	FN_SEL_SPEED_PULSE_IF_2 = 1095,
	FN_SEL_SPEED_PULSE_IF_1 = 1096,
	PINMUX_FUNCTION_END___3 = 1097,
	PINMUX_MARK_BEGIN___3 = 1098,
	AVB_PHY_INT_MARK___3 = 1099,
	CLKOUT_MARK___3 = 1100,
	AVB_RD3_MARK___3 = 1101,
	AVB_RXC_MARK___3 = 1102,
	AVB_RX_CTL_MARK___3 = 1103,
	QSPI0_SSL_MARK___3 = 1104,
	IP0_3_0_MARK___3 = 1105,
	QSPI0_SPCLK_MARK___3 = 1106,
	HSCK4_A_MARK = 1107,
	IP1_3_0_MARK___3 = 1108,
	QSPI1_IO2_MARK___3 = 1109,
	RIF2_D1_A_MARK___3 = 1110,
	HTX3_C_MARK___3 = 1111,
	VI4_DATA3_A_MARK___3 = 1112,
	IP2_3_0_MARK___3 = 1113,
	AVB_TXCREFCLK_MARK___3 = 1114,
	IP3_3_0_MARK___3 = 1115,
	A1_MARK___3 = 1116,
	IRQ1_MARK___3 = 1117,
	PWM3_A_MARK___3 = 1118,
	DU_DOTCLKIN1_MARK___3 = 1119,
	VI5_DATA0_A_MARK = 1120,
	DU_DISP_CDE_MARK = 1121,
	SDA6_B_MARK___3 = 1122,
	IETX_MARK = 1123,
	QCPV_QDE_MARK___3 = 1124,
	IP0_7_4_MARK___3 = 1125,
	QSPI0_MOSI_IO0_MARK___3 = 1126,
	HCTS4_N_A_MARK = 1127,
	IP1_7_4_MARK___3 = 1128,
	QSPI1_IO3_MARK___3 = 1129,
	RIF3_CLK_A_MARK___3 = 1130,
	HRX3_C_MARK___3 = 1131,
	VI4_DATA4_A_MARK___3 = 1132,
	IP2_7_4_MARK___3 = 1133,
	AVB_MDIO_MARK___3 = 1134,
	IP3_7_4_MARK___3 = 1135,
	A2_MARK___3 = 1136,
	IRQ2_MARK___3 = 1137,
	AVB_AVTP_PPS_MARK___3 = 1138,
	VI4_CLKENB_MARK___3 = 1139,
	VI5_DATA1_A_MARK = 1140,
	DU_DISP_MARK___3 = 1141,
	SCL6_B_MARK___3 = 1142,
	QSTVB_QVE_MARK___3 = 1143,
	IP0_11_8_MARK___3 = 1144,
	QSPI0_MISO_IO1_MARK___3 = 1145,
	HRTS4_N_A_MARK = 1146,
	IP1_11_8_MARK___3 = 1147,
	QSPI1_SSL_MARK___3 = 1148,
	RIF3_SYNC_A_MARK___3 = 1149,
	HSCK3_C_MARK = 1150,
	VI4_DATA5_A_MARK___3 = 1151,
	IP2_11_8_MARK___3 = 1152,
	AVB_MDC_MARK___3 = 1153,
	IP3_11_8_MARK___3 = 1154,
	A3_MARK___3 = 1155,
	CTS4_N_A_MARK___3 = 1156,
	PWM4_A_MARK___3 = 1157,
	VI4_DATA12_MARK___3 = 1158,
	DU_DOTCLKOUT0_MARK___3 = 1159,
	HTX3_D_MARK___3 = 1160,
	IECLK_MARK = 1161,
	LCDOUT12_MARK___3 = 1162,
	IP0_15_12_MARK___3 = 1163,
	QSPI0_IO2_MARK___3 = 1164,
	HTX4_A_MARK___3 = 1165,
	IP1_15_12_MARK___3 = 1166,
	RPC_INT_N_MARK = 1167,
	RIF3_D0_A_MARK___3 = 1168,
	HCTS3_N_C_MARK = 1169,
	VI4_DATA6_A_MARK___3 = 1170,
	IP2_15_12_MARK___3 = 1171,
	BS_N_MARK___3 = 1172,
	PWM0_A_MARK = 1173,
	AVB_MAGIC_MARK___3 = 1174,
	VI4_CLK_MARK___3 = 1175,
	TX3_C_MARK = 1176,
	VI5_CLK_B_MARK = 1177,
	IP3_15_12_MARK___3 = 1178,
	A4_MARK___3 = 1179,
	RTS4_N_A_MARK___3 = 1180,
	MSIOF3_SYNC_B_MARK___3 = 1181,
	VI4_DATA8_MARK___3 = 1182,
	PWM2_B_MARK___3 = 1183,
	DU_DG4_MARK___3 = 1184,
	RIF2_CLK_B_MARK___3 = 1185,
	IP0_19_16_MARK___3 = 1186,
	QSPI0_IO3_MARK___3 = 1187,
	HRX4_A_MARK___3 = 1188,
	IP1_19_16_MARK___3 = 1189,
	RPC_RESET_N_MARK = 1190,
	RIF3_D1_A_MARK___3 = 1191,
	HRTS3_N_C_MARK = 1192,
	VI4_DATA7_A_MARK___3 = 1193,
	IP2_19_16_MARK___3 = 1194,
	RD_N_MARK___3 = 1195,
	PWM1_A_MARK___3 = 1196,
	AVB_LINK_MARK___3 = 1197,
	VI4_FIELD_MARK___3 = 1198,
	RX3_C_MARK = 1199,
	FSCLKST2_N_A_MARK___2 = 1200,
	VI5_DATA0_B_MARK = 1201,
	IP3_19_16_MARK___3 = 1202,
	A5_MARK___3 = 1203,
	SCK4_A_MARK___3 = 1204,
	MSIOF3_SCK_B_MARK___3 = 1205,
	VI4_DATA9_MARK___3 = 1206,
	PWM3_B_MARK___3 = 1207,
	RIF2_SYNC_B_MARK___3 = 1208,
	QPOLA_MARK___3 = 1209,
	IP0_23_20_MARK___3 = 1210,
	QSPI1_SPCLK_MARK___3 = 1211,
	RIF2_CLK_A_MARK___3 = 1212,
	HSCK4_B_MARK = 1213,
	VI4_DATA0_A_MARK___3 = 1214,
	IP1_23_20_MARK___3 = 1215,
	AVB_RD0_MARK___3 = 1216,
	IP2_23_20_MARK___3 = 1217,
	RD_WR_N_MARK___3 = 1218,
	SCL7_A_MARK = 1219,
	AVB_AVTP_MATCH_MARK = 1220,
	VI4_VSYNC_N_MARK___3 = 1221,
	TX5_B_MARK___3 = 1222,
	SCK3_C_MARK = 1223,
	PWM5_A_MARK___3 = 1224,
	IP3_23_20_MARK___3 = 1225,
	A6_MARK___3 = 1226,
	RX4_A_MARK___3 = 1227,
	MSIOF3_RXD_B_MARK___3 = 1228,
	VI4_DATA10_MARK___3 = 1229,
	RIF2_D0_B_MARK___3 = 1230,
	IP0_27_24_MARK___3 = 1231,
	QSPI1_MOSI_IO0_MARK___3 = 1232,
	RIF2_SYNC_A_MARK___3 = 1233,
	HTX4_B_MARK___3 = 1234,
	VI4_DATA1_A_MARK___3 = 1235,
	IP1_27_24_MARK___3 = 1236,
	AVB_RD1_MARK___3 = 1237,
	IP2_27_24_MARK___3 = 1238,
	EX_WAIT0_MARK = 1239,
	SDA7_A_MARK = 1240,
	AVB_AVTP_CAPTURE_MARK = 1241,
	VI4_HSYNC_N_MARK___3 = 1242,
	RX5_B_MARK___3 = 1243,
	PWM6_A_MARK___3 = 1244,
	IP3_27_24_MARK___3 = 1245,
	A7_MARK___3 = 1246,
	TX4_A_MARK___3 = 1247,
	MSIOF3_TXD_B_MARK___3 = 1248,
	VI4_DATA11_MARK___3 = 1249,
	RIF2_D1_B_MARK___3 = 1250,
	IP0_31_28_MARK___3 = 1251,
	QSPI1_MISO_IO1_MARK___3 = 1252,
	RIF2_D0_A_MARK___3 = 1253,
	HRX4_B_MARK___3 = 1254,
	VI4_DATA2_A_MARK___3 = 1255,
	IP1_31_28_MARK___3 = 1256,
	AVB_RD2_MARK___3 = 1257,
	IP2_31_28_MARK___3 = 1258,
	A0_MARK___3 = 1259,
	IRQ0_MARK___3 = 1260,
	PWM2_A_MARK___3 = 1261,
	MSIOF3_SS1_B_MARK___3 = 1262,
	VI5_CLK_A_MARK = 1263,
	DU_CDE_MARK___3 = 1264,
	HRX3_D_MARK___3 = 1265,
	IERX_MARK = 1266,
	QSTB_QHE_MARK___3 = 1267,
	IP3_31_28_MARK___3 = 1268,
	A8_MARK___3 = 1269,
	SDA6_A_MARK___3 = 1270,
	RX3_B_MARK___3 = 1271,
	HRX4_C_MARK = 1272,
	VI5_HSYNC_N_A_MARK = 1273,
	DU_HSYNC_MARK = 1274,
	VI4_DATA0_B_MARK___3 = 1275,
	QSTH_QHS_MARK___3 = 1276,
	IP4_3_0_MARK___3 = 1277,
	A9_MARK___3 = 1278,
	TX5_A_MARK___3 = 1279,
	IRQ3_MARK___3 = 1280,
	VI4_DATA16_MARK___3 = 1281,
	VI5_VSYNC_N_A_MARK = 1282,
	DU_DG7_MARK___3 = 1283,
	LCDOUT15_MARK___3 = 1284,
	IP5_3_0_MARK___3 = 1285,
	A17_MARK___3 = 1286,
	MSIOF1_RXD_MARK = 1287,
	VI4_DATA20_MARK___3 = 1288,
	VI5_DATA6_A_MARK = 1289,
	DU_DB6_MARK___3 = 1290,
	LCDOUT6_MARK___3 = 1291,
	IP6_3_0_MARK___3 = 1292,
	D3_MARK___3 = 1293,
	MSIOF3_TXD_A_MARK___3 = 1294,
	TX5_C_MARK = 1295,
	VI5_DATA15_A_MARK = 1296,
	DU_DR4_MARK___3 = 1297,
	TX4_C_MARK___3 = 1298,
	LCDOUT20_MARK___3 = 1299,
	IP7_3_0_MARK___3 = 1300,
	D11_MARK___3 = 1301,
	MSIOF2_TXD_A_MARK___3 = 1302,
	VI5_DATA11_A_MARK = 1303,
	DU_DG2_MARK___3 = 1304,
	RIF3_D1_B_MARK___3 = 1305,
	HRTS3_N_E_MARK = 1306,
	LCDOUT10_MARK___3 = 1307,
	IP4_7_4_MARK___3 = 1308,
	A10_MARK___3 = 1309,
	IRQ4_MARK___3 = 1310,
	MSIOF2_SYNC_B_MARK___3 = 1311,
	VI4_DATA13_MARK___3 = 1312,
	VI5_FIELD_A_MARK = 1313,
	DU_DG5_MARK___3 = 1314,
	FSCLKST2_N_B_MARK___2 = 1315,
	LCDOUT13_MARK___3 = 1316,
	IP5_7_4_MARK___3 = 1317,
	A18_MARK___3 = 1318,
	MSIOF1_TXD_MARK = 1319,
	VI4_DATA21_MARK___3 = 1320,
	VI5_DATA7_A_MARK = 1321,
	DU_DB0_MARK___3 = 1322,
	HRX4_E_MARK = 1323,
	LCDOUT0_MARK___3 = 1324,
	IP6_7_4_MARK___3 = 1325,
	D4_MARK___3 = 1326,
	CANFD1_TX_MARK___3 = 1327,
	HSCK3_B_MARK = 1328,
	CAN1_TX_MARK___3 = 1329,
	RTS3_N_A_MARK = 1330,
	MSIOF3_SS2_A_MARK___3 = 1331,
	VI5_DATA1_B_MARK = 1332,
	IP7_7_4_MARK___3 = 1333,
	D12_MARK___3 = 1334,
	CANFD0_TX_MARK = 1335,
	TX4_B_MARK___3 = 1336,
	CAN0_TX_MARK = 1337,
	VI5_DATA8_A_MARK = 1338,
	VI5_DATA3_B_MARK = 1339,
	IP4_11_8_MARK___3 = 1340,
	A11_MARK___3 = 1341,
	SCL6_A_MARK___3 = 1342,
	TX3_B_MARK___3 = 1343,
	HTX4_C_MARK = 1344,
	DU_VSYNC_MARK = 1345,
	VI4_DATA1_B_MARK___3 = 1346,
	QSTVA_QVS_MARK___3 = 1347,
	IP5_11_8_MARK___3 = 1348,
	A19_MARK___3 = 1349,
	MSIOF1_SCK_MARK = 1350,
	VI4_DATA22_MARK___3 = 1351,
	VI5_DATA2_A_MARK = 1352,
	DU_DB1_MARK___3 = 1353,
	HTX4_E_MARK = 1354,
	LCDOUT1_MARK___3 = 1355,
	IP6_11_8_MARK___3 = 1356,
	D5_MARK___3 = 1357,
	RX3_A_MARK___3 = 1358,
	HRX3_B_MARK___3 = 1359,
	DU_DR5_MARK___3 = 1360,
	VI4_DATA4_B_MARK___3 = 1361,
	LCDOUT21_MARK___3 = 1362,
	IP7_11_8_MARK___3 = 1363,
	D13_MARK___3 = 1364,
	CANFD0_RX_MARK = 1365,
	RX4_B_MARK___3 = 1366,
	CAN0_RX_MARK = 1367,
	VI5_DATA9_A_MARK = 1368,
	SCL7_B_MARK = 1369,
	VI5_DATA4_B_MARK = 1370,
	IP4_15_12_MARK___3 = 1371,
	A12_MARK___3 = 1372,
	RX5_A_MARK___3 = 1373,
	MSIOF2_SS2_B_MARK___3 = 1374,
	VI4_DATA17_MARK___3 = 1375,
	VI5_DATA3_A_MARK = 1376,
	DU_DG6_MARK___3 = 1377,
	LCDOUT14_MARK___3 = 1378,
	IP5_15_12_MARK___3 = 1379,
	CS0_N_MARK___3 = 1380,
	SCL5_MARK___3 = 1381,
	DU_DR0_MARK___3 = 1382,
	VI4_DATA2_B_MARK___3 = 1383,
	LCDOUT16_MARK___3 = 1384,
	IP6_15_12_MARK___3 = 1385,
	D6_MARK___3 = 1386,
	TX3_A_MARK___3 = 1387,
	HTX3_B_MARK___3 = 1388,
	DU_DR6_MARK___3 = 1389,
	VI4_DATA5_B_MARK___3 = 1390,
	LCDOUT22_MARK___3 = 1391,
	IP7_15_12_MARK = 1392,
	D14_MARK___3 = 1393,
	CAN_CLK_MARK___3 = 1394,
	HRX3_A_MARK___3 = 1395,
	MSIOF2_SS2_A_MARK___3 = 1396,
	SDA7_B_MARK = 1397,
	VI5_DATA5_B_MARK = 1398,
	IP4_19_16_MARK___3 = 1399,
	A13_MARK___3 = 1400,
	SCK5_A_MARK___3 = 1401,
	MSIOF2_SCK_B_MARK___3 = 1402,
	VI4_DATA14_MARK___3 = 1403,
	HRX4_D_MARK = 1404,
	DU_DB2_MARK___3 = 1405,
	LCDOUT2_MARK___3 = 1406,
	IP5_19_16_MARK___3 = 1407,
	WE0_N_MARK___3 = 1408,
	SDA5_MARK___3 = 1409,
	DU_DR1_MARK___3 = 1410,
	VI4_DATA3_B_MARK___3 = 1411,
	LCDOUT17_MARK___3 = 1412,
	IP6_19_16_MARK___3 = 1413,
	D7_MARK___3 = 1414,
	CANFD1_RX_MARK___3 = 1415,
	IRQ5_MARK___3 = 1416,
	CAN1_RX_MARK___3 = 1417,
	CTS3_N_A_MARK = 1418,
	VI5_DATA2_B_MARK = 1419,
	IP7_19_16_MARK___3 = 1420,
	D15_MARK___3 = 1421,
	MSIOF2_SS1_A_MARK___3 = 1422,
	HTX3_A_MARK___3 = 1423,
	MSIOF3_SS1_A_MARK___3 = 1424,
	DU_DG3_MARK___3 = 1425,
	LCDOUT11_MARK___3 = 1426,
	IP4_23_20_MARK___3 = 1427,
	A14_MARK___3 = 1428,
	MSIOF1_SS1_MARK = 1429,
	MSIOF2_RXD_B_MARK___3 = 1430,
	VI4_DATA15_MARK___3 = 1431,
	HTX4_D_MARK = 1432,
	DU_DB3_MARK___3 = 1433,
	LCDOUT3_MARK___3 = 1434,
	IP5_23_20_MARK___3 = 1435,
	D0_MARK___3 = 1436,
	MSIOF3_SCK_A_MARK___3 = 1437,
	DU_DR2_MARK___3 = 1438,
	CTS4_N_C_MARK___3 = 1439,
	LCDOUT18_MARK___3 = 1440,
	IP6_23_20_MARK___3 = 1441,
	D8_MARK___3 = 1442,
	MSIOF2_SCK_A_MARK___3 = 1443,
	SCK4_B_MARK___3 = 1444,
	VI5_DATA12_A_MARK = 1445,
	DU_DR7_MARK___3 = 1446,
	RIF3_CLK_B_MARK___3 = 1447,
	HCTS3_N_E_MARK = 1448,
	LCDOUT23_MARK___3 = 1449,
	IP7_23_20_MARK___3 = 1450,
	SCL4_MARK = 1451,
	CS1_N_A26_MARK = 1452,
	DU_DOTCLKIN0_MARK___3 = 1453,
	VI4_DATA6_B_MARK___3 = 1454,
	VI5_DATA6_B_MARK = 1455,
	QCLK_MARK___3 = 1456,
	IP4_27_24_MARK___3 = 1457,
	A15_MARK___3 = 1458,
	MSIOF1_SS2_MARK = 1459,
	MSIOF2_TXD_B_MARK___3 = 1460,
	VI4_DATA18_MARK___3 = 1461,
	VI5_DATA4_A_MARK = 1462,
	DU_DB4_MARK___3 = 1463,
	LCDOUT4_MARK___3 = 1464,
	IP5_27_24_MARK___3 = 1465,
	D1_MARK___3 = 1466,
	MSIOF3_SYNC_A_MARK___3 = 1467,
	SCK3_A_MARK = 1468,
	VI4_DATA23_MARK___3 = 1469,
	VI5_CLKENB_A_MARK = 1470,
	DU_DB7_MARK___3 = 1471,
	RTS4_N_C_MARK___3 = 1472,
	LCDOUT7_MARK___3 = 1473,
	IP6_27_24_MARK___3 = 1474,
	D9_MARK___3 = 1475,
	MSIOF2_SYNC_A_MARK___3 = 1476,
	VI5_DATA10_A_MARK = 1477,
	DU_DG0_MARK___3 = 1478,
	RIF3_SYNC_B_MARK___3 = 1479,
	HRX3_E_MARK = 1480,
	LCDOUT8_MARK___3 = 1481,
	IP7_27_24_MARK___3 = 1482,
	SDA4_MARK = 1483,
	WE1_N_MARK___3 = 1484,
	VI4_DATA7_B_MARK___3 = 1485,
	VI5_DATA7_B_MARK = 1486,
	QPOLB_MARK___3 = 1487,
	IP4_31_28_MARK___3 = 1488,
	A16_MARK___3 = 1489,
	MSIOF1_SYNC_MARK = 1490,
	MSIOF2_SS1_B_MARK___3 = 1491,
	VI4_DATA19_MARK___3 = 1492,
	VI5_DATA5_A_MARK = 1493,
	DU_DB5_MARK___3 = 1494,
	LCDOUT5_MARK___3 = 1495,
	IP5_31_28_MARK___3 = 1496,
	D2_MARK___3 = 1497,
	MSIOF3_RXD_A_MARK___3 = 1498,
	RX5_C_MARK = 1499,
	VI5_DATA14_A_MARK = 1500,
	DU_DR3_MARK___3 = 1501,
	RX4_C_MARK___3 = 1502,
	LCDOUT19_MARK___3 = 1503,
	IP6_31_28_MARK___3 = 1504,
	D10_MARK___3 = 1505,
	MSIOF2_RXD_A_MARK___3 = 1506,
	VI5_DATA13_A_MARK = 1507,
	DU_DG1_MARK___3 = 1508,
	RIF3_D0_B_MARK___3 = 1509,
	HTX3_E_MARK = 1510,
	LCDOUT9_MARK___3 = 1511,
	IP7_31_28_MARK___3 = 1512,
	SD0_CLK_MARK___3 = 1513,
	NFDATA8_MARK___3 = 1514,
	SCL1_C_MARK = 1515,
	HSCK1_B_MARK___3 = 1516,
	SDA2_E_MARK = 1517,
	FMCLK_B_MARK___3 = 1518,
	IP8_3_0_MARK___3 = 1519,
	SD0_CMD_MARK___3 = 1520,
	NFDATA9_MARK___3 = 1521,
	HRX1_B_MARK___3 = 1522,
	SPEEDIN_B_MARK___3 = 1523,
	IP9_3_0_MARK___3 = 1524,
	SD1_DAT1_MARK___3 = 1525,
	NFCE_N_B_MARK___3 = 1526,
	IP10_3_0_MARK___3 = 1527,
	SD3_DAT3_MARK___3 = 1528,
	NFDATA3_MARK___3 = 1529,
	IP11_3_0_MARK___3 = 1530,
	SD1_CD_MARK___3 = 1531,
	NFCE_N_A_MARK___3 = 1532,
	SSI_SCK1_MARK = 1533,
	RIF0_D1_B_MARK___3 = 1534,
	TS_SDEN0_MARK = 1535,
	IP8_7_4_MARK___3 = 1536,
	SD0_DAT0_MARK___3 = 1537,
	NFDATA10_MARK___3 = 1538,
	HTX1_B_MARK___3 = 1539,
	REMOCON_B_MARK___3 = 1540,
	IP9_7_4_MARK___3 = 1541,
	SD1_DAT2_MARK___3 = 1542,
	NFALE_B_MARK = 1543,
	IP10_7_4_MARK___3 = 1544,
	SD3_DAT4_MARK___3 = 1545,
	NFDATA4_MARK___3 = 1546,
	IP11_7_4_MARK___3 = 1547,
	SD1_WP_MARK___3 = 1548,
	NFWP_N_A_MARK___3 = 1549,
	SSI_WS1_MARK = 1550,
	RIF0_SYNC_B_MARK___3 = 1551,
	TS_SPSYNC0_MARK = 1552,
	IP8_11_8_MARK___3 = 1553,
	SD0_DAT1_MARK___3 = 1554,
	NFDATA11_MARK___3 = 1555,
	SDA2_C_MARK = 1556,
	HCTS1_N_B_MARK___3 = 1557,
	FMIN_B_MARK___3 = 1558,
	IP9_11_8_MARK___3 = 1559,
	SD1_DAT3_MARK___3 = 1560,
	NFRB_N_B_MARK___3 = 1561,
	IP10_11_8_MARK___3 = 1562,
	SD3_DAT5_MARK___3 = 1563,
	NFDATA5_MARK___3 = 1564,
	IP11_11_8_MARK___3 = 1565,
	RX0_A_MARK = 1566,
	HRX1_A_MARK___3 = 1567,
	SSI_SCK2_A_MARK___3 = 1568,
	RIF1_SYNC_MARK = 1569,
	TS_SCK1_MARK = 1570,
	IP8_15_12_MARK___3 = 1571,
	SD0_DAT2_MARK___3 = 1572,
	NFDATA12_MARK___3 = 1573,
	SCL2_C_MARK = 1574,
	HRTS1_N_B_MARK___3 = 1575,
	BPFCLK_B_MARK___3 = 1576,
	IP9_15_12_MARK___3 = 1577,
	SD3_CLK_MARK___3 = 1578,
	NFWE_N_MARK___3 = 1579,
	IP10_15_12_MARK___3 = 1580,
	SD3_DAT6_MARK___3 = 1581,
	NFDATA6_MARK___3 = 1582,
	IP11_15_12_MARK___3 = 1583,
	TX0_A_MARK = 1584,
	HTX1_A_MARK___3 = 1585,
	SSI_WS2_A_MARK___3 = 1586,
	RIF1_D0_MARK = 1587,
	TS_SDAT1_MARK = 1588,
	IP8_19_16_MARK___3 = 1589,
	SD0_DAT3_MARK___3 = 1590,
	NFDATA13_MARK___3 = 1591,
	SDA1_C_MARK = 1592,
	SCL2_E_MARK = 1593,
	SPEEDIN_C_MARK = 1594,
	REMOCON_C_MARK = 1595,
	IP9_19_16_MARK___3 = 1596,
	SD3_CMD_MARK___3 = 1597,
	NFRE_N_MARK___3 = 1598,
	IP10_19_16_MARK___3 = 1599,
	SD3_DAT7_MARK___3 = 1600,
	NFDATA7_MARK___3 = 1601,
	IP11_19_16_MARK___3 = 1602,
	CTS0_N_A_MARK = 1603,
	NFDATA14_A_MARK___3 = 1604,
	AUDIO_CLKOUT_A_MARK___3 = 1605,
	RIF1_D1_MARK = 1606,
	SCIF_CLK_A_MARK___3 = 1607,
	FMCLK_A_MARK___3 = 1608,
	IP8_23_20_MARK___3 = 1609,
	SD1_CLK_MARK___3 = 1610,
	NFDATA14_B_MARK___3 = 1611,
	IP9_23_20_MARK___3 = 1612,
	SD3_DAT0_MARK___3 = 1613,
	NFDATA0_MARK___3 = 1614,
	IP10_23_20_MARK___3 = 1615,
	SD3_DS_MARK___3 = 1616,
	NFCLE_MARK___3 = 1617,
	IP11_23_20_MARK___3 = 1618,
	RTS0_N_A_MARK = 1619,
	NFDATA15_A_MARK___3 = 1620,
	AUDIO_CLKOUT1_A_MARK___3 = 1621,
	RIF1_CLK_MARK = 1622,
	SCL2_A_MARK___3 = 1623,
	FMIN_A_MARK___3 = 1624,
	IP8_27_24_MARK___3 = 1625,
	SD1_CMD_MARK___3 = 1626,
	NFDATA15_B_MARK___3 = 1627,
	IP9_27_24_MARK___3 = 1628,
	SD3_DAT1_MARK___3 = 1629,
	NFDATA1_MARK___3 = 1630,
	IP10_27_24_MARK___3 = 1631,
	SD0_CD_MARK___3 = 1632,
	NFALE_A_MARK = 1633,
	SD3_CD_MARK___3 = 1634,
	RIF0_CLK_B_MARK___3 = 1635,
	SCL2_B_MARK___3 = 1636,
	TCLK1_A_MARK___3 = 1637,
	SSI_SCK2_B_MARK___3 = 1638,
	TS_SCK0_MARK = 1639,
	IP11_27_24_MARK___3 = 1640,
	SCK0_A_MARK = 1641,
	HSCK1_A_MARK___3 = 1642,
	USB3HS0_ID_MARK = 1643,
	RTS1_N_MARK___3 = 1644,
	SDA2_A_MARK___3 = 1645,
	FMCLK_C_MARK___3 = 1646,
	USB0_ID_MARK = 1647,
	IP8_31_28_MARK___3 = 1648,
	SD1_DAT0_MARK___3 = 1649,
	NFWP_N_B_MARK___3 = 1650,
	IP9_31_28_MARK___3 = 1651,
	SD3_DAT2_MARK___3 = 1652,
	NFDATA2_MARK___3 = 1653,
	IP10_31_28_MARK___3 = 1654,
	SD0_WP_MARK___3 = 1655,
	NFRB_N_A_MARK___3 = 1656,
	SD3_WP_MARK___3 = 1657,
	RIF0_D0_B_MARK___3 = 1658,
	SDA2_B_MARK___3 = 1659,
	TCLK2_A_MARK___3 = 1660,
	SSI_WS2_B_MARK___3 = 1661,
	TS_SDAT0_MARK = 1662,
	IP11_31_28_MARK___3 = 1663,
	RX1_MARK = 1664,
	HRX2_B_MARK___3 = 1665,
	SSI_SCK9_B_MARK___3 = 1666,
	AUDIO_CLKOUT1_B_MARK___3 = 1667,
	IP12_3_0_MARK___3 = 1668,
	TX1_MARK = 1669,
	HTX2_B_MARK___3 = 1670,
	SSI_WS9_B_MARK___3 = 1671,
	AUDIO_CLKOUT3_B_MARK___3 = 1672,
	IP13_3_0_MARK___3 = 1673,
	MSIOF0_SS1_MARK___3 = 1674,
	HRX2_A_MARK___3 = 1675,
	SSI_SCK4_MARK___3 = 1676,
	HCTS0_N_A_MARK = 1677,
	BPFCLK_C_MARK___3 = 1678,
	SPEEDIN_A_MARK___3 = 1679,
	IP14_3_0_MARK___3 = 1680,
	SSI_SDATA0_MARK___3 = 1681,
	IP15_3_0_MARK___3 = 1682,
	SSI_WS5_MARK___3 = 1683,
	HTX0_B_MARK = 1684,
	USB0_OVC_B_MARK = 1685,
	SDA2_D_MARK = 1686,
	IP12_7_4_MARK___3 = 1687,
	SCK2_A_MARK = 1688,
	HSCK0_A_MARK = 1689,
	AUDIO_CLKB_A_MARK___3 = 1690,
	CTS1_N_MARK___3 = 1691,
	RIF0_CLK_A_MARK___3 = 1692,
	REMOCON_A_MARK___3 = 1693,
	SCIF_CLK_B_MARK___3 = 1694,
	IP13_7_4_MARK___3 = 1695,
	MSIOF0_SS2_MARK___3 = 1696,
	HTX2_A_MARK___3 = 1697,
	SSI_WS4_MARK___3 = 1698,
	HRTS0_N_A_MARK = 1699,
	FMIN_C_MARK___3 = 1700,
	BPFCLK_A_MARK___3 = 1701,
	IP14_7_4_MARK___3 = 1702,
	SSI_SDATA1_MARK = 1703,
	AUDIO_CLKC_B_MARK___3 = 1704,
	PWM0_B_MARK = 1705,
	IP15_7_4_MARK___3 = 1706,
	SSI_SDATA5_MARK___3 = 1707,
	HSCK0_B_MARK = 1708,
	AUDIO_CLKB_C_MARK = 1709,
	TPU0TO0_MARK___3 = 1710,
	IP12_11_8_MARK___3 = 1711,
	TX2_A_MARK___3 = 1712,
	HRX0_A_MARK = 1713,
	AUDIO_CLKOUT2_A_MARK___3 = 1714,
	SCL1_A_MARK___3 = 1715,
	FSO_CFE_0_N_A_MARK = 1716,
	TS_SDEN1_MARK = 1717,
	IP13_11_8_MARK___3 = 1718,
	SSI_SDATA9_MARK = 1719,
	AUDIO_CLKC_A_MARK___3 = 1720,
	SCK1_MARK___3 = 1721,
	IP14_11_8_MARK___3 = 1722,
	SSI_SDATA2_MARK = 1723,
	AUDIO_CLKOUT2_B_MARK___3 = 1724,
	SSI_SCK9_A_MARK___3 = 1725,
	PWM1_B_MARK___3 = 1726,
	IP15_11_8_MARK___3 = 1727,
	SSI_SCK6_MARK___3 = 1728,
	HSCK2_A_MARK___3 = 1729,
	AUDIO_CLKC_C_MARK = 1730,
	TPU0TO1_MARK___3 = 1731,
	FSO_CFE_0_N_B_MARK = 1732,
	SIM0_RST_B_MARK___3 = 1733,
	IP12_15_12_MARK___3 = 1734,
	RX2_A_MARK___3 = 1735,
	HTX0_A_MARK = 1736,
	AUDIO_CLKOUT3_A_MARK___3 = 1737,
	SDA1_A_MARK___3 = 1738,
	FSO_CFE_1_N_A_MARK = 1739,
	TS_SPSYNC1_MARK = 1740,
	IP13_15_12_MARK___3 = 1741,
	MLB_CLK_MARK___3 = 1742,
	RX0_B_MARK = 1743,
	RIF0_D0_A_MARK___3 = 1744,
	SCL1_B_MARK___3 = 1745,
	TCLK1_B_MARK___3 = 1746,
	SIM0_RST_A_MARK___3 = 1747,
	IP14_15_12_MARK___3 = 1748,
	SSI_SCK349_MARK___3 = 1749,
	PWM2_C_MARK = 1750,
	IP15_15_12_MARK___3 = 1751,
	SSI_WS6_MARK___3 = 1752,
	HCTS2_N_A_MARK___3 = 1753,
	AUDIO_CLKOUT2_C_MARK = 1754,
	TPU0TO2_MARK___3 = 1755,
	SDA1_D_MARK = 1756,
	FSO_CFE_1_N_B_MARK = 1757,
	SIM0_D_B_MARK___3 = 1758,
	IP12_19_16_MARK___3 = 1759,
	MSIOF0_SCK_MARK___3 = 1760,
	SSI_SCK78_MARK___3 = 1761,
	IP13_19_16_MARK___3 = 1762,
	MLB_SIG_MARK___3 = 1763,
	SCK0_B_MARK = 1764,
	RIF0_D1_A_MARK___3 = 1765,
	SDA1_B_MARK___3 = 1766,
	TCLK2_B_MARK___3 = 1767,
	SIM0_D_A_MARK___3 = 1768,
	IP14_19_16_MARK___3 = 1769,
	SSI_WS349_MARK___3 = 1770,
	PWM3_C_MARK = 1771,
	IP15_19_16_MARK___3 = 1772,
	SSI_SDATA6_MARK___3 = 1773,
	HRTS2_N_A_MARK___3 = 1774,
	AUDIO_CLKOUT3_C_MARK = 1775,
	TPU0TO3_MARK___3 = 1776,
	SCL1_D_MARK = 1777,
	FSO_TOE_N_B_MARK = 1778,
	SIM0_CLK_B_MARK___3 = 1779,
	IP12_23_20_MARK___3 = 1780,
	MSIOF0_RXD_MARK___3 = 1781,
	SSI_WS78_MARK___3 = 1782,
	TX2_B_MARK___3 = 1783,
	IP13_23_20_MARK___3 = 1784,
	MLB_DAT_MARK___3 = 1785,
	TX0_B_MARK = 1786,
	RIF0_SYNC_A_MARK___3 = 1787,
	SIM0_CLK_A_MARK___3 = 1788,
	IP14_23_20_MARK___3 = 1789,
	SSI_SDATA3_MARK___3 = 1790,
	AUDIO_CLKOUT1_C_MARK = 1791,
	AUDIO_CLKB_B_MARK___3 = 1792,
	PWM4_B_MARK___3 = 1793,
	IP15_23_20_MARK___3 = 1794,
	AUDIO_CLKA_MARK = 1795,
	IP12_27_24_MARK___3 = 1796,
	MSIOF0_TXD_MARK___3 = 1797,
	SSI_SDATA7_MARK___3 = 1798,
	RX2_B_MARK___3 = 1799,
	IP13_27_24_MARK___3 = 1800,
	SSI_SCK01239_MARK___3 = 1801,
	IP14_27_24_MARK___3 = 1802,
	SSI_SDATA4_MARK___3 = 1803,
	SSI_WS9_A_MARK___3 = 1804,
	PWM5_B_MARK___3 = 1805,
	IP15_27_24_MARK___3 = 1806,
	USB30_PWEN_MARK___3 = 1807,
	USB0_PWEN_A_MARK = 1808,
	IP12_31_28_MARK___3 = 1809,
	MSIOF0_SYNC_MARK___3 = 1810,
	AUDIO_CLKOUT_B_MARK___3 = 1811,
	SSI_SDATA8_MARK___3 = 1812,
	IP13_31_28_MARK___3 = 1813,
	SSI_WS01239_MARK___3 = 1814,
	IP14_31_28_MARK___3 = 1815,
	SSI_SCK5_MARK___3 = 1816,
	HRX0_B_MARK = 1817,
	USB0_PWEN_B_MARK = 1818,
	SCL2_D_MARK = 1819,
	PWM6_B_MARK___3 = 1820,
	IP15_31_28_MARK___3 = 1821,
	USB30_OVC_MARK___3 = 1822,
	USB0_OVC_A_MARK = 1823,
	FSO_TOE_N_A_MARK = 1824,
	SEL_SIMCARD_0_MARK___3 = 1825,
	SEL_SIMCARD_1_MARK___3 = 1826,
	SEL_ADGB_0_MARK___3 = 1827,
	SEL_ADGB_2_MARK = 1828,
	SEL_ADGB_1_MARK___3 = 1829,
	SEL_SSI2_0_MARK___3 = 1830,
	SEL_SSI2_1_MARK___3 = 1831,
	SEL_TIMER_TMU_0_MARK___3 = 1832,
	SEL_TIMER_TMU_1_MARK___3 = 1833,
	SEL_DRIF0_0_MARK___3 = 1834,
	SEL_DRIF0_1_MARK___3 = 1835,
	SEL_USB_20_CH0_0_MARK = 1836,
	SEL_USB_20_CH0_1_MARK = 1837,
	SEL_FM_0_MARK___3 = 1838,
	SEL_FM_2_MARK___3 = 1839,
	SEL_FM_1_MARK___3 = 1840,
	SEL_DRIF2_0_MARK___3 = 1841,
	SEL_DRIF2_1_MARK___3 = 1842,
	SEL_FSO_0_MARK = 1843,
	SEL_FSO_1_MARK = 1844,
	SEL_DRIF3_0_MARK___3 = 1845,
	SEL_DRIF3_1_MARK___3 = 1846,
	SEL_HSCIF0_0_MARK = 1847,
	SEL_HSCIF0_1_MARK = 1848,
	SEL_HSCIF3_0_MARK___3 = 1849,
	SEL_HSCIF3_4_MARK = 1850,
	SEL_HSCIF3_2_MARK___3 = 1851,
	SEL_HSCIF3_1_MARK___3 = 1852,
	SEL_HSCIF3_3_MARK___3 = 1853,
	SEL_HSCIF1_0_MARK___3 = 1854,
	SEL_HSCIF1_1_MARK___3 = 1855,
	SEL_HSCIF2_0_MARK___3 = 1856,
	SEL_HSCIF2_1_MARK___3 = 1857,
	SEL_I2C1_0_MARK___3 = 1858,
	SEL_I2C1_2_MARK = 1859,
	SEL_I2C1_1_MARK___3 = 1860,
	SEL_I2C1_3_MARK = 1861,
	SEL_HSCIF4_0_MARK___3 = 1862,
	SEL_HSCIF4_4_MARK = 1863,
	SEL_HSCIF4_2_MARK = 1864,
	SEL_HSCIF4_1_MARK___3 = 1865,
	SEL_HSCIF4_3_MARK = 1866,
	SEL_I2C2_0_MARK___3 = 1867,
	SEL_I2C2_4_MARK = 1868,
	SEL_I2C2_2_MARK = 1869,
	SEL_I2C2_1_MARK___3 = 1870,
	SEL_I2C2_3_MARK = 1871,
	SEL_I2C6_0_MARK___3 = 1872,
	SEL_I2C6_1_MARK___3 = 1873,
	SEL_I2C7_0_MARK = 1874,
	SEL_I2C7_1_MARK = 1875,
	SEL_NDF_0_MARK___3 = 1876,
	SEL_NDF_1_MARK___3 = 1877,
	SEL_MSIOF2_0_MARK___3 = 1878,
	SEL_MSIOF2_1_MARK___3 = 1879,
	SEL_PWM0_0_MARK = 1880,
	SEL_PWM0_1_MARK = 1881,
	SEL_MSIOF3_0_MARK___3 = 1882,
	SEL_MSIOF3_1_MARK___3 = 1883,
	SEL_PWM1_0_MARK___3 = 1884,
	SEL_PWM1_1_MARK___3 = 1885,
	SEL_SCIF3_0_MARK___3 = 1886,
	SEL_SCIF3_2_MARK = 1887,
	SEL_SCIF3_1_MARK___3 = 1888,
	SEL_PWM2_0_MARK___3 = 1889,
	SEL_PWM2_2_MARK = 1890,
	SEL_PWM2_1_MARK___3 = 1891,
	SEL_SCIF4_0_MARK___3 = 1892,
	SEL_SCIF4_2_MARK___3 = 1893,
	SEL_SCIF4_1_MARK___3 = 1894,
	SEL_PWM3_0_MARK___3 = 1895,
	SEL_PWM3_2_MARK = 1896,
	SEL_PWM3_1_MARK___3 = 1897,
	SEL_SCIF5_0_MARK___3 = 1898,
	SEL_SCIF5_2_MARK = 1899,
	SEL_SCIF5_1_MARK___3 = 1900,
	SEL_PWM4_0_MARK___3 = 1901,
	SEL_PWM4_1_MARK___3 = 1902,
	SEL_PWM5_0_MARK___3 = 1903,
	SEL_PWM5_1_MARK___3 = 1904,
	SEL_VIN4_0_MARK___3 = 1905,
	SEL_VIN4_1_MARK___3 = 1906,
	SEL_PWM6_0_MARK___3 = 1907,
	SEL_PWM6_1_MARK___3 = 1908,
	SEL_VIN5_0_MARK = 1909,
	SEL_VIN5_1_MARK = 1910,
	SEL_REMOCON_0_MARK___3 = 1911,
	SEL_REMOCON_2_MARK = 1912,
	SEL_REMOCON_1_MARK___3 = 1913,
	SEL_ADGC_0_MARK___3 = 1914,
	SEL_ADGC_2_MARK = 1915,
	SEL_ADGC_1_MARK___3 = 1916,
	SEL_SCIF_0_MARK___3 = 1917,
	SEL_SCIF_1_MARK___3 = 1918,
	SEL_SSI9_0_MARK___3 = 1919,
	SEL_SSI9_1_MARK___3 = 1920,
	SEL_SCIF0_0_MARK = 1921,
	SEL_SCIF0_1_MARK = 1922,
	SEL_SCIF2_0_MARK___3 = 1923,
	SEL_SCIF2_1_MARK___3 = 1924,
	SEL_SPEED_PULSE_IF_0_MARK = 1925,
	SEL_SPEED_PULSE_IF_2_MARK = 1926,
	SEL_SPEED_PULSE_IF_1_MARK = 1927,
	AVB_TX_CTL_MARK___3 = 1928,
	AVB_TXC_MARK___3 = 1929,
	AVB_TD0_MARK___3 = 1930,
	AVB_TD1_MARK___3 = 1931,
	AVB_TD2_MARK___3 = 1932,
	AVB_TD3_MARK___3 = 1933,
	PRESETOUT_N_MARK = 1934,
	FSCLKST_N_MARK = 1935,
	TRST_N_MARK = 1936,
	TCK_MARK___3 = 1937,
	TMS_MARK___3 = 1938,
	TDI_MARK___3 = 1939,
	ASEBRK_MARK___3 = 1940,
	MLB_REF_MARK___3 = 1941,
	PINMUX_MARK_END___3 = 1942,
};

enum {
	GP_LAST___3 = 209,
	PIN_ASEBRK___3 = 210,
	PIN_AVB_MDC = 211,
	PIN_AVB_MDIO___3 = 212,
	PIN_AVB_TD0___3 = 213,
	PIN_AVB_TD1___3 = 214,
	PIN_AVB_TD2___3 = 215,
	PIN_AVB_TD3___3 = 216,
	PIN_AVB_TXC___3 = 217,
	PIN_AVB_TX_CTL___3 = 218,
	PIN_FSCLKST_N = 219,
	PIN_MLB_REF___3 = 220,
	PIN_PRESETOUT_N___3 = 221,
	PIN_TCK___3 = 222,
	PIN_TDI___3 = 223,
	PIN_TMS___3 = 224,
	PIN_TRST_N___3 = 225,
};

enum ioctrl_regs___2 {
	POCCTRL0 = 0,
	TDSELCTRL___2 = 1,
};

enum {
	PINMUX_RESERVED___4 = 0,
	PINMUX_DATA_BEGIN___4 = 1,
	GP_0_0_DATA___4 = 2,
	GP_0_1_DATA___4 = 3,
	GP_0_2_DATA___4 = 4,
	GP_0_3_DATA___4 = 5,
	GP_0_4_DATA___4 = 6,
	GP_0_5_DATA___4 = 7,
	GP_0_6_DATA___4 = 8,
	GP_0_7_DATA___4 = 9,
	GP_0_8_DATA___4 = 10,
	GP_0_9_DATA___4 = 11,
	GP_0_10_DATA___4 = 12,
	GP_0_11_DATA___4 = 13,
	GP_0_12_DATA___4 = 14,
	GP_0_13_DATA___4 = 15,
	GP_0_14_DATA___4 = 16,
	GP_0_15_DATA___4 = 17,
	GP_1_0_DATA___4 = 18,
	GP_1_1_DATA___4 = 19,
	GP_1_2_DATA___4 = 20,
	GP_1_3_DATA___4 = 21,
	GP_1_4_DATA___4 = 22,
	GP_1_5_DATA___4 = 23,
	GP_1_6_DATA___4 = 24,
	GP_1_7_DATA___4 = 25,
	GP_1_8_DATA___4 = 26,
	GP_1_9_DATA___4 = 27,
	GP_1_10_DATA___4 = 28,
	GP_1_11_DATA___4 = 29,
	GP_1_12_DATA___4 = 30,
	GP_1_13_DATA___4 = 31,
	GP_1_14_DATA___4 = 32,
	GP_1_15_DATA___4 = 33,
	GP_1_16_DATA___4 = 34,
	GP_1_17_DATA___4 = 35,
	GP_1_18_DATA___4 = 36,
	GP_1_19_DATA___4 = 37,
	GP_1_20_DATA___4 = 38,
	GP_1_21_DATA___4 = 39,
	GP_1_22_DATA___4 = 40,
	GP_1_23_DATA___3 = 41,
	GP_1_24_DATA___3 = 42,
	GP_1_25_DATA___3 = 43,
	GP_1_26_DATA___3 = 44,
	GP_1_27_DATA___3 = 45,
	GP_1_28_DATA___3 = 46,
	GP_2_0_DATA___4 = 47,
	GP_2_1_DATA___4 = 48,
	GP_2_2_DATA___4 = 49,
	GP_2_3_DATA___4 = 50,
	GP_2_4_DATA___4 = 51,
	GP_2_5_DATA___4 = 52,
	GP_2_6_DATA___4 = 53,
	GP_2_7_DATA___4 = 54,
	GP_2_8_DATA___4 = 55,
	GP_2_9_DATA___4 = 56,
	GP_2_10_DATA___4 = 57,
	GP_2_11_DATA___4 = 58,
	GP_2_12_DATA___4 = 59,
	GP_2_13_DATA___4 = 60,
	GP_2_14_DATA___4 = 61,
	GP_3_0_DATA___4 = 62,
	GP_3_1_DATA___4 = 63,
	GP_3_2_DATA___4 = 64,
	GP_3_3_DATA___4 = 65,
	GP_3_4_DATA___4 = 66,
	GP_3_5_DATA___4 = 67,
	GP_3_6_DATA___4 = 68,
	GP_3_7_DATA___4 = 69,
	GP_3_8_DATA___4 = 70,
	GP_3_9_DATA___4 = 71,
	GP_3_10_DATA___4 = 72,
	GP_3_11_DATA___4 = 73,
	GP_3_12_DATA___4 = 74,
	GP_3_13_DATA___4 = 75,
	GP_3_14_DATA___4 = 76,
	GP_3_15_DATA___4 = 77,
	GP_4_0_DATA___4 = 78,
	GP_4_1_DATA___4 = 79,
	GP_4_2_DATA___4 = 80,
	GP_4_3_DATA___4 = 81,
	GP_4_4_DATA___4 = 82,
	GP_4_5_DATA___4 = 83,
	GP_4_6_DATA___4 = 84,
	GP_4_7_DATA___4 = 85,
	GP_4_8_DATA___4 = 86,
	GP_4_9_DATA___4 = 87,
	GP_4_10_DATA___4 = 88,
	GP_4_11_DATA___3 = 89,
	GP_4_12_DATA___3 = 90,
	GP_4_13_DATA___3 = 91,
	GP_4_14_DATA___3 = 92,
	GP_4_15_DATA___3 = 93,
	GP_4_16_DATA___3 = 94,
	GP_4_17_DATA___3 = 95,
	GP_5_0_DATA___4 = 96,
	GP_5_1_DATA___4 = 97,
	GP_5_2_DATA___4 = 98,
	GP_5_3_DATA___4 = 99,
	GP_5_4_DATA___4 = 100,
	GP_5_5_DATA___4 = 101,
	GP_5_6_DATA___4 = 102,
	GP_5_7_DATA___4 = 103,
	GP_5_8_DATA___4 = 104,
	GP_5_9_DATA___4 = 105,
	GP_5_10_DATA___4 = 106,
	GP_5_11_DATA___4 = 107,
	GP_5_12_DATA___4 = 108,
	GP_5_13_DATA___4 = 109,
	GP_5_14_DATA___4 = 110,
	GP_5_15_DATA___4 = 111,
	GP_5_16_DATA___4 = 112,
	GP_5_17_DATA___4 = 113,
	GP_5_18_DATA___4 = 114,
	GP_5_19_DATA___4 = 115,
	GP_5_20_DATA___3 = 116,
	GP_5_21_DATA___3 = 117,
	GP_5_22_DATA___3 = 118,
	GP_5_23_DATA___3 = 119,
	GP_5_24_DATA___3 = 120,
	GP_5_25_DATA___3 = 121,
	GP_6_0_DATA___4 = 122,
	GP_6_1_DATA___4 = 123,
	GP_6_2_DATA___4 = 124,
	GP_6_3_DATA___4 = 125,
	GP_6_4_DATA___4 = 126,
	GP_6_5_DATA___4 = 127,
	GP_6_6_DATA___4 = 128,
	GP_6_7_DATA___4 = 129,
	GP_6_8_DATA___4 = 130,
	GP_6_9_DATA___4 = 131,
	GP_6_10_DATA___4 = 132,
	GP_6_11_DATA___4 = 133,
	GP_6_12_DATA___4 = 134,
	GP_6_13_DATA___4 = 135,
	GP_6_14_DATA___4 = 136,
	GP_6_15_DATA___4 = 137,
	GP_6_16_DATA___4 = 138,
	GP_6_17_DATA___4 = 139,
	GP_6_18_DATA___3 = 140,
	GP_6_19_DATA___3 = 141,
	GP_6_20_DATA___3 = 142,
	GP_6_21_DATA___3 = 143,
	GP_6_22_DATA___3 = 144,
	GP_6_23_DATA___3 = 145,
	GP_6_24_DATA___3 = 146,
	GP_6_25_DATA___3 = 147,
	GP_6_26_DATA___3 = 148,
	GP_6_27_DATA___3 = 149,
	GP_6_28_DATA___3 = 150,
	GP_6_29_DATA___3 = 151,
	GP_6_30_DATA___3 = 152,
	GP_6_31_DATA___3 = 153,
	GP_7_0_DATA___3 = 154,
	GP_7_1_DATA___3 = 155,
	GP_7_2_DATA___3 = 156,
	GP_7_3_DATA___3 = 157,
	PINMUX_DATA_END___4 = 158,
	PINMUX_FUNCTION_BEGIN___4 = 159,
	GP_0_0_FN___4 = 160,
	GP_0_1_FN___4 = 161,
	GP_0_2_FN___4 = 162,
	GP_0_3_FN___4 = 163,
	GP_0_4_FN___4 = 164,
	GP_0_5_FN___4 = 165,
	GP_0_6_FN___4 = 166,
	GP_0_7_FN___4 = 167,
	GP_0_8_FN___4 = 168,
	GP_0_9_FN___4 = 169,
	GP_0_10_FN___4 = 170,
	GP_0_11_FN___4 = 171,
	GP_0_12_FN___4 = 172,
	GP_0_13_FN___4 = 173,
	GP_0_14_FN___4 = 174,
	GP_0_15_FN___4 = 175,
	GP_1_0_FN___4 = 176,
	GP_1_1_FN___4 = 177,
	GP_1_2_FN___4 = 178,
	GP_1_3_FN___4 = 179,
	GP_1_4_FN___4 = 180,
	GP_1_5_FN___4 = 181,
	GP_1_6_FN___4 = 182,
	GP_1_7_FN___4 = 183,
	GP_1_8_FN___4 = 184,
	GP_1_9_FN___4 = 185,
	GP_1_10_FN___4 = 186,
	GP_1_11_FN___4 = 187,
	GP_1_12_FN___4 = 188,
	GP_1_13_FN___4 = 189,
	GP_1_14_FN___4 = 190,
	GP_1_15_FN___4 = 191,
	GP_1_16_FN___4 = 192,
	GP_1_17_FN___4 = 193,
	GP_1_18_FN___4 = 194,
	GP_1_19_FN___4 = 195,
	GP_1_20_FN___4 = 196,
	GP_1_21_FN___4 = 197,
	GP_1_22_FN___4 = 198,
	GP_1_23_FN___3 = 199,
	GP_1_24_FN___3 = 200,
	GP_1_25_FN___3 = 201,
	GP_1_26_FN___3 = 202,
	GP_1_27_FN___3 = 203,
	GP_1_28_FN___3 = 204,
	GP_2_0_FN___4 = 205,
	GP_2_1_FN___4 = 206,
	GP_2_2_FN___4 = 207,
	GP_2_3_FN___4 = 208,
	GP_2_4_FN___4 = 209,
	GP_2_5_FN___4 = 210,
	GP_2_6_FN___4 = 211,
	GP_2_7_FN___4 = 212,
	GP_2_8_FN___4 = 213,
	GP_2_9_FN___4 = 214,
	GP_2_10_FN___4 = 215,
	GP_2_11_FN___4 = 216,
	GP_2_12_FN___4 = 217,
	GP_2_13_FN___4 = 218,
	GP_2_14_FN___4 = 219,
	GP_3_0_FN___4 = 220,
	GP_3_1_FN___4 = 221,
	GP_3_2_FN___4 = 222,
	GP_3_3_FN___4 = 223,
	GP_3_4_FN___4 = 224,
	GP_3_5_FN___4 = 225,
	GP_3_6_FN___4 = 226,
	GP_3_7_FN___4 = 227,
	GP_3_8_FN___4 = 228,
	GP_3_9_FN___4 = 229,
	GP_3_10_FN___4 = 230,
	GP_3_11_FN___4 = 231,
	GP_3_12_FN___4 = 232,
	GP_3_13_FN___4 = 233,
	GP_3_14_FN___4 = 234,
	GP_3_15_FN___4 = 235,
	GP_4_0_FN___4 = 236,
	GP_4_1_FN___4 = 237,
	GP_4_2_FN___4 = 238,
	GP_4_3_FN___4 = 239,
	GP_4_4_FN___4 = 240,
	GP_4_5_FN___4 = 241,
	GP_4_6_FN___4 = 242,
	GP_4_7_FN___4 = 243,
	GP_4_8_FN___4 = 244,
	GP_4_9_FN___4 = 245,
	GP_4_10_FN___4 = 246,
	GP_4_11_FN___3 = 247,
	GP_4_12_FN___3 = 248,
	GP_4_13_FN___3 = 249,
	GP_4_14_FN___3 = 250,
	GP_4_15_FN___3 = 251,
	GP_4_16_FN___3 = 252,
	GP_4_17_FN___3 = 253,
	GP_5_0_FN___4 = 254,
	GP_5_1_FN___4 = 255,
	GP_5_2_FN___4 = 256,
	GP_5_3_FN___4 = 257,
	GP_5_4_FN___4 = 258,
	GP_5_5_FN___4 = 259,
	GP_5_6_FN___4 = 260,
	GP_5_7_FN___4 = 261,
	GP_5_8_FN___4 = 262,
	GP_5_9_FN___4 = 263,
	GP_5_10_FN___4 = 264,
	GP_5_11_FN___4 = 265,
	GP_5_12_FN___4 = 266,
	GP_5_13_FN___4 = 267,
	GP_5_14_FN___4 = 268,
	GP_5_15_FN___4 = 269,
	GP_5_16_FN___4 = 270,
	GP_5_17_FN___4 = 271,
	GP_5_18_FN___4 = 272,
	GP_5_19_FN___4 = 273,
	GP_5_20_FN___3 = 274,
	GP_5_21_FN___3 = 275,
	GP_5_22_FN___3 = 276,
	GP_5_23_FN___3 = 277,
	GP_5_24_FN___3 = 278,
	GP_5_25_FN___3 = 279,
	GP_6_0_FN___4 = 280,
	GP_6_1_FN___4 = 281,
	GP_6_2_FN___4 = 282,
	GP_6_3_FN___4 = 283,
	GP_6_4_FN___4 = 284,
	GP_6_5_FN___4 = 285,
	GP_6_6_FN___4 = 286,
	GP_6_7_FN___4 = 287,
	GP_6_8_FN___4 = 288,
	GP_6_9_FN___4 = 289,
	GP_6_10_FN___4 = 290,
	GP_6_11_FN___4 = 291,
	GP_6_12_FN___4 = 292,
	GP_6_13_FN___4 = 293,
	GP_6_14_FN___4 = 294,
	GP_6_15_FN___4 = 295,
	GP_6_16_FN___4 = 296,
	GP_6_17_FN___4 = 297,
	GP_6_18_FN___3 = 298,
	GP_6_19_FN___3 = 299,
	GP_6_20_FN___3 = 300,
	GP_6_21_FN___3 = 301,
	GP_6_22_FN___3 = 302,
	GP_6_23_FN___3 = 303,
	GP_6_24_FN___3 = 304,
	GP_6_25_FN___3 = 305,
	GP_6_26_FN___3 = 306,
	GP_6_27_FN___3 = 307,
	GP_6_28_FN___3 = 308,
	GP_6_29_FN___3 = 309,
	GP_6_30_FN___3 = 310,
	GP_6_31_FN___3 = 311,
	GP_7_0_FN___3 = 312,
	GP_7_1_FN___3 = 313,
	GP_7_2_FN___3 = 314,
	GP_7_3_FN___3 = 315,
	FN_CLKOUT___4 = 316,
	FN_MSIOF0_RXD___4 = 317,
	FN_MSIOF0_TXD___4 = 318,
	FN_MSIOF0_SCK___4 = 319,
	FN_SSI_SDATA5___4 = 320,
	FN_SSI_WS5___4 = 321,
	FN_SSI_SCK5___4 = 322,
	FN_GP7_03___3 = 323,
	FN_GP7_02___3 = 324,
	FN_AVS2___3 = 325,
	FN_AVS1___3 = 326,
	FN_IP0_3_0___4 = 327,
	FN_AVB_MDC___4 = 328,
	FN_MSIOF2_SS2_C___3 = 329,
	FN_IP1_3_0___4 = 330,
	FN_IRQ2___4 = 331,
	FN_QCPV_QDE___4 = 332,
	FN_DU_EXODDF_DU_ODDF_DISP_CDE___3 = 333,
	FN_VI4_DATA2_B___4 = 334,
	FN_MSIOF3_SYNC_E___3 = 335,
	FN_PWM3_B___4 = 336,
	FN_IP2_3_0___4 = 337,
	FN_A1___4 = 338,
	FN_LCDOUT17___4 = 339,
	FN_MSIOF3_TXD_B___4 = 340,
	FN_VI4_DATA9___4 = 341,
	FN_DU_DB1___4 = 342,
	FN_PWM4_A___4 = 343,
	FN_IP3_3_0___4 = 344,
	FN_A9___4 = 345,
	FN_MSIOF2_SCK_A___4 = 346,
	FN_CTS4_N_B___3 = 347,
	FN_VI5_VSYNC_N___3 = 348,
	FN_IP0_7_4___4 = 349,
	FN_AVB_MAGIC___4 = 350,
	FN_MSIOF2_SS1_C___3 = 351,
	FN_SCK4_A___4 = 352,
	FN_IP1_7_4___4 = 353,
	FN_IRQ3___4 = 354,
	FN_QSTVB_QVE___4 = 355,
	FN_DU_DOTCLKOUT1___3 = 356,
	FN_VI4_DATA3_B___4 = 357,
	FN_MSIOF3_SCK_E___3 = 358,
	FN_PWM4_B___4 = 359,
	FN_IP2_7_4___4 = 360,
	FN_A2___4 = 361,
	FN_LCDOUT18___4 = 362,
	FN_MSIOF3_SCK_B___4 = 363,
	FN_VI4_DATA10___4 = 364,
	FN_DU_DB2___4 = 365,
	FN_PWM5_A___4 = 366,
	FN_IP3_7_4___4 = 367,
	FN_A10___4 = 368,
	FN_MSIOF2_RXD_A___4 = 369,
	FN_RTS4_N_B___3 = 370,
	FN_VI5_HSYNC_N___3 = 371,
	FN_IP0_11_8___4 = 372,
	FN_AVB_PHY_INT___4 = 373,
	FN_MSIOF2_SYNC_C___3 = 374,
	FN_RX4_A___4 = 375,
	FN_IP1_11_8___4 = 376,
	FN_IRQ4___4 = 377,
	FN_QSTH_QHS___4 = 378,
	FN_DU_EXHSYNC_DU_HSYNC___3 = 379,
	FN_VI4_DATA4_B___4 = 380,
	FN_MSIOF3_RXD_E___3 = 381,
	FN_PWM5_B___4 = 382,
	FN_IP2_11_8___4 = 383,
	FN_A3___4 = 384,
	FN_LCDOUT19___4 = 385,
	FN_MSIOF3_RXD_B___4 = 386,
	FN_VI4_DATA11___4 = 387,
	FN_DU_DB3___4 = 388,
	FN_PWM6_A___4 = 389,
	FN_IP3_11_8___4 = 390,
	FN_A11___4 = 391,
	FN_TX3_B___4 = 392,
	FN_MSIOF2_TXD_A___4 = 393,
	FN_HTX4_B___4 = 394,
	FN_HSCK4___3 = 395,
	FN_VI5_FIELD___3 = 396,
	FN_SCL6_A___4 = 397,
	FN_AVB_AVTP_CAPTURE_B___3 = 398,
	FN_PWM2_B___4 = 399,
	FN_IP0_15_12___4 = 400,
	FN_AVB_LINK___4 = 401,
	FN_MSIOF2_SCK_C___3 = 402,
	FN_TX4_A___4 = 403,
	FN_IP1_15_12___4 = 404,
	FN_IRQ5___4 = 405,
	FN_QSTB_QHE___4 = 406,
	FN_DU_EXVSYNC_DU_VSYNC___3 = 407,
	FN_VI4_DATA5_B___4 = 408,
	FN_FSCLKST2_N_B___3 = 409,
	FN_MSIOF3_TXD_E___3 = 410,
	FN_PWM6_B___4 = 411,
	FN_IP2_15_12___4 = 412,
	FN_A4___4 = 413,
	FN_LCDOUT20___4 = 414,
	FN_MSIOF3_SS1_B___4 = 415,
	FN_VI4_DATA12___4 = 416,
	FN_VI5_DATA12___3 = 417,
	FN_DU_DB4___4 = 418,
	FN_IP3_15_12___4 = 419,
	FN_A12___4 = 420,
	FN_LCDOUT12___4 = 421,
	FN_MSIOF3_SCK_C___3 = 422,
	FN_HRX4_A___4 = 423,
	FN_VI5_DATA8___3 = 424,
	FN_DU_DG4___4 = 425,
	FN_IP0_19_16___4 = 426,
	FN_AVB_AVTP_MATCH_A___3 = 427,
	FN_MSIOF2_RXD_C___3 = 428,
	FN_CTS4_N_A___4 = 429,
	FN_FSCLKST2_N_A___3 = 430,
	FN_IP1_19_16___4 = 431,
	FN_PWM0___3 = 432,
	FN_AVB_AVTP_PPS___4 = 433,
	FN_VI4_DATA6_B___4 = 434,
	FN_IECLK_B___3 = 435,
	FN_IP2_19_16___4 = 436,
	FN_A5___4 = 437,
	FN_LCDOUT21___4 = 438,
	FN_MSIOF3_SS2_B___3 = 439,
	FN_SCK4_B___4 = 440,
	FN_VI4_DATA13___4 = 441,
	FN_VI5_DATA13___3 = 442,
	FN_DU_DB5___4 = 443,
	FN_IP3_19_16___4 = 444,
	FN_A13___4 = 445,
	FN_LCDOUT13___4 = 446,
	FN_MSIOF3_SYNC_C___3 = 447,
	FN_HTX4_A___4 = 448,
	FN_VI5_DATA9___3 = 449,
	FN_DU_DG5___4 = 450,
	FN_IP0_23_20___4 = 451,
	FN_AVB_AVTP_CAPTURE_A___3 = 452,
	FN_MSIOF2_TXD_C___3 = 453,
	FN_RTS4_N_A___4 = 454,
	FN_IP1_23_20___4 = 455,
	FN_PWM1_A___4 = 456,
	FN_HRX3_D___4 = 457,
	FN_VI4_DATA7_B___4 = 458,
	FN_IERX_B___3 = 459,
	FN_IP2_23_20___4 = 460,
	FN_A6___4 = 461,
	FN_LCDOUT22___4 = 462,
	FN_MSIOF2_SS1_A___4 = 463,
	FN_RX4_B___4 = 464,
	FN_VI4_DATA14___4 = 465,
	FN_VI5_DATA14___3 = 466,
	FN_DU_DB6___4 = 467,
	FN_IP3_23_20___4 = 468,
	FN_A14___4 = 469,
	FN_LCDOUT14___4 = 470,
	FN_MSIOF3_RXD_C___3 = 471,
	FN_HCTS4_N___3 = 472,
	FN_VI5_DATA10___3 = 473,
	FN_DU_DG6___4 = 474,
	FN_IP0_27_24___4 = 475,
	FN_IRQ0___4 = 476,
	FN_QPOLB___4 = 477,
	FN_DU_CDE___4 = 478,
	FN_VI4_DATA0_B___4 = 479,
	FN_CAN0_TX_B___3 = 480,
	FN_CANFD0_TX_B___3 = 481,
	FN_MSIOF3_SS2_E___3 = 482,
	FN_IP1_27_24___4 = 483,
	FN_PWM2_A___4 = 484,
	FN_HTX3_D___4 = 485,
	FN_IETX_B___3 = 486,
	FN_IP2_27_24___4 = 487,
	FN_A7___4 = 488,
	FN_LCDOUT23___4 = 489,
	FN_MSIOF2_SS2_A___4 = 490,
	FN_TX4_B___4 = 491,
	FN_VI4_DATA15___4 = 492,
	FN_VI5_DATA15___3 = 493,
	FN_DU_DB7___4 = 494,
	FN_IP3_27_24___4 = 495,
	FN_A15___4 = 496,
	FN_LCDOUT15___4 = 497,
	FN_MSIOF3_TXD_C___3 = 498,
	FN_HRTS4_N___3 = 499,
	FN_VI5_DATA11___3 = 500,
	FN_DU_DG7___4 = 501,
	FN_IP0_31_28___4 = 502,
	FN_IRQ1___4 = 503,
	FN_QPOLA___4 = 504,
	FN_DU_DISP___4 = 505,
	FN_VI4_DATA1_B___4 = 506,
	FN_CAN0_RX_B___3 = 507,
	FN_CANFD0_RX_B___3 = 508,
	FN_MSIOF3_SS1_E___3 = 509,
	FN_IP1_31_28___4 = 510,
	FN_A0___4 = 511,
	FN_LCDOUT16___4 = 512,
	FN_MSIOF3_SYNC_B___4 = 513,
	FN_VI4_DATA8___4 = 514,
	FN_DU_DB0___4 = 515,
	FN_PWM3_A___4 = 516,
	FN_IP2_31_28___4 = 517,
	FN_A8___4 = 518,
	FN_RX3_B___4 = 519,
	FN_MSIOF2_SYNC_A___4 = 520,
	FN_HRX4_B___4 = 521,
	FN_SDA6_A___4 = 522,
	FN_AVB_AVTP_MATCH_B___3 = 523,
	FN_PWM1_B___4 = 524,
	FN_IP3_31_28___4 = 525,
	FN_A16___4 = 526,
	FN_LCDOUT8___4 = 527,
	FN_VI4_FIELD___4 = 528,
	FN_DU_DG0___4 = 529,
	FN_IP4_3_0___4 = 530,
	FN_A17___4 = 531,
	FN_LCDOUT9___4 = 532,
	FN_VI4_VSYNC_N___4 = 533,
	FN_DU_DG1___4 = 534,
	FN_IP5_3_0___4 = 535,
	FN_WE0_N___4 = 536,
	FN_MSIOF3_TXD_D___3 = 537,
	FN_CTS3_N___3 = 538,
	FN_HCTS3_N___3 = 539,
	FN_SCL6_B___4 = 540,
	FN_CAN_CLK___4 = 541,
	FN_IECLK_A___3 = 542,
	FN_IP6_3_0___4 = 543,
	FN_D5___4 = 544,
	FN_MSIOF2_SYNC_B___4 = 545,
	FN_VI4_DATA21___4 = 546,
	FN_VI5_DATA5___3 = 547,
	FN_IP7_3_0___4 = 548,
	FN_D13___4 = 549,
	FN_LCDOUT5___4 = 550,
	FN_MSIOF2_SS2_D___3 = 551,
	FN_TX4_C___4 = 552,
	FN_VI4_DATA5_A___4 = 553,
	FN_DU_DR5___4 = 554,
	FN_IP4_7_4___4 = 555,
	FN_A18___4 = 556,
	FN_LCDOUT10___4 = 557,
	FN_VI4_HSYNC_N___4 = 558,
	FN_DU_DG2___4 = 559,
	FN_IP5_7_4___4 = 560,
	FN_WE1_N___4 = 561,
	FN_MSIOF3_SS1_D___3 = 562,
	FN_RTS3_N___3 = 563,
	FN_HRTS3_N___3 = 564,
	FN_SDA6_B___4 = 565,
	FN_CAN1_RX___4 = 566,
	FN_CANFD1_RX___4 = 567,
	FN_IERX_A___3 = 568,
	FN_IP6_7_4___4 = 569,
	FN_D6___4 = 570,
	FN_MSIOF2_RXD_B___4 = 571,
	FN_VI4_DATA22___4 = 572,
	FN_VI5_DATA6___3 = 573,
	FN_IP7_7_4___4 = 574,
	FN_D14___4 = 575,
	FN_LCDOUT6___4 = 576,
	FN_MSIOF3_SS1_A___4 = 577,
	FN_HRX3_C___4 = 578,
	FN_VI4_DATA6_A___4 = 579,
	FN_DU_DR6___4 = 580,
	FN_SCL6_C___3 = 581,
	FN_IP4_11_8___4 = 582,
	FN_A19___4 = 583,
	FN_LCDOUT11___4 = 584,
	FN_VI4_CLKENB___4 = 585,
	FN_DU_DG3___4 = 586,
	FN_IP5_11_8___4 = 587,
	FN_EX_WAIT0_A___3 = 588,
	FN_QCLK___4 = 589,
	FN_VI4_CLK___4 = 590,
	FN_DU_DOTCLKOUT0___4 = 591,
	FN_IP6_11_8___4 = 592,
	FN_D7___4 = 593,
	FN_MSIOF2_TXD_B___4 = 594,
	FN_VI4_DATA23___4 = 595,
	FN_VI5_DATA7___3 = 596,
	FN_IP7_11_8___4 = 597,
	FN_D15___4 = 598,
	FN_LCDOUT7___4 = 599,
	FN_MSIOF3_SS2_A___4 = 600,
	FN_HTX3_C___4 = 601,
	FN_VI4_DATA7_A___4 = 602,
	FN_DU_DR7___4 = 603,
	FN_SDA6_C___3 = 604,
	FN_IP4_15_12___4 = 605,
	FN_CS0_N___4 = 606,
	FN_VI5_CLKENB___3 = 607,
	FN_IP5_15_12___4 = 608,
	FN_D0___4 = 609,
	FN_MSIOF2_SS1_B___4 = 610,
	FN_MSIOF3_SCK_A___4 = 611,
	FN_VI4_DATA16___4 = 612,
	FN_VI5_DATA0___3 = 613,
	FN_IP6_15_12___4 = 614,
	FN_D8___4 = 615,
	FN_LCDOUT0___4 = 616,
	FN_MSIOF2_SCK_D___3 = 617,
	FN_SCK4_C___3 = 618,
	FN_VI4_DATA0_A___4 = 619,
	FN_DU_DR0___4 = 620,
	FN_IP4_19_16___4 = 621,
	FN_CS1_N___3 = 622,
	FN_VI5_CLK___3 = 623,
	FN_EX_WAIT0_B___3 = 624,
	FN_IP5_19_16___4 = 625,
	FN_D1___4 = 626,
	FN_MSIOF2_SS2_B___4 = 627,
	FN_MSIOF3_SYNC_A___4 = 628,
	FN_VI4_DATA17___4 = 629,
	FN_VI5_DATA1___3 = 630,
	FN_IP6_19_16___4 = 631,
	FN_D9___4 = 632,
	FN_LCDOUT1___4 = 633,
	FN_MSIOF2_SYNC_D___3 = 634,
	FN_VI4_DATA1_A___4 = 635,
	FN_DU_DR1___4 = 636,
	FN_IP7_19_16___4 = 637,
	FN_SD0_CLK___4 = 638,
	FN_MSIOF1_SCK_E___3 = 639,
	FN_STP_OPWM_0_B___3 = 640,
	FN_IP4_23_20___4 = 641,
	FN_BS_N___4 = 642,
	FN_QSTVA_QVS___4 = 643,
	FN_MSIOF3_SCK_D___3 = 644,
	FN_SCK3___3 = 645,
	FN_HSCK3___3 = 646,
	FN_CAN1_TX___4 = 647,
	FN_CANFD1_TX___4 = 648,
	FN_IETX_A___3 = 649,
	FN_IP5_23_20___4 = 650,
	FN_D2___4 = 651,
	FN_MSIOF3_RXD_A___4 = 652,
	FN_VI4_DATA18___4 = 653,
	FN_VI5_DATA2___3 = 654,
	FN_IP6_23_20___4 = 655,
	FN_D10___4 = 656,
	FN_LCDOUT2___4 = 657,
	FN_MSIOF2_RXD_D___3 = 658,
	FN_HRX3_B___4 = 659,
	FN_VI4_DATA2_A___4 = 660,
	FN_CTS4_N_C___4 = 661,
	FN_DU_DR2___4 = 662,
	FN_IP7_23_20___4 = 663,
	FN_SD0_CMD___4 = 664,
	FN_MSIOF1_SYNC_E___3 = 665,
	FN_STP_IVCXO27_0_B___3 = 666,
	FN_IP4_27_24___4 = 667,
	FN_RD_N___4 = 668,
	FN_MSIOF3_SYNC_D___3 = 669,
	FN_RX3_A___4 = 670,
	FN_HRX3_A___4 = 671,
	FN_CAN0_TX_A___3 = 672,
	FN_CANFD0_TX_A___3 = 673,
	FN_IP5_27_24___4 = 674,
	FN_D3___4 = 675,
	FN_MSIOF3_TXD_A___4 = 676,
	FN_VI4_DATA19___4 = 677,
	FN_VI5_DATA3___3 = 678,
	FN_IP6_27_24___4 = 679,
	FN_D11___4 = 680,
	FN_LCDOUT3___4 = 681,
	FN_MSIOF2_TXD_D___3 = 682,
	FN_HTX3_B___4 = 683,
	FN_VI4_DATA3_A___4 = 684,
	FN_RTS4_N_C___4 = 685,
	FN_DU_DR3___4 = 686,
	FN_IP7_27_24___4 = 687,
	FN_SD0_DAT0___4 = 688,
	FN_MSIOF1_RXD_E___3 = 689,
	FN_TS_SCK0_B___3 = 690,
	FN_STP_ISCLK_0_B___3 = 691,
	FN_IP4_31_28___4 = 692,
	FN_RD_WR_N___4 = 693,
	FN_MSIOF3_RXD_D___3 = 694,
	FN_TX3_A___4 = 695,
	FN_HTX3_A___4 = 696,
	FN_CAN0_RX_A___3 = 697,
	FN_CANFD0_RX_A___3 = 698,
	FN_IP5_31_28___4 = 699,
	FN_D4___4 = 700,
	FN_MSIOF2_SCK_B___4 = 701,
	FN_VI4_DATA20___4 = 702,
	FN_VI5_DATA4___3 = 703,
	FN_IP6_31_28___4 = 704,
	FN_D12___4 = 705,
	FN_LCDOUT4___4 = 706,
	FN_MSIOF2_SS1_D___3 = 707,
	FN_RX4_C___4 = 708,
	FN_VI4_DATA4_A___4 = 709,
	FN_DU_DR4___4 = 710,
	FN_IP7_31_28___4 = 711,
	FN_SD0_DAT1___4 = 712,
	FN_MSIOF1_TXD_E___3 = 713,
	FN_TS_SPSYNC0_B___3 = 714,
	FN_STP_ISSYNC_0_B___3 = 715,
	FN_IP8_3_0___4 = 716,
	FN_SD0_DAT2___4 = 717,
	FN_MSIOF1_SS1_E___3 = 718,
	FN_TS_SDAT0_B___3 = 719,
	FN_STP_ISD_0_B___3 = 720,
	FN_IP9_3_0___4 = 721,
	FN_SD2_CLK___3 = 722,
	FN_NFDATA8___4 = 723,
	FN_IP10_3_0___4 = 724,
	FN_SD3_CMD___4 = 725,
	FN_NFRE_N___4 = 726,
	FN_IP11_3_0___4 = 727,
	FN_SD3_DAT7___4 = 728,
	FN_SD3_WP___4 = 729,
	FN_NFDATA7___4 = 730,
	FN_IP8_7_4___4 = 731,
	FN_SD0_DAT3___4 = 732,
	FN_MSIOF1_SS2_E___3 = 733,
	FN_TS_SDEN0_B___3 = 734,
	FN_STP_ISEN_0_B___3 = 735,
	FN_IP9_7_4___4 = 736,
	FN_SD2_CMD___3 = 737,
	FN_NFDATA9___4 = 738,
	FN_IP10_7_4___4 = 739,
	FN_SD3_DAT0___4 = 740,
	FN_NFDATA0___4 = 741,
	FN_IP11_7_4___4 = 742,
	FN_SD3_DS___4 = 743,
	FN_NFCLE___4 = 744,
	FN_IP8_11_8___4 = 745,
	FN_SD1_CLK___4 = 746,
	FN_MSIOF1_SCK_G___3 = 747,
	FN_SIM0_CLK_A___4 = 748,
	FN_IP9_11_8___4 = 749,
	FN_SD2_DAT0___3 = 750,
	FN_NFDATA10___4 = 751,
	FN_IP10_11_8___4 = 752,
	FN_SD3_DAT1___4 = 753,
	FN_NFDATA1___4 = 754,
	FN_IP11_11_8___4 = 755,
	FN_SD0_CD___4 = 756,
	FN_NFDATA14_A___4 = 757,
	FN_SCL2_B___4 = 758,
	FN_SIM0_RST_A___4 = 759,
	FN_IP8_15_12___4 = 760,
	FN_SD1_CMD___4 = 761,
	FN_MSIOF1_SYNC_G___3 = 762,
	FN_NFCE_N_B___4 = 763,
	FN_SIM0_D_A___4 = 764,
	FN_STP_IVCXO27_1_B___3 = 765,
	FN_IP9_15_12___4 = 766,
	FN_SD2_DAT1___3 = 767,
	FN_NFDATA11___4 = 768,
	FN_IP10_15_12___4 = 769,
	FN_SD3_DAT2___4 = 770,
	FN_NFDATA2___4 = 771,
	FN_IP11_15_12___4 = 772,
	FN_SD0_WP___4 = 773,
	FN_NFDATA15_A___4 = 774,
	FN_SDA2_B___4 = 775,
	FN_IP8_19_16___4 = 776,
	FN_SD1_DAT0___4 = 777,
	FN_SD2_DAT4___3 = 778,
	FN_MSIOF1_RXD_G___3 = 779,
	FN_NFWP_N_B___4 = 780,
	FN_TS_SCK1_B___3 = 781,
	FN_STP_ISCLK_1_B___3 = 782,
	FN_IP9_19_16___4 = 783,
	FN_SD2_DAT2___3 = 784,
	FN_NFDATA12___4 = 785,
	FN_IP10_19_16___4 = 786,
	FN_SD3_DAT3___4 = 787,
	FN_NFDATA3___4 = 788,
	FN_IP11_19_16___4 = 789,
	FN_SD1_CD___4 = 790,
	FN_NFRB_N_A___4 = 791,
	FN_SIM0_CLK_B___4 = 792,
	FN_IP8_23_20___4 = 793,
	FN_SD1_DAT1___4 = 794,
	FN_SD2_DAT5___3 = 795,
	FN_MSIOF1_TXD_G___3 = 796,
	FN_NFDATA14_B___4 = 797,
	FN_TS_SPSYNC1_B___3 = 798,
	FN_STP_ISSYNC_1_B___3 = 799,
	FN_IP9_23_20___4 = 800,
	FN_SD2_DAT3___3 = 801,
	FN_NFDATA13___4 = 802,
	FN_IP10_23_20___4 = 803,
	FN_SD3_DAT4___4 = 804,
	FN_SD2_CD_A___3 = 805,
	FN_NFDATA4___4 = 806,
	FN_IP11_23_20___4 = 807,
	FN_SD1_WP___4 = 808,
	FN_NFCE_N_A___4 = 809,
	FN_SIM0_D_B___4 = 810,
	FN_IP8_27_24___4 = 811,
	FN_SD1_DAT2___4 = 812,
	FN_SD2_DAT6___3 = 813,
	FN_MSIOF1_SS1_G___3 = 814,
	FN_NFDATA15_B___4 = 815,
	FN_TS_SDAT1_B___3 = 816,
	FN_STP_ISD_1_B___3 = 817,
	FN_IP9_27_24___4 = 818,
	FN_SD2_DS___3 = 819,
	FN_NFALE___3 = 820,
	FN_SATA_DEVSLP_B___2 = 821,
	FN_IP10_27_24___4 = 822,
	FN_SD3_DAT5___4 = 823,
	FN_SD2_WP_A___3 = 824,
	FN_NFDATA5___4 = 825,
	FN_IP11_27_24___4 = 826,
	FN_SCK0___3 = 827,
	FN_HSCK1_B___4 = 828,
	FN_MSIOF1_SS2_B___3 = 829,
	FN_AUDIO_CLKC_B___4 = 830,
	FN_SDA2_A___4 = 831,
	FN_SIM0_RST_B___4 = 832,
	FN_STP_OPWM_0_C___3 = 833,
	FN_RIF0_CLK_B___4 = 834,
	FN_ADICHS2___3 = 835,
	FN_SCK5_B___3 = 836,
	FN_IP8_31_28___4 = 837,
	FN_SD1_DAT3___4 = 838,
	FN_SD2_DAT7___3 = 839,
	FN_MSIOF1_SS2_G___3 = 840,
	FN_NFRB_N_B___4 = 841,
	FN_TS_SDEN1_B___3 = 842,
	FN_STP_ISEN_1_B___3 = 843,
	FN_IP9_31_28___4 = 844,
	FN_SD3_CLK___4 = 845,
	FN_NFWE_N___4 = 846,
	FN_IP10_31_28___4 = 847,
	FN_SD3_DAT6___4 = 848,
	FN_SD3_CD___4 = 849,
	FN_NFDATA6___4 = 850,
	FN_IP11_31_28___4 = 851,
	FN_RX0___3 = 852,
	FN_HRX1_B___4 = 853,
	FN_TS_SCK0_C___3 = 854,
	FN_STP_ISCLK_0_C___3 = 855,
	FN_RIF0_D0_B___4 = 856,
	FN_IP12_3_0___4 = 857,
	FN_TX0___3 = 858,
	FN_HTX1_B___4 = 859,
	FN_TS_SPSYNC0_C___3 = 860,
	FN_STP_ISSYNC_0_C___3 = 861,
	FN_RIF0_D1_B___4 = 862,
	FN_IP13_3_0___4 = 863,
	FN_TX2_A___4 = 864,
	FN_SD2_CD_B___3 = 865,
	FN_SCL1_A___4 = 866,
	FN_FMCLK_A___4 = 867,
	FN_RIF1_D1_C___3 = 868,
	FN_FSO_CFE_0_N___3 = 869,
	FN_IP14_3_0___4 = 870,
	FN_MSIOF0_SS1___4 = 871,
	FN_RX5_A___4 = 872,
	FN_NFWP_N_A___4 = 873,
	FN_AUDIO_CLKA_C___3 = 874,
	FN_SSI_SCK2_A___4 = 875,
	FN_STP_IVCXO27_0_C___3 = 876,
	FN_AUDIO_CLKOUT3_A___4 = 877,
	FN_TCLK1_B___4 = 878,
	FN_IP15_3_0___4 = 879,
	FN_SSI_SDATA1_A___3 = 880,
	FN_IP12_7_4___4 = 881,
	FN_CTS0_N___3 = 882,
	FN_HCTS1_N_B___4 = 883,
	FN_MSIOF1_SYNC_B___3 = 884,
	FN_TS_SPSYNC1_C___3 = 885,
	FN_STP_ISSYNC_1_C___3 = 886,
	FN_RIF1_SYNC_B___3 = 887,
	FN_AUDIO_CLKOUT_C___3 = 888,
	FN_ADICS_SAMP___3 = 889,
	FN_IP13_7_4___4 = 890,
	FN_RX2_A___4 = 891,
	FN_SD2_WP_B___3 = 892,
	FN_SDA1_A___4 = 893,
	FN_FMIN_A___4 = 894,
	FN_RIF1_SYNC_C___3 = 895,
	FN_FSO_CFE_1_N___3 = 896,
	FN_IP14_7_4___4 = 897,
	FN_MSIOF0_SS2___4 = 898,
	FN_TX5_A___4 = 899,
	FN_MSIOF1_SS2_D___3 = 900,
	FN_AUDIO_CLKC_A___4 = 901,
	FN_SSI_WS2_A___4 = 902,
	FN_STP_OPWM_0_D___3 = 903,
	FN_AUDIO_CLKOUT_D___3 = 904,
	FN_SPEEDIN_B___4 = 905,
	FN_IP15_7_4___4 = 906,
	FN_SSI_SDATA2_A___3 = 907,
	FN_SSI_SCK1_B___3 = 908,
	FN_IP12_11_8___4 = 909,
	FN_RTS0_N___3 = 910,
	FN_HRTS1_N_B___4 = 911,
	FN_MSIOF1_SS1_B___3 = 912,
	FN_AUDIO_CLKA_B___3 = 913,
	FN_SCL2_A___4 = 914,
	FN_STP_IVCXO27_1_C___3 = 915,
	FN_RIF0_SYNC_B___4 = 916,
	FN_ADICHS1___3 = 917,
	FN_IP13_11_8___4 = 918,
	FN_HSCK0___3 = 919,
	FN_MSIOF1_SCK_D___3 = 920,
	FN_AUDIO_CLKB_A___4 = 921,
	FN_SSI_SDATA1_B___3 = 922,
	FN_TS_SCK0_D___3 = 923,
	FN_STP_ISCLK_0_D___3 = 924,
	FN_RIF0_CLK_C___3 = 925,
	FN_RX5_B___4 = 926,
	FN_IP14_11_8___4 = 927,
	FN_MLB_CLK___4 = 928,
	FN_MSIOF1_SCK_F___3 = 929,
	FN_SCL1_B___4 = 930,
	FN_IP15_11_8___4 = 931,
	FN_SSI_SCK349___4 = 932,
	FN_MSIOF1_SS1_A___3 = 933,
	FN_STP_OPWM_0_A___3 = 934,
	FN_IP12_15_12___4 = 935,
	FN_RX1_A___3 = 936,
	FN_HRX1_A___4 = 937,
	FN_TS_SDAT0_C___3 = 938,
	FN_STP_ISD_0_C___3 = 939,
	FN_RIF1_CLK_C___3 = 940,
	FN_IP13_15_12___4 = 941,
	FN_HRX0___3 = 942,
	FN_MSIOF1_RXD_D___3 = 943,
	FN_SSI_SDATA2_B___3 = 944,
	FN_TS_SDEN0_D___3 = 945,
	FN_STP_ISEN_0_D___3 = 946,
	FN_RIF0_D0_C___3 = 947,
	FN_IP14_15_12___4 = 948,
	FN_MLB_SIG___4 = 949,
	FN_RX1_B___3 = 950,
	FN_MSIOF1_SYNC_F___3 = 951,
	FN_SDA1_B___4 = 952,
	FN_IP15_15_12___4 = 953,
	FN_SSI_WS349___4 = 954,
	FN_HCTS2_N_A___4 = 955,
	FN_MSIOF1_SS2_A___3 = 956,
	FN_STP_IVCXO27_0_A___3 = 957,
	FN_IP12_19_16___4 = 958,
	FN_TX1_A___3 = 959,
	FN_HTX1_A___4 = 960,
	FN_TS_SDEN0_C___3 = 961,
	FN_STP_ISEN_0_C___3 = 962,
	FN_RIF1_D0_C___3 = 963,
	FN_IP13_19_16___4 = 964,
	FN_HTX0___3 = 965,
	FN_MSIOF1_TXD_D___3 = 966,
	FN_SSI_SDATA9_B___3 = 967,
	FN_TS_SDAT0_D___3 = 968,
	FN_STP_ISD_0_D___3 = 969,
	FN_RIF0_D1_C___3 = 970,
	FN_IP14_19_16___4 = 971,
	FN_MLB_DAT___4 = 972,
	FN_TX1_B___3 = 973,
	FN_MSIOF1_RXD_F___3 = 974,
	FN_IP15_19_16___4 = 975,
	FN_SSI_SDATA3___4 = 976,
	FN_HRTS2_N_A___4 = 977,
	FN_MSIOF1_TXD_A___3 = 978,
	FN_TS_SCK0_A___3 = 979,
	FN_STP_ISCLK_0_A___3 = 980,
	FN_RIF0_D1_A___4 = 981,
	FN_RIF2_D0_A___4 = 982,
	FN_IP12_23_20___4 = 983,
	FN_CTS1_N___4 = 984,
	FN_HCTS1_N_A___3 = 985,
	FN_MSIOF1_RXD_B___3 = 986,
	FN_TS_SDEN1_C___3 = 987,
	FN_STP_ISEN_1_C___3 = 988,
	FN_RIF1_D0_B___3 = 989,
	FN_ADIDATA___3 = 990,
	FN_IP13_23_20___4 = 991,
	FN_HCTS0_N___3 = 992,
	FN_RX2_B___4 = 993,
	FN_MSIOF1_SYNC_D___3 = 994,
	FN_SSI_SCK9_A___4 = 995,
	FN_TS_SPSYNC0_D___3 = 996,
	FN_STP_ISSYNC_0_D___3 = 997,
	FN_RIF0_SYNC_C___3 = 998,
	FN_AUDIO_CLKOUT1_A___4 = 999,
	FN_IP14_23_20___4 = 1000,
	FN_SSI_SCK01239___4 = 1001,
	FN_MSIOF1_TXD_F___3 = 1002,
	FN_IP15_23_20___4 = 1003,
	FN_SSI_SCK4___4 = 1004,
	FN_HRX2_A___4 = 1005,
	FN_MSIOF1_SCK_A___3 = 1006,
	FN_TS_SDAT0_A___3 = 1007,
	FN_STP_ISD_0_A___3 = 1008,
	FN_RIF0_CLK_A___4 = 1009,
	FN_RIF2_CLK_A___4 = 1010,
	FN_IP12_27_24___4 = 1011,
	FN_RTS1_N___4 = 1012,
	FN_HRTS1_N_A___3 = 1013,
	FN_MSIOF1_TXD_B___3 = 1014,
	FN_TS_SDAT1_C___3 = 1015,
	FN_STP_ISD_1_C___3 = 1016,
	FN_RIF1_D1_B___3 = 1017,
	FN_ADICHS0___3 = 1018,
	FN_IP13_27_24___4 = 1019,
	FN_HRTS0_N___3 = 1020,
	FN_TX2_B___4 = 1021,
	FN_MSIOF1_SS1_D___3 = 1022,
	FN_SSI_WS9_A___4 = 1023,
	FN_STP_IVCXO27_0_D___3 = 1024,
	FN_BPFCLK_A___4 = 1025,
	FN_AUDIO_CLKOUT2_A___4 = 1026,
	FN_IP14_27_24___4 = 1027,
	FN_SSI_WS01239___4 = 1028,
	FN_MSIOF1_SS1_F___3 = 1029,
	FN_IP15_27_24___4 = 1030,
	FN_SSI_WS4___4 = 1031,
	FN_HTX2_A___4 = 1032,
	FN_MSIOF1_SYNC_A___3 = 1033,
	FN_TS_SDEN0_A___3 = 1034,
	FN_STP_ISEN_0_A___3 = 1035,
	FN_RIF0_SYNC_A___4 = 1036,
	FN_RIF2_SYNC_A___4 = 1037,
	FN_IP12_31_28___4 = 1038,
	FN_SCK2___3 = 1039,
	FN_SCIF_CLK_B___4 = 1040,
	FN_MSIOF1_SCK_B___3 = 1041,
	FN_TS_SCK1_C___3 = 1042,
	FN_STP_ISCLK_1_C___3 = 1043,
	FN_RIF1_CLK_B___3 = 1044,
	FN_ADICLK___3 = 1045,
	FN_IP13_31_28___4 = 1046,
	FN_MSIOF0_SYNC___4 = 1047,
	FN_AUDIO_CLKOUT_A___4 = 1048,
	FN_TX5_B___4 = 1049,
	FN_BPFCLK_D___3 = 1050,
	FN_IP14_31_28___4 = 1051,
	FN_SSI_SDATA0___4 = 1052,
	FN_MSIOF1_SS2_F___3 = 1053,
	FN_IP15_31_28___4 = 1054,
	FN_SSI_SDATA4___4 = 1055,
	FN_HSCK2_A___4 = 1056,
	FN_MSIOF1_RXD_A___3 = 1057,
	FN_TS_SPSYNC0_A___3 = 1058,
	FN_STP_ISSYNC_0_A___3 = 1059,
	FN_RIF0_D0_A___4 = 1060,
	FN_RIF2_D1_A___4 = 1061,
	FN_IP16_3_0___3 = 1062,
	FN_SSI_SCK6___4 = 1063,
	FN_USB2_PWEN = 1064,
	FN_SIM0_RST_D___3 = 1065,
	FN_IP17_3_0___3 = 1066,
	FN_AUDIO_CLKA_A___3 = 1067,
	FN_IP18_3_0___3 = 1068,
	FN_USB2_CH3_PWEN = 1069,
	FN_AUDIO_CLKOUT2_B___4 = 1070,
	FN_SSI_SCK9_B___4 = 1071,
	FN_TS_SDEN0_E___3 = 1072,
	FN_STP_ISEN_0_E___3 = 1073,
	FN_RIF2_D0_B___4 = 1074,
	FN_TPU0TO2___4 = 1075,
	FN_FMCLK_C___4 = 1076,
	FN_FMCLK_D___3 = 1077,
	FN_IP16_7_4___3 = 1078,
	FN_SSI_WS6___4 = 1079,
	FN_USB2_OVC = 1080,
	FN_SIM0_D_D___3 = 1081,
	FN_IP17_7_4___3 = 1082,
	FN_AUDIO_CLKB_B___4 = 1083,
	FN_SCIF_CLK_A___4 = 1084,
	FN_STP_IVCXO27_1_D___3 = 1085,
	FN_REMOCON_A___4 = 1086,
	FN_TCLK1_A___4 = 1087,
	FN_IP18_7_4___3 = 1088,
	FN_USB2_CH3_OVC = 1089,
	FN_AUDIO_CLKOUT3_B___4 = 1090,
	FN_SSI_WS9_B___4 = 1091,
	FN_TS_SPSYNC0_E___3 = 1092,
	FN_STP_ISSYNC_0_E___3 = 1093,
	FN_RIF2_D1_B___4 = 1094,
	FN_TPU0TO3___4 = 1095,
	FN_FMIN_C___4 = 1096,
	FN_FMIN_D___3 = 1097,
	FN_IP16_11_8___3 = 1098,
	FN_SSI_SDATA6___4 = 1099,
	FN_SIM0_CLK_D___3 = 1100,
	FN_SATA_DEVSLP_A___2 = 1101,
	FN_IP17_11_8___3 = 1102,
	FN_USB0_PWEN___3 = 1103,
	FN_SIM0_RST_C___3 = 1104,
	FN_TS_SCK1_D___3 = 1105,
	FN_STP_ISCLK_1_D___3 = 1106,
	FN_BPFCLK_B___4 = 1107,
	FN_RIF3_CLK_B___4 = 1108,
	FN_HSCK2_C___3 = 1109,
	FN_IP16_15_12___3 = 1110,
	FN_SSI_SCK78___4 = 1111,
	FN_HRX2_B___4 = 1112,
	FN_MSIOF1_SCK_C___3 = 1113,
	FN_TS_SCK1_A___3 = 1114,
	FN_STP_ISCLK_1_A___3 = 1115,
	FN_RIF1_CLK_A___3 = 1116,
	FN_RIF3_CLK_A___4 = 1117,
	FN_IP17_15_12___3 = 1118,
	FN_USB0_OVC___3 = 1119,
	FN_SIM0_D_C___3 = 1120,
	FN_TS_SDAT1_D___3 = 1121,
	FN_STP_ISD_1_D___3 = 1122,
	FN_RIF3_SYNC_B___4 = 1123,
	FN_HRX2_C___3 = 1124,
	FN_IP16_19_16___3 = 1125,
	FN_SSI_WS78___4 = 1126,
	FN_HTX2_B___4 = 1127,
	FN_MSIOF1_SYNC_C___3 = 1128,
	FN_TS_SDAT1_A___3 = 1129,
	FN_STP_ISD_1_A___3 = 1130,
	FN_RIF1_SYNC_A___3 = 1131,
	FN_RIF3_SYNC_A___4 = 1132,
	FN_IP17_19_16___3 = 1133,
	FN_USB1_PWEN___3 = 1134,
	FN_SIM0_CLK_C___3 = 1135,
	FN_SSI_SCK1_A___3 = 1136,
	FN_TS_SCK0_E___3 = 1137,
	FN_STP_ISCLK_0_E___3 = 1138,
	FN_FMCLK_B___4 = 1139,
	FN_RIF2_CLK_B___4 = 1140,
	FN_SPEEDIN_A___4 = 1141,
	FN_HTX2_C___3 = 1142,
	FN_IP16_23_20___3 = 1143,
	FN_SSI_SDATA7___4 = 1144,
	FN_HCTS2_N_B___3 = 1145,
	FN_MSIOF1_RXD_C___3 = 1146,
	FN_TS_SDEN1_A___3 = 1147,
	FN_STP_ISEN_1_A___3 = 1148,
	FN_RIF1_D0_A___3 = 1149,
	FN_RIF3_D0_A___4 = 1150,
	FN_TCLK2_A___4 = 1151,
	FN_IP17_23_20___3 = 1152,
	FN_USB1_OVC___3 = 1153,
	FN_MSIOF1_SS2_C___3 = 1154,
	FN_SSI_WS1_A___3 = 1155,
	FN_TS_SDAT0_E___3 = 1156,
	FN_STP_ISD_0_E___3 = 1157,
	FN_FMIN_B___4 = 1158,
	FN_RIF2_SYNC_B___4 = 1159,
	FN_REMOCON_B___4 = 1160,
	FN_HCTS2_N_C___3 = 1161,
	FN_IP16_27_24___3 = 1162,
	FN_SSI_SDATA8___4 = 1163,
	FN_HRTS2_N_B___3 = 1164,
	FN_MSIOF1_TXD_C___3 = 1165,
	FN_TS_SPSYNC1_A___3 = 1166,
	FN_STP_ISSYNC_1_A___3 = 1167,
	FN_RIF1_D1_A___3 = 1168,
	FN_RIF3_D1_A___4 = 1169,
	FN_IP17_27_24___3 = 1170,
	FN_USB30_PWEN___4 = 1171,
	FN_AUDIO_CLKOUT_B___4 = 1172,
	FN_SSI_SCK2_B___4 = 1173,
	FN_TS_SDEN1_D___3 = 1174,
	FN_STP_ISEN_1_D___3 = 1175,
	FN_STP_OPWM_0_E___3 = 1176,
	FN_RIF3_D0_B___4 = 1177,
	FN_TCLK2_B___4 = 1178,
	FN_TPU0TO0___4 = 1179,
	FN_BPFCLK_C___4 = 1180,
	FN_HRTS2_N_C___3 = 1181,
	FN_IP16_31_28___3 = 1182,
	FN_SSI_SDATA9_A___3 = 1183,
	FN_HSCK2_B___3 = 1184,
	FN_MSIOF1_SS1_C___3 = 1185,
	FN_HSCK1_A___4 = 1186,
	FN_SSI_WS1_B___3 = 1187,
	FN_SCK1___4 = 1188,
	FN_STP_IVCXO27_1_A___3 = 1189,
	FN_SCK5_A___4 = 1190,
	FN_IP17_31_28___3 = 1191,
	FN_USB30_OVC___4 = 1192,
	FN_AUDIO_CLKOUT1_B___4 = 1193,
	FN_SSI_WS2_B___4 = 1194,
	FN_TS_SPSYNC1_D___3 = 1195,
	FN_STP_ISSYNC_1_D___3 = 1196,
	FN_STP_IVCXO27_0_E___3 = 1197,
	FN_RIF3_D1_B___4 = 1198,
	FN_FSO_TOE_N___3 = 1199,
	FN_TPU0TO1___4 = 1200,
	FN_SEL_MSIOF3_0___4 = 1201,
	FN_SEL_MSIOF3_1___4 = 1202,
	FN_SEL_MSIOF3_2___3 = 1203,
	FN_SEL_MSIOF3_3___3 = 1204,
	FN_SEL_MSIOF3_4___3 = 1205,
	FN_SEL_TSIF1_0___3 = 1206,
	FN_SEL_TSIF1_1___3 = 1207,
	FN_SEL_TSIF1_2___3 = 1208,
	FN_SEL_TSIF1_3___3 = 1209,
	FN_I2C_SEL_5_0___3 = 1210,
	FN_I2C_SEL_5_1___3 = 1211,
	FN_I2C_SEL_3_0___3 = 1212,
	FN_I2C_SEL_3_1___3 = 1213,
	FN_SEL_TSIF0_0___3 = 1214,
	FN_SEL_TSIF0_1___3 = 1215,
	FN_SEL_TSIF0_2___3 = 1216,
	FN_SEL_TSIF0_3___3 = 1217,
	FN_SEL_TSIF0_4___3 = 1218,
	FN_I2C_SEL_0_0___3 = 1219,
	FN_I2C_SEL_0_1___3 = 1220,
	FN_SEL_MSIOF2_0___4 = 1221,
	FN_SEL_MSIOF2_1___4 = 1222,
	FN_SEL_MSIOF2_2___3 = 1223,
	FN_SEL_MSIOF2_3___3 = 1224,
	FN_SEL_FM_0___4 = 1225,
	FN_SEL_FM_1___4 = 1226,
	FN_SEL_FM_2___4 = 1227,
	FN_SEL_FM_3___3 = 1228,
	FN_SEL_MSIOF1_0___3 = 1229,
	FN_SEL_MSIOF1_1___3 = 1230,
	FN_SEL_MSIOF1_2___3 = 1231,
	FN_SEL_MSIOF1_3___3 = 1232,
	FN_SEL_MSIOF1_4___3 = 1233,
	FN_SEL_MSIOF1_5___3 = 1234,
	FN_SEL_MSIOF1_6___3 = 1235,
	FN_SEL_TIMER_TMU1_0 = 1236,
	FN_SEL_TIMER_TMU1_1 = 1237,
	FN_SEL_SCIF5_0___4 = 1238,
	FN_SEL_SCIF5_1___4 = 1239,
	FN_SEL_SSP1_1_0___3 = 1240,
	FN_SEL_SSP1_1_1___3 = 1241,
	FN_SEL_SSP1_1_2___3 = 1242,
	FN_SEL_SSP1_1_3___3 = 1243,
	FN_SEL_I2C6_0___4 = 1244,
	FN_SEL_I2C6_1___4 = 1245,
	FN_SEL_I2C6_2___3 = 1246,
	FN_SEL_LBSC_0___3 = 1247,
	FN_SEL_LBSC_1___3 = 1248,
	FN_SEL_SSP1_0_0___3 = 1249,
	FN_SEL_SSP1_0_1___3 = 1250,
	FN_SEL_SSP1_0_2___3 = 1251,
	FN_SEL_SSP1_0_3___3 = 1252,
	FN_SEL_SSP1_0_4___3 = 1253,
	FN_SEL_IEBUS_0___3 = 1254,
	FN_SEL_IEBUS_1___3 = 1255,
	FN_SEL_I2C2_0___4 = 1256,
	FN_SEL_I2C2_1___4 = 1257,
	FN_SEL_SSI2_0___4 = 1258,
	FN_SEL_SSI2_1___4 = 1259,
	FN_SEL_I2C1_0___4 = 1260,
	FN_SEL_I2C1_1___4 = 1261,
	FN_SEL_SSI1_0___3 = 1262,
	FN_SEL_SSI1_1___3 = 1263,
	FN_SEL_SSI9_0___4 = 1264,
	FN_SEL_SSI9_1___4 = 1265,
	FN_SEL_HSCIF4_0___4 = 1266,
	FN_SEL_HSCIF4_1___4 = 1267,
	FN_SEL_SPEED_PULSE_0___3 = 1268,
	FN_SEL_SPEED_PULSE_1___3 = 1269,
	FN_SEL_TIMER_TMU2_0___3 = 1270,
	FN_SEL_TIMER_TMU2_1___3 = 1271,
	FN_SEL_HSCIF3_0___4 = 1272,
	FN_SEL_HSCIF3_1___4 = 1273,
	FN_SEL_HSCIF3_2___4 = 1274,
	FN_SEL_HSCIF3_3___4 = 1275,
	FN_SEL_SIMCARD_0___4 = 1276,
	FN_SEL_SIMCARD_1___4 = 1277,
	FN_SEL_SIMCARD_2___3 = 1278,
	FN_SEL_SIMCARD_3___3 = 1279,
	FN_SEL_ADGB_0___4 = 1280,
	FN_SEL_ADGB_1___4 = 1281,
	FN_SEL_ADGC_0___4 = 1282,
	FN_SEL_ADGC_1___4 = 1283,
	FN_SEL_HSCIF1_0___4 = 1284,
	FN_SEL_HSCIF1_1___4 = 1285,
	FN_SEL_SDHI2_0___3 = 1286,
	FN_SEL_SDHI2_1___3 = 1287,
	FN_SEL_SCIF4_0___4 = 1288,
	FN_SEL_SCIF4_1___4 = 1289,
	FN_SEL_SCIF4_2___4 = 1290,
	FN_SEL_HSCIF2_0___4 = 1291,
	FN_SEL_HSCIF2_1___4 = 1292,
	FN_SEL_HSCIF2_2___3 = 1293,
	FN_SEL_SCIF3_0___4 = 1294,
	FN_SEL_SCIF3_1___4 = 1295,
	FN_SEL_ETHERAVB_0___3 = 1296,
	FN_SEL_ETHERAVB_1___3 = 1297,
	FN_SEL_SCIF2_0___4 = 1298,
	FN_SEL_SCIF2_1___4 = 1299,
	FN_SEL_DRIF3_0___4 = 1300,
	FN_SEL_DRIF3_1___4 = 1301,
	FN_SEL_SCIF1_0___3 = 1302,
	FN_SEL_SCIF1_1___3 = 1303,
	FN_SEL_DRIF2_0___4 = 1304,
	FN_SEL_DRIF2_1___4 = 1305,
	FN_SEL_SCIF_0___4 = 1306,
	FN_SEL_SCIF_1___4 = 1307,
	FN_SEL_DRIF1_0___3 = 1308,
	FN_SEL_DRIF1_1___3 = 1309,
	FN_SEL_DRIF1_2___3 = 1310,
	FN_SEL_REMOCON_0___4 = 1311,
	FN_SEL_REMOCON_1___4 = 1312,
	FN_SEL_DRIF0_0___4 = 1313,
	FN_SEL_DRIF0_1___4 = 1314,
	FN_SEL_DRIF0_2___3 = 1315,
	FN_SEL_RCAN0_0___3 = 1316,
	FN_SEL_RCAN0_1___3 = 1317,
	FN_SEL_CANFD0_0___3 = 1318,
	FN_SEL_CANFD0_1___3 = 1319,
	FN_SEL_PWM6_0___4 = 1320,
	FN_SEL_PWM6_1___4 = 1321,
	FN_SEL_ADGA_0___3 = 1322,
	FN_SEL_ADGA_1___3 = 1323,
	FN_SEL_ADGA_2___3 = 1324,
	FN_SEL_ADGA_3___3 = 1325,
	FN_SEL_PWM5_0___4 = 1326,
	FN_SEL_PWM5_1___4 = 1327,
	FN_SEL_PWM4_0___4 = 1328,
	FN_SEL_PWM4_1___4 = 1329,
	FN_SEL_PWM3_0___4 = 1330,
	FN_SEL_PWM3_1___4 = 1331,
	FN_SEL_PWM2_0___4 = 1332,
	FN_SEL_PWM2_1___4 = 1333,
	FN_SEL_PWM1_0___4 = 1334,
	FN_SEL_PWM1_1___4 = 1335,
	FN_SEL_VIN4_0___4 = 1336,
	FN_SEL_VIN4_1___4 = 1337,
	PINMUX_FUNCTION_END___4 = 1338,
	PINMUX_MARK_BEGIN___4 = 1339,
	CLKOUT_MARK___4 = 1340,
	MSIOF0_RXD_MARK___4 = 1341,
	MSIOF0_TXD_MARK___4 = 1342,
	MSIOF0_SCK_MARK___4 = 1343,
	SSI_SDATA5_MARK___4 = 1344,
	SSI_WS5_MARK___4 = 1345,
	SSI_SCK5_MARK___4 = 1346,
	GP7_03_MARK___3 = 1347,
	GP7_02_MARK___3 = 1348,
	AVS2_MARK___3 = 1349,
	AVS1_MARK___3 = 1350,
	IP0_3_0_MARK___4 = 1351,
	AVB_MDC_MARK___4 = 1352,
	MSIOF2_SS2_C_MARK___3 = 1353,
	IP1_3_0_MARK___4 = 1354,
	IRQ2_MARK___4 = 1355,
	QCPV_QDE_MARK___4 = 1356,
	DU_EXODDF_DU_ODDF_DISP_CDE_MARK___3 = 1357,
	VI4_DATA2_B_MARK___4 = 1358,
	MSIOF3_SYNC_E_MARK___3 = 1359,
	PWM3_B_MARK___4 = 1360,
	IP2_3_0_MARK___4 = 1361,
	A1_MARK___4 = 1362,
	LCDOUT17_MARK___4 = 1363,
	MSIOF3_TXD_B_MARK___4 = 1364,
	VI4_DATA9_MARK___4 = 1365,
	DU_DB1_MARK___4 = 1366,
	PWM4_A_MARK___4 = 1367,
	IP3_3_0_MARK___4 = 1368,
	A9_MARK___4 = 1369,
	MSIOF2_SCK_A_MARK___4 = 1370,
	CTS4_N_B_MARK___3 = 1371,
	VI5_VSYNC_N_MARK___3 = 1372,
	IP0_7_4_MARK___4 = 1373,
	AVB_MAGIC_MARK___4 = 1374,
	MSIOF2_SS1_C_MARK___3 = 1375,
	SCK4_A_MARK___4 = 1376,
	IP1_7_4_MARK___4 = 1377,
	IRQ3_MARK___4 = 1378,
	QSTVB_QVE_MARK___4 = 1379,
	DU_DOTCLKOUT1_MARK___3 = 1380,
	VI4_DATA3_B_MARK___4 = 1381,
	MSIOF3_SCK_E_MARK___3 = 1382,
	PWM4_B_MARK___4 = 1383,
	IP2_7_4_MARK___4 = 1384,
	A2_MARK___4 = 1385,
	LCDOUT18_MARK___4 = 1386,
	MSIOF3_SCK_B_MARK___4 = 1387,
	VI4_DATA10_MARK___4 = 1388,
	DU_DB2_MARK___4 = 1389,
	PWM5_A_MARK___4 = 1390,
	IP3_7_4_MARK___4 = 1391,
	A10_MARK___4 = 1392,
	MSIOF2_RXD_A_MARK___4 = 1393,
	RTS4_N_B_MARK___3 = 1394,
	VI5_HSYNC_N_MARK___3 = 1395,
	IP0_11_8_MARK___4 = 1396,
	AVB_PHY_INT_MARK___4 = 1397,
	MSIOF2_SYNC_C_MARK___3 = 1398,
	RX4_A_MARK___4 = 1399,
	IP1_11_8_MARK___4 = 1400,
	IRQ4_MARK___4 = 1401,
	QSTH_QHS_MARK___4 = 1402,
	DU_EXHSYNC_DU_HSYNC_MARK___3 = 1403,
	VI4_DATA4_B_MARK___4 = 1404,
	MSIOF3_RXD_E_MARK___3 = 1405,
	PWM5_B_MARK___4 = 1406,
	IP2_11_8_MARK___4 = 1407,
	A3_MARK___4 = 1408,
	LCDOUT19_MARK___4 = 1409,
	MSIOF3_RXD_B_MARK___4 = 1410,
	VI4_DATA11_MARK___4 = 1411,
	DU_DB3_MARK___4 = 1412,
	PWM6_A_MARK___4 = 1413,
	IP3_11_8_MARK___4 = 1414,
	A11_MARK___4 = 1415,
	TX3_B_MARK___4 = 1416,
	MSIOF2_TXD_A_MARK___4 = 1417,
	HTX4_B_MARK___4 = 1418,
	HSCK4_MARK___3 = 1419,
	VI5_FIELD_MARK___3 = 1420,
	SCL6_A_MARK___4 = 1421,
	AVB_AVTP_CAPTURE_B_MARK___3 = 1422,
	PWM2_B_MARK___4 = 1423,
	IP0_15_12_MARK___4 = 1424,
	AVB_LINK_MARK___4 = 1425,
	MSIOF2_SCK_C_MARK___3 = 1426,
	TX4_A_MARK___4 = 1427,
	IP1_15_12_MARK___4 = 1428,
	IRQ5_MARK___4 = 1429,
	QSTB_QHE_MARK___4 = 1430,
	DU_EXVSYNC_DU_VSYNC_MARK___3 = 1431,
	VI4_DATA5_B_MARK___4 = 1432,
	FSCLKST2_N_B_MARK___3 = 1433,
	MSIOF3_TXD_E_MARK___3 = 1434,
	PWM6_B_MARK___4 = 1435,
	IP2_15_12_MARK___4 = 1436,
	A4_MARK___4 = 1437,
	LCDOUT20_MARK___4 = 1438,
	MSIOF3_SS1_B_MARK___4 = 1439,
	VI4_DATA12_MARK___4 = 1440,
	VI5_DATA12_MARK___3 = 1441,
	DU_DB4_MARK___4 = 1442,
	IP3_15_12_MARK___4 = 1443,
	A12_MARK___4 = 1444,
	LCDOUT12_MARK___4 = 1445,
	MSIOF3_SCK_C_MARK___3 = 1446,
	HRX4_A_MARK___4 = 1447,
	VI5_DATA8_MARK___3 = 1448,
	DU_DG4_MARK___4 = 1449,
	IP0_19_16_MARK___4 = 1450,
	AVB_AVTP_MATCH_A_MARK___3 = 1451,
	MSIOF2_RXD_C_MARK___3 = 1452,
	CTS4_N_A_MARK___4 = 1453,
	FSCLKST2_N_A_MARK___3 = 1454,
	IP1_19_16_MARK___4 = 1455,
	PWM0_MARK___3 = 1456,
	AVB_AVTP_PPS_MARK___4 = 1457,
	VI4_DATA6_B_MARK___4 = 1458,
	IECLK_B_MARK___3 = 1459,
	IP2_19_16_MARK___4 = 1460,
	A5_MARK___4 = 1461,
	LCDOUT21_MARK___4 = 1462,
	MSIOF3_SS2_B_MARK___3 = 1463,
	SCK4_B_MARK___4 = 1464,
	VI4_DATA13_MARK___4 = 1465,
	VI5_DATA13_MARK___3 = 1466,
	DU_DB5_MARK___4 = 1467,
	IP3_19_16_MARK___4 = 1468,
	A13_MARK___4 = 1469,
	LCDOUT13_MARK___4 = 1470,
	MSIOF3_SYNC_C_MARK___3 = 1471,
	HTX4_A_MARK___4 = 1472,
	VI5_DATA9_MARK___3 = 1473,
	DU_DG5_MARK___4 = 1474,
	IP0_23_20_MARK___4 = 1475,
	AVB_AVTP_CAPTURE_A_MARK___3 = 1476,
	MSIOF2_TXD_C_MARK___3 = 1477,
	RTS4_N_A_MARK___4 = 1478,
	IP1_23_20_MARK___4 = 1479,
	PWM1_A_MARK___4 = 1480,
	HRX3_D_MARK___4 = 1481,
	VI4_DATA7_B_MARK___4 = 1482,
	IERX_B_MARK___3 = 1483,
	IP2_23_20_MARK___4 = 1484,
	A6_MARK___4 = 1485,
	LCDOUT22_MARK___4 = 1486,
	MSIOF2_SS1_A_MARK___4 = 1487,
	RX4_B_MARK___4 = 1488,
	VI4_DATA14_MARK___4 = 1489,
	VI5_DATA14_MARK___3 = 1490,
	DU_DB6_MARK___4 = 1491,
	IP3_23_20_MARK___4 = 1492,
	A14_MARK___4 = 1493,
	LCDOUT14_MARK___4 = 1494,
	MSIOF3_RXD_C_MARK___3 = 1495,
	HCTS4_N_MARK___3 = 1496,
	VI5_DATA10_MARK___3 = 1497,
	DU_DG6_MARK___4 = 1498,
	IP0_27_24_MARK___4 = 1499,
	IRQ0_MARK___4 = 1500,
	QPOLB_MARK___4 = 1501,
	DU_CDE_MARK___4 = 1502,
	VI4_DATA0_B_MARK___4 = 1503,
	CAN0_TX_B_MARK___3 = 1504,
	CANFD0_TX_B_MARK___3 = 1505,
	MSIOF3_SS2_E_MARK___3 = 1506,
	IP1_27_24_MARK___4 = 1507,
	PWM2_A_MARK___4 = 1508,
	HTX3_D_MARK___4 = 1509,
	IETX_B_MARK___3 = 1510,
	IP2_27_24_MARK___4 = 1511,
	A7_MARK___4 = 1512,
	LCDOUT23_MARK___4 = 1513,
	MSIOF2_SS2_A_MARK___4 = 1514,
	TX4_B_MARK___4 = 1515,
	VI4_DATA15_MARK___4 = 1516,
	VI5_DATA15_MARK___3 = 1517,
	DU_DB7_MARK___4 = 1518,
	IP3_27_24_MARK___4 = 1519,
	A15_MARK___4 = 1520,
	LCDOUT15_MARK___4 = 1521,
	MSIOF3_TXD_C_MARK___3 = 1522,
	HRTS4_N_MARK___3 = 1523,
	VI5_DATA11_MARK___3 = 1524,
	DU_DG7_MARK___4 = 1525,
	IP0_31_28_MARK___4 = 1526,
	IRQ1_MARK___4 = 1527,
	QPOLA_MARK___4 = 1528,
	DU_DISP_MARK___4 = 1529,
	VI4_DATA1_B_MARK___4 = 1530,
	CAN0_RX_B_MARK___3 = 1531,
	CANFD0_RX_B_MARK___3 = 1532,
	MSIOF3_SS1_E_MARK___3 = 1533,
	IP1_31_28_MARK___4 = 1534,
	A0_MARK___4 = 1535,
	LCDOUT16_MARK___4 = 1536,
	MSIOF3_SYNC_B_MARK___4 = 1537,
	VI4_DATA8_MARK___4 = 1538,
	DU_DB0_MARK___4 = 1539,
	PWM3_A_MARK___4 = 1540,
	IP2_31_28_MARK___4 = 1541,
	A8_MARK___4 = 1542,
	RX3_B_MARK___4 = 1543,
	MSIOF2_SYNC_A_MARK___4 = 1544,
	HRX4_B_MARK___4 = 1545,
	SDA6_A_MARK___4 = 1546,
	AVB_AVTP_MATCH_B_MARK___3 = 1547,
	PWM1_B_MARK___4 = 1548,
	IP3_31_28_MARK___4 = 1549,
	A16_MARK___4 = 1550,
	LCDOUT8_MARK___4 = 1551,
	VI4_FIELD_MARK___4 = 1552,
	DU_DG0_MARK___4 = 1553,
	IP4_3_0_MARK___4 = 1554,
	A17_MARK___4 = 1555,
	LCDOUT9_MARK___4 = 1556,
	VI4_VSYNC_N_MARK___4 = 1557,
	DU_DG1_MARK___4 = 1558,
	IP5_3_0_MARK___4 = 1559,
	WE0_N_MARK___4 = 1560,
	MSIOF3_TXD_D_MARK___3 = 1561,
	CTS3_N_MARK___3 = 1562,
	HCTS3_N_MARK___3 = 1563,
	SCL6_B_MARK___4 = 1564,
	CAN_CLK_MARK___4 = 1565,
	IECLK_A_MARK___3 = 1566,
	IP6_3_0_MARK___4 = 1567,
	D5_MARK___4 = 1568,
	MSIOF2_SYNC_B_MARK___4 = 1569,
	VI4_DATA21_MARK___4 = 1570,
	VI5_DATA5_MARK___3 = 1571,
	IP7_3_0_MARK___4 = 1572,
	D13_MARK___4 = 1573,
	LCDOUT5_MARK___4 = 1574,
	MSIOF2_SS2_D_MARK___3 = 1575,
	TX4_C_MARK___4 = 1576,
	VI4_DATA5_A_MARK___4 = 1577,
	DU_DR5_MARK___4 = 1578,
	IP4_7_4_MARK___4 = 1579,
	A18_MARK___4 = 1580,
	LCDOUT10_MARK___4 = 1581,
	VI4_HSYNC_N_MARK___4 = 1582,
	DU_DG2_MARK___4 = 1583,
	IP5_7_4_MARK___4 = 1584,
	WE1_N_MARK___4 = 1585,
	MSIOF3_SS1_D_MARK___3 = 1586,
	RTS3_N_MARK___3 = 1587,
	HRTS3_N_MARK___3 = 1588,
	SDA6_B_MARK___4 = 1589,
	CAN1_RX_MARK___4 = 1590,
	CANFD1_RX_MARK___4 = 1591,
	IERX_A_MARK___3 = 1592,
	IP6_7_4_MARK___4 = 1593,
	D6_MARK___4 = 1594,
	MSIOF2_RXD_B_MARK___4 = 1595,
	VI4_DATA22_MARK___4 = 1596,
	VI5_DATA6_MARK___3 = 1597,
	IP7_7_4_MARK___4 = 1598,
	D14_MARK___4 = 1599,
	LCDOUT6_MARK___4 = 1600,
	MSIOF3_SS1_A_MARK___4 = 1601,
	HRX3_C_MARK___4 = 1602,
	VI4_DATA6_A_MARK___4 = 1603,
	DU_DR6_MARK___4 = 1604,
	SCL6_C_MARK___3 = 1605,
	IP4_11_8_MARK___4 = 1606,
	A19_MARK___4 = 1607,
	LCDOUT11_MARK___4 = 1608,
	VI4_CLKENB_MARK___4 = 1609,
	DU_DG3_MARK___4 = 1610,
	IP5_11_8_MARK___4 = 1611,
	EX_WAIT0_A_MARK___3 = 1612,
	QCLK_MARK___4 = 1613,
	VI4_CLK_MARK___4 = 1614,
	DU_DOTCLKOUT0_MARK___4 = 1615,
	IP6_11_8_MARK___4 = 1616,
	D7_MARK___4 = 1617,
	MSIOF2_TXD_B_MARK___4 = 1618,
	VI4_DATA23_MARK___4 = 1619,
	VI5_DATA7_MARK___3 = 1620,
	IP7_11_8_MARK___4 = 1621,
	D15_MARK___4 = 1622,
	LCDOUT7_MARK___4 = 1623,
	MSIOF3_SS2_A_MARK___4 = 1624,
	HTX3_C_MARK___4 = 1625,
	VI4_DATA7_A_MARK___4 = 1626,
	DU_DR7_MARK___4 = 1627,
	SDA6_C_MARK___3 = 1628,
	IP4_15_12_MARK___4 = 1629,
	CS0_N_MARK___4 = 1630,
	VI5_CLKENB_MARK___3 = 1631,
	IP5_15_12_MARK___4 = 1632,
	D0_MARK___4 = 1633,
	MSIOF2_SS1_B_MARK___4 = 1634,
	MSIOF3_SCK_A_MARK___4 = 1635,
	VI4_DATA16_MARK___4 = 1636,
	VI5_DATA0_MARK___3 = 1637,
	IP6_15_12_MARK___4 = 1638,
	D8_MARK___4 = 1639,
	LCDOUT0_MARK___4 = 1640,
	MSIOF2_SCK_D_MARK___3 = 1641,
	SCK4_C_MARK___3 = 1642,
	VI4_DATA0_A_MARK___4 = 1643,
	DU_DR0_MARK___4 = 1644,
	IP4_19_16_MARK___4 = 1645,
	CS1_N_MARK___3 = 1646,
	VI5_CLK_MARK___3 = 1647,
	EX_WAIT0_B_MARK___3 = 1648,
	IP5_19_16_MARK___4 = 1649,
	D1_MARK___4 = 1650,
	MSIOF2_SS2_B_MARK___4 = 1651,
	MSIOF3_SYNC_A_MARK___4 = 1652,
	VI4_DATA17_MARK___4 = 1653,
	VI5_DATA1_MARK___3 = 1654,
	IP6_19_16_MARK___4 = 1655,
	D9_MARK___4 = 1656,
	LCDOUT1_MARK___4 = 1657,
	MSIOF2_SYNC_D_MARK___3 = 1658,
	VI4_DATA1_A_MARK___4 = 1659,
	DU_DR1_MARK___4 = 1660,
	IP7_19_16_MARK___4 = 1661,
	SD0_CLK_MARK___4 = 1662,
	MSIOF1_SCK_E_MARK___3 = 1663,
	STP_OPWM_0_B_MARK___3 = 1664,
	IP4_23_20_MARK___4 = 1665,
	BS_N_MARK___4 = 1666,
	QSTVA_QVS_MARK___4 = 1667,
	MSIOF3_SCK_D_MARK___3 = 1668,
	SCK3_MARK___3 = 1669,
	HSCK3_MARK___3 = 1670,
	CAN1_TX_MARK___4 = 1671,
	CANFD1_TX_MARK___4 = 1672,
	IETX_A_MARK___3 = 1673,
	IP5_23_20_MARK___4 = 1674,
	D2_MARK___4 = 1675,
	MSIOF3_RXD_A_MARK___4 = 1676,
	VI4_DATA18_MARK___4 = 1677,
	VI5_DATA2_MARK___3 = 1678,
	IP6_23_20_MARK___4 = 1679,
	D10_MARK___4 = 1680,
	LCDOUT2_MARK___4 = 1681,
	MSIOF2_RXD_D_MARK___3 = 1682,
	HRX3_B_MARK___4 = 1683,
	VI4_DATA2_A_MARK___4 = 1684,
	CTS4_N_C_MARK___4 = 1685,
	DU_DR2_MARK___4 = 1686,
	IP7_23_20_MARK___4 = 1687,
	SD0_CMD_MARK___4 = 1688,
	MSIOF1_SYNC_E_MARK___3 = 1689,
	STP_IVCXO27_0_B_MARK___3 = 1690,
	IP4_27_24_MARK___4 = 1691,
	RD_N_MARK___4 = 1692,
	MSIOF3_SYNC_D_MARK___3 = 1693,
	RX3_A_MARK___4 = 1694,
	HRX3_A_MARK___4 = 1695,
	CAN0_TX_A_MARK___3 = 1696,
	CANFD0_TX_A_MARK___3 = 1697,
	IP5_27_24_MARK___4 = 1698,
	D3_MARK___4 = 1699,
	MSIOF3_TXD_A_MARK___4 = 1700,
	VI4_DATA19_MARK___4 = 1701,
	VI5_DATA3_MARK___3 = 1702,
	IP6_27_24_MARK___4 = 1703,
	D11_MARK___4 = 1704,
	LCDOUT3_MARK___4 = 1705,
	MSIOF2_TXD_D_MARK___3 = 1706,
	HTX3_B_MARK___4 = 1707,
	VI4_DATA3_A_MARK___4 = 1708,
	RTS4_N_C_MARK___4 = 1709,
	DU_DR3_MARK___4 = 1710,
	IP7_27_24_MARK___4 = 1711,
	SD0_DAT0_MARK___4 = 1712,
	MSIOF1_RXD_E_MARK___3 = 1713,
	TS_SCK0_B_MARK___3 = 1714,
	STP_ISCLK_0_B_MARK___3 = 1715,
	IP4_31_28_MARK___4 = 1716,
	RD_WR_N_MARK___4 = 1717,
	MSIOF3_RXD_D_MARK___3 = 1718,
	TX3_A_MARK___4 = 1719,
	HTX3_A_MARK___4 = 1720,
	CAN0_RX_A_MARK___3 = 1721,
	CANFD0_RX_A_MARK___3 = 1722,
	IP5_31_28_MARK___4 = 1723,
	D4_MARK___4 = 1724,
	MSIOF2_SCK_B_MARK___4 = 1725,
	VI4_DATA20_MARK___4 = 1726,
	VI5_DATA4_MARK___3 = 1727,
	IP6_31_28_MARK___4 = 1728,
	D12_MARK___4 = 1729,
	LCDOUT4_MARK___4 = 1730,
	MSIOF2_SS1_D_MARK___3 = 1731,
	RX4_C_MARK___4 = 1732,
	VI4_DATA4_A_MARK___4 = 1733,
	DU_DR4_MARK___4 = 1734,
	IP7_31_28_MARK___4 = 1735,
	SD0_DAT1_MARK___4 = 1736,
	MSIOF1_TXD_E_MARK___3 = 1737,
	TS_SPSYNC0_B_MARK___3 = 1738,
	STP_ISSYNC_0_B_MARK___3 = 1739,
	IP8_3_0_MARK___4 = 1740,
	SD0_DAT2_MARK___4 = 1741,
	MSIOF1_SS1_E_MARK___3 = 1742,
	TS_SDAT0_B_MARK___3 = 1743,
	STP_ISD_0_B_MARK___3 = 1744,
	IP9_3_0_MARK___4 = 1745,
	SD2_CLK_MARK___3 = 1746,
	NFDATA8_MARK___4 = 1747,
	IP10_3_0_MARK___4 = 1748,
	SD3_CMD_MARK___4 = 1749,
	NFRE_N_MARK___4 = 1750,
	IP11_3_0_MARK___4 = 1751,
	SD3_DAT7_MARK___4 = 1752,
	SD3_WP_MARK___4 = 1753,
	NFDATA7_MARK___4 = 1754,
	IP8_7_4_MARK___4 = 1755,
	SD0_DAT3_MARK___4 = 1756,
	MSIOF1_SS2_E_MARK___3 = 1757,
	TS_SDEN0_B_MARK___3 = 1758,
	STP_ISEN_0_B_MARK___3 = 1759,
	IP9_7_4_MARK___4 = 1760,
	SD2_CMD_MARK___3 = 1761,
	NFDATA9_MARK___4 = 1762,
	IP10_7_4_MARK___4 = 1763,
	SD3_DAT0_MARK___4 = 1764,
	NFDATA0_MARK___4 = 1765,
	IP11_7_4_MARK___4 = 1766,
	SD3_DS_MARK___4 = 1767,
	NFCLE_MARK___4 = 1768,
	IP8_11_8_MARK___4 = 1769,
	SD1_CLK_MARK___4 = 1770,
	MSIOF1_SCK_G_MARK___3 = 1771,
	SIM0_CLK_A_MARK___4 = 1772,
	IP9_11_8_MARK___4 = 1773,
	SD2_DAT0_MARK___3 = 1774,
	NFDATA10_MARK___4 = 1775,
	IP10_11_8_MARK___4 = 1776,
	SD3_DAT1_MARK___4 = 1777,
	NFDATA1_MARK___4 = 1778,
	IP11_11_8_MARK___4 = 1779,
	SD0_CD_MARK___4 = 1780,
	NFDATA14_A_MARK___4 = 1781,
	SCL2_B_MARK___4 = 1782,
	SIM0_RST_A_MARK___4 = 1783,
	IP8_15_12_MARK___4 = 1784,
	SD1_CMD_MARK___4 = 1785,
	MSIOF1_SYNC_G_MARK___3 = 1786,
	NFCE_N_B_MARK___4 = 1787,
	SIM0_D_A_MARK___4 = 1788,
	STP_IVCXO27_1_B_MARK___3 = 1789,
	IP9_15_12_MARK___4 = 1790,
	SD2_DAT1_MARK___3 = 1791,
	NFDATA11_MARK___4 = 1792,
	IP10_15_12_MARK___4 = 1793,
	SD3_DAT2_MARK___4 = 1794,
	NFDATA2_MARK___4 = 1795,
	IP11_15_12_MARK___4 = 1796,
	SD0_WP_MARK___4 = 1797,
	NFDATA15_A_MARK___4 = 1798,
	SDA2_B_MARK___4 = 1799,
	IP8_19_16_MARK___4 = 1800,
	SD1_DAT0_MARK___4 = 1801,
	SD2_DAT4_MARK___3 = 1802,
	MSIOF1_RXD_G_MARK___3 = 1803,
	NFWP_N_B_MARK___4 = 1804,
	TS_SCK1_B_MARK___3 = 1805,
	STP_ISCLK_1_B_MARK___3 = 1806,
	IP9_19_16_MARK___4 = 1807,
	SD2_DAT2_MARK___3 = 1808,
	NFDATA12_MARK___4 = 1809,
	IP10_19_16_MARK___4 = 1810,
	SD3_DAT3_MARK___4 = 1811,
	NFDATA3_MARK___4 = 1812,
	IP11_19_16_MARK___4 = 1813,
	SD1_CD_MARK___4 = 1814,
	NFRB_N_A_MARK___4 = 1815,
	SIM0_CLK_B_MARK___4 = 1816,
	IP8_23_20_MARK___4 = 1817,
	SD1_DAT1_MARK___4 = 1818,
	SD2_DAT5_MARK___3 = 1819,
	MSIOF1_TXD_G_MARK___3 = 1820,
	NFDATA14_B_MARK___4 = 1821,
	TS_SPSYNC1_B_MARK___3 = 1822,
	STP_ISSYNC_1_B_MARK___3 = 1823,
	IP9_23_20_MARK___4 = 1824,
	SD2_DAT3_MARK___3 = 1825,
	NFDATA13_MARK___4 = 1826,
	IP10_23_20_MARK___4 = 1827,
	SD3_DAT4_MARK___4 = 1828,
	SD2_CD_A_MARK___3 = 1829,
	NFDATA4_MARK___4 = 1830,
	IP11_23_20_MARK___4 = 1831,
	SD1_WP_MARK___4 = 1832,
	NFCE_N_A_MARK___4 = 1833,
	SIM0_D_B_MARK___4 = 1834,
	IP8_27_24_MARK___4 = 1835,
	SD1_DAT2_MARK___4 = 1836,
	SD2_DAT6_MARK___3 = 1837,
	MSIOF1_SS1_G_MARK___3 = 1838,
	NFDATA15_B_MARK___4 = 1839,
	TS_SDAT1_B_MARK___3 = 1840,
	STP_ISD_1_B_MARK___3 = 1841,
	IP9_27_24_MARK___4 = 1842,
	SD2_DS_MARK___3 = 1843,
	NFALE_MARK___3 = 1844,
	SATA_DEVSLP_B_MARK___2 = 1845,
	IP10_27_24_MARK___4 = 1846,
	SD3_DAT5_MARK___4 = 1847,
	SD2_WP_A_MARK___3 = 1848,
	NFDATA5_MARK___4 = 1849,
	IP11_27_24_MARK___4 = 1850,
	SCK0_MARK___3 = 1851,
	HSCK1_B_MARK___4 = 1852,
	MSIOF1_SS2_B_MARK___3 = 1853,
	AUDIO_CLKC_B_MARK___4 = 1854,
	SDA2_A_MARK___4 = 1855,
	SIM0_RST_B_MARK___4 = 1856,
	STP_OPWM_0_C_MARK___3 = 1857,
	RIF0_CLK_B_MARK___4 = 1858,
	ADICHS2_MARK___3 = 1859,
	SCK5_B_MARK___3 = 1860,
	IP8_31_28_MARK___4 = 1861,
	SD1_DAT3_MARK___4 = 1862,
	SD2_DAT7_MARK___3 = 1863,
	MSIOF1_SS2_G_MARK___3 = 1864,
	NFRB_N_B_MARK___4 = 1865,
	TS_SDEN1_B_MARK___3 = 1866,
	STP_ISEN_1_B_MARK___3 = 1867,
	IP9_31_28_MARK___4 = 1868,
	SD3_CLK_MARK___4 = 1869,
	NFWE_N_MARK___4 = 1870,
	IP10_31_28_MARK___4 = 1871,
	SD3_DAT6_MARK___4 = 1872,
	SD3_CD_MARK___4 = 1873,
	NFDATA6_MARK___4 = 1874,
	IP11_31_28_MARK___4 = 1875,
	RX0_MARK___3 = 1876,
	HRX1_B_MARK___4 = 1877,
	TS_SCK0_C_MARK___3 = 1878,
	STP_ISCLK_0_C_MARK___3 = 1879,
	RIF0_D0_B_MARK___4 = 1880,
	IP12_3_0_MARK___4 = 1881,
	TX0_MARK___3 = 1882,
	HTX1_B_MARK___4 = 1883,
	TS_SPSYNC0_C_MARK___3 = 1884,
	STP_ISSYNC_0_C_MARK___3 = 1885,
	RIF0_D1_B_MARK___4 = 1886,
	IP13_3_0_MARK___4 = 1887,
	TX2_A_MARK___4 = 1888,
	SD2_CD_B_MARK___3 = 1889,
	SCL1_A_MARK___4 = 1890,
	FMCLK_A_MARK___4 = 1891,
	RIF1_D1_C_MARK___3 = 1892,
	FSO_CFE_0_N_MARK___3 = 1893,
	IP14_3_0_MARK___4 = 1894,
	MSIOF0_SS1_MARK___4 = 1895,
	RX5_A_MARK___4 = 1896,
	NFWP_N_A_MARK___4 = 1897,
	AUDIO_CLKA_C_MARK___3 = 1898,
	SSI_SCK2_A_MARK___4 = 1899,
	STP_IVCXO27_0_C_MARK___3 = 1900,
	AUDIO_CLKOUT3_A_MARK___4 = 1901,
	TCLK1_B_MARK___4 = 1902,
	IP15_3_0_MARK___4 = 1903,
	SSI_SDATA1_A_MARK___3 = 1904,
	IP12_7_4_MARK___4 = 1905,
	CTS0_N_MARK___3 = 1906,
	HCTS1_N_B_MARK___4 = 1907,
	MSIOF1_SYNC_B_MARK___3 = 1908,
	TS_SPSYNC1_C_MARK___3 = 1909,
	STP_ISSYNC_1_C_MARK___3 = 1910,
	RIF1_SYNC_B_MARK___3 = 1911,
	AUDIO_CLKOUT_C_MARK___3 = 1912,
	ADICS_SAMP_MARK___3 = 1913,
	IP13_7_4_MARK___4 = 1914,
	RX2_A_MARK___4 = 1915,
	SD2_WP_B_MARK___3 = 1916,
	SDA1_A_MARK___4 = 1917,
	FMIN_A_MARK___4 = 1918,
	RIF1_SYNC_C_MARK___3 = 1919,
	FSO_CFE_1_N_MARK___3 = 1920,
	IP14_7_4_MARK___4 = 1921,
	MSIOF0_SS2_MARK___4 = 1922,
	TX5_A_MARK___4 = 1923,
	MSIOF1_SS2_D_MARK___3 = 1924,
	AUDIO_CLKC_A_MARK___4 = 1925,
	SSI_WS2_A_MARK___4 = 1926,
	STP_OPWM_0_D_MARK___3 = 1927,
	AUDIO_CLKOUT_D_MARK___3 = 1928,
	SPEEDIN_B_MARK___4 = 1929,
	IP15_7_4_MARK___4 = 1930,
	SSI_SDATA2_A_MARK___3 = 1931,
	SSI_SCK1_B_MARK___3 = 1932,
	IP12_11_8_MARK___4 = 1933,
	RTS0_N_MARK___3 = 1934,
	HRTS1_N_B_MARK___4 = 1935,
	MSIOF1_SS1_B_MARK___3 = 1936,
	AUDIO_CLKA_B_MARK___3 = 1937,
	SCL2_A_MARK___4 = 1938,
	STP_IVCXO27_1_C_MARK___3 = 1939,
	RIF0_SYNC_B_MARK___4 = 1940,
	ADICHS1_MARK___3 = 1941,
	IP13_11_8_MARK___4 = 1942,
	HSCK0_MARK___3 = 1943,
	MSIOF1_SCK_D_MARK___3 = 1944,
	AUDIO_CLKB_A_MARK___4 = 1945,
	SSI_SDATA1_B_MARK___3 = 1946,
	TS_SCK0_D_MARK___3 = 1947,
	STP_ISCLK_0_D_MARK___3 = 1948,
	RIF0_CLK_C_MARK___3 = 1949,
	RX5_B_MARK___4 = 1950,
	IP14_11_8_MARK___4 = 1951,
	MLB_CLK_MARK___4 = 1952,
	MSIOF1_SCK_F_MARK___3 = 1953,
	SCL1_B_MARK___4 = 1954,
	IP15_11_8_MARK___4 = 1955,
	SSI_SCK349_MARK___4 = 1956,
	MSIOF1_SS1_A_MARK___3 = 1957,
	STP_OPWM_0_A_MARK___3 = 1958,
	IP12_15_12_MARK___4 = 1959,
	RX1_A_MARK___3 = 1960,
	HRX1_A_MARK___4 = 1961,
	TS_SDAT0_C_MARK___3 = 1962,
	STP_ISD_0_C_MARK___3 = 1963,
	RIF1_CLK_C_MARK___3 = 1964,
	IP13_15_12_MARK___4 = 1965,
	HRX0_MARK___3 = 1966,
	MSIOF1_RXD_D_MARK___3 = 1967,
	SSI_SDATA2_B_MARK___3 = 1968,
	TS_SDEN0_D_MARK___3 = 1969,
	STP_ISEN_0_D_MARK___3 = 1970,
	RIF0_D0_C_MARK___3 = 1971,
	IP14_15_12_MARK___4 = 1972,
	MLB_SIG_MARK___4 = 1973,
	RX1_B_MARK___3 = 1974,
	MSIOF1_SYNC_F_MARK___3 = 1975,
	SDA1_B_MARK___4 = 1976,
	IP15_15_12_MARK___4 = 1977,
	SSI_WS349_MARK___4 = 1978,
	HCTS2_N_A_MARK___4 = 1979,
	MSIOF1_SS2_A_MARK___3 = 1980,
	STP_IVCXO27_0_A_MARK___3 = 1981,
	IP12_19_16_MARK___4 = 1982,
	TX1_A_MARK___3 = 1983,
	HTX1_A_MARK___4 = 1984,
	TS_SDEN0_C_MARK___3 = 1985,
	STP_ISEN_0_C_MARK___3 = 1986,
	RIF1_D0_C_MARK___3 = 1987,
	IP13_19_16_MARK___4 = 1988,
	HTX0_MARK___3 = 1989,
	MSIOF1_TXD_D_MARK___3 = 1990,
	SSI_SDATA9_B_MARK___3 = 1991,
	TS_SDAT0_D_MARK___3 = 1992,
	STP_ISD_0_D_MARK___3 = 1993,
	RIF0_D1_C_MARK___3 = 1994,
	IP14_19_16_MARK___4 = 1995,
	MLB_DAT_MARK___4 = 1996,
	TX1_B_MARK___3 = 1997,
	MSIOF1_RXD_F_MARK___3 = 1998,
	IP15_19_16_MARK___4 = 1999,
	SSI_SDATA3_MARK___4 = 2000,
	HRTS2_N_A_MARK___4 = 2001,
	MSIOF1_TXD_A_MARK___3 = 2002,
	TS_SCK0_A_MARK___3 = 2003,
	STP_ISCLK_0_A_MARK___3 = 2004,
	RIF0_D1_A_MARK___4 = 2005,
	RIF2_D0_A_MARK___4 = 2006,
	IP12_23_20_MARK___4 = 2007,
	CTS1_N_MARK___4 = 2008,
	HCTS1_N_A_MARK___3 = 2009,
	MSIOF1_RXD_B_MARK___3 = 2010,
	TS_SDEN1_C_MARK___3 = 2011,
	STP_ISEN_1_C_MARK___3 = 2012,
	RIF1_D0_B_MARK___3 = 2013,
	ADIDATA_MARK___3 = 2014,
	IP13_23_20_MARK___4 = 2015,
	HCTS0_N_MARK___3 = 2016,
	RX2_B_MARK___4 = 2017,
	MSIOF1_SYNC_D_MARK___3 = 2018,
	SSI_SCK9_A_MARK___4 = 2019,
	TS_SPSYNC0_D_MARK___3 = 2020,
	STP_ISSYNC_0_D_MARK___3 = 2021,
	RIF0_SYNC_C_MARK___3 = 2022,
	AUDIO_CLKOUT1_A_MARK___4 = 2023,
	IP14_23_20_MARK___4 = 2024,
	SSI_SCK01239_MARK___4 = 2025,
	MSIOF1_TXD_F_MARK___3 = 2026,
	IP15_23_20_MARK___4 = 2027,
	SSI_SCK4_MARK___4 = 2028,
	HRX2_A_MARK___4 = 2029,
	MSIOF1_SCK_A_MARK___3 = 2030,
	TS_SDAT0_A_MARK___3 = 2031,
	STP_ISD_0_A_MARK___3 = 2032,
	RIF0_CLK_A_MARK___4 = 2033,
	RIF2_CLK_A_MARK___4 = 2034,
	IP12_27_24_MARK___4 = 2035,
	RTS1_N_MARK___4 = 2036,
	HRTS1_N_A_MARK___3 = 2037,
	MSIOF1_TXD_B_MARK___3 = 2038,
	TS_SDAT1_C_MARK___3 = 2039,
	STP_ISD_1_C_MARK___3 = 2040,
	RIF1_D1_B_MARK___3 = 2041,
	ADICHS0_MARK___3 = 2042,
	IP13_27_24_MARK___4 = 2043,
	HRTS0_N_MARK___3 = 2044,
	TX2_B_MARK___4 = 2045,
	MSIOF1_SS1_D_MARK___3 = 2046,
	SSI_WS9_A_MARK___4 = 2047,
	STP_IVCXO27_0_D_MARK___3 = 2048,
	BPFCLK_A_MARK___4 = 2049,
	AUDIO_CLKOUT2_A_MARK___4 = 2050,
	IP14_27_24_MARK___4 = 2051,
	SSI_WS01239_MARK___4 = 2052,
	MSIOF1_SS1_F_MARK___3 = 2053,
	IP15_27_24_MARK___4 = 2054,
	SSI_WS4_MARK___4 = 2055,
	HTX2_A_MARK___4 = 2056,
	MSIOF1_SYNC_A_MARK___3 = 2057,
	TS_SDEN0_A_MARK___3 = 2058,
	STP_ISEN_0_A_MARK___3 = 2059,
	RIF0_SYNC_A_MARK___4 = 2060,
	RIF2_SYNC_A_MARK___4 = 2061,
	IP12_31_28_MARK___4 = 2062,
	SCK2_MARK___3 = 2063,
	SCIF_CLK_B_MARK___4 = 2064,
	MSIOF1_SCK_B_MARK___3 = 2065,
	TS_SCK1_C_MARK___3 = 2066,
	STP_ISCLK_1_C_MARK___3 = 2067,
	RIF1_CLK_B_MARK___3 = 2068,
	ADICLK_MARK___3 = 2069,
	IP13_31_28_MARK___4 = 2070,
	MSIOF0_SYNC_MARK___4 = 2071,
	AUDIO_CLKOUT_A_MARK___4 = 2072,
	TX5_B_MARK___4 = 2073,
	BPFCLK_D_MARK___3 = 2074,
	IP14_31_28_MARK___4 = 2075,
	SSI_SDATA0_MARK___4 = 2076,
	MSIOF1_SS2_F_MARK___3 = 2077,
	IP15_31_28_MARK___4 = 2078,
	SSI_SDATA4_MARK___4 = 2079,
	HSCK2_A_MARK___4 = 2080,
	MSIOF1_RXD_A_MARK___3 = 2081,
	TS_SPSYNC0_A_MARK___3 = 2082,
	STP_ISSYNC_0_A_MARK___3 = 2083,
	RIF0_D0_A_MARK___4 = 2084,
	RIF2_D1_A_MARK___4 = 2085,
	IP16_3_0_MARK___3 = 2086,
	SSI_SCK6_MARK___4 = 2087,
	USB2_PWEN_MARK = 2088,
	SIM0_RST_D_MARK___3 = 2089,
	IP17_3_0_MARK___3 = 2090,
	AUDIO_CLKA_A_MARK___3 = 2091,
	IP18_3_0_MARK___3 = 2092,
	USB2_CH3_PWEN_MARK = 2093,
	AUDIO_CLKOUT2_B_MARK___4 = 2094,
	SSI_SCK9_B_MARK___4 = 2095,
	TS_SDEN0_E_MARK___3 = 2096,
	STP_ISEN_0_E_MARK___3 = 2097,
	RIF2_D0_B_MARK___4 = 2098,
	TPU0TO2_MARK___4 = 2099,
	FMCLK_C_MARK___4 = 2100,
	FMCLK_D_MARK___3 = 2101,
	IP16_7_4_MARK___3 = 2102,
	SSI_WS6_MARK___4 = 2103,
	USB2_OVC_MARK = 2104,
	SIM0_D_D_MARK___3 = 2105,
	IP17_7_4_MARK___3 = 2106,
	AUDIO_CLKB_B_MARK___4 = 2107,
	SCIF_CLK_A_MARK___4 = 2108,
	STP_IVCXO27_1_D_MARK___3 = 2109,
	REMOCON_A_MARK___4 = 2110,
	TCLK1_A_MARK___4 = 2111,
	IP18_7_4_MARK___3 = 2112,
	USB2_CH3_OVC_MARK = 2113,
	AUDIO_CLKOUT3_B_MARK___4 = 2114,
	SSI_WS9_B_MARK___4 = 2115,
	TS_SPSYNC0_E_MARK___3 = 2116,
	STP_ISSYNC_0_E_MARK___3 = 2117,
	RIF2_D1_B_MARK___4 = 2118,
	TPU0TO3_MARK___4 = 2119,
	FMIN_C_MARK___4 = 2120,
	FMIN_D_MARK___3 = 2121,
	IP16_11_8_MARK___3 = 2122,
	SSI_SDATA6_MARK___4 = 2123,
	SIM0_CLK_D_MARK___3 = 2124,
	SATA_DEVSLP_A_MARK___2 = 2125,
	IP17_11_8_MARK___3 = 2126,
	USB0_PWEN_MARK___3 = 2127,
	SIM0_RST_C_MARK___3 = 2128,
	TS_SCK1_D_MARK___3 = 2129,
	STP_ISCLK_1_D_MARK___3 = 2130,
	BPFCLK_B_MARK___4 = 2131,
	RIF3_CLK_B_MARK___4 = 2132,
	HSCK2_C_MARK___3 = 2133,
	IP16_15_12_MARK___3 = 2134,
	SSI_SCK78_MARK___4 = 2135,
	HRX2_B_MARK___4 = 2136,
	MSIOF1_SCK_C_MARK___3 = 2137,
	TS_SCK1_A_MARK___3 = 2138,
	STP_ISCLK_1_A_MARK___3 = 2139,
	RIF1_CLK_A_MARK___3 = 2140,
	RIF3_CLK_A_MARK___4 = 2141,
	IP17_15_12_MARK___3 = 2142,
	USB0_OVC_MARK___3 = 2143,
	SIM0_D_C_MARK___3 = 2144,
	TS_SDAT1_D_MARK___3 = 2145,
	STP_ISD_1_D_MARK___3 = 2146,
	RIF3_SYNC_B_MARK___4 = 2147,
	HRX2_C_MARK___3 = 2148,
	IP16_19_16_MARK___3 = 2149,
	SSI_WS78_MARK___4 = 2150,
	HTX2_B_MARK___4 = 2151,
	MSIOF1_SYNC_C_MARK___3 = 2152,
	TS_SDAT1_A_MARK___3 = 2153,
	STP_ISD_1_A_MARK___3 = 2154,
	RIF1_SYNC_A_MARK___3 = 2155,
	RIF3_SYNC_A_MARK___4 = 2156,
	IP17_19_16_MARK___3 = 2157,
	USB1_PWEN_MARK___3 = 2158,
	SIM0_CLK_C_MARK___3 = 2159,
	SSI_SCK1_A_MARK___3 = 2160,
	TS_SCK0_E_MARK___3 = 2161,
	STP_ISCLK_0_E_MARK___3 = 2162,
	FMCLK_B_MARK___4 = 2163,
	RIF2_CLK_B_MARK___4 = 2164,
	SPEEDIN_A_MARK___4 = 2165,
	HTX2_C_MARK___3 = 2166,
	IP16_23_20_MARK___3 = 2167,
	SSI_SDATA7_MARK___4 = 2168,
	HCTS2_N_B_MARK___3 = 2169,
	MSIOF1_RXD_C_MARK___3 = 2170,
	TS_SDEN1_A_MARK___3 = 2171,
	STP_ISEN_1_A_MARK___3 = 2172,
	RIF1_D0_A_MARK___3 = 2173,
	RIF3_D0_A_MARK___4 = 2174,
	TCLK2_A_MARK___4 = 2175,
	IP17_23_20_MARK___3 = 2176,
	USB1_OVC_MARK___3 = 2177,
	MSIOF1_SS2_C_MARK___3 = 2178,
	SSI_WS1_A_MARK___3 = 2179,
	TS_SDAT0_E_MARK___3 = 2180,
	STP_ISD_0_E_MARK___3 = 2181,
	FMIN_B_MARK___4 = 2182,
	RIF2_SYNC_B_MARK___4 = 2183,
	REMOCON_B_MARK___4 = 2184,
	HCTS2_N_C_MARK___3 = 2185,
	IP16_27_24_MARK___3 = 2186,
	SSI_SDATA8_MARK___4 = 2187,
	HRTS2_N_B_MARK___3 = 2188,
	MSIOF1_TXD_C_MARK___3 = 2189,
	TS_SPSYNC1_A_MARK___3 = 2190,
	STP_ISSYNC_1_A_MARK___3 = 2191,
	RIF1_D1_A_MARK___3 = 2192,
	RIF3_D1_A_MARK___4 = 2193,
	IP17_27_24_MARK___3 = 2194,
	USB30_PWEN_MARK___4 = 2195,
	AUDIO_CLKOUT_B_MARK___4 = 2196,
	SSI_SCK2_B_MARK___4 = 2197,
	TS_SDEN1_D_MARK___3 = 2198,
	STP_ISEN_1_D_MARK___3 = 2199,
	STP_OPWM_0_E_MARK___3 = 2200,
	RIF3_D0_B_MARK___4 = 2201,
	TCLK2_B_MARK___4 = 2202,
	TPU0TO0_MARK___4 = 2203,
	BPFCLK_C_MARK___4 = 2204,
	HRTS2_N_C_MARK___3 = 2205,
	IP16_31_28_MARK___3 = 2206,
	SSI_SDATA9_A_MARK___3 = 2207,
	HSCK2_B_MARK___3 = 2208,
	MSIOF1_SS1_C_MARK___3 = 2209,
	HSCK1_A_MARK___4 = 2210,
	SSI_WS1_B_MARK___3 = 2211,
	SCK1_MARK___4 = 2212,
	STP_IVCXO27_1_A_MARK___3 = 2213,
	SCK5_A_MARK___4 = 2214,
	IP17_31_28_MARK___3 = 2215,
	USB30_OVC_MARK___4 = 2216,
	AUDIO_CLKOUT1_B_MARK___4 = 2217,
	SSI_WS2_B_MARK___4 = 2218,
	TS_SPSYNC1_D_MARK___3 = 2219,
	STP_ISSYNC_1_D_MARK___3 = 2220,
	STP_IVCXO27_0_E_MARK___3 = 2221,
	RIF3_D1_B_MARK___4 = 2222,
	FSO_TOE_N_MARK___3 = 2223,
	TPU0TO1_MARK___4 = 2224,
	SEL_MSIOF3_0_MARK___4 = 2225,
	SEL_MSIOF3_1_MARK___4 = 2226,
	SEL_MSIOF3_2_MARK___3 = 2227,
	SEL_MSIOF3_3_MARK___3 = 2228,
	SEL_MSIOF3_4_MARK___3 = 2229,
	SEL_TSIF1_0_MARK___3 = 2230,
	SEL_TSIF1_1_MARK___3 = 2231,
	SEL_TSIF1_2_MARK___3 = 2232,
	SEL_TSIF1_3_MARK___3 = 2233,
	I2C_SEL_5_0_MARK___3 = 2234,
	I2C_SEL_5_1_MARK___3 = 2235,
	I2C_SEL_3_0_MARK___3 = 2236,
	I2C_SEL_3_1_MARK___3 = 2237,
	SEL_TSIF0_0_MARK___3 = 2238,
	SEL_TSIF0_1_MARK___3 = 2239,
	SEL_TSIF0_2_MARK___3 = 2240,
	SEL_TSIF0_3_MARK___3 = 2241,
	SEL_TSIF0_4_MARK___3 = 2242,
	I2C_SEL_0_0_MARK___3 = 2243,
	I2C_SEL_0_1_MARK___3 = 2244,
	SEL_MSIOF2_0_MARK___4 = 2245,
	SEL_MSIOF2_1_MARK___4 = 2246,
	SEL_MSIOF2_2_MARK___3 = 2247,
	SEL_MSIOF2_3_MARK___3 = 2248,
	SEL_FM_0_MARK___4 = 2249,
	SEL_FM_1_MARK___4 = 2250,
	SEL_FM_2_MARK___4 = 2251,
	SEL_FM_3_MARK___3 = 2252,
	SEL_MSIOF1_0_MARK___3 = 2253,
	SEL_MSIOF1_1_MARK___3 = 2254,
	SEL_MSIOF1_2_MARK___3 = 2255,
	SEL_MSIOF1_3_MARK___3 = 2256,
	SEL_MSIOF1_4_MARK___3 = 2257,
	SEL_MSIOF1_5_MARK___3 = 2258,
	SEL_MSIOF1_6_MARK___3 = 2259,
	SEL_TIMER_TMU1_0_MARK = 2260,
	SEL_TIMER_TMU1_1_MARK = 2261,
	SEL_SCIF5_0_MARK___4 = 2262,
	SEL_SCIF5_1_MARK___4 = 2263,
	SEL_SSP1_1_0_MARK___3 = 2264,
	SEL_SSP1_1_1_MARK___3 = 2265,
	SEL_SSP1_1_2_MARK___3 = 2266,
	SEL_SSP1_1_3_MARK___3 = 2267,
	SEL_I2C6_0_MARK___4 = 2268,
	SEL_I2C6_1_MARK___4 = 2269,
	SEL_I2C6_2_MARK___3 = 2270,
	SEL_LBSC_0_MARK___3 = 2271,
	SEL_LBSC_1_MARK___3 = 2272,
	SEL_SSP1_0_0_MARK___3 = 2273,
	SEL_SSP1_0_1_MARK___3 = 2274,
	SEL_SSP1_0_2_MARK___3 = 2275,
	SEL_SSP1_0_3_MARK___3 = 2276,
	SEL_SSP1_0_4_MARK___3 = 2277,
	SEL_IEBUS_0_MARK___3 = 2278,
	SEL_IEBUS_1_MARK___3 = 2279,
	SEL_I2C2_0_MARK___4 = 2280,
	SEL_I2C2_1_MARK___4 = 2281,
	SEL_SSI2_0_MARK___4 = 2282,
	SEL_SSI2_1_MARK___4 = 2283,
	SEL_I2C1_0_MARK___4 = 2284,
	SEL_I2C1_1_MARK___4 = 2285,
	SEL_SSI1_0_MARK___3 = 2286,
	SEL_SSI1_1_MARK___3 = 2287,
	SEL_SSI9_0_MARK___4 = 2288,
	SEL_SSI9_1_MARK___4 = 2289,
	SEL_HSCIF4_0_MARK___4 = 2290,
	SEL_HSCIF4_1_MARK___4 = 2291,
	SEL_SPEED_PULSE_0_MARK___3 = 2292,
	SEL_SPEED_PULSE_1_MARK___3 = 2293,
	SEL_TIMER_TMU2_0_MARK___3 = 2294,
	SEL_TIMER_TMU2_1_MARK___3 = 2295,
	SEL_HSCIF3_0_MARK___4 = 2296,
	SEL_HSCIF3_1_MARK___4 = 2297,
	SEL_HSCIF3_2_MARK___4 = 2298,
	SEL_HSCIF3_3_MARK___4 = 2299,
	SEL_SIMCARD_0_MARK___4 = 2300,
	SEL_SIMCARD_1_MARK___4 = 2301,
	SEL_SIMCARD_2_MARK___3 = 2302,
	SEL_SIMCARD_3_MARK___3 = 2303,
	SEL_ADGB_0_MARK___4 = 2304,
	SEL_ADGB_1_MARK___4 = 2305,
	SEL_ADGC_0_MARK___4 = 2306,
	SEL_ADGC_1_MARK___4 = 2307,
	SEL_HSCIF1_0_MARK___4 = 2308,
	SEL_HSCIF1_1_MARK___4 = 2309,
	SEL_SDHI2_0_MARK___3 = 2310,
	SEL_SDHI2_1_MARK___3 = 2311,
	SEL_SCIF4_0_MARK___4 = 2312,
	SEL_SCIF4_1_MARK___4 = 2313,
	SEL_SCIF4_2_MARK___4 = 2314,
	SEL_HSCIF2_0_MARK___4 = 2315,
	SEL_HSCIF2_1_MARK___4 = 2316,
	SEL_HSCIF2_2_MARK___3 = 2317,
	SEL_SCIF3_0_MARK___4 = 2318,
	SEL_SCIF3_1_MARK___4 = 2319,
	SEL_ETHERAVB_0_MARK___3 = 2320,
	SEL_ETHERAVB_1_MARK___3 = 2321,
	SEL_SCIF2_0_MARK___4 = 2322,
	SEL_SCIF2_1_MARK___4 = 2323,
	SEL_DRIF3_0_MARK___4 = 2324,
	SEL_DRIF3_1_MARK___4 = 2325,
	SEL_SCIF1_0_MARK___3 = 2326,
	SEL_SCIF1_1_MARK___3 = 2327,
	SEL_DRIF2_0_MARK___4 = 2328,
	SEL_DRIF2_1_MARK___4 = 2329,
	SEL_SCIF_0_MARK___4 = 2330,
	SEL_SCIF_1_MARK___4 = 2331,
	SEL_DRIF1_0_MARK___3 = 2332,
	SEL_DRIF1_1_MARK___3 = 2333,
	SEL_DRIF1_2_MARK___3 = 2334,
	SEL_REMOCON_0_MARK___4 = 2335,
	SEL_REMOCON_1_MARK___4 = 2336,
	SEL_DRIF0_0_MARK___4 = 2337,
	SEL_DRIF0_1_MARK___4 = 2338,
	SEL_DRIF0_2_MARK___3 = 2339,
	SEL_RCAN0_0_MARK___3 = 2340,
	SEL_RCAN0_1_MARK___3 = 2341,
	SEL_CANFD0_0_MARK___3 = 2342,
	SEL_CANFD0_1_MARK___3 = 2343,
	SEL_PWM6_0_MARK___4 = 2344,
	SEL_PWM6_1_MARK___4 = 2345,
	SEL_ADGA_0_MARK___3 = 2346,
	SEL_ADGA_1_MARK___3 = 2347,
	SEL_ADGA_2_MARK___3 = 2348,
	SEL_ADGA_3_MARK___3 = 2349,
	SEL_PWM5_0_MARK___4 = 2350,
	SEL_PWM5_1_MARK___4 = 2351,
	SEL_PWM4_0_MARK___4 = 2352,
	SEL_PWM4_1_MARK___4 = 2353,
	SEL_PWM3_0_MARK___4 = 2354,
	SEL_PWM3_1_MARK___4 = 2355,
	SEL_PWM2_0_MARK___4 = 2356,
	SEL_PWM2_1_MARK___4 = 2357,
	SEL_PWM1_0_MARK___4 = 2358,
	SEL_PWM1_1_MARK___4 = 2359,
	SEL_VIN4_0_MARK___4 = 2360,
	SEL_VIN4_1_MARK___4 = 2361,
	QSPI0_SPCLK_MARK___4 = 2362,
	QSPI0_SSL_MARK___4 = 2363,
	QSPI0_MOSI_IO0_MARK___4 = 2364,
	QSPI0_MISO_IO1_MARK___4 = 2365,
	QSPI0_IO2_MARK___4 = 2366,
	QSPI0_IO3_MARK___4 = 2367,
	QSPI1_SPCLK_MARK___4 = 2368,
	QSPI1_SSL_MARK___4 = 2369,
	QSPI1_MOSI_IO0_MARK___4 = 2370,
	QSPI1_MISO_IO1_MARK___4 = 2371,
	QSPI1_IO2_MARK___4 = 2372,
	QSPI1_IO3_MARK___4 = 2373,
	RPC_INT_MARK___3 = 2374,
	RPC_WP_MARK___3 = 2375,
	RPC_RESET_MARK___3 = 2376,
	AVB_TX_CTL_MARK___4 = 2377,
	AVB_TXC_MARK___4 = 2378,
	AVB_TD0_MARK___4 = 2379,
	AVB_TD1_MARK___4 = 2380,
	AVB_TD2_MARK___4 = 2381,
	AVB_TD3_MARK___4 = 2382,
	AVB_RX_CTL_MARK___4 = 2383,
	AVB_RXC_MARK___4 = 2384,
	AVB_RD0_MARK___4 = 2385,
	AVB_RD1_MARK___4 = 2386,
	AVB_RD2_MARK___4 = 2387,
	AVB_RD3_MARK___4 = 2388,
	AVB_TXCREFCLK_MARK___4 = 2389,
	AVB_MDIO_MARK___4 = 2390,
	PRESETOUT_MARK___3 = 2391,
	DU_DOTCLKIN0_MARK___4 = 2392,
	DU_DOTCLKIN1_MARK___4 = 2393,
	DU_DOTCLKIN2_MARK___2 = 2394,
	DU_DOTCLKIN3_MARK___2 = 2395,
	TMS_MARK___4 = 2396,
	TDO_MARK___3 = 2397,
	ASEBRK_MARK___4 = 2398,
	MLB_REF_MARK___4 = 2399,
	TDI_MARK___4 = 2400,
	TCK_MARK___4 = 2401,
	TRST_MARK___3 = 2402,
	EXTALR_MARK___3 = 2403,
	SCL0_MARK___3 = 2404,
	SDA0_MARK___3 = 2405,
	SCL3_MARK___3 = 2406,
	SDA3_MARK___3 = 2407,
	SCL5_MARK___4 = 2408,
	SDA5_MARK___4 = 2409,
	PINMUX_MARK_END___4 = 2410,
};

enum {
	GP_LAST___4 = 227,
	PIN_ASEBRK___4 = 228,
	PIN_AVB_MDIO___4 = 229,
	PIN_AVB_RD0___3 = 230,
	PIN_AVB_RD1___3 = 231,
	PIN_AVB_RD2___3 = 232,
	PIN_AVB_RD3___3 = 233,
	PIN_AVB_RXC___3 = 234,
	PIN_AVB_RX_CTL___3 = 235,
	PIN_AVB_TD0___4 = 236,
	PIN_AVB_TD1___4 = 237,
	PIN_AVB_TD2___4 = 238,
	PIN_AVB_TD3___4 = 239,
	PIN_AVB_TXC___4 = 240,
	PIN_AVB_TXCREFCLK___3 = 241,
	PIN_AVB_TX_CTL___4 = 242,
	PIN_DU_DOTCLKIN0___3 = 243,
	PIN_DU_DOTCLKIN1___3 = 244,
	PIN_DU_DOTCLKIN2___2 = 245,
	PIN_DU_DOTCLKIN3___2 = 246,
	PIN_EXTALR___3 = 247,
	PIN_FSCLKST_N___2 = 248,
	PIN_MLB_REF___4 = 249,
	PIN_PRESETOUT_N___4 = 250,
	PIN_QSPI0_IO2___3 = 251,
	PIN_QSPI0_IO3___3 = 252,
	PIN_QSPI0_MISO_IO1___3 = 253,
	PIN_QSPI0_MOSI_IO0___3 = 254,
	PIN_QSPI0_SPCLK___3 = 255,
	PIN_QSPI0_SSL___3 = 256,
	PIN_QSPI1_IO2___3 = 257,
	PIN_QSPI1_IO3___3 = 258,
	PIN_QSPI1_MISO_IO1___3 = 259,
	PIN_QSPI1_MOSI_IO0___3 = 260,
	PIN_QSPI1_SPCLK___3 = 261,
	PIN_QSPI1_SSL___3 = 262,
	PIN_RPC_INT_N___3 = 263,
	PIN_RPC_RESET_N___3 = 264,
	PIN_RPC_WP_N___3 = 265,
	PIN_TCK___4 = 266,
	PIN_TDI___4 = 267,
	PIN_TDO___3 = 268,
	PIN_TMS___4 = 269,
	PIN_TRST_N___4 = 270,
};

enum {
	PINMUX_RESERVED___5 = 0,
	PINMUX_DATA_BEGIN___5 = 1,
	GP_0_0_DATA___5 = 2,
	GP_0_1_DATA___5 = 3,
	GP_0_2_DATA___5 = 4,
	GP_0_3_DATA___5 = 5,
	GP_0_4_DATA___5 = 6,
	GP_0_5_DATA___5 = 7,
	GP_0_6_DATA___5 = 8,
	GP_0_7_DATA___5 = 9,
	GP_0_8_DATA___5 = 10,
	GP_0_9_DATA___5 = 11,
	GP_0_10_DATA___5 = 12,
	GP_0_11_DATA___5 = 13,
	GP_0_12_DATA___5 = 14,
	GP_0_13_DATA___5 = 15,
	GP_0_14_DATA___5 = 16,
	GP_0_15_DATA___5 = 17,
	GP_1_0_DATA___5 = 18,
	GP_1_1_DATA___5 = 19,
	GP_1_2_DATA___5 = 20,
	GP_1_3_DATA___5 = 21,
	GP_1_4_DATA___5 = 22,
	GP_1_5_DATA___5 = 23,
	GP_1_6_DATA___5 = 24,
	GP_1_7_DATA___5 = 25,
	GP_1_8_DATA___5 = 26,
	GP_1_9_DATA___5 = 27,
	GP_1_10_DATA___5 = 28,
	GP_1_11_DATA___5 = 29,
	GP_1_12_DATA___5 = 30,
	GP_1_13_DATA___5 = 31,
	GP_1_14_DATA___5 = 32,
	GP_1_15_DATA___5 = 33,
	GP_1_16_DATA___5 = 34,
	GP_1_17_DATA___5 = 35,
	GP_1_18_DATA___5 = 36,
	GP_1_19_DATA___5 = 37,
	GP_1_20_DATA___5 = 38,
	GP_1_21_DATA___5 = 39,
	GP_1_22_DATA___5 = 40,
	GP_1_23_DATA___4 = 41,
	GP_1_24_DATA___4 = 42,
	GP_1_25_DATA___4 = 43,
	GP_1_26_DATA___4 = 44,
	GP_1_27_DATA___4 = 45,
	GP_2_0_DATA___5 = 46,
	GP_2_1_DATA___5 = 47,
	GP_2_2_DATA___5 = 48,
	GP_2_3_DATA___5 = 49,
	GP_2_4_DATA___5 = 50,
	GP_2_5_DATA___5 = 51,
	GP_2_6_DATA___5 = 52,
	GP_2_7_DATA___5 = 53,
	GP_2_8_DATA___5 = 54,
	GP_2_9_DATA___5 = 55,
	GP_2_10_DATA___5 = 56,
	GP_2_11_DATA___5 = 57,
	GP_2_12_DATA___5 = 58,
	GP_2_13_DATA___5 = 59,
	GP_2_14_DATA___5 = 60,
	GP_3_0_DATA___5 = 61,
	GP_3_1_DATA___5 = 62,
	GP_3_2_DATA___5 = 63,
	GP_3_3_DATA___5 = 64,
	GP_3_4_DATA___5 = 65,
	GP_3_5_DATA___5 = 66,
	GP_3_6_DATA___5 = 67,
	GP_3_7_DATA___5 = 68,
	GP_3_8_DATA___5 = 69,
	GP_3_9_DATA___5 = 70,
	GP_3_10_DATA___5 = 71,
	GP_3_11_DATA___5 = 72,
	GP_3_12_DATA___5 = 73,
	GP_3_13_DATA___5 = 74,
	GP_3_14_DATA___5 = 75,
	GP_3_15_DATA___5 = 76,
	GP_4_0_DATA___5 = 77,
	GP_4_1_DATA___5 = 78,
	GP_4_2_DATA___5 = 79,
	GP_4_3_DATA___5 = 80,
	GP_4_4_DATA___5 = 81,
	GP_4_5_DATA___5 = 82,
	GP_4_6_DATA___5 = 83,
	GP_4_7_DATA___5 = 84,
	GP_4_8_DATA___5 = 85,
	GP_4_9_DATA___5 = 86,
	GP_4_10_DATA___5 = 87,
	GP_4_11_DATA___4 = 88,
	GP_4_12_DATA___4 = 89,
	GP_4_13_DATA___4 = 90,
	GP_4_14_DATA___4 = 91,
	GP_4_15_DATA___4 = 92,
	GP_4_16_DATA___4 = 93,
	GP_4_17_DATA___4 = 94,
	GP_5_0_DATA___5 = 95,
	GP_5_1_DATA___5 = 96,
	GP_5_2_DATA___5 = 97,
	GP_5_3_DATA___5 = 98,
	GP_5_4_DATA___5 = 99,
	GP_5_5_DATA___5 = 100,
	GP_5_6_DATA___5 = 101,
	GP_5_7_DATA___5 = 102,
	GP_5_8_DATA___5 = 103,
	GP_5_9_DATA___5 = 104,
	GP_5_10_DATA___5 = 105,
	GP_5_11_DATA___5 = 106,
	GP_5_12_DATA___5 = 107,
	GP_5_13_DATA___5 = 108,
	GP_5_14_DATA___5 = 109,
	GP_5_15_DATA___5 = 110,
	GP_5_16_DATA___5 = 111,
	GP_5_17_DATA___5 = 112,
	GP_5_18_DATA___5 = 113,
	GP_5_19_DATA___5 = 114,
	GP_5_20_DATA___4 = 115,
	GP_5_21_DATA___4 = 116,
	GP_5_22_DATA___4 = 117,
	GP_5_23_DATA___4 = 118,
	GP_5_24_DATA___4 = 119,
	GP_5_25_DATA___4 = 120,
	GP_6_0_DATA___5 = 121,
	GP_6_1_DATA___5 = 122,
	GP_6_2_DATA___5 = 123,
	GP_6_3_DATA___5 = 124,
	GP_6_4_DATA___5 = 125,
	GP_6_5_DATA___5 = 126,
	GP_6_6_DATA___5 = 127,
	GP_6_7_DATA___5 = 128,
	GP_6_8_DATA___5 = 129,
	GP_6_9_DATA___5 = 130,
	GP_6_10_DATA___5 = 131,
	GP_6_11_DATA___5 = 132,
	GP_6_12_DATA___5 = 133,
	GP_6_13_DATA___5 = 134,
	GP_6_14_DATA___5 = 135,
	GP_6_15_DATA___5 = 136,
	GP_6_16_DATA___5 = 137,
	GP_6_17_DATA___5 = 138,
	GP_6_18_DATA___4 = 139,
	GP_6_19_DATA___4 = 140,
	GP_6_20_DATA___4 = 141,
	GP_6_21_DATA___4 = 142,
	GP_6_22_DATA___4 = 143,
	GP_6_23_DATA___4 = 144,
	GP_6_24_DATA___4 = 145,
	GP_6_25_DATA___4 = 146,
	GP_6_26_DATA___4 = 147,
	GP_6_27_DATA___4 = 148,
	GP_6_28_DATA___4 = 149,
	GP_6_29_DATA___4 = 150,
	GP_6_30_DATA___4 = 151,
	GP_6_31_DATA___4 = 152,
	GP_7_0_DATA___4 = 153,
	GP_7_1_DATA___4 = 154,
	GP_7_2_DATA___4 = 155,
	GP_7_3_DATA___4 = 156,
	PINMUX_DATA_END___5 = 157,
	PINMUX_FUNCTION_BEGIN___5 = 158,
	GP_0_0_FN___5 = 159,
	GP_0_1_FN___5 = 160,
	GP_0_2_FN___5 = 161,
	GP_0_3_FN___5 = 162,
	GP_0_4_FN___5 = 163,
	GP_0_5_FN___5 = 164,
	GP_0_6_FN___5 = 165,
	GP_0_7_FN___5 = 166,
	GP_0_8_FN___5 = 167,
	GP_0_9_FN___5 = 168,
	GP_0_10_FN___5 = 169,
	GP_0_11_FN___5 = 170,
	GP_0_12_FN___5 = 171,
	GP_0_13_FN___5 = 172,
	GP_0_14_FN___5 = 173,
	GP_0_15_FN___5 = 174,
	GP_1_0_FN___5 = 175,
	GP_1_1_FN___5 = 176,
	GP_1_2_FN___5 = 177,
	GP_1_3_FN___5 = 178,
	GP_1_4_FN___5 = 179,
	GP_1_5_FN___5 = 180,
	GP_1_6_FN___5 = 181,
	GP_1_7_FN___5 = 182,
	GP_1_8_FN___5 = 183,
	GP_1_9_FN___5 = 184,
	GP_1_10_FN___5 = 185,
	GP_1_11_FN___5 = 186,
	GP_1_12_FN___5 = 187,
	GP_1_13_FN___5 = 188,
	GP_1_14_FN___5 = 189,
	GP_1_15_FN___5 = 190,
	GP_1_16_FN___5 = 191,
	GP_1_17_FN___5 = 192,
	GP_1_18_FN___5 = 193,
	GP_1_19_FN___5 = 194,
	GP_1_20_FN___5 = 195,
	GP_1_21_FN___5 = 196,
	GP_1_22_FN___5 = 197,
	GP_1_23_FN___4 = 198,
	GP_1_24_FN___4 = 199,
	GP_1_25_FN___4 = 200,
	GP_1_26_FN___4 = 201,
	GP_1_27_FN___4 = 202,
	GP_2_0_FN___5 = 203,
	GP_2_1_FN___5 = 204,
	GP_2_2_FN___5 = 205,
	GP_2_3_FN___5 = 206,
	GP_2_4_FN___5 = 207,
	GP_2_5_FN___5 = 208,
	GP_2_6_FN___5 = 209,
	GP_2_7_FN___5 = 210,
	GP_2_8_FN___5 = 211,
	GP_2_9_FN___5 = 212,
	GP_2_10_FN___5 = 213,
	GP_2_11_FN___5 = 214,
	GP_2_12_FN___5 = 215,
	GP_2_13_FN___5 = 216,
	GP_2_14_FN___5 = 217,
	GP_3_0_FN___5 = 218,
	GP_3_1_FN___5 = 219,
	GP_3_2_FN___5 = 220,
	GP_3_3_FN___5 = 221,
	GP_3_4_FN___5 = 222,
	GP_3_5_FN___5 = 223,
	GP_3_6_FN___5 = 224,
	GP_3_7_FN___5 = 225,
	GP_3_8_FN___5 = 226,
	GP_3_9_FN___5 = 227,
	GP_3_10_FN___5 = 228,
	GP_3_11_FN___5 = 229,
	GP_3_12_FN___5 = 230,
	GP_3_13_FN___5 = 231,
	GP_3_14_FN___5 = 232,
	GP_3_15_FN___5 = 233,
	GP_4_0_FN___5 = 234,
	GP_4_1_FN___5 = 235,
	GP_4_2_FN___5 = 236,
	GP_4_3_FN___5 = 237,
	GP_4_4_FN___5 = 238,
	GP_4_5_FN___5 = 239,
	GP_4_6_FN___5 = 240,
	GP_4_7_FN___5 = 241,
	GP_4_8_FN___5 = 242,
	GP_4_9_FN___5 = 243,
	GP_4_10_FN___5 = 244,
	GP_4_11_FN___4 = 245,
	GP_4_12_FN___4 = 246,
	GP_4_13_FN___4 = 247,
	GP_4_14_FN___4 = 248,
	GP_4_15_FN___4 = 249,
	GP_4_16_FN___4 = 250,
	GP_4_17_FN___4 = 251,
	GP_5_0_FN___5 = 252,
	GP_5_1_FN___5 = 253,
	GP_5_2_FN___5 = 254,
	GP_5_3_FN___5 = 255,
	GP_5_4_FN___5 = 256,
	GP_5_5_FN___5 = 257,
	GP_5_6_FN___5 = 258,
	GP_5_7_FN___5 = 259,
	GP_5_8_FN___5 = 260,
	GP_5_9_FN___5 = 261,
	GP_5_10_FN___5 = 262,
	GP_5_11_FN___5 = 263,
	GP_5_12_FN___5 = 264,
	GP_5_13_FN___5 = 265,
	GP_5_14_FN___5 = 266,
	GP_5_15_FN___5 = 267,
	GP_5_16_FN___5 = 268,
	GP_5_17_FN___5 = 269,
	GP_5_18_FN___5 = 270,
	GP_5_19_FN___5 = 271,
	GP_5_20_FN___4 = 272,
	GP_5_21_FN___4 = 273,
	GP_5_22_FN___4 = 274,
	GP_5_23_FN___4 = 275,
	GP_5_24_FN___4 = 276,
	GP_5_25_FN___4 = 277,
	GP_6_0_FN___5 = 278,
	GP_6_1_FN___5 = 279,
	GP_6_2_FN___5 = 280,
	GP_6_3_FN___5 = 281,
	GP_6_4_FN___5 = 282,
	GP_6_5_FN___5 = 283,
	GP_6_6_FN___5 = 284,
	GP_6_7_FN___5 = 285,
	GP_6_8_FN___5 = 286,
	GP_6_9_FN___5 = 287,
	GP_6_10_FN___5 = 288,
	GP_6_11_FN___5 = 289,
	GP_6_12_FN___5 = 290,
	GP_6_13_FN___5 = 291,
	GP_6_14_FN___5 = 292,
	GP_6_15_FN___5 = 293,
	GP_6_16_FN___5 = 294,
	GP_6_17_FN___5 = 295,
	GP_6_18_FN___4 = 296,
	GP_6_19_FN___4 = 297,
	GP_6_20_FN___4 = 298,
	GP_6_21_FN___4 = 299,
	GP_6_22_FN___4 = 300,
	GP_6_23_FN___4 = 301,
	GP_6_24_FN___4 = 302,
	GP_6_25_FN___4 = 303,
	GP_6_26_FN___4 = 304,
	GP_6_27_FN___4 = 305,
	GP_6_28_FN___4 = 306,
	GP_6_29_FN___4 = 307,
	GP_6_30_FN___4 = 308,
	GP_6_31_FN___4 = 309,
	GP_7_0_FN___4 = 310,
	GP_7_1_FN___4 = 311,
	GP_7_2_FN___4 = 312,
	GP_7_3_FN___4 = 313,
	FN_MSIOF0_RXD___5 = 314,
	FN_MSIOF0_TXD___5 = 315,
	FN_SD3_DS___5 = 316,
	FN_MSIOF0_SCK___5 = 317,
	FN_SSI_SDATA5___5 = 318,
	FN_SD3_DAT3___5 = 319,
	FN_SSI_WS5___5 = 320,
	FN_SD3_DAT2___5 = 321,
	FN_SSI_SCK5___5 = 322,
	FN_SD3_DAT1___5 = 323,
	FN_SD3_DAT0___5 = 324,
	FN_SD3_CMD___5 = 325,
	FN_SD3_CLK___5 = 326,
	FN_GP7_03___4 = 327,
	FN_GP7_02___4 = 328,
	FN_SD2_CMD___4 = 329,
	FN_AVS2___4 = 330,
	FN_AVS1___4 = 331,
	FN_IP0_3_0___5 = 332,
	FN_AVB_MDC___5 = 333,
	FN_MSIOF2_SS2_C___4 = 334,
	FN_IP1_3_0___5 = 335,
	FN_IRQ2___5 = 336,
	FN_QCPV_QDE___5 = 337,
	FN_DU_EXODDF_DU_ODDF_DISP_CDE___4 = 338,
	FN_VI4_DATA2_B___5 = 339,
	FN_PWM3_B___5 = 340,
	FN_IP2_3_0___5 = 341,
	FN_A1___5 = 342,
	FN_LCDOUT17___5 = 343,
	FN_MSIOF3_TXD_B___5 = 344,
	FN_VI4_DATA9___5 = 345,
	FN_DU_DB1___5 = 346,
	FN_PWM4_A___5 = 347,
	FN_IP3_3_0___5 = 348,
	FN_A9___5 = 349,
	FN_MSIOF2_SCK_A___5 = 350,
	FN_CTS4_N_B___4 = 351,
	FN_VI5_VSYNC_N___4 = 352,
	FN_IP0_7_4___5 = 353,
	FN_AVB_MAGIC___5 = 354,
	FN_MSIOF2_SS1_C___4 = 355,
	FN_SCK4_A___5 = 356,
	FN_IP1_7_4___5 = 357,
	FN_IRQ3___5 = 358,
	FN_QSTVB_QVE___5 = 359,
	FN_A25 = 360,
	FN_DU_DOTCLKOUT1___4 = 361,
	FN_VI4_DATA3_B___5 = 362,
	FN_PWM4_B___5 = 363,
	FN_IP2_7_4___5 = 364,
	FN_A2___5 = 365,
	FN_LCDOUT18___5 = 366,
	FN_MSIOF3_SCK_B___5 = 367,
	FN_VI4_DATA10___5 = 368,
	FN_DU_DB2___5 = 369,
	FN_PWM5_A___5 = 370,
	FN_IP3_7_4___5 = 371,
	FN_A10___5 = 372,
	FN_MSIOF2_RXD_A___5 = 373,
	FN_RTS4_N_B___4 = 374,
	FN_VI5_HSYNC_N___4 = 375,
	FN_IP0_11_8___5 = 376,
	FN_AVB_PHY_INT___5 = 377,
	FN_MSIOF2_SYNC_C___4 = 378,
	FN_RX4_A___5 = 379,
	FN_IP1_11_8___5 = 380,
	FN_IRQ4___5 = 381,
	FN_QSTH_QHS___5 = 382,
	FN_A24 = 383,
	FN_DU_EXHSYNC_DU_HSYNC___4 = 384,
	FN_VI4_DATA4_B___5 = 385,
	FN_PWM5_B___5 = 386,
	FN_IP2_11_8___5 = 387,
	FN_A3___5 = 388,
	FN_LCDOUT19___5 = 389,
	FN_MSIOF3_RXD_B___5 = 390,
	FN_VI4_DATA11___5 = 391,
	FN_DU_DB3___5 = 392,
	FN_PWM6_A___5 = 393,
	FN_IP3_11_8___5 = 394,
	FN_A11___5 = 395,
	FN_TX3_B___5 = 396,
	FN_MSIOF2_TXD_A___5 = 397,
	FN_HTX4_B___5 = 398,
	FN_HSCK4___4 = 399,
	FN_VI5_FIELD___4 = 400,
	FN_SCL6_A___5 = 401,
	FN_AVB_AVTP_CAPTURE_B___4 = 402,
	FN_PWM2_B___5 = 403,
	FN_IP0_15_12___5 = 404,
	FN_AVB_LINK___5 = 405,
	FN_MSIOF2_SCK_C___4 = 406,
	FN_TX4_A___5 = 407,
	FN_IP1_15_12___5 = 408,
	FN_IRQ5___5 = 409,
	FN_QSTB_QHE___5 = 410,
	FN_A23 = 411,
	FN_DU_EXVSYNC_DU_VSYNC___4 = 412,
	FN_VI4_DATA5_B___5 = 413,
	FN_PWM6_B___5 = 414,
	FN_IP2_15_12___5 = 415,
	FN_A4___5 = 416,
	FN_LCDOUT20___5 = 417,
	FN_MSIOF3_SS1_B___5 = 418,
	FN_VI4_DATA12___5 = 419,
	FN_VI5_DATA12___4 = 420,
	FN_DU_DB4___5 = 421,
	FN_IP3_15_12___5 = 422,
	FN_A12___5 = 423,
	FN_LCDOUT12___5 = 424,
	FN_MSIOF3_SCK_C___4 = 425,
	FN_HRX4_A___5 = 426,
	FN_VI5_DATA8___4 = 427,
	FN_DU_DG4___5 = 428,
	FN_IP0_19_16___5 = 429,
	FN_AVB_AVTP_MATCH_A___4 = 430,
	FN_MSIOF2_RXD_C___4 = 431,
	FN_CTS4_N_A___5 = 432,
	FN_IP1_19_16___5 = 433,
	FN_PWM0___4 = 434,
	FN_AVB_AVTP_PPS___5 = 435,
	FN_A22 = 436,
	FN_VI4_DATA6_B___5 = 437,
	FN_IECLK_B___4 = 438,
	FN_IP2_19_16___5 = 439,
	FN_A5___5 = 440,
	FN_LCDOUT21___5 = 441,
	FN_MSIOF3_SS2_B___4 = 442,
	FN_SCK4_B___5 = 443,
	FN_VI4_DATA13___5 = 444,
	FN_VI5_DATA13___4 = 445,
	FN_DU_DB5___5 = 446,
	FN_IP3_19_16___5 = 447,
	FN_A13___5 = 448,
	FN_LCDOUT13___5 = 449,
	FN_MSIOF3_SYNC_C___4 = 450,
	FN_HTX4_A___5 = 451,
	FN_VI5_DATA9___4 = 452,
	FN_DU_DG5___5 = 453,
	FN_IP0_23_20___5 = 454,
	FN_AVB_AVTP_CAPTURE_A___4 = 455,
	FN_MSIOF2_TXD_C___4 = 456,
	FN_RTS4_N_A___5 = 457,
	FN_IP1_23_20___5 = 458,
	FN_PWM1_A___5 = 459,
	FN_A21 = 460,
	FN_HRX3_D___5 = 461,
	FN_VI4_DATA7_B___5 = 462,
	FN_IERX_B___4 = 463,
	FN_IP2_23_20___5 = 464,
	FN_A6___5 = 465,
	FN_LCDOUT22___5 = 466,
	FN_MSIOF2_SS1_A___5 = 467,
	FN_RX4_B___5 = 468,
	FN_VI4_DATA14___5 = 469,
	FN_VI5_DATA14___4 = 470,
	FN_DU_DB6___5 = 471,
	FN_IP3_23_20___5 = 472,
	FN_A14___5 = 473,
	FN_LCDOUT14___5 = 474,
	FN_MSIOF3_RXD_C___4 = 475,
	FN_HCTS4_N___4 = 476,
	FN_VI5_DATA10___4 = 477,
	FN_DU_DG6___5 = 478,
	FN_IP0_27_24___5 = 479,
	FN_IRQ0___5 = 480,
	FN_QPOLB___5 = 481,
	FN_DU_CDE___5 = 482,
	FN_VI4_DATA0_B___5 = 483,
	FN_CAN0_TX_B___4 = 484,
	FN_CANFD0_TX_B___4 = 485,
	FN_IP1_27_24___5 = 486,
	FN_PWM2_A___5 = 487,
	FN_A20 = 488,
	FN_HTX3_D___5 = 489,
	FN_IETX_B___4 = 490,
	FN_IP2_27_24___5 = 491,
	FN_A7___5 = 492,
	FN_LCDOUT23___5 = 493,
	FN_MSIOF2_SS2_A___5 = 494,
	FN_TX4_B___5 = 495,
	FN_VI4_DATA15___5 = 496,
	FN_VI5_DATA15___4 = 497,
	FN_DU_DB7___5 = 498,
	FN_IP3_27_24___5 = 499,
	FN_A15___5 = 500,
	FN_LCDOUT15___5 = 501,
	FN_MSIOF3_TXD_C___4 = 502,
	FN_HRTS4_N___4 = 503,
	FN_VI5_DATA11___4 = 504,
	FN_DU_DG7___5 = 505,
	FN_IP0_31_28___5 = 506,
	FN_IRQ1___5 = 507,
	FN_QPOLA___5 = 508,
	FN_DU_DISP___5 = 509,
	FN_VI4_DATA1_B___5 = 510,
	FN_CAN0_RX_B___4 = 511,
	FN_CANFD0_RX_B___4 = 512,
	FN_IP1_31_28___5 = 513,
	FN_A0___5 = 514,
	FN_LCDOUT16___5 = 515,
	FN_MSIOF3_SYNC_B___5 = 516,
	FN_VI4_DATA8___5 = 517,
	FN_DU_DB0___5 = 518,
	FN_PWM3_A___5 = 519,
	FN_IP2_31_28___5 = 520,
	FN_A8___5 = 521,
	FN_RX3_B___5 = 522,
	FN_MSIOF2_SYNC_A___5 = 523,
	FN_HRX4_B___5 = 524,
	FN_SDA6_A___5 = 525,
	FN_AVB_AVTP_MATCH_B___4 = 526,
	FN_PWM1_B___5 = 527,
	FN_IP3_31_28___5 = 528,
	FN_A16___5 = 529,
	FN_LCDOUT8___5 = 530,
	FN_VI4_FIELD___5 = 531,
	FN_DU_DG0___5 = 532,
	FN_IP4_3_0___5 = 533,
	FN_A17___5 = 534,
	FN_LCDOUT9___5 = 535,
	FN_VI4_VSYNC_N___5 = 536,
	FN_DU_DG1___5 = 537,
	FN_IP5_3_0___5 = 538,
	FN_WE0_N___5 = 539,
	FN_MSIOF3_TXD_D___4 = 540,
	FN_CTS3_N___4 = 541,
	FN_HCTS3_N___4 = 542,
	FN_SCL6_B___5 = 543,
	FN_CAN_CLK___5 = 544,
	FN_IECLK_A___4 = 545,
	FN_IP6_3_0___5 = 546,
	FN_D5___5 = 547,
	FN_MSIOF2_SYNC_B___5 = 548,
	FN_VI4_DATA21___5 = 549,
	FN_VI5_DATA5___4 = 550,
	FN_IP7_3_0___5 = 551,
	FN_D13___5 = 552,
	FN_LCDOUT5___5 = 553,
	FN_MSIOF2_SS2_D___4 = 554,
	FN_TX4_C___5 = 555,
	FN_VI4_DATA5_A___5 = 556,
	FN_DU_DR5___5 = 557,
	FN_IP4_7_4___5 = 558,
	FN_A18___5 = 559,
	FN_LCDOUT10___5 = 560,
	FN_VI4_HSYNC_N___5 = 561,
	FN_DU_DG2___5 = 562,
	FN_IP5_7_4___5 = 563,
	FN_WE1_N___5 = 564,
	FN_MSIOF3_SS1_D___4 = 565,
	FN_RTS3_N___4 = 566,
	FN_HRTS3_N___4 = 567,
	FN_SDA6_B___5 = 568,
	FN_CAN1_RX___5 = 569,
	FN_CANFD1_RX___5 = 570,
	FN_IERX_A___4 = 571,
	FN_IP6_7_4___5 = 572,
	FN_D6___5 = 573,
	FN_MSIOF2_RXD_B___5 = 574,
	FN_VI4_DATA22___5 = 575,
	FN_VI5_DATA6___4 = 576,
	FN_IP7_7_4___5 = 577,
	FN_D14___5 = 578,
	FN_LCDOUT6___5 = 579,
	FN_MSIOF3_SS1_A___5 = 580,
	FN_HRX3_C___5 = 581,
	FN_VI4_DATA6_A___5 = 582,
	FN_DU_DR6___5 = 583,
	FN_SCL6_C___4 = 584,
	FN_IP4_11_8___5 = 585,
	FN_A19___5 = 586,
	FN_LCDOUT11___5 = 587,
	FN_VI4_CLKENB___5 = 588,
	FN_DU_DG3___5 = 589,
	FN_IP5_11_8___5 = 590,
	FN_EX_WAIT0_A___4 = 591,
	FN_QCLK___5 = 592,
	FN_VI4_CLK___5 = 593,
	FN_DU_DOTCLKOUT0___5 = 594,
	FN_IP6_11_8___5 = 595,
	FN_D7___5 = 596,
	FN_MSIOF2_TXD_B___5 = 597,
	FN_VI4_DATA23___5 = 598,
	FN_VI5_DATA7___4 = 599,
	FN_IP7_11_8___5 = 600,
	FN_D15___5 = 601,
	FN_LCDOUT7___5 = 602,
	FN_MSIOF3_SS2_A___5 = 603,
	FN_HTX3_C___5 = 604,
	FN_VI4_DATA7_A___5 = 605,
	FN_DU_DR7___5 = 606,
	FN_SDA6_C___4 = 607,
	FN_IP4_15_12___5 = 608,
	FN_CS0_N___5 = 609,
	FN_VI5_CLKENB___4 = 610,
	FN_IP5_15_12___5 = 611,
	FN_D0___5 = 612,
	FN_MSIOF2_SS1_B___5 = 613,
	FN_MSIOF3_SCK_A___5 = 614,
	FN_VI4_DATA16___5 = 615,
	FN_VI5_DATA0___4 = 616,
	FN_IP6_15_12___5 = 617,
	FN_D8___5 = 618,
	FN_LCDOUT0___5 = 619,
	FN_MSIOF2_SCK_D___4 = 620,
	FN_SCK4_C___4 = 621,
	FN_VI4_DATA0_A___5 = 622,
	FN_DU_DR0___5 = 623,
	FN_IP7_15_12___2 = 624,
	FN_FSCLKST = 625,
	FN_IP4_19_16___5 = 626,
	FN_CS1_N_A26___2 = 627,
	FN_VI5_CLK___4 = 628,
	FN_EX_WAIT0_B___4 = 629,
	FN_IP5_19_16___5 = 630,
	FN_D1___5 = 631,
	FN_MSIOF2_SS2_B___5 = 632,
	FN_MSIOF3_SYNC_A___5 = 633,
	FN_VI4_DATA17___5 = 634,
	FN_VI5_DATA1___4 = 635,
	FN_IP6_19_16___5 = 636,
	FN_D9___5 = 637,
	FN_LCDOUT1___5 = 638,
	FN_MSIOF2_SYNC_D___4 = 639,
	FN_VI4_DATA1_A___5 = 640,
	FN_DU_DR1___5 = 641,
	FN_IP7_19_16___5 = 642,
	FN_SD0_CLK___5 = 643,
	FN_MSIOF1_SCK_E___4 = 644,
	FN_STP_OPWM_0_B___4 = 645,
	FN_IP4_23_20___5 = 646,
	FN_BS_N___5 = 647,
	FN_QSTVA_QVS___5 = 648,
	FN_MSIOF3_SCK_D___4 = 649,
	FN_SCK3___4 = 650,
	FN_HSCK3___4 = 651,
	FN_CAN1_TX___5 = 652,
	FN_CANFD1_TX___5 = 653,
	FN_IETX_A___4 = 654,
	FN_IP5_23_20___5 = 655,
	FN_D2___5 = 656,
	FN_MSIOF3_RXD_A___5 = 657,
	FN_VI4_DATA18___5 = 658,
	FN_VI5_DATA2___4 = 659,
	FN_IP6_23_20___5 = 660,
	FN_D10___5 = 661,
	FN_LCDOUT2___5 = 662,
	FN_MSIOF2_RXD_D___4 = 663,
	FN_HRX3_B___5 = 664,
	FN_VI4_DATA2_A___5 = 665,
	FN_CTS4_N_C___5 = 666,
	FN_DU_DR2___5 = 667,
	FN_IP7_23_20___5 = 668,
	FN_SD0_CMD___5 = 669,
	FN_MSIOF1_SYNC_E___4 = 670,
	FN_STP_IVCXO27_0_B___4 = 671,
	FN_IP4_27_24___5 = 672,
	FN_RD_N___5 = 673,
	FN_MSIOF3_SYNC_D___4 = 674,
	FN_RX3_A___5 = 675,
	FN_HRX3_A___5 = 676,
	FN_CAN0_TX_A___4 = 677,
	FN_CANFD0_TX_A___4 = 678,
	FN_IP5_27_24___5 = 679,
	FN_D3___5 = 680,
	FN_MSIOF3_TXD_A___5 = 681,
	FN_VI4_DATA19___5 = 682,
	FN_VI5_DATA3___4 = 683,
	FN_IP6_27_24___5 = 684,
	FN_D11___5 = 685,
	FN_LCDOUT3___5 = 686,
	FN_MSIOF2_TXD_D___4 = 687,
	FN_HTX3_B___5 = 688,
	FN_VI4_DATA3_A___5 = 689,
	FN_RTS4_N_C___5 = 690,
	FN_DU_DR3___5 = 691,
	FN_IP7_27_24___5 = 692,
	FN_SD0_DAT0___5 = 693,
	FN_MSIOF1_RXD_E___4 = 694,
	FN_TS_SCK0_B___4 = 695,
	FN_STP_ISCLK_0_B___4 = 696,
	FN_IP4_31_28___5 = 697,
	FN_RD_WR_N___5 = 698,
	FN_MSIOF3_RXD_D___4 = 699,
	FN_TX3_A___5 = 700,
	FN_HTX3_A___5 = 701,
	FN_CAN0_RX_A___4 = 702,
	FN_CANFD0_RX_A___4 = 703,
	FN_IP5_31_28___5 = 704,
	FN_D4___5 = 705,
	FN_MSIOF2_SCK_B___5 = 706,
	FN_VI4_DATA20___5 = 707,
	FN_VI5_DATA4___4 = 708,
	FN_IP6_31_28___5 = 709,
	FN_D12___5 = 710,
	FN_LCDOUT4___5 = 711,
	FN_MSIOF2_SS1_D___4 = 712,
	FN_RX4_C___5 = 713,
	FN_VI4_DATA4_A___5 = 714,
	FN_DU_DR4___5 = 715,
	FN_IP7_31_28___5 = 716,
	FN_SD0_DAT1___5 = 717,
	FN_MSIOF1_TXD_E___4 = 718,
	FN_TS_SPSYNC0_B___4 = 719,
	FN_STP_ISSYNC_0_B___4 = 720,
	FN_IP8_3_0___5 = 721,
	FN_SD0_DAT2___5 = 722,
	FN_MSIOF1_SS1_E___4 = 723,
	FN_TS_SDAT0_B___4 = 724,
	FN_STP_ISD_0_B___4 = 725,
	FN_IP9_3_0___5 = 726,
	FN_SD2_CLK___4 = 727,
	FN_IP10_3_0___5 = 728,
	FN_SD3_DAT6___5 = 729,
	FN_SD3_CD___5 = 730,
	FN_IP11_3_0___5 = 731,
	FN_TX0___4 = 732,
	FN_HTX1_B___5 = 733,
	FN_TS_SPSYNC0_C___4 = 734,
	FN_STP_ISSYNC_0_C___4 = 735,
	FN_RIF0_D1_B___5 = 736,
	FN_IP8_7_4___5 = 737,
	FN_SD0_DAT3___5 = 738,
	FN_MSIOF1_SS2_E___4 = 739,
	FN_TS_SDEN0_B___4 = 740,
	FN_STP_ISEN_0_B___4 = 741,
	FN_IP9_7_4___5 = 742,
	FN_SD2_DAT0___4 = 743,
	FN_IP10_7_4___5 = 744,
	FN_SD3_DAT7___5 = 745,
	FN_SD3_WP___5 = 746,
	FN_IP11_7_4___5 = 747,
	FN_CTS0_N___4 = 748,
	FN_HCTS1_N_B___5 = 749,
	FN_MSIOF1_SYNC_B___4 = 750,
	FN_TS_SPSYNC1_C___4 = 751,
	FN_STP_ISSYNC_1_C___4 = 752,
	FN_RIF1_SYNC_B___4 = 753,
	FN_AUDIO_CLKOUT_C___4 = 754,
	FN_ADICS_SAMP___4 = 755,
	FN_IP8_11_8___5 = 756,
	FN_SD1_CLK___5 = 757,
	FN_MSIOF1_SCK_G___4 = 758,
	FN_SIM0_CLK_A___5 = 759,
	FN_IP9_11_8___5 = 760,
	FN_SD2_DAT1___4 = 761,
	FN_IP10_11_8___5 = 762,
	FN_SD0_CD___5 = 763,
	FN_SCL2_B___5 = 764,
	FN_SIM0_RST_A___5 = 765,
	FN_IP11_11_8___5 = 766,
	FN_RTS0_N___4 = 767,
	FN_HRTS1_N_B___5 = 768,
	FN_MSIOF1_SS1_B___4 = 769,
	FN_AUDIO_CLKA_B___4 = 770,
	FN_SCL2_A___5 = 771,
	FN_STP_IVCXO27_1_C___4 = 772,
	FN_RIF0_SYNC_B___5 = 773,
	FN_ADICHS1___4 = 774,
	FN_IP8_15_12___5 = 775,
	FN_SD1_CMD___5 = 776,
	FN_MSIOF1_SYNC_G___4 = 777,
	FN_SIM0_D_A___5 = 778,
	FN_STP_IVCXO27_1_B___4 = 779,
	FN_IP9_15_12___5 = 780,
	FN_SD2_DAT2___4 = 781,
	FN_IP10_15_12___5 = 782,
	FN_SD0_WP___5 = 783,
	FN_SDA2_B___5 = 784,
	FN_IP11_15_12___5 = 785,
	FN_RX1_A___4 = 786,
	FN_HRX1_A___5 = 787,
	FN_TS_SDAT0_C___4 = 788,
	FN_STP_ISD_0_C___4 = 789,
	FN_RIF1_CLK_C___4 = 790,
	FN_IP8_19_16___5 = 791,
	FN_SD1_DAT0___5 = 792,
	FN_SD2_DAT4___4 = 793,
	FN_MSIOF1_RXD_G___4 = 794,
	FN_TS_SCK1_B___4 = 795,
	FN_STP_ISCLK_1_B___4 = 796,
	FN_IP9_19_16___5 = 797,
	FN_SD2_DAT3___4 = 798,
	FN_IP10_19_16___5 = 799,
	FN_SD1_CD___5 = 800,
	FN_SIM0_CLK_B___5 = 801,
	FN_IP11_19_16___5 = 802,
	FN_TX1_A___4 = 803,
	FN_HTX1_A___5 = 804,
	FN_TS_SDEN0_C___4 = 805,
	FN_STP_ISEN_0_C___4 = 806,
	FN_RIF1_D0_C___4 = 807,
	FN_IP8_23_20___5 = 808,
	FN_SD1_DAT1___5 = 809,
	FN_SD2_DAT5___4 = 810,
	FN_MSIOF1_TXD_G___4 = 811,
	FN_TS_SPSYNC1_B___4 = 812,
	FN_STP_ISSYNC_1_B___4 = 813,
	FN_IP9_23_20___5 = 814,
	FN_SD2_DS___4 = 815,
	FN_SATA_DEVSLP_B___3 = 816,
	FN_IP10_23_20___5 = 817,
	FN_SD1_WP___5 = 818,
	FN_SIM0_D_B___5 = 819,
	FN_IP11_23_20___5 = 820,
	FN_CTS1_N___5 = 821,
	FN_HCTS1_N_A___4 = 822,
	FN_MSIOF1_RXD_B___4 = 823,
	FN_TS_SDEN1_C___4 = 824,
	FN_STP_ISEN_1_C___4 = 825,
	FN_RIF1_D0_B___4 = 826,
	FN_ADIDATA___4 = 827,
	FN_IP8_27_24___5 = 828,
	FN_SD1_DAT2___5 = 829,
	FN_SD2_DAT6___4 = 830,
	FN_MSIOF1_SS1_G___4 = 831,
	FN_TS_SDAT1_B___4 = 832,
	FN_STP_ISD_1_B___4 = 833,
	FN_IP9_27_24___5 = 834,
	FN_SD3_DAT4___5 = 835,
	FN_SD2_CD_A___4 = 836,
	FN_IP10_27_24___5 = 837,
	FN_SCK0___4 = 838,
	FN_HSCK1_B___5 = 839,
	FN_MSIOF1_SS2_B___4 = 840,
	FN_AUDIO_CLKC_B___5 = 841,
	FN_SDA2_A___5 = 842,
	FN_SIM0_RST_B___5 = 843,
	FN_STP_OPWM_0_C___4 = 844,
	FN_RIF0_CLK_B___5 = 845,
	FN_ADICHS2___4 = 846,
	FN_IP11_27_24___5 = 847,
	FN_RTS1_N___5 = 848,
	FN_HRTS1_N_A___4 = 849,
	FN_MSIOF1_TXD_B___4 = 850,
	FN_TS_SDAT1_C___4 = 851,
	FN_STP_ISD_1_C___4 = 852,
	FN_RIF1_D1_B___4 = 853,
	FN_ADICHS0___4 = 854,
	FN_IP8_31_28___5 = 855,
	FN_SD1_DAT3___5 = 856,
	FN_SD2_DAT7___4 = 857,
	FN_MSIOF1_SS2_G___4 = 858,
	FN_TS_SDEN1_B___4 = 859,
	FN_STP_ISEN_1_B___4 = 860,
	FN_IP9_31_28___5 = 861,
	FN_SD3_DAT5___5 = 862,
	FN_SD2_WP_A___4 = 863,
	FN_IP10_31_28___5 = 864,
	FN_RX0___4 = 865,
	FN_HRX1_B___5 = 866,
	FN_TS_SCK0_C___4 = 867,
	FN_STP_ISCLK_0_C___4 = 868,
	FN_RIF0_D0_B___5 = 869,
	FN_IP11_31_28___5 = 870,
	FN_SCK2___4 = 871,
	FN_SCIF_CLK_B___5 = 872,
	FN_MSIOF1_SCK_B___4 = 873,
	FN_TS_SCK1_C___4 = 874,
	FN_STP_ISCLK_1_C___4 = 875,
	FN_RIF1_CLK_B___4 = 876,
	FN_ADICLK___4 = 877,
	FN_IP12_3_0___5 = 878,
	FN_TX2_A___5 = 879,
	FN_SD2_CD_B___4 = 880,
	FN_SCL1_A___5 = 881,
	FN_FMCLK_A___5 = 882,
	FN_RIF1_D1_C___4 = 883,
	FN_FSO_CFE_0_B = 884,
	FN_IP13_3_0___5 = 885,
	FN_MSIOF0_SS1___5 = 886,
	FN_RX5 = 887,
	FN_AUDIO_CLKA_C___4 = 888,
	FN_SSI_SCK2_A___5 = 889,
	FN_STP_IVCXO27_0_C___4 = 890,
	FN_AUDIO_CLKOUT3_A___5 = 891,
	FN_TCLK1_B___5 = 892,
	FN_IP14_3_0___5 = 893,
	FN_SSI_SDATA1_A___4 = 894,
	FN_IP15_3_0___5 = 895,
	FN_SSI_SCK6___5 = 896,
	FN_USB2_PWEN___2 = 897,
	FN_SIM0_RST_D___4 = 898,
	FN_IP12_7_4___5 = 899,
	FN_RX2_A___5 = 900,
	FN_SD2_WP_B___4 = 901,
	FN_SDA1_A___5 = 902,
	FN_FMIN_A___5 = 903,
	FN_RIF1_SYNC_C___4 = 904,
	FN_FSO_CFE_1_B = 905,
	FN_IP13_7_4___5 = 906,
	FN_MSIOF0_SS2___5 = 907,
	FN_TX5 = 908,
	FN_MSIOF1_SS2_D___4 = 909,
	FN_AUDIO_CLKC_A___5 = 910,
	FN_SSI_WS2_A___5 = 911,
	FN_STP_OPWM_0_D___4 = 912,
	FN_AUDIO_CLKOUT_D___4 = 913,
	FN_SPEEDIN_B___5 = 914,
	FN_IP14_7_4___5 = 915,
	FN_SSI_SDATA2_A___4 = 916,
	FN_SSI_SCK1_B___4 = 917,
	FN_IP15_7_4___5 = 918,
	FN_SSI_WS6___5 = 919,
	FN_USB2_OVC___2 = 920,
	FN_SIM0_D_D___4 = 921,
	FN_IP12_11_8___5 = 922,
	FN_HSCK0___4 = 923,
	FN_MSIOF1_SCK_D___4 = 924,
	FN_AUDIO_CLKB_A___5 = 925,
	FN_SSI_SDATA1_B___4 = 926,
	FN_TS_SCK0_D___4 = 927,
	FN_STP_ISCLK_0_D___4 = 928,
	FN_RIF0_CLK_C___4 = 929,
	FN_IP13_11_8___5 = 930,
	FN_MLB_CLK___5 = 931,
	FN_MSIOF1_SCK_F___4 = 932,
	FN_SCL1_B___5 = 933,
	FN_IP14_11_8___5 = 934,
	FN_SSI_SCK349___5 = 935,
	FN_MSIOF1_SS1_A___4 = 936,
	FN_STP_OPWM_0_A___4 = 937,
	FN_IP15_11_8___5 = 938,
	FN_SSI_SDATA6___5 = 939,
	FN_SIM0_CLK_D___4 = 940,
	FN_SATA_DEVSLP_A___3 = 941,
	FN_IP12_15_12___5 = 942,
	FN_HRX0___4 = 943,
	FN_MSIOF1_RXD_D___4 = 944,
	FN_SSI_SDATA2_B___4 = 945,
	FN_TS_SDEN0_D___4 = 946,
	FN_STP_ISEN_0_D___4 = 947,
	FN_RIF0_D0_C___4 = 948,
	FN_IP13_15_12___5 = 949,
	FN_MLB_SIG___5 = 950,
	FN_RX1_B___4 = 951,
	FN_MSIOF1_SYNC_F___4 = 952,
	FN_SDA1_B___5 = 953,
	FN_IP14_15_12___5 = 954,
	FN_SSI_WS349___5 = 955,
	FN_HCTS2_N_A___5 = 956,
	FN_MSIOF1_SS2_A___4 = 957,
	FN_STP_IVCXO27_0_A___4 = 958,
	FN_IP15_15_12___5 = 959,
	FN_SSI_SCK78___5 = 960,
	FN_HRX2_B___5 = 961,
	FN_MSIOF1_SCK_C___4 = 962,
	FN_TS_SCK1_A___4 = 963,
	FN_STP_ISCLK_1_A___4 = 964,
	FN_RIF1_CLK_A___4 = 965,
	FN_RIF3_CLK_A___5 = 966,
	FN_IP12_19_16___5 = 967,
	FN_HTX0___4 = 968,
	FN_MSIOF1_TXD_D___4 = 969,
	FN_SSI_SDATA9_B___4 = 970,
	FN_TS_SDAT0_D___4 = 971,
	FN_STP_ISD_0_D___4 = 972,
	FN_RIF0_D1_C___4 = 973,
	FN_IP13_19_16___5 = 974,
	FN_MLB_DAT___5 = 975,
	FN_TX1_B___4 = 976,
	FN_MSIOF1_RXD_F___4 = 977,
	FN_IP14_19_16___5 = 978,
	FN_SSI_SDATA3___5 = 979,
	FN_HRTS2_N_A___5 = 980,
	FN_MSIOF1_TXD_A___4 = 981,
	FN_TS_SCK0_A___4 = 982,
	FN_STP_ISCLK_0_A___4 = 983,
	FN_RIF0_D1_A___5 = 984,
	FN_RIF2_D0_A___5 = 985,
	FN_IP15_19_16___5 = 986,
	FN_SSI_WS78___5 = 987,
	FN_HTX2_B___5 = 988,
	FN_MSIOF1_SYNC_C___4 = 989,
	FN_TS_SDAT1_A___4 = 990,
	FN_STP_ISD_1_A___4 = 991,
	FN_RIF1_SYNC_A___4 = 992,
	FN_RIF3_SYNC_A___5 = 993,
	FN_IP12_23_20___5 = 994,
	FN_HCTS0_N___4 = 995,
	FN_RX2_B___5 = 996,
	FN_MSIOF1_SYNC_D___4 = 997,
	FN_SSI_SCK9_A___5 = 998,
	FN_TS_SPSYNC0_D___4 = 999,
	FN_STP_ISSYNC_0_D___4 = 1000,
	FN_RIF0_SYNC_C___4 = 1001,
	FN_AUDIO_CLKOUT1_A___5 = 1002,
	FN_IP13_23_20___5 = 1003,
	FN_SSI_SCK01239___5 = 1004,
	FN_MSIOF1_TXD_F___4 = 1005,
	FN_IP14_23_20___5 = 1006,
	FN_SSI_SCK4___5 = 1007,
	FN_HRX2_A___5 = 1008,
	FN_MSIOF1_SCK_A___4 = 1009,
	FN_TS_SDAT0_A___4 = 1010,
	FN_STP_ISD_0_A___4 = 1011,
	FN_RIF0_CLK_A___5 = 1012,
	FN_RIF2_CLK_A___5 = 1013,
	FN_IP15_23_20___5 = 1014,
	FN_SSI_SDATA7___5 = 1015,
	FN_HCTS2_N_B___4 = 1016,
	FN_MSIOF1_RXD_C___4 = 1017,
	FN_TS_SDEN1_A___4 = 1018,
	FN_STP_ISEN_1_A___4 = 1019,
	FN_RIF1_D0_A___4 = 1020,
	FN_RIF3_D0_A___5 = 1021,
	FN_TCLK2_A___5 = 1022,
	FN_IP12_27_24___5 = 1023,
	FN_HRTS0_N___4 = 1024,
	FN_TX2_B___5 = 1025,
	FN_MSIOF1_SS1_D___4 = 1026,
	FN_SSI_WS9_A___5 = 1027,
	FN_STP_IVCXO27_0_D___4 = 1028,
	FN_BPFCLK_A___5 = 1029,
	FN_AUDIO_CLKOUT2_A___5 = 1030,
	FN_IP13_27_24___5 = 1031,
	FN_SSI_WS01239___5 = 1032,
	FN_MSIOF1_SS1_F___4 = 1033,
	FN_IP14_27_24___5 = 1034,
	FN_SSI_WS4___5 = 1035,
	FN_HTX2_A___5 = 1036,
	FN_MSIOF1_SYNC_A___4 = 1037,
	FN_TS_SDEN0_A___4 = 1038,
	FN_STP_ISEN_0_A___4 = 1039,
	FN_RIF0_SYNC_A___5 = 1040,
	FN_RIF2_SYNC_A___5 = 1041,
	FN_IP15_27_24___5 = 1042,
	FN_SSI_SDATA8___5 = 1043,
	FN_HRTS2_N_B___4 = 1044,
	FN_MSIOF1_TXD_C___4 = 1045,
	FN_TS_SPSYNC1_A___4 = 1046,
	FN_STP_ISSYNC_1_A___4 = 1047,
	FN_RIF1_D1_A___4 = 1048,
	FN_RIF3_D1_A___5 = 1049,
	FN_IP12_31_28___5 = 1050,
	FN_MSIOF0_SYNC___5 = 1051,
	FN_AUDIO_CLKOUT_A___5 = 1052,
	FN_IP13_31_28___5 = 1053,
	FN_SSI_SDATA0___5 = 1054,
	FN_MSIOF1_SS2_F___4 = 1055,
	FN_IP14_31_28___5 = 1056,
	FN_SSI_SDATA4___5 = 1057,
	FN_HSCK2_A___5 = 1058,
	FN_MSIOF1_RXD_A___4 = 1059,
	FN_TS_SPSYNC0_A___4 = 1060,
	FN_STP_ISSYNC_0_A___4 = 1061,
	FN_RIF0_D0_A___5 = 1062,
	FN_RIF2_D1_A___5 = 1063,
	FN_IP15_31_28___5 = 1064,
	FN_SSI_SDATA9_A___4 = 1065,
	FN_HSCK2_B___4 = 1066,
	FN_MSIOF1_SS1_C___4 = 1067,
	FN_HSCK1_A___5 = 1068,
	FN_SSI_WS1_B___4 = 1069,
	FN_SCK1___5 = 1070,
	FN_STP_IVCXO27_1_A___4 = 1071,
	FN_SCK5 = 1072,
	FN_IP16_3_0___4 = 1073,
	FN_AUDIO_CLKA_A___4 = 1074,
	FN_IP17_3_0___4 = 1075,
	FN_USB31_PWEN = 1076,
	FN_AUDIO_CLKOUT2_B___5 = 1077,
	FN_SSI_SCK9_B___5 = 1078,
	FN_TS_SDEN0_E___4 = 1079,
	FN_STP_ISEN_0_E___4 = 1080,
	FN_RIF2_D0_B___5 = 1081,
	FN_TPU0TO2___5 = 1082,
	FN_IP16_7_4___4 = 1083,
	FN_AUDIO_CLKB_B___5 = 1084,
	FN_SCIF_CLK_A___5 = 1085,
	FN_STP_IVCXO27_1_D___4 = 1086,
	FN_REMOCON_A___5 = 1087,
	FN_TCLK1_A___5 = 1088,
	FN_IP17_7_4___4 = 1089,
	FN_USB31_OVC = 1090,
	FN_AUDIO_CLKOUT3_B___5 = 1091,
	FN_SSI_WS9_B___5 = 1092,
	FN_TS_SPSYNC0_E___4 = 1093,
	FN_STP_ISSYNC_0_E___4 = 1094,
	FN_RIF2_D1_B___5 = 1095,
	FN_TPU0TO3___5 = 1096,
	FN_IP16_11_8___4 = 1097,
	FN_USB0_PWEN___4 = 1098,
	FN_SIM0_RST_C___4 = 1099,
	FN_TS_SCK1_D___4 = 1100,
	FN_STP_ISCLK_1_D___4 = 1101,
	FN_BPFCLK_B___5 = 1102,
	FN_RIF3_CLK_B___5 = 1103,
	FN_IP16_15_12___4 = 1104,
	FN_USB0_OVC___4 = 1105,
	FN_SIM0_D_C___4 = 1106,
	FN_TS_SDAT1_D___4 = 1107,
	FN_STP_ISD_1_D___4 = 1108,
	FN_RIF3_SYNC_B___5 = 1109,
	FN_IP16_19_16___4 = 1110,
	FN_USB1_PWEN___4 = 1111,
	FN_SIM0_CLK_C___4 = 1112,
	FN_SSI_SCK1_A___4 = 1113,
	FN_TS_SCK0_E___4 = 1114,
	FN_STP_ISCLK_0_E___4 = 1115,
	FN_FMCLK_B___5 = 1116,
	FN_RIF2_CLK_B___5 = 1117,
	FN_SPEEDIN_A___5 = 1118,
	FN_IP16_23_20___4 = 1119,
	FN_USB1_OVC___4 = 1120,
	FN_MSIOF1_SS2_C___4 = 1121,
	FN_SSI_WS1_A___4 = 1122,
	FN_TS_SDAT0_E___4 = 1123,
	FN_STP_ISD_0_E___4 = 1124,
	FN_FMIN_B___5 = 1125,
	FN_RIF2_SYNC_B___5 = 1126,
	FN_REMOCON_B___5 = 1127,
	FN_IP16_27_24___4 = 1128,
	FN_USB30_PWEN___5 = 1129,
	FN_AUDIO_CLKOUT_B___5 = 1130,
	FN_SSI_SCK2_B___5 = 1131,
	FN_TS_SDEN1_D___4 = 1132,
	FN_STP_ISEN_1_D___4 = 1133,
	FN_STP_OPWM_0_E___4 = 1134,
	FN_RIF3_D0_B___5 = 1135,
	FN_TCLK2_B___5 = 1136,
	FN_TPU0TO0___5 = 1137,
	FN_IP16_31_28___4 = 1138,
	FN_USB30_OVC___5 = 1139,
	FN_AUDIO_CLKOUT1_B___5 = 1140,
	FN_SSI_WS2_B___5 = 1141,
	FN_TS_SPSYNC1_D___4 = 1142,
	FN_STP_ISSYNC_1_D___4 = 1143,
	FN_STP_IVCXO27_0_E___4 = 1144,
	FN_RIF3_D1_B___5 = 1145,
	FN_FSO_TOE_B = 1146,
	FN_TPU0TO1___5 = 1147,
	FN_SEL_TSIF1_0___4 = 1148,
	FN_SEL_TSIF1_1___4 = 1149,
	FN_SEL_TSIF1_2___4 = 1150,
	FN_SEL_TSIF1_3___4 = 1151,
	FN_I2C_SEL_5_0___4 = 1152,
	FN_I2C_SEL_5_1___4 = 1153,
	FN_SEL_MSIOF3_0___5 = 1154,
	FN_SEL_MSIOF3_1___5 = 1155,
	FN_SEL_MSIOF3_2___4 = 1156,
	FN_SEL_MSIOF3_3___4 = 1157,
	FN_I2C_SEL_3_0___4 = 1158,
	FN_I2C_SEL_3_1___4 = 1159,
	FN_SEL_TSIF0_0___4 = 1160,
	FN_SEL_TSIF0_1___4 = 1161,
	FN_SEL_TSIF0_2___4 = 1162,
	FN_SEL_TSIF0_3___4 = 1163,
	FN_SEL_TSIF0_4___4 = 1164,
	FN_I2C_SEL_0_0___4 = 1165,
	FN_I2C_SEL_0_1___4 = 1166,
	FN_SEL_MSIOF2_0___5 = 1167,
	FN_SEL_MSIOF2_1___5 = 1168,
	FN_SEL_MSIOF2_2___4 = 1169,
	FN_SEL_MSIOF2_3___4 = 1170,
	FN_SEL_MSIOF1_0___4 = 1171,
	FN_SEL_MSIOF1_1___4 = 1172,
	FN_SEL_MSIOF1_2___4 = 1173,
	FN_SEL_MSIOF1_3___4 = 1174,
	FN_SEL_MSIOF1_4___4 = 1175,
	FN_SEL_MSIOF1_5___4 = 1176,
	FN_SEL_MSIOF1_6___4 = 1177,
	FN_SEL_TIMER_TMU_0___4 = 1178,
	FN_SEL_TIMER_TMU_1___4 = 1179,
	FN_SEL_SSP1_1_0___4 = 1180,
	FN_SEL_SSP1_1_1___4 = 1181,
	FN_SEL_SSP1_1_2___4 = 1182,
	FN_SEL_SSP1_1_3___4 = 1183,
	FN_SEL_LBSC_0___4 = 1184,
	FN_SEL_LBSC_1___4 = 1185,
	FN_SEL_SSP1_0_0___4 = 1186,
	FN_SEL_SSP1_0_1___4 = 1187,
	FN_SEL_SSP1_0_2___4 = 1188,
	FN_SEL_SSP1_0_3___4 = 1189,
	FN_SEL_SSP1_0_4___4 = 1190,
	FN_SEL_IEBUS_0___4 = 1191,
	FN_SEL_IEBUS_1___4 = 1192,
	FN_SEL_I2C6_0___5 = 1193,
	FN_SEL_I2C6_1___5 = 1194,
	FN_SEL_I2C6_2___4 = 1195,
	FN_SEL_SSI_0 = 1196,
	FN_SEL_SSI_1 = 1197,
	FN_SEL_I2C2_0___5 = 1198,
	FN_SEL_I2C2_1___5 = 1199,
	FN_SEL_SPEED_PULSE_0___4 = 1200,
	FN_SEL_SPEED_PULSE_1___4 = 1201,
	FN_SEL_I2C1_0___5 = 1202,
	FN_SEL_I2C1_1___5 = 1203,
	FN_SEL_SIMCARD_0___5 = 1204,
	FN_SEL_SIMCARD_1___5 = 1205,
	FN_SEL_SIMCARD_2___4 = 1206,
	FN_SEL_SIMCARD_3___4 = 1207,
	FN_SEL_HSCIF4_0___5 = 1208,
	FN_SEL_HSCIF4_1___5 = 1209,
	FN_SEL_HSCIF3_0___5 = 1210,
	FN_SEL_HSCIF3_1___5 = 1211,
	FN_SEL_HSCIF3_2___5 = 1212,
	FN_SEL_HSCIF3_3___5 = 1213,
	FN_SEL_SDHI2_0___4 = 1214,
	FN_SEL_SDHI2_1___4 = 1215,
	FN_SEL_SCIF4_0___5 = 1216,
	FN_SEL_SCIF4_1___5 = 1217,
	FN_SEL_SCIF4_2___5 = 1218,
	FN_SEL_HSCIF2_0___5 = 1219,
	FN_SEL_HSCIF2_1___5 = 1220,
	FN_SEL_HSCIF1_0___5 = 1221,
	FN_SEL_HSCIF1_1___5 = 1222,
	FN_SEL_SCIF3_0___5 = 1223,
	FN_SEL_SCIF3_1___5 = 1224,
	FN_SEL_FSO_0___2 = 1225,
	FN_SEL_FSO_1___2 = 1226,
	FN_SEL_SCIF2_0___5 = 1227,
	FN_SEL_SCIF2_1___5 = 1228,
	FN_SEL_FM_0___5 = 1229,
	FN_SEL_FM_1___5 = 1230,
	FN_SEL_SCIF1_0___4 = 1231,
	FN_SEL_SCIF1_1___4 = 1232,
	FN_SEL_ETHERAVB_0___4 = 1233,
	FN_SEL_ETHERAVB_1___4 = 1234,
	FN_SEL_SATA_0 = 1235,
	FN_SEL_SATA_1 = 1236,
	FN_SEL_DRIF3_0___5 = 1237,
	FN_SEL_DRIF3_1___5 = 1238,
	FN_SEL_REMOCON_0___5 = 1239,
	FN_SEL_REMOCON_1___5 = 1240,
	FN_SEL_DRIF2_0___5 = 1241,
	FN_SEL_DRIF2_1___5 = 1242,
	FN_SEL_DRIF1_0___4 = 1243,
	FN_SEL_DRIF1_1___4 = 1244,
	FN_SEL_DRIF1_2___4 = 1245,
	FN_SEL_RCAN0_0___4 = 1246,
	FN_SEL_RCAN0_1___4 = 1247,
	FN_SEL_DRIF0_0___5 = 1248,
	FN_SEL_DRIF0_1___5 = 1249,
	FN_SEL_DRIF0_2___4 = 1250,
	FN_SEL_PWM6_0___5 = 1251,
	FN_SEL_PWM6_1___5 = 1252,
	FN_SEL_PWM5_0___5 = 1253,
	FN_SEL_PWM5_1___5 = 1254,
	FN_SEL_CANFD0_0___4 = 1255,
	FN_SEL_CANFD0_1___4 = 1256,
	FN_SEL_PWM4_0___5 = 1257,
	FN_SEL_PWM4_1___5 = 1258,
	FN_SEL_ADG_0 = 1259,
	FN_SEL_ADG_1 = 1260,
	FN_SEL_ADG_2 = 1261,
	FN_SEL_ADG_3 = 1262,
	FN_SEL_PWM3_0___5 = 1263,
	FN_SEL_PWM3_1___5 = 1264,
	FN_SEL_PWM2_0___5 = 1265,
	FN_SEL_PWM2_1___5 = 1266,
	FN_SEL_PWM1_0___5 = 1267,
	FN_SEL_PWM1_1___5 = 1268,
	FN_SEL_VIN4_0___5 = 1269,
	FN_SEL_VIN4_1___5 = 1270,
	PINMUX_FUNCTION_END___5 = 1271,
	PINMUX_MARK_BEGIN___5 = 1272,
	MSIOF0_RXD_MARK___5 = 1273,
	MSIOF0_TXD_MARK___5 = 1274,
	SD3_DS_MARK___5 = 1275,
	MSIOF0_SCK_MARK___5 = 1276,
	SSI_SDATA5_MARK___5 = 1277,
	SD3_DAT3_MARK___5 = 1278,
	SSI_WS5_MARK___5 = 1279,
	SD3_DAT2_MARK___5 = 1280,
	SSI_SCK5_MARK___5 = 1281,
	SD3_DAT1_MARK___5 = 1282,
	SD3_DAT0_MARK___5 = 1283,
	SD3_CMD_MARK___5 = 1284,
	SD3_CLK_MARK___5 = 1285,
	GP7_03_MARK___4 = 1286,
	GP7_02_MARK___4 = 1287,
	SD2_CMD_MARK___4 = 1288,
	AVS2_MARK___4 = 1289,
	AVS1_MARK___4 = 1290,
	IP0_3_0_MARK___5 = 1291,
	AVB_MDC_MARK___5 = 1292,
	MSIOF2_SS2_C_MARK___4 = 1293,
	IP1_3_0_MARK___5 = 1294,
	IRQ2_MARK___5 = 1295,
	QCPV_QDE_MARK___5 = 1296,
	DU_EXODDF_DU_ODDF_DISP_CDE_MARK___4 = 1297,
	VI4_DATA2_B_MARK___5 = 1298,
	PWM3_B_MARK___5 = 1299,
	IP2_3_0_MARK___5 = 1300,
	A1_MARK___5 = 1301,
	LCDOUT17_MARK___5 = 1302,
	MSIOF3_TXD_B_MARK___5 = 1303,
	VI4_DATA9_MARK___5 = 1304,
	DU_DB1_MARK___5 = 1305,
	PWM4_A_MARK___5 = 1306,
	IP3_3_0_MARK___5 = 1307,
	A9_MARK___5 = 1308,
	MSIOF2_SCK_A_MARK___5 = 1309,
	CTS4_N_B_MARK___4 = 1310,
	VI5_VSYNC_N_MARK___4 = 1311,
	IP0_7_4_MARK___5 = 1312,
	AVB_MAGIC_MARK___5 = 1313,
	MSIOF2_SS1_C_MARK___4 = 1314,
	SCK4_A_MARK___5 = 1315,
	IP1_7_4_MARK___5 = 1316,
	IRQ3_MARK___5 = 1317,
	QSTVB_QVE_MARK___5 = 1318,
	A25_MARK = 1319,
	DU_DOTCLKOUT1_MARK___4 = 1320,
	VI4_DATA3_B_MARK___5 = 1321,
	PWM4_B_MARK___5 = 1322,
	IP2_7_4_MARK___5 = 1323,
	A2_MARK___5 = 1324,
	LCDOUT18_MARK___5 = 1325,
	MSIOF3_SCK_B_MARK___5 = 1326,
	VI4_DATA10_MARK___5 = 1327,
	DU_DB2_MARK___5 = 1328,
	PWM5_A_MARK___5 = 1329,
	IP3_7_4_MARK___5 = 1330,
	A10_MARK___5 = 1331,
	MSIOF2_RXD_A_MARK___5 = 1332,
	RTS4_N_B_MARK___4 = 1333,
	VI5_HSYNC_N_MARK___4 = 1334,
	IP0_11_8_MARK___5 = 1335,
	AVB_PHY_INT_MARK___5 = 1336,
	MSIOF2_SYNC_C_MARK___4 = 1337,
	RX4_A_MARK___5 = 1338,
	IP1_11_8_MARK___5 = 1339,
	IRQ4_MARK___5 = 1340,
	QSTH_QHS_MARK___5 = 1341,
	A24_MARK = 1342,
	DU_EXHSYNC_DU_HSYNC_MARK___4 = 1343,
	VI4_DATA4_B_MARK___5 = 1344,
	PWM5_B_MARK___5 = 1345,
	IP2_11_8_MARK___5 = 1346,
	A3_MARK___5 = 1347,
	LCDOUT19_MARK___5 = 1348,
	MSIOF3_RXD_B_MARK___5 = 1349,
	VI4_DATA11_MARK___5 = 1350,
	DU_DB3_MARK___5 = 1351,
	PWM6_A_MARK___5 = 1352,
	IP3_11_8_MARK___5 = 1353,
	A11_MARK___5 = 1354,
	TX3_B_MARK___5 = 1355,
	MSIOF2_TXD_A_MARK___5 = 1356,
	HTX4_B_MARK___5 = 1357,
	HSCK4_MARK___4 = 1358,
	VI5_FIELD_MARK___4 = 1359,
	SCL6_A_MARK___5 = 1360,
	AVB_AVTP_CAPTURE_B_MARK___4 = 1361,
	PWM2_B_MARK___5 = 1362,
	IP0_15_12_MARK___5 = 1363,
	AVB_LINK_MARK___5 = 1364,
	MSIOF2_SCK_C_MARK___4 = 1365,
	TX4_A_MARK___5 = 1366,
	IP1_15_12_MARK___5 = 1367,
	IRQ5_MARK___5 = 1368,
	QSTB_QHE_MARK___5 = 1369,
	A23_MARK = 1370,
	DU_EXVSYNC_DU_VSYNC_MARK___4 = 1371,
	VI4_DATA5_B_MARK___5 = 1372,
	PWM6_B_MARK___5 = 1373,
	IP2_15_12_MARK___5 = 1374,
	A4_MARK___5 = 1375,
	LCDOUT20_MARK___5 = 1376,
	MSIOF3_SS1_B_MARK___5 = 1377,
	VI4_DATA12_MARK___5 = 1378,
	VI5_DATA12_MARK___4 = 1379,
	DU_DB4_MARK___5 = 1380,
	IP3_15_12_MARK___5 = 1381,
	A12_MARK___5 = 1382,
	LCDOUT12_MARK___5 = 1383,
	MSIOF3_SCK_C_MARK___4 = 1384,
	HRX4_A_MARK___5 = 1385,
	VI5_DATA8_MARK___4 = 1386,
	DU_DG4_MARK___5 = 1387,
	IP0_19_16_MARK___5 = 1388,
	AVB_AVTP_MATCH_A_MARK___4 = 1389,
	MSIOF2_RXD_C_MARK___4 = 1390,
	CTS4_N_A_MARK___5 = 1391,
	IP1_19_16_MARK___5 = 1392,
	PWM0_MARK___4 = 1393,
	AVB_AVTP_PPS_MARK___5 = 1394,
	A22_MARK = 1395,
	VI4_DATA6_B_MARK___5 = 1396,
	IECLK_B_MARK___4 = 1397,
	IP2_19_16_MARK___5 = 1398,
	A5_MARK___5 = 1399,
	LCDOUT21_MARK___5 = 1400,
	MSIOF3_SS2_B_MARK___4 = 1401,
	SCK4_B_MARK___5 = 1402,
	VI4_DATA13_MARK___5 = 1403,
	VI5_DATA13_MARK___4 = 1404,
	DU_DB5_MARK___5 = 1405,
	IP3_19_16_MARK___5 = 1406,
	A13_MARK___5 = 1407,
	LCDOUT13_MARK___5 = 1408,
	MSIOF3_SYNC_C_MARK___4 = 1409,
	HTX4_A_MARK___5 = 1410,
	VI5_DATA9_MARK___4 = 1411,
	DU_DG5_MARK___5 = 1412,
	IP0_23_20_MARK___5 = 1413,
	AVB_AVTP_CAPTURE_A_MARK___4 = 1414,
	MSIOF2_TXD_C_MARK___4 = 1415,
	RTS4_N_A_MARK___5 = 1416,
	IP1_23_20_MARK___5 = 1417,
	PWM1_A_MARK___5 = 1418,
	A21_MARK = 1419,
	HRX3_D_MARK___5 = 1420,
	VI4_DATA7_B_MARK___5 = 1421,
	IERX_B_MARK___4 = 1422,
	IP2_23_20_MARK___5 = 1423,
	A6_MARK___5 = 1424,
	LCDOUT22_MARK___5 = 1425,
	MSIOF2_SS1_A_MARK___5 = 1426,
	RX4_B_MARK___5 = 1427,
	VI4_DATA14_MARK___5 = 1428,
	VI5_DATA14_MARK___4 = 1429,
	DU_DB6_MARK___5 = 1430,
	IP3_23_20_MARK___5 = 1431,
	A14_MARK___5 = 1432,
	LCDOUT14_MARK___5 = 1433,
	MSIOF3_RXD_C_MARK___4 = 1434,
	HCTS4_N_MARK___4 = 1435,
	VI5_DATA10_MARK___4 = 1436,
	DU_DG6_MARK___5 = 1437,
	IP0_27_24_MARK___5 = 1438,
	IRQ0_MARK___5 = 1439,
	QPOLB_MARK___5 = 1440,
	DU_CDE_MARK___5 = 1441,
	VI4_DATA0_B_MARK___5 = 1442,
	CAN0_TX_B_MARK___4 = 1443,
	CANFD0_TX_B_MARK___4 = 1444,
	IP1_27_24_MARK___5 = 1445,
	PWM2_A_MARK___5 = 1446,
	A20_MARK = 1447,
	HTX3_D_MARK___5 = 1448,
	IETX_B_MARK___4 = 1449,
	IP2_27_24_MARK___5 = 1450,
	A7_MARK___5 = 1451,
	LCDOUT23_MARK___5 = 1452,
	MSIOF2_SS2_A_MARK___5 = 1453,
	TX4_B_MARK___5 = 1454,
	VI4_DATA15_MARK___5 = 1455,
	VI5_DATA15_MARK___4 = 1456,
	DU_DB7_MARK___5 = 1457,
	IP3_27_24_MARK___5 = 1458,
	A15_MARK___5 = 1459,
	LCDOUT15_MARK___5 = 1460,
	MSIOF3_TXD_C_MARK___4 = 1461,
	HRTS4_N_MARK___4 = 1462,
	VI5_DATA11_MARK___4 = 1463,
	DU_DG7_MARK___5 = 1464,
	IP0_31_28_MARK___5 = 1465,
	IRQ1_MARK___5 = 1466,
	QPOLA_MARK___5 = 1467,
	DU_DISP_MARK___5 = 1468,
	VI4_DATA1_B_MARK___5 = 1469,
	CAN0_RX_B_MARK___4 = 1470,
	CANFD0_RX_B_MARK___4 = 1471,
	IP1_31_28_MARK___5 = 1472,
	A0_MARK___5 = 1473,
	LCDOUT16_MARK___5 = 1474,
	MSIOF3_SYNC_B_MARK___5 = 1475,
	VI4_DATA8_MARK___5 = 1476,
	DU_DB0_MARK___5 = 1477,
	PWM3_A_MARK___5 = 1478,
	IP2_31_28_MARK___5 = 1479,
	A8_MARK___5 = 1480,
	RX3_B_MARK___5 = 1481,
	MSIOF2_SYNC_A_MARK___5 = 1482,
	HRX4_B_MARK___5 = 1483,
	SDA6_A_MARK___5 = 1484,
	AVB_AVTP_MATCH_B_MARK___4 = 1485,
	PWM1_B_MARK___5 = 1486,
	IP3_31_28_MARK___5 = 1487,
	A16_MARK___5 = 1488,
	LCDOUT8_MARK___5 = 1489,
	VI4_FIELD_MARK___5 = 1490,
	DU_DG0_MARK___5 = 1491,
	IP4_3_0_MARK___5 = 1492,
	A17_MARK___5 = 1493,
	LCDOUT9_MARK___5 = 1494,
	VI4_VSYNC_N_MARK___5 = 1495,
	DU_DG1_MARK___5 = 1496,
	IP5_3_0_MARK___5 = 1497,
	WE0_N_MARK___5 = 1498,
	MSIOF3_TXD_D_MARK___4 = 1499,
	CTS3_N_MARK___4 = 1500,
	HCTS3_N_MARK___4 = 1501,
	SCL6_B_MARK___5 = 1502,
	CAN_CLK_MARK___5 = 1503,
	IECLK_A_MARK___4 = 1504,
	IP6_3_0_MARK___5 = 1505,
	D5_MARK___5 = 1506,
	MSIOF2_SYNC_B_MARK___5 = 1507,
	VI4_DATA21_MARK___5 = 1508,
	VI5_DATA5_MARK___4 = 1509,
	IP7_3_0_MARK___5 = 1510,
	D13_MARK___5 = 1511,
	LCDOUT5_MARK___5 = 1512,
	MSIOF2_SS2_D_MARK___4 = 1513,
	TX4_C_MARK___5 = 1514,
	VI4_DATA5_A_MARK___5 = 1515,
	DU_DR5_MARK___5 = 1516,
	IP4_7_4_MARK___5 = 1517,
	A18_MARK___5 = 1518,
	LCDOUT10_MARK___5 = 1519,
	VI4_HSYNC_N_MARK___5 = 1520,
	DU_DG2_MARK___5 = 1521,
	IP5_7_4_MARK___5 = 1522,
	WE1_N_MARK___5 = 1523,
	MSIOF3_SS1_D_MARK___4 = 1524,
	RTS3_N_MARK___4 = 1525,
	HRTS3_N_MARK___4 = 1526,
	SDA6_B_MARK___5 = 1527,
	CAN1_RX_MARK___5 = 1528,
	CANFD1_RX_MARK___5 = 1529,
	IERX_A_MARK___4 = 1530,
	IP6_7_4_MARK___5 = 1531,
	D6_MARK___5 = 1532,
	MSIOF2_RXD_B_MARK___5 = 1533,
	VI4_DATA22_MARK___5 = 1534,
	VI5_DATA6_MARK___4 = 1535,
	IP7_7_4_MARK___5 = 1536,
	D14_MARK___5 = 1537,
	LCDOUT6_MARK___5 = 1538,
	MSIOF3_SS1_A_MARK___5 = 1539,
	HRX3_C_MARK___5 = 1540,
	VI4_DATA6_A_MARK___5 = 1541,
	DU_DR6_MARK___5 = 1542,
	SCL6_C_MARK___4 = 1543,
	IP4_11_8_MARK___5 = 1544,
	A19_MARK___5 = 1545,
	LCDOUT11_MARK___5 = 1546,
	VI4_CLKENB_MARK___5 = 1547,
	DU_DG3_MARK___5 = 1548,
	IP5_11_8_MARK___5 = 1549,
	EX_WAIT0_A_MARK___4 = 1550,
	QCLK_MARK___5 = 1551,
	VI4_CLK_MARK___5 = 1552,
	DU_DOTCLKOUT0_MARK___5 = 1553,
	IP6_11_8_MARK___5 = 1554,
	D7_MARK___5 = 1555,
	MSIOF2_TXD_B_MARK___5 = 1556,
	VI4_DATA23_MARK___5 = 1557,
	VI5_DATA7_MARK___4 = 1558,
	IP7_11_8_MARK___5 = 1559,
	D15_MARK___5 = 1560,
	LCDOUT7_MARK___5 = 1561,
	MSIOF3_SS2_A_MARK___5 = 1562,
	HTX3_C_MARK___5 = 1563,
	VI4_DATA7_A_MARK___5 = 1564,
	DU_DR7_MARK___5 = 1565,
	SDA6_C_MARK___4 = 1566,
	IP4_15_12_MARK___5 = 1567,
	CS0_N_MARK___5 = 1568,
	VI5_CLKENB_MARK___4 = 1569,
	IP5_15_12_MARK___5 = 1570,
	D0_MARK___5 = 1571,
	MSIOF2_SS1_B_MARK___5 = 1572,
	MSIOF3_SCK_A_MARK___5 = 1573,
	VI4_DATA16_MARK___5 = 1574,
	VI5_DATA0_MARK___4 = 1575,
	IP6_15_12_MARK___5 = 1576,
	D8_MARK___5 = 1577,
	LCDOUT0_MARK___5 = 1578,
	MSIOF2_SCK_D_MARK___4 = 1579,
	SCK4_C_MARK___4 = 1580,
	VI4_DATA0_A_MARK___5 = 1581,
	DU_DR0_MARK___5 = 1582,
	IP7_15_12_MARK___2 = 1583,
	FSCLKST_MARK = 1584,
	IP4_19_16_MARK___5 = 1585,
	CS1_N_A26_MARK___2 = 1586,
	VI5_CLK_MARK___4 = 1587,
	EX_WAIT0_B_MARK___4 = 1588,
	IP5_19_16_MARK___5 = 1589,
	D1_MARK___5 = 1590,
	MSIOF2_SS2_B_MARK___5 = 1591,
	MSIOF3_SYNC_A_MARK___5 = 1592,
	VI4_DATA17_MARK___5 = 1593,
	VI5_DATA1_MARK___4 = 1594,
	IP6_19_16_MARK___5 = 1595,
	D9_MARK___5 = 1596,
	LCDOUT1_MARK___5 = 1597,
	MSIOF2_SYNC_D_MARK___4 = 1598,
	VI4_DATA1_A_MARK___5 = 1599,
	DU_DR1_MARK___5 = 1600,
	IP7_19_16_MARK___5 = 1601,
	SD0_CLK_MARK___5 = 1602,
	MSIOF1_SCK_E_MARK___4 = 1603,
	STP_OPWM_0_B_MARK___4 = 1604,
	IP4_23_20_MARK___5 = 1605,
	BS_N_MARK___5 = 1606,
	QSTVA_QVS_MARK___5 = 1607,
	MSIOF3_SCK_D_MARK___4 = 1608,
	SCK3_MARK___4 = 1609,
	HSCK3_MARK___4 = 1610,
	CAN1_TX_MARK___5 = 1611,
	CANFD1_TX_MARK___5 = 1612,
	IETX_A_MARK___4 = 1613,
	IP5_23_20_MARK___5 = 1614,
	D2_MARK___5 = 1615,
	MSIOF3_RXD_A_MARK___5 = 1616,
	VI4_DATA18_MARK___5 = 1617,
	VI5_DATA2_MARK___4 = 1618,
	IP6_23_20_MARK___5 = 1619,
	D10_MARK___5 = 1620,
	LCDOUT2_MARK___5 = 1621,
	MSIOF2_RXD_D_MARK___4 = 1622,
	HRX3_B_MARK___5 = 1623,
	VI4_DATA2_A_MARK___5 = 1624,
	CTS4_N_C_MARK___5 = 1625,
	DU_DR2_MARK___5 = 1626,
	IP7_23_20_MARK___5 = 1627,
	SD0_CMD_MARK___5 = 1628,
	MSIOF1_SYNC_E_MARK___4 = 1629,
	STP_IVCXO27_0_B_MARK___4 = 1630,
	IP4_27_24_MARK___5 = 1631,
	RD_N_MARK___5 = 1632,
	MSIOF3_SYNC_D_MARK___4 = 1633,
	RX3_A_MARK___5 = 1634,
	HRX3_A_MARK___5 = 1635,
	CAN0_TX_A_MARK___4 = 1636,
	CANFD0_TX_A_MARK___4 = 1637,
	IP5_27_24_MARK___5 = 1638,
	D3_MARK___5 = 1639,
	MSIOF3_TXD_A_MARK___5 = 1640,
	VI4_DATA19_MARK___5 = 1641,
	VI5_DATA3_MARK___4 = 1642,
	IP6_27_24_MARK___5 = 1643,
	D11_MARK___5 = 1644,
	LCDOUT3_MARK___5 = 1645,
	MSIOF2_TXD_D_MARK___4 = 1646,
	HTX3_B_MARK___5 = 1647,
	VI4_DATA3_A_MARK___5 = 1648,
	RTS4_N_C_MARK___5 = 1649,
	DU_DR3_MARK___5 = 1650,
	IP7_27_24_MARK___5 = 1651,
	SD0_DAT0_MARK___5 = 1652,
	MSIOF1_RXD_E_MARK___4 = 1653,
	TS_SCK0_B_MARK___4 = 1654,
	STP_ISCLK_0_B_MARK___4 = 1655,
	IP4_31_28_MARK___5 = 1656,
	RD_WR_N_MARK___5 = 1657,
	MSIOF3_RXD_D_MARK___4 = 1658,
	TX3_A_MARK___5 = 1659,
	HTX3_A_MARK___5 = 1660,
	CAN0_RX_A_MARK___4 = 1661,
	CANFD0_RX_A_MARK___4 = 1662,
	IP5_31_28_MARK___5 = 1663,
	D4_MARK___5 = 1664,
	MSIOF2_SCK_B_MARK___5 = 1665,
	VI4_DATA20_MARK___5 = 1666,
	VI5_DATA4_MARK___4 = 1667,
	IP6_31_28_MARK___5 = 1668,
	D12_MARK___5 = 1669,
	LCDOUT4_MARK___5 = 1670,
	MSIOF2_SS1_D_MARK___4 = 1671,
	RX4_C_MARK___5 = 1672,
	VI4_DATA4_A_MARK___5 = 1673,
	DU_DR4_MARK___5 = 1674,
	IP7_31_28_MARK___5 = 1675,
	SD0_DAT1_MARK___5 = 1676,
	MSIOF1_TXD_E_MARK___4 = 1677,
	TS_SPSYNC0_B_MARK___4 = 1678,
	STP_ISSYNC_0_B_MARK___4 = 1679,
	IP8_3_0_MARK___5 = 1680,
	SD0_DAT2_MARK___5 = 1681,
	MSIOF1_SS1_E_MARK___4 = 1682,
	TS_SDAT0_B_MARK___4 = 1683,
	STP_ISD_0_B_MARK___4 = 1684,
	IP9_3_0_MARK___5 = 1685,
	SD2_CLK_MARK___4 = 1686,
	IP10_3_0_MARK___5 = 1687,
	SD3_DAT6_MARK___5 = 1688,
	SD3_CD_MARK___5 = 1689,
	IP11_3_0_MARK___5 = 1690,
	TX0_MARK___4 = 1691,
	HTX1_B_MARK___5 = 1692,
	TS_SPSYNC0_C_MARK___4 = 1693,
	STP_ISSYNC_0_C_MARK___4 = 1694,
	RIF0_D1_B_MARK___5 = 1695,
	IP8_7_4_MARK___5 = 1696,
	SD0_DAT3_MARK___5 = 1697,
	MSIOF1_SS2_E_MARK___4 = 1698,
	TS_SDEN0_B_MARK___4 = 1699,
	STP_ISEN_0_B_MARK___4 = 1700,
	IP9_7_4_MARK___5 = 1701,
	SD2_DAT0_MARK___4 = 1702,
	IP10_7_4_MARK___5 = 1703,
	SD3_DAT7_MARK___5 = 1704,
	SD3_WP_MARK___5 = 1705,
	IP11_7_4_MARK___5 = 1706,
	CTS0_N_MARK___4 = 1707,
	HCTS1_N_B_MARK___5 = 1708,
	MSIOF1_SYNC_B_MARK___4 = 1709,
	TS_SPSYNC1_C_MARK___4 = 1710,
	STP_ISSYNC_1_C_MARK___4 = 1711,
	RIF1_SYNC_B_MARK___4 = 1712,
	AUDIO_CLKOUT_C_MARK___4 = 1713,
	ADICS_SAMP_MARK___4 = 1714,
	IP8_11_8_MARK___5 = 1715,
	SD1_CLK_MARK___5 = 1716,
	MSIOF1_SCK_G_MARK___4 = 1717,
	SIM0_CLK_A_MARK___5 = 1718,
	IP9_11_8_MARK___5 = 1719,
	SD2_DAT1_MARK___4 = 1720,
	IP10_11_8_MARK___5 = 1721,
	SD0_CD_MARK___5 = 1722,
	SCL2_B_MARK___5 = 1723,
	SIM0_RST_A_MARK___5 = 1724,
	IP11_11_8_MARK___5 = 1725,
	RTS0_N_MARK___4 = 1726,
	HRTS1_N_B_MARK___5 = 1727,
	MSIOF1_SS1_B_MARK___4 = 1728,
	AUDIO_CLKA_B_MARK___4 = 1729,
	SCL2_A_MARK___5 = 1730,
	STP_IVCXO27_1_C_MARK___4 = 1731,
	RIF0_SYNC_B_MARK___5 = 1732,
	ADICHS1_MARK___4 = 1733,
	IP8_15_12_MARK___5 = 1734,
	SD1_CMD_MARK___5 = 1735,
	MSIOF1_SYNC_G_MARK___4 = 1736,
	SIM0_D_A_MARK___5 = 1737,
	STP_IVCXO27_1_B_MARK___4 = 1738,
	IP9_15_12_MARK___5 = 1739,
	SD2_DAT2_MARK___4 = 1740,
	IP10_15_12_MARK___5 = 1741,
	SD0_WP_MARK___5 = 1742,
	SDA2_B_MARK___5 = 1743,
	IP11_15_12_MARK___5 = 1744,
	RX1_A_MARK___4 = 1745,
	HRX1_A_MARK___5 = 1746,
	TS_SDAT0_C_MARK___4 = 1747,
	STP_ISD_0_C_MARK___4 = 1748,
	RIF1_CLK_C_MARK___4 = 1749,
	IP8_19_16_MARK___5 = 1750,
	SD1_DAT0_MARK___5 = 1751,
	SD2_DAT4_MARK___4 = 1752,
	MSIOF1_RXD_G_MARK___4 = 1753,
	TS_SCK1_B_MARK___4 = 1754,
	STP_ISCLK_1_B_MARK___4 = 1755,
	IP9_19_16_MARK___5 = 1756,
	SD2_DAT3_MARK___4 = 1757,
	IP10_19_16_MARK___5 = 1758,
	SD1_CD_MARK___5 = 1759,
	SIM0_CLK_B_MARK___5 = 1760,
	IP11_19_16_MARK___5 = 1761,
	TX1_A_MARK___4 = 1762,
	HTX1_A_MARK___5 = 1763,
	TS_SDEN0_C_MARK___4 = 1764,
	STP_ISEN_0_C_MARK___4 = 1765,
	RIF1_D0_C_MARK___4 = 1766,
	IP8_23_20_MARK___5 = 1767,
	SD1_DAT1_MARK___5 = 1768,
	SD2_DAT5_MARK___4 = 1769,
	MSIOF1_TXD_G_MARK___4 = 1770,
	TS_SPSYNC1_B_MARK___4 = 1771,
	STP_ISSYNC_1_B_MARK___4 = 1772,
	IP9_23_20_MARK___5 = 1773,
	SD2_DS_MARK___4 = 1774,
	SATA_DEVSLP_B_MARK___3 = 1775,
	IP10_23_20_MARK___5 = 1776,
	SD1_WP_MARK___5 = 1777,
	SIM0_D_B_MARK___5 = 1778,
	IP11_23_20_MARK___5 = 1779,
	CTS1_N_MARK___5 = 1780,
	HCTS1_N_A_MARK___4 = 1781,
	MSIOF1_RXD_B_MARK___4 = 1782,
	TS_SDEN1_C_MARK___4 = 1783,
	STP_ISEN_1_C_MARK___4 = 1784,
	RIF1_D0_B_MARK___4 = 1785,
	ADIDATA_MARK___4 = 1786,
	IP8_27_24_MARK___5 = 1787,
	SD1_DAT2_MARK___5 = 1788,
	SD2_DAT6_MARK___4 = 1789,
	MSIOF1_SS1_G_MARK___4 = 1790,
	TS_SDAT1_B_MARK___4 = 1791,
	STP_ISD_1_B_MARK___4 = 1792,
	IP9_27_24_MARK___5 = 1793,
	SD3_DAT4_MARK___5 = 1794,
	SD2_CD_A_MARK___4 = 1795,
	IP10_27_24_MARK___5 = 1796,
	SCK0_MARK___4 = 1797,
	HSCK1_B_MARK___5 = 1798,
	MSIOF1_SS2_B_MARK___4 = 1799,
	AUDIO_CLKC_B_MARK___5 = 1800,
	SDA2_A_MARK___5 = 1801,
	SIM0_RST_B_MARK___5 = 1802,
	STP_OPWM_0_C_MARK___4 = 1803,
	RIF0_CLK_B_MARK___5 = 1804,
	ADICHS2_MARK___4 = 1805,
	IP11_27_24_MARK___5 = 1806,
	RTS1_N_MARK___5 = 1807,
	HRTS1_N_A_MARK___4 = 1808,
	MSIOF1_TXD_B_MARK___4 = 1809,
	TS_SDAT1_C_MARK___4 = 1810,
	STP_ISD_1_C_MARK___4 = 1811,
	RIF1_D1_B_MARK___4 = 1812,
	ADICHS0_MARK___4 = 1813,
	IP8_31_28_MARK___5 = 1814,
	SD1_DAT3_MARK___5 = 1815,
	SD2_DAT7_MARK___4 = 1816,
	MSIOF1_SS2_G_MARK___4 = 1817,
	TS_SDEN1_B_MARK___4 = 1818,
	STP_ISEN_1_B_MARK___4 = 1819,
	IP9_31_28_MARK___5 = 1820,
	SD3_DAT5_MARK___5 = 1821,
	SD2_WP_A_MARK___4 = 1822,
	IP10_31_28_MARK___5 = 1823,
	RX0_MARK___4 = 1824,
	HRX1_B_MARK___5 = 1825,
	TS_SCK0_C_MARK___4 = 1826,
	STP_ISCLK_0_C_MARK___4 = 1827,
	RIF0_D0_B_MARK___5 = 1828,
	IP11_31_28_MARK___5 = 1829,
	SCK2_MARK___4 = 1830,
	SCIF_CLK_B_MARK___5 = 1831,
	MSIOF1_SCK_B_MARK___4 = 1832,
	TS_SCK1_C_MARK___4 = 1833,
	STP_ISCLK_1_C_MARK___4 = 1834,
	RIF1_CLK_B_MARK___4 = 1835,
	ADICLK_MARK___4 = 1836,
	IP12_3_0_MARK___5 = 1837,
	TX2_A_MARK___5 = 1838,
	SD2_CD_B_MARK___4 = 1839,
	SCL1_A_MARK___5 = 1840,
	FMCLK_A_MARK___5 = 1841,
	RIF1_D1_C_MARK___4 = 1842,
	FSO_CFE_0_B_MARK = 1843,
	IP13_3_0_MARK___5 = 1844,
	MSIOF0_SS1_MARK___5 = 1845,
	RX5_MARK = 1846,
	AUDIO_CLKA_C_MARK___4 = 1847,
	SSI_SCK2_A_MARK___5 = 1848,
	STP_IVCXO27_0_C_MARK___4 = 1849,
	AUDIO_CLKOUT3_A_MARK___5 = 1850,
	TCLK1_B_MARK___5 = 1851,
	IP14_3_0_MARK___5 = 1852,
	SSI_SDATA1_A_MARK___4 = 1853,
	IP15_3_0_MARK___5 = 1854,
	SSI_SCK6_MARK___5 = 1855,
	USB2_PWEN_MARK___2 = 1856,
	SIM0_RST_D_MARK___4 = 1857,
	IP12_7_4_MARK___5 = 1858,
	RX2_A_MARK___5 = 1859,
	SD2_WP_B_MARK___4 = 1860,
	SDA1_A_MARK___5 = 1861,
	FMIN_A_MARK___5 = 1862,
	RIF1_SYNC_C_MARK___4 = 1863,
	FSO_CFE_1_B_MARK = 1864,
	IP13_7_4_MARK___5 = 1865,
	MSIOF0_SS2_MARK___5 = 1866,
	TX5_MARK = 1867,
	MSIOF1_SS2_D_MARK___4 = 1868,
	AUDIO_CLKC_A_MARK___5 = 1869,
	SSI_WS2_A_MARK___5 = 1870,
	STP_OPWM_0_D_MARK___4 = 1871,
	AUDIO_CLKOUT_D_MARK___4 = 1872,
	SPEEDIN_B_MARK___5 = 1873,
	IP14_7_4_MARK___5 = 1874,
	SSI_SDATA2_A_MARK___4 = 1875,
	SSI_SCK1_B_MARK___4 = 1876,
	IP15_7_4_MARK___5 = 1877,
	SSI_WS6_MARK___5 = 1878,
	USB2_OVC_MARK___2 = 1879,
	SIM0_D_D_MARK___4 = 1880,
	IP12_11_8_MARK___5 = 1881,
	HSCK0_MARK___4 = 1882,
	MSIOF1_SCK_D_MARK___4 = 1883,
	AUDIO_CLKB_A_MARK___5 = 1884,
	SSI_SDATA1_B_MARK___4 = 1885,
	TS_SCK0_D_MARK___4 = 1886,
	STP_ISCLK_0_D_MARK___4 = 1887,
	RIF0_CLK_C_MARK___4 = 1888,
	IP13_11_8_MARK___5 = 1889,
	MLB_CLK_MARK___5 = 1890,
	MSIOF1_SCK_F_MARK___4 = 1891,
	SCL1_B_MARK___5 = 1892,
	IP14_11_8_MARK___5 = 1893,
	SSI_SCK349_MARK___5 = 1894,
	MSIOF1_SS1_A_MARK___4 = 1895,
	STP_OPWM_0_A_MARK___4 = 1896,
	IP15_11_8_MARK___5 = 1897,
	SSI_SDATA6_MARK___5 = 1898,
	SIM0_CLK_D_MARK___4 = 1899,
	SATA_DEVSLP_A_MARK___3 = 1900,
	IP12_15_12_MARK___5 = 1901,
	HRX0_MARK___4 = 1902,
	MSIOF1_RXD_D_MARK___4 = 1903,
	SSI_SDATA2_B_MARK___4 = 1904,
	TS_SDEN0_D_MARK___4 = 1905,
	STP_ISEN_0_D_MARK___4 = 1906,
	RIF0_D0_C_MARK___4 = 1907,
	IP13_15_12_MARK___5 = 1908,
	MLB_SIG_MARK___5 = 1909,
	RX1_B_MARK___4 = 1910,
	MSIOF1_SYNC_F_MARK___4 = 1911,
	SDA1_B_MARK___5 = 1912,
	IP14_15_12_MARK___5 = 1913,
	SSI_WS349_MARK___5 = 1914,
	HCTS2_N_A_MARK___5 = 1915,
	MSIOF1_SS2_A_MARK___4 = 1916,
	STP_IVCXO27_0_A_MARK___4 = 1917,
	IP15_15_12_MARK___5 = 1918,
	SSI_SCK78_MARK___5 = 1919,
	HRX2_B_MARK___5 = 1920,
	MSIOF1_SCK_C_MARK___4 = 1921,
	TS_SCK1_A_MARK___4 = 1922,
	STP_ISCLK_1_A_MARK___4 = 1923,
	RIF1_CLK_A_MARK___4 = 1924,
	RIF3_CLK_A_MARK___5 = 1925,
	IP12_19_16_MARK___5 = 1926,
	HTX0_MARK___4 = 1927,
	MSIOF1_TXD_D_MARK___4 = 1928,
	SSI_SDATA9_B_MARK___4 = 1929,
	TS_SDAT0_D_MARK___4 = 1930,
	STP_ISD_0_D_MARK___4 = 1931,
	RIF0_D1_C_MARK___4 = 1932,
	IP13_19_16_MARK___5 = 1933,
	MLB_DAT_MARK___5 = 1934,
	TX1_B_MARK___4 = 1935,
	MSIOF1_RXD_F_MARK___4 = 1936,
	IP14_19_16_MARK___5 = 1937,
	SSI_SDATA3_MARK___5 = 1938,
	HRTS2_N_A_MARK___5 = 1939,
	MSIOF1_TXD_A_MARK___4 = 1940,
	TS_SCK0_A_MARK___4 = 1941,
	STP_ISCLK_0_A_MARK___4 = 1942,
	RIF0_D1_A_MARK___5 = 1943,
	RIF2_D0_A_MARK___5 = 1944,
	IP15_19_16_MARK___5 = 1945,
	SSI_WS78_MARK___5 = 1946,
	HTX2_B_MARK___5 = 1947,
	MSIOF1_SYNC_C_MARK___4 = 1948,
	TS_SDAT1_A_MARK___4 = 1949,
	STP_ISD_1_A_MARK___4 = 1950,
	RIF1_SYNC_A_MARK___4 = 1951,
	RIF3_SYNC_A_MARK___5 = 1952,
	IP12_23_20_MARK___5 = 1953,
	HCTS0_N_MARK___4 = 1954,
	RX2_B_MARK___5 = 1955,
	MSIOF1_SYNC_D_MARK___4 = 1956,
	SSI_SCK9_A_MARK___5 = 1957,
	TS_SPSYNC0_D_MARK___4 = 1958,
	STP_ISSYNC_0_D_MARK___4 = 1959,
	RIF0_SYNC_C_MARK___4 = 1960,
	AUDIO_CLKOUT1_A_MARK___5 = 1961,
	IP13_23_20_MARK___5 = 1962,
	SSI_SCK01239_MARK___5 = 1963,
	MSIOF1_TXD_F_MARK___4 = 1964,
	IP14_23_20_MARK___5 = 1965,
	SSI_SCK4_MARK___5 = 1966,
	HRX2_A_MARK___5 = 1967,
	MSIOF1_SCK_A_MARK___4 = 1968,
	TS_SDAT0_A_MARK___4 = 1969,
	STP_ISD_0_A_MARK___4 = 1970,
	RIF0_CLK_A_MARK___5 = 1971,
	RIF2_CLK_A_MARK___5 = 1972,
	IP15_23_20_MARK___5 = 1973,
	SSI_SDATA7_MARK___5 = 1974,
	HCTS2_N_B_MARK___4 = 1975,
	MSIOF1_RXD_C_MARK___4 = 1976,
	TS_SDEN1_A_MARK___4 = 1977,
	STP_ISEN_1_A_MARK___4 = 1978,
	RIF1_D0_A_MARK___4 = 1979,
	RIF3_D0_A_MARK___5 = 1980,
	TCLK2_A_MARK___5 = 1981,
	IP12_27_24_MARK___5 = 1982,
	HRTS0_N_MARK___4 = 1983,
	TX2_B_MARK___5 = 1984,
	MSIOF1_SS1_D_MARK___4 = 1985,
	SSI_WS9_A_MARK___5 = 1986,
	STP_IVCXO27_0_D_MARK___4 = 1987,
	BPFCLK_A_MARK___5 = 1988,
	AUDIO_CLKOUT2_A_MARK___5 = 1989,
	IP13_27_24_MARK___5 = 1990,
	SSI_WS01239_MARK___5 = 1991,
	MSIOF1_SS1_F_MARK___4 = 1992,
	IP14_27_24_MARK___5 = 1993,
	SSI_WS4_MARK___5 = 1994,
	HTX2_A_MARK___5 = 1995,
	MSIOF1_SYNC_A_MARK___4 = 1996,
	TS_SDEN0_A_MARK___4 = 1997,
	STP_ISEN_0_A_MARK___4 = 1998,
	RIF0_SYNC_A_MARK___5 = 1999,
	RIF2_SYNC_A_MARK___5 = 2000,
	IP15_27_24_MARK___5 = 2001,
	SSI_SDATA8_MARK___5 = 2002,
	HRTS2_N_B_MARK___4 = 2003,
	MSIOF1_TXD_C_MARK___4 = 2004,
	TS_SPSYNC1_A_MARK___4 = 2005,
	STP_ISSYNC_1_A_MARK___4 = 2006,
	RIF1_D1_A_MARK___4 = 2007,
	RIF3_D1_A_MARK___5 = 2008,
	IP12_31_28_MARK___5 = 2009,
	MSIOF0_SYNC_MARK___5 = 2010,
	AUDIO_CLKOUT_A_MARK___5 = 2011,
	IP13_31_28_MARK___5 = 2012,
	SSI_SDATA0_MARK___5 = 2013,
	MSIOF1_SS2_F_MARK___4 = 2014,
	IP14_31_28_MARK___5 = 2015,
	SSI_SDATA4_MARK___5 = 2016,
	HSCK2_A_MARK___5 = 2017,
	MSIOF1_RXD_A_MARK___4 = 2018,
	TS_SPSYNC0_A_MARK___4 = 2019,
	STP_ISSYNC_0_A_MARK___4 = 2020,
	RIF0_D0_A_MARK___5 = 2021,
	RIF2_D1_A_MARK___5 = 2022,
	IP15_31_28_MARK___5 = 2023,
	SSI_SDATA9_A_MARK___4 = 2024,
	HSCK2_B_MARK___4 = 2025,
	MSIOF1_SS1_C_MARK___4 = 2026,
	HSCK1_A_MARK___5 = 2027,
	SSI_WS1_B_MARK___4 = 2028,
	SCK1_MARK___5 = 2029,
	STP_IVCXO27_1_A_MARK___4 = 2030,
	SCK5_MARK = 2031,
	IP16_3_0_MARK___4 = 2032,
	AUDIO_CLKA_A_MARK___4 = 2033,
	IP17_3_0_MARK___4 = 2034,
	USB31_PWEN_MARK = 2035,
	AUDIO_CLKOUT2_B_MARK___5 = 2036,
	SSI_SCK9_B_MARK___5 = 2037,
	TS_SDEN0_E_MARK___4 = 2038,
	STP_ISEN_0_E_MARK___4 = 2039,
	RIF2_D0_B_MARK___5 = 2040,
	TPU0TO2_MARK___5 = 2041,
	IP16_7_4_MARK___4 = 2042,
	AUDIO_CLKB_B_MARK___5 = 2043,
	SCIF_CLK_A_MARK___5 = 2044,
	STP_IVCXO27_1_D_MARK___4 = 2045,
	REMOCON_A_MARK___5 = 2046,
	TCLK1_A_MARK___5 = 2047,
	IP17_7_4_MARK___4 = 2048,
	USB31_OVC_MARK = 2049,
	AUDIO_CLKOUT3_B_MARK___5 = 2050,
	SSI_WS9_B_MARK___5 = 2051,
	TS_SPSYNC0_E_MARK___4 = 2052,
	STP_ISSYNC_0_E_MARK___4 = 2053,
	RIF2_D1_B_MARK___5 = 2054,
	TPU0TO3_MARK___5 = 2055,
	IP16_11_8_MARK___4 = 2056,
	USB0_PWEN_MARK___4 = 2057,
	SIM0_RST_C_MARK___4 = 2058,
	TS_SCK1_D_MARK___4 = 2059,
	STP_ISCLK_1_D_MARK___4 = 2060,
	BPFCLK_B_MARK___5 = 2061,
	RIF3_CLK_B_MARK___5 = 2062,
	IP16_15_12_MARK___4 = 2063,
	USB0_OVC_MARK___4 = 2064,
	SIM0_D_C_MARK___4 = 2065,
	TS_SDAT1_D_MARK___4 = 2066,
	STP_ISD_1_D_MARK___4 = 2067,
	RIF3_SYNC_B_MARK___5 = 2068,
	IP16_19_16_MARK___4 = 2069,
	USB1_PWEN_MARK___4 = 2070,
	SIM0_CLK_C_MARK___4 = 2071,
	SSI_SCK1_A_MARK___4 = 2072,
	TS_SCK0_E_MARK___4 = 2073,
	STP_ISCLK_0_E_MARK___4 = 2074,
	FMCLK_B_MARK___5 = 2075,
	RIF2_CLK_B_MARK___5 = 2076,
	SPEEDIN_A_MARK___5 = 2077,
	IP16_23_20_MARK___4 = 2078,
	USB1_OVC_MARK___4 = 2079,
	MSIOF1_SS2_C_MARK___4 = 2080,
	SSI_WS1_A_MARK___4 = 2081,
	TS_SDAT0_E_MARK___4 = 2082,
	STP_ISD_0_E_MARK___4 = 2083,
	FMIN_B_MARK___5 = 2084,
	RIF2_SYNC_B_MARK___5 = 2085,
	REMOCON_B_MARK___5 = 2086,
	IP16_27_24_MARK___4 = 2087,
	USB30_PWEN_MARK___5 = 2088,
	AUDIO_CLKOUT_B_MARK___5 = 2089,
	SSI_SCK2_B_MARK___5 = 2090,
	TS_SDEN1_D_MARK___4 = 2091,
	STP_ISEN_1_D_MARK___4 = 2092,
	STP_OPWM_0_E_MARK___4 = 2093,
	RIF3_D0_B_MARK___5 = 2094,
	TCLK2_B_MARK___5 = 2095,
	TPU0TO0_MARK___5 = 2096,
	IP16_31_28_MARK___4 = 2097,
	USB30_OVC_MARK___5 = 2098,
	AUDIO_CLKOUT1_B_MARK___5 = 2099,
	SSI_WS2_B_MARK___5 = 2100,
	TS_SPSYNC1_D_MARK___4 = 2101,
	STP_ISSYNC_1_D_MARK___4 = 2102,
	STP_IVCXO27_0_E_MARK___4 = 2103,
	RIF3_D1_B_MARK___5 = 2104,
	FSO_TOE_B_MARK = 2105,
	TPU0TO1_MARK___5 = 2106,
	SEL_TSIF1_0_MARK___4 = 2107,
	SEL_TSIF1_1_MARK___4 = 2108,
	SEL_TSIF1_2_MARK___4 = 2109,
	SEL_TSIF1_3_MARK___4 = 2110,
	I2C_SEL_5_0_MARK___4 = 2111,
	I2C_SEL_5_1_MARK___4 = 2112,
	SEL_MSIOF3_0_MARK___5 = 2113,
	SEL_MSIOF3_1_MARK___5 = 2114,
	SEL_MSIOF3_2_MARK___4 = 2115,
	SEL_MSIOF3_3_MARK___4 = 2116,
	I2C_SEL_3_0_MARK___4 = 2117,
	I2C_SEL_3_1_MARK___4 = 2118,
	SEL_TSIF0_0_MARK___4 = 2119,
	SEL_TSIF0_1_MARK___4 = 2120,
	SEL_TSIF0_2_MARK___4 = 2121,
	SEL_TSIF0_3_MARK___4 = 2122,
	SEL_TSIF0_4_MARK___4 = 2123,
	I2C_SEL_0_0_MARK___4 = 2124,
	I2C_SEL_0_1_MARK___4 = 2125,
	SEL_MSIOF2_0_MARK___5 = 2126,
	SEL_MSIOF2_1_MARK___5 = 2127,
	SEL_MSIOF2_2_MARK___4 = 2128,
	SEL_MSIOF2_3_MARK___4 = 2129,
	SEL_MSIOF1_0_MARK___4 = 2130,
	SEL_MSIOF1_1_MARK___4 = 2131,
	SEL_MSIOF1_2_MARK___4 = 2132,
	SEL_MSIOF1_3_MARK___4 = 2133,
	SEL_MSIOF1_4_MARK___4 = 2134,
	SEL_MSIOF1_5_MARK___4 = 2135,
	SEL_MSIOF1_6_MARK___4 = 2136,
	SEL_TIMER_TMU_0_MARK___4 = 2137,
	SEL_TIMER_TMU_1_MARK___4 = 2138,
	SEL_SSP1_1_0_MARK___4 = 2139,
	SEL_SSP1_1_1_MARK___4 = 2140,
	SEL_SSP1_1_2_MARK___4 = 2141,
	SEL_SSP1_1_3_MARK___4 = 2142,
	SEL_LBSC_0_MARK___4 = 2143,
	SEL_LBSC_1_MARK___4 = 2144,
	SEL_SSP1_0_0_MARK___4 = 2145,
	SEL_SSP1_0_1_MARK___4 = 2146,
	SEL_SSP1_0_2_MARK___4 = 2147,
	SEL_SSP1_0_3_MARK___4 = 2148,
	SEL_SSP1_0_4_MARK___4 = 2149,
	SEL_IEBUS_0_MARK___4 = 2150,
	SEL_IEBUS_1_MARK___4 = 2151,
	SEL_I2C6_0_MARK___5 = 2152,
	SEL_I2C6_1_MARK___5 = 2153,
	SEL_I2C6_2_MARK___4 = 2154,
	SEL_SSI_0_MARK = 2155,
	SEL_SSI_1_MARK = 2156,
	SEL_I2C2_0_MARK___5 = 2157,
	SEL_I2C2_1_MARK___5 = 2158,
	SEL_SPEED_PULSE_0_MARK___4 = 2159,
	SEL_SPEED_PULSE_1_MARK___4 = 2160,
	SEL_I2C1_0_MARK___5 = 2161,
	SEL_I2C1_1_MARK___5 = 2162,
	SEL_SIMCARD_0_MARK___5 = 2163,
	SEL_SIMCARD_1_MARK___5 = 2164,
	SEL_SIMCARD_2_MARK___4 = 2165,
	SEL_SIMCARD_3_MARK___4 = 2166,
	SEL_HSCIF4_0_MARK___5 = 2167,
	SEL_HSCIF4_1_MARK___5 = 2168,
	SEL_HSCIF3_0_MARK___5 = 2169,
	SEL_HSCIF3_1_MARK___5 = 2170,
	SEL_HSCIF3_2_MARK___5 = 2171,
	SEL_HSCIF3_3_MARK___5 = 2172,
	SEL_SDHI2_0_MARK___4 = 2173,
	SEL_SDHI2_1_MARK___4 = 2174,
	SEL_SCIF4_0_MARK___5 = 2175,
	SEL_SCIF4_1_MARK___5 = 2176,
	SEL_SCIF4_2_MARK___5 = 2177,
	SEL_HSCIF2_0_MARK___5 = 2178,
	SEL_HSCIF2_1_MARK___5 = 2179,
	SEL_HSCIF1_0_MARK___5 = 2180,
	SEL_HSCIF1_1_MARK___5 = 2181,
	SEL_SCIF3_0_MARK___5 = 2182,
	SEL_SCIF3_1_MARK___5 = 2183,
	SEL_FSO_0_MARK___2 = 2184,
	SEL_FSO_1_MARK___2 = 2185,
	SEL_SCIF2_0_MARK___5 = 2186,
	SEL_SCIF2_1_MARK___5 = 2187,
	SEL_FM_0_MARK___5 = 2188,
	SEL_FM_1_MARK___5 = 2189,
	SEL_SCIF1_0_MARK___4 = 2190,
	SEL_SCIF1_1_MARK___4 = 2191,
	SEL_ETHERAVB_0_MARK___4 = 2192,
	SEL_ETHERAVB_1_MARK___4 = 2193,
	SEL_SATA_0_MARK = 2194,
	SEL_SATA_1_MARK = 2195,
	SEL_DRIF3_0_MARK___5 = 2196,
	SEL_DRIF3_1_MARK___5 = 2197,
	SEL_REMOCON_0_MARK___5 = 2198,
	SEL_REMOCON_1_MARK___5 = 2199,
	SEL_DRIF2_0_MARK___5 = 2200,
	SEL_DRIF2_1_MARK___5 = 2201,
	SEL_DRIF1_0_MARK___4 = 2202,
	SEL_DRIF1_1_MARK___4 = 2203,
	SEL_DRIF1_2_MARK___4 = 2204,
	SEL_RCAN0_0_MARK___4 = 2205,
	SEL_RCAN0_1_MARK___4 = 2206,
	SEL_DRIF0_0_MARK___5 = 2207,
	SEL_DRIF0_1_MARK___5 = 2208,
	SEL_DRIF0_2_MARK___4 = 2209,
	SEL_PWM6_0_MARK___5 = 2210,
	SEL_PWM6_1_MARK___5 = 2211,
	SEL_PWM5_0_MARK___5 = 2212,
	SEL_PWM5_1_MARK___5 = 2213,
	SEL_CANFD0_0_MARK___4 = 2214,
	SEL_CANFD0_1_MARK___4 = 2215,
	SEL_PWM4_0_MARK___5 = 2216,
	SEL_PWM4_1_MARK___5 = 2217,
	SEL_ADG_0_MARK = 2218,
	SEL_ADG_1_MARK = 2219,
	SEL_ADG_2_MARK = 2220,
	SEL_ADG_3_MARK = 2221,
	SEL_PWM3_0_MARK___5 = 2222,
	SEL_PWM3_1_MARK___5 = 2223,
	SEL_PWM2_0_MARK___5 = 2224,
	SEL_PWM2_1_MARK___5 = 2225,
	SEL_PWM1_0_MARK___5 = 2226,
	SEL_PWM1_1_MARK___5 = 2227,
	SEL_VIN4_0_MARK___5 = 2228,
	SEL_VIN4_1_MARK___5 = 2229,
	QSPI0_SPCLK_MARK___5 = 2230,
	QSPI0_SSL_MARK___5 = 2231,
	QSPI0_MOSI_IO0_MARK___5 = 2232,
	QSPI0_MISO_IO1_MARK___5 = 2233,
	QSPI0_IO2_MARK___5 = 2234,
	QSPI0_IO3_MARK___5 = 2235,
	QSPI1_SPCLK_MARK___5 = 2236,
	QSPI1_SSL_MARK___5 = 2237,
	QSPI1_MOSI_IO0_MARK___5 = 2238,
	QSPI1_MISO_IO1_MARK___5 = 2239,
	QSPI1_IO2_MARK___5 = 2240,
	QSPI1_IO3_MARK___5 = 2241,
	RPC_INT_MARK___4 = 2242,
	RPC_WP_MARK___4 = 2243,
	RPC_RESET_MARK___4 = 2244,
	AVB_TX_CTL_MARK___5 = 2245,
	AVB_TXC_MARK___5 = 2246,
	AVB_TD0_MARK___5 = 2247,
	AVB_TD1_MARK___5 = 2248,
	AVB_TD2_MARK___5 = 2249,
	AVB_TD3_MARK___5 = 2250,
	AVB_RX_CTL_MARK___5 = 2251,
	AVB_RXC_MARK___5 = 2252,
	AVB_RD0_MARK___5 = 2253,
	AVB_RD1_MARK___5 = 2254,
	AVB_RD2_MARK___5 = 2255,
	AVB_RD3_MARK___5 = 2256,
	AVB_TXCREFCLK_MARK___5 = 2257,
	AVB_MDIO_MARK___5 = 2258,
	CLKOUT_MARK___5 = 2259,
	PRESETOUT_MARK___4 = 2260,
	DU_DOTCLKIN0_MARK___5 = 2261,
	DU_DOTCLKIN1_MARK___5 = 2262,
	DU_DOTCLKIN2_MARK___3 = 2263,
	DU_DOTCLKIN3_MARK___3 = 2264,
	TMS_MARK___5 = 2265,
	TDO_MARK___4 = 2266,
	ASEBRK_MARK___5 = 2267,
	MLB_REF_MARK___5 = 2268,
	TDI_MARK___5 = 2269,
	TCK_MARK___5 = 2270,
	TRST_MARK___4 = 2271,
	EXTALR_MARK___4 = 2272,
	SCL0_MARK___4 = 2273,
	SDA0_MARK___4 = 2274,
	SCL3_MARK___4 = 2275,
	SDA3_MARK___4 = 2276,
	SCL5_MARK___5 = 2277,
	SDA5_MARK___5 = 2278,
	PINMUX_MARK_END___5 = 2279,
};

enum {
	GP_LAST___5 = 227,
	PIN_ASEBRK___5 = 228,
	PIN_AVB_MDIO___5 = 229,
	PIN_AVB_RD0___4 = 230,
	PIN_AVB_RD1___4 = 231,
	PIN_AVB_RD2___4 = 232,
	PIN_AVB_RD3___4 = 233,
	PIN_AVB_RXC___4 = 234,
	PIN_AVB_RX_CTL___4 = 235,
	PIN_AVB_TD0___5 = 236,
	PIN_AVB_TD1___5 = 237,
	PIN_AVB_TD2___5 = 238,
	PIN_AVB_TD3___5 = 239,
	PIN_AVB_TXC___5 = 240,
	PIN_AVB_TXCREFCLK___4 = 241,
	PIN_AVB_TX_CTL___5 = 242,
	PIN_CLKOUT = 243,
	PIN_DU_DOTCLKIN0___4 = 244,
	PIN_DU_DOTCLKIN1___4 = 245,
	PIN_DU_DOTCLKIN2___3 = 246,
	PIN_DU_DOTCLKIN3___3 = 247,
	PIN_EXTALR___4 = 248,
	PIN_FSCLKST_N___3 = 249,
	PIN_MLB_REF___5 = 250,
	PIN_PRESETOUT_N___5 = 251,
	PIN_QSPI0_IO2___4 = 252,
	PIN_QSPI0_IO3___4 = 253,
	PIN_QSPI0_MISO_IO1___4 = 254,
	PIN_QSPI0_MOSI_IO0___4 = 255,
	PIN_QSPI0_SPCLK___4 = 256,
	PIN_QSPI0_SSL___4 = 257,
	PIN_QSPI1_IO2___4 = 258,
	PIN_QSPI1_IO3___4 = 259,
	PIN_QSPI1_MISO_IO1___4 = 260,
	PIN_QSPI1_MOSI_IO0___4 = 261,
	PIN_QSPI1_SPCLK___4 = 262,
	PIN_QSPI1_SSL___4 = 263,
	PIN_RPC_INT_N___4 = 264,
	PIN_RPC_RESET_N___4 = 265,
	PIN_RPC_WP_N___4 = 266,
	PIN_TCK___5 = 267,
	PIN_TDI___5 = 268,
	PIN_TDO___4 = 269,
	PIN_TMS___5 = 270,
	PIN_TRST_N___5 = 271,
};

union vin_data12 {
	unsigned int data12[12];
	unsigned int data10[10];
	unsigned int data8[8];
};

enum {
	PINMUX_RESERVED___6 = 0,
	PINMUX_DATA_BEGIN___6 = 1,
	GP_0_0_DATA___6 = 2,
	GP_0_1_DATA___6 = 3,
	GP_0_2_DATA___6 = 4,
	GP_0_3_DATA___6 = 5,
	GP_0_4_DATA___6 = 6,
	GP_0_5_DATA___6 = 7,
	GP_0_6_DATA___6 = 8,
	GP_0_7_DATA___6 = 9,
	GP_0_8_DATA___6 = 10,
	GP_0_9_DATA___6 = 11,
	GP_0_10_DATA___6 = 12,
	GP_0_11_DATA___6 = 13,
	GP_0_12_DATA___6 = 14,
	GP_0_13_DATA___6 = 15,
	GP_0_14_DATA___6 = 16,
	GP_0_15_DATA___6 = 17,
	GP_0_16_DATA___2 = 18,
	GP_0_17_DATA___2 = 19,
	GP_0_18_DATA = 20,
	GP_0_19_DATA = 21,
	GP_0_20_DATA = 22,
	GP_0_21_DATA = 23,
	GP_1_0_DATA___6 = 24,
	GP_1_1_DATA___6 = 25,
	GP_1_2_DATA___6 = 26,
	GP_1_3_DATA___6 = 27,
	GP_1_4_DATA___6 = 28,
	GP_1_5_DATA___6 = 29,
	GP_1_6_DATA___6 = 30,
	GP_1_7_DATA___6 = 31,
	GP_1_8_DATA___6 = 32,
	GP_1_9_DATA___6 = 33,
	GP_1_10_DATA___6 = 34,
	GP_1_11_DATA___6 = 35,
	GP_1_12_DATA___6 = 36,
	GP_1_13_DATA___6 = 37,
	GP_1_14_DATA___6 = 38,
	GP_1_15_DATA___6 = 39,
	GP_1_16_DATA___6 = 40,
	GP_1_17_DATA___6 = 41,
	GP_1_18_DATA___6 = 42,
	GP_1_19_DATA___6 = 43,
	GP_1_20_DATA___6 = 44,
	GP_1_21_DATA___6 = 45,
	GP_1_22_DATA___6 = 46,
	GP_1_23_DATA___5 = 47,
	GP_1_24_DATA___5 = 48,
	GP_1_25_DATA___5 = 49,
	GP_1_26_DATA___5 = 50,
	GP_1_27_DATA___5 = 51,
	GP_2_0_DATA___6 = 52,
	GP_2_1_DATA___6 = 53,
	GP_2_2_DATA___6 = 54,
	GP_2_3_DATA___6 = 55,
	GP_2_4_DATA___6 = 56,
	GP_2_5_DATA___6 = 57,
	GP_2_6_DATA___6 = 58,
	GP_2_7_DATA___6 = 59,
	GP_2_8_DATA___6 = 60,
	GP_2_9_DATA___6 = 61,
	GP_2_10_DATA___6 = 62,
	GP_2_11_DATA___6 = 63,
	GP_2_12_DATA___6 = 64,
	GP_2_13_DATA___6 = 65,
	GP_2_14_DATA___6 = 66,
	GP_2_15_DATA___2 = 67,
	GP_2_16_DATA___2 = 68,
	GP_3_0_DATA___6 = 69,
	GP_3_1_DATA___6 = 70,
	GP_3_2_DATA___6 = 71,
	GP_3_3_DATA___6 = 72,
	GP_3_4_DATA___6 = 73,
	GP_3_5_DATA___6 = 74,
	GP_3_6_DATA___6 = 75,
	GP_3_7_DATA___6 = 76,
	GP_3_8_DATA___6 = 77,
	GP_3_9_DATA___6 = 78,
	GP_3_10_DATA___6 = 79,
	GP_3_11_DATA___6 = 80,
	GP_3_12_DATA___6 = 81,
	GP_3_13_DATA___6 = 82,
	GP_3_14_DATA___6 = 83,
	GP_3_15_DATA___6 = 84,
	GP_3_16_DATA = 85,
	GP_4_0_DATA___6 = 86,
	GP_4_1_DATA___6 = 87,
	GP_4_2_DATA___6 = 88,
	GP_4_3_DATA___6 = 89,
	GP_4_4_DATA___6 = 90,
	GP_4_5_DATA___6 = 91,
	GP_5_0_DATA___6 = 92,
	GP_5_1_DATA___6 = 93,
	GP_5_2_DATA___6 = 94,
	GP_5_3_DATA___6 = 95,
	GP_5_4_DATA___6 = 96,
	GP_5_5_DATA___6 = 97,
	GP_5_6_DATA___6 = 98,
	GP_5_7_DATA___6 = 99,
	GP_5_8_DATA___6 = 100,
	GP_5_9_DATA___6 = 101,
	GP_5_10_DATA___6 = 102,
	GP_5_11_DATA___6 = 103,
	GP_5_12_DATA___6 = 104,
	GP_5_13_DATA___6 = 105,
	GP_5_14_DATA___6 = 106,
	PINMUX_DATA_END___6 = 107,
	PINMUX_FUNCTION_BEGIN___6 = 108,
	GP_0_0_FN___6 = 109,
	GP_0_1_FN___6 = 110,
	GP_0_2_FN___6 = 111,
	GP_0_3_FN___6 = 112,
	GP_0_4_FN___6 = 113,
	GP_0_5_FN___6 = 114,
	GP_0_6_FN___6 = 115,
	GP_0_7_FN___6 = 116,
	GP_0_8_FN___6 = 117,
	GP_0_9_FN___6 = 118,
	GP_0_10_FN___6 = 119,
	GP_0_11_FN___6 = 120,
	GP_0_12_FN___6 = 121,
	GP_0_13_FN___6 = 122,
	GP_0_14_FN___6 = 123,
	GP_0_15_FN___6 = 124,
	GP_0_16_FN___2 = 125,
	GP_0_17_FN___2 = 126,
	GP_0_18_FN = 127,
	GP_0_19_FN = 128,
	GP_0_20_FN = 129,
	GP_0_21_FN = 130,
	GP_1_0_FN___6 = 131,
	GP_1_1_FN___6 = 132,
	GP_1_2_FN___6 = 133,
	GP_1_3_FN___6 = 134,
	GP_1_4_FN___6 = 135,
	GP_1_5_FN___6 = 136,
	GP_1_6_FN___6 = 137,
	GP_1_7_FN___6 = 138,
	GP_1_8_FN___6 = 139,
	GP_1_9_FN___6 = 140,
	GP_1_10_FN___6 = 141,
	GP_1_11_FN___6 = 142,
	GP_1_12_FN___6 = 143,
	GP_1_13_FN___6 = 144,
	GP_1_14_FN___6 = 145,
	GP_1_15_FN___6 = 146,
	GP_1_16_FN___6 = 147,
	GP_1_17_FN___6 = 148,
	GP_1_18_FN___6 = 149,
	GP_1_19_FN___6 = 150,
	GP_1_20_FN___6 = 151,
	GP_1_21_FN___6 = 152,
	GP_1_22_FN___6 = 153,
	GP_1_23_FN___5 = 154,
	GP_1_24_FN___5 = 155,
	GP_1_25_FN___5 = 156,
	GP_1_26_FN___5 = 157,
	GP_1_27_FN___5 = 158,
	GP_2_0_FN___6 = 159,
	GP_2_1_FN___6 = 160,
	GP_2_2_FN___6 = 161,
	GP_2_3_FN___6 = 162,
	GP_2_4_FN___6 = 163,
	GP_2_5_FN___6 = 164,
	GP_2_6_FN___6 = 165,
	GP_2_7_FN___6 = 166,
	GP_2_8_FN___6 = 167,
	GP_2_9_FN___6 = 168,
	GP_2_10_FN___6 = 169,
	GP_2_11_FN___6 = 170,
	GP_2_12_FN___6 = 171,
	GP_2_13_FN___6 = 172,
	GP_2_14_FN___6 = 173,
	GP_2_15_FN___2 = 174,
	GP_2_16_FN___2 = 175,
	GP_3_0_FN___6 = 176,
	GP_3_1_FN___6 = 177,
	GP_3_2_FN___6 = 178,
	GP_3_3_FN___6 = 179,
	GP_3_4_FN___6 = 180,
	GP_3_5_FN___6 = 181,
	GP_3_6_FN___6 = 182,
	GP_3_7_FN___6 = 183,
	GP_3_8_FN___6 = 184,
	GP_3_9_FN___6 = 185,
	GP_3_10_FN___6 = 186,
	GP_3_11_FN___6 = 187,
	GP_3_12_FN___6 = 188,
	GP_3_13_FN___6 = 189,
	GP_3_14_FN___6 = 190,
	GP_3_15_FN___6 = 191,
	GP_3_16_FN = 192,
	GP_4_0_FN___6 = 193,
	GP_4_1_FN___6 = 194,
	GP_4_2_FN___6 = 195,
	GP_4_3_FN___6 = 196,
	GP_4_4_FN___6 = 197,
	GP_4_5_FN___6 = 198,
	GP_5_0_FN___6 = 199,
	GP_5_1_FN___6 = 200,
	GP_5_2_FN___6 = 201,
	GP_5_3_FN___6 = 202,
	GP_5_4_FN___6 = 203,
	GP_5_5_FN___6 = 204,
	GP_5_6_FN___6 = 205,
	GP_5_7_FN___6 = 206,
	GP_5_8_FN___6 = 207,
	GP_5_9_FN___6 = 208,
	GP_5_10_FN___6 = 209,
	GP_5_11_FN___6 = 210,
	GP_5_12_FN___6 = 211,
	GP_5_13_FN___6 = 212,
	GP_5_14_FN___6 = 213,
	FN_AVB0_AVTP_MATCH = 214,
	FN_AVB0_LINK = 215,
	FN_AVB0_PHY_INT = 216,
	FN_AVB0_MAGIC = 217,
	FN_AVB0_MDC = 218,
	FN_AVB0_MDIO = 219,
	FN_RPC_INT_N___2 = 220,
	FN_AVB0_TXCREFCLK = 221,
	FN_RPC_WP_N = 222,
	FN_AVB0_TD3 = 223,
	FN_RPC_RESET_N___2 = 224,
	FN_AVB0_TD2 = 225,
	FN_QSPI1_SSL___2 = 226,
	FN_AVB0_TD1 = 227,
	FN_QSPI1_IO3___2 = 228,
	FN_AVB0_TD0 = 229,
	FN_QSPI1_IO2___2 = 230,
	FN_AVB0_TXC = 231,
	FN_QSPI1_MISO_IO1___2 = 232,
	FN_AVB0_TX_CTL = 233,
	FN_QSPI1_MOSI_IO0___2 = 234,
	FN_AVB0_RD3 = 235,
	FN_QSPI1_SPCLK___2 = 236,
	FN_AVB0_RD2 = 237,
	FN_QSPI0_SSL___2 = 238,
	FN_AVB0_RD1 = 239,
	FN_QSPI0_IO3___2 = 240,
	FN_AVB0_RD0 = 241,
	FN_QSPI0_IO2___2 = 242,
	FN_AVB0_RXC = 243,
	FN_QSPI0_MISO_IO1___2 = 244,
	FN_AVB0_RX_CTL = 245,
	FN_QSPI0_MOSI_IO0___2 = 246,
	FN_QSPI0_SPCLK___2 = 247,
	FN_IP0_3_0___6 = 248,
	FN_DU_DR2___6 = 249,
	FN_HSCK0___5 = 250,
	FN_A0___6 = 251,
	FN_IP1_3_0___6 = 252,
	FN_DU_DG4___6 = 253,
	FN_A8___6 = 254,
	FN_FSO_CFE_0_N_A___2 = 255,
	FN_IP2_3_0___6 = 256,
	FN_DU_DB6___6 = 257,
	FN_A16___6 = 258,
	FN_FXR_TXENB_N = 259,
	FN_IP3_3_0___6 = 260,
	FN_VI0_CLKENB = 261,
	FN_MSIOF2_RXD = 262,
	FN_RX3 = 263,
	FN_RD_WR_N___6 = 264,
	FN_HCTS3_N___5 = 265,
	FN_IP0_7_4___6 = 266,
	FN_DU_DR3___6 = 267,
	FN_HRTS0_N___5 = 268,
	FN_A1___6 = 269,
	FN_IP1_7_4___6 = 270,
	FN_DU_DG5___6 = 271,
	FN_A9___6 = 272,
	FN_FSO_CFE_1_N_A___2 = 273,
	FN_IP2_7_4___6 = 274,
	FN_DU_DB7___6 = 275,
	FN_A17___6 = 276,
	FN_IP3_7_4___6 = 277,
	FN_VI0_HSYNC_N = 278,
	FN_MSIOF2_TXD = 279,
	FN_TX3 = 280,
	FN_HRTS3_N___5 = 281,
	FN_IP0_11_8___6 = 282,
	FN_DU_DR4___6 = 283,
	FN_HCTS0_N___5 = 284,
	FN_A2___6 = 285,
	FN_IP1_11_8___6 = 286,
	FN_DU_DG6___6 = 287,
	FN_A10___6 = 288,
	FN_FSO_TOE_N_A___2 = 289,
	FN_IP2_11_8___6 = 290,
	FN_DU_DOTCLKOUT = 291,
	FN_SCIF_CLK_A___6 = 292,
	FN_A18___6 = 293,
	FN_IP3_11_8___6 = 294,
	FN_VI0_VSYNC_N = 295,
	FN_MSIOF2_SYNC = 296,
	FN_CTS3_N___5 = 297,
	FN_HTX3 = 298,
	FN_IP0_15_12___6 = 299,
	FN_DU_DR5___6 = 300,
	FN_HTX0___5 = 301,
	FN_A3___6 = 302,
	FN_IP1_15_12___6 = 303,
	FN_DU_DG7___6 = 304,
	FN_A11___6 = 305,
	FN_IRQ1___6 = 306,
	FN_IP2_15_12___6 = 307,
	FN_DU_EXHSYNC_DU_HSYNC___5 = 308,
	FN_HRX0___5 = 309,
	FN_A19___6 = 310,
	FN_IRQ3___6 = 311,
	FN_IP3_15_12___6 = 312,
	FN_VI0_DATA0 = 313,
	FN_MSIOF2_SS1 = 314,
	FN_RTS3_N___5 = 315,
	FN_HRX3 = 316,
	FN_IP0_19_16___6 = 317,
	FN_DU_DR6___6 = 318,
	FN_MSIOF3_RXD = 319,
	FN_A4___6 = 320,
	FN_IP1_19_16___6 = 321,
	FN_DU_DB2___6 = 322,
	FN_A12___6 = 323,
	FN_IRQ2___6 = 324,
	FN_IP2_19_16___6 = 325,
	FN_DU_EXVSYNC_DU_VSYNC___5 = 326,
	FN_MSIOF3_SCK = 327,
	FN_IP3_19_16___6 = 328,
	FN_VI0_DATA1 = 329,
	FN_MSIOF2_SS2 = 330,
	FN_SCK1___6 = 331,
	FN_SPEEDIN_A___6 = 332,
	FN_IP0_23_20___6 = 333,
	FN_DU_DR7___6 = 334,
	FN_MSIOF3_TXD = 335,
	FN_A5___6 = 336,
	FN_IP1_23_20___6 = 337,
	FN_DU_DB3___6 = 338,
	FN_A13___6 = 339,
	FN_FXR_CLKOUT1 = 340,
	FN_IP2_23_20___6 = 341,
	FN_DU_EXODDF_DU_ODDF_DISP_CDE___5 = 342,
	FN_MSIOF3_SYNC = 343,
	FN_IP3_23_20___6 = 344,
	FN_VI0_DATA2 = 345,
	FN_AVB0_AVTP_PPS = 346,
	FN_SDA3_A = 347,
	FN_IP0_27_24___6 = 348,
	FN_DU_DG2___6 = 349,
	FN_MSIOF3_SS1 = 350,
	FN_A6___6 = 351,
	FN_IP1_27_24___6 = 352,
	FN_DU_DB4___6 = 353,
	FN_A14___6 = 354,
	FN_FXR_CLKOUT2 = 355,
	FN_IP2_27_24___6 = 356,
	FN_IRQ0___6 = 357,
	FN_IP3_27_24___6 = 358,
	FN_VI0_DATA3 = 359,
	FN_HSCK1 = 360,
	FN_SCL3_A = 361,
	FN_IP0_31_28___6 = 362,
	FN_DU_DG3___6 = 363,
	FN_MSIOF3_SS2 = 364,
	FN_A7___6 = 365,
	FN_PWMFSW0 = 366,
	FN_IP1_31_28___6 = 367,
	FN_DU_DB5___6 = 368,
	FN_A15___6 = 369,
	FN_FXR_TXENA_N = 370,
	FN_IP2_31_28___6 = 371,
	FN_VI0_CLK = 372,
	FN_MSIOF2_SCK = 373,
	FN_SCK3___5 = 374,
	FN_HSCK3___5 = 375,
	FN_IP3_31_28___6 = 376,
	FN_VI0_DATA4 = 377,
	FN_HRTS1_N = 378,
	FN_RX1_A___5 = 379,
	FN_IP4_3_0___6 = 380,
	FN_VI0_DATA5 = 381,
	FN_HCTS1_N = 382,
	FN_TX1_A___5 = 383,
	FN_IP5_3_0___6 = 384,
	FN_VI1_CLK = 385,
	FN_MSIOF1_RXD___2 = 386,
	FN_CS0_N___6 = 387,
	FN_IP6_3_0___6 = 388,
	FN_VI1_DATA4 = 389,
	FN_CANFD_CLK_B = 390,
	FN_D7___6 = 391,
	FN_MMC_D2 = 392,
	FN_IP7_3_0___6 = 393,
	FN_VI1_FIELD = 394,
	FN_SDA4___2 = 395,
	FN_IRQ5___6 = 396,
	FN_D15___6 = 397,
	FN_IP4_7_4___6 = 398,
	FN_VI0_DATA6 = 399,
	FN_HTX1 = 400,
	FN_CTS1_N___6 = 401,
	FN_IP5_7_4___6 = 402,
	FN_VI1_CLKENB = 403,
	FN_MSIOF1_TXD___2 = 404,
	FN_D0___6 = 405,
	FN_IP6_7_4___6 = 406,
	FN_VI1_DATA5 = 407,
	FN_SCK4 = 408,
	FN_D8___6 = 409,
	FN_MMC_D3 = 410,
	FN_IP7_7_4___6 = 411,
	FN_SCL0 = 412,
	FN_DU_DR0___6 = 413,
	FN_TPU0TO0___6 = 414,
	FN_CLKOUT___5 = 415,
	FN_MSIOF0_RXD___6 = 416,
	FN_IP4_11_8___6 = 417,
	FN_VI0_DATA7 = 418,
	FN_HRX1 = 419,
	FN_RTS1_N___6 = 420,
	FN_IP5_11_8___6 = 421,
	FN_VI1_HSYNC_N = 422,
	FN_MSIOF1_SCK___2 = 423,
	FN_D1___6 = 424,
	FN_IP6_11_8___6 = 425,
	FN_VI1_DATA6 = 426,
	FN_RX4 = 427,
	FN_D9___6 = 428,
	FN_MMC_CLK = 429,
	FN_IP7_11_8___6 = 430,
	FN_SDA0 = 431,
	FN_DU_DR1___6 = 432,
	FN_TPU0TO1___6 = 433,
	FN_BS_N___6 = 434,
	FN_SCK0___5 = 435,
	FN_MSIOF0_TXD___6 = 436,
	FN_IP4_15_12___6 = 437,
	FN_VI0_DATA8 = 438,
	FN_HSCK2 = 439,
	FN_PWM0_A___2 = 440,
	FN_A22___2 = 441,
	FN_IP5_15_12___6 = 442,
	FN_VI1_VSYNC_N = 443,
	FN_MSIOF1_SYNC___2 = 444,
	FN_D2___6 = 445,
	FN_IP6_15_12___6 = 446,
	FN_VI1_DATA7 = 447,
	FN_TX4 = 448,
	FN_D10___6 = 449,
	FN_MMC_D4 = 450,
	FN_IP7_15_12___3 = 451,
	FN_SCL1 = 452,
	FN_DU_DG0___6 = 453,
	FN_TPU0TO2___6 = 454,
	FN_RD_N___6 = 455,
	FN_CTS0_N___5 = 456,
	FN_MSIOF0_SCK___6 = 457,
	FN_IP4_19_16___6 = 458,
	FN_VI0_DATA9 = 459,
	FN_HCTS2_N = 460,
	FN_PWM1_A___6 = 461,
	FN_A23___2 = 462,
	FN_FSO_CFE_0_N_B___2 = 463,
	FN_IP5_19_16___6 = 464,
	FN_VI1_DATA0 = 465,
	FN_MSIOF1_SS1___2 = 466,
	FN_D3___6 = 467,
	FN_IP6_19_16___6 = 468,
	FN_VI1_DATA8 = 469,
	FN_CTS4_N = 470,
	FN_D11___6 = 471,
	FN_MMC_D5 = 472,
	FN_IP7_19_16___6 = 473,
	FN_SDA1 = 474,
	FN_DU_DG1___6 = 475,
	FN_TPU0TO3___6 = 476,
	FN_WE0_N___6 = 477,
	FN_RTS0_N___5 = 478,
	FN_MSIOF0_SYNC___6 = 479,
	FN_IP4_23_20___6 = 480,
	FN_VI0_DATA10 = 481,
	FN_HRTS2_N = 482,
	FN_PWM2_A___6 = 483,
	FN_A24___2 = 484,
	FN_FSO_CFE_1_N_B___2 = 485,
	FN_IP5_23_20___6 = 486,
	FN_VI1_DATA1 = 487,
	FN_MSIOF1_SS2___2 = 488,
	FN_D4___6 = 489,
	FN_MMC_CMD = 490,
	FN_IP6_23_20___6 = 491,
	FN_VI1_DATA9 = 492,
	FN_RTS4_N = 493,
	FN_D12___6 = 494,
	FN_MMC_D6 = 495,
	FN_SCL3_B = 496,
	FN_IP7_23_20___6 = 497,
	FN_SCL2 = 498,
	FN_DU_DB0___6 = 499,
	FN_TCLK1_A___6 = 500,
	FN_WE1_N___6 = 501,
	FN_RX0___5 = 502,
	FN_MSIOF0_SS1___6 = 503,
	FN_IP4_27_24___6 = 504,
	FN_VI0_DATA11 = 505,
	FN_HTX2 = 506,
	FN_PWM3_A___6 = 507,
	FN_A25___2 = 508,
	FN_FSO_TOE_N_B___2 = 509,
	FN_IP5_27_24___6 = 510,
	FN_VI1_DATA2 = 511,
	FN_CANFD0_TX_B___5 = 512,
	FN_D5___6 = 513,
	FN_MMC_D0 = 514,
	FN_IP6_27_24___6 = 515,
	FN_VI1_DATA10 = 516,
	FN_D13___6 = 517,
	FN_MMC_D7 = 518,
	FN_SDA3_B = 519,
	FN_IP7_27_24___6 = 520,
	FN_SDA2 = 521,
	FN_DU_DB1___6 = 522,
	FN_TCLK2_A___6 = 523,
	FN_EX_WAIT0___2 = 524,
	FN_TX0___5 = 525,
	FN_MSIOF0_SS2___6 = 526,
	FN_IP4_31_28___6 = 527,
	FN_VI0_FIELD = 528,
	FN_HRX2 = 529,
	FN_PWM4_A___6 = 530,
	FN_CS1_N___4 = 531,
	FN_FSCLKST2_N_A___4 = 532,
	FN_IP5_31_28___6 = 533,
	FN_VI1_DATA3 = 534,
	FN_CANFD0_RX_B___5 = 535,
	FN_D6___6 = 536,
	FN_MMC_D1 = 537,
	FN_IP6_31_28___6 = 538,
	FN_VI1_DATA11 = 539,
	FN_SCL4___2 = 540,
	FN_IRQ4___6 = 541,
	FN_D14___6 = 542,
	FN_IP7_31_28___6 = 543,
	FN_AVB0_AVTP_CAPTURE = 544,
	FN_FSCLKST2_N_B___4 = 545,
	FN_IP8_3_0___6 = 546,
	FN_CANFD0_TX_A___5 = 547,
	FN_FXR_TXDA = 548,
	FN_PWM0_B___2 = 549,
	FN_DU_DISP___6 = 550,
	FN_FSCLKST2_N_C = 551,
	FN_IP8_7_4___6 = 552,
	FN_CANFD0_RX_A___5 = 553,
	FN_RXDA_EXTFXR = 554,
	FN_PWM1_B___6 = 555,
	FN_DU_CDE___6 = 556,
	FN_IP8_11_8___6 = 557,
	FN_CANFD1_TX___6 = 558,
	FN_FXR_TXDB = 559,
	FN_PWM2_B___6 = 560,
	FN_TCLK1_B___6 = 561,
	FN_TX1_B___5 = 562,
	FN_IP8_15_12___6 = 563,
	FN_CANFD1_RX___6 = 564,
	FN_RXDB_EXTFXR = 565,
	FN_PWM3_B___6 = 566,
	FN_TCLK2_B___6 = 567,
	FN_RX1_B___5 = 568,
	FN_IP8_19_16___6 = 569,
	FN_CANFD_CLK_A = 570,
	FN_CLK_EXTFXR = 571,
	FN_PWM4_B___6 = 572,
	FN_SPEEDIN_B___6 = 573,
	FN_SCIF_CLK_B___6 = 574,
	FN_IP8_23_20___6 = 575,
	FN_DIGRF_CLKIN = 576,
	FN_DIGRF_CLKEN_IN = 577,
	FN_IP8_27_24___6 = 578,
	FN_DIGRF_CLKOUT = 579,
	FN_DIGRF_CLKEN_OUT = 580,
	FN_IP8_31_28___6 = 581,
	FN_SEL_I2C3_0 = 582,
	FN_SEL_I2C3_1 = 583,
	FN_SEL_HSCIF0_0___2 = 584,
	FN_SEL_HSCIF0_1___2 = 585,
	FN_SEL_SCIF1_0___5 = 586,
	FN_SEL_SCIF1_1___5 = 587,
	FN_SEL_CANFD0_0___5 = 588,
	FN_SEL_CANFD0_1___5 = 589,
	FN_SEL_PWM4_0___6 = 590,
	FN_SEL_PWM4_1___6 = 591,
	FN_SEL_PWM3_0___6 = 592,
	FN_SEL_PWM3_1___6 = 593,
	FN_SEL_PWM2_0___6 = 594,
	FN_SEL_PWM2_1___6 = 595,
	FN_SEL_PWM1_0___6 = 596,
	FN_SEL_PWM1_1___6 = 597,
	FN_SEL_PWM0_0___2 = 598,
	FN_SEL_PWM0_1___2 = 599,
	FN_SEL_RFSO_0 = 600,
	FN_SEL_RFSO_1 = 601,
	FN_SEL_RSP_0 = 602,
	FN_SEL_RSP_1 = 603,
	FN_SEL_TMU_0 = 604,
	FN_SEL_TMU_1 = 605,
	PINMUX_FUNCTION_END___6 = 606,
	PINMUX_MARK_BEGIN___6 = 607,
	AVB0_AVTP_MATCH_MARK = 608,
	AVB0_LINK_MARK = 609,
	AVB0_PHY_INT_MARK = 610,
	AVB0_MAGIC_MARK = 611,
	AVB0_MDC_MARK = 612,
	AVB0_MDIO_MARK = 613,
	RPC_INT_N_MARK___2 = 614,
	AVB0_TXCREFCLK_MARK = 615,
	RPC_WP_N_MARK = 616,
	AVB0_TD3_MARK = 617,
	RPC_RESET_N_MARK___2 = 618,
	AVB0_TD2_MARK = 619,
	QSPI1_SSL_MARK___6 = 620,
	AVB0_TD1_MARK = 621,
	QSPI1_IO3_MARK___6 = 622,
	AVB0_TD0_MARK = 623,
	QSPI1_IO2_MARK___6 = 624,
	AVB0_TXC_MARK = 625,
	QSPI1_MISO_IO1_MARK___6 = 626,
	AVB0_TX_CTL_MARK = 627,
	QSPI1_MOSI_IO0_MARK___6 = 628,
	AVB0_RD3_MARK = 629,
	QSPI1_SPCLK_MARK___6 = 630,
	AVB0_RD2_MARK = 631,
	QSPI0_SSL_MARK___6 = 632,
	AVB0_RD1_MARK = 633,
	QSPI0_IO3_MARK___6 = 634,
	AVB0_RD0_MARK = 635,
	QSPI0_IO2_MARK___6 = 636,
	AVB0_RXC_MARK = 637,
	QSPI0_MISO_IO1_MARK___6 = 638,
	AVB0_RX_CTL_MARK = 639,
	QSPI0_MOSI_IO0_MARK___6 = 640,
	QSPI0_SPCLK_MARK___6 = 641,
	IP0_3_0_MARK___6 = 642,
	DU_DR2_MARK___6 = 643,
	HSCK0_MARK___5 = 644,
	A0_MARK___6 = 645,
	IP1_3_0_MARK___6 = 646,
	DU_DG4_MARK___6 = 647,
	A8_MARK___6 = 648,
	FSO_CFE_0_N_A_MARK___2 = 649,
	IP2_3_0_MARK___6 = 650,
	DU_DB6_MARK___6 = 651,
	A16_MARK___6 = 652,
	FXR_TXENB_N_MARK = 653,
	IP3_3_0_MARK___6 = 654,
	VI0_CLKENB_MARK = 655,
	MSIOF2_RXD_MARK = 656,
	RX3_MARK = 657,
	RD_WR_N_MARK___6 = 658,
	HCTS3_N_MARK___5 = 659,
	IP0_7_4_MARK___6 = 660,
	DU_DR3_MARK___6 = 661,
	HRTS0_N_MARK___5 = 662,
	A1_MARK___6 = 663,
	IP1_7_4_MARK___6 = 664,
	DU_DG5_MARK___6 = 665,
	A9_MARK___6 = 666,
	FSO_CFE_1_N_A_MARK___2 = 667,
	IP2_7_4_MARK___6 = 668,
	DU_DB7_MARK___6 = 669,
	A17_MARK___6 = 670,
	IP3_7_4_MARK___6 = 671,
	VI0_HSYNC_N_MARK = 672,
	MSIOF2_TXD_MARK = 673,
	TX3_MARK = 674,
	HRTS3_N_MARK___5 = 675,
	IP0_11_8_MARK___6 = 676,
	DU_DR4_MARK___6 = 677,
	HCTS0_N_MARK___5 = 678,
	A2_MARK___6 = 679,
	IP1_11_8_MARK___6 = 680,
	DU_DG6_MARK___6 = 681,
	A10_MARK___6 = 682,
	FSO_TOE_N_A_MARK___2 = 683,
	IP2_11_8_MARK___6 = 684,
	DU_DOTCLKOUT_MARK = 685,
	SCIF_CLK_A_MARK___6 = 686,
	A18_MARK___6 = 687,
	IP3_11_8_MARK___6 = 688,
	VI0_VSYNC_N_MARK = 689,
	MSIOF2_SYNC_MARK = 690,
	CTS3_N_MARK___5 = 691,
	HTX3_MARK = 692,
	IP0_15_12_MARK___6 = 693,
	DU_DR5_MARK___6 = 694,
	HTX0_MARK___5 = 695,
	A3_MARK___6 = 696,
	IP1_15_12_MARK___6 = 697,
	DU_DG7_MARK___6 = 698,
	A11_MARK___6 = 699,
	IRQ1_MARK___6 = 700,
	IP2_15_12_MARK___6 = 701,
	DU_EXHSYNC_DU_HSYNC_MARK___5 = 702,
	HRX0_MARK___5 = 703,
	A19_MARK___6 = 704,
	IRQ3_MARK___6 = 705,
	IP3_15_12_MARK___6 = 706,
	VI0_DATA0_MARK = 707,
	MSIOF2_SS1_MARK = 708,
	RTS3_N_MARK___5 = 709,
	HRX3_MARK = 710,
	IP0_19_16_MARK___6 = 711,
	DU_DR6_MARK___6 = 712,
	MSIOF3_RXD_MARK = 713,
	A4_MARK___6 = 714,
	IP1_19_16_MARK___6 = 715,
	DU_DB2_MARK___6 = 716,
	A12_MARK___6 = 717,
	IRQ2_MARK___6 = 718,
	IP2_19_16_MARK___6 = 719,
	DU_EXVSYNC_DU_VSYNC_MARK___5 = 720,
	MSIOF3_SCK_MARK = 721,
	IP3_19_16_MARK___6 = 722,
	VI0_DATA1_MARK = 723,
	MSIOF2_SS2_MARK = 724,
	SCK1_MARK___6 = 725,
	SPEEDIN_A_MARK___6 = 726,
	IP0_23_20_MARK___6 = 727,
	DU_DR7_MARK___6 = 728,
	MSIOF3_TXD_MARK = 729,
	A5_MARK___6 = 730,
	IP1_23_20_MARK___6 = 731,
	DU_DB3_MARK___6 = 732,
	A13_MARK___6 = 733,
	FXR_CLKOUT1_MARK = 734,
	IP2_23_20_MARK___6 = 735,
	DU_EXODDF_DU_ODDF_DISP_CDE_MARK___5 = 736,
	MSIOF3_SYNC_MARK = 737,
	IP3_23_20_MARK___6 = 738,
	VI0_DATA2_MARK = 739,
	AVB0_AVTP_PPS_MARK = 740,
	SDA3_A_MARK = 741,
	IP0_27_24_MARK___6 = 742,
	DU_DG2_MARK___6 = 743,
	MSIOF3_SS1_MARK = 744,
	A6_MARK___6 = 745,
	IP1_27_24_MARK___6 = 746,
	DU_DB4_MARK___6 = 747,
	A14_MARK___6 = 748,
	FXR_CLKOUT2_MARK = 749,
	IP2_27_24_MARK___6 = 750,
	IRQ0_MARK___6 = 751,
	IP3_27_24_MARK___6 = 752,
	VI0_DATA3_MARK = 753,
	HSCK1_MARK = 754,
	SCL3_A_MARK = 755,
	IP0_31_28_MARK___6 = 756,
	DU_DG3_MARK___6 = 757,
	MSIOF3_SS2_MARK = 758,
	A7_MARK___6 = 759,
	PWMFSW0_MARK = 760,
	IP1_31_28_MARK___6 = 761,
	DU_DB5_MARK___6 = 762,
	A15_MARK___6 = 763,
	FXR_TXENA_N_MARK = 764,
	IP2_31_28_MARK___6 = 765,
	VI0_CLK_MARK = 766,
	MSIOF2_SCK_MARK = 767,
	SCK3_MARK___5 = 768,
	HSCK3_MARK___5 = 769,
	IP3_31_28_MARK___6 = 770,
	VI0_DATA4_MARK = 771,
	HRTS1_N_MARK = 772,
	RX1_A_MARK___5 = 773,
	IP4_3_0_MARK___6 = 774,
	VI0_DATA5_MARK = 775,
	HCTS1_N_MARK = 776,
	TX1_A_MARK___5 = 777,
	IP5_3_0_MARK___6 = 778,
	VI1_CLK_MARK = 779,
	MSIOF1_RXD_MARK___2 = 780,
	CS0_N_MARK___6 = 781,
	IP6_3_0_MARK___6 = 782,
	VI1_DATA4_MARK = 783,
	CANFD_CLK_B_MARK = 784,
	D7_MARK___6 = 785,
	MMC_D2_MARK = 786,
	IP7_3_0_MARK___6 = 787,
	VI1_FIELD_MARK = 788,
	SDA4_MARK___2 = 789,
	IRQ5_MARK___6 = 790,
	D15_MARK___6 = 791,
	IP4_7_4_MARK___6 = 792,
	VI0_DATA6_MARK = 793,
	HTX1_MARK = 794,
	CTS1_N_MARK___6 = 795,
	IP5_7_4_MARK___6 = 796,
	VI1_CLKENB_MARK = 797,
	MSIOF1_TXD_MARK___2 = 798,
	D0_MARK___6 = 799,
	IP6_7_4_MARK___6 = 800,
	VI1_DATA5_MARK = 801,
	SCK4_MARK = 802,
	D8_MARK___6 = 803,
	MMC_D3_MARK = 804,
	IP7_7_4_MARK___6 = 805,
	SCL0_MARK___5 = 806,
	DU_DR0_MARK___6 = 807,
	TPU0TO0_MARK___6 = 808,
	CLKOUT_MARK___6 = 809,
	MSIOF0_RXD_MARK___6 = 810,
	IP4_11_8_MARK___6 = 811,
	VI0_DATA7_MARK = 812,
	HRX1_MARK = 813,
	RTS1_N_MARK___6 = 814,
	IP5_11_8_MARK___6 = 815,
	VI1_HSYNC_N_MARK = 816,
	MSIOF1_SCK_MARK___2 = 817,
	D1_MARK___6 = 818,
	IP6_11_8_MARK___6 = 819,
	VI1_DATA6_MARK = 820,
	RX4_MARK = 821,
	D9_MARK___6 = 822,
	MMC_CLK_MARK = 823,
	IP7_11_8_MARK___6 = 824,
	SDA0_MARK___5 = 825,
	DU_DR1_MARK___6 = 826,
	TPU0TO1_MARK___6 = 827,
	BS_N_MARK___6 = 828,
	SCK0_MARK___5 = 829,
	MSIOF0_TXD_MARK___6 = 830,
	IP4_15_12_MARK___6 = 831,
	VI0_DATA8_MARK = 832,
	HSCK2_MARK = 833,
	PWM0_A_MARK___2 = 834,
	A22_MARK___2 = 835,
	IP5_15_12_MARK___6 = 836,
	VI1_VSYNC_N_MARK = 837,
	MSIOF1_SYNC_MARK___2 = 838,
	D2_MARK___6 = 839,
	IP6_15_12_MARK___6 = 840,
	VI1_DATA7_MARK = 841,
	TX4_MARK = 842,
	D10_MARK___6 = 843,
	MMC_D4_MARK = 844,
	IP7_15_12_MARK___3 = 845,
	SCL1_MARK = 846,
	DU_DG0_MARK___6 = 847,
	TPU0TO2_MARK___6 = 848,
	RD_N_MARK___6 = 849,
	CTS0_N_MARK___5 = 850,
	MSIOF0_SCK_MARK___6 = 851,
	IP4_19_16_MARK___6 = 852,
	VI0_DATA9_MARK = 853,
	HCTS2_N_MARK = 854,
	PWM1_A_MARK___6 = 855,
	A23_MARK___2 = 856,
	FSO_CFE_0_N_B_MARK___2 = 857,
	IP5_19_16_MARK___6 = 858,
	VI1_DATA0_MARK = 859,
	MSIOF1_SS1_MARK___2 = 860,
	D3_MARK___6 = 861,
	IP6_19_16_MARK___6 = 862,
	VI1_DATA8_MARK = 863,
	CTS4_N_MARK = 864,
	D11_MARK___6 = 865,
	MMC_D5_MARK = 866,
	IP7_19_16_MARK___6 = 867,
	SDA1_MARK = 868,
	DU_DG1_MARK___6 = 869,
	TPU0TO3_MARK___6 = 870,
	WE0_N_MARK___6 = 871,
	RTS0_N_MARK___5 = 872,
	MSIOF0_SYNC_MARK___6 = 873,
	IP4_23_20_MARK___6 = 874,
	VI0_DATA10_MARK = 875,
	HRTS2_N_MARK = 876,
	PWM2_A_MARK___6 = 877,
	A24_MARK___2 = 878,
	FSO_CFE_1_N_B_MARK___2 = 879,
	IP5_23_20_MARK___6 = 880,
	VI1_DATA1_MARK = 881,
	MSIOF1_SS2_MARK___2 = 882,
	D4_MARK___6 = 883,
	MMC_CMD_MARK = 884,
	IP6_23_20_MARK___6 = 885,
	VI1_DATA9_MARK = 886,
	RTS4_N_MARK = 887,
	D12_MARK___6 = 888,
	MMC_D6_MARK = 889,
	SCL3_B_MARK = 890,
	IP7_23_20_MARK___6 = 891,
	SCL2_MARK = 892,
	DU_DB0_MARK___6 = 893,
	TCLK1_A_MARK___6 = 894,
	WE1_N_MARK___6 = 895,
	RX0_MARK___5 = 896,
	MSIOF0_SS1_MARK___6 = 897,
	IP4_27_24_MARK___6 = 898,
	VI0_DATA11_MARK = 899,
	HTX2_MARK = 900,
	PWM3_A_MARK___6 = 901,
	A25_MARK___2 = 902,
	FSO_TOE_N_B_MARK___2 = 903,
	IP5_27_24_MARK___6 = 904,
	VI1_DATA2_MARK = 905,
	CANFD0_TX_B_MARK___5 = 906,
	D5_MARK___6 = 907,
	MMC_D0_MARK = 908,
	IP6_27_24_MARK___6 = 909,
	VI1_DATA10_MARK = 910,
	D13_MARK___6 = 911,
	MMC_D7_MARK = 912,
	SDA3_B_MARK = 913,
	IP7_27_24_MARK___6 = 914,
	SDA2_MARK = 915,
	DU_DB1_MARK___6 = 916,
	TCLK2_A_MARK___6 = 917,
	EX_WAIT0_MARK___2 = 918,
	TX0_MARK___5 = 919,
	MSIOF0_SS2_MARK___6 = 920,
	IP4_31_28_MARK___6 = 921,
	VI0_FIELD_MARK = 922,
	HRX2_MARK = 923,
	PWM4_A_MARK___6 = 924,
	CS1_N_MARK___4 = 925,
	FSCLKST2_N_A_MARK___4 = 926,
	IP5_31_28_MARK___6 = 927,
	VI1_DATA3_MARK = 928,
	CANFD0_RX_B_MARK___5 = 929,
	D6_MARK___6 = 930,
	MMC_D1_MARK = 931,
	IP6_31_28_MARK___6 = 932,
	VI1_DATA11_MARK = 933,
	SCL4_MARK___2 = 934,
	IRQ4_MARK___6 = 935,
	D14_MARK___6 = 936,
	IP7_31_28_MARK___6 = 937,
	AVB0_AVTP_CAPTURE_MARK = 938,
	FSCLKST2_N_B_MARK___4 = 939,
	IP8_3_0_MARK___6 = 940,
	CANFD0_TX_A_MARK___5 = 941,
	FXR_TXDA_MARK = 942,
	PWM0_B_MARK___2 = 943,
	DU_DISP_MARK___6 = 944,
	FSCLKST2_N_C_MARK = 945,
	IP8_7_4_MARK___6 = 946,
	CANFD0_RX_A_MARK___5 = 947,
	RXDA_EXTFXR_MARK = 948,
	PWM1_B_MARK___6 = 949,
	DU_CDE_MARK___6 = 950,
	IP8_11_8_MARK___6 = 951,
	CANFD1_TX_MARK___6 = 952,
	FXR_TXDB_MARK = 953,
	PWM2_B_MARK___6 = 954,
	TCLK1_B_MARK___6 = 955,
	TX1_B_MARK___5 = 956,
	IP8_15_12_MARK___6 = 957,
	CANFD1_RX_MARK___6 = 958,
	RXDB_EXTFXR_MARK = 959,
	PWM3_B_MARK___6 = 960,
	TCLK2_B_MARK___6 = 961,
	RX1_B_MARK___5 = 962,
	IP8_19_16_MARK___6 = 963,
	CANFD_CLK_A_MARK = 964,
	CLK_EXTFXR_MARK = 965,
	PWM4_B_MARK___6 = 966,
	SPEEDIN_B_MARK___6 = 967,
	SCIF_CLK_B_MARK___6 = 968,
	IP8_23_20_MARK___6 = 969,
	DIGRF_CLKIN_MARK = 970,
	DIGRF_CLKEN_IN_MARK = 971,
	IP8_27_24_MARK___6 = 972,
	DIGRF_CLKOUT_MARK = 973,
	DIGRF_CLKEN_OUT_MARK = 974,
	IP8_31_28_MARK___6 = 975,
	SEL_I2C3_0_MARK = 976,
	SEL_I2C3_1_MARK = 977,
	SEL_HSCIF0_0_MARK___2 = 978,
	SEL_HSCIF0_1_MARK___2 = 979,
	SEL_SCIF1_0_MARK___5 = 980,
	SEL_SCIF1_1_MARK___5 = 981,
	SEL_CANFD0_0_MARK___5 = 982,
	SEL_CANFD0_1_MARK___5 = 983,
	SEL_PWM4_0_MARK___6 = 984,
	SEL_PWM4_1_MARK___6 = 985,
	SEL_PWM3_0_MARK___6 = 986,
	SEL_PWM3_1_MARK___6 = 987,
	SEL_PWM2_0_MARK___6 = 988,
	SEL_PWM2_1_MARK___6 = 989,
	SEL_PWM1_0_MARK___6 = 990,
	SEL_PWM1_1_MARK___6 = 991,
	SEL_PWM0_0_MARK___2 = 992,
	SEL_PWM0_1_MARK___2 = 993,
	SEL_RFSO_0_MARK = 994,
	SEL_RFSO_1_MARK = 995,
	SEL_RSP_0_MARK = 996,
	SEL_RSP_1_MARK = 997,
	SEL_TMU_0_MARK = 998,
	SEL_TMU_1_MARK = 999,
	PINMUX_MARK_END___6 = 1000,
};

enum {
	GP_LAST___6 = 174,
	PIN_DU_DOTCLKIN = 175,
	PIN_EXTALR___5 = 176,
	PIN_FSCLKST_N___4 = 177,
	PIN_PRESETOUT_N___6 = 178,
	PIN_TCK___6 = 179,
	PIN_TDI___6 = 180,
	PIN_TMS___6 = 181,
	PIN_TRST_N___6 = 182,
};

enum ioctrl_regs___3 {
	POCCTRL0___2 = 0,
	POCCTRL1 = 1,
	POCCTRL2 = 2,
	TDSELCTRL___3 = 3,
};

enum {
	PINMUX_RESERVED___7 = 0,
	PINMUX_DATA_BEGIN___7 = 1,
	GP_0_0_DATA___7 = 2,
	GP_0_1_DATA___7 = 3,
	GP_0_2_DATA___7 = 4,
	GP_0_3_DATA___7 = 5,
	GP_0_4_DATA___7 = 6,
	GP_0_5_DATA___7 = 7,
	GP_0_6_DATA___7 = 8,
	GP_0_7_DATA___7 = 9,
	GP_0_8_DATA___7 = 10,
	GP_0_9_DATA___7 = 11,
	GP_0_10_DATA___7 = 12,
	GP_0_11_DATA___7 = 13,
	GP_0_12_DATA___7 = 14,
	GP_0_13_DATA___7 = 15,
	GP_0_14_DATA___7 = 16,
	GP_0_15_DATA___7 = 17,
	GP_0_16_DATA___3 = 18,
	GP_0_17_DATA___3 = 19,
	GP_0_18_DATA___2 = 20,
	GP_0_19_DATA___2 = 21,
	GP_0_20_DATA___2 = 22,
	GP_0_21_DATA___2 = 23,
	GP_1_0_DATA___7 = 24,
	GP_1_1_DATA___7 = 25,
	GP_1_2_DATA___7 = 26,
	GP_1_3_DATA___7 = 27,
	GP_1_4_DATA___7 = 28,
	GP_1_5_DATA___7 = 29,
	GP_1_6_DATA___7 = 30,
	GP_1_7_DATA___7 = 31,
	GP_1_8_DATA___7 = 32,
	GP_1_9_DATA___7 = 33,
	GP_1_10_DATA___7 = 34,
	GP_1_11_DATA___7 = 35,
	GP_1_12_DATA___7 = 36,
	GP_1_13_DATA___7 = 37,
	GP_1_14_DATA___7 = 38,
	GP_1_15_DATA___7 = 39,
	GP_1_16_DATA___7 = 40,
	GP_1_17_DATA___7 = 41,
	GP_1_18_DATA___7 = 42,
	GP_1_19_DATA___7 = 43,
	GP_1_20_DATA___7 = 44,
	GP_1_21_DATA___7 = 45,
	GP_1_22_DATA___7 = 46,
	GP_1_23_DATA___6 = 47,
	GP_1_24_DATA___6 = 48,
	GP_1_25_DATA___6 = 49,
	GP_1_26_DATA___6 = 50,
	GP_1_27_DATA___6 = 51,
	GP_2_0_DATA___7 = 52,
	GP_2_1_DATA___7 = 53,
	GP_2_2_DATA___7 = 54,
	GP_2_3_DATA___7 = 55,
	GP_2_4_DATA___7 = 56,
	GP_2_5_DATA___7 = 57,
	GP_2_6_DATA___7 = 58,
	GP_2_7_DATA___7 = 59,
	GP_2_8_DATA___7 = 60,
	GP_2_9_DATA___7 = 61,
	GP_2_10_DATA___7 = 62,
	GP_2_11_DATA___7 = 63,
	GP_2_12_DATA___7 = 64,
	GP_2_13_DATA___7 = 65,
	GP_2_14_DATA___7 = 66,
	GP_2_15_DATA___3 = 67,
	GP_2_16_DATA___3 = 68,
	GP_2_17_DATA___2 = 69,
	GP_2_18_DATA___2 = 70,
	GP_2_19_DATA___2 = 71,
	GP_2_20_DATA___2 = 72,
	GP_2_21_DATA___2 = 73,
	GP_2_22_DATA___2 = 74,
	GP_2_23_DATA___2 = 75,
	GP_2_24_DATA___2 = 76,
	GP_2_25_DATA___2 = 77,
	GP_2_26_DATA = 78,
	GP_2_27_DATA = 79,
	GP_2_28_DATA = 80,
	GP_2_29_DATA = 81,
	GP_3_0_DATA___7 = 82,
	GP_3_1_DATA___7 = 83,
	GP_3_2_DATA___7 = 84,
	GP_3_3_DATA___7 = 85,
	GP_3_4_DATA___7 = 86,
	GP_3_5_DATA___7 = 87,
	GP_3_6_DATA___7 = 88,
	GP_3_7_DATA___7 = 89,
	GP_3_8_DATA___7 = 90,
	GP_3_9_DATA___7 = 91,
	GP_3_10_DATA___7 = 92,
	GP_3_11_DATA___7 = 93,
	GP_3_12_DATA___7 = 94,
	GP_3_13_DATA___7 = 95,
	GP_3_14_DATA___7 = 96,
	GP_3_15_DATA___7 = 97,
	GP_3_16_DATA___2 = 98,
	GP_4_0_DATA___7 = 99,
	GP_4_1_DATA___7 = 100,
	GP_4_2_DATA___7 = 101,
	GP_4_3_DATA___7 = 102,
	GP_4_4_DATA___7 = 103,
	GP_4_5_DATA___7 = 104,
	GP_4_6_DATA___6 = 105,
	GP_4_7_DATA___6 = 106,
	GP_4_8_DATA___6 = 107,
	GP_4_9_DATA___6 = 108,
	GP_4_10_DATA___6 = 109,
	GP_4_11_DATA___5 = 110,
	GP_4_12_DATA___5 = 111,
	GP_4_13_DATA___5 = 112,
	GP_4_14_DATA___5 = 113,
	GP_4_15_DATA___5 = 114,
	GP_4_16_DATA___5 = 115,
	GP_4_17_DATA___5 = 116,
	GP_4_18_DATA = 117,
	GP_4_19_DATA = 118,
	GP_4_20_DATA = 119,
	GP_4_21_DATA = 120,
	GP_4_22_DATA = 121,
	GP_4_23_DATA = 122,
	GP_4_24_DATA = 123,
	GP_5_0_DATA___7 = 124,
	GP_5_1_DATA___7 = 125,
	GP_5_2_DATA___7 = 126,
	GP_5_3_DATA___7 = 127,
	GP_5_4_DATA___7 = 128,
	GP_5_5_DATA___7 = 129,
	GP_5_6_DATA___7 = 130,
	GP_5_7_DATA___7 = 131,
	GP_5_8_DATA___7 = 132,
	GP_5_9_DATA___7 = 133,
	GP_5_10_DATA___7 = 134,
	GP_5_11_DATA___7 = 135,
	GP_5_12_DATA___7 = 136,
	GP_5_13_DATA___7 = 137,
	GP_5_14_DATA___7 = 138,
	PINMUX_DATA_END___7 = 139,
	PINMUX_FUNCTION_BEGIN___7 = 140,
	GP_0_0_FN___7 = 141,
	GP_0_1_FN___7 = 142,
	GP_0_2_FN___7 = 143,
	GP_0_3_FN___7 = 144,
	GP_0_4_FN___7 = 145,
	GP_0_5_FN___7 = 146,
	GP_0_6_FN___7 = 147,
	GP_0_7_FN___7 = 148,
	GP_0_8_FN___7 = 149,
	GP_0_9_FN___7 = 150,
	GP_0_10_FN___7 = 151,
	GP_0_11_FN___7 = 152,
	GP_0_12_FN___7 = 153,
	GP_0_13_FN___7 = 154,
	GP_0_14_FN___7 = 155,
	GP_0_15_FN___7 = 156,
	GP_0_16_FN___3 = 157,
	GP_0_17_FN___3 = 158,
	GP_0_18_FN___2 = 159,
	GP_0_19_FN___2 = 160,
	GP_0_20_FN___2 = 161,
	GP_0_21_FN___2 = 162,
	GP_1_0_FN___7 = 163,
	GP_1_1_FN___7 = 164,
	GP_1_2_FN___7 = 165,
	GP_1_3_FN___7 = 166,
	GP_1_4_FN___7 = 167,
	GP_1_5_FN___7 = 168,
	GP_1_6_FN___7 = 169,
	GP_1_7_FN___7 = 170,
	GP_1_8_FN___7 = 171,
	GP_1_9_FN___7 = 172,
	GP_1_10_FN___7 = 173,
	GP_1_11_FN___7 = 174,
	GP_1_12_FN___7 = 175,
	GP_1_13_FN___7 = 176,
	GP_1_14_FN___7 = 177,
	GP_1_15_FN___7 = 178,
	GP_1_16_FN___7 = 179,
	GP_1_17_FN___7 = 180,
	GP_1_18_FN___7 = 181,
	GP_1_19_FN___7 = 182,
	GP_1_20_FN___7 = 183,
	GP_1_21_FN___7 = 184,
	GP_1_22_FN___7 = 185,
	GP_1_23_FN___6 = 186,
	GP_1_24_FN___6 = 187,
	GP_1_25_FN___6 = 188,
	GP_1_26_FN___6 = 189,
	GP_1_27_FN___6 = 190,
	GP_2_0_FN___7 = 191,
	GP_2_1_FN___7 = 192,
	GP_2_2_FN___7 = 193,
	GP_2_3_FN___7 = 194,
	GP_2_4_FN___7 = 195,
	GP_2_5_FN___7 = 196,
	GP_2_6_FN___7 = 197,
	GP_2_7_FN___7 = 198,
	GP_2_8_FN___7 = 199,
	GP_2_9_FN___7 = 200,
	GP_2_10_FN___7 = 201,
	GP_2_11_FN___7 = 202,
	GP_2_12_FN___7 = 203,
	GP_2_13_FN___7 = 204,
	GP_2_14_FN___7 = 205,
	GP_2_15_FN___3 = 206,
	GP_2_16_FN___3 = 207,
	GP_2_17_FN___2 = 208,
	GP_2_18_FN___2 = 209,
	GP_2_19_FN___2 = 210,
	GP_2_20_FN___2 = 211,
	GP_2_21_FN___2 = 212,
	GP_2_22_FN___2 = 213,
	GP_2_23_FN___2 = 214,
	GP_2_24_FN___2 = 215,
	GP_2_25_FN___2 = 216,
	GP_2_26_FN = 217,
	GP_2_27_FN = 218,
	GP_2_28_FN = 219,
	GP_2_29_FN = 220,
	GP_3_0_FN___7 = 221,
	GP_3_1_FN___7 = 222,
	GP_3_2_FN___7 = 223,
	GP_3_3_FN___7 = 224,
	GP_3_4_FN___7 = 225,
	GP_3_5_FN___7 = 226,
	GP_3_6_FN___7 = 227,
	GP_3_7_FN___7 = 228,
	GP_3_8_FN___7 = 229,
	GP_3_9_FN___7 = 230,
	GP_3_10_FN___7 = 231,
	GP_3_11_FN___7 = 232,
	GP_3_12_FN___7 = 233,
	GP_3_13_FN___7 = 234,
	GP_3_14_FN___7 = 235,
	GP_3_15_FN___7 = 236,
	GP_3_16_FN___2 = 237,
	GP_4_0_FN___7 = 238,
	GP_4_1_FN___7 = 239,
	GP_4_2_FN___7 = 240,
	GP_4_3_FN___7 = 241,
	GP_4_4_FN___7 = 242,
	GP_4_5_FN___7 = 243,
	GP_4_6_FN___6 = 244,
	GP_4_7_FN___6 = 245,
	GP_4_8_FN___6 = 246,
	GP_4_9_FN___6 = 247,
	GP_4_10_FN___6 = 248,
	GP_4_11_FN___5 = 249,
	GP_4_12_FN___5 = 250,
	GP_4_13_FN___5 = 251,
	GP_4_14_FN___5 = 252,
	GP_4_15_FN___5 = 253,
	GP_4_16_FN___5 = 254,
	GP_4_17_FN___5 = 255,
	GP_4_18_FN = 256,
	GP_4_19_FN = 257,
	GP_4_20_FN = 258,
	GP_4_21_FN = 259,
	GP_4_22_FN = 260,
	GP_4_23_FN = 261,
	GP_4_24_FN = 262,
	GP_5_0_FN___7 = 263,
	GP_5_1_FN___7 = 264,
	GP_5_2_FN___7 = 265,
	GP_5_3_FN___7 = 266,
	GP_5_4_FN___7 = 267,
	GP_5_5_FN___7 = 268,
	GP_5_6_FN___7 = 269,
	GP_5_7_FN___7 = 270,
	GP_5_8_FN___7 = 271,
	GP_5_9_FN___7 = 272,
	GP_5_10_FN___7 = 273,
	GP_5_11_FN___7 = 274,
	GP_5_12_FN___7 = 275,
	GP_5_13_FN___7 = 276,
	GP_5_14_FN___7 = 277,
	FN_GETHER_LINK_A = 278,
	FN_GETHER_PHY_INT_A = 279,
	FN_GETHER_MAGIC = 280,
	FN_GETHER_MDC_A = 281,
	FN_GETHER_MDIO_A = 282,
	FN_GETHER_TXCREFCLK_MEGA = 283,
	FN_AVB_LINK___6 = 284,
	FN_GETHER_TXCREFCLK = 285,
	FN_AVB_PHY_INT___6 = 286,
	FN_GETHER_TD3 = 287,
	FN_AVB_MAGIC___6 = 288,
	FN_GETHER_TD2 = 289,
	FN_AVB_MDC___6 = 290,
	FN_GETHER_TD1 = 291,
	FN_AVB_MDIO___2 = 292,
	FN_GETHER_TD0 = 293,
	FN_RPC_INT_N___3 = 294,
	FN_AVB_TXCREFCLK___2 = 295,
	FN_GETHER_TXC = 296,
	FN_RPC_WP_N___2 = 297,
	FN_AVB_TD3 = 298,
	FN_GETHER_TX_CTL = 299,
	FN_RPC_RESET_N___3 = 300,
	FN_AVB_TD2 = 301,
	FN_GETHER_RD3 = 302,
	FN_QSPI1_SSL___3 = 303,
	FN_AVB_TD1 = 304,
	FN_GETHER_RD2 = 305,
	FN_QSPI1_IO3___3 = 306,
	FN_AVB_TD0 = 307,
	FN_GETHER_RD1 = 308,
	FN_QSPI1_IO2___3 = 309,
	FN_AVB_TXC = 310,
	FN_GETHER_RD0 = 311,
	FN_QSPI1_MISO_IO1___3 = 312,
	FN_AVB_TX_CTL = 313,
	FN_GETHER_RXC = 314,
	FN_QSPI1_MOSI_IO0___3 = 315,
	FN_AVB_RD3___2 = 316,
	FN_GETHER_RX_CTL = 317,
	FN_QSPI1_SPCLK___3 = 318,
	FN_AVB_RD2___2 = 319,
	FN_QSPI0_SSL___3 = 320,
	FN_AVB_RD1___2 = 321,
	FN_QSPI0_IO3___3 = 322,
	FN_AVB_RD0___2 = 323,
	FN_QSPI0_IO2___3 = 324,
	FN_AVB_RXC___2 = 325,
	FN_QSPI0_MISO_IO1___3 = 326,
	FN_AVB_RX_CTL___2 = 327,
	FN_QSPI0_MOSI_IO0___3 = 328,
	FN_QSPI0_SPCLK___3 = 329,
	FN_IP0_3_0___7 = 330,
	FN_DU_DR2___7 = 331,
	FN_SCK4___2 = 332,
	FN_GETHER_RMII_CRS_DV = 333,
	FN_A0___7 = 334,
	FN_IP1_3_0___7 = 335,
	FN_DU_DG4___7 = 336,
	FN_SCL5___2 = 337,
	FN_A8___7 = 338,
	FN_IP2_3_0___7 = 339,
	FN_DU_DB6___7 = 340,
	FN_MSIOF3_RXD___2 = 341,
	FN_A16___7 = 342,
	FN_IP3_3_0___7 = 343,
	FN_VI0_CLKENB___2 = 344,
	FN_MSIOF2_RXD___2 = 345,
	FN_RX3___2 = 346,
	FN_RD_WR_N___7 = 347,
	FN_HCTS3_N___6 = 348,
	FN_IP0_7_4___7 = 349,
	FN_DU_DR3___7 = 350,
	FN_RX4___2 = 351,
	FN_GETHER_RMII_RX_ER = 352,
	FN_A1___7 = 353,
	FN_IP1_7_4___7 = 354,
	FN_DU_DG5___7 = 355,
	FN_SDA5___2 = 356,
	FN_GETHER_MDC_B = 357,
	FN_A9___7 = 358,
	FN_IP2_7_4___7 = 359,
	FN_DU_DB7___7 = 360,
	FN_MSIOF3_TXD___2 = 361,
	FN_A17___7 = 362,
	FN_IP3_7_4___7 = 363,
	FN_VI0_HSYNC_N___2 = 364,
	FN_MSIOF2_TXD___2 = 365,
	FN_TX3___2 = 366,
	FN_HRTS3_N___6 = 367,
	FN_IP0_11_8___7 = 368,
	FN_DU_DR4___7 = 369,
	FN_TX4___2 = 370,
	FN_GETHER_RMII_RXD0 = 371,
	FN_A2___7 = 372,
	FN_IP1_11_8___7 = 373,
	FN_DU_DG6___7 = 374,
	FN_SCIF_CLK_A___7 = 375,
	FN_GETHER_MDIO_B = 376,
	FN_A10___7 = 377,
	FN_IP2_11_8___7 = 378,
	FN_DU_DOTCLKOUT___2 = 379,
	FN_MSIOF3_SS1___2 = 380,
	FN_GETHER_LINK_B = 381,
	FN_A18___7 = 382,
	FN_IP3_11_8___7 = 383,
	FN_VI0_VSYNC_N___2 = 384,
	FN_MSIOF2_SYNC___2 = 385,
	FN_CTS3_N___6 = 386,
	FN_HTX3___2 = 387,
	FN_IP0_15_12___7 = 388,
	FN_DU_DR5___7 = 389,
	FN_CTS4_N___2 = 390,
	FN_GETHER_RMII_RXD1 = 391,
	FN_A3___7 = 392,
	FN_IP1_15_12___7 = 393,
	FN_DU_DG7___7 = 394,
	FN_HRX0_A___2 = 395,
	FN_A11___7 = 396,
	FN_IP2_15_12___7 = 397,
	FN_DU_EXHSYNC_DU_HSYNC___6 = 398,
	FN_MSIOF3_SS2___2 = 399,
	FN_GETHER_PHY_INT_B = 400,
	FN_A19___7 = 401,
	FN_FXR_TXENA_N___2 = 402,
	FN_IP3_15_12___7 = 403,
	FN_VI0_DATA0___2 = 404,
	FN_MSIOF2_SS1___2 = 405,
	FN_RTS3_N___6 = 406,
	FN_HRX3___2 = 407,
	FN_IP0_19_16___7 = 408,
	FN_DU_DR6___7 = 409,
	FN_RTS4_N___2 = 410,
	FN_GETHER_RMII_TXD_EN = 411,
	FN_A4___7 = 412,
	FN_IP1_19_16___7 = 413,
	FN_DU_DB2___7 = 414,
	FN_HSCK0_A___2 = 415,
	FN_A12___7 = 416,
	FN_IRQ1___7 = 417,
	FN_IP2_19_16___7 = 418,
	FN_DU_EXVSYNC_DU_VSYNC___6 = 419,
	FN_MSIOF3_SCK___2 = 420,
	FN_FXR_TXENB_N___2 = 421,
	FN_IP3_19_16___7 = 422,
	FN_VI0_DATA1___2 = 423,
	FN_MSIOF2_SS2___2 = 424,
	FN_SCK1___7 = 425,
	FN_SPEEDIN_A___7 = 426,
	FN_IP0_23_20___7 = 427,
	FN_DU_DR7___7 = 428,
	FN_GETHER_RMII_TXD0 = 429,
	FN_A5___7 = 430,
	FN_IP1_23_20___7 = 431,
	FN_DU_DB3___7 = 432,
	FN_HRTS0_N_A___2 = 433,
	FN_A13___7 = 434,
	FN_IRQ2___7 = 435,
	FN_IP2_23_20___7 = 436,
	FN_DU_EXODDF_DU_ODDF_DISP_CDE___6 = 437,
	FN_MSIOF3_SYNC___2 = 438,
	FN_IP3_23_20___7 = 439,
	FN_VI0_DATA2___2 = 440,
	FN_AVB_AVTP_PPS___6 = 441,
	FN_IP0_27_24___7 = 442,
	FN_DU_DG2___7 = 443,
	FN_GETHER_RMII_TXD1 = 444,
	FN_A6___7 = 445,
	FN_IP1_27_24___7 = 446,
	FN_DU_DB4___7 = 447,
	FN_HCTS0_N_A___2 = 448,
	FN_A14___7 = 449,
	FN_IRQ3___7 = 450,
	FN_IP2_27_24___7 = 451,
	FN_IRQ0___7 = 452,
	FN_IP3_27_24___7 = 453,
	FN_VI0_DATA3___2 = 454,
	FN_HSCK1___2 = 455,
	FN_IP0_31_28___7 = 456,
	FN_DU_DG3___7 = 457,
	FN_CPG_CPCKOUT = 458,
	FN_GETHER_RMII_REFCLK = 459,
	FN_A7___7 = 460,
	FN_PWMFSW0___2 = 461,
	FN_IP1_31_28___7 = 462,
	FN_DU_DB5___7 = 463,
	FN_HTX0_A___2 = 464,
	FN_PWM0_A___3 = 465,
	FN_A15___7 = 466,
	FN_IP2_31_28___7 = 467,
	FN_VI0_CLK___2 = 468,
	FN_MSIOF2_SCK___2 = 469,
	FN_SCK3___6 = 470,
	FN_HSCK3___6 = 471,
	FN_IP3_31_28___7 = 472,
	FN_VI0_DATA4___2 = 473,
	FN_HRTS1_N___2 = 474,
	FN_RX1_A___6 = 475,
	FN_IP4_3_0___7 = 476,
	FN_VI0_DATA5___2 = 477,
	FN_HCTS1_N___2 = 478,
	FN_TX1_A___6 = 479,
	FN_IP5_3_0___7 = 480,
	FN_VI1_CLK___2 = 481,
	FN_MSIOF1_RXD___3 = 482,
	FN_CS0_N___7 = 483,
	FN_IP6_3_0___7 = 484,
	FN_VI1_DATA4___2 = 485,
	FN_CANFD_CLK_B___2 = 486,
	FN_D7___7 = 487,
	FN_MMC_D0___2 = 488,
	FN_IP7_3_0___7 = 489,
	FN_VI1_FIELD___2 = 490,
	FN_SDA4___3 = 491,
	FN_D15___7 = 492,
	FN_MMC_D7___2 = 493,
	FN_IP4_7_4___7 = 494,
	FN_VI0_DATA6___2 = 495,
	FN_HTX1___2 = 496,
	FN_CTS1_N___7 = 497,
	FN_IP5_7_4___7 = 498,
	FN_VI1_CLKENB___2 = 499,
	FN_MSIOF1_TXD___3 = 500,
	FN_D0___7 = 501,
	FN_IP6_7_4___7 = 502,
	FN_VI1_DATA5___2 = 503,
	FN_D8___7 = 504,
	FN_MMC_D1___2 = 505,
	FN_IP7_7_4___7 = 506,
	FN_SCL0___2 = 507,
	FN_CLKOUT___6 = 508,
	FN_IP4_11_8___7 = 509,
	FN_VI0_DATA7___2 = 510,
	FN_HRX1___2 = 511,
	FN_RTS1_N___7 = 512,
	FN_IP5_11_8___7 = 513,
	FN_VI1_HSYNC_N___2 = 514,
	FN_MSIOF1_SCK___3 = 515,
	FN_D1___7 = 516,
	FN_IP6_11_8___7 = 517,
	FN_VI1_DATA6___2 = 518,
	FN_D9___7 = 519,
	FN_MMC_D2___2 = 520,
	FN_IP7_11_8___7 = 521,
	FN_SDA0___2 = 522,
	FN_BS_N___7 = 523,
	FN_SCK0___6 = 524,
	FN_HSCK0_B___2 = 525,
	FN_IP4_15_12___7 = 526,
	FN_VI0_DATA8___2 = 527,
	FN_HSCK2___2 = 528,
	FN_IP5_15_12___7 = 529,
	FN_VI1_VSYNC_N___2 = 530,
	FN_MSIOF1_SYNC___3 = 531,
	FN_D2___7 = 532,
	FN_IP6_15_12___7 = 533,
	FN_VI1_DATA7___2 = 534,
	FN_D10___7 = 535,
	FN_MMC_D3___2 = 536,
	FN_IP7_15_12___4 = 537,
	FN_SCL1___2 = 538,
	FN_TPU0TO2___7 = 539,
	FN_RD_N___7 = 540,
	FN_CTS0_N___6 = 541,
	FN_HCTS0_N_B = 542,
	FN_IP4_19_16___7 = 543,
	FN_VI0_DATA9___2 = 544,
	FN_HCTS2_N___2 = 545,
	FN_PWM1_A___7 = 546,
	FN_IP5_19_16___7 = 547,
	FN_VI1_DATA0___2 = 548,
	FN_MSIOF1_SS1___3 = 549,
	FN_D3___7 = 550,
	FN_MMC_WP = 551,
	FN_IP6_19_16___7 = 552,
	FN_VI1_DATA8___2 = 553,
	FN_D11___7 = 554,
	FN_MMC_CLK___2 = 555,
	FN_IP7_19_16___7 = 556,
	FN_SDA1___2 = 557,
	FN_TPU0TO3___7 = 558,
	FN_WE0_N___7 = 559,
	FN_RTS0_N___6 = 560,
	FN_HRTS0_N_B = 561,
	FN_IP4_23_20___7 = 562,
	FN_VI0_DATA10___2 = 563,
	FN_HRTS2_N___2 = 564,
	FN_PWM2_A___7 = 565,
	FN_IP5_23_20___7 = 566,
	FN_VI1_DATA1___2 = 567,
	FN_MSIOF1_SS2___3 = 568,
	FN_D4___7 = 569,
	FN_MMC_CD = 570,
	FN_IP6_23_20___7 = 571,
	FN_VI1_DATA9___2 = 572,
	FN_TCLK1_A___7 = 573,
	FN_D12___7 = 574,
	FN_MMC_D4___2 = 575,
	FN_IP7_23_20___7 = 576,
	FN_SCL2___2 = 577,
	FN_WE1_N___7 = 578,
	FN_RX0___6 = 579,
	FN_HRX0_B___2 = 580,
	FN_IP4_27_24___7 = 581,
	FN_VI0_DATA11___2 = 582,
	FN_HTX2___2 = 583,
	FN_PWM3_A___7 = 584,
	FN_IP5_27_24___7 = 585,
	FN_VI1_DATA2___2 = 586,
	FN_CANFD0_TX_B___6 = 587,
	FN_D5___7 = 588,
	FN_MMC_DS = 589,
	FN_IP6_27_24___7 = 590,
	FN_VI1_DATA10___2 = 591,
	FN_TCLK2_A___7 = 592,
	FN_D13___7 = 593,
	FN_MMC_D5___2 = 594,
	FN_IP7_27_24___7 = 595,
	FN_SDA2___2 = 596,
	FN_EX_WAIT0___3 = 597,
	FN_TX0___6 = 598,
	FN_HTX0_B___2 = 599,
	FN_IP4_31_28___7 = 600,
	FN_VI0_FIELD___2 = 601,
	FN_HRX2___2 = 602,
	FN_PWM4_A___7 = 603,
	FN_CS1_N___5 = 604,
	FN_IP5_31_28___7 = 605,
	FN_VI1_DATA3___2 = 606,
	FN_CANFD0_RX_B___6 = 607,
	FN_D6___7 = 608,
	FN_MMC_CMD___2 = 609,
	FN_IP6_31_28___7 = 610,
	FN_VI1_DATA11___2 = 611,
	FN_SCL4___3 = 612,
	FN_D14___7 = 613,
	FN_MMC_D6___2 = 614,
	FN_IP7_31_28___7 = 615,
	FN_AVB_AVTP_MATCH___2 = 616,
	FN_TPU0TO0___7 = 617,
	FN_IP8_3_0___7 = 618,
	FN_AVB_AVTP_CAPTURE___2 = 619,
	FN_TPU0TO1___7 = 620,
	FN_IP9_3_0___6 = 621,
	FN_IRQ4___7 = 622,
	FN_VI0_DATA12 = 623,
	FN_IP10_3_0___6 = 624,
	FN_SCL3 = 625,
	FN_VI0_DATA20 = 626,
	FN_IP8_7_4___7 = 627,
	FN_CANFD0_TX_A___6 = 628,
	FN_FXR_TXDA___2 = 629,
	FN_PWM0_B___3 = 630,
	FN_DU_DISP___7 = 631,
	FN_IP9_7_4___6 = 632,
	FN_IRQ5___7 = 633,
	FN_VI0_DATA13 = 634,
	FN_IP10_7_4___6 = 635,
	FN_SDA3 = 636,
	FN_VI0_DATA21 = 637,
	FN_IP8_11_8___7 = 638,
	FN_CANFD0_RX_A___6 = 639,
	FN_RXDA_EXTFXR___2 = 640,
	FN_PWM1_B___7 = 641,
	FN_DU_CDE___7 = 642,
	FN_IP9_11_8___6 = 643,
	FN_MSIOF0_RXD___7 = 644,
	FN_DU_DR0___7 = 645,
	FN_VI0_DATA14 = 646,
	FN_IP10_11_8___6 = 647,
	FN_FSO_CFE_0_N___4 = 648,
	FN_VI0_DATA22 = 649,
	FN_IP8_15_12___7 = 650,
	FN_CANFD1_TX___7 = 651,
	FN_FXR_TXDB___2 = 652,
	FN_PWM2_B___7 = 653,
	FN_TCLK1_B___7 = 654,
	FN_TX1_B___6 = 655,
	FN_IP9_15_12___6 = 656,
	FN_MSIOF0_TXD___7 = 657,
	FN_DU_DR1___7 = 658,
	FN_VI0_DATA15 = 659,
	FN_IP10_15_12___6 = 660,
	FN_FSO_CFE_1_N___4 = 661,
	FN_VI0_DATA23 = 662,
	FN_IP8_19_16___7 = 663,
	FN_CANFD1_RX___7 = 664,
	FN_RXDB_EXTFXR___2 = 665,
	FN_PWM3_B___7 = 666,
	FN_TCLK2_B___7 = 667,
	FN_RX1_B___6 = 668,
	FN_IP9_19_16___6 = 669,
	FN_MSIOF0_SCK___7 = 670,
	FN_DU_DG0___7 = 671,
	FN_VI0_DATA16 = 672,
	FN_IP10_19_16___6 = 673,
	FN_FSO_TOE_N___4 = 674,
	FN_IP8_23_20___7 = 675,
	FN_CANFD_CLK_A___2 = 676,
	FN_CLK_EXTFXR___2 = 677,
	FN_PWM4_B___7 = 678,
	FN_SPEEDIN_B___7 = 679,
	FN_SCIF_CLK_B___7 = 680,
	FN_IP9_23_20___6 = 681,
	FN_MSIOF0_SYNC___7 = 682,
	FN_DU_DG1___7 = 683,
	FN_VI0_DATA17 = 684,
	FN_IP10_23_20___6 = 685,
	FN_IP8_27_24___7 = 686,
	FN_DIGRF_CLKIN___2 = 687,
	FN_DIGRF_CLKEN_IN___2 = 688,
	FN_IP9_27_24___6 = 689,
	FN_MSIOF0_SS1___7 = 690,
	FN_DU_DB0___7 = 691,
	FN_TCLK3 = 692,
	FN_VI0_DATA18 = 693,
	FN_IP10_27_24___6 = 694,
	FN_IP8_31_28___7 = 695,
	FN_DIGRF_CLKOUT___2 = 696,
	FN_DIGRF_CLKEN_OUT___2 = 697,
	FN_IP9_31_28___6 = 698,
	FN_MSIOF0_SS2___7 = 699,
	FN_DU_DB1___7 = 700,
	FN_TCLK4 = 701,
	FN_VI0_DATA19 = 702,
	FN_IP10_31_28___6 = 703,
	FN_SEL_CANFD0_0___6 = 704,
	FN_SEL_CANFD0_1___6 = 705,
	FN_SEL_GETHER_0 = 706,
	FN_SEL_GETHER_1 = 707,
	FN_SEL_HSCIF0_0___3 = 708,
	FN_SEL_HSCIF0_1___3 = 709,
	FN_SEL_PWM0_0___3 = 710,
	FN_SEL_PWM0_1___3 = 711,
	FN_SEL_PWM1_0___7 = 712,
	FN_SEL_PWM1_1___7 = 713,
	FN_SEL_PWM2_0___7 = 714,
	FN_SEL_PWM2_1___7 = 715,
	FN_SEL_PWM3_0___7 = 716,
	FN_SEL_PWM3_1___7 = 717,
	FN_SEL_PWM4_0___7 = 718,
	FN_SEL_PWM4_1___7 = 719,
	FN_SEL_RSP_0___2 = 720,
	FN_SEL_RSP_1___2 = 721,
	FN_SEL_SCIF1_0___6 = 722,
	FN_SEL_SCIF1_1___6 = 723,
	FN_SEL_TMU_0___2 = 724,
	FN_SEL_TMU_1___2 = 725,
	PINMUX_FUNCTION_END___7 = 726,
	PINMUX_MARK_BEGIN___7 = 727,
	GETHER_LINK_A_MARK = 728,
	GETHER_PHY_INT_A_MARK = 729,
	GETHER_MAGIC_MARK = 730,
	GETHER_MDC_A_MARK = 731,
	GETHER_MDIO_A_MARK = 732,
	GETHER_TXCREFCLK_MEGA_MARK = 733,
	AVB_LINK_MARK___6 = 734,
	GETHER_TXCREFCLK_MARK = 735,
	AVB_PHY_INT_MARK___6 = 736,
	GETHER_TD3_MARK = 737,
	AVB_MAGIC_MARK___6 = 738,
	GETHER_TD2_MARK = 739,
	AVB_MDC_MARK___6 = 740,
	GETHER_TD1_MARK = 741,
	AVB_MDIO_MARK___6 = 742,
	GETHER_TD0_MARK = 743,
	RPC_INT_N_MARK___3 = 744,
	AVB_TXCREFCLK_MARK___6 = 745,
	GETHER_TXC_MARK = 746,
	RPC_WP_N_MARK___2 = 747,
	AVB_TD3_MARK___6 = 748,
	GETHER_TX_CTL_MARK = 749,
	RPC_RESET_N_MARK___3 = 750,
	AVB_TD2_MARK___6 = 751,
	GETHER_RD3_MARK = 752,
	QSPI1_SSL_MARK___7 = 753,
	AVB_TD1_MARK___6 = 754,
	GETHER_RD2_MARK = 755,
	QSPI1_IO3_MARK___7 = 756,
	AVB_TD0_MARK___6 = 757,
	GETHER_RD1_MARK = 758,
	QSPI1_IO2_MARK___7 = 759,
	AVB_TXC_MARK___6 = 760,
	GETHER_RD0_MARK = 761,
	QSPI1_MISO_IO1_MARK___7 = 762,
	AVB_TX_CTL_MARK___6 = 763,
	GETHER_RXC_MARK = 764,
	QSPI1_MOSI_IO0_MARK___7 = 765,
	AVB_RD3_MARK___6 = 766,
	GETHER_RX_CTL_MARK = 767,
	QSPI1_SPCLK_MARK___7 = 768,
	AVB_RD2_MARK___6 = 769,
	QSPI0_SSL_MARK___7 = 770,
	AVB_RD1_MARK___6 = 771,
	QSPI0_IO3_MARK___7 = 772,
	AVB_RD0_MARK___6 = 773,
	QSPI0_IO2_MARK___7 = 774,
	AVB_RXC_MARK___6 = 775,
	QSPI0_MISO_IO1_MARK___7 = 776,
	AVB_RX_CTL_MARK___6 = 777,
	QSPI0_MOSI_IO0_MARK___7 = 778,
	QSPI0_SPCLK_MARK___7 = 779,
	IP0_3_0_MARK___7 = 780,
	DU_DR2_MARK___7 = 781,
	SCK4_MARK___2 = 782,
	GETHER_RMII_CRS_DV_MARK = 783,
	A0_MARK___7 = 784,
	IP1_3_0_MARK___7 = 785,
	DU_DG4_MARK___7 = 786,
	SCL5_MARK___6 = 787,
	A8_MARK___7 = 788,
	IP2_3_0_MARK___7 = 789,
	DU_DB6_MARK___7 = 790,
	MSIOF3_RXD_MARK___2 = 791,
	A16_MARK___7 = 792,
	IP3_3_0_MARK___7 = 793,
	VI0_CLKENB_MARK___2 = 794,
	MSIOF2_RXD_MARK___2 = 795,
	RX3_MARK___2 = 796,
	RD_WR_N_MARK___7 = 797,
	HCTS3_N_MARK___6 = 798,
	IP0_7_4_MARK___7 = 799,
	DU_DR3_MARK___7 = 800,
	RX4_MARK___2 = 801,
	GETHER_RMII_RX_ER_MARK = 802,
	A1_MARK___7 = 803,
	IP1_7_4_MARK___7 = 804,
	DU_DG5_MARK___7 = 805,
	SDA5_MARK___6 = 806,
	GETHER_MDC_B_MARK = 807,
	A9_MARK___7 = 808,
	IP2_7_4_MARK___7 = 809,
	DU_DB7_MARK___7 = 810,
	MSIOF3_TXD_MARK___2 = 811,
	A17_MARK___7 = 812,
	IP3_7_4_MARK___7 = 813,
	VI0_HSYNC_N_MARK___2 = 814,
	MSIOF2_TXD_MARK___2 = 815,
	TX3_MARK___2 = 816,
	HRTS3_N_MARK___6 = 817,
	IP0_11_8_MARK___7 = 818,
	DU_DR4_MARK___7 = 819,
	TX4_MARK___2 = 820,
	GETHER_RMII_RXD0_MARK = 821,
	A2_MARK___7 = 822,
	IP1_11_8_MARK___7 = 823,
	DU_DG6_MARK___7 = 824,
	SCIF_CLK_A_MARK___7 = 825,
	GETHER_MDIO_B_MARK = 826,
	A10_MARK___7 = 827,
	IP2_11_8_MARK___7 = 828,
	DU_DOTCLKOUT_MARK___2 = 829,
	MSIOF3_SS1_MARK___2 = 830,
	GETHER_LINK_B_MARK = 831,
	A18_MARK___7 = 832,
	IP3_11_8_MARK___7 = 833,
	VI0_VSYNC_N_MARK___2 = 834,
	MSIOF2_SYNC_MARK___2 = 835,
	CTS3_N_MARK___6 = 836,
	HTX3_MARK___2 = 837,
	IP0_15_12_MARK___7 = 838,
	DU_DR5_MARK___7 = 839,
	CTS4_N_MARK___2 = 840,
	GETHER_RMII_RXD1_MARK = 841,
	A3_MARK___7 = 842,
	IP1_15_12_MARK___7 = 843,
	DU_DG7_MARK___7 = 844,
	HRX0_A_MARK___2 = 845,
	A11_MARK___7 = 846,
	IP2_15_12_MARK___7 = 847,
	DU_EXHSYNC_DU_HSYNC_MARK___6 = 848,
	MSIOF3_SS2_MARK___2 = 849,
	GETHER_PHY_INT_B_MARK = 850,
	A19_MARK___7 = 851,
	FXR_TXENA_N_MARK___2 = 852,
	IP3_15_12_MARK___7 = 853,
	VI0_DATA0_MARK___2 = 854,
	MSIOF2_SS1_MARK___2 = 855,
	RTS3_N_MARK___6 = 856,
	HRX3_MARK___2 = 857,
	IP0_19_16_MARK___7 = 858,
	DU_DR6_MARK___7 = 859,
	RTS4_N_MARK___2 = 860,
	GETHER_RMII_TXD_EN_MARK = 861,
	A4_MARK___7 = 862,
	IP1_19_16_MARK___7 = 863,
	DU_DB2_MARK___7 = 864,
	HSCK0_A_MARK___2 = 865,
	A12_MARK___7 = 866,
	IRQ1_MARK___7 = 867,
	IP2_19_16_MARK___7 = 868,
	DU_EXVSYNC_DU_VSYNC_MARK___6 = 869,
	MSIOF3_SCK_MARK___2 = 870,
	FXR_TXENB_N_MARK___2 = 871,
	IP3_19_16_MARK___7 = 872,
	VI0_DATA1_MARK___2 = 873,
	MSIOF2_SS2_MARK___2 = 874,
	SCK1_MARK___7 = 875,
	SPEEDIN_A_MARK___7 = 876,
	IP0_23_20_MARK___7 = 877,
	DU_DR7_MARK___7 = 878,
	GETHER_RMII_TXD0_MARK = 879,
	A5_MARK___7 = 880,
	IP1_23_20_MARK___7 = 881,
	DU_DB3_MARK___7 = 882,
	HRTS0_N_A_MARK___2 = 883,
	A13_MARK___7 = 884,
	IRQ2_MARK___7 = 885,
	IP2_23_20_MARK___7 = 886,
	DU_EXODDF_DU_ODDF_DISP_CDE_MARK___6 = 887,
	MSIOF3_SYNC_MARK___2 = 888,
	IP3_23_20_MARK___7 = 889,
	VI0_DATA2_MARK___2 = 890,
	AVB_AVTP_PPS_MARK___6 = 891,
	IP0_27_24_MARK___7 = 892,
	DU_DG2_MARK___7 = 893,
	GETHER_RMII_TXD1_MARK = 894,
	A6_MARK___7 = 895,
	IP1_27_24_MARK___7 = 896,
	DU_DB4_MARK___7 = 897,
	HCTS0_N_A_MARK___2 = 898,
	A14_MARK___7 = 899,
	IRQ3_MARK___7 = 900,
	IP2_27_24_MARK___7 = 901,
	IRQ0_MARK___7 = 902,
	IP3_27_24_MARK___7 = 903,
	VI0_DATA3_MARK___2 = 904,
	HSCK1_MARK___2 = 905,
	IP0_31_28_MARK___7 = 906,
	DU_DG3_MARK___7 = 907,
	CPG_CPCKOUT_MARK = 908,
	GETHER_RMII_REFCLK_MARK = 909,
	A7_MARK___7 = 910,
	PWMFSW0_MARK___2 = 911,
	IP1_31_28_MARK___7 = 912,
	DU_DB5_MARK___7 = 913,
	HTX0_A_MARK___2 = 914,
	PWM0_A_MARK___3 = 915,
	A15_MARK___7 = 916,
	IP2_31_28_MARK___7 = 917,
	VI0_CLK_MARK___2 = 918,
	MSIOF2_SCK_MARK___2 = 919,
	SCK3_MARK___6 = 920,
	HSCK3_MARK___6 = 921,
	IP3_31_28_MARK___7 = 922,
	VI0_DATA4_MARK___2 = 923,
	HRTS1_N_MARK___2 = 924,
	RX1_A_MARK___6 = 925,
	IP4_3_0_MARK___7 = 926,
	VI0_DATA5_MARK___2 = 927,
	HCTS1_N_MARK___2 = 928,
	TX1_A_MARK___6 = 929,
	IP5_3_0_MARK___7 = 930,
	VI1_CLK_MARK___2 = 931,
	MSIOF1_RXD_MARK___3 = 932,
	CS0_N_MARK___7 = 933,
	IP6_3_0_MARK___7 = 934,
	VI1_DATA4_MARK___2 = 935,
	CANFD_CLK_B_MARK___2 = 936,
	D7_MARK___7 = 937,
	MMC_D0_MARK___2 = 938,
	IP7_3_0_MARK___7 = 939,
	VI1_FIELD_MARK___2 = 940,
	SDA4_MARK___3 = 941,
	D15_MARK___7 = 942,
	MMC_D7_MARK___2 = 943,
	IP4_7_4_MARK___7 = 944,
	VI0_DATA6_MARK___2 = 945,
	HTX1_MARK___2 = 946,
	CTS1_N_MARK___7 = 947,
	IP5_7_4_MARK___7 = 948,
	VI1_CLKENB_MARK___2 = 949,
	MSIOF1_TXD_MARK___3 = 950,
	D0_MARK___7 = 951,
	IP6_7_4_MARK___7 = 952,
	VI1_DATA5_MARK___2 = 953,
	D8_MARK___7 = 954,
	MMC_D1_MARK___2 = 955,
	IP7_7_4_MARK___7 = 956,
	SCL0_MARK___6 = 957,
	CLKOUT_MARK___7 = 958,
	IP4_11_8_MARK___7 = 959,
	VI0_DATA7_MARK___2 = 960,
	HRX1_MARK___2 = 961,
	RTS1_N_MARK___7 = 962,
	IP5_11_8_MARK___7 = 963,
	VI1_HSYNC_N_MARK___2 = 964,
	MSIOF1_SCK_MARK___3 = 965,
	D1_MARK___7 = 966,
	IP6_11_8_MARK___7 = 967,
	VI1_DATA6_MARK___2 = 968,
	D9_MARK___7 = 969,
	MMC_D2_MARK___2 = 970,
	IP7_11_8_MARK___7 = 971,
	SDA0_MARK___6 = 972,
	BS_N_MARK___7 = 973,
	SCK0_MARK___6 = 974,
	HSCK0_B_MARK___2 = 975,
	IP4_15_12_MARK___7 = 976,
	VI0_DATA8_MARK___2 = 977,
	HSCK2_MARK___2 = 978,
	IP5_15_12_MARK___7 = 979,
	VI1_VSYNC_N_MARK___2 = 980,
	MSIOF1_SYNC_MARK___3 = 981,
	D2_MARK___7 = 982,
	IP6_15_12_MARK___7 = 983,
	VI1_DATA7_MARK___2 = 984,
	D10_MARK___7 = 985,
	MMC_D3_MARK___2 = 986,
	IP7_15_12_MARK___4 = 987,
	SCL1_MARK___2 = 988,
	TPU0TO2_MARK___7 = 989,
	RD_N_MARK___7 = 990,
	CTS0_N_MARK___6 = 991,
	HCTS0_N_B_MARK = 992,
	IP4_19_16_MARK___7 = 993,
	VI0_DATA9_MARK___2 = 994,
	HCTS2_N_MARK___2 = 995,
	PWM1_A_MARK___7 = 996,
	IP5_19_16_MARK___7 = 997,
	VI1_DATA0_MARK___2 = 998,
	MSIOF1_SS1_MARK___3 = 999,
	D3_MARK___7 = 1000,
	MMC_WP_MARK = 1001,
	IP6_19_16_MARK___7 = 1002,
	VI1_DATA8_MARK___2 = 1003,
	D11_MARK___7 = 1004,
	MMC_CLK_MARK___2 = 1005,
	IP7_19_16_MARK___7 = 1006,
	SDA1_MARK___2 = 1007,
	TPU0TO3_MARK___7 = 1008,
	WE0_N_MARK___7 = 1009,
	RTS0_N_MARK___6 = 1010,
	HRTS0_N_B_MARK = 1011,
	IP4_23_20_MARK___7 = 1012,
	VI0_DATA10_MARK___2 = 1013,
	HRTS2_N_MARK___2 = 1014,
	PWM2_A_MARK___7 = 1015,
	IP5_23_20_MARK___7 = 1016,
	VI1_DATA1_MARK___2 = 1017,
	MSIOF1_SS2_MARK___3 = 1018,
	D4_MARK___7 = 1019,
	MMC_CD_MARK = 1020,
	IP6_23_20_MARK___7 = 1021,
	VI1_DATA9_MARK___2 = 1022,
	TCLK1_A_MARK___7 = 1023,
	D12_MARK___7 = 1024,
	MMC_D4_MARK___2 = 1025,
	IP7_23_20_MARK___7 = 1026,
	SCL2_MARK___2 = 1027,
	WE1_N_MARK___7 = 1028,
	RX0_MARK___6 = 1029,
	HRX0_B_MARK___2 = 1030,
	IP4_27_24_MARK___7 = 1031,
	VI0_DATA11_MARK___2 = 1032,
	HTX2_MARK___2 = 1033,
	PWM3_A_MARK___7 = 1034,
	IP5_27_24_MARK___7 = 1035,
	VI1_DATA2_MARK___2 = 1036,
	CANFD0_TX_B_MARK___6 = 1037,
	D5_MARK___7 = 1038,
	MMC_DS_MARK = 1039,
	IP6_27_24_MARK___7 = 1040,
	VI1_DATA10_MARK___2 = 1041,
	TCLK2_A_MARK___7 = 1042,
	D13_MARK___7 = 1043,
	MMC_D5_MARK___2 = 1044,
	IP7_27_24_MARK___7 = 1045,
	SDA2_MARK___2 = 1046,
	EX_WAIT0_MARK___3 = 1047,
	TX0_MARK___6 = 1048,
	HTX0_B_MARK___2 = 1049,
	IP4_31_28_MARK___7 = 1050,
	VI0_FIELD_MARK___2 = 1051,
	HRX2_MARK___2 = 1052,
	PWM4_A_MARK___7 = 1053,
	CS1_N_MARK___5 = 1054,
	IP5_31_28_MARK___7 = 1055,
	VI1_DATA3_MARK___2 = 1056,
	CANFD0_RX_B_MARK___6 = 1057,
	D6_MARK___7 = 1058,
	MMC_CMD_MARK___2 = 1059,
	IP6_31_28_MARK___7 = 1060,
	VI1_DATA11_MARK___2 = 1061,
	SCL4_MARK___3 = 1062,
	D14_MARK___7 = 1063,
	MMC_D6_MARK___2 = 1064,
	IP7_31_28_MARK___7 = 1065,
	AVB_AVTP_MATCH_MARK___2 = 1066,
	TPU0TO0_MARK___7 = 1067,
	IP8_3_0_MARK___7 = 1068,
	AVB_AVTP_CAPTURE_MARK___2 = 1069,
	TPU0TO1_MARK___7 = 1070,
	IP9_3_0_MARK___6 = 1071,
	IRQ4_MARK___7 = 1072,
	VI0_DATA12_MARK = 1073,
	IP10_3_0_MARK___6 = 1074,
	SCL3_MARK___5 = 1075,
	VI0_DATA20_MARK = 1076,
	IP8_7_4_MARK___7 = 1077,
	CANFD0_TX_A_MARK___6 = 1078,
	FXR_TXDA_MARK___2 = 1079,
	PWM0_B_MARK___3 = 1080,
	DU_DISP_MARK___7 = 1081,
	IP9_7_4_MARK___6 = 1082,
	IRQ5_MARK___7 = 1083,
	VI0_DATA13_MARK = 1084,
	IP10_7_4_MARK___6 = 1085,
	SDA3_MARK___5 = 1086,
	VI0_DATA21_MARK = 1087,
	IP8_11_8_MARK___7 = 1088,
	CANFD0_RX_A_MARK___6 = 1089,
	RXDA_EXTFXR_MARK___2 = 1090,
	PWM1_B_MARK___7 = 1091,
	DU_CDE_MARK___7 = 1092,
	IP9_11_8_MARK___6 = 1093,
	MSIOF0_RXD_MARK___7 = 1094,
	DU_DR0_MARK___7 = 1095,
	VI0_DATA14_MARK = 1096,
	IP10_11_8_MARK___6 = 1097,
	FSO_CFE_0_N_MARK___4 = 1098,
	VI0_DATA22_MARK = 1099,
	IP8_15_12_MARK___7 = 1100,
	CANFD1_TX_MARK___7 = 1101,
	FXR_TXDB_MARK___2 = 1102,
	PWM2_B_MARK___7 = 1103,
	TCLK1_B_MARK___7 = 1104,
	TX1_B_MARK___6 = 1105,
	IP9_15_12_MARK___6 = 1106,
	MSIOF0_TXD_MARK___7 = 1107,
	DU_DR1_MARK___7 = 1108,
	VI0_DATA15_MARK = 1109,
	IP10_15_12_MARK___6 = 1110,
	FSO_CFE_1_N_MARK___4 = 1111,
	VI0_DATA23_MARK = 1112,
	IP8_19_16_MARK___7 = 1113,
	CANFD1_RX_MARK___7 = 1114,
	RXDB_EXTFXR_MARK___2 = 1115,
	PWM3_B_MARK___7 = 1116,
	TCLK2_B_MARK___7 = 1117,
	RX1_B_MARK___6 = 1118,
	IP9_19_16_MARK___6 = 1119,
	MSIOF0_SCK_MARK___7 = 1120,
	DU_DG0_MARK___7 = 1121,
	VI0_DATA16_MARK = 1122,
	IP10_19_16_MARK___6 = 1123,
	FSO_TOE_N_MARK___4 = 1124,
	IP8_23_20_MARK___7 = 1125,
	CANFD_CLK_A_MARK___2 = 1126,
	CLK_EXTFXR_MARK___2 = 1127,
	PWM4_B_MARK___7 = 1128,
	SPEEDIN_B_MARK___7 = 1129,
	SCIF_CLK_B_MARK___7 = 1130,
	IP9_23_20_MARK___6 = 1131,
	MSIOF0_SYNC_MARK___7 = 1132,
	DU_DG1_MARK___7 = 1133,
	VI0_DATA17_MARK = 1134,
	IP10_23_20_MARK___6 = 1135,
	IP8_27_24_MARK___7 = 1136,
	DIGRF_CLKIN_MARK___2 = 1137,
	DIGRF_CLKEN_IN_MARK___2 = 1138,
	IP9_27_24_MARK___6 = 1139,
	MSIOF0_SS1_MARK___7 = 1140,
	DU_DB0_MARK___7 = 1141,
	TCLK3_MARK = 1142,
	VI0_DATA18_MARK = 1143,
	IP10_27_24_MARK___6 = 1144,
	IP8_31_28_MARK___7 = 1145,
	DIGRF_CLKOUT_MARK___2 = 1146,
	DIGRF_CLKEN_OUT_MARK___2 = 1147,
	IP9_31_28_MARK___6 = 1148,
	MSIOF0_SS2_MARK___7 = 1149,
	DU_DB1_MARK___7 = 1150,
	TCLK4_MARK = 1151,
	VI0_DATA19_MARK = 1152,
	IP10_31_28_MARK___6 = 1153,
	SEL_CANFD0_0_MARK___6 = 1154,
	SEL_CANFD0_1_MARK___6 = 1155,
	SEL_GETHER_0_MARK = 1156,
	SEL_GETHER_1_MARK = 1157,
	SEL_HSCIF0_0_MARK___3 = 1158,
	SEL_HSCIF0_1_MARK___3 = 1159,
	SEL_PWM0_0_MARK___3 = 1160,
	SEL_PWM0_1_MARK___3 = 1161,
	SEL_PWM1_0_MARK___7 = 1162,
	SEL_PWM1_1_MARK___7 = 1163,
	SEL_PWM2_0_MARK___7 = 1164,
	SEL_PWM2_1_MARK___7 = 1165,
	SEL_PWM3_0_MARK___7 = 1166,
	SEL_PWM3_1_MARK___7 = 1167,
	SEL_PWM4_0_MARK___7 = 1168,
	SEL_PWM4_1_MARK___7 = 1169,
	SEL_RSP_0_MARK___2 = 1170,
	SEL_RSP_1_MARK___2 = 1171,
	SEL_SCIF1_0_MARK___6 = 1172,
	SEL_SCIF1_1_MARK___6 = 1173,
	SEL_TMU_0_MARK___2 = 1174,
	SEL_TMU_1_MARK___2 = 1175,
	PINMUX_MARK_END___7 = 1176,
};

enum {
	GP_LAST___7 = 174,
	PIN_DCUTCK_LPDCLK = 175,
	PIN_DCUTDI_LPDI = 176,
	PIN_DCUTMS = 177,
	PIN_DCUTRST_N = 178,
	PIN_DU_DOTCLKIN___2 = 179,
	PIN_EXTALR___6 = 180,
	PIN_FSCLKST___3 = 181,
	PIN_FSCLKST_N___5 = 182,
	PIN_PRESETOUT_N___7 = 183,
};

enum ioctrl_regs___4 {
	POCCTRL0___3 = 0,
	POCCTRL1___2 = 1,
	POCCTRL2___2 = 2,
	POCCTRL3 = 3,
	TDSELCTRL___4 = 4,
};

enum {
	PINMUX_RESERVED___8 = 0,
	PINMUX_DATA_BEGIN___8 = 1,
	GP_0_0_DATA___8 = 2,
	GP_0_1_DATA___8 = 3,
	GP_0_2_DATA___8 = 4,
	GP_0_3_DATA___8 = 5,
	GP_0_4_DATA___8 = 6,
	GP_0_5_DATA___8 = 7,
	GP_0_6_DATA___8 = 8,
	GP_0_7_DATA___8 = 9,
	GP_0_8_DATA___8 = 10,
	GP_1_0_DATA___8 = 11,
	GP_1_1_DATA___8 = 12,
	GP_1_2_DATA___8 = 13,
	GP_1_3_DATA___8 = 14,
	GP_1_4_DATA___8 = 15,
	GP_1_5_DATA___8 = 16,
	GP_1_6_DATA___8 = 17,
	GP_1_7_DATA___8 = 18,
	GP_1_8_DATA___8 = 19,
	GP_1_9_DATA___8 = 20,
	GP_1_10_DATA___8 = 21,
	GP_1_11_DATA___8 = 22,
	GP_1_12_DATA___8 = 23,
	GP_1_13_DATA___8 = 24,
	GP_1_14_DATA___8 = 25,
	GP_1_15_DATA___8 = 26,
	GP_1_16_DATA___8 = 27,
	GP_1_17_DATA___8 = 28,
	GP_1_18_DATA___8 = 29,
	GP_1_19_DATA___8 = 30,
	GP_1_20_DATA___8 = 31,
	GP_1_21_DATA___8 = 32,
	GP_1_22_DATA___8 = 33,
	GP_1_23_DATA___7 = 34,
	GP_1_24_DATA___7 = 35,
	GP_1_25_DATA___7 = 36,
	GP_1_26_DATA___7 = 37,
	GP_1_27_DATA___7 = 38,
	GP_1_28_DATA___4 = 39,
	GP_1_29_DATA = 40,
	GP_1_30_DATA = 41,
	GP_1_31_DATA = 42,
	GP_2_0_DATA___8 = 43,
	GP_2_1_DATA___8 = 44,
	GP_2_2_DATA___8 = 45,
	GP_2_3_DATA___8 = 46,
	GP_2_4_DATA___8 = 47,
	GP_2_5_DATA___8 = 48,
	GP_2_6_DATA___8 = 49,
	GP_2_7_DATA___8 = 50,
	GP_2_8_DATA___8 = 51,
	GP_2_9_DATA___8 = 52,
	GP_2_10_DATA___8 = 53,
	GP_2_11_DATA___8 = 54,
	GP_2_12_DATA___8 = 55,
	GP_2_13_DATA___8 = 56,
	GP_2_14_DATA___8 = 57,
	GP_2_15_DATA___4 = 58,
	GP_2_16_DATA___4 = 59,
	GP_2_17_DATA___3 = 60,
	GP_2_18_DATA___3 = 61,
	GP_2_19_DATA___3 = 62,
	GP_2_20_DATA___3 = 63,
	GP_2_21_DATA___3 = 64,
	GP_2_22_DATA___3 = 65,
	GP_2_23_DATA___3 = 66,
	GP_2_24_DATA___3 = 67,
	GP_2_25_DATA___3 = 68,
	GP_2_26_DATA___2 = 69,
	GP_2_27_DATA___2 = 70,
	GP_2_28_DATA___2 = 71,
	GP_2_29_DATA___2 = 72,
	GP_2_30_DATA = 73,
	GP_2_31_DATA = 74,
	GP_3_0_DATA___8 = 75,
	GP_3_1_DATA___8 = 76,
	GP_3_2_DATA___8 = 77,
	GP_3_3_DATA___8 = 78,
	GP_3_4_DATA___8 = 79,
	GP_3_5_DATA___8 = 80,
	GP_3_6_DATA___8 = 81,
	GP_3_7_DATA___8 = 82,
	GP_3_8_DATA___8 = 83,
	GP_3_9_DATA___8 = 84,
	GP_4_0_DATA___8 = 85,
	GP_4_1_DATA___8 = 86,
	GP_4_2_DATA___8 = 87,
	GP_4_3_DATA___8 = 88,
	GP_4_4_DATA___8 = 89,
	GP_4_5_DATA___8 = 90,
	GP_4_6_DATA___7 = 91,
	GP_4_7_DATA___7 = 92,
	GP_4_8_DATA___7 = 93,
	GP_4_9_DATA___7 = 94,
	GP_4_10_DATA___7 = 95,
	GP_4_11_DATA___6 = 96,
	GP_4_12_DATA___6 = 97,
	GP_4_13_DATA___6 = 98,
	GP_4_14_DATA___6 = 99,
	GP_4_15_DATA___6 = 100,
	GP_4_16_DATA___6 = 101,
	GP_4_17_DATA___6 = 102,
	GP_4_18_DATA___2 = 103,
	GP_4_19_DATA___2 = 104,
	GP_4_20_DATA___2 = 105,
	GP_4_21_DATA___2 = 106,
	GP_4_22_DATA___2 = 107,
	GP_4_23_DATA___2 = 108,
	GP_4_24_DATA___2 = 109,
	GP_4_25_DATA = 110,
	GP_4_26_DATA = 111,
	GP_4_27_DATA = 112,
	GP_4_28_DATA = 113,
	GP_4_29_DATA = 114,
	GP_4_30_DATA = 115,
	GP_4_31_DATA = 116,
	GP_5_0_DATA___8 = 117,
	GP_5_1_DATA___8 = 118,
	GP_5_2_DATA___8 = 119,
	GP_5_3_DATA___8 = 120,
	GP_5_4_DATA___8 = 121,
	GP_5_5_DATA___8 = 122,
	GP_5_6_DATA___8 = 123,
	GP_5_7_DATA___8 = 124,
	GP_5_8_DATA___8 = 125,
	GP_5_9_DATA___8 = 126,
	GP_5_10_DATA___8 = 127,
	GP_5_11_DATA___8 = 128,
	GP_5_12_DATA___8 = 129,
	GP_5_13_DATA___8 = 130,
	GP_5_14_DATA___8 = 131,
	GP_5_15_DATA___6 = 132,
	GP_5_16_DATA___6 = 133,
	GP_5_17_DATA___6 = 134,
	GP_5_18_DATA___6 = 135,
	GP_5_19_DATA___6 = 136,
	GP_5_20_DATA___5 = 137,
	GP_6_0_DATA___6 = 138,
	GP_6_1_DATA___6 = 139,
	GP_6_2_DATA___6 = 140,
	GP_6_3_DATA___6 = 141,
	GP_6_4_DATA___6 = 142,
	GP_6_5_DATA___6 = 143,
	GP_6_6_DATA___6 = 144,
	GP_6_7_DATA___6 = 145,
	GP_6_8_DATA___6 = 146,
	GP_6_9_DATA___6 = 147,
	GP_6_10_DATA___6 = 148,
	GP_6_11_DATA___6 = 149,
	GP_6_12_DATA___6 = 150,
	GP_6_13_DATA___6 = 151,
	PINMUX_DATA_END___8 = 152,
	PINMUX_FUNCTION_BEGIN___8 = 153,
	GP_0_0_FN___8 = 154,
	GP_0_1_FN___8 = 155,
	GP_0_2_FN___8 = 156,
	GP_0_3_FN___8 = 157,
	GP_0_4_FN___8 = 158,
	GP_0_5_FN___8 = 159,
	GP_0_6_FN___8 = 160,
	GP_0_7_FN___8 = 161,
	GP_0_8_FN___8 = 162,
	GP_1_0_FN___8 = 163,
	GP_1_1_FN___8 = 164,
	GP_1_2_FN___8 = 165,
	GP_1_3_FN___8 = 166,
	GP_1_4_FN___8 = 167,
	GP_1_5_FN___8 = 168,
	GP_1_6_FN___8 = 169,
	GP_1_7_FN___8 = 170,
	GP_1_8_FN___8 = 171,
	GP_1_9_FN___8 = 172,
	GP_1_10_FN___8 = 173,
	GP_1_11_FN___8 = 174,
	GP_1_12_FN___8 = 175,
	GP_1_13_FN___8 = 176,
	GP_1_14_FN___8 = 177,
	GP_1_15_FN___8 = 178,
	GP_1_16_FN___8 = 179,
	GP_1_17_FN___8 = 180,
	GP_1_18_FN___8 = 181,
	GP_1_19_FN___8 = 182,
	GP_1_20_FN___8 = 183,
	GP_1_21_FN___8 = 184,
	GP_1_22_FN___8 = 185,
	GP_1_23_FN___7 = 186,
	GP_1_24_FN___7 = 187,
	GP_1_25_FN___7 = 188,
	GP_1_26_FN___7 = 189,
	GP_1_27_FN___7 = 190,
	GP_1_28_FN___4 = 191,
	GP_1_29_FN = 192,
	GP_1_30_FN = 193,
	GP_1_31_FN = 194,
	GP_2_0_FN___8 = 195,
	GP_2_1_FN___8 = 196,
	GP_2_2_FN___8 = 197,
	GP_2_3_FN___8 = 198,
	GP_2_4_FN___8 = 199,
	GP_2_5_FN___8 = 200,
	GP_2_6_FN___8 = 201,
	GP_2_7_FN___8 = 202,
	GP_2_8_FN___8 = 203,
	GP_2_9_FN___8 = 204,
	GP_2_10_FN___8 = 205,
	GP_2_11_FN___8 = 206,
	GP_2_12_FN___8 = 207,
	GP_2_13_FN___8 = 208,
	GP_2_14_FN___8 = 209,
	GP_2_15_FN___4 = 210,
	GP_2_16_FN___4 = 211,
	GP_2_17_FN___3 = 212,
	GP_2_18_FN___3 = 213,
	GP_2_19_FN___3 = 214,
	GP_2_20_FN___3 = 215,
	GP_2_21_FN___3 = 216,
	GP_2_22_FN___3 = 217,
	GP_2_23_FN___3 = 218,
	GP_2_24_FN___3 = 219,
	GP_2_25_FN___3 = 220,
	GP_2_26_FN___2 = 221,
	GP_2_27_FN___2 = 222,
	GP_2_28_FN___2 = 223,
	GP_2_29_FN___2 = 224,
	GP_2_30_FN = 225,
	GP_2_31_FN = 226,
	GP_3_0_FN___8 = 227,
	GP_3_1_FN___8 = 228,
	GP_3_2_FN___8 = 229,
	GP_3_3_FN___8 = 230,
	GP_3_4_FN___8 = 231,
	GP_3_5_FN___8 = 232,
	GP_3_6_FN___8 = 233,
	GP_3_7_FN___8 = 234,
	GP_3_8_FN___8 = 235,
	GP_3_9_FN___8 = 236,
	GP_4_0_FN___8 = 237,
	GP_4_1_FN___8 = 238,
	GP_4_2_FN___8 = 239,
	GP_4_3_FN___8 = 240,
	GP_4_4_FN___8 = 241,
	GP_4_5_FN___8 = 242,
	GP_4_6_FN___7 = 243,
	GP_4_7_FN___7 = 244,
	GP_4_8_FN___7 = 245,
	GP_4_9_FN___7 = 246,
	GP_4_10_FN___7 = 247,
	GP_4_11_FN___6 = 248,
	GP_4_12_FN___6 = 249,
	GP_4_13_FN___6 = 250,
	GP_4_14_FN___6 = 251,
	GP_4_15_FN___6 = 252,
	GP_4_16_FN___6 = 253,
	GP_4_17_FN___6 = 254,
	GP_4_18_FN___2 = 255,
	GP_4_19_FN___2 = 256,
	GP_4_20_FN___2 = 257,
	GP_4_21_FN___2 = 258,
	GP_4_22_FN___2 = 259,
	GP_4_23_FN___2 = 260,
	GP_4_24_FN___2 = 261,
	GP_4_25_FN = 262,
	GP_4_26_FN = 263,
	GP_4_27_FN = 264,
	GP_4_28_FN = 265,
	GP_4_29_FN = 266,
	GP_4_30_FN = 267,
	GP_4_31_FN = 268,
	GP_5_0_FN___8 = 269,
	GP_5_1_FN___8 = 270,
	GP_5_2_FN___8 = 271,
	GP_5_3_FN___8 = 272,
	GP_5_4_FN___8 = 273,
	GP_5_5_FN___8 = 274,
	GP_5_6_FN___8 = 275,
	GP_5_7_FN___8 = 276,
	GP_5_8_FN___8 = 277,
	GP_5_9_FN___8 = 278,
	GP_5_10_FN___8 = 279,
	GP_5_11_FN___8 = 280,
	GP_5_12_FN___8 = 281,
	GP_5_13_FN___8 = 282,
	GP_5_14_FN___8 = 283,
	GP_5_15_FN___6 = 284,
	GP_5_16_FN___6 = 285,
	GP_5_17_FN___6 = 286,
	GP_5_18_FN___6 = 287,
	GP_5_19_FN___6 = 288,
	GP_5_20_FN___5 = 289,
	GP_6_0_FN___6 = 290,
	GP_6_1_FN___6 = 291,
	GP_6_2_FN___6 = 292,
	GP_6_3_FN___6 = 293,
	GP_6_4_FN___6 = 294,
	GP_6_5_FN___6 = 295,
	GP_6_6_FN___6 = 296,
	GP_6_7_FN___6 = 297,
	GP_6_8_FN___6 = 298,
	GP_6_9_FN___6 = 299,
	GP_6_10_FN___6 = 300,
	GP_6_11_FN___6 = 301,
	GP_6_12_FN___6 = 302,
	GP_6_13_FN___6 = 303,
	FN_TX2 = 304,
	FN_RX2 = 305,
	FN_AVB0_LINK___2 = 306,
	FN_AVB0_PHY_INT___2 = 307,
	FN_AVB0_MAGIC___2 = 308,
	FN_AVB0_MDC___2 = 309,
	FN_AVB0_MDIO___2 = 310,
	FN_MSIOF0_RXD___8 = 311,
	FN_AVB0_TXCREFCLK___2 = 312,
	FN_MSIOF0_TXD___8 = 313,
	FN_AVB0_TD3___2 = 314,
	FN_MSIOF0_SYNC___8 = 315,
	FN_AVB0_TD2___2 = 316,
	FN_RPC_INT_N___4 = 317,
	FN_MSIOF0_SCK___8 = 318,
	FN_AVB0_TD1___2 = 319,
	FN_RPC_RESET_N___4 = 320,
	FN_AVB0_TD0___2 = 321,
	FN_QSPI1_SSL___4 = 322,
	FN_AVB0_TXC___2 = 323,
	FN_QSPI1_IO3___4 = 324,
	FN_SDA0___3 = 325,
	FN_AVB0_TX_CTL___2 = 326,
	FN_QSPI1_IO2___4 = 327,
	FN_SCL0___3 = 328,
	FN_AVB0_RD3___2 = 329,
	FN_QSPI1_MISO_IO1___4 = 330,
	FN_AVB0_RD2___2 = 331,
	FN_QSPI1_MOSI_IO0___4 = 332,
	FN_AVB0_RD1___2 = 333,
	FN_QSPI1_SPCLK___4 = 334,
	FN_VI4_DATA4 = 335,
	FN_AVB0_RD0___2 = 336,
	FN_QSPI0_SSL___4 = 337,
	FN_AVB0_RXC___2 = 338,
	FN_QSPI0_IO3___4 = 339,
	FN_AVB0_RX_CTL___2 = 340,
	FN_QSPI0_IO2___4 = 341,
	FN_QSPI0_MISO_IO1___4 = 342,
	FN_USB0_OVC___5 = 343,
	FN_QSPI0_MOSI_IO0___4 = 344,
	FN_USB0_PWEN___5 = 345,
	FN_VI4_CLK___6 = 346,
	FN_QSPI0_SPCLK___4 = 347,
	FN_IP0_3_0___8 = 348,
	FN_IRQ0_A = 349,
	FN_MSIOF2_SYNC_B___6 = 350,
	FN_IP1_3_0___8 = 351,
	FN_DU_DB1___8 = 352,
	FN_LCDOUT1___6 = 353,
	FN_MSIOF3_RXD_B___6 = 354,
	FN_IP2_3_0___8 = 355,
	FN_DU_DG1___8 = 356,
	FN_LCDOUT9___6 = 357,
	FN_MSIOF3_SYNC_B___6 = 358,
	FN_IP3_3_0___8 = 359,
	FN_DU_DR1___8 = 360,
	FN_LCDOUT17___6 = 361,
	FN_TX4_B___6 = 362,
	FN_IP0_7_4___8 = 363,
	FN_MSIOF2_SCK___3 = 364,
	FN_IP1_7_4___8 = 365,
	FN_DU_DB2___8 = 366,
	FN_LCDOUT2___6 = 367,
	FN_IRQ0_B = 368,
	FN_IP2_7_4___8 = 369,
	FN_DU_DG2___8 = 370,
	FN_LCDOUT10___6 = 371,
	FN_IP3_7_4___8 = 372,
	FN_DU_DR2___8 = 373,
	FN_LCDOUT18___6 = 374,
	FN_PWM0_B___4 = 375,
	FN_IP0_11_8___8 = 376,
	FN_MSIOF2_TXD___3 = 377,
	FN_SCL3_A___2 = 378,
	FN_IP1_11_8___8 = 379,
	FN_DU_DB3___8 = 380,
	FN_LCDOUT3___6 = 381,
	FN_SCK5_B___4 = 382,
	FN_IP2_11_8___8 = 383,
	FN_DU_DG3___8 = 384,
	FN_LCDOUT11___6 = 385,
	FN_IRQ1_A = 386,
	FN_IP3_11_8___8 = 387,
	FN_DU_DR3___8 = 388,
	FN_LCDOUT19___6 = 389,
	FN_PWM1_B___8 = 390,
	FN_IP0_15_12___8 = 391,
	FN_MSIOF2_RXD___3 = 392,
	FN_SDA3_A___2 = 393,
	FN_IP1_15_12___8 = 394,
	FN_DU_DB4___8 = 395,
	FN_LCDOUT4___6 = 396,
	FN_RX5_B___5 = 397,
	FN_IP2_15_12___8 = 398,
	FN_DU_DG4___8 = 399,
	FN_LCDOUT12___6 = 400,
	FN_HSCK3_B___2 = 401,
	FN_IP3_15_12___8 = 402,
	FN_DU_DR4___8 = 403,
	FN_LCDOUT20___6 = 404,
	FN_TCLK2_B___8 = 405,
	FN_IP0_19_16___8 = 406,
	FN_MLB_CLK___6 = 407,
	FN_MSIOF2_SYNC_A___6 = 408,
	FN_SCK5_A___5 = 409,
	FN_IP1_19_16___8 = 410,
	FN_DU_DB5___8 = 411,
	FN_LCDOUT5___6 = 412,
	FN_TX5_B___5 = 413,
	FN_IP2_19_16___8 = 414,
	FN_DU_DG5___8 = 415,
	FN_LCDOUT13___6 = 416,
	FN_HTX3_B___6 = 417,
	FN_IP3_19_16___8 = 418,
	FN_DU_DR5___8 = 419,
	FN_LCDOUT21___6 = 420,
	FN_NMI = 421,
	FN_IP0_23_20___8 = 422,
	FN_MLB_DAT___6 = 423,
	FN_MSIOF2_SS1___3 = 424,
	FN_RX5_A___5 = 425,
	FN_SCL3_B___2 = 426,
	FN_IP1_23_20___8 = 427,
	FN_DU_DB6___8 = 428,
	FN_LCDOUT6___6 = 429,
	FN_MSIOF3_SS1_B___6 = 430,
	FN_IP2_23_20___8 = 431,
	FN_DU_DG6___8 = 432,
	FN_LCDOUT14___6 = 433,
	FN_HRX3_B___6 = 434,
	FN_IP3_23_20___8 = 435,
	FN_DU_DR6___8 = 436,
	FN_LCDOUT22___6 = 437,
	FN_PWM2_B___8 = 438,
	FN_IP0_27_24___8 = 439,
	FN_MLB_SIG___6 = 440,
	FN_MSIOF2_SS2___3 = 441,
	FN_TX5_A___5 = 442,
	FN_SDA3_B___2 = 443,
	FN_IP1_27_24___8 = 444,
	FN_DU_DB7___8 = 445,
	FN_LCDOUT7___6 = 446,
	FN_MSIOF3_SS2_B___5 = 447,
	FN_IP2_27_24___8 = 448,
	FN_DU_DG7___8 = 449,
	FN_LCDOUT15___6 = 450,
	FN_SCK4_B___6 = 451,
	FN_IP3_27_24___8 = 452,
	FN_DU_DR7___8 = 453,
	FN_LCDOUT23___6 = 454,
	FN_TCLK1_B___8 = 455,
	FN_IP0_31_28___8 = 456,
	FN_DU_DB0___8 = 457,
	FN_LCDOUT0___6 = 458,
	FN_MSIOF3_TXD_B___6 = 459,
	FN_IP1_31_28___8 = 460,
	FN_DU_DG0___8 = 461,
	FN_LCDOUT8___6 = 462,
	FN_MSIOF3_SCK_B___6 = 463,
	FN_IP2_31_28___8 = 464,
	FN_DU_DR0___8 = 465,
	FN_LCDOUT16___6 = 466,
	FN_RX4_B___6 = 467,
	FN_IP3_31_28___8 = 468,
	FN_DU_DOTCLKOUT0___6 = 469,
	FN_QCLK___6 = 470,
	FN_IP4_3_0___8 = 471,
	FN_DU_HSYNC___2 = 472,
	FN_QSTH_QHS___6 = 473,
	FN_IRQ3_A = 474,
	FN_IP5_3_0___8 = 475,
	FN_VI4_DATA1 = 476,
	FN_PWM1_A___8 = 477,
	FN_IP6_3_0___8 = 478,
	FN_VI4_DATA10___6 = 479,
	FN_RX4_A___6 = 480,
	FN_IP7_3_0___8 = 481,
	FN_VI4_DATA18___6 = 482,
	FN_HSCK3_A = 483,
	FN_IP4_7_4___8 = 484,
	FN_DU_VSYNC___2 = 485,
	FN_QSTVA_QVS___6 = 486,
	FN_IRQ4_A = 487,
	FN_IP5_7_4___8 = 488,
	FN_VI4_DATA2 = 489,
	FN_PWM2_A___8 = 490,
	FN_IP6_7_4___8 = 491,
	FN_VI4_DATA11___6 = 492,
	FN_TX4_A___6 = 493,
	FN_IP7_7_4___8 = 494,
	FN_VI4_DATA19___6 = 495,
	FN_SSI_WS4_B = 496,
	FN_NFDATA15 = 497,
	FN_IP4_11_8___8 = 498,
	FN_DU_DISP___8 = 499,
	FN_QSTVB_QVE___6 = 500,
	FN_PWM3_B___8 = 501,
	FN_IP5_11_8___8 = 502,
	FN_VI4_DATA3 = 503,
	FN_PWM3_A___8 = 504,
	FN_IP6_11_8___8 = 505,
	FN_VI4_DATA12___6 = 506,
	FN_TCLK1_A___8 = 507,
	FN_IP7_11_8___8 = 508,
	FN_VI4_DATA20___6 = 509,
	FN_MSIOF3_SYNC_A___6 = 510,
	FN_NFDATA14 = 511,
	FN_IP4_15_12___8 = 512,
	FN_DU_DISP_CDE___2 = 513,
	FN_QCPV_QDE___6 = 514,
	FN_IRQ2_B = 515,
	FN_DU_DOTCLKIN1___2 = 516,
	FN_IP5_15_12___8 = 517,
	FN_VI4_DATA5 = 518,
	FN_SCK4_A___6 = 519,
	FN_IP6_15_12___8 = 520,
	FN_VI4_DATA13___6 = 521,
	FN_MSIOF3_SS1_A___6 = 522,
	FN_HCTS3_N___7 = 523,
	FN_IP7_15_12___5 = 524,
	FN_VI4_DATA21___6 = 525,
	FN_MSIOF3_TXD_A___6 = 526,
	FN_NFDATA13___5 = 527,
	FN_IP4_19_16___8 = 528,
	FN_DU_CDE___8 = 529,
	FN_QSTB_QHE___6 = 530,
	FN_SCK3_B = 531,
	FN_IP5_19_16___8 = 532,
	FN_VI4_DATA6 = 533,
	FN_IRQ2_A = 534,
	FN_IP6_19_16___8 = 535,
	FN_VI4_DATA14___6 = 536,
	FN_SSI_SCK4_B = 537,
	FN_HRTS3_N___7 = 538,
	FN_IP7_19_16___8 = 539,
	FN_VI4_DATA22___6 = 540,
	FN_MSIOF3_RXD_A___6 = 541,
	FN_NFDATA12___5 = 542,
	FN_IP4_23_20___8 = 543,
	FN_QPOLA___6 = 544,
	FN_RX3_B___6 = 545,
	FN_IP5_23_20___8 = 546,
	FN_VI4_DATA7 = 547,
	FN_TCLK2_A___8 = 548,
	FN_IP6_23_20___8 = 549,
	FN_VI4_DATA15___6 = 550,
	FN_SSI_SDATA4_B = 551,
	FN_IP7_23_20___8 = 552,
	FN_VI4_DATA23___6 = 553,
	FN_MSIOF3_SCK_A___6 = 554,
	FN_NFDATA11___5 = 555,
	FN_IP4_27_24___8 = 556,
	FN_QPOLB___6 = 557,
	FN_TX3_B___6 = 558,
	FN_IP5_27_24___8 = 559,
	FN_VI4_DATA8___6 = 560,
	FN_IP6_27_24___8 = 561,
	FN_VI4_DATA16___6 = 562,
	FN_HRX3_A___6 = 563,
	FN_IP7_27_24___8 = 564,
	FN_VI4_VSYNC_N___6 = 565,
	FN_SCK1_B = 566,
	FN_NFDATA10___5 = 567,
	FN_IP4_31_28___8 = 568,
	FN_VI4_DATA0 = 569,
	FN_PWM0_A___4 = 570,
	FN_IP5_31_28___8 = 571,
	FN_VI4_DATA9___6 = 572,
	FN_MSIOF3_SS2_A___6 = 573,
	FN_IRQ1_B = 574,
	FN_IP6_31_28___8 = 575,
	FN_VI4_DATA17___6 = 576,
	FN_HTX3_A___6 = 577,
	FN_IP7_31_28___8 = 578,
	FN_VI4_HSYNC_N___6 = 579,
	FN_RX1_B___7 = 580,
	FN_NFDATA9___5 = 581,
	FN_IP8_3_0___8 = 582,
	FN_VI4_FIELD___6 = 583,
	FN_AUDIO_CLKB = 584,
	FN_IRQ5_A = 585,
	FN_SCIF_CLK = 586,
	FN_NFDATA8___5 = 587,
	FN_IP9_3_0___7 = 588,
	FN_NFDATA0___5 = 589,
	FN_MMC_D0___3 = 590,
	FN_IP10_3_0___7 = 591,
	FN_AUDIO_CLKA___2 = 592,
	FN_DVC_MUTE_B = 593,
	FN_IP11_3_0___6 = 594,
	FN_SDA1___3 = 595,
	FN_RTS1_N___8 = 596,
	FN_IP8_7_4___8 = 597,
	FN_VI4_CLKENB___6 = 598,
	FN_TX1_B___7 = 599,
	FN_NFWP_N = 600,
	FN_DVC_MUTE_A = 601,
	FN_IP9_7_4___7 = 602,
	FN_NFDATA1___5 = 603,
	FN_MMC_D1___3 = 604,
	FN_IP10_7_4___7 = 605,
	FN_SSI_SCK34 = 606,
	FN_FSO_CFE_0_N_A___3 = 607,
	FN_IP11_7_4___6 = 608,
	FN_MSIOF1_SCK___4 = 609,
	FN_AVB0_AVTP_PPS_B = 610,
	FN_IP8_11_8___8 = 611,
	FN_NFALE___4 = 612,
	FN_SCL2_B___6 = 613,
	FN_IRQ3_B = 614,
	FN_PWM0_C = 615,
	FN_IP9_11_8___7 = 616,
	FN_NFDATA2___5 = 617,
	FN_MMC_D2___3 = 618,
	FN_IP10_11_8___7 = 619,
	FN_SSI_SDATA3___6 = 620,
	FN_FSO_CFE_1_N_A___3 = 621,
	FN_IP11_11_8___6 = 622,
	FN_MSIOF1_TXD___4 = 623,
	FN_AVB0_AVTP_CAPTURE_B = 624,
	FN_IP8_15_12___8 = 625,
	FN_NFCLE___5 = 626,
	FN_SDA2_B___6 = 627,
	FN_SCK3_A___2 = 628,
	FN_PWM1_C = 629,
	FN_IP9_15_12___7 = 630,
	FN_NFDATA3___5 = 631,
	FN_MMC_D3___3 = 632,
	FN_IP10_15_12___7 = 633,
	FN_SSI_WS34 = 634,
	FN_FSO_TOE_N_A___3 = 635,
	FN_IP11_15_12___6 = 636,
	FN_MSIOF1_RXD___4 = 637,
	FN_AVB0_AVTP_MATCH_B = 638,
	FN_IP8_19_16___8 = 639,
	FN_NFCE_N = 640,
	FN_RX3_A___6 = 641,
	FN_PWM2_C___2 = 642,
	FN_IP9_19_16___7 = 643,
	FN_NFDATA4___5 = 644,
	FN_MMC_D4___3 = 645,
	FN_IP10_19_16___7 = 646,
	FN_SSI_SCK4_A = 647,
	FN_HSCK0___6 = 648,
	FN_AUDIO_CLKOUT = 649,
	FN_CAN0_RX_B___5 = 650,
	FN_IRQ4_B = 651,
	FN_IP11_19_16___6 = 652,
	FN_SCK0_A___2 = 653,
	FN_MSIOF1_SYNC___4 = 654,
	FN_FSO_CFE_0_N_B___3 = 655,
	FN_IP8_23_20___8 = 656,
	FN_NFRB_N = 657,
	FN_TX3_A___6 = 658,
	FN_PWM3_C___2 = 659,
	FN_IP9_23_20___7 = 660,
	FN_NFDATA5___5 = 661,
	FN_MMC_D5___3 = 662,
	FN_IP10_23_20___7 = 663,
	FN_SSI_SDATA4_A = 664,
	FN_HTX0___6 = 665,
	FN_SCL2_A___6 = 666,
	FN_CAN1_RX_B = 667,
	FN_IP11_23_20___6 = 668,
	FN_RX0_A___2 = 669,
	FN_MSIOF0_SS1___8 = 670,
	FN_FSO_CFE_1_N_B___3 = 671,
	FN_IP8_27_24___8 = 672,
	FN_NFRE_N___5 = 673,
	FN_MMC_CMD___3 = 674,
	FN_IP9_27_24___7 = 675,
	FN_NFDATA6___5 = 676,
	FN_MMC_D6___3 = 677,
	FN_IP10_27_24___7 = 678,
	FN_SSI_WS4_A = 679,
	FN_HRX0___6 = 680,
	FN_SDA2_A___6 = 681,
	FN_CAN1_TX_B = 682,
	FN_IP11_27_24___6 = 683,
	FN_TX0_A___2 = 684,
	FN_MSIOF0_SS2___8 = 685,
	FN_FSO_TOE_N_B___3 = 686,
	FN_IP8_31_28___8 = 687,
	FN_NFWE_N___5 = 688,
	FN_MMC_CLK___3 = 689,
	FN_IP9_31_28___7 = 690,
	FN_NFDATA7___5 = 691,
	FN_MMC_D7___3 = 692,
	FN_IP10_31_28___7 = 693,
	FN_SCL1___3 = 694,
	FN_CTS1_N___8 = 695,
	FN_IP11_31_28___6 = 696,
	FN_SCK1_A = 697,
	FN_MSIOF1_SS2___4 = 698,
	FN_TPU0TO2_B = 699,
	FN_CAN0_TX_B___5 = 700,
	FN_AUDIO_CLKOUT1 = 701,
	FN_IP12_3_0___6 = 702,
	FN_RX1_A___7 = 703,
	FN_CTS0_N___7 = 704,
	FN_TPU0TO0_B = 705,
	FN_IP13_3_0___6 = 706,
	FN_CAN1_RX_A = 707,
	FN_CANFD1_RX___8 = 708,
	FN_TPU0TO2_A = 709,
	FN_IP12_7_4___6 = 710,
	FN_TX1_A___7 = 711,
	FN_RTS0_N___7 = 712,
	FN_TPU0TO1_B = 713,
	FN_IP13_7_4___6 = 714,
	FN_CAN1_TX_A = 715,
	FN_CANFD1_TX___8 = 716,
	FN_TPU0TO3_A = 717,
	FN_IP12_11_8___6 = 718,
	FN_SCK2___5 = 719,
	FN_MSIOF1_SS1___4 = 720,
	FN_TPU0TO3_B = 721,
	FN_IP12_15_12___6 = 722,
	FN_TPU0TO0_A = 723,
	FN_AVB0_AVTP_CAPTURE_A = 724,
	FN_HCTS0_N___6 = 725,
	FN_IP12_19_16___6 = 726,
	FN_TPU0TO1_A = 727,
	FN_AVB0_AVTP_MATCH_A = 728,
	FN_HRTS0_N___6 = 729,
	FN_IP12_23_20___6 = 730,
	FN_CAN_CLK___6 = 731,
	FN_AVB0_AVTP_PPS_A = 732,
	FN_SCK0_B___2 = 733,
	FN_IRQ5_B = 734,
	FN_IP12_27_24___6 = 735,
	FN_CAN0_RX_A___5 = 736,
	FN_CANFD0_RX___2 = 737,
	FN_RX0_B___2 = 738,
	FN_IP12_31_28___6 = 739,
	FN_CAN0_TX_A___5 = 740,
	FN_CANFD0_TX___2 = 741,
	FN_TX0_B___2 = 742,
	FN_SEL_CAN0_0 = 743,
	FN_SEL_CAN0_1 = 744,
	FN_SEL_MSIOF2_0___6 = 745,
	FN_SEL_MSIOF2_1___6 = 746,
	FN_SEL_CAN1_0 = 747,
	FN_SEL_CAN1_1 = 748,
	FN_SEL_I2C3_0___2 = 749,
	FN_SEL_I2C3_1___2 = 750,
	FN_SEL_I2C2_0___6 = 751,
	FN_SEL_I2C2_1___6 = 752,
	FN_SEL_SCIF5_0___5 = 753,
	FN_SEL_SCIF5_1___5 = 754,
	FN_SEL_ETHERAVB_0___5 = 755,
	FN_SEL_ETHERAVB_1___5 = 756,
	FN_SEL_MSIOF3_0___6 = 757,
	FN_SEL_MSIOF3_1___6 = 758,
	FN_SEL_SCIF0_0___2 = 759,
	FN_SEL_SCIF0_1___2 = 760,
	FN_SEL_HSCIF3_0___6 = 761,
	FN_SEL_HSCIF3_1___6 = 762,
	FN_SEL_SSIF4_0 = 763,
	FN_SEL_SSIF4_1 = 764,
	FN_SEL_SCIF4_0___6 = 765,
	FN_SEL_SCIF4_1___6 = 766,
	FN_SEL_PWM0_0___4 = 767,
	FN_SEL_PWM0_2 = 768,
	FN_SEL_PWM0_1___4 = 769,
	FN_SEL_PWM1_0___8 = 770,
	FN_SEL_PWM1_2 = 771,
	FN_SEL_PWM1_1___8 = 772,
	FN_SEL_PWM2_0___8 = 773,
	FN_SEL_PWM2_2___2 = 774,
	FN_SEL_PWM2_1___8 = 775,
	FN_SEL_PWM3_0___8 = 776,
	FN_SEL_PWM3_2___2 = 777,
	FN_SEL_PWM3_1___8 = 778,
	FN_SEL_IRQ_0_0 = 779,
	FN_SEL_IRQ_0_1 = 780,
	FN_SEL_IRQ_1_0 = 781,
	FN_SEL_IRQ_1_1 = 782,
	FN_SEL_IRQ_2_0 = 783,
	FN_SEL_IRQ_2_1 = 784,
	FN_SEL_IRQ_3_0 = 785,
	FN_SEL_IRQ_3_1 = 786,
	FN_SEL_IRQ_4_0 = 787,
	FN_SEL_IRQ_4_1 = 788,
	FN_SEL_IRQ_5_0 = 789,
	FN_SEL_IRQ_5_1 = 790,
	FN_SEL_TMU_0_0 = 791,
	FN_SEL_TMU_0_1 = 792,
	FN_SEL_TMU_1_0 = 793,
	FN_SEL_TMU_1_1 = 794,
	FN_SEL_SCIF3_0___6 = 795,
	FN_SEL_SCIF3_1___6 = 796,
	FN_SEL_SCIF1_0___7 = 797,
	FN_SEL_SCIF1_1___7 = 798,
	FN_SEL_SCU_0 = 799,
	FN_SEL_SCU_1 = 800,
	FN_SEL_RFSO_0___2 = 801,
	FN_SEL_RFSO_1___2 = 802,
	PINMUX_FUNCTION_END___8 = 803,
	PINMUX_MARK_BEGIN___8 = 804,
	TX2_MARK = 805,
	RX2_MARK = 806,
	AVB0_LINK_MARK___2 = 807,
	AVB0_PHY_INT_MARK___2 = 808,
	AVB0_MAGIC_MARK___2 = 809,
	AVB0_MDC_MARK___2 = 810,
	AVB0_MDIO_MARK___2 = 811,
	MSIOF0_RXD_MARK___8 = 812,
	AVB0_TXCREFCLK_MARK___2 = 813,
	MSIOF0_TXD_MARK___8 = 814,
	AVB0_TD3_MARK___2 = 815,
	MSIOF0_SYNC_MARK___8 = 816,
	AVB0_TD2_MARK___2 = 817,
	RPC_INT_N_MARK___4 = 818,
	MSIOF0_SCK_MARK___8 = 819,
	AVB0_TD1_MARK___2 = 820,
	RPC_RESET_N_MARK___4 = 821,
	AVB0_TD0_MARK___2 = 822,
	QSPI1_SSL_MARK___8 = 823,
	AVB0_TXC_MARK___2 = 824,
	QSPI1_IO3_MARK___8 = 825,
	SDA0_MARK___7 = 826,
	AVB0_TX_CTL_MARK___2 = 827,
	QSPI1_IO2_MARK___8 = 828,
	SCL0_MARK___7 = 829,
	AVB0_RD3_MARK___2 = 830,
	QSPI1_MISO_IO1_MARK___8 = 831,
	AVB0_RD2_MARK___2 = 832,
	QSPI1_MOSI_IO0_MARK___8 = 833,
	AVB0_RD1_MARK___2 = 834,
	QSPI1_SPCLK_MARK___8 = 835,
	VI4_DATA4_MARK = 836,
	AVB0_RD0_MARK___2 = 837,
	QSPI0_SSL_MARK___8 = 838,
	AVB0_RXC_MARK___2 = 839,
	QSPI0_IO3_MARK___8 = 840,
	AVB0_RX_CTL_MARK___2 = 841,
	QSPI0_IO2_MARK___8 = 842,
	QSPI0_MISO_IO1_MARK___8 = 843,
	USB0_OVC_MARK___5 = 844,
	QSPI0_MOSI_IO0_MARK___8 = 845,
	USB0_PWEN_MARK___5 = 846,
	VI4_CLK_MARK___6 = 847,
	QSPI0_SPCLK_MARK___8 = 848,
	IP0_3_0_MARK___8 = 849,
	IRQ0_A_MARK = 850,
	MSIOF2_SYNC_B_MARK___6 = 851,
	IP1_3_0_MARK___8 = 852,
	DU_DB1_MARK___8 = 853,
	LCDOUT1_MARK___6 = 854,
	MSIOF3_RXD_B_MARK___6 = 855,
	IP2_3_0_MARK___8 = 856,
	DU_DG1_MARK___8 = 857,
	LCDOUT9_MARK___6 = 858,
	MSIOF3_SYNC_B_MARK___6 = 859,
	IP3_3_0_MARK___8 = 860,
	DU_DR1_MARK___8 = 861,
	LCDOUT17_MARK___6 = 862,
	TX4_B_MARK___6 = 863,
	IP0_7_4_MARK___8 = 864,
	MSIOF2_SCK_MARK___3 = 865,
	IP1_7_4_MARK___8 = 866,
	DU_DB2_MARK___8 = 867,
	LCDOUT2_MARK___6 = 868,
	IRQ0_B_MARK = 869,
	IP2_7_4_MARK___8 = 870,
	DU_DG2_MARK___8 = 871,
	LCDOUT10_MARK___6 = 872,
	IP3_7_4_MARK___8 = 873,
	DU_DR2_MARK___8 = 874,
	LCDOUT18_MARK___6 = 875,
	PWM0_B_MARK___4 = 876,
	IP0_11_8_MARK___8 = 877,
	MSIOF2_TXD_MARK___3 = 878,
	SCL3_A_MARK___2 = 879,
	IP1_11_8_MARK___8 = 880,
	DU_DB3_MARK___8 = 881,
	LCDOUT3_MARK___6 = 882,
	SCK5_B_MARK___4 = 883,
	IP2_11_8_MARK___8 = 884,
	DU_DG3_MARK___8 = 885,
	LCDOUT11_MARK___6 = 886,
	IRQ1_A_MARK = 887,
	IP3_11_8_MARK___8 = 888,
	DU_DR3_MARK___8 = 889,
	LCDOUT19_MARK___6 = 890,
	PWM1_B_MARK___8 = 891,
	IP0_15_12_MARK___8 = 892,
	MSIOF2_RXD_MARK___3 = 893,
	SDA3_A_MARK___2 = 894,
	IP1_15_12_MARK___8 = 895,
	DU_DB4_MARK___8 = 896,
	LCDOUT4_MARK___6 = 897,
	RX5_B_MARK___5 = 898,
	IP2_15_12_MARK___8 = 899,
	DU_DG4_MARK___8 = 900,
	LCDOUT12_MARK___6 = 901,
	HSCK3_B_MARK___2 = 902,
	IP3_15_12_MARK___8 = 903,
	DU_DR4_MARK___8 = 904,
	LCDOUT20_MARK___6 = 905,
	TCLK2_B_MARK___8 = 906,
	IP0_19_16_MARK___8 = 907,
	MLB_CLK_MARK___6 = 908,
	MSIOF2_SYNC_A_MARK___6 = 909,
	SCK5_A_MARK___5 = 910,
	IP1_19_16_MARK___8 = 911,
	DU_DB5_MARK___8 = 912,
	LCDOUT5_MARK___6 = 913,
	TX5_B_MARK___5 = 914,
	IP2_19_16_MARK___8 = 915,
	DU_DG5_MARK___8 = 916,
	LCDOUT13_MARK___6 = 917,
	HTX3_B_MARK___6 = 918,
	IP3_19_16_MARK___8 = 919,
	DU_DR5_MARK___8 = 920,
	LCDOUT21_MARK___6 = 921,
	NMI_MARK = 922,
	IP0_23_20_MARK___8 = 923,
	MLB_DAT_MARK___6 = 924,
	MSIOF2_SS1_MARK___3 = 925,
	RX5_A_MARK___5 = 926,
	SCL3_B_MARK___2 = 927,
	IP1_23_20_MARK___8 = 928,
	DU_DB6_MARK___8 = 929,
	LCDOUT6_MARK___6 = 930,
	MSIOF3_SS1_B_MARK___6 = 931,
	IP2_23_20_MARK___8 = 932,
	DU_DG6_MARK___8 = 933,
	LCDOUT14_MARK___6 = 934,
	HRX3_B_MARK___6 = 935,
	IP3_23_20_MARK___8 = 936,
	DU_DR6_MARK___8 = 937,
	LCDOUT22_MARK___6 = 938,
	PWM2_B_MARK___8 = 939,
	IP0_27_24_MARK___8 = 940,
	MLB_SIG_MARK___6 = 941,
	MSIOF2_SS2_MARK___3 = 942,
	TX5_A_MARK___5 = 943,
	SDA3_B_MARK___2 = 944,
	IP1_27_24_MARK___8 = 945,
	DU_DB7_MARK___8 = 946,
	LCDOUT7_MARK___6 = 947,
	MSIOF3_SS2_B_MARK___5 = 948,
	IP2_27_24_MARK___8 = 949,
	DU_DG7_MARK___8 = 950,
	LCDOUT15_MARK___6 = 951,
	SCK4_B_MARK___6 = 952,
	IP3_27_24_MARK___8 = 953,
	DU_DR7_MARK___8 = 954,
	LCDOUT23_MARK___6 = 955,
	TCLK1_B_MARK___8 = 956,
	IP0_31_28_MARK___8 = 957,
	DU_DB0_MARK___8 = 958,
	LCDOUT0_MARK___6 = 959,
	MSIOF3_TXD_B_MARK___6 = 960,
	IP1_31_28_MARK___8 = 961,
	DU_DG0_MARK___8 = 962,
	LCDOUT8_MARK___6 = 963,
	MSIOF3_SCK_B_MARK___6 = 964,
	IP2_31_28_MARK___8 = 965,
	DU_DR0_MARK___8 = 966,
	LCDOUT16_MARK___6 = 967,
	RX4_B_MARK___6 = 968,
	IP3_31_28_MARK___8 = 969,
	DU_DOTCLKOUT0_MARK___6 = 970,
	QCLK_MARK___6 = 971,
	IP4_3_0_MARK___8 = 972,
	DU_HSYNC_MARK___2 = 973,
	QSTH_QHS_MARK___6 = 974,
	IRQ3_A_MARK = 975,
	IP5_3_0_MARK___8 = 976,
	VI4_DATA1_MARK = 977,
	PWM1_A_MARK___8 = 978,
	IP6_3_0_MARK___8 = 979,
	VI4_DATA10_MARK___6 = 980,
	RX4_A_MARK___6 = 981,
	IP7_3_0_MARK___8 = 982,
	VI4_DATA18_MARK___6 = 983,
	HSCK3_A_MARK = 984,
	IP4_7_4_MARK___8 = 985,
	DU_VSYNC_MARK___2 = 986,
	QSTVA_QVS_MARK___6 = 987,
	IRQ4_A_MARK = 988,
	IP5_7_4_MARK___8 = 989,
	VI4_DATA2_MARK = 990,
	PWM2_A_MARK___8 = 991,
	IP6_7_4_MARK___8 = 992,
	VI4_DATA11_MARK___6 = 993,
	TX4_A_MARK___6 = 994,
	IP7_7_4_MARK___8 = 995,
	VI4_DATA19_MARK___6 = 996,
	SSI_WS4_B_MARK = 997,
	NFDATA15_MARK = 998,
	IP4_11_8_MARK___8 = 999,
	DU_DISP_MARK___8 = 1000,
	QSTVB_QVE_MARK___6 = 1001,
	PWM3_B_MARK___8 = 1002,
	IP5_11_8_MARK___8 = 1003,
	VI4_DATA3_MARK = 1004,
	PWM3_A_MARK___8 = 1005,
	IP6_11_8_MARK___8 = 1006,
	VI4_DATA12_MARK___6 = 1007,
	TCLK1_A_MARK___8 = 1008,
	IP7_11_8_MARK___8 = 1009,
	VI4_DATA20_MARK___6 = 1010,
	MSIOF3_SYNC_A_MARK___6 = 1011,
	NFDATA14_MARK = 1012,
	IP4_15_12_MARK___8 = 1013,
	DU_DISP_CDE_MARK___2 = 1014,
	QCPV_QDE_MARK___6 = 1015,
	IRQ2_B_MARK = 1016,
	DU_DOTCLKIN1_MARK___6 = 1017,
	IP5_15_12_MARK___8 = 1018,
	VI4_DATA5_MARK = 1019,
	SCK4_A_MARK___6 = 1020,
	IP6_15_12_MARK___8 = 1021,
	VI4_DATA13_MARK___6 = 1022,
	MSIOF3_SS1_A_MARK___6 = 1023,
	HCTS3_N_MARK___7 = 1024,
	IP7_15_12_MARK___5 = 1025,
	VI4_DATA21_MARK___6 = 1026,
	MSIOF3_TXD_A_MARK___6 = 1027,
	NFDATA13_MARK___5 = 1028,
	IP4_19_16_MARK___8 = 1029,
	DU_CDE_MARK___8 = 1030,
	QSTB_QHE_MARK___6 = 1031,
	SCK3_B_MARK = 1032,
	IP5_19_16_MARK___8 = 1033,
	VI4_DATA6_MARK = 1034,
	IRQ2_A_MARK = 1035,
	IP6_19_16_MARK___8 = 1036,
	VI4_DATA14_MARK___6 = 1037,
	SSI_SCK4_B_MARK = 1038,
	HRTS3_N_MARK___7 = 1039,
	IP7_19_16_MARK___8 = 1040,
	VI4_DATA22_MARK___6 = 1041,
	MSIOF3_RXD_A_MARK___6 = 1042,
	NFDATA12_MARK___5 = 1043,
	IP4_23_20_MARK___8 = 1044,
	QPOLA_MARK___6 = 1045,
	RX3_B_MARK___6 = 1046,
	IP5_23_20_MARK___8 = 1047,
	VI4_DATA7_MARK = 1048,
	TCLK2_A_MARK___8 = 1049,
	IP6_23_20_MARK___8 = 1050,
	VI4_DATA15_MARK___6 = 1051,
	SSI_SDATA4_B_MARK = 1052,
	IP7_23_20_MARK___8 = 1053,
	VI4_DATA23_MARK___6 = 1054,
	MSIOF3_SCK_A_MARK___6 = 1055,
	NFDATA11_MARK___5 = 1056,
	IP4_27_24_MARK___8 = 1057,
	QPOLB_MARK___6 = 1058,
	TX3_B_MARK___6 = 1059,
	IP5_27_24_MARK___8 = 1060,
	VI4_DATA8_MARK___6 = 1061,
	IP6_27_24_MARK___8 = 1062,
	VI4_DATA16_MARK___6 = 1063,
	HRX3_A_MARK___6 = 1064,
	IP7_27_24_MARK___8 = 1065,
	VI4_VSYNC_N_MARK___6 = 1066,
	SCK1_B_MARK = 1067,
	NFDATA10_MARK___5 = 1068,
	IP4_31_28_MARK___8 = 1069,
	VI4_DATA0_MARK = 1070,
	PWM0_A_MARK___4 = 1071,
	IP5_31_28_MARK___8 = 1072,
	VI4_DATA9_MARK___6 = 1073,
	MSIOF3_SS2_A_MARK___6 = 1074,
	IRQ1_B_MARK = 1075,
	IP6_31_28_MARK___8 = 1076,
	VI4_DATA17_MARK___6 = 1077,
	HTX3_A_MARK___6 = 1078,
	IP7_31_28_MARK___8 = 1079,
	VI4_HSYNC_N_MARK___6 = 1080,
	RX1_B_MARK___7 = 1081,
	NFDATA9_MARK___5 = 1082,
	IP8_3_0_MARK___8 = 1083,
	VI4_FIELD_MARK___6 = 1084,
	AUDIO_CLKB_MARK = 1085,
	IRQ5_A_MARK = 1086,
	SCIF_CLK_MARK = 1087,
	NFDATA8_MARK___5 = 1088,
	IP9_3_0_MARK___7 = 1089,
	NFDATA0_MARK___5 = 1090,
	MMC_D0_MARK___3 = 1091,
	IP10_3_0_MARK___7 = 1092,
	AUDIO_CLKA_MARK___2 = 1093,
	DVC_MUTE_B_MARK = 1094,
	IP11_3_0_MARK___6 = 1095,
	SDA1_MARK___3 = 1096,
	RTS1_N_MARK___8 = 1097,
	IP8_7_4_MARK___8 = 1098,
	VI4_CLKENB_MARK___6 = 1099,
	TX1_B_MARK___7 = 1100,
	NFWP_N_MARK = 1101,
	DVC_MUTE_A_MARK = 1102,
	IP9_7_4_MARK___7 = 1103,
	NFDATA1_MARK___5 = 1104,
	MMC_D1_MARK___3 = 1105,
	IP10_7_4_MARK___7 = 1106,
	SSI_SCK34_MARK = 1107,
	FSO_CFE_0_N_A_MARK___3 = 1108,
	IP11_7_4_MARK___6 = 1109,
	MSIOF1_SCK_MARK___4 = 1110,
	AVB0_AVTP_PPS_B_MARK = 1111,
	IP8_11_8_MARK___8 = 1112,
	NFALE_MARK___4 = 1113,
	SCL2_B_MARK___6 = 1114,
	IRQ3_B_MARK = 1115,
	PWM0_C_MARK = 1116,
	IP9_11_8_MARK___7 = 1117,
	NFDATA2_MARK___5 = 1118,
	MMC_D2_MARK___3 = 1119,
	IP10_11_8_MARK___7 = 1120,
	SSI_SDATA3_MARK___6 = 1121,
	FSO_CFE_1_N_A_MARK___3 = 1122,
	IP11_11_8_MARK___6 = 1123,
	MSIOF1_TXD_MARK___4 = 1124,
	AVB0_AVTP_CAPTURE_B_MARK = 1125,
	IP8_15_12_MARK___8 = 1126,
	NFCLE_MARK___5 = 1127,
	SDA2_B_MARK___6 = 1128,
	SCK3_A_MARK___2 = 1129,
	PWM1_C_MARK = 1130,
	IP9_15_12_MARK___7 = 1131,
	NFDATA3_MARK___5 = 1132,
	MMC_D3_MARK___3 = 1133,
	IP10_15_12_MARK___7 = 1134,
	SSI_WS34_MARK = 1135,
	FSO_TOE_N_A_MARK___3 = 1136,
	IP11_15_12_MARK___6 = 1137,
	MSIOF1_RXD_MARK___4 = 1138,
	AVB0_AVTP_MATCH_B_MARK = 1139,
	IP8_19_16_MARK___8 = 1140,
	NFCE_N_MARK = 1141,
	RX3_A_MARK___6 = 1142,
	PWM2_C_MARK___2 = 1143,
	IP9_19_16_MARK___7 = 1144,
	NFDATA4_MARK___5 = 1145,
	MMC_D4_MARK___3 = 1146,
	IP10_19_16_MARK___7 = 1147,
	SSI_SCK4_A_MARK = 1148,
	HSCK0_MARK___6 = 1149,
	AUDIO_CLKOUT_MARK = 1150,
	CAN0_RX_B_MARK___5 = 1151,
	IRQ4_B_MARK = 1152,
	IP11_19_16_MARK___6 = 1153,
	SCK0_A_MARK___2 = 1154,
	MSIOF1_SYNC_MARK___4 = 1155,
	FSO_CFE_0_N_B_MARK___3 = 1156,
	IP8_23_20_MARK___8 = 1157,
	NFRB_N_MARK = 1158,
	TX3_A_MARK___6 = 1159,
	PWM3_C_MARK___2 = 1160,
	IP9_23_20_MARK___7 = 1161,
	NFDATA5_MARK___5 = 1162,
	MMC_D5_MARK___3 = 1163,
	IP10_23_20_MARK___7 = 1164,
	SSI_SDATA4_A_MARK = 1165,
	HTX0_MARK___6 = 1166,
	SCL2_A_MARK___6 = 1167,
	CAN1_RX_B_MARK = 1168,
	IP11_23_20_MARK___6 = 1169,
	RX0_A_MARK___2 = 1170,
	MSIOF0_SS1_MARK___8 = 1171,
	FSO_CFE_1_N_B_MARK___3 = 1172,
	IP8_27_24_MARK___8 = 1173,
	NFRE_N_MARK___5 = 1174,
	MMC_CMD_MARK___3 = 1175,
	IP9_27_24_MARK___7 = 1176,
	NFDATA6_MARK___5 = 1177,
	MMC_D6_MARK___3 = 1178,
	IP10_27_24_MARK___7 = 1179,
	SSI_WS4_A_MARK = 1180,
	HRX0_MARK___6 = 1181,
	SDA2_A_MARK___6 = 1182,
	CAN1_TX_B_MARK = 1183,
	IP11_27_24_MARK___6 = 1184,
	TX0_A_MARK___2 = 1185,
	MSIOF0_SS2_MARK___8 = 1186,
	FSO_TOE_N_B_MARK___3 = 1187,
	IP8_31_28_MARK___8 = 1188,
	NFWE_N_MARK___5 = 1189,
	MMC_CLK_MARK___3 = 1190,
	IP9_31_28_MARK___7 = 1191,
	NFDATA7_MARK___5 = 1192,
	MMC_D7_MARK___3 = 1193,
	IP10_31_28_MARK___7 = 1194,
	SCL1_MARK___3 = 1195,
	CTS1_N_MARK___8 = 1196,
	IP11_31_28_MARK___6 = 1197,
	SCK1_A_MARK = 1198,
	MSIOF1_SS2_MARK___4 = 1199,
	TPU0TO2_B_MARK = 1200,
	CAN0_TX_B_MARK___5 = 1201,
	AUDIO_CLKOUT1_MARK = 1202,
	IP12_3_0_MARK___6 = 1203,
	RX1_A_MARK___7 = 1204,
	CTS0_N_MARK___7 = 1205,
	TPU0TO0_B_MARK = 1206,
	IP13_3_0_MARK___6 = 1207,
	CAN1_RX_A_MARK = 1208,
	CANFD1_RX_MARK___8 = 1209,
	TPU0TO2_A_MARK = 1210,
	IP12_7_4_MARK___6 = 1211,
	TX1_A_MARK___7 = 1212,
	RTS0_N_MARK___7 = 1213,
	TPU0TO1_B_MARK = 1214,
	IP13_7_4_MARK___6 = 1215,
	CAN1_TX_A_MARK = 1216,
	CANFD1_TX_MARK___8 = 1217,
	TPU0TO3_A_MARK = 1218,
	IP12_11_8_MARK___6 = 1219,
	SCK2_MARK___5 = 1220,
	MSIOF1_SS1_MARK___4 = 1221,
	TPU0TO3_B_MARK = 1222,
	IP12_15_12_MARK___6 = 1223,
	TPU0TO0_A_MARK = 1224,
	AVB0_AVTP_CAPTURE_A_MARK = 1225,
	HCTS0_N_MARK___6 = 1226,
	IP12_19_16_MARK___6 = 1227,
	TPU0TO1_A_MARK = 1228,
	AVB0_AVTP_MATCH_A_MARK = 1229,
	HRTS0_N_MARK___6 = 1230,
	IP12_23_20_MARK___6 = 1231,
	CAN_CLK_MARK___6 = 1232,
	AVB0_AVTP_PPS_A_MARK = 1233,
	SCK0_B_MARK___2 = 1234,
	IRQ5_B_MARK = 1235,
	IP12_27_24_MARK___6 = 1236,
	CAN0_RX_A_MARK___5 = 1237,
	CANFD0_RX_MARK___2 = 1238,
	RX0_B_MARK___2 = 1239,
	IP12_31_28_MARK___6 = 1240,
	CAN0_TX_A_MARK___5 = 1241,
	CANFD0_TX_MARK___2 = 1242,
	TX0_B_MARK___2 = 1243,
	SEL_CAN0_0_MARK = 1244,
	SEL_CAN0_1_MARK = 1245,
	SEL_MSIOF2_0_MARK___6 = 1246,
	SEL_MSIOF2_1_MARK___6 = 1247,
	SEL_CAN1_0_MARK = 1248,
	SEL_CAN1_1_MARK = 1249,
	SEL_I2C3_0_MARK___2 = 1250,
	SEL_I2C3_1_MARK___2 = 1251,
	SEL_I2C2_0_MARK___6 = 1252,
	SEL_I2C2_1_MARK___6 = 1253,
	SEL_SCIF5_0_MARK___5 = 1254,
	SEL_SCIF5_1_MARK___5 = 1255,
	SEL_ETHERAVB_0_MARK___5 = 1256,
	SEL_ETHERAVB_1_MARK___5 = 1257,
	SEL_MSIOF3_0_MARK___6 = 1258,
	SEL_MSIOF3_1_MARK___6 = 1259,
	SEL_SCIF0_0_MARK___2 = 1260,
	SEL_SCIF0_1_MARK___2 = 1261,
	SEL_HSCIF3_0_MARK___6 = 1262,
	SEL_HSCIF3_1_MARK___6 = 1263,
	SEL_SSIF4_0_MARK = 1264,
	SEL_SSIF4_1_MARK = 1265,
	SEL_SCIF4_0_MARK___6 = 1266,
	SEL_SCIF4_1_MARK___6 = 1267,
	SEL_PWM0_0_MARK___4 = 1268,
	SEL_PWM0_2_MARK = 1269,
	SEL_PWM0_1_MARK___4 = 1270,
	SEL_PWM1_0_MARK___8 = 1271,
	SEL_PWM1_2_MARK = 1272,
	SEL_PWM1_1_MARK___8 = 1273,
	SEL_PWM2_0_MARK___8 = 1274,
	SEL_PWM2_2_MARK___2 = 1275,
	SEL_PWM2_1_MARK___8 = 1276,
	SEL_PWM3_0_MARK___8 = 1277,
	SEL_PWM3_2_MARK___2 = 1278,
	SEL_PWM3_1_MARK___8 = 1279,
	SEL_IRQ_0_0_MARK = 1280,
	SEL_IRQ_0_1_MARK = 1281,
	SEL_IRQ_1_0_MARK = 1282,
	SEL_IRQ_1_1_MARK = 1283,
	SEL_IRQ_2_0_MARK = 1284,
	SEL_IRQ_2_1_MARK = 1285,
	SEL_IRQ_3_0_MARK = 1286,
	SEL_IRQ_3_1_MARK = 1287,
	SEL_IRQ_4_0_MARK = 1288,
	SEL_IRQ_4_1_MARK = 1289,
	SEL_IRQ_5_0_MARK = 1290,
	SEL_IRQ_5_1_MARK = 1291,
	SEL_TMU_0_0_MARK = 1292,
	SEL_TMU_0_1_MARK = 1293,
	SEL_TMU_1_0_MARK = 1294,
	SEL_TMU_1_1_MARK = 1295,
	SEL_SCIF3_0_MARK___6 = 1296,
	SEL_SCIF3_1_MARK___6 = 1297,
	SEL_SCIF1_0_MARK___7 = 1298,
	SEL_SCIF1_1_MARK___7 = 1299,
	SEL_SCU_0_MARK = 1300,
	SEL_SCU_1_MARK = 1301,
	SEL_RFSO_0_MARK___2 = 1302,
	SEL_RFSO_1_MARK___2 = 1303,
	PINMUX_MARK_END___8 = 1304,
};

enum {
	GP_LAST___8 = 205,
	PIN_DU_DOTCLKIN0___5 = 206,
	PIN_FSCLKST_N___6 = 207,
	PIN_MLB_REF___6 = 208,
	PIN_PRESETOUT_N___8 = 209,
	PIN_TCK___7 = 210,
	PIN_TDI___7 = 211,
	PIN_TMS___7 = 212,
	PIN_TRST_N___7 = 213,
};

enum ioctrl_regs___5 {
	TDSELCTRL___5 = 0,
};

enum {
	PINMUX_RESERVED___9 = 0,
	PINMUX_DATA_BEGIN___9 = 1,
	GP_0_0_DATA___9 = 2,
	GP_0_1_DATA___9 = 3,
	GP_0_2_DATA___9 = 4,
	GP_0_3_DATA___9 = 5,
	GP_0_4_DATA___9 = 6,
	GP_0_5_DATA___9 = 7,
	GP_0_6_DATA___9 = 8,
	GP_0_7_DATA___9 = 9,
	GP_0_8_DATA___9 = 10,
	GP_0_9_DATA___8 = 11,
	GP_0_10_DATA___8 = 12,
	GP_0_11_DATA___8 = 13,
	GP_0_12_DATA___8 = 14,
	GP_0_13_DATA___8 = 15,
	GP_0_14_DATA___8 = 16,
	GP_0_15_DATA___8 = 17,
	GP_0_16_DATA___4 = 18,
	GP_0_17_DATA___4 = 19,
	GP_0_18_DATA___3 = 20,
	GP_0_19_DATA___3 = 21,
	GP_0_20_DATA___3 = 22,
	GP_0_21_DATA___3 = 23,
	GP_0_22_DATA = 24,
	GP_0_23_DATA = 25,
	GP_0_24_DATA = 26,
	GP_0_25_DATA = 27,
	GP_0_26_DATA = 28,
	GP_0_27_DATA = 29,
	GP_1_0_DATA___9 = 30,
	GP_1_1_DATA___9 = 31,
	GP_1_2_DATA___9 = 32,
	GP_1_3_DATA___9 = 33,
	GP_1_4_DATA___9 = 34,
	GP_1_5_DATA___9 = 35,
	GP_1_6_DATA___9 = 36,
	GP_1_7_DATA___9 = 37,
	GP_1_8_DATA___9 = 38,
	GP_1_9_DATA___9 = 39,
	GP_1_10_DATA___9 = 40,
	GP_1_11_DATA___9 = 41,
	GP_1_12_DATA___9 = 42,
	GP_1_13_DATA___9 = 43,
	GP_1_14_DATA___9 = 44,
	GP_1_15_DATA___9 = 45,
	GP_1_16_DATA___9 = 46,
	GP_1_17_DATA___9 = 47,
	GP_1_18_DATA___9 = 48,
	GP_1_19_DATA___9 = 49,
	GP_1_20_DATA___9 = 50,
	GP_1_21_DATA___9 = 51,
	GP_1_22_DATA___9 = 52,
	GP_1_23_DATA___8 = 53,
	GP_1_24_DATA___8 = 54,
	GP_1_25_DATA___8 = 55,
	GP_1_26_DATA___8 = 56,
	GP_1_27_DATA___8 = 57,
	GP_1_28_DATA___5 = 58,
	GP_1_29_DATA___2 = 59,
	GP_1_30_DATA___2 = 60,
	GP_2_0_DATA___9 = 61,
	GP_2_1_DATA___9 = 62,
	GP_2_2_DATA___9 = 63,
	GP_2_3_DATA___9 = 64,
	GP_2_4_DATA___9 = 65,
	GP_2_5_DATA___9 = 66,
	GP_2_6_DATA___9 = 67,
	GP_2_7_DATA___9 = 68,
	GP_2_8_DATA___9 = 69,
	GP_2_9_DATA___9 = 70,
	GP_2_10_DATA___9 = 71,
	GP_2_11_DATA___9 = 72,
	GP_2_12_DATA___9 = 73,
	GP_2_13_DATA___9 = 74,
	GP_2_14_DATA___9 = 75,
	GP_2_15_DATA___5 = 76,
	GP_2_16_DATA___5 = 77,
	GP_2_17_DATA___4 = 78,
	GP_2_18_DATA___4 = 79,
	GP_2_19_DATA___4 = 80,
	GP_2_20_DATA___4 = 81,
	GP_2_21_DATA___4 = 82,
	GP_2_22_DATA___4 = 83,
	GP_2_23_DATA___4 = 84,
	GP_2_24_DATA___4 = 85,
	GP_3_0_DATA___9 = 86,
	GP_3_1_DATA___9 = 87,
	GP_3_2_DATA___9 = 88,
	GP_3_3_DATA___9 = 89,
	GP_3_4_DATA___9 = 90,
	GP_3_5_DATA___9 = 91,
	GP_3_6_DATA___9 = 92,
	GP_3_7_DATA___9 = 93,
	GP_3_8_DATA___9 = 94,
	GP_3_9_DATA___9 = 95,
	GP_3_10_DATA___8 = 96,
	GP_3_11_DATA___8 = 97,
	GP_3_12_DATA___8 = 98,
	GP_3_13_DATA___8 = 99,
	GP_3_14_DATA___8 = 100,
	GP_3_15_DATA___8 = 101,
	GP_3_16_DATA___3 = 102,
	GP_4_0_DATA___9 = 103,
	GP_4_1_DATA___9 = 104,
	GP_4_2_DATA___9 = 105,
	GP_4_3_DATA___9 = 106,
	GP_4_4_DATA___9 = 107,
	GP_4_5_DATA___9 = 108,
	GP_4_6_DATA___8 = 109,
	GP_4_7_DATA___8 = 110,
	GP_4_8_DATA___8 = 111,
	GP_4_9_DATA___8 = 112,
	GP_4_10_DATA___8 = 113,
	GP_4_11_DATA___7 = 114,
	GP_4_12_DATA___7 = 115,
	GP_4_13_DATA___7 = 116,
	GP_4_14_DATA___7 = 117,
	GP_4_15_DATA___7 = 118,
	GP_4_16_DATA___7 = 119,
	GP_4_17_DATA___7 = 120,
	GP_4_18_DATA___3 = 121,
	GP_4_19_DATA___3 = 122,
	GP_4_20_DATA___3 = 123,
	GP_4_21_DATA___3 = 124,
	GP_4_22_DATA___3 = 125,
	GP_4_23_DATA___3 = 126,
	GP_4_24_DATA___3 = 127,
	GP_4_25_DATA___2 = 128,
	GP_4_26_DATA___2 = 129,
	GP_5_0_DATA___9 = 130,
	GP_5_1_DATA___9 = 131,
	GP_5_2_DATA___9 = 132,
	GP_5_3_DATA___9 = 133,
	GP_5_4_DATA___9 = 134,
	GP_5_5_DATA___9 = 135,
	GP_5_6_DATA___9 = 136,
	GP_5_7_DATA___9 = 137,
	GP_5_8_DATA___9 = 138,
	GP_5_9_DATA___9 = 139,
	GP_5_10_DATA___9 = 140,
	GP_5_11_DATA___9 = 141,
	GP_5_12_DATA___9 = 142,
	GP_5_13_DATA___9 = 143,
	GP_5_14_DATA___9 = 144,
	GP_5_15_DATA___7 = 145,
	GP_5_16_DATA___7 = 146,
	GP_5_17_DATA___7 = 147,
	GP_5_18_DATA___7 = 148,
	GP_5_19_DATA___7 = 149,
	GP_5_20_DATA___6 = 150,
	GP_6_0_DATA___7 = 151,
	GP_6_1_DATA___7 = 152,
	GP_6_2_DATA___7 = 153,
	GP_6_3_DATA___7 = 154,
	GP_6_4_DATA___7 = 155,
	GP_6_5_DATA___7 = 156,
	GP_6_6_DATA___7 = 157,
	GP_6_7_DATA___7 = 158,
	GP_6_8_DATA___7 = 159,
	GP_6_9_DATA___7 = 160,
	GP_6_10_DATA___7 = 161,
	GP_6_11_DATA___7 = 162,
	GP_6_12_DATA___7 = 163,
	GP_6_13_DATA___7 = 164,
	GP_6_14_DATA___6 = 165,
	GP_6_15_DATA___6 = 166,
	GP_6_16_DATA___6 = 167,
	GP_6_17_DATA___6 = 168,
	GP_6_18_DATA___5 = 169,
	GP_6_19_DATA___5 = 170,
	GP_6_20_DATA___5 = 171,
	GP_7_0_DATA___5 = 172,
	GP_7_1_DATA___5 = 173,
	GP_7_2_DATA___5 = 174,
	GP_7_3_DATA___5 = 175,
	GP_7_4_DATA = 176,
	GP_7_5_DATA = 177,
	GP_7_6_DATA = 178,
	GP_7_7_DATA = 179,
	GP_7_8_DATA = 180,
	GP_7_9_DATA = 181,
	GP_7_10_DATA = 182,
	GP_7_11_DATA = 183,
	GP_7_12_DATA = 184,
	GP_7_13_DATA = 185,
	GP_7_14_DATA = 186,
	GP_7_15_DATA = 187,
	GP_7_16_DATA = 188,
	GP_7_17_DATA = 189,
	GP_7_18_DATA = 190,
	GP_7_19_DATA = 191,
	GP_7_20_DATA = 192,
	GP_8_0_DATA = 193,
	GP_8_1_DATA = 194,
	GP_8_2_DATA = 195,
	GP_8_3_DATA = 196,
	GP_8_4_DATA = 197,
	GP_8_5_DATA = 198,
	GP_8_6_DATA = 199,
	GP_8_7_DATA = 200,
	GP_8_8_DATA = 201,
	GP_8_9_DATA = 202,
	GP_8_10_DATA = 203,
	GP_8_11_DATA = 204,
	GP_8_12_DATA = 205,
	GP_8_13_DATA = 206,
	GP_8_14_DATA = 207,
	GP_8_15_DATA = 208,
	GP_8_16_DATA = 209,
	GP_8_17_DATA = 210,
	GP_8_18_DATA = 211,
	GP_8_19_DATA = 212,
	GP_8_20_DATA = 213,
	GP_9_0_DATA = 214,
	GP_9_1_DATA = 215,
	GP_9_2_DATA = 216,
	GP_9_3_DATA = 217,
	GP_9_4_DATA = 218,
	GP_9_5_DATA = 219,
	GP_9_6_DATA = 220,
	GP_9_7_DATA = 221,
	GP_9_8_DATA = 222,
	GP_9_9_DATA = 223,
	GP_9_10_DATA = 224,
	GP_9_11_DATA = 225,
	GP_9_12_DATA = 226,
	GP_9_13_DATA = 227,
	GP_9_14_DATA = 228,
	GP_9_15_DATA = 229,
	GP_9_16_DATA = 230,
	GP_9_17_DATA = 231,
	GP_9_18_DATA = 232,
	GP_9_19_DATA = 233,
	GP_9_20_DATA = 234,
	PINMUX_DATA_END___9 = 235,
	PINMUX_FUNCTION_BEGIN___9 = 236,
	GP_0_0_FN___9 = 237,
	GP_0_1_FN___9 = 238,
	GP_0_2_FN___9 = 239,
	GP_0_3_FN___9 = 240,
	GP_0_4_FN___9 = 241,
	GP_0_5_FN___9 = 242,
	GP_0_6_FN___9 = 243,
	GP_0_7_FN___9 = 244,
	GP_0_8_FN___9 = 245,
	GP_0_9_FN___8 = 246,
	GP_0_10_FN___8 = 247,
	GP_0_11_FN___8 = 248,
	GP_0_12_FN___8 = 249,
	GP_0_13_FN___8 = 250,
	GP_0_14_FN___8 = 251,
	GP_0_15_FN___8 = 252,
	GP_0_16_FN___4 = 253,
	GP_0_17_FN___4 = 254,
	GP_0_18_FN___3 = 255,
	GP_0_19_FN___3 = 256,
	GP_0_20_FN___3 = 257,
	GP_0_21_FN___3 = 258,
	GP_0_22_FN = 259,
	GP_0_23_FN = 260,
	GP_0_24_FN = 261,
	GP_0_25_FN = 262,
	GP_0_26_FN = 263,
	GP_0_27_FN = 264,
	GP_1_0_FN___9 = 265,
	GP_1_1_FN___9 = 266,
	GP_1_2_FN___9 = 267,
	GP_1_3_FN___9 = 268,
	GP_1_4_FN___9 = 269,
	GP_1_5_FN___9 = 270,
	GP_1_6_FN___9 = 271,
	GP_1_7_FN___9 = 272,
	GP_1_8_FN___9 = 273,
	GP_1_9_FN___9 = 274,
	GP_1_10_FN___9 = 275,
	GP_1_11_FN___9 = 276,
	GP_1_12_FN___9 = 277,
	GP_1_13_FN___9 = 278,
	GP_1_14_FN___9 = 279,
	GP_1_15_FN___9 = 280,
	GP_1_16_FN___9 = 281,
	GP_1_17_FN___9 = 282,
	GP_1_18_FN___9 = 283,
	GP_1_19_FN___9 = 284,
	GP_1_20_FN___9 = 285,
	GP_1_21_FN___9 = 286,
	GP_1_22_FN___9 = 287,
	GP_1_23_FN___8 = 288,
	GP_1_24_FN___8 = 289,
	GP_1_25_FN___8 = 290,
	GP_1_26_FN___8 = 291,
	GP_1_27_FN___8 = 292,
	GP_1_28_FN___5 = 293,
	GP_1_29_FN___2 = 294,
	GP_1_30_FN___2 = 295,
	GP_2_0_FN___9 = 296,
	GP_2_1_FN___9 = 297,
	GP_2_2_FN___9 = 298,
	GP_2_3_FN___9 = 299,
	GP_2_4_FN___9 = 300,
	GP_2_5_FN___9 = 301,
	GP_2_6_FN___9 = 302,
	GP_2_7_FN___9 = 303,
	GP_2_8_FN___9 = 304,
	GP_2_9_FN___9 = 305,
	GP_2_10_FN___9 = 306,
	GP_2_11_FN___9 = 307,
	GP_2_12_FN___9 = 308,
	GP_2_13_FN___9 = 309,
	GP_2_14_FN___9 = 310,
	GP_2_15_FN___5 = 311,
	GP_2_16_FN___5 = 312,
	GP_2_17_FN___4 = 313,
	GP_2_18_FN___4 = 314,
	GP_2_19_FN___4 = 315,
	GP_2_20_FN___4 = 316,
	GP_2_21_FN___4 = 317,
	GP_2_22_FN___4 = 318,
	GP_2_23_FN___4 = 319,
	GP_2_24_FN___4 = 320,
	GP_3_0_FN___9 = 321,
	GP_3_1_FN___9 = 322,
	GP_3_2_FN___9 = 323,
	GP_3_3_FN___9 = 324,
	GP_3_4_FN___9 = 325,
	GP_3_5_FN___9 = 326,
	GP_3_6_FN___9 = 327,
	GP_3_7_FN___9 = 328,
	GP_3_8_FN___9 = 329,
	GP_3_9_FN___9 = 330,
	GP_3_10_FN___8 = 331,
	GP_3_11_FN___8 = 332,
	GP_3_12_FN___8 = 333,
	GP_3_13_FN___8 = 334,
	GP_3_14_FN___8 = 335,
	GP_3_15_FN___8 = 336,
	GP_3_16_FN___3 = 337,
	GP_4_0_FN___9 = 338,
	GP_4_1_FN___9 = 339,
	GP_4_2_FN___9 = 340,
	GP_4_3_FN___9 = 341,
	GP_4_4_FN___9 = 342,
	GP_4_5_FN___9 = 343,
	GP_4_6_FN___8 = 344,
	GP_4_7_FN___8 = 345,
	GP_4_8_FN___8 = 346,
	GP_4_9_FN___8 = 347,
	GP_4_10_FN___8 = 348,
	GP_4_11_FN___7 = 349,
	GP_4_12_FN___7 = 350,
	GP_4_13_FN___7 = 351,
	GP_4_14_FN___7 = 352,
	GP_4_15_FN___7 = 353,
	GP_4_16_FN___7 = 354,
	GP_4_17_FN___7 = 355,
	GP_4_18_FN___3 = 356,
	GP_4_19_FN___3 = 357,
	GP_4_20_FN___3 = 358,
	GP_4_21_FN___3 = 359,
	GP_4_22_FN___3 = 360,
	GP_4_23_FN___3 = 361,
	GP_4_24_FN___3 = 362,
	GP_4_25_FN___2 = 363,
	GP_4_26_FN___2 = 364,
	GP_5_0_FN___9 = 365,
	GP_5_1_FN___9 = 366,
	GP_5_2_FN___9 = 367,
	GP_5_3_FN___9 = 368,
	GP_5_4_FN___9 = 369,
	GP_5_5_FN___9 = 370,
	GP_5_6_FN___9 = 371,
	GP_5_7_FN___9 = 372,
	GP_5_8_FN___9 = 373,
	GP_5_9_FN___9 = 374,
	GP_5_10_FN___9 = 375,
	GP_5_11_FN___9 = 376,
	GP_5_12_FN___9 = 377,
	GP_5_13_FN___9 = 378,
	GP_5_14_FN___9 = 379,
	GP_5_15_FN___7 = 380,
	GP_5_16_FN___7 = 381,
	GP_5_17_FN___7 = 382,
	GP_5_18_FN___7 = 383,
	GP_5_19_FN___7 = 384,
	GP_5_20_FN___6 = 385,
	GP_6_0_FN___7 = 386,
	GP_6_1_FN___7 = 387,
	GP_6_2_FN___7 = 388,
	GP_6_3_FN___7 = 389,
	GP_6_4_FN___7 = 390,
	GP_6_5_FN___7 = 391,
	GP_6_6_FN___7 = 392,
	GP_6_7_FN___7 = 393,
	GP_6_8_FN___7 = 394,
	GP_6_9_FN___7 = 395,
	GP_6_10_FN___7 = 396,
	GP_6_11_FN___7 = 397,
	GP_6_12_FN___7 = 398,
	GP_6_13_FN___7 = 399,
	GP_6_14_FN___6 = 400,
	GP_6_15_FN___6 = 401,
	GP_6_16_FN___6 = 402,
	GP_6_17_FN___6 = 403,
	GP_6_18_FN___5 = 404,
	GP_6_19_FN___5 = 405,
	GP_6_20_FN___5 = 406,
	GP_7_0_FN___5 = 407,
	GP_7_1_FN___5 = 408,
	GP_7_2_FN___5 = 409,
	GP_7_3_FN___5 = 410,
	GP_7_4_FN = 411,
	GP_7_5_FN = 412,
	GP_7_6_FN = 413,
	GP_7_7_FN = 414,
	GP_7_8_FN = 415,
	GP_7_9_FN = 416,
	GP_7_10_FN = 417,
	GP_7_11_FN = 418,
	GP_7_12_FN = 419,
	GP_7_13_FN = 420,
	GP_7_14_FN = 421,
	GP_7_15_FN = 422,
	GP_7_16_FN = 423,
	GP_7_17_FN = 424,
	GP_7_18_FN = 425,
	GP_7_19_FN = 426,
	GP_7_20_FN = 427,
	GP_8_0_FN = 428,
	GP_8_1_FN = 429,
	GP_8_2_FN = 430,
	GP_8_3_FN = 431,
	GP_8_4_FN = 432,
	GP_8_5_FN = 433,
	GP_8_6_FN = 434,
	GP_8_7_FN = 435,
	GP_8_8_FN = 436,
	GP_8_9_FN = 437,
	GP_8_10_FN = 438,
	GP_8_11_FN = 439,
	GP_8_12_FN = 440,
	GP_8_13_FN = 441,
	GP_8_14_FN = 442,
	GP_8_15_FN = 443,
	GP_8_16_FN = 444,
	GP_8_17_FN = 445,
	GP_8_18_FN = 446,
	GP_8_19_FN = 447,
	GP_8_20_FN = 448,
	GP_9_0_FN = 449,
	GP_9_1_FN = 450,
	GP_9_2_FN = 451,
	GP_9_3_FN = 452,
	GP_9_4_FN = 453,
	GP_9_5_FN = 454,
	GP_9_6_FN = 455,
	GP_9_7_FN = 456,
	GP_9_8_FN = 457,
	GP_9_9_FN = 458,
	GP_9_10_FN = 459,
	GP_9_11_FN = 460,
	GP_9_12_FN = 461,
	GP_9_13_FN = 462,
	GP_9_14_FN = 463,
	GP_9_15_FN = 464,
	GP_9_16_FN = 465,
	GP_9_17_FN = 466,
	GP_9_18_FN = 467,
	GP_9_19_FN = 468,
	GP_9_20_FN = 469,
	FN_MMC_D7___4 = 470,
	FN_MMC_D6___4 = 471,
	FN_AVS1___5 = 472,
	FN_MMC_D5___4 = 473,
	FN_AVS0 = 474,
	FN_MMC_D4___4 = 475,
	FN_TCLK2_A___9 = 476,
	FN_PCIE3_CLKREQ_N = 477,
	FN_MMC_SD_CLK = 478,
	FN_PCIE2_CLKREQ_N = 479,
	FN_MMC_SD_D3 = 480,
	FN_PCIE1_CLKREQ_N = 481,
	FN_MMC_SD_D2 = 482,
	FN_PCIE0_CLKREQ_N = 483,
	FN_MMC_SD_D1 = 484,
	FN_AVB2_AVTP_PPS = 485,
	FN_AVB3_AVTP_PPS = 486,
	FN_AVB4_AVTP_PPS = 487,
	FN_AVB5_AVTP_PPS = 488,
	FN_MMC_SD_D0 = 489,
	FN_AVB2_AVTP_CAPTURE = 490,
	FN_AVB3_AVTP_CAPTURE = 491,
	FN_AVB4_AVTP_CAPTURE = 492,
	FN_AVB5_AVTP_CAPTURE = 493,
	FN_MMC_SD_CMD = 494,
	FN_AVB2_AVTP_MATCH = 495,
	FN_AVB3_AVTP_MATCH = 496,
	FN_AVB4_AVTP_MATCH = 497,
	FN_AVB5_AVTP_MATCH = 498,
	FN_MMC_DS___2 = 499,
	FN_AVB2_LINK = 500,
	FN_AVB3_LINK = 501,
	FN_AVB4_LINK = 502,
	FN_AVB5_LINK = 503,
	FN_SD_CD = 504,
	FN_CANFD7_RX = 505,
	FN_AVB0_PHY_INT___3 = 506,
	FN_AVB1_PHY_INT = 507,
	FN_AVB2_PHY_INT = 508,
	FN_AVB3_PHY_INT = 509,
	FN_AVB4_PHY_INT = 510,
	FN_AVB5_PHY_INT = 511,
	FN_SD_WP = 512,
	FN_CANFD7_TX = 513,
	FN_AVB2_MAGIC = 514,
	FN_AVB3_MAGIC = 515,
	FN_AVB4_MAGIC = 516,
	FN_AVB5_MAGIC = 517,
	FN_RPC_INT_N___5 = 518,
	FN_CANFD6_RX = 519,
	FN_AVB2_MDC = 520,
	FN_AVB3_MDC = 521,
	FN_AVB4_MDC = 522,
	FN_AVB5_MDC = 523,
	FN_RPC_WP_N___3 = 524,
	FN_AVB2_MDIO = 525,
	FN_AVB3_MDIO = 526,
	FN_AVB4_MDIO = 527,
	FN_AVB5_MDIO = 528,
	FN_RPC_RESET_N___5 = 529,
	FN_AVB2_TXCREFCLK = 530,
	FN_AVB3_TXCREFCLK = 531,
	FN_AVB4_TXCREFCLK = 532,
	FN_AVB5_TXCREFCLK = 533,
	FN_QSPI1_SSL___5 = 534,
	FN_AVB2_TD3 = 535,
	FN_AVB3_TD3 = 536,
	FN_AVB4_TD3 = 537,
	FN_AVB5_TD3 = 538,
	FN_QSPI1_IO3___5 = 539,
	FN_AVB2_TD2 = 540,
	FN_AVB3_TD2 = 541,
	FN_AVB4_TD2 = 542,
	FN_AVB5_TD2 = 543,
	FN_QSPI1_IO2___5 = 544,
	FN_AVB2_TD1 = 545,
	FN_AVB3_TD1 = 546,
	FN_AVB4_TD1 = 547,
	FN_AVB5_TD1 = 548,
	FN_QSPI1_MISO_IO1___5 = 549,
	FN_AVB2_TD0 = 550,
	FN_AVB3_TD0 = 551,
	FN_AVB4_TD0 = 552,
	FN_AVB5_TD0 = 553,
	FN_QSPI1_MOSI_IO0___5 = 554,
	FN_AVB2_TXC = 555,
	FN_AVB3_TXC = 556,
	FN_AVB4_TXC = 557,
	FN_AVB5_TXC = 558,
	FN_QSPI1_SPCLK___5 = 559,
	FN_AVB2_TX_CTL = 560,
	FN_AVB3_TX_CTL = 561,
	FN_AVB4_TX_CTL = 562,
	FN_AVB5_TX_CTL = 563,
	FN_QSPI0_SSL___5 = 564,
	FN_AVB2_RD3 = 565,
	FN_AVB3_RD3 = 566,
	FN_AVB4_RD3 = 567,
	FN_AVB5_RD3 = 568,
	FN_QSPI0_IO3___5 = 569,
	FN_CANFD1_RX___9 = 570,
	FN_AVB2_RD2 = 571,
	FN_AVB3_RD2 = 572,
	FN_AVB4_RD2 = 573,
	FN_AVB5_RD2 = 574,
	FN_QSPI0_IO2___5 = 575,
	FN_CANFD1_TX___9 = 576,
	FN_AVB2_RD1 = 577,
	FN_AVB3_RD1 = 578,
	FN_AVB4_RD1 = 579,
	FN_AVB5_RD1 = 580,
	FN_QSPI0_MISO_IO1___5 = 581,
	FN_AVB2_RD0 = 582,
	FN_AVB3_RD0 = 583,
	FN_AVB4_RD0 = 584,
	FN_AVB5_RD0 = 585,
	FN_QSPI0_MOSI_IO0___5 = 586,
	FN_AVB2_RXC = 587,
	FN_AVB3_RXC = 588,
	FN_AVB4_RXC = 589,
	FN_AVB5_RXC = 590,
	FN_QSPI0_SPCLK___5 = 591,
	FN_CAN_CLK___7 = 592,
	FN_AVB2_RX_CTL = 593,
	FN_AVB3_RX_CTL = 594,
	FN_AVB4_RX_CTL = 595,
	FN_AVB5_RX_CTL = 596,
	FN_IP0SR1_3_0 = 597,
	FN_SCIF_CLK___2 = 598,
	FN_A0___8 = 599,
	FN_IP1SR1_3_0 = 600,
	FN_MSIOF0_SCK___9 = 601,
	FN_DU_DR4___9 = 602,
	FN_A8___8 = 603,
	FN_IP2SR1_3_0 = 604,
	FN_MSIOF1_SS1___5 = 605,
	FN_HCTS3_N___8 = 606,
	FN_RX3___3 = 607,
	FN_DU_DG6___9 = 608,
	FN_A16___8 = 609,
	FN_IP3SR1_3_0 = 610,
	FN_IRQ0___8 = 611,
	FN_DU_DOTCLKOUT___3 = 612,
	FN_A24___3 = 613,
	FN_IP0SR1_7_4 = 614,
	FN_HRX0___7 = 615,
	FN_RX0___7 = 616,
	FN_A1___8 = 617,
	FN_IP1SR1_7_4 = 618,
	FN_MSIOF0_SYNC___9 = 619,
	FN_DU_DR5___9 = 620,
	FN_A9___8 = 621,
	FN_IP2SR1_7_4 = 622,
	FN_MSIOF1_SS2___5 = 623,
	FN_HTX3___3 = 624,
	FN_TX3___3 = 625,
	FN_DU_DG7___9 = 626,
	FN_A17___8 = 627,
	FN_IP3SR1_7_4 = 628,
	FN_IRQ1___8 = 629,
	FN_DU_HSYNC___3 = 630,
	FN_A25___3 = 631,
	FN_IP0SR1_11_8 = 632,
	FN_HSCK0___7 = 633,
	FN_SCK0___7 = 634,
	FN_A2___8 = 635,
	FN_IP1SR1_11_8 = 636,
	FN_MSIOF0_SS1___9 = 637,
	FN_DU_DR6___9 = 638,
	FN_A10___8 = 639,
	FN_IP2SR1_11_8 = 640,
	FN_MSIOF2_RXD___4 = 641,
	FN_HSCK1___3 = 642,
	FN_SCK1___8 = 643,
	FN_DU_DB2___9 = 644,
	FN_A18___8 = 645,
	FN_IP3SR1_11_8 = 646,
	FN_IRQ2___8 = 647,
	FN_DU_VSYNC___3 = 648,
	FN_CS1_N_A26___3 = 649,
	FN_IP0SR1_15_12 = 650,
	FN_HRTS0_N___7 = 651,
	FN_RTS0_N___8 = 652,
	FN_A3___8 = 653,
	FN_IP1SR1_15_12 = 654,
	FN_MSIOF0_SS2___9 = 655,
	FN_DU_DR7___9 = 656,
	FN_A11___8 = 657,
	FN_IP2SR1_15_12 = 658,
	FN_MSIOF2_TXD___4 = 659,
	FN_HCTS1_N___3 = 660,
	FN_CTS1_N___9 = 661,
	FN_DU_DB3___9 = 662,
	FN_A19___8 = 663,
	FN_IP3SR1_15_12 = 664,
	FN_IRQ3___8 = 665,
	FN_DU_ODDF_DISP_CDE = 666,
	FN_CS0_N___8 = 667,
	FN_IP0SR1_19_16 = 668,
	FN_HCTS0_N___7 = 669,
	FN_CTS0_N___8 = 670,
	FN_A4___8 = 671,
	FN_IP1SR1_19_16 = 672,
	FN_MSIOF1_RXD___5 = 673,
	FN_DU_DG2___9 = 674,
	FN_A12___8 = 675,
	FN_IP2SR1_19_16 = 676,
	FN_MSIOF2_SCK___4 = 677,
	FN_HRTS1_N___3 = 678,
	FN_RTS1_N___9 = 679,
	FN_DU_DB4___9 = 680,
	FN_A20___2 = 681,
	FN_IP3SR1_19_16 = 682,
	FN_GP1_28 = 683,
	FN_D0___8 = 684,
	FN_IP0SR1_23_20 = 685,
	FN_HTX0___7 = 686,
	FN_TX0___7 = 687,
	FN_A5___8 = 688,
	FN_IP1SR1_23_20 = 689,
	FN_MSIOF1_TXD___5 = 690,
	FN_HRX3___3 = 691,
	FN_SCK3___7 = 692,
	FN_DU_DG3___9 = 693,
	FN_A13___8 = 694,
	FN_IP2SR1_23_20 = 695,
	FN_MSIOF2_SYNC___3 = 696,
	FN_HRX1___3 = 697,
	FN_RX1_A___8 = 698,
	FN_DU_DB5___9 = 699,
	FN_A21___2 = 700,
	FN_IP3SR1_23_20 = 701,
	FN_GP1_29 = 702,
	FN_D1___8 = 703,
	FN_IP0SR1_27_24 = 704,
	FN_MSIOF0_RXD___9 = 705,
	FN_DU_DR2___9 = 706,
	FN_A6___8 = 707,
	FN_IP1SR1_27_24 = 708,
	FN_MSIOF1_SCK___5 = 709,
	FN_HSCK3___7 = 710,
	FN_CTS3_N___7 = 711,
	FN_DU_DG4___9 = 712,
	FN_A14___8 = 713,
	FN_IP2SR1_27_24 = 714,
	FN_MSIOF2_SS1___4 = 715,
	FN_HTX1___3 = 716,
	FN_TX1_A___8 = 717,
	FN_DU_DB6___9 = 718,
	FN_A22___3 = 719,
	FN_IP3SR1_27_24 = 720,
	FN_GP1_30 = 721,
	FN_D2___8 = 722,
	FN_IP0SR1_31_28 = 723,
	FN_MSIOF0_TXD___9 = 724,
	FN_DU_DR3___9 = 725,
	FN_A7___8 = 726,
	FN_IP1SR1_31_28 = 727,
	FN_MSIOF1_SYNC___5 = 728,
	FN_HRTS3_N___8 = 729,
	FN_RTS3_N___7 = 730,
	FN_DU_DG5___9 = 731,
	FN_A15___8 = 732,
	FN_IP2SR1_31_28 = 733,
	FN_MSIOF2_SS2___4 = 734,
	FN_TCLK1_B___9 = 735,
	FN_DU_DB7___9 = 736,
	FN_A23___3 = 737,
	FN_IP3SR1_31_28 = 738,
	FN_IP0SR2_3_0 = 739,
	FN_IPC_CLKIN = 740,
	FN_IPC_CLKEN_IN = 741,
	FN_DU_DOTCLKIN = 742,
	FN_IP1SR2_3_0 = 743,
	FN_GP2_08 = 744,
	FN_HRX2___3 = 745,
	FN_MSIOF4_SS1 = 746,
	FN_RX4___3 = 747,
	FN_D9___8 = 748,
	FN_IP2SR2_3_0 = 749,
	FN_FXR_TXDA_A = 750,
	FN_MSIOF3_SS1___3 = 751,
	FN_IP0SR2_7_4 = 752,
	FN_IPC_CLKOUT = 753,
	FN_IPC_CLKEN_OUT = 754,
	FN_IP1SR2_7_4 = 755,
	FN_GP2_09 = 756,
	FN_HTX2___3 = 757,
	FN_MSIOF4_SS2 = 758,
	FN_TX4___3 = 759,
	FN_D10___8 = 760,
	FN_IP2SR2_7_4 = 761,
	FN_RXDA_EXTFXR_A = 762,
	FN_MSIOF3_SS2___3 = 763,
	FN_BS_N___8 = 764,
	FN_IP0SR2_11_8 = 765,
	FN_GP2_02 = 766,
	FN_D3___8 = 767,
	FN_IP1SR2_11_8 = 768,
	FN_GP2_10 = 769,
	FN_TCLK2_B___9 = 770,
	FN_MSIOF5_RXD = 771,
	FN_D11___8 = 772,
	FN_IP2SR2_11_8 = 773,
	FN_FXR_TXDB___3 = 774,
	FN_MSIOF3_RXD___3 = 775,
	FN_RD_N___8 = 776,
	FN_IP0SR2_15_12 = 777,
	FN_GP2_03 = 778,
	FN_D4___8 = 779,
	FN_IP1SR2_15_12 = 780,
	FN_GP2_11 = 781,
	FN_TCLK3___2 = 782,
	FN_MSIOF5_TXD = 783,
	FN_D12___8 = 784,
	FN_IP2SR2_15_12 = 785,
	FN_RXDB_EXTFXR___3 = 786,
	FN_MSIOF3_TXD___3 = 787,
	FN_WE0_N___8 = 788,
	FN_IP0SR2_19_16 = 789,
	FN_GP2_04 = 790,
	FN_MSIOF4_RXD = 791,
	FN_D5___8 = 792,
	FN_IP1SR2_19_16 = 793,
	FN_GP2_12 = 794,
	FN_TCLK4___2 = 795,
	FN_MSIOF5_SCK = 796,
	FN_D13___8 = 797,
	FN_IP2SR2_19_16 = 798,
	FN_CLK_EXTFXR___3 = 799,
	FN_MSIOF3_SCK___3 = 800,
	FN_WE1_N___8 = 801,
	FN_IP0SR2_23_20 = 802,
	FN_GP2_05 = 803,
	FN_HSCK2___3 = 804,
	FN_MSIOF4_TXD = 805,
	FN_SCK4___3 = 806,
	FN_D6___8 = 807,
	FN_IP1SR2_23_20 = 808,
	FN_GP2_13 = 809,
	FN_MSIOF5_SYNC = 810,
	FN_D14___8 = 811,
	FN_IP2SR2_23_20 = 812,
	FN_TPU0TO0___8 = 813,
	FN_MSIOF3_SYNC___3 = 814,
	FN_RD_WR_N___8 = 815,
	FN_IP0SR2_27_24 = 816,
	FN_GP2_06 = 817,
	FN_HCTS2_N___3 = 818,
	FN_MSIOF4_SCK = 819,
	FN_CTS4_N___3 = 820,
	FN_D7___8 = 821,
	FN_IP1SR2_27_24 = 822,
	FN_GP2_14 = 823,
	FN_IRQ4___8 = 824,
	FN_MSIOF5_SS1 = 825,
	FN_D15___8 = 826,
	FN_IP2SR2_27_24 = 827,
	FN_TPU0TO1___8 = 828,
	FN_CLKOUT___7 = 829,
	FN_IP0SR2_31_28 = 830,
	FN_GP2_07 = 831,
	FN_HRTS2_N___3 = 832,
	FN_MSIOF4_SYNC = 833,
	FN_RTS4_N___3 = 834,
	FN_D8___8 = 835,
	FN_IP1SR2_31_28 = 836,
	FN_GP2_15 = 837,
	FN_IRQ5___8 = 838,
	FN_MSIOF5_SS2 = 839,
	FN_CPG_CPCKOUT___2 = 840,
	FN_IP2SR2_31_28 = 841,
	FN_TCLK1_A___9 = 842,
	FN_EX_WAIT0___4 = 843,
	FN_IP0SR3_3_0 = 844,
	FN_IP1SR3_3_0 = 845,
	FN_CANFD3_RX = 846,
	FN_PWM3 = 847,
	FN_IP0SR3_7_4 = 848,
	FN_CANFD0_TX___3 = 849,
	FN_FXR_TXDA_B = 850,
	FN_TX1_B___8 = 851,
	FN_IP1SR3_7_4 = 852,
	FN_CANFD4_TX = 853,
	FN_PWM4 = 854,
	FN_FXR_CLKOUT1___2 = 855,
	FN_IP0SR3_11_8 = 856,
	FN_CANFD0_RX___3 = 857,
	FN_RXDA_EXTFXR_B = 858,
	FN_RX1_B___8 = 859,
	FN_IP1SR3_11_8 = 860,
	FN_CANFD4_RX = 861,
	FN_FXR_CLKOUT2___2 = 862,
	FN_IP0SR3_15_12 = 863,
	FN_IP1SR3_15_12 = 864,
	FN_CANFD5_TX = 865,
	FN_FXR_TXENA_N___3 = 866,
	FN_IP0SR3_19_16 = 867,
	FN_IP1SR3_19_16 = 868,
	FN_CANFD5_RX = 869,
	FN_FXR_TXENB_N___3 = 870,
	FN_IP0SR3_23_20 = 871,
	FN_CANFD2_TX = 872,
	FN_TPU0TO2___8 = 873,
	FN_PWM0___5 = 874,
	FN_IP1SR3_23_20 = 875,
	FN_CANFD6_TX = 876,
	FN_STPWT_EXTFXR = 877,
	FN_IP0SR3_27_24 = 878,
	FN_CANFD2_RX = 879,
	FN_TPU0TO3___8 = 880,
	FN_PWM1 = 881,
	FN_IP1SR3_27_24 = 882,
	FN_IP0SR3_31_28 = 883,
	FN_CANFD3_TX = 884,
	FN_PWM2 = 885,
	FN_IP1SR3_31_28 = 886,
	FN_IP0SR4_3_0 = 887,
	FN_AVB0_RX_CTL___3 = 888,
	FN_AVB0_MII_RX_DV = 889,
	FN_IP1SR4_3_0 = 890,
	FN_AVB0_TD0___3 = 891,
	FN_AVB0_MII_TD0 = 892,
	FN_IP2SR4_3_0 = 893,
	FN_IP0SR4_7_4 = 894,
	FN_AVB0_RXC___3 = 895,
	FN_AVB0_MII_RXC = 896,
	FN_IP1SR4_7_4 = 897,
	FN_AVB0_TD1___3 = 898,
	FN_AVB0_MII_TD1 = 899,
	FN_IP2SR4_7_4 = 900,
	FN_AVB0_LINK___3 = 901,
	FN_AVB0_MII_TX_ER = 902,
	FN_IP0SR4_11_8 = 903,
	FN_AVB0_RD0___3 = 904,
	FN_AVB0_MII_RD0 = 905,
	FN_IP1SR4_11_8 = 906,
	FN_AVB0_TD2___3 = 907,
	FN_AVB0_MII_TD2 = 908,
	FN_IP2SR4_11_8 = 909,
	FN_AVB0_AVTP_MATCH___2 = 910,
	FN_AVB0_MII_RX_ER = 911,
	FN_CC5_OSCOUT = 912,
	FN_IP0SR4_15_12 = 913,
	FN_AVB0_RD1___3 = 914,
	FN_AVB0_MII_RD1 = 915,
	FN_IP1SR4_15_12 = 916,
	FN_AVB0_TD3___3 = 917,
	FN_AVB0_MII_TD3 = 918,
	FN_IP2SR4_15_12 = 919,
	FN_AVB0_AVTP_CAPTURE___2 = 920,
	FN_AVB0_MII_CRS = 921,
	FN_IP0SR4_19_16 = 922,
	FN_AVB0_RD2___3 = 923,
	FN_AVB0_MII_RD2 = 924,
	FN_IP1SR4_19_16 = 925,
	FN_AVB0_TXCREFCLK___3 = 926,
	FN_IP2SR4_19_16 = 927,
	FN_AVB0_AVTP_PPS___2 = 928,
	FN_AVB0_MII_COL = 929,
	FN_IP0SR4_23_20 = 930,
	FN_AVB0_RD3___3 = 931,
	FN_AVB0_MII_RD3 = 932,
	FN_IP1SR4_23_20 = 933,
	FN_AVB0_MDIO___3 = 934,
	FN_IP2SR4_23_20 = 935,
	FN_IP0SR4_27_24 = 936,
	FN_AVB0_TX_CTL___3 = 937,
	FN_AVB0_MII_TX_EN = 938,
	FN_IP1SR4_27_24 = 939,
	FN_AVB0_MDC___3 = 940,
	FN_IP2SR4_27_24 = 941,
	FN_IP0SR4_31_28 = 942,
	FN_AVB0_TXC___3 = 943,
	FN_AVB0_MII_TXC = 944,
	FN_IP1SR4_31_28 = 945,
	FN_AVB0_MAGIC___3 = 946,
	FN_IP2SR4_31_28 = 947,
	FN_IP0SR5_3_0 = 948,
	FN_AVB1_RX_CTL = 949,
	FN_AVB1_MII_RX_DV = 950,
	FN_IP1SR5_3_0 = 951,
	FN_AVB1_TD0 = 952,
	FN_AVB1_MII_TD0 = 953,
	FN_IP2SR5_3_0 = 954,
	FN_IP0SR5_7_4 = 955,
	FN_AVB1_RXC = 956,
	FN_AVB1_MII_RXC = 957,
	FN_IP1SR5_7_4 = 958,
	FN_AVB1_TD1 = 959,
	FN_AVB1_MII_TD1 = 960,
	FN_IP2SR5_7_4 = 961,
	FN_AVB1_LINK = 962,
	FN_AVB1_MII_TX_ER = 963,
	FN_IP0SR5_11_8 = 964,
	FN_AVB1_RD0 = 965,
	FN_AVB1_MII_RD0 = 966,
	FN_IP1SR5_11_8 = 967,
	FN_AVB1_TD2 = 968,
	FN_AVB1_MII_TD2 = 969,
	FN_IP2SR5_11_8 = 970,
	FN_AVB1_AVTP_MATCH = 971,
	FN_AVB1_MII_RX_ER = 972,
	FN_IP0SR5_15_12 = 973,
	FN_AVB1_RD1 = 974,
	FN_AVB1_MII_RD1 = 975,
	FN_IP1SR5_15_12 = 976,
	FN_AVB1_TD3 = 977,
	FN_AVB1_MII_TD3 = 978,
	FN_IP2SR5_15_12 = 979,
	FN_AVB1_AVTP_CAPTURE = 980,
	FN_AVB1_MII_CRS = 981,
	FN_IP0SR5_19_16 = 982,
	FN_AVB1_RD2 = 983,
	FN_AVB1_MII_RD2 = 984,
	FN_IP1SR5_19_16 = 985,
	FN_AVB1_TXCREFCLK = 986,
	FN_IP2SR5_19_16 = 987,
	FN_AVB1_AVTP_PPS = 988,
	FN_AVB1_MII_COL = 989,
	FN_IP0SR5_23_20 = 990,
	FN_AVB1_RD3 = 991,
	FN_AVB1_MII_RD3 = 992,
	FN_IP1SR5_23_20 = 993,
	FN_AVB1_MDIO = 994,
	FN_IP2SR5_23_20 = 995,
	FN_IP0SR5_27_24 = 996,
	FN_AVB1_TX_CTL = 997,
	FN_AVB1_MII_TX_EN = 998,
	FN_IP1SR5_27_24 = 999,
	FN_AVB1_MDC = 1000,
	FN_IP2SR5_27_24 = 1001,
	FN_IP0SR5_31_28 = 1002,
	FN_AVB1_TXC = 1003,
	FN_AVB1_MII_TXC = 1004,
	FN_IP1SR5_31_28 = 1005,
	FN_AVB1_MAGIC = 1006,
	FN_IP2SR5_31_28 = 1007,
	FN_SEL_I2C6_0___6 = 1008,
	FN_SEL_I2C6_3 = 1009,
	FN_SEL_I2C5_0 = 1010,
	FN_SEL_I2C5_3 = 1011,
	FN_SEL_I2C4_0 = 1012,
	FN_SEL_I2C4_3 = 1013,
	FN_SEL_I2C3_0___3 = 1014,
	FN_SEL_I2C3_3 = 1015,
	FN_SEL_I2C2_0___7 = 1016,
	FN_SEL_I2C2_3___2 = 1017,
	FN_SEL_I2C1_0___6 = 1018,
	FN_SEL_I2C1_3___2 = 1019,
	FN_SEL_I2C0_0 = 1020,
	FN_SEL_I2C0_3 = 1021,
	PINMUX_FUNCTION_END___9 = 1022,
	PINMUX_MARK_BEGIN___9 = 1023,
	MMC_D7_MARK___4 = 1024,
	MMC_D6_MARK___4 = 1025,
	AVS1_MARK___5 = 1026,
	MMC_D5_MARK___4 = 1027,
	AVS0_MARK = 1028,
	MMC_D4_MARK___4 = 1029,
	TCLK2_A_MARK___9 = 1030,
	PCIE3_CLKREQ_N_MARK = 1031,
	MMC_SD_CLK_MARK = 1032,
	PCIE2_CLKREQ_N_MARK = 1033,
	MMC_SD_D3_MARK = 1034,
	PCIE1_CLKREQ_N_MARK = 1035,
	MMC_SD_D2_MARK = 1036,
	PCIE0_CLKREQ_N_MARK = 1037,
	MMC_SD_D1_MARK = 1038,
	AVB2_AVTP_PPS_MARK = 1039,
	AVB3_AVTP_PPS_MARK = 1040,
	AVB4_AVTP_PPS_MARK = 1041,
	AVB5_AVTP_PPS_MARK = 1042,
	MMC_SD_D0_MARK = 1043,
	AVB2_AVTP_CAPTURE_MARK = 1044,
	AVB3_AVTP_CAPTURE_MARK = 1045,
	AVB4_AVTP_CAPTURE_MARK = 1046,
	AVB5_AVTP_CAPTURE_MARK = 1047,
	MMC_SD_CMD_MARK = 1048,
	AVB2_AVTP_MATCH_MARK = 1049,
	AVB3_AVTP_MATCH_MARK = 1050,
	AVB4_AVTP_MATCH_MARK = 1051,
	AVB5_AVTP_MATCH_MARK = 1052,
	MMC_DS_MARK___2 = 1053,
	AVB2_LINK_MARK = 1054,
	AVB3_LINK_MARK = 1055,
	AVB4_LINK_MARK = 1056,
	AVB5_LINK_MARK = 1057,
	SD_CD_MARK = 1058,
	CANFD7_RX_MARK = 1059,
	AVB0_PHY_INT_MARK___3 = 1060,
	AVB1_PHY_INT_MARK = 1061,
	AVB2_PHY_INT_MARK = 1062,
	AVB3_PHY_INT_MARK = 1063,
	AVB4_PHY_INT_MARK = 1064,
	AVB5_PHY_INT_MARK = 1065,
	SD_WP_MARK = 1066,
	CANFD7_TX_MARK = 1067,
	AVB2_MAGIC_MARK = 1068,
	AVB3_MAGIC_MARK = 1069,
	AVB4_MAGIC_MARK = 1070,
	AVB5_MAGIC_MARK = 1071,
	RPC_INT_N_MARK___5 = 1072,
	CANFD6_RX_MARK = 1073,
	AVB2_MDC_MARK = 1074,
	AVB3_MDC_MARK = 1075,
	AVB4_MDC_MARK = 1076,
	AVB5_MDC_MARK = 1077,
	RPC_WP_N_MARK___3 = 1078,
	AVB2_MDIO_MARK = 1079,
	AVB3_MDIO_MARK = 1080,
	AVB4_MDIO_MARK = 1081,
	AVB5_MDIO_MARK = 1082,
	RPC_RESET_N_MARK___5 = 1083,
	AVB2_TXCREFCLK_MARK = 1084,
	AVB3_TXCREFCLK_MARK = 1085,
	AVB4_TXCREFCLK_MARK = 1086,
	AVB5_TXCREFCLK_MARK = 1087,
	QSPI1_SSL_MARK___9 = 1088,
	AVB2_TD3_MARK = 1089,
	AVB3_TD3_MARK = 1090,
	AVB4_TD3_MARK = 1091,
	AVB5_TD3_MARK = 1092,
	QSPI1_IO3_MARK___9 = 1093,
	AVB2_TD2_MARK = 1094,
	AVB3_TD2_MARK = 1095,
	AVB4_TD2_MARK = 1096,
	AVB5_TD2_MARK = 1097,
	QSPI1_IO2_MARK___9 = 1098,
	AVB2_TD1_MARK = 1099,
	AVB3_TD1_MARK = 1100,
	AVB4_TD1_MARK = 1101,
	AVB5_TD1_MARK = 1102,
	QSPI1_MISO_IO1_MARK___9 = 1103,
	AVB2_TD0_MARK = 1104,
	AVB3_TD0_MARK = 1105,
	AVB4_TD0_MARK = 1106,
	AVB5_TD0_MARK = 1107,
	QSPI1_MOSI_IO0_MARK___9 = 1108,
	AVB2_TXC_MARK = 1109,
	AVB3_TXC_MARK = 1110,
	AVB4_TXC_MARK = 1111,
	AVB5_TXC_MARK = 1112,
	QSPI1_SPCLK_MARK___9 = 1113,
	AVB2_TX_CTL_MARK = 1114,
	AVB3_TX_CTL_MARK = 1115,
	AVB4_TX_CTL_MARK = 1116,
	AVB5_TX_CTL_MARK = 1117,
	QSPI0_SSL_MARK___9 = 1118,
	AVB2_RD3_MARK = 1119,
	AVB3_RD3_MARK = 1120,
	AVB4_RD3_MARK = 1121,
	AVB5_RD3_MARK = 1122,
	QSPI0_IO3_MARK___9 = 1123,
	CANFD1_RX_MARK___9 = 1124,
	AVB2_RD2_MARK = 1125,
	AVB3_RD2_MARK = 1126,
	AVB4_RD2_MARK = 1127,
	AVB5_RD2_MARK = 1128,
	QSPI0_IO2_MARK___9 = 1129,
	CANFD1_TX_MARK___9 = 1130,
	AVB2_RD1_MARK = 1131,
	AVB3_RD1_MARK = 1132,
	AVB4_RD1_MARK = 1133,
	AVB5_RD1_MARK = 1134,
	QSPI0_MISO_IO1_MARK___9 = 1135,
	AVB2_RD0_MARK = 1136,
	AVB3_RD0_MARK = 1137,
	AVB4_RD0_MARK = 1138,
	AVB5_RD0_MARK = 1139,
	QSPI0_MOSI_IO0_MARK___9 = 1140,
	AVB2_RXC_MARK = 1141,
	AVB3_RXC_MARK = 1142,
	AVB4_RXC_MARK = 1143,
	AVB5_RXC_MARK = 1144,
	QSPI0_SPCLK_MARK___9 = 1145,
	CAN_CLK_MARK___7 = 1146,
	AVB2_RX_CTL_MARK = 1147,
	AVB3_RX_CTL_MARK = 1148,
	AVB4_RX_CTL_MARK = 1149,
	AVB5_RX_CTL_MARK = 1150,
	IP0SR1_3_0_MARK = 1151,
	SCIF_CLK_MARK___2 = 1152,
	A0_MARK___8 = 1153,
	IP1SR1_3_0_MARK = 1154,
	MSIOF0_SCK_MARK___9 = 1155,
	DU_DR4_MARK___9 = 1156,
	A8_MARK___8 = 1157,
	IP2SR1_3_0_MARK = 1158,
	MSIOF1_SS1_MARK___5 = 1159,
	HCTS3_N_MARK___8 = 1160,
	RX3_MARK___3 = 1161,
	DU_DG6_MARK___9 = 1162,
	A16_MARK___8 = 1163,
	IP3SR1_3_0_MARK = 1164,
	IRQ0_MARK___8 = 1165,
	DU_DOTCLKOUT_MARK___3 = 1166,
	A24_MARK___3 = 1167,
	IP0SR1_7_4_MARK = 1168,
	HRX0_MARK___7 = 1169,
	RX0_MARK___7 = 1170,
	A1_MARK___8 = 1171,
	IP1SR1_7_4_MARK = 1172,
	MSIOF0_SYNC_MARK___9 = 1173,
	DU_DR5_MARK___9 = 1174,
	A9_MARK___8 = 1175,
	IP2SR1_7_4_MARK = 1176,
	MSIOF1_SS2_MARK___5 = 1177,
	HTX3_MARK___3 = 1178,
	TX3_MARK___3 = 1179,
	DU_DG7_MARK___9 = 1180,
	A17_MARK___8 = 1181,
	IP3SR1_7_4_MARK = 1182,
	IRQ1_MARK___8 = 1183,
	DU_HSYNC_MARK___3 = 1184,
	A25_MARK___3 = 1185,
	IP0SR1_11_8_MARK = 1186,
	HSCK0_MARK___7 = 1187,
	SCK0_MARK___7 = 1188,
	A2_MARK___8 = 1189,
	IP1SR1_11_8_MARK = 1190,
	MSIOF0_SS1_MARK___9 = 1191,
	DU_DR6_MARK___9 = 1192,
	A10_MARK___8 = 1193,
	IP2SR1_11_8_MARK = 1194,
	MSIOF2_RXD_MARK___4 = 1195,
	HSCK1_MARK___3 = 1196,
	SCK1_MARK___8 = 1197,
	DU_DB2_MARK___9 = 1198,
	A18_MARK___8 = 1199,
	IP3SR1_11_8_MARK = 1200,
	IRQ2_MARK___8 = 1201,
	DU_VSYNC_MARK___3 = 1202,
	CS1_N_A26_MARK___3 = 1203,
	IP0SR1_15_12_MARK = 1204,
	HRTS0_N_MARK___7 = 1205,
	RTS0_N_MARK___8 = 1206,
	A3_MARK___8 = 1207,
	IP1SR1_15_12_MARK = 1208,
	MSIOF0_SS2_MARK___9 = 1209,
	DU_DR7_MARK___9 = 1210,
	A11_MARK___8 = 1211,
	IP2SR1_15_12_MARK = 1212,
	MSIOF2_TXD_MARK___4 = 1213,
	HCTS1_N_MARK___3 = 1214,
	CTS1_N_MARK___9 = 1215,
	DU_DB3_MARK___9 = 1216,
	A19_MARK___8 = 1217,
	IP3SR1_15_12_MARK = 1218,
	IRQ3_MARK___8 = 1219,
	DU_ODDF_DISP_CDE_MARK = 1220,
	CS0_N_MARK___8 = 1221,
	IP0SR1_19_16_MARK = 1222,
	HCTS0_N_MARK___7 = 1223,
	CTS0_N_MARK___8 = 1224,
	A4_MARK___8 = 1225,
	IP1SR1_19_16_MARK = 1226,
	MSIOF1_RXD_MARK___5 = 1227,
	DU_DG2_MARK___9 = 1228,
	A12_MARK___8 = 1229,
	IP2SR1_19_16_MARK = 1230,
	MSIOF2_SCK_MARK___4 = 1231,
	HRTS1_N_MARK___3 = 1232,
	RTS1_N_MARK___9 = 1233,
	DU_DB4_MARK___9 = 1234,
	A20_MARK___2 = 1235,
	IP3SR1_19_16_MARK = 1236,
	GP1_28_MARK = 1237,
	D0_MARK___8 = 1238,
	IP0SR1_23_20_MARK = 1239,
	HTX0_MARK___7 = 1240,
	TX0_MARK___7 = 1241,
	A5_MARK___8 = 1242,
	IP1SR1_23_20_MARK = 1243,
	MSIOF1_TXD_MARK___5 = 1244,
	HRX3_MARK___3 = 1245,
	SCK3_MARK___7 = 1246,
	DU_DG3_MARK___9 = 1247,
	A13_MARK___8 = 1248,
	IP2SR1_23_20_MARK = 1249,
	MSIOF2_SYNC_MARK___3 = 1250,
	HRX1_MARK___3 = 1251,
	RX1_A_MARK___8 = 1252,
	DU_DB5_MARK___9 = 1253,
	A21_MARK___2 = 1254,
	IP3SR1_23_20_MARK = 1255,
	GP1_29_MARK = 1256,
	D1_MARK___8 = 1257,
	IP0SR1_27_24_MARK = 1258,
	MSIOF0_RXD_MARK___9 = 1259,
	DU_DR2_MARK___9 = 1260,
	A6_MARK___8 = 1261,
	IP1SR1_27_24_MARK = 1262,
	MSIOF1_SCK_MARK___5 = 1263,
	HSCK3_MARK___7 = 1264,
	CTS3_N_MARK___7 = 1265,
	DU_DG4_MARK___9 = 1266,
	A14_MARK___8 = 1267,
	IP2SR1_27_24_MARK = 1268,
	MSIOF2_SS1_MARK___4 = 1269,
	HTX1_MARK___3 = 1270,
	TX1_A_MARK___8 = 1271,
	DU_DB6_MARK___9 = 1272,
	A22_MARK___3 = 1273,
	IP3SR1_27_24_MARK = 1274,
	GP1_30_MARK = 1275,
	D2_MARK___8 = 1276,
	IP0SR1_31_28_MARK = 1277,
	MSIOF0_TXD_MARK___9 = 1278,
	DU_DR3_MARK___9 = 1279,
	A7_MARK___8 = 1280,
	IP1SR1_31_28_MARK = 1281,
	MSIOF1_SYNC_MARK___5 = 1282,
	HRTS3_N_MARK___8 = 1283,
	RTS3_N_MARK___7 = 1284,
	DU_DG5_MARK___9 = 1285,
	A15_MARK___8 = 1286,
	IP2SR1_31_28_MARK = 1287,
	MSIOF2_SS2_MARK___4 = 1288,
	TCLK1_B_MARK___9 = 1289,
	DU_DB7_MARK___9 = 1290,
	A23_MARK___3 = 1291,
	IP3SR1_31_28_MARK = 1292,
	IP0SR2_3_0_MARK = 1293,
	IPC_CLKIN_MARK = 1294,
	IPC_CLKEN_IN_MARK = 1295,
	DU_DOTCLKIN_MARK = 1296,
	IP1SR2_3_0_MARK = 1297,
	GP2_08_MARK = 1298,
	HRX2_MARK___3 = 1299,
	MSIOF4_SS1_MARK = 1300,
	RX4_MARK___3 = 1301,
	D9_MARK___8 = 1302,
	IP2SR2_3_0_MARK = 1303,
	FXR_TXDA_A_MARK = 1304,
	MSIOF3_SS1_MARK___3 = 1305,
	IP0SR2_7_4_MARK = 1306,
	IPC_CLKOUT_MARK = 1307,
	IPC_CLKEN_OUT_MARK = 1308,
	IP1SR2_7_4_MARK = 1309,
	GP2_09_MARK = 1310,
	HTX2_MARK___3 = 1311,
	MSIOF4_SS2_MARK = 1312,
	TX4_MARK___3 = 1313,
	D10_MARK___8 = 1314,
	IP2SR2_7_4_MARK = 1315,
	RXDA_EXTFXR_A_MARK = 1316,
	MSIOF3_SS2_MARK___3 = 1317,
	BS_N_MARK___8 = 1318,
	IP0SR2_11_8_MARK = 1319,
	GP2_02_MARK = 1320,
	D3_MARK___8 = 1321,
	IP1SR2_11_8_MARK = 1322,
	GP2_10_MARK = 1323,
	TCLK2_B_MARK___9 = 1324,
	MSIOF5_RXD_MARK = 1325,
	D11_MARK___8 = 1326,
	IP2SR2_11_8_MARK = 1327,
	FXR_TXDB_MARK___3 = 1328,
	MSIOF3_RXD_MARK___3 = 1329,
	RD_N_MARK___8 = 1330,
	IP0SR2_15_12_MARK = 1331,
	GP2_03_MARK = 1332,
	D4_MARK___8 = 1333,
	IP1SR2_15_12_MARK = 1334,
	GP2_11_MARK = 1335,
	TCLK3_MARK___2 = 1336,
	MSIOF5_TXD_MARK = 1337,
	D12_MARK___8 = 1338,
	IP2SR2_15_12_MARK = 1339,
	RXDB_EXTFXR_MARK___3 = 1340,
	MSIOF3_TXD_MARK___3 = 1341,
	WE0_N_MARK___8 = 1342,
	IP0SR2_19_16_MARK = 1343,
	GP2_04_MARK = 1344,
	MSIOF4_RXD_MARK = 1345,
	D5_MARK___8 = 1346,
	IP1SR2_19_16_MARK = 1347,
	GP2_12_MARK = 1348,
	TCLK4_MARK___2 = 1349,
	MSIOF5_SCK_MARK = 1350,
	D13_MARK___8 = 1351,
	IP2SR2_19_16_MARK = 1352,
	CLK_EXTFXR_MARK___3 = 1353,
	MSIOF3_SCK_MARK___3 = 1354,
	WE1_N_MARK___8 = 1355,
	IP0SR2_23_20_MARK = 1356,
	GP2_05_MARK = 1357,
	HSCK2_MARK___3 = 1358,
	MSIOF4_TXD_MARK = 1359,
	SCK4_MARK___3 = 1360,
	D6_MARK___8 = 1361,
	IP1SR2_23_20_MARK = 1362,
	GP2_13_MARK = 1363,
	MSIOF5_SYNC_MARK = 1364,
	D14_MARK___8 = 1365,
	IP2SR2_23_20_MARK = 1366,
	TPU0TO0_MARK___8 = 1367,
	MSIOF3_SYNC_MARK___3 = 1368,
	RD_WR_N_MARK___8 = 1369,
	IP0SR2_27_24_MARK = 1370,
	GP2_06_MARK = 1371,
	HCTS2_N_MARK___3 = 1372,
	MSIOF4_SCK_MARK = 1373,
	CTS4_N_MARK___3 = 1374,
	D7_MARK___8 = 1375,
	IP1SR2_27_24_MARK = 1376,
	GP2_14_MARK = 1377,
	IRQ4_MARK___8 = 1378,
	MSIOF5_SS1_MARK = 1379,
	D15_MARK___8 = 1380,
	IP2SR2_27_24_MARK = 1381,
	TPU0TO1_MARK___8 = 1382,
	CLKOUT_MARK___8 = 1383,
	IP0SR2_31_28_MARK = 1384,
	GP2_07_MARK = 1385,
	HRTS2_N_MARK___3 = 1386,
	MSIOF4_SYNC_MARK = 1387,
	RTS4_N_MARK___3 = 1388,
	D8_MARK___8 = 1389,
	IP1SR2_31_28_MARK = 1390,
	GP2_15_MARK = 1391,
	IRQ5_MARK___8 = 1392,
	MSIOF5_SS2_MARK = 1393,
	CPG_CPCKOUT_MARK___2 = 1394,
	IP2SR2_31_28_MARK = 1395,
	TCLK1_A_MARK___9 = 1396,
	EX_WAIT0_MARK___4 = 1397,
	IP0SR3_3_0_MARK = 1398,
	IP1SR3_3_0_MARK = 1399,
	CANFD3_RX_MARK = 1400,
	PWM3_MARK = 1401,
	IP0SR3_7_4_MARK = 1402,
	CANFD0_TX_MARK___3 = 1403,
	FXR_TXDA_B_MARK = 1404,
	TX1_B_MARK___8 = 1405,
	IP1SR3_7_4_MARK = 1406,
	CANFD4_TX_MARK = 1407,
	PWM4_MARK = 1408,
	FXR_CLKOUT1_MARK___2 = 1409,
	IP0SR3_11_8_MARK = 1410,
	CANFD0_RX_MARK___3 = 1411,
	RXDA_EXTFXR_B_MARK = 1412,
	RX1_B_MARK___8 = 1413,
	IP1SR3_11_8_MARK = 1414,
	CANFD4_RX_MARK = 1415,
	FXR_CLKOUT2_MARK___2 = 1416,
	IP0SR3_15_12_MARK = 1417,
	IP1SR3_15_12_MARK = 1418,
	CANFD5_TX_MARK = 1419,
	FXR_TXENA_N_MARK___3 = 1420,
	IP0SR3_19_16_MARK = 1421,
	IP1SR3_19_16_MARK = 1422,
	CANFD5_RX_MARK = 1423,
	FXR_TXENB_N_MARK___3 = 1424,
	IP0SR3_23_20_MARK = 1425,
	CANFD2_TX_MARK = 1426,
	TPU0TO2_MARK___8 = 1427,
	PWM0_MARK___5 = 1428,
	IP1SR3_23_20_MARK = 1429,
	CANFD6_TX_MARK = 1430,
	STPWT_EXTFXR_MARK = 1431,
	IP0SR3_27_24_MARK = 1432,
	CANFD2_RX_MARK = 1433,
	TPU0TO3_MARK___8 = 1434,
	PWM1_MARK = 1435,
	IP1SR3_27_24_MARK = 1436,
	IP0SR3_31_28_MARK = 1437,
	CANFD3_TX_MARK = 1438,
	PWM2_MARK = 1439,
	IP1SR3_31_28_MARK = 1440,
	IP0SR4_3_0_MARK = 1441,
	AVB0_RX_CTL_MARK___3 = 1442,
	AVB0_MII_RX_DV_MARK = 1443,
	IP1SR4_3_0_MARK = 1444,
	AVB0_TD0_MARK___3 = 1445,
	AVB0_MII_TD0_MARK = 1446,
	IP2SR4_3_0_MARK = 1447,
	IP0SR4_7_4_MARK = 1448,
	AVB0_RXC_MARK___3 = 1449,
	AVB0_MII_RXC_MARK = 1450,
	IP1SR4_7_4_MARK = 1451,
	AVB0_TD1_MARK___3 = 1452,
	AVB0_MII_TD1_MARK = 1453,
	IP2SR4_7_4_MARK = 1454,
	AVB0_LINK_MARK___3 = 1455,
	AVB0_MII_TX_ER_MARK = 1456,
	IP0SR4_11_8_MARK = 1457,
	AVB0_RD0_MARK___3 = 1458,
	AVB0_MII_RD0_MARK = 1459,
	IP1SR4_11_8_MARK = 1460,
	AVB0_TD2_MARK___3 = 1461,
	AVB0_MII_TD2_MARK = 1462,
	IP2SR4_11_8_MARK = 1463,
	AVB0_AVTP_MATCH_MARK___2 = 1464,
	AVB0_MII_RX_ER_MARK = 1465,
	CC5_OSCOUT_MARK = 1466,
	IP0SR4_15_12_MARK = 1467,
	AVB0_RD1_MARK___3 = 1468,
	AVB0_MII_RD1_MARK = 1469,
	IP1SR4_15_12_MARK = 1470,
	AVB0_TD3_MARK___3 = 1471,
	AVB0_MII_TD3_MARK = 1472,
	IP2SR4_15_12_MARK = 1473,
	AVB0_AVTP_CAPTURE_MARK___2 = 1474,
	AVB0_MII_CRS_MARK = 1475,
	IP0SR4_19_16_MARK = 1476,
	AVB0_RD2_MARK___3 = 1477,
	AVB0_MII_RD2_MARK = 1478,
	IP1SR4_19_16_MARK = 1479,
	AVB0_TXCREFCLK_MARK___3 = 1480,
	IP2SR4_19_16_MARK = 1481,
	AVB0_AVTP_PPS_MARK___2 = 1482,
	AVB0_MII_COL_MARK = 1483,
	IP0SR4_23_20_MARK = 1484,
	AVB0_RD3_MARK___3 = 1485,
	AVB0_MII_RD3_MARK = 1486,
	IP1SR4_23_20_MARK = 1487,
	AVB0_MDIO_MARK___3 = 1488,
	IP2SR4_23_20_MARK = 1489,
	IP0SR4_27_24_MARK = 1490,
	AVB0_TX_CTL_MARK___3 = 1491,
	AVB0_MII_TX_EN_MARK = 1492,
	IP1SR4_27_24_MARK = 1493,
	AVB0_MDC_MARK___3 = 1494,
	IP2SR4_27_24_MARK = 1495,
	IP0SR4_31_28_MARK = 1496,
	AVB0_TXC_MARK___3 = 1497,
	AVB0_MII_TXC_MARK = 1498,
	IP1SR4_31_28_MARK = 1499,
	AVB0_MAGIC_MARK___3 = 1500,
	IP2SR4_31_28_MARK = 1501,
	IP0SR5_3_0_MARK = 1502,
	AVB1_RX_CTL_MARK = 1503,
	AVB1_MII_RX_DV_MARK = 1504,
	IP1SR5_3_0_MARK = 1505,
	AVB1_TD0_MARK = 1506,
	AVB1_MII_TD0_MARK = 1507,
	IP2SR5_3_0_MARK = 1508,
	IP0SR5_7_4_MARK = 1509,
	AVB1_RXC_MARK = 1510,
	AVB1_MII_RXC_MARK = 1511,
	IP1SR5_7_4_MARK = 1512,
	AVB1_TD1_MARK = 1513,
	AVB1_MII_TD1_MARK = 1514,
	IP2SR5_7_4_MARK = 1515,
	AVB1_LINK_MARK = 1516,
	AVB1_MII_TX_ER_MARK = 1517,
	IP0SR5_11_8_MARK = 1518,
	AVB1_RD0_MARK = 1519,
	AVB1_MII_RD0_MARK = 1520,
	IP1SR5_11_8_MARK = 1521,
	AVB1_TD2_MARK = 1522,
	AVB1_MII_TD2_MARK = 1523,
	IP2SR5_11_8_MARK = 1524,
	AVB1_AVTP_MATCH_MARK = 1525,
	AVB1_MII_RX_ER_MARK = 1526,
	IP0SR5_15_12_MARK = 1527,
	AVB1_RD1_MARK = 1528,
	AVB1_MII_RD1_MARK = 1529,
	IP1SR5_15_12_MARK = 1530,
	AVB1_TD3_MARK = 1531,
	AVB1_MII_TD3_MARK = 1532,
	IP2SR5_15_12_MARK = 1533,
	AVB1_AVTP_CAPTURE_MARK = 1534,
	AVB1_MII_CRS_MARK = 1535,
	IP0SR5_19_16_MARK = 1536,
	AVB1_RD2_MARK = 1537,
	AVB1_MII_RD2_MARK = 1538,
	IP1SR5_19_16_MARK = 1539,
	AVB1_TXCREFCLK_MARK = 1540,
	IP2SR5_19_16_MARK = 1541,
	AVB1_AVTP_PPS_MARK = 1542,
	AVB1_MII_COL_MARK = 1543,
	IP0SR5_23_20_MARK = 1544,
	AVB1_RD3_MARK = 1545,
	AVB1_MII_RD3_MARK = 1546,
	IP1SR5_23_20_MARK = 1547,
	AVB1_MDIO_MARK = 1548,
	IP2SR5_23_20_MARK = 1549,
	IP0SR5_27_24_MARK = 1550,
	AVB1_TX_CTL_MARK = 1551,
	AVB1_MII_TX_EN_MARK = 1552,
	IP1SR5_27_24_MARK = 1553,
	AVB1_MDC_MARK = 1554,
	IP2SR5_27_24_MARK = 1555,
	IP0SR5_31_28_MARK = 1556,
	AVB1_TXC_MARK = 1557,
	AVB1_MII_TXC_MARK = 1558,
	IP1SR5_31_28_MARK = 1559,
	AVB1_MAGIC_MARK = 1560,
	IP2SR5_31_28_MARK = 1561,
	SEL_I2C6_0_MARK___6 = 1562,
	SEL_I2C6_3_MARK = 1563,
	SEL_I2C5_0_MARK = 1564,
	SEL_I2C5_3_MARK = 1565,
	SEL_I2C4_0_MARK = 1566,
	SEL_I2C4_3_MARK = 1567,
	SEL_I2C3_0_MARK___3 = 1568,
	SEL_I2C3_3_MARK = 1569,
	SEL_I2C2_0_MARK___7 = 1570,
	SEL_I2C2_3_MARK___2 = 1571,
	SEL_I2C1_0_MARK___6 = 1572,
	SEL_I2C1_3_MARK___2 = 1573,
	SEL_I2C0_0_MARK = 1574,
	SEL_I2C0_3_MARK = 1575,
	SCL0_MARK___8 = 1576,
	SDA0_MARK___8 = 1577,
	SCL1_MARK___4 = 1578,
	SDA1_MARK___4 = 1579,
	SCL2_MARK___3 = 1580,
	SDA2_MARK___3 = 1581,
	SCL3_MARK___6 = 1582,
	SDA3_MARK___6 = 1583,
	SCL4_MARK___4 = 1584,
	SDA4_MARK___4 = 1585,
	SCL5_MARK___7 = 1586,
	SDA5_MARK___7 = 1587,
	SCL6_MARK = 1588,
	SDA6_MARK = 1589,
	PINMUX_MARK_END___9 = 1590,
};

enum ioctrl_regs___6 {
	POC0 = 0,
	POC1 = 1,
	POC2 = 2,
	POC4 = 3,
	POC5 = 4,
	POC6 = 5,
	POC7 = 6,
	POC8 = 7,
	POC9 = 8,
	TD1SEL0 = 9,
};

struct rzg2l_dedicated_configs {
	const char *name;
	u32 config;
};

struct rzg2l_pinctrl_data {
	const char * const *port_pins;
	const u32 *port_pin_configs;
	struct rzg2l_dedicated_configs *dedicated_pins;
	unsigned int n_port_pins;
	unsigned int n_dedicated_pins;
};

struct rzg2l_pinctrl {
	struct pinctrl_dev___6 *pctl;
	struct pinctrl_desc___7 desc;
	struct pinctrl_pin_desc *pins;
	const struct rzg2l_pinctrl_data *data;
	void *base;
	struct device___144 *dev;
	struct clk *clk;
	struct gpio_chip___4 gpio_chip;
	struct pinctrl_gpio_range___2 gpio_range;
	spinlock_t lock;
};

enum pin_type {
	GLOBAL_CTRL_PIN = 0,
	COMMON_PIN = 1,
	MISC_PIN = 2,
};

struct sprd_pins_info {
	const char *name;
	unsigned int num;
	enum pin_type type;
	long unsigned int bit_offset;
	long unsigned int bit_width;
	unsigned int reg;
};

enum pin_sleep_mode {
	AP_SLEEP = 1,
	PUBCP_SLEEP = 2,
	TGLDSP_SLEEP = 4,
	AGDSP_SLEEP = 8,
	CM4_SLEEP = 16,
};

enum pin_func_sel {
	PIN_FUNC_1 = 0,
	PIN_FUNC_2 = 1,
	PIN_FUNC_3 = 2,
	PIN_FUNC_4 = 3,
	PIN_FUNC_MAX = 4,
};

struct sprd_pin {
	const char *name;
	unsigned int number;
	enum pin_type type;
	long unsigned int reg;
	long unsigned int bit_offset;
	long unsigned int bit_width;
};

struct sprd_pin_group {
	const char *name;
	unsigned int npins;
	unsigned int *pins;
};

struct sprd_pinctrl_soc_info {
	struct sprd_pin_group *groups;
	unsigned int ngroups;
	struct sprd_pin *pins;
	unsigned int npins;
	const char **grp_names;
};

struct sprd_pinctrl {
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctl;
	void *base;
	struct sprd_pinctrl_soc_info *info;
};

enum sprd_sc9860_pins {
	SC9860_VIO28_0_IRTE = 2832,
	SC9860_VIO_SD2_IRTE = 1051152,
	SC9860_VIO_SD0_IRTE = 2099472,
	SC9860_VIO_SIM2_IRTE = 3147792,
	SC9860_VIO_SIM1_IRTE = 4196112,
	SC9860_VIO_SIM0_IRTE = 5244432,
	SC9860_VIO28_0_MS = 6292752,
	SC9860_VIO_SD2_MS = 7341072,
	SC9860_VIO_SD0_MS = 8389392,
	SC9860_VIO_SIM2_MS = 9437712,
	SC9860_VIO_SIM1_MS = 10486032,
	SC9860_VIO_SIM0_MS = 11534352,
	SC9860_SPSPI_PIN_IN_SEL = 12590866,
	SC9860_UART1_USB30_PHY_SEL = 13639186,
	SC9860_USB30_PHY_DM_OE = 14687506,
	SC9860_USB30_PHY_DP_OE = 15735826,
	SC9860_UART5_SYS_SEL = 16783666,
	SC9860_ORP_URXD_PIN_IN_SEL = 17831954,
	SC9860_SIM2_SYS_SEL = 18880274,
	SC9860_SIM1_SYS_SEL = 19928594,
	SC9860_SIM0_SYS_SEL = 20976914,
	SC9860_CLK26MHZ_BUF_OUT_SEL = 22025234,
	SC9860_UART4_SYS_SEL = 23072818,
	SC9860_UART3_SYS_SEL = 24120626,
	SC9860_UART2_SYS_SEL = 25168434,
	SC9860_UART1_SYS_SEL = 26216242,
	SC9860_UART0_SYS_SEL = 27264050,
	SC9860_UART24_LOOP_SEL = 28312338,
	SC9860_UART23_LOOP_SEL = 29360658,
	SC9860_UART14_LOOP_SEL = 30408978,
	SC9860_UART13_LOOP_SEL = 31457298,
	SC9860_IIS3_SYS_SEL = 32510531,
	SC9860_IIS2_SYS_SEL = 33558083,
	SC9860_IIS1_SYS_SEL = 34605635,
	SC9860_IIS0_SYS_SEL = 35653187,
	SC9860_IIS23_LOOP_SEL = 36701459,
	SC9860_IIS13_LOOP_SEL = 37749779,
	SC9860_IIS12_LOOP_SEL = 38798099,
	SC9860_IIS03_LOOP_SEL = 39846419,
	SC9860_IIS02_LOOP_SEL = 40894739,
	SC9860_IIS01_LOOP_SEL = 41943059,
	SC9860_IIS6_SYS_SEL = 42998596,
	SC9860_IIS5_SYS_SEL = 44046148,
	SC9860_IIS4_SYS_SEL = 45093700,
	SC9860_I2C_INF6_SYS_SEL = 46139428,
	SC9860_I2C_INF4_SYS_SEL = 47187492,
	SC9860_I2C_INF2_SYS_SEL = 48235556,
	SC9860_I2C_INF1_SYS_SEL = 49283620,
	SC9860_I2C_INF0_SYS_SEL = 50331684,
	SC9860_GPIO_INF7_SYS_SEL = 51387157,
	SC9860_GPIO_INF6_SYS_SEL = 52435477,
	SC9860_GPIO_INF5_SYS_SEL = 53483797,
	SC9860_GPIO_INF4_SYS_SEL = 54532117,
	SC9860_GPIO_INF3_SYS_SEL = 55580437,
	SC9860_GPIO_INF2_SYS_SEL = 56628757,
	SC9860_GPIO_INF1_SYS_SEL = 57677077,
	SC9860_GPIO_INF0_SYS_SEL = 58725397,
	SC9860_WDRST_OUT_SEL = 59772981,
	SC9860_ADI_SYNC_PIN_OUT_SEL = 60821013,
	SC9860_CMRST_SEL = 61869333,
	SC9860_CMPD_SEL = 62917653,
	SC9860_TEST_DBG_MODE11 = 63965973,
	SC9860_TEST_DBG_MODE10 = 65014293,
	SC9860_TEST_DBG_MODE9 = 66062613,
	SC9860_TEST_DBG_MODE8 = 67110933,
	SC9860_TEST_DBG_MODE7 = 68159253,
	SC9860_TEST_DBG_MODE6 = 69207573,
	SC9860_TEST_DBG_MODE5 = 70255893,
	SC9860_TEST_DBG_MODE4 = 71304213,
	SC9860_TEST_DBG_MODE3 = 72352533,
	SC9860_TEST_DBG_MODE2 = 73400853,
	SC9860_TEST_DBG_MODE1 = 74449173,
	SC9860_TEST_DBG_MODE0 = 75497493,
	SC9860_SP_EIC_DPAD3_SEL = 76552326,
	SC9860_SP_EIC_DPAD2_SEL = 77598854,
	SC9860_SP_EIC_DPAD1_SEL = 78645382,
	SC9860_SP_EIC_DPAD0_SEL = 79691910,
	SC9860_SP_EIC_DPAD7_SEL = 80746631,
	SC9860_SP_EIC_DPAD6_SEL = 81793159,
	SC9860_SP_EIC_DPAD5_SEL = 82839687,
	SC9860_SP_EIC_DPAD4_SEL = 83886215,
	SC9860_RFCTL20 = 85000192,
	SC9860_RFCTL21 = 87097344,
	SC9860_RFCTL30 = 89194496,
	SC9860_RFCTL31 = 91291648,
	SC9860_RFCTL32 = 93388800,
	SC9860_RFCTL33 = 95485952,
	SC9860_RFCTL34 = 97583104,
	SC9860_RFCTL35 = 99680256,
	SC9860_RFCTL36 = 101777408,
	SC9860_RFCTL37 = 103874560,
	SC9860_RFCTL22 = 105971712,
	SC9860_RFCTL23 = 108068864,
	SC9860_RFCTL24 = 110166016,
	SC9860_RFCTL25 = 112263168,
	SC9860_RFCTL26 = 114360320,
	SC9860_RFCTL27 = 116457472,
	SC9860_RFCTL28 = 118554624,
	SC9860_RFCTL29 = 120651776,
	SC9860_SCL2 = 122748928,
	SC9860_SDA2 = 124846080,
	SC9860_MTCK_ARM = 126943232,
	SC9860_MTMS_ARM = 129040384,
	SC9860_XTL_EN0 = 131137536,
	SC9860_PTEST = 133234688,
	SC9860_AUD_DAD1 = 135331840,
	SC9860_AUD_ADD0 = 137428992,
	SC9860_AUD_ADSYNC = 139526144,
	SC9860_AUD_SCLK = 141623296,
	SC9860_CHIP_SLEEP = 143720448,
	SC9860_CLK_32K = 145817600,
	SC9860_DCDC_ARM_EN = 147914752,
	SC9860_EXT_RST_B = 150011904,
	SC9860_ADI_D = 152109056,
	SC9860_ADI_SCLK = 154206208,
	SC9860_XTL_EN1 = 156303360,
	SC9860_ANA_INT = 158400512,
	SC9860_AUD_DAD0 = 160497664,
	SC9860_AUD_DASYNC = 162594816,
	SC9860_LCM_RSTN = 164691968,
	SC9860_DSI_TE = 166789120,
	SC9860_PWMA = 168886272,
	SC9860_EXTINT0 = 170983424,
	SC9860_EXTINT1 = 173080576,
	SC9860_SDA1 = 175177728,
	SC9860_SCL1 = 177274880,
	SC9860_SIMCLK2 = 179372032,
	SC9860_SIMDA2 = 181469184,
	SC9860_SIMRST2 = 183566336,
	SC9860_SIMCLK1 = 185663488,
	SC9860_SIMDA1 = 187760640,
	SC9860_SIMRST1 = 189857792,
	SC9860_SIMCLK0 = 191954944,
	SC9860_SIMDA0 = 194052096,
	SC9860_SIMRST0 = 196149248,
	SC9860_SD2_CMD = 198246400,
	SC9860_SD2_D0 = 200343552,
	SC9860_SD2_D1 = 202440704,
	SC9860_SD2_CLK = 204537856,
	SC9860_SD2_D2 = 206635008,
	SC9860_SD2_D3 = 208732160,
	SC9860_SD0_D3 = 210829312,
	SC9860_SD0_D2 = 212926464,
	SC9860_SD0_CMD = 215023616,
	SC9860_SD0_D0 = 217120768,
	SC9860_SD0_D1 = 219217920,
	SC9860_SD0_CLK = 221315072,
	SC9860_EMMC_CMD_reserved = 223412224,
	SC9860_EMMC_CMD = 225509376,
	SC9860_EMMC_D6 = 227606528,
	SC9860_EMMC_D7 = 229703680,
	SC9860_EMMC_CLK = 231800832,
	SC9860_EMMC_D5 = 233897984,
	SC9860_EMMC_D4 = 235995136,
	SC9860_EMMC_DS = 238092288,
	SC9860_EMMC_D3_reserved = 240189440,
	SC9860_EMMC_D3 = 242286592,
	SC9860_EMMC_RST = 244383744,
	SC9860_EMMC_D1 = 246480896,
	SC9860_EMMC_D2 = 248578048,
	SC9860_EMMC_D0 = 250675200,
	SC9860_IIS0DI = 252772352,
	SC9860_IIS0DO = 254869504,
	SC9860_IIS0CLK = 256966656,
	SC9860_IIS0LRCK = 259063808,
	SC9860_SD1_CLK = 261160960,
	SC9860_SD1_CMD = 263258112,
	SC9860_SD1_D0 = 265355264,
	SC9860_SD1_D1 = 267452416,
	SC9860_SD1_D2 = 269549568,
	SC9860_SD1_D3 = 271646720,
	SC9860_CLK_AUX0 = 273743872,
	SC9860_WIFI_COEXIST = 275841024,
	SC9860_BEIDOU_COEXIST = 277938176,
	SC9860_U3TXD = 280035328,
	SC9860_U3RXD = 282132480,
	SC9860_U3CTS = 284229632,
	SC9860_U3RTS = 286326784,
	SC9860_U0TXD = 288423936,
	SC9860_U0RXD = 290521088,
	SC9860_U0CTS = 292618240,
	SC9860_U0RTS = 294715392,
	SC9860_IIS1DI = 296812544,
	SC9860_IIS1DO = 298909696,
	SC9860_IIS1CLK = 301006848,
	SC9860_IIS1LRCK = 303104000,
	SC9860_SPI0_CSN = 305201152,
	SC9860_SPI0_DO = 307298304,
	SC9860_SPI0_DI = 309395456,
	SC9860_SPI0_CLK = 311492608,
	SC9860_U2TXD = 313589760,
	SC9860_U2RXD = 315686912,
	SC9860_U4TXD = 317784064,
	SC9860_U4RXD = 319881216,
	SC9860_CMMCLK1 = 321978368,
	SC9860_CMRST1 = 324075520,
	SC9860_CMMCLK0 = 326172672,
	SC9860_CMRST0 = 328269824,
	SC9860_CMPD0 = 330366976,
	SC9860_CMPD1 = 332464128,
	SC9860_SCL0 = 334561280,
	SC9860_SDA0 = 336658432,
	SC9860_SDA6 = 338755584,
	SC9860_SCL6 = 340852736,
	SC9860_U1TXD = 342949888,
	SC9860_U1RXD = 345047040,
	SC9860_KEYOUT0 = 347144192,
	SC9860_KEYOUT1 = 349241344,
	SC9860_KEYOUT2 = 351338496,
	SC9860_KEYIN0 = 353435648,
	SC9860_KEYIN1 = 355532800,
	SC9860_KEYIN2 = 357629952,
	SC9860_IIS3DI = 359727104,
	SC9860_IIS3DO = 361824256,
	SC9860_IIS3CLK = 363921408,
	SC9860_IIS3LRCK = 366018560,
	SC9860_RFCTL0 = 368115712,
	SC9860_RFCTL1 = 370212864,
	SC9860_RFCTL10 = 372310016,
	SC9860_RFCTL11 = 374407168,
	SC9860_RFCTL12 = 376504320,
	SC9860_RFCTL13 = 378601472,
	SC9860_RFCTL14 = 380698624,
	SC9860_RFCTL15 = 382795776,
	SC9860_RFCTL16 = 384892928,
	SC9860_RFCTL17 = 386990080,
	SC9860_RFCTL18 = 389087232,
	SC9860_RFCTL19 = 391184384,
	SC9860_RFCTL2 = 393281536,
	SC9860_EXTINT5 = 395378688,
	SC9860_EXTINT6 = 397475840,
	SC9860_EXTINT7 = 399572992,
	SC9860_GPIO30 = 401670144,
	SC9860_GPIO31 = 403767296,
	SC9860_GPIO32 = 405864448,
	SC9860_GPIO33 = 407961600,
	SC9860_GPIO34 = 410058752,
	SC9860_RFCTL3 = 412155904,
	SC9860_RFCTL4 = 414253056,
	SC9860_RFCTL5 = 416350208,
	SC9860_RFCTL6 = 418447360,
	SC9860_RFCTL7 = 420544512,
	SC9860_RFCTL8 = 422641664,
	SC9860_RFCTL9 = 424738816,
	SC9860_RFFE0_SCK0 = 426835968,
	SC9860_GPIO38 = 428933120,
	SC9860_RFFE0_SDA0 = 431030272,
	SC9860_GPIO39 = 433127424,
	SC9860_RFFE1_SCK0 = 435224576,
	SC9860_GPIO181 = 437321728,
	SC9860_RFFE1_SDA0 = 439418880,
	SC9860_GPIO182 = 441516032,
	SC9860_RF_LVDS0_ADC_ON = 443613184,
	SC9860_RF_LVDS0_DAC_ON = 445710336,
	SC9860_RFSCK0 = 447807488,
	SC9860_RFSDA0 = 449904640,
	SC9860_RFSEN0 = 452001792,
	SC9860_RF_LVDS1_ADC_ON = 454098944,
	SC9860_RF_LVDS1_DAC_ON = 456196096,
	SC9860_RFSCK1 = 458293248,
	SC9860_RFSDA1 = 460390400,
	SC9860_RFSEN1 = 462487552,
	SC9860_RFCTL38 = 464584704,
	SC9860_RFCTL39 = 466681856,
	SC9860_RFCTL20_MISC = 86114304,
	SC9860_RFCTL21_MISC = 88211456,
	SC9860_RFCTL30_MISC = 90308608,
	SC9860_RFCTL31_MISC = 92405760,
	SC9860_RFCTL32_MISC = 94502912,
	SC9860_RFCTL33_MISC = 96600064,
	SC9860_RFCTL34_MISC = 98697216,
	SC9860_RFCTL35_MISC = 100794368,
	SC9860_RFCTL36_MISC = 102891520,
	SC9860_RFCTL37_MISC = 104988672,
	SC9860_RFCTL22_MISC = 107085824,
	SC9860_RFCTL23_MISC = 109182976,
	SC9860_RFCTL24_MISC = 111280128,
	SC9860_RFCTL25_MISC = 113377280,
	SC9860_RFCTL26_MISC = 115474432,
	SC9860_RFCTL27_MISC = 117571584,
	SC9860_RFCTL28_MISC = 119668736,
	SC9860_RFCTL29_MISC = 121765888,
	SC9860_SCL2_MISC = 123863040,
	SC9860_SDA2_MISC = 125960192,
	SC9860_MTCK_ARM_MISC = 128057344,
	SC9860_MTMS_ARM_MISC = 130154496,
	SC9860_XTL_EN0_MISC = 132251648,
	SC9860_PTEST_MISC = 134348800,
	SC9860_AUD_DAD1_MISC = 136445952,
	SC9860_AUD_ADD0_MISC = 138543104,
	SC9860_AUD_ADSYNC_MISC = 140640256,
	SC9860_AUD_SCLK_MISC = 142737408,
	SC9860_CHIP_SLEEP_MISC = 144834560,
	SC9860_CLK_32K_MISC = 146931712,
	SC9860_DCDC_ARM_EN_MISC = 149028864,
	SC9860_EXT_RST_B_MISC = 151126016,
	SC9860_ADI_D_MISC = 153223168,
	SC9860_ADI_SCLK_MISC = 155320320,
	SC9860_XTL_EN1_MISC = 157417472,
	SC9860_ANA_INT_MISC = 159514624,
	SC9860_AUD_DAD0_MISC = 161611776,
	SC9860_AUD_DASYNC_MISC = 163708928,
	SC9860_LCM_RSTN_MISC = 165806080,
	SC9860_DSI_TE_MISC = 167903232,
	SC9860_PWMA_MISC = 170000384,
	SC9860_EXTINT0_MISC = 172097536,
	SC9860_EXTINT1_MISC = 174194688,
	SC9860_SDA1_MISC = 176291840,
	SC9860_SCL1_MISC = 178388992,
	SC9860_SIMCLK2_MISC = 180486144,
	SC9860_SIMDA2_MISC = 182583296,
	SC9860_SIMRST2_MISC = 184680448,
	SC9860_SIMCLK1_MISC = 186777600,
	SC9860_SIMDA1_MISC = 188874752,
	SC9860_SIMRST1_MISC = 190971904,
	SC9860_SIMCLK0_MISC = 193069056,
	SC9860_SIMDA0_MISC = 195166208,
	SC9860_SIMRST0_MISC = 197263360,
	SC9860_SD2_CMD_MISC = 199360512,
	SC9860_SD2_D0_MISC = 201457664,
	SC9860_SD2_D1_MISC = 203554816,
	SC9860_SD2_CLK_MISC = 205651968,
	SC9860_SD2_D2_MISC = 207749120,
	SC9860_SD2_D3_MISC = 209846272,
	SC9860_SD0_D3_MISC = 211943424,
	SC9860_SD0_D2_MISC = 214040576,
	SC9860_SD0_CMD_MISC = 216137728,
	SC9860_SD0_D0_MISC = 218234880,
	SC9860_SD0_D1_MISC = 220332032,
	SC9860_SD0_CLK_MISC = 222429184,
	SC9860_EMMC_CMD_reserved_MISC = 224526336,
	SC9860_EMMC_CMD_MISC = 226623488,
	SC9860_EMMC_D6_MISC = 228720640,
	SC9860_EMMC_D7_MISC = 230817792,
	SC9860_EMMC_CLK_MISC = 232914944,
	SC9860_EMMC_D5_MISC = 235012096,
	SC9860_EMMC_D4_MISC = 237109248,
	SC9860_EMMC_DS_MISC = 239206400,
	SC9860_EMMC_D3_reserved_MISC = 241303552,
	SC9860_EMMC_D3_MISC = 243400704,
	SC9860_EMMC_RST_MISC = 245497856,
	SC9860_EMMC_D1_MISC = 247595008,
	SC9860_EMMC_D2_MISC = 249692160,
	SC9860_EMMC_D0_MISC = 251789312,
	SC9860_IIS0DI_MISC = 253886464,
	SC9860_IIS0DO_MISC = 255983616,
	SC9860_IIS0CLK_MISC = 258080768,
	SC9860_IIS0LRCK_MISC = 260177920,
	SC9860_SD1_CLK_MISC = 262275072,
	SC9860_SD1_CMD_MISC = 264372224,
	SC9860_SD1_D0_MISC = 266469376,
	SC9860_SD1_D1_MISC = 268566528,
	SC9860_SD1_D2_MISC = 270663680,
	SC9860_SD1_D3_MISC = 272760832,
	SC9860_CLK_AUX0_MISC = 274857984,
	SC9860_WIFI_COEXIST_MISC = 276955136,
	SC9860_BEIDOU_COEXIST_MISC = 279052288,
	SC9860_U3TXD_MISC = 281149440,
	SC9860_U3RXD_MISC = 283246592,
	SC9860_U3CTS_MISC = 285343744,
	SC9860_U3RTS_MISC = 287440896,
	SC9860_U0TXD_MISC = 289538048,
	SC9860_U0RXD_MISC = 291635200,
	SC9860_U0CTS_MISC = 293732352,
	SC9860_U0RTS_MISC = 295829504,
	SC9860_IIS1DI_MISC = 297926656,
	SC9860_IIS1DO_MISC = 300023808,
	SC9860_IIS1CLK_MISC = 302120960,
	SC9860_IIS1LRCK_MISC = 304218112,
	SC9860_SPI0_CSN_MISC = 306315264,
	SC9860_SPI0_DO_MISC = 308412416,
	SC9860_SPI0_DI_MISC = 310509568,
	SC9860_SPI0_CLK_MISC = 312606720,
	SC9860_U2TXD_MISC = 314703872,
	SC9860_U2RXD_MISC = 316801024,
	SC9860_U4TXD_MISC = 318898176,
	SC9860_U4RXD_MISC = 320995328,
	SC9860_CMMCLK1_MISC = 323092480,
	SC9860_CMRST1_MISC = 325189632,
	SC9860_CMMCLK0_MISC = 327286784,
	SC9860_CMRST0_MISC = 329383936,
	SC9860_CMPD0_MISC = 331481088,
	SC9860_CMPD1_MISC = 333578240,
	SC9860_SCL0_MISC = 335675392,
	SC9860_SDA0_MISC = 337772544,
	SC9860_SDA6_MISC = 339869696,
	SC9860_SCL6_MISC = 341966848,
	SC9860_U1TXD_MISC = 344064000,
	SC9860_U1RXD_MISC = 346161152,
	SC9860_KEYOUT0_MISC = 348258304,
	SC9860_KEYOUT1_MISC = 350355456,
	SC9860_KEYOUT2_MISC = 352452608,
	SC9860_KEYIN0_MISC = 354549760,
	SC9860_KEYIN1_MISC = 356646912,
	SC9860_KEYIN2_MISC = 358744064,
	SC9860_IIS3DI_MISC = 360841216,
	SC9860_IIS3DO_MISC = 362938368,
	SC9860_IIS3CLK_MISC = 365035520,
	SC9860_IIS3LRCK_MISC = 367132672,
	SC9860_RFCTL0_MISC = 369229824,
	SC9860_RFCTL1_MISC = 371326976,
	SC9860_RFCTL10_MISC = 373424128,
	SC9860_RFCTL11_MISC = 375521280,
	SC9860_RFCTL12_MISC = 377618432,
	SC9860_RFCTL13_MISC = 379715584,
	SC9860_RFCTL14_MISC = 381812736,
	SC9860_RFCTL15_MISC = 383909888,
	SC9860_RFCTL16_MISC = 386007040,
	SC9860_RFCTL17_MISC = 388104192,
	SC9860_RFCTL18_MISC = 390201344,
	SC9860_RFCTL19_MISC = 392298496,
	SC9860_RFCTL2_MISC = 394395648,
	SC9860_EXTINT5_MISC = 396492800,
	SC9860_EXTINT6_MISC = 398589952,
	SC9860_EXTINT7_MISC = 400687104,
	SC9860_GPIO30_MISC = 402784256,
	SC9860_GPIO31_MISC = 404881408,
	SC9860_GPIO32_MISC = 406978560,
	SC9860_GPIO33_MISC = 409075712,
	SC9860_GPIO34_MISC = 411172864,
	SC9860_RFCTL3_MISC = 413270016,
	SC9860_RFCTL4_MISC = 415367168,
	SC9860_RFCTL5_MISC = 417464320,
	SC9860_RFCTL6_MISC = 419561472,
	SC9860_RFCTL7_MISC = 421658624,
	SC9860_RFCTL8_MISC = 423755776,
	SC9860_RFCTL9_MISC = 425852928,
	SC9860_RFFE0_SCK0_MISC = 427950080,
	SC9860_GPIO38_MISC = 430047232,
	SC9860_RFFE0_SDA0_MISC = 432144384,
	SC9860_GPIO39_MISC = 434241536,
	SC9860_RFFE1_SCK0_MISC = 436338688,
	SC9860_GPIO181_MISC = 438435840,
	SC9860_RFFE1_SDA0_MISC = 440532992,
	SC9860_GPIO182_MISC = 442630144,
	SC9860_RF_LVDS0_ADC_ON_MISC = 444727296,
	SC9860_RF_LVDS0_DAC_ON_MISC = 446824448,
	SC9860_RFSCK0_MISC = 448921600,
	SC9860_RFSDA0_MISC = 451018752,
	SC9860_RFSEN0_MISC = 453115904,
	SC9860_RF_LVDS1_ADC_ON_MISC = 455213056,
	SC9860_RF_LVDS1_DAC_ON_MISC = 457310208,
	SC9860_RFSCK1_MISC = 459407360,
	SC9860_RFSDA1_MISC = 461504512,
	SC9860_RFSEN1_MISC = 463601664,
	SC9860_RFCTL38_MISC = 465698816,
	SC9860_RFCTL39_MISC = 467795968,
};

enum sunxi_desc_bias_voltage {
	BIAS_VOLTAGE_NONE = 0,
	BIAS_VOLTAGE_GRP_CONFIG = 1,
	BIAS_VOLTAGE_PIO_POW_MODE_SEL = 2,
};

struct sunxi_desc_function {
	long unsigned int variant;
	const char *name;
	u8 muxval;
	u8 irqbank;
	u8 irqnum;
};

struct sunxi_desc_pin {
	struct pinctrl_pin_desc pin;
	long unsigned int variant;
	struct sunxi_desc_function *functions;
};

struct sunxi_pinctrl_desc {
	const struct sunxi_desc_pin *pins;
	int npins;
	unsigned int pin_base;
	unsigned int irq_banks;
	const unsigned int *irq_bank_map;
	bool irq_read_needs_mux;
	bool disable_strict_mode;
	enum sunxi_desc_bias_voltage io_bias_cfg_variant;
};

struct sunxi_pinctrl_function {
	const char *name;
	const char **groups;
	unsigned int ngroups;
};

struct sunxi_pinctrl_group {
	const char *name;
	unsigned int pin;
};

struct sunxi_pinctrl_regulator {
	struct regulator *regulator;
	refcount_t refcount;
};

struct sunxi_pinctrl {
	void *membase;
	struct gpio_chip___4 *chip;
	const struct sunxi_pinctrl_desc *desc;
	struct device___144 *dev;
	struct sunxi_pinctrl_regulator regulators[9];
	struct irq_domain___25 *domain;
	struct sunxi_pinctrl_function *functions;
	unsigned int nfunctions;
	struct sunxi_pinctrl_group *groups;
	unsigned int ngroups;
	int *irq;
	unsigned int *irq_array;
	raw_spinlock_t lock;
	struct pinctrl_dev___6 *pctl_dev;
	long unsigned int variant;
};

struct mtk_eint_regs {
	unsigned int stat;
	unsigned int ack;
	unsigned int mask;
	unsigned int mask_set;
	unsigned int mask_clr;
	unsigned int sens;
	unsigned int sens_set;
	unsigned int sens_clr;
	unsigned int soft;
	unsigned int soft_set;
	unsigned int soft_clr;
	unsigned int pol;
	unsigned int pol_set;
	unsigned int pol_clr;
	unsigned int dom_en;
	unsigned int dbnc_ctrl;
	unsigned int dbnc_set;
	unsigned int dbnc_clr;
};

struct mtk_eint_hw {
	u8 port_mask;
	u8 ports;
	unsigned int ap_num;
	unsigned int db_cnt;
};

struct mtk_eint_xt {
	int (*get_gpio_n)(void *, long unsigned int, unsigned int *, struct gpio_chip___5 **);
	int (*get_gpio_state)(void *, long unsigned int);
	int (*set_gpio_as_eint)(void *, long unsigned int);
};

struct mtk_eint {
	struct device___145 *dev;
	void *base;
	struct irq_domain___26 *domain;
	int irq;
	int *dual_edge;
	u32 *wake_mask;
	u32 *cur_mask;
	const struct mtk_eint_hw *hw;
	const struct mtk_eint_regs *regs;
	void *pctl;
	const struct mtk_eint_xt *gpio_xlate;
};

struct mtk_desc_function {
	const char *name;
	unsigned char muxval;
};

struct mtk_desc_eint {
	unsigned char eintmux;
	unsigned char eintnum;
};

struct mtk_desc_pin {
	struct pinctrl_pin_desc pin;
	const struct mtk_desc_eint eint;
	const struct mtk_desc_function *functions;
};

struct mtk_pinctrl_group {
	const char *name;
	long unsigned int config;
	unsigned int pin;
};

struct mtk_drv_group_desc {
	unsigned char min_drv;
	unsigned char max_drv;
	unsigned char low_bit;
	unsigned char high_bit;
	unsigned char step;
};

struct mtk_pin_drv_grp {
	short unsigned int pin;
	short unsigned int offset;
	unsigned char bit;
	unsigned char grp;
};

struct mtk_pin_spec_pupd_set_samereg {
	short unsigned int pin;
	short unsigned int offset;
	unsigned char pupd_bit;
	unsigned char r1_bit;
	unsigned char r0_bit;
};

struct mtk_pin_ies_smt_set {
	short unsigned int start;
	short unsigned int end;
	short unsigned int offset;
	unsigned char bit;
};

struct mtk_pinctrl_devdata {
	const struct mtk_desc_pin *pins;
	unsigned int npins;
	const struct mtk_drv_group_desc *grp_desc;
	unsigned int n_grp_cls;
	const struct mtk_pin_drv_grp *pin_drv_grp;
	unsigned int n_pin_drv_grps;
	int (*spec_pull_set)(struct regmap *, unsigned int, unsigned char, bool, unsigned int);
	int (*spec_ies_smt_set)(struct regmap *, unsigned int, unsigned char, int, enum pin_config_param);
	void (*spec_pinmux_set)(struct regmap *, unsigned int, unsigned int);
	void (*spec_dir_set)(unsigned int *, unsigned int);
	unsigned int dir_offset;
	unsigned int ies_offset;
	unsigned int smt_offset;
	unsigned int pullen_offset;
	unsigned int pullsel_offset;
	unsigned int drv_offset;
	unsigned int dout_offset;
	unsigned int din_offset;
	unsigned int pinmux_offset;
	short unsigned int type1_start;
	short unsigned int type1_end;
	unsigned char port_shf;
	unsigned char port_mask;
	unsigned char port_align;
	struct mtk_eint_hw eint_hw;
	struct mtk_eint_regs *eint_regs;
	unsigned int mode_mask;
	unsigned int mode_per_reg;
	unsigned int mode_shf;
};

struct mtk_pinctrl {
	struct regmap *regmap1;
	struct regmap *regmap2;
	struct pinctrl_desc___8 pctl_desc;
	struct device___145 *dev;
	struct gpio_chip___5 *chip;
	struct mtk_pinctrl_group *groups;
	unsigned int ngroups;
	const char **grp_names;
	struct pinctrl_dev___7 *pctl_dev;
	const struct mtk_pinctrl_devdata *devdata;
	struct mtk_eint *eint;
};

struct mtk_eint_xt___2 {
	int (*get_gpio_n)(void *, long unsigned int, unsigned int *, struct gpio_chip___4 **);
	int (*get_gpio_state)(void *, long unsigned int);
	int (*set_gpio_as_eint)(void *, long unsigned int);
};

struct mtk_eint___2 {
	struct device___144 *dev;
	void *base;
	struct irq_domain___25 *domain;
	int irq;
	int *dual_edge;
	u32 *wake_mask;
	u32 *cur_mask;
	const struct mtk_eint_hw *hw;
	const struct mtk_eint_regs *regs;
	void *pctl;
	const struct mtk_eint_xt___2 *gpio_xlate;
};

enum {
	PINCTRL_PIN_REG_MODE = 0,
	PINCTRL_PIN_REG_DIR = 1,
	PINCTRL_PIN_REG_DI = 2,
	PINCTRL_PIN_REG_DO = 3,
	PINCTRL_PIN_REG_SR = 4,
	PINCTRL_PIN_REG_SMT = 5,
	PINCTRL_PIN_REG_PD = 6,
	PINCTRL_PIN_REG_PU = 7,
	PINCTRL_PIN_REG_E4 = 8,
	PINCTRL_PIN_REG_E8 = 9,
	PINCTRL_PIN_REG_TDSEL = 10,
	PINCTRL_PIN_REG_RDSEL = 11,
	PINCTRL_PIN_REG_DRV = 12,
	PINCTRL_PIN_REG_PUPD = 13,
	PINCTRL_PIN_REG_R0 = 14,
	PINCTRL_PIN_REG_R1 = 15,
	PINCTRL_PIN_REG_IES = 16,
	PINCTRL_PIN_REG_PULLEN = 17,
	PINCTRL_PIN_REG_PULLSEL = 18,
	PINCTRL_PIN_REG_DRV_EN = 19,
	PINCTRL_PIN_REG_DRV_E0 = 20,
	PINCTRL_PIN_REG_DRV_E1 = 21,
	PINCTRL_PIN_REG_DRV_ADV = 22,
	PINCTRL_PIN_REG_MAX = 23,
};

enum {
	DRV_FIXED = 0,
	DRV_GRP0 = 1,
	DRV_GRP1 = 2,
	DRV_GRP2 = 3,
	DRV_GRP3 = 4,
	DRV_GRP4 = 5,
	DRV_GRP_MAX = 6,
};

struct mtk_pin_field {
	u8 index;
	u32 offset;
	u32 mask;
	u8 bitpos;
	u8 next;
};

struct mtk_pin_field_calc {
	u16 s_pin;
	u16 e_pin;
	u8 i_base;
	u32 s_addr;
	u8 x_addrs;
	u8 s_bit;
	u8 x_bits;
	u8 sz_reg;
	u8 fixed;
};

struct mtk_pin_reg_calc {
	const struct mtk_pin_field_calc *range;
	unsigned int nranges;
};

struct mtk_func_desc {
	const char *name;
	u8 muxval;
};

struct mtk_eint_desc {
	u16 eint_m;
	u16 eint_n;
};

struct mtk_pin_desc {
	unsigned int number;
	const char *name;
	struct mtk_eint_desc eint;
	u8 drv_n;
	struct mtk_func_desc *funcs;
};

struct group_desc___2;

struct function_desc___2;

struct mtk_pinctrl___2;

struct mtk_pin_soc {
	const struct mtk_pin_reg_calc *reg_cal;
	const struct mtk_pin_desc *pins;
	unsigned int npins;
	const struct group_desc___2 *grps;
	unsigned int ngrps;
	const struct function_desc___2 *funcs;
	unsigned int nfuncs;
	const struct mtk_eint_regs *eint_regs;
	const struct mtk_eint_hw *eint_hw;
	u8 gpio_m;
	bool ies_present;
	const char * const *base_names;
	unsigned int nbase_names;
	int (*bias_disable_set)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *);
	int (*bias_disable_get)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, int *);
	int (*bias_set)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, bool);
	int (*bias_get)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, bool, int *);
	int (*bias_set_combo)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, u32, u32);
	int (*bias_get_combo)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, u32 *, u32 *);
	int (*drive_set)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, u32);
	int (*drive_get)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, int *);
	int (*adv_pull_set)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, bool, u32);
	int (*adv_pull_get)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, bool, u32 *);
	int (*adv_drive_set)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, u32);
	int (*adv_drive_get)(struct mtk_pinctrl___2 *, const struct mtk_pin_desc *, u32 *);
	void *driver_data;
};

struct mtk_pinctrl___2 {
	struct pinctrl_dev___4 *pctrl;
	void **base;
	u8 nbase;
	struct device___144 *dev;
	struct gpio_chip___4 chip;
	const struct mtk_pin_soc *soc;
	struct mtk_eint___2 *eint;
	struct mtk_pinctrl_group *groups;
	const char **grp_names;
	spinlock_t lock;
};

struct mtk_drive_desc {
	u8 min;
	u8 max;
	u8 step;
	u8 scal;
};

struct mtk_pinctrl___3;

struct mtk_pin_soc___2 {
	const struct mtk_pin_reg_calc *reg_cal;
	const struct mtk_pin_desc *pins;
	unsigned int npins;
	const struct group_desc *grps;
	unsigned int ngrps;
	const struct function_desc *funcs;
	unsigned int nfuncs;
	const struct mtk_eint_regs *eint_regs;
	const struct mtk_eint_hw *eint_hw;
	u8 gpio_m;
	bool ies_present;
	const char * const *base_names;
	unsigned int nbase_names;
	int (*bias_disable_set)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *);
	int (*bias_disable_get)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, int *);
	int (*bias_set)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, bool);
	int (*bias_get)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, bool, int *);
	int (*bias_set_combo)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, u32, u32);
	int (*bias_get_combo)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, u32 *, u32 *);
	int (*drive_set)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, u32);
	int (*drive_get)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, int *);
	int (*adv_pull_set)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, bool, u32);
	int (*adv_pull_get)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, bool, u32 *);
	int (*adv_drive_set)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, u32);
	int (*adv_drive_get)(struct mtk_pinctrl___3 *, const struct mtk_pin_desc *, u32 *);
	void *driver_data;
};

struct mtk_pinctrl___3 {
	struct pinctrl_dev___6 *pctrl;
	void **base;
	u8 nbase;
	struct device___144 *dev;
	struct gpio_chip___4 chip;
	const struct mtk_pin_soc___2 *soc;
	struct mtk_eint___2 *eint;
	struct mtk_pinctrl_group *groups;
	const char **grp_names;
	spinlock_t lock;
};

struct mtk_pinctrl___4;

struct mtk_pin_soc___3 {
	const struct mtk_pin_reg_calc *reg_cal;
	const struct mtk_pin_desc *pins;
	unsigned int npins;
	const struct group_desc *grps;
	unsigned int ngrps;
	const struct function_desc *funcs;
	unsigned int nfuncs;
	const struct mtk_eint_regs *eint_regs;
	const struct mtk_eint_hw *eint_hw;
	u8 gpio_m;
	bool ies_present;
	const char * const *base_names;
	unsigned int nbase_names;
	int (*bias_disable_set)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *);
	int (*bias_disable_get)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, int *);
	int (*bias_set)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, bool);
	int (*bias_get)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, bool, int *);
	int (*bias_set_combo)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, u32, u32);
	int (*bias_get_combo)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, u32 *, u32 *);
	int (*drive_set)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, u32);
	int (*drive_get)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, int *);
	int (*adv_pull_set)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, bool, u32);
	int (*adv_pull_get)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, bool, u32 *);
	int (*adv_drive_set)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, u32);
	int (*adv_drive_get)(struct mtk_pinctrl___4 *, const struct mtk_pin_desc *, u32 *);
	void *driver_data;
};

struct mtk_pinctrl___4 {
	struct pinctrl_dev___7 *pctrl;
	void **base;
	u8 nbase;
	struct device___145 *dev;
	struct gpio_chip___5 chip;
	const struct mtk_pin_soc___3 *soc;
	struct mtk_eint *eint;
	struct mtk_pinctrl_group *groups;
	const char **grp_names;
	spinlock_t lock;
};

struct mt6397_chip {
	struct device___145 *dev;
	struct regmap *regmap;
	struct notifier_block pm_nb;
	int irq;
	struct irq_domain___26 *irq_domain;
	struct mutex irqlock;
	u16 wake_mask[2];
	u16 irq_masks_cur[2];
	u16 irq_masks_cache[2];
	u16 int_con[2];
	u16 int_status[2];
	u16 chip_id;
	void *irq_data;
};

struct visconti_desc_pin {
	struct pinctrl_pin_desc pin;
	unsigned int dsel_offset;
	unsigned int dsel_shift;
	unsigned int pude_offset;
	unsigned int pudsel_offset;
	unsigned int pud_shift;
};

struct visconti_mux {
	unsigned int offset;
	unsigned int mask;
	unsigned int val;
};

struct visconti_pin_group {
	const char *name;
	const unsigned int *pins;
	unsigned int nr_pins;
	struct visconti_mux mux;
};

struct visconti_pin_function {
	const char *name;
	const char * const *groups;
	unsigned int nr_groups;
};

struct visconti_pinctrl_devdata {
	const struct visconti_desc_pin *pins;
	unsigned int nr_pins;
	const struct visconti_pin_group *groups;
	unsigned int nr_groups;
	const struct visconti_pin_function *functions;
	unsigned int nr_functions;
	const struct visconti_mux *gpio_mux;
	void (*unlock)(void *);
};

struct visconti_pinctrl {
	void *base;
	struct device___144 *dev;
	struct pinctrl_dev___6 *pctl;
	struct pinctrl_desc___7 pctl_desc;
	const struct visconti_pinctrl_devdata *devdata;
	spinlock_t lock;
};

struct of_phandle_args___14 {
	struct device_node___4 *np;
	int args_count;
	uint32_t args[16];
};

struct gpio_chip___6;

struct pinctrl_gpio_range___4 {
	struct list_head node;
	const char *name;
	unsigned int id;
	unsigned int base;
	unsigned int pin_base;
	unsigned int npins;
	const unsigned int *pins;
	struct gpio_chip___6 *gc;
};

struct gpio_irq_chip___6 {
	struct irq_chip___4 *chip;
	struct irq_domain___4 *domain;
	const struct irq_domain_ops___4 *domain_ops;
	struct fwnode_handle___9 *fwnode;
	struct irq_domain___4 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___6 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___6 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___6 *, unsigned int);
	struct irq_domain_ops___4 child_irq_domain_ops;
	irq_flow_handler_t___4 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___4 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___6 *);
	void (*init_valid_mask)(struct gpio_chip___6 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___4 *);
	void (*irq_disable)(struct irq_data___4 *);
	void (*irq_unmask)(struct irq_data___4 *);
	void (*irq_mask)(struct irq_data___4 *);
};

struct gpio_device___2;

struct gpio_chip___6 {
	const char *label;
	struct gpio_device___2 *gpiodev;
	struct device___9 *parent;
	struct module___14 *owner;
	int (*request)(struct gpio_chip___6 *, unsigned int);
	void (*free)(struct gpio_chip___6 *, unsigned int);
	int (*get_direction)(struct gpio_chip___6 *, unsigned int);
	int (*direction_input)(struct gpio_chip___6 *, unsigned int);
	int (*direction_output)(struct gpio_chip___6 *, unsigned int, int);
	int (*get)(struct gpio_chip___6 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___6 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___6 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___6 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___6 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___6 *, unsigned int);
	void (*dbg_show)(struct seq_file___14 *, struct gpio_chip___6 *);
	int (*init_valid_mask)(struct gpio_chip___6 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___6 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___6 irq;
	long unsigned int *valid_mask;
	struct device_node___4 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___6 *, const struct of_phandle_args___14 *, u32 *);
};

struct gpio_desc___3;

struct gpio_device___2 {
	int id;
	struct device___9 dev;
	struct cdev___6 chrdev;
	struct device___9 *mockdev;
	struct module___14 *owner;
	struct gpio_chip___6 *chip;
	struct gpio_desc___3 *descs;
	int base;
	u16 ngpio;
	const char *label;
	void *data;
	struct list_head list;
	struct blocking_notifier_head notifier;
	struct list_head pin_ranges;
};

struct gpio_pin_range {
	struct list_head node;
	struct pinctrl_dev___4 *pctldev;
	struct pinctrl_gpio_range___4 range;
};

struct gpio_array;

struct gpio_descs {
	struct gpio_array *info;
	unsigned int ndescs;
	struct gpio_desc___3 *desc[0];
};

struct gpio_array {
	struct gpio_desc___3 **desc;
	unsigned int size;
	struct gpio_chip___6 *chip;
	long unsigned int *get_mask;
	long unsigned int *set_mask;
	long unsigned int invert_mask[0];
};

struct gpio_desc___3 {
	struct gpio_device___2 *gdev;
	long unsigned int flags;
	const char *label;
	const char *name;
	struct device_node___4 *hog;
	unsigned int debounce_period_us;
};

enum gpiod_flags {
	GPIOD_ASIS = 0,
	GPIOD_IN = 1,
	GPIOD_OUT_LOW = 3,
	GPIOD_OUT_HIGH = 7,
	GPIOD_OUT_LOW_OPEN_DRAIN = 11,
	GPIOD_OUT_HIGH_OPEN_DRAIN = 15,
};

struct acpi_device___4;

struct acpi_hotplug_profile___4 {
	struct kobject___12 kobj;
	int (*scan_dependent)(struct acpi_device___4 *);
	void (*notify_online)(struct acpi_device___4 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___4 {
	void (*func)(struct acpi_device_wakeup_context___4 *);
	struct device___9 *dev;
};

struct acpi_device_wakeup___4 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___4 context;
	struct wakeup_source___9 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___4;

struct acpi_hotplug_context___4;

struct acpi_driver___4;

struct acpi_device___4 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___9 fwnode;
	struct acpi_device___4 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___4 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___4 *handler;
	struct acpi_hotplug_context___4 *hp;
	struct acpi_driver___4 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___9 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___4 *);
};

struct acpi_scan_handler___4 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___4 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___4 *);
	void (*bind)(struct device___9 *);
	void (*unbind)(struct device___9 *);
	struct acpi_hotplug_profile___4 hotplug;
};

struct acpi_hotplug_context___4 {
	struct acpi_device___4 *self;
	int (*notify)(struct acpi_device___4 *, u32);
	void (*uevent)(struct acpi_device___4 *, u32);
	void (*fixup)(struct acpi_device___4 *);
};

typedef int (*acpi_op_add___4)(struct acpi_device___4 *);

typedef int (*acpi_op_remove___4)(struct acpi_device___4 *);

typedef void (*acpi_op_notify___4)(struct acpi_device___4 *, u32);

struct acpi_device_ops___4 {
	acpi_op_add___4 add;
	acpi_op_remove___4 remove;
	acpi_op_notify___4 notify;
};

struct acpi_driver___4 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___4 ops;
	struct device_driver___9 drv;
	struct module___14 *owner;
};

enum gpio_lookup_flags {
	GPIO_ACTIVE_HIGH = 0,
	GPIO_ACTIVE_LOW = 1,
	GPIO_OPEN_DRAIN = 2,
	GPIO_OPEN_SOURCE = 4,
	GPIO_PERSISTENT = 0,
	GPIO_TRANSITORY = 8,
	GPIO_PULL_UP = 16,
	GPIO_PULL_DOWN = 32,
	GPIO_LOOKUP_FLAGS_DEFAULT = 0,
};

struct gpiod_lookup {
	const char *key;
	u16 chip_hwnum;
	const char *con_id;
	unsigned int idx;
	long unsigned int flags;
};

struct gpiod_lookup_table {
	struct list_head list;
	const char *dev_id;
	struct gpiod_lookup table[0];
};

struct gpiod_hog {
	struct list_head list;
	const char *chip_label;
	u16 chip_hwnum;
	const char *line_name;
	long unsigned int lflags;
	int dflags;
};

enum {
	GPIOLINE_CHANGED_REQUESTED = 1,
	GPIOLINE_CHANGED_RELEASED = 2,
	GPIOLINE_CHANGED_CONFIG = 3,
};

struct acpi_gpio_info {
	struct acpi_device___4 *adev;
	enum gpiod_flags flags;
	bool gpioint;
	int pin_config;
	int polarity;
	int triggering;
	unsigned int debounce;
	unsigned int quirks;
};

struct trace_event_raw_gpio_direction {
	struct trace_entry ent;
	unsigned int gpio;
	int in;
	int err;
	char __data[0];
};

struct trace_event_raw_gpio_value {
	struct trace_entry ent;
	unsigned int gpio;
	int get;
	int value;
	char __data[0];
};

struct trace_event_data_offsets_gpio_direction {};

struct trace_event_data_offsets_gpio_value {};

typedef void (*btf_trace_gpio_direction)(void *, unsigned int, int, int);

typedef void (*btf_trace_gpio_value)(void *, unsigned int, int, int);

typedef void (*dr_release_t___10)(struct device___145 *, void *);

typedef int (*dr_match_t___9)(struct device___145 *, void *, void *);

struct gpio_chip___7;

struct gpio_irq_chip___7 {
	struct irq_chip___27 *chip;
	struct irq_domain___26 *domain;
	const struct irq_domain_ops___26 *domain_ops;
	struct fwnode_handle___145 *fwnode;
	struct irq_domain___26 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___7 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___7 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___7 *, unsigned int);
	struct irq_domain_ops___26 child_irq_domain_ops;
	irq_flow_handler_t___28 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___28 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___7 *);
	void (*init_valid_mask)(struct gpio_chip___7 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___27 *);
	void (*irq_disable)(struct irq_data___27 *);
	void (*irq_unmask)(struct irq_data___27 *);
	void (*irq_mask)(struct irq_data___27 *);
};

struct gpio_device___3;

struct gpio_chip___7 {
	const char *label;
	struct gpio_device___3 *gpiodev;
	struct device___145 *parent;
	struct module___171 *owner;
	int (*request)(struct gpio_chip___7 *, unsigned int);
	void (*free)(struct gpio_chip___7 *, unsigned int);
	int (*get_direction)(struct gpio_chip___7 *, unsigned int);
	int (*direction_input)(struct gpio_chip___7 *, unsigned int);
	int (*direction_output)(struct gpio_chip___7 *, unsigned int, int);
	int (*get)(struct gpio_chip___7 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___7 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___7 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___7 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___7 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___7 *, unsigned int);
	void (*dbg_show)(struct seq_file___163 *, struct gpio_chip___7 *);
	int (*init_valid_mask)(struct gpio_chip___7 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___7 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___7 irq;
	long unsigned int *valid_mask;
	struct device_node___47 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___7 *, const struct of_phandle_args___13 *, u32 *);
};

struct gpio_desc___4;

struct gpio_device___3 {
	int id;
	struct device___145 dev;
	struct cdev___36 chrdev;
	struct device___145 *mockdev;
	struct module___171 *owner;
	struct gpio_chip___7 *chip;
	struct gpio_desc___4 *descs;
	int base;
	u16 ngpio;
	const char *label;
	void *data;
	struct list_head list;
	struct blocking_notifier_head notifier;
	struct list_head pin_ranges;
};

struct gpio_array___2;

struct gpio_descs___2 {
	struct gpio_array___2 *info;
	unsigned int ndescs;
	struct gpio_desc___4 *desc[0];
};

struct gpio_array___2 {
	struct gpio_desc___4 **desc;
	unsigned int size;
	struct gpio_chip___7 *chip;
	long unsigned int *get_mask;
	long unsigned int *set_mask;
	long unsigned int invert_mask[0];
};

struct gpio_desc___4 {
	struct gpio_device___3 *gdev;
	long unsigned int flags;
	const char *label;
	const char *name;
	struct device_node___47 *hog;
	unsigned int debounce_period_us;
};

struct devres;

struct gpio {
	unsigned int gpio;
	long unsigned int flags;
	const char *label;
};

struct of_reconfig_data {
	struct device_node___45 *dn;
	struct property___34 *prop;
	struct property___34 *old_prop;
};

enum of_reconfig_change {
	OF_RECONFIG_NO_CHANGE = 0,
	OF_RECONFIG_CHANGE_ADD = 1,
	OF_RECONFIG_CHANGE_REMOVE = 2,
};

enum of_gpio_flags {
	OF_GPIO_ACTIVE_LOW = 1,
	OF_GPIO_SINGLE_ENDED = 2,
	OF_GPIO_OPEN_DRAIN = 4,
	OF_GPIO_TRANSITORY = 8,
	OF_GPIO_PULL_UP = 16,
	OF_GPIO_PULL_DOWN = 32,
};

struct of_mm_gpio_chip {
	struct gpio_chip___6 gc;
	void (*save_regs)(struct of_mm_gpio_chip *);
	void *regs;
};

struct dentry___188;

struct super_block___188;

struct module___172;

struct file_system_type___188 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___188 * (*mount)(struct file_system_type___188 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___188 *);
	struct module___172 *owner;
	struct file_system_type___188 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___188;

struct kiocb___188;

struct poll_table_struct___122;

struct vm_area_struct___193;

struct inode___188;

struct file_lock___188;

struct page___193;

struct seq_file___164;

struct file_operations___189 {
	struct module___172 *owner;
	loff_t (*llseek)(struct file___188 *, loff_t, int);
	ssize_t (*read)(struct file___188 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___188 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___188 *, struct iov_iter___111 *);
	ssize_t (*write_iter)(struct kiocb___188 *, struct iov_iter___111 *);
	int (*iopoll)(struct kiocb___188 *, bool);
	int (*iterate)(struct file___188 *, struct dir_context *);
	int (*iterate_shared)(struct file___188 *, struct dir_context *);
	__poll_t (*poll)(struct file___188 *, struct poll_table_struct___122 *);
	long int (*unlocked_ioctl)(struct file___188 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___188 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___188 *, struct vm_area_struct___193 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___188 *, struct file___188 *);
	int (*flush)(struct file___188 *, fl_owner_t);
	int (*release)(struct inode___188 *, struct file___188 *);
	int (*fsync)(struct file___188 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___188 *, int);
	int (*lock)(struct file___188 *, int, struct file_lock___188 *);
	ssize_t (*sendpage)(struct file___188 *, struct page___193 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___188 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___188 *, long unsigned int);
	int (*flock)(struct file___188 *, int, struct file_lock___188 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___188 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___188 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___188 *, long int, struct file_lock___188 **, void **);
	long int (*fallocate)(struct file___188 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___164 *, struct file___188 *);
	ssize_t (*copy_file_range)(struct file___188 *, loff_t, struct file___188 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___188 *, loff_t, struct file___188 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___188 *, loff_t, loff_t, int);
};

struct vmacache___193 {
	u64 seqnum;
	struct vm_area_struct___193 *vmas[4];
};

struct page_frag___193 {
	struct page___193 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___194;

struct signal_struct___189;

struct vm_struct___171;

struct task_struct___195 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___195 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___194 *mm;
	struct mm_struct___194 *active_mm;
	struct vmacache___193 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___195 *real_parent;
	struct task_struct___195 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___195 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___166 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___8 *nsproxy;
	struct signal_struct___189 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___195 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___93 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___193 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___195 *oom_reaper_list;
	struct vm_struct___171 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___176;

struct kobj_type___176;

struct kernfs_node___176;

struct kobject___176 {
	const char *name;
	struct list_head entry;
	struct kobject___176 *parent;
	struct kset___176 *kset;
	struct kobj_type___176 *ktype;
	struct kernfs_node___176 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___172 {
	struct kobject___176 kobj;
	struct module___172 *mod;
	struct kobject___176 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___172 {
	struct module___172 *mod;
	struct latch_tree_node node;
};

struct module_layout___172 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___172 mtn;
};

struct module_attribute___172;

struct kernel_param___172;

struct srcu_struct___2;

struct module___172 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___172 mkobj;
	struct module_attribute___172 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___176 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___172 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___172 core_layout;
	struct module_layout___172 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct___2 **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___193 *pgtable_t___193;

struct address_space___188;

struct dev_pagemap___183;

struct page___193 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___188 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___193 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___193 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___194 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___183 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___183;

struct vm_area_struct___193 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___193 *vm_next;
	struct vm_area_struct___193 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___194 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___183 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___188 *vm_file;
	struct file___188 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___193;

struct mm_struct___194 {
	struct {
		struct vm_area_struct___193 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___188 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___193 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___195 *owner;
		struct user_namespace *user_ns;
		struct file___188 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___188;

struct address_space___188 {
	struct inode___188 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___188 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___183;

struct dev_pagemap___183 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___183 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___188;

struct path___188 {
	struct vfsmount___188 *mnt;
	struct dentry___188 *dentry;
};

struct file___188 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___188 f_path;
	struct inode___188 *f_inode;
	const struct file_operations___189 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___166 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___188 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___183;

struct vm_operations_struct___183 {
	void (*open)(struct vm_area_struct___193 *);
	void (*close)(struct vm_area_struct___193 *);
	int (*may_split)(struct vm_area_struct___193 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___193 *);
	int (*mprotect)(struct vm_area_struct___193 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___183 *);
	vm_fault_t (*huge_fault)(struct vm_fault___183 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___183 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___193 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___183 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___183 *);
	int (*access)(struct vm_area_struct___193 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___193 *);
	int (*set_policy)(struct vm_area_struct___193 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___193 *, long unsigned int);
	struct page___193 * (*find_special_page)(struct vm_area_struct___193 *, long unsigned int);
};

struct core_thread___193 {
	struct task_struct___195 *task;
	struct core_thread___193 *next;
};

struct core_state___193 {
	atomic_t nr_threads;
	struct core_thread___193 dumper;
	struct completion startup;
};

struct vm_fault___183 {
	const struct {
		struct vm_area_struct___193 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___193 *cow_page;
	struct page___193 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___193 prealloc_pte;
};

struct srcu_data___2 {
	long unsigned int srcu_lock_count[2];
	long unsigned int srcu_unlock_count[2];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	struct rcu_segcblist srcu_cblist;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	bool srcu_cblist_invoking;
	struct timer_list delay_work;
	struct work_struct work;
	struct callback_head srcu_barrier_head;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct srcu_node *mynode;
	long unsigned int grpmask;
	int cpu;
	struct srcu_struct___2 *ssp;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct srcu_struct___2 {
	struct srcu_node node[17];
	struct srcu_node *level[3];
	struct mutex srcu_cb_mutex;
	spinlock_t lock;
	struct mutex srcu_gp_mutex;
	unsigned int srcu_idx;
	long unsigned int srcu_gp_seq;
	long unsigned int srcu_gp_seq_needed;
	long unsigned int srcu_gp_seq_needed_exp;
	long unsigned int srcu_last_gp_end;
	struct srcu_data___2 *sda;
	long unsigned int srcu_barrier_seq;
	struct mutex srcu_barrier_mutex;
	struct completion srcu_barrier_completion;
	atomic_t srcu_barrier_cpu_cnt;
	struct delayed_work work;
	struct lockdep_map dep_map;
};

struct kernfs_root___176;

struct kernfs_elem_dir___176 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___176 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___176;

struct kernfs_root___176 {
	struct kernfs_node___176 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___176 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___176 {
	struct kernfs_node___176 *target_kn;
};

struct kernfs_ops___176;

struct kernfs_elem_attr___176 {
	const struct kernfs_ops___176 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___176 *notify_next;
};

struct kernfs_node___176 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___176 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___176 dir;
		struct kernfs_elem_symlink___176 symlink;
		struct kernfs_elem_attr___176 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___176;

struct kernfs_ops___176 {
	int (*open)(struct kernfs_open_file___176 *);
	void (*release)(struct kernfs_open_file___176 *);
	int (*seq_show)(struct seq_file___164 *, void *);
	void * (*seq_start)(struct seq_file___164 *, loff_t *);
	void * (*seq_next)(struct seq_file___164 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___164 *, void *);
	ssize_t (*read)(struct kernfs_open_file___176 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___176 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___176 *, struct poll_table_struct___122 *);
	int (*mmap)(struct kernfs_open_file___176 *, struct vm_area_struct___193 *);
};

struct kernfs_syscall_ops___176 {
	int (*show_options)(struct seq_file___164 *, struct kernfs_root___176 *);
	int (*mkdir)(struct kernfs_node___176 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___176 *);
	int (*rename)(struct kernfs_node___176 *, struct kernfs_node___176 *, const char *);
	int (*show_path)(struct seq_file___164 *, struct kernfs_node___176 *, struct kernfs_root___176 *);
};

struct seq_operations___164;

struct seq_file___164 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___164 *op;
	int poll_event;
	const struct file___188 *file;
	void *private;
};

struct kernfs_open_file___176 {
	struct kernfs_node___176 *kn;
	struct file___188 *file;
	struct seq_file___164 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___183 *vm_ops;
};

typedef void (*poll_queue_proc___127)(struct file___188 *, wait_queue_head_t *, struct poll_table_struct___122 *);

struct poll_table_struct___122 {
	poll_queue_proc___127 _qproc;
	__poll_t _key;
};

struct signal_struct___189 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___195 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___195 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___166 *pids[4];
	struct pid___166 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___194 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct vm_struct___171 {
	struct vm_struct___171 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___193 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___176;

struct attribute_group___176 {
	const char *name;
	umode_t (*is_visible)(struct kobject___176 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___176 *, struct bin_attribute___176 *, int);
	struct attribute **attrs;
	struct bin_attribute___176 **bin_attrs;
};

struct bin_attribute___176 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___188 * (*f_mapping)();
	ssize_t (*read)(struct file___188 *, struct kobject___176 *, struct bin_attribute___176 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___188 *, struct kobject___176 *, struct bin_attribute___176 *, char *, loff_t, size_t);
	int (*mmap)(struct file___188 *, struct kobject___176 *, struct bin_attribute___176 *, struct vm_area_struct___193 *);
};

struct sysfs_ops___176 {
	ssize_t (*show)(struct kobject___176 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___176 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___176;

struct kset___176 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___176 kobj;
	const struct kset_uevent_ops___176 *uevent_ops;
};

struct kobj_type___176 {
	void (*release)(struct kobject___176 *);
	const struct sysfs_ops___176 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___176 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___176 *);
	const void * (*namespace)(struct kobject___176 *);
	void (*get_ownership)(struct kobject___176 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___176 {
	int (* const filter)(struct kset___176 *, struct kobject___176 *);
	const char * (* const name)(struct kset___176 *, struct kobject___176 *);
	int (* const uevent)(struct kset___176 *, struct kobject___176 *, struct kobj_uevent_env *);
};

struct wakeup_source___146;

struct device___146;

struct dev_pm_info___146 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___146 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___146 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___146;

struct bus_type___146;

struct device_driver___146;

struct dev_pm_domain___146;

struct irq_domain___27;

struct device_node___48;

struct fwnode_handle___146;

struct class___146;

struct device___146 {
	struct kobject___176 kobj;
	struct device___146 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___146 *type;
	struct bus_type___146 *bus;
	struct device_driver___146 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___146 power;
	struct dev_pm_domain___146 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___27 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___48 *of_node;
	struct fwnode_handle___146 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___146 *class;
	const struct attribute_group___176 **groups;
	void (*release)(struct device___146 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___146 {
	int (*prepare)(struct device___146 *);
	void (*complete)(struct device___146 *);
	int (*suspend)(struct device___146 *);
	int (*resume)(struct device___146 *);
	int (*freeze)(struct device___146 *);
	int (*thaw)(struct device___146 *);
	int (*poweroff)(struct device___146 *);
	int (*restore)(struct device___146 *);
	int (*suspend_late)(struct device___146 *);
	int (*resume_early)(struct device___146 *);
	int (*freeze_late)(struct device___146 *);
	int (*thaw_early)(struct device___146 *);
	int (*poweroff_late)(struct device___146 *);
	int (*restore_early)(struct device___146 *);
	int (*suspend_noirq)(struct device___146 *);
	int (*resume_noirq)(struct device___146 *);
	int (*freeze_noirq)(struct device___146 *);
	int (*thaw_noirq)(struct device___146 *);
	int (*poweroff_noirq)(struct device___146 *);
	int (*restore_noirq)(struct device___146 *);
	int (*runtime_suspend)(struct device___146 *);
	int (*runtime_resume)(struct device___146 *);
	int (*runtime_idle)(struct device___146 *);
};

struct wakeup_source___146 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___146 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___146 {
	struct dev_pm_ops___146 ops;
	int (*start)(struct device___146 *);
	void (*detach)(struct device___146 *, bool);
	int (*activate)(struct device___146 *);
	void (*sync)(struct device___146 *);
	void (*dismiss)(struct device___146 *);
};

struct bus_type___146 {
	const char *name;
	const char *dev_name;
	struct device___146 *dev_root;
	const struct attribute_group___176 **bus_groups;
	const struct attribute_group___176 **dev_groups;
	const struct attribute_group___176 **drv_groups;
	int (*match)(struct device___146 *, struct device_driver___146 *);
	int (*uevent)(struct device___146 *, struct kobj_uevent_env *);
	int (*probe)(struct device___146 *);
	void (*sync_state)(struct device___146 *);
	void (*remove)(struct device___146 *);
	void (*shutdown)(struct device___146 *);
	int (*online)(struct device___146 *);
	int (*offline)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	int (*num_vf)(struct device___146 *);
	int (*dma_configure)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___146 {
	const char *name;
	struct bus_type___146 *bus;
	struct module___172 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___146 *);
	void (*sync_state)(struct device___146 *);
	int (*remove)(struct device___146 *);
	void (*shutdown)(struct device___146 *);
	int (*suspend)(struct device___146 *, pm_message_t);
	int (*resume)(struct device___146 *);
	const struct attribute_group___176 **groups;
	const struct attribute_group___176 **dev_groups;
	const struct dev_pm_ops___146 *pm;
	void (*coredump)(struct device___146 *);
	struct driver_private *p;
};

struct device_type___146 {
	const char *name;
	const struct attribute_group___176 **groups;
	int (*uevent)(struct device___146 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___146 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___146 *);
	const struct dev_pm_ops___146 *pm;
};

struct class___146 {
	const char *name;
	struct module___172 *owner;
	const struct attribute_group___176 **class_groups;
	const struct attribute_group___176 **dev_groups;
	struct kobject___176 *dev_kobj;
	int (*dev_uevent)(struct device___146 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___146 *, umode_t *);
	void (*class_release)(struct class___146 *);
	void (*dev_release)(struct device___146 *);
	int (*shutdown_pre)(struct device___146 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___146 *);
	void (*get_ownership)(struct device___146 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___146 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___27;

struct irq_domain_chip_generic___27;

struct irq_data___28;

struct irq_domain___27 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___27 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___146 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___27 *gc;
	struct irq_domain___27 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___28 *revmap[0];
};

struct fwnode_operations___146;

struct fwnode_handle___146 {
	struct fwnode_handle___146 *secondary;
	const struct fwnode_operations___146 *ops;
	struct device___146 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___38;

struct device_node___48 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___146 fwnode;
	struct property___38 *properties;
	struct property___38 *deadprops;
	struct device_node___48 *parent;
	struct device_node___48 *child;
	struct device_node___48 *sibling;
	struct kobject___176 kobj;
	long unsigned int _flags;
	void *data;
};

struct cdev___37 {
	struct kobject___176 kobj;
	struct module___172 *owner;
	const struct file_operations___189 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct kiocb___188 {
	struct file___188 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___188 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___86 *ki_waitq;
	};
};

struct dentry_operations___188;

struct dentry___188 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___188 *d_parent;
	struct qstr d_name;
	struct inode___188 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___188 *d_op;
	struct super_block___188 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___188;

struct inode___188 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___188 *i_op;
	struct super_block___188 *i_sb;
	struct address_space___188 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___189 *i_fop;
		void (*free_inode)(struct inode___188 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___188 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___37 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___188 {
	int (*d_revalidate)(struct dentry___188 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___188 *, unsigned int);
	int (*d_hash)(const struct dentry___188 *, struct qstr *);
	int (*d_compare)(const struct dentry___188 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___188 *);
	int (*d_init)(struct dentry___188 *);
	void (*d_release)(struct dentry___188 *);
	void (*d_prune)(struct dentry___188 *);
	void (*d_iput)(struct dentry___188 *, struct inode___188 *);
	char * (*d_dname)(struct dentry___188 *, char *, int);
	struct vfsmount___188 * (*d_automount)(struct path___188 *);
	int (*d_manage)(const struct path___188 *, bool);
	struct dentry___188 * (*d_real)(struct dentry___188 *, const struct inode___188 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___188;

struct mem_dqinfo___188 {
	struct quota_format_type___188 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___188;

struct quota_info___188 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___188 *files[3];
	struct mem_dqinfo___188 info[3];
	const struct quota_format_ops___188 *ops[3];
};

struct rcuwait___189 {
	struct task_struct___195 *task;
};

struct percpu_rw_semaphore___189 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___189 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___188 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___189 rw_sem[3];
};

struct super_operations___188;

struct dquot_operations___188;

struct quotactl_ops___188;

struct super_block___188 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___188 *s_type;
	const struct super_operations___188 *s_op;
	const struct dquot_operations___188 *dq_op;
	const struct quotactl_ops___188 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___188 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___188 s_dquot;
	struct sb_writers___188 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___188 *s_d_op;
	int cleancache_poolid;
	struct shrinker___77 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___188 {
	struct dentry___188 *mnt_root;
	struct super_block___188 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct iattr___188 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___188 *ia_file;
};

struct dquot___188 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___188 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___188 {
	int qf_fmt_id;
	const struct quota_format_ops___188 *qf_ops;
	struct module___172 *qf_owner;
	struct quota_format_type___188 *qf_next;
};

struct quota_format_ops___188 {
	int (*check_quota_file)(struct super_block___188 *, int);
	int (*read_file_info)(struct super_block___188 *, int);
	int (*write_file_info)(struct super_block___188 *, int);
	int (*free_file_info)(struct super_block___188 *, int);
	int (*read_dqblk)(struct dquot___188 *);
	int (*commit_dqblk)(struct dquot___188 *);
	int (*release_dqblk)(struct dquot___188 *);
	int (*get_next_id)(struct super_block___188 *, struct kqid *);
};

struct dquot_operations___188 {
	int (*write_dquot)(struct dquot___188 *);
	struct dquot___188 * (*alloc_dquot)(struct super_block___188 *, int);
	void (*destroy_dquot)(struct dquot___188 *);
	int (*acquire_dquot)(struct dquot___188 *);
	int (*release_dquot)(struct dquot___188 *);
	int (*mark_dirty)(struct dquot___188 *);
	int (*write_info)(struct super_block___188 *, int);
	qsize_t * (*get_reserved_space)(struct inode___188 *);
	int (*get_projid)(struct inode___188 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___188 *, qsize_t *);
	int (*get_next_id)(struct super_block___188 *, struct kqid *);
};

struct quotactl_ops___188 {
	int (*quota_on)(struct super_block___188 *, int, int, const struct path___188 *);
	int (*quota_off)(struct super_block___188 *, int);
	int (*quota_enable)(struct super_block___188 *, unsigned int);
	int (*quota_disable)(struct super_block___188 *, unsigned int);
	int (*quota_sync)(struct super_block___188 *, int);
	int (*set_info)(struct super_block___188 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___188 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___188 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___188 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___188 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___188 *, unsigned int);
};

struct address_space_operations___188 {
	int (*writepage)(struct page___193 *, struct writeback_control___3 *);
	int (*readpage)(struct file___188 *, struct page___193 *);
	int (*writepages)(struct address_space___188 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___193 *);
	int (*readpages)(struct file___188 *, struct address_space___188 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___188 *, struct address_space___188 *, loff_t, unsigned int, unsigned int, struct page___193 **, void **);
	int (*write_end)(struct file___188 *, struct address_space___188 *, loff_t, unsigned int, unsigned int, struct page___193 *, void *);
	sector_t (*bmap)(struct address_space___188 *, sector_t);
	void (*invalidatepage)(struct page___193 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___193 *, gfp_t);
	void (*freepage)(struct page___193 *);
	ssize_t (*direct_IO)(struct kiocb___188 *, struct iov_iter___111 *);
	int (*migratepage)(struct address_space___188 *, struct page___193 *, struct page___193 *, enum migrate_mode);
	bool (*isolate_page)(struct page___193 *, isolate_mode_t);
	void (*putback_page)(struct page___193 *);
	int (*launder_page)(struct page___193 *);
	int (*is_partially_uptodate)(struct page___193 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___193 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___188 *, struct page___193 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___188 *, sector_t *);
	void (*swap_deactivate)(struct file___188 *);
};

struct inode_operations___188 {
	struct dentry___188 * (*lookup)(struct inode___188 *, struct dentry___188 *, unsigned int);
	const char * (*get_link)(struct dentry___188 *, struct inode___188 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___188 *, int);
	struct posix_acl * (*get_acl)(struct inode___188 *, int, bool);
	int (*readlink)(struct dentry___188 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___188 *, struct dentry___188 *, umode_t, bool);
	int (*link)(struct dentry___188 *, struct inode___188 *, struct dentry___188 *);
	int (*unlink)(struct inode___188 *, struct dentry___188 *);
	int (*symlink)(struct user_namespace *, struct inode___188 *, struct dentry___188 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___188 *, struct dentry___188 *, umode_t);
	int (*rmdir)(struct inode___188 *, struct dentry___188 *);
	int (*mknod)(struct user_namespace *, struct inode___188 *, struct dentry___188 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___188 *, struct dentry___188 *, struct inode___188 *, struct dentry___188 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___188 *, struct iattr___188 *);
	int (*getattr)(struct user_namespace *, const struct path___188 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___188 *, char *, size_t);
	int (*fiemap)(struct inode___188 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___188 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___188 *, struct dentry___188 *, struct file___188 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___188 *, struct dentry___188 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___188 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___188 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___188 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___188 {
	void (*fl_copy_lock)(struct file_lock___188 *, struct file_lock___188 *);
	void (*fl_release_private)(struct file_lock___188 *);
};

struct fasync_struct___188;

struct lock_manager_operations___188;

struct file_lock___188 {
	struct file_lock___188 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___188 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___188 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___188 *fl_ops;
	const struct lock_manager_operations___188 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___188 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___188 *);
	int (*lm_grant)(struct file_lock___188 *, int);
	bool (*lm_break)(struct file_lock___188 *);
	int (*lm_change)(struct file_lock___188 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___188 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___188 *);
};

struct fasync_struct___188 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___188 *fa_next;
	struct file___188 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___188 {
	struct inode___188 * (*alloc_inode)(struct super_block___188 *);
	void (*destroy_inode)(struct inode___188 *);
	void (*free_inode)(struct inode___188 *);
	void (*dirty_inode)(struct inode___188 *, int);
	int (*write_inode)(struct inode___188 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___188 *);
	void (*evict_inode)(struct inode___188 *);
	void (*put_super)(struct super_block___188 *);
	int (*sync_fs)(struct super_block___188 *, int);
	int (*freeze_super)(struct super_block___188 *);
	int (*freeze_fs)(struct super_block___188 *);
	int (*thaw_super)(struct super_block___188 *);
	int (*unfreeze_fs)(struct super_block___188 *);
	int (*statfs)(struct dentry___188 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___188 *, int *, char *);
	void (*umount_begin)(struct super_block___188 *);
	int (*show_options)(struct seq_file___164 *, struct dentry___188 *);
	int (*show_devname)(struct seq_file___164 *, struct dentry___188 *);
	int (*show_path)(struct seq_file___164 *, struct dentry___188 *);
	int (*show_stats)(struct seq_file___164 *, struct dentry___188 *);
	ssize_t (*quota_read)(struct super_block___188 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___188 *, int, const char *, size_t, loff_t);
	struct dquot___188 ** (*get_dquots)(struct inode___188 *);
	long int (*nr_cached_objects)(struct super_block___188 *, struct shrink_control___77 *);
	long int (*free_cached_objects)(struct super_block___188 *, struct shrink_control___77 *);
	struct file___188 * (*real_loop)(struct file___188 *);
};

struct irq_desc___29;

typedef void (*irq_flow_handler_t___29)(struct irq_desc___29 *);

struct irq_chip___28;

struct irq_data___28 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___28 *chip;
	struct irq_domain___27 *domain;
	struct irq_data___28 *parent_data;
	void *chip_data;
};

struct irqaction___19;

struct irq_desc___29 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___28 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___29 handle_irq;
	struct irqaction___19 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___176 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___172 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___146;

struct fwnode_endpoint___146;

struct fwnode_operations___146 {
	struct fwnode_handle___146 * (*get)(struct fwnode_handle___146 *);
	void (*put)(struct fwnode_handle___146 *);
	bool (*device_is_available)(const struct fwnode_handle___146 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___146 *, const struct device___146 *);
	bool (*property_present)(const struct fwnode_handle___146 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___146 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___146 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___146 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*get_parent)(const struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*get_next_child_node)(const struct fwnode_handle___146 *, struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*get_named_child_node)(const struct fwnode_handle___146 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___146 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___146 *);
	struct fwnode_handle___146 * (*graph_get_next_endpoint)(const struct fwnode_handle___146 *, struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*graph_get_remote_endpoint)(const struct fwnode_handle___146 *);
	struct fwnode_handle___146 * (*graph_get_port_parent)(struct fwnode_handle___146 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___146 *, struct fwnode_endpoint___146 *);
	int (*add_links)(struct fwnode_handle___146 *);
};

struct fwnode_endpoint___146 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___146 *local_fwnode;
};

struct fwnode_reference_args___146 {
	struct fwnode_handle___146 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___28 {
	struct device___146 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___28 *);
	void (*irq_shutdown)(struct irq_data___28 *);
	void (*irq_enable)(struct irq_data___28 *);
	void (*irq_disable)(struct irq_data___28 *);
	void (*irq_ack)(struct irq_data___28 *);
	void (*irq_mask)(struct irq_data___28 *);
	void (*irq_mask_ack)(struct irq_data___28 *);
	void (*irq_unmask)(struct irq_data___28 *);
	void (*irq_eoi)(struct irq_data___28 *);
	int (*irq_set_affinity)(struct irq_data___28 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___28 *);
	int (*irq_set_type)(struct irq_data___28 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___28 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___28 *);
	void (*irq_bus_sync_unlock)(struct irq_data___28 *);
	void (*irq_cpu_online)(struct irq_data___28 *);
	void (*irq_cpu_offline)(struct irq_data___28 *);
	void (*irq_suspend)(struct irq_data___28 *);
	void (*irq_resume)(struct irq_data___28 *);
	void (*irq_pm_shutdown)(struct irq_data___28 *);
	void (*irq_calc_mask)(struct irq_data___28 *);
	void (*irq_print_chip)(struct irq_data___28 *, struct seq_file___164 *);
	int (*irq_request_resources)(struct irq_data___28 *);
	void (*irq_release_resources)(struct irq_data___28 *);
	void (*irq_compose_msi_msg)(struct irq_data___28 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___28 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___28 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___28 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___28 *, void *);
	void (*ipi_send_single)(struct irq_data___28 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___28 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___28 *);
	void (*irq_nmi_teardown)(struct irq_data___28 *);
	long unsigned int flags;
};

struct irqaction___19 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___19 *next;
	irq_handler_t thread_fn;
	struct task_struct___195 *thread;
	struct irqaction___19 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___27 {
	struct irq_chip___28 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___29 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___27 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___27 *);
	void (*resume)(struct irq_chip_generic___27 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___27 *domain;
	struct list_head list;
	struct irq_chip_type___27 chip_types[0];
};

struct irq_domain_chip_generic___27 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___27 *gc[0];
};

struct property___38 {
	char *name;
	int length;
	void *value;
	struct property___38 *next;
	long unsigned int _flags;
	struct bin_attribute___176 attr;
};

struct of_phandle_args___15 {
	struct device_node___48 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___25 {
	struct fwnode_handle___146 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___27 {
	int (*match)(struct irq_domain___27 *, struct device_node___48 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___27 *, struct irq_fwspec___25 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___27 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___27 *, unsigned int);
	int (*xlate)(struct irq_domain___27 *, struct device_node___48 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___27 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___27 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___27 *, struct irq_data___28 *, bool);
	void (*deactivate)(struct irq_domain___27 *, struct irq_data___28 *);
	int (*translate)(struct irq_domain___27 *, struct irq_fwspec___25 *, long unsigned int *, unsigned int *);
};

struct seq_operations___164 {
	void * (*start)(struct seq_file___164 *, loff_t *);
	void (*stop)(struct seq_file___164 *, void *);
	void * (*next)(struct seq_file___164 *, void *, loff_t *);
	int (*show)(struct seq_file___164 *, void *);
};

struct gpio_chip___8;

struct gpio_irq_chip___8 {
	struct irq_chip___28 *chip;
	struct irq_domain___27 *domain;
	const struct irq_domain_ops___27 *domain_ops;
	struct fwnode_handle___146 *fwnode;
	struct irq_domain___27 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___8 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___8 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___8 *, unsigned int);
	struct irq_domain_ops___27 child_irq_domain_ops;
	irq_flow_handler_t___29 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___29 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___8 *);
	void (*init_valid_mask)(struct gpio_chip___8 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___28 *);
	void (*irq_disable)(struct irq_data___28 *);
	void (*irq_unmask)(struct irq_data___28 *);
	void (*irq_mask)(struct irq_data___28 *);
};

struct gpio_device___4;

struct gpio_chip___8 {
	const char *label;
	struct gpio_device___4 *gpiodev;
	struct device___146 *parent;
	struct module___172 *owner;
	int (*request)(struct gpio_chip___8 *, unsigned int);
	void (*free)(struct gpio_chip___8 *, unsigned int);
	int (*get_direction)(struct gpio_chip___8 *, unsigned int);
	int (*direction_input)(struct gpio_chip___8 *, unsigned int);
	int (*direction_output)(struct gpio_chip___8 *, unsigned int, int);
	int (*get)(struct gpio_chip___8 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___8 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___8 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___8 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___8 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___8 *, unsigned int);
	void (*dbg_show)(struct seq_file___164 *, struct gpio_chip___8 *);
	int (*init_valid_mask)(struct gpio_chip___8 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___8 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___8 irq;
	long unsigned int *valid_mask;
	struct device_node___48 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___8 *, const struct of_phandle_args___15 *, u32 *);
};

struct gpio_desc___5;

struct gpio_device___4 {
	int id;
	struct device___146 dev;
	struct cdev___37 chrdev;
	struct device___146 *mockdev;
	struct module___172 *owner;
	struct gpio_chip___8 *chip;
	struct gpio_desc___5 *descs;
	int base;
	u16 ngpio;
	const char *label;
	void *data;
	struct list_head list;
	struct blocking_notifier_head notifier;
	struct list_head pin_ranges;
};

struct gpio_array___3 {
	struct gpio_desc___5 **desc;
	unsigned int size;
	struct gpio_chip___8 *chip;
	long unsigned int *get_mask;
	long unsigned int *set_mask;
	long unsigned int invert_mask[0];
};

struct gpio_desc___5 {
	struct gpio_device___4 *gdev;
	long unsigned int flags;
	const char *label;
	const char *name;
	struct device_node___48 *hog;
	unsigned int debounce_period_us;
};

struct dev_pagemap_ops___183 {
	void (*page_free)(struct page___193 *);
	void (*kill)(struct dev_pagemap___183 *);
	void (*cleanup)(struct dev_pagemap___183 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___183 *);
};

struct kernel_param_ops___172 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___172 *);
	int (*get)(char *, const struct kernel_param___172 *);
	void (*free)(void *);
};

struct kparam_array___172;

struct kernel_param___172 {
	const char *name;
	struct module___172 *mod;
	const struct kernel_param_ops___172 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___172 *arr;
	};
};

struct kparam_array___172 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___172 *ops;
	void *elem;
};

struct module_attribute___172 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___172 *, struct module_kobject___172 *, char *);
	ssize_t (*store)(struct module_attribute___172 *, struct module_kobject___172 *, const char *, size_t);
	void (*setup)(struct module___172 *, const char *);
	int (*test)(struct module___172 *);
	void (*free)(struct module___172 *);
};

typedef struct poll_table_struct___122 poll_table___31;

struct gpiochip_info {
	char name[32];
	char label[32];
	__u32 lines;
};

enum gpio_v2_line_flag {
	GPIO_V2_LINE_FLAG_USED = 1,
	GPIO_V2_LINE_FLAG_ACTIVE_LOW = 2,
	GPIO_V2_LINE_FLAG_INPUT = 4,
	GPIO_V2_LINE_FLAG_OUTPUT = 8,
	GPIO_V2_LINE_FLAG_EDGE_RISING = 16,
	GPIO_V2_LINE_FLAG_EDGE_FALLING = 32,
	GPIO_V2_LINE_FLAG_OPEN_DRAIN = 64,
	GPIO_V2_LINE_FLAG_OPEN_SOURCE = 128,
	GPIO_V2_LINE_FLAG_BIAS_PULL_UP = 256,
	GPIO_V2_LINE_FLAG_BIAS_PULL_DOWN = 512,
	GPIO_V2_LINE_FLAG_BIAS_DISABLED = 1024,
	GPIO_V2_LINE_FLAG_EVENT_CLOCK_REALTIME = 2048,
};

struct gpio_v2_line_values {
	__u64 bits;
	__u64 mask;
};

enum gpio_v2_line_attr_id {
	GPIO_V2_LINE_ATTR_ID_FLAGS = 1,
	GPIO_V2_LINE_ATTR_ID_OUTPUT_VALUES = 2,
	GPIO_V2_LINE_ATTR_ID_DEBOUNCE = 3,
};

struct gpio_v2_line_attribute {
	__u32 id;
	__u32 padding;
	union {
		__u64 flags;
		__u64 values;
		__u32 debounce_period_us;
	};
};

struct gpio_v2_line_config_attribute {
	struct gpio_v2_line_attribute attr;
	__u64 mask;
};

struct gpio_v2_line_config {
	__u64 flags;
	__u32 num_attrs;
	__u32 padding[5];
	struct gpio_v2_line_config_attribute attrs[10];
};

struct gpio_v2_line_request {
	__u32 offsets[64];
	char consumer[32];
	struct gpio_v2_line_config config;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u32 num_lines;
	__u32 event_buffer_size;
	__u32 padding[5];
	__s32 fd;
};

struct gpio_v2_line_info {
	char name[32];
	char consumer[32];
	__u32 offset;
	__u32 num_attrs;
	__u64 flags;
	struct gpio_v2_line_attribute attrs[10];
	__u32 padding[4];
};

enum gpio_v2_line_changed_type {
	GPIO_V2_LINE_CHANGED_REQUESTED = 1,
	GPIO_V2_LINE_CHANGED_RELEASED = 2,
	GPIO_V2_LINE_CHANGED_CONFIG = 3,
};

struct gpio_v2_line_info_changed {
	struct gpio_v2_line_info info;
	__u64 timestamp_ns;
	__u32 event_type;
	__u32 padding[5];
};

enum gpio_v2_line_event_id {
	GPIO_V2_LINE_EVENT_RISING_EDGE = 1,
	GPIO_V2_LINE_EVENT_FALLING_EDGE = 2,
};

struct gpio_v2_line_event {
	__u64 timestamp_ns;
	__u32 id;
	__u32 offset;
	__u32 seqno;
	__u32 line_seqno;
	__u32 padding[6];
};

struct linereq;

struct line {
	struct gpio_desc___5 *desc;
	struct linereq *req;
	unsigned int irq;
	u64 eflags;
	u64 timestamp_ns;
	u32 req_seqno;
	u32 line_seqno;
	struct delayed_work work;
	unsigned int sw_debounced;
	unsigned int level;
};

struct linereq {
	struct gpio_device___4 *gdev;
	const char *label;
	u32 num_lines;
	wait_queue_head_t wait;
	u32 event_buffer_size;
	struct {
		union {
			struct __kfifo kfifo;
			struct gpio_v2_line_event *type;
			const struct gpio_v2_line_event *const_type;
			char (*rectype)[0];
			struct gpio_v2_line_event *ptr;
			const struct gpio_v2_line_event *ptr_const;
		};
		struct gpio_v2_line_event buf[0];
	} events;
	atomic_t seqno;
	struct mutex config_mutex;
	struct line lines[0];
};

struct gpio_chardev_data {
	struct gpio_device___4 *gdev;
	wait_queue_head_t wait;
	struct {
		union {
			struct __kfifo kfifo;
			struct gpio_v2_line_info_changed *type;
			const struct gpio_v2_line_info_changed *const_type;
			char (*rectype)[0];
			struct gpio_v2_line_info_changed *ptr;
			const struct gpio_v2_line_info_changed *ptr_const;
		};
		struct gpio_v2_line_info_changed buf[32];
	} events;
	struct notifier_block lineinfo_changed_nb;
	long unsigned int *watched_lines;
};

struct class_attribute {
	struct attribute attr;
	ssize_t (*show)(struct class___143 *, struct class_attribute *, char *);
	ssize_t (*store)(struct class___143 *, struct class_attribute *, const char *, size_t);
};

struct gpiod_data {
	struct gpio_desc___3 *desc;
	struct mutex mutex;
	struct kernfs_node___172 *value_kn;
	int irq;
	unsigned char irq_flags;
	bool direction_can_change;
};

enum dmi_field {
	DMI_NONE = 0,
	DMI_BIOS_VENDOR = 1,
	DMI_BIOS_VERSION = 2,
	DMI_BIOS_DATE = 3,
	DMI_BIOS_RELEASE = 4,
	DMI_EC_FIRMWARE_RELEASE = 5,
	DMI_SYS_VENDOR = 6,
	DMI_PRODUCT_NAME = 7,
	DMI_PRODUCT_VERSION = 8,
	DMI_PRODUCT_SERIAL = 9,
	DMI_PRODUCT_UUID = 10,
	DMI_PRODUCT_SKU = 11,
	DMI_PRODUCT_FAMILY = 12,
	DMI_BOARD_VENDOR = 13,
	DMI_BOARD_NAME = 14,
	DMI_BOARD_VERSION = 15,
	DMI_BOARD_SERIAL = 16,
	DMI_BOARD_ASSET_TAG = 17,
	DMI_CHASSIS_VENDOR = 18,
	DMI_CHASSIS_TYPE = 19,
	DMI_CHASSIS_VERSION = 20,
	DMI_CHASSIS_SERIAL = 21,
	DMI_CHASSIS_ASSET_TAG = 22,
	DMI_STRING_MAX = 23,
	DMI_OEM_STRING = 24,
};

struct dmi_strmatch {
	unsigned char slot: 7;
	unsigned char exact_match: 1;
	char substr[79];
};

struct dmi_system_id {
	int (*callback)(const struct dmi_system_id *);
	const char *ident;
	struct dmi_strmatch matches[4];
	void *driver_data;
};

typedef void (*dr_release_t___11)(struct device___9 *, void *);

typedef int (*dr_match_t___10)(struct device___9 *, void *, void *);

typedef u8 acpi_adr_space_type;

struct acpi_object_list {
	u32 count;
	union acpi_object *pointer;
};

struct acpi_buffer {
	acpi_size length;
	void *pointer;
};

typedef void (*acpi_object_handler)(acpi_handle, void *);

typedef acpi_status (*acpi_adr_space_handler)(u32, acpi_physical_address, u32, u64 *, void *, void *);

struct acpi_connection_info {
	u8 *connection;
	u16 length;
	u8 access_length;
};

typedef acpi_status (*acpi_adr_space_setup)(acpi_handle, u32, void *, void **);

struct acpi_gpiolib_dmi_quirk {
	bool no_edge_events_on_boot;
	char *ignore_wake;
};

struct acpi_gpio_event {
	struct list_head node;
	acpi_handle handle;
	irq_handler_t handler;
	unsigned int pin;
	unsigned int irq;
	long unsigned int irqflags;
	bool irq_is_wake;
	bool irq_requested;
	struct gpio_desc___3 *desc;
};

struct acpi_gpio_connection {
	struct list_head node;
	unsigned int pin;
	struct gpio_desc___3 *desc;
};

struct acpi_gpio_chip {
	struct acpi_connection_info conn_info;
	struct list_head conns;
	struct mutex conn_lock;
	struct gpio_chip___6 *chip;
	struct list_head events;
	struct list_head deferred_req_irqs_list_entry;
};

struct acpi_gpio_lookup {
	struct acpi_gpio_info info;
	int index;
	u16 pin_index;
	bool active_low;
	struct gpio_desc___3 *desc;
	int n;
};

struct bgpio_pdata {
	const char *label;
	int base;
	int ngpio;
};

struct davinci_gpio_platform_data {
	bool no_auto_base;
	u32 base;
	u32 ngpio;
	u32 gpio_unbanked;
};

struct davinci_gpio_regs {
	u32 dir;
	u32 out_data;
	u32 set_data;
	u32 clr_data;
	u32 in_data;
	u32 set_rising;
	u32 clr_rising;
	u32 set_falling;
	u32 clr_falling;
	u32 intstat;
};

typedef struct irq_chip___27 * (*gpio_get_irq_chip_cb_t)(unsigned int);

struct davinci_gpio_controller;

struct davinci_gpio_irq_data {
	void *regs;
	struct davinci_gpio_controller *chip;
	int bank_num;
};

struct davinci_gpio_controller {
	struct gpio_chip___7 chip;
	struct irq_domain___26 *irq_domain;
	spinlock_t lock;
	void *regs[5];
	int gpio_unbanked;
	int irqs[32];
};

struct ftgpio_gpio {
	struct device___146 *dev;
	struct gpio_chip___8 gc;
	struct irq_chip___28 irq;
	void *base;
	struct clk *clk;
};

struct mpc8xxx_gpio_chip {
	struct gpio_chip___6 gc;
	void *regs;
	raw_spinlock_t lock;
	int (*direction_output)(struct gpio_chip___6 *, unsigned int, int);
	struct irq_domain___24 *irq;
	int irqn;
};

struct mpc8xxx_gpio_devtype {
	int (*gpio_dir_out)(struct gpio_chip___6 *, unsigned int, int);
	int (*gpio_get)(struct gpio_chip___6 *, unsigned int);
	int (*irq_set_type)(struct irq_data___25 *, unsigned int);
};

enum pwm_polarity {
	PWM_POLARITY_NORMAL = 0,
	PWM_POLARITY_INVERSED = 1,
};

struct pwm_args {
	u64 period;
	enum pwm_polarity polarity;
};

struct pwm_state {
	u64 period;
	u64 duty_cycle;
	enum pwm_polarity polarity;
	bool enabled;
	bool usage_power;
};

struct pwm_chip;

struct pwm_device {
	const char *label;
	long unsigned int flags;
	unsigned int hwpwm;
	unsigned int pwm;
	struct pwm_chip *chip;
	void *chip_data;
	struct pwm_args args;
	struct pwm_state state;
	struct pwm_state last;
};

struct pwm_ops;

struct pwm_chip {
	struct device___145 *dev;
	const struct pwm_ops *ops;
	int base;
	unsigned int npwm;
	struct pwm_device * (*of_xlate)(struct pwm_chip *, const struct of_phandle_args___13 *);
	unsigned int of_pwm_n_cells;
	struct list_head list;
	struct pwm_device *pwms;
};

struct pwm_capture;

struct pwm_ops {
	int (*request)(struct pwm_chip *, struct pwm_device *);
	void (*free)(struct pwm_chip *, struct pwm_device *);
	int (*capture)(struct pwm_chip *, struct pwm_device *, struct pwm_capture *, long unsigned int);
	int (*apply)(struct pwm_chip *, struct pwm_device *, const struct pwm_state *);
	void (*get_state)(struct pwm_chip *, struct pwm_device *, struct pwm_state *);
	struct module___8 *owner;
	int (*config)(struct pwm_chip *, struct pwm_device *, int, int);
	int (*set_polarity)(struct pwm_chip *, struct pwm_device *, enum pwm_polarity);
	int (*enable)(struct pwm_chip *, struct pwm_device *);
	void (*disable)(struct pwm_chip *, struct pwm_device *);
};

struct pwm_capture {
	unsigned int period;
	unsigned int duty_cycle;
};

struct mvebu_gpio_chip;

struct mvebu_pwm {
	struct regmap *regs;
	u32 offset;
	long unsigned int clk_rate;
	struct gpio_desc *gpiod;
	struct pwm_chip chip;
	spinlock_t lock;
	struct mvebu_gpio_chip *mvchip;
	u32 blink_select;
	u32 blink_on_duration;
	u32 blink_off_duration;
};

struct mvebu_gpio_chip {
	struct gpio_chip___7 chip;
	struct regmap *regs;
	u32 offset;
	struct regmap *percpu_regs;
	int irqbase;
	struct irq_domain___26 *domain;
	int soc_variant;
	struct clk *clk;
	struct mvebu_pwm *mvpwm;
	u32 out_reg;
	u32 io_conf_reg;
	u32 blink_en_reg;
	u32 in_pol_reg;
	u32 edge_mask_regs[4];
	u32 level_mask_regs[4];
};

struct mxc_gpio_hwdata {
	unsigned int dr_reg;
	unsigned int gdir_reg;
	unsigned int psr_reg;
	unsigned int icr1_reg;
	unsigned int icr2_reg;
	unsigned int imr_reg;
	unsigned int isr_reg;
	int edge_sel_reg;
	unsigned int low_level;
	unsigned int high_level;
	unsigned int rise_edge;
	unsigned int fall_edge;
};

struct mxc_gpio_reg_saved {
	u32 icr1;
	u32 icr2;
	u32 imr;
	u32 gdir;
	u32 edge_sel;
	u32 dr;
};

struct mxc_gpio_port {
	struct list_head node;
	void *base;
	struct clk *clk;
	int irq;
	int irq_high;
	struct irq_domain___25 *domain;
	struct gpio_chip___6 gc;
	struct device___144 *dev;
	u32 both_edges;
	struct mxc_gpio_reg_saved gpio_saved_reg;
	bool power_off;
	const struct mxc_gpio_hwdata *hwdata;
};

struct ww_acquire_ctx___5;

struct ww_mutex___3 {
	struct mutex base;
	struct ww_acquire_ctx___5 *ctx;
};

struct ww_acquire_ctx___5 {
	struct task_struct___194 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct regulator_dev___2;

struct regulator_ops___2 {
	int (*list_voltage)(struct regulator_dev___2 *, unsigned int);
	int (*set_voltage)(struct regulator_dev___2 *, int, int, unsigned int *);
	int (*map_voltage)(struct regulator_dev___2 *, int, int);
	int (*set_voltage_sel)(struct regulator_dev___2 *, unsigned int);
	int (*get_voltage)(struct regulator_dev___2 *);
	int (*get_voltage_sel)(struct regulator_dev___2 *);
	int (*set_current_limit)(struct regulator_dev___2 *, int, int);
	int (*get_current_limit)(struct regulator_dev___2 *);
	int (*set_input_current_limit)(struct regulator_dev___2 *, int);
	int (*set_over_current_protection)(struct regulator_dev___2 *, int, int, bool);
	int (*set_over_voltage_protection)(struct regulator_dev___2 *, int, int, bool);
	int (*set_under_voltage_protection)(struct regulator_dev___2 *, int, int, bool);
	int (*set_thermal_protection)(struct regulator_dev___2 *, int, int, bool);
	int (*set_active_discharge)(struct regulator_dev___2 *, bool);
	int (*enable)(struct regulator_dev___2 *);
	int (*disable)(struct regulator_dev___2 *);
	int (*is_enabled)(struct regulator_dev___2 *);
	int (*set_mode)(struct regulator_dev___2 *, unsigned int);
	unsigned int (*get_mode)(struct regulator_dev___2 *);
	int (*get_error_flags)(struct regulator_dev___2 *, unsigned int *);
	int (*enable_time)(struct regulator_dev___2 *);
	int (*set_ramp_delay)(struct regulator_dev___2 *, int);
	int (*set_voltage_time)(struct regulator_dev___2 *, int, int);
	int (*set_voltage_time_sel)(struct regulator_dev___2 *, unsigned int, unsigned int);
	int (*set_soft_start)(struct regulator_dev___2 *);
	int (*get_status)(struct regulator_dev___2 *);
	unsigned int (*get_optimum_mode)(struct regulator_dev___2 *, int, int, int);
	int (*set_load)(struct regulator_dev___2 *, int);
	int (*set_bypass)(struct regulator_dev___2 *, bool);
	int (*get_bypass)(struct regulator_dev___2 *, bool *);
	int (*set_suspend_voltage)(struct regulator_dev___2 *, int);
	int (*set_suspend_enable)(struct regulator_dev___2 *);
	int (*set_suspend_disable)(struct regulator_dev___2 *);
	int (*set_suspend_mode)(struct regulator_dev___2 *, unsigned int);
	int (*resume)(struct regulator_dev___2 *);
	int (*set_pull_down)(struct regulator_dev___2 *);
};

struct coupling_desc___2 {
	struct regulator_dev___2 **coupled_rdevs;
	struct regulator_coupler *coupler;
	int n_resolved;
	int n_coupled;
};

struct regulator_desc___2;

struct regulator_dev___2 {
	const struct regulator_desc___2 *desc;
	int exclusive;
	u32 use_count;
	u32 open_count;
	u32 bypass_count;
	struct list_head list;
	struct list_head consumer_list;
	struct coupling_desc___2 coupling_desc;
	struct blocking_notifier_head notifier;
	struct ww_mutex___3 mutex;
	struct task_struct___194 *mutex_owner;
	int ref_cnt;
	struct module___171 *owner;
	struct device___145 dev;
	struct regulation_constraints *constraints;
	struct regulator *supply;
	const char *supply_name;
	struct regmap *regmap;
	struct delayed_work disable_work;
	void *reg_data;
	struct dentry___187 *debugfs;
	struct regulator_enable_gpio *ena_pin;
	unsigned int ena_gpio_state: 1;
	unsigned int is_switch: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	ktime_t last_off;
	int cached_err;
	bool use_cached_err;
	spinlock_t err_lock;
};

struct regulator_config___2;

struct regulator_desc___2 {
	const char *name;
	const char *supply_name;
	const char *of_match;
	bool of_match_full_name;
	const char *regulators_node;
	int (*of_parse_cb)(struct device_node___47 *, const struct regulator_desc___2 *, struct regulator_config___2 *);
	int id;
	unsigned int continuous_voltage_range: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int n_voltages;
	unsigned int n_current_limits;
	const struct regulator_ops___2 *ops;
	int irq;
	enum regulator_type type;
	struct module___171 *owner;
	unsigned int min_uV;
	unsigned int uV_step;
	unsigned int linear_min_sel;
	int fixed_uV;
	unsigned int ramp_delay;
	int min_dropout_uV;
	const struct linear_range *linear_ranges;
	const unsigned int *linear_range_selectors;
	int n_linear_ranges;
	const unsigned int *volt_table;
	const unsigned int *curr_table;
	unsigned int vsel_range_reg;
	unsigned int vsel_range_mask;
	unsigned int vsel_reg;
	unsigned int vsel_mask;
	unsigned int vsel_step;
	unsigned int csel_reg;
	unsigned int csel_mask;
	unsigned int apply_reg;
	unsigned int apply_bit;
	unsigned int enable_reg;
	unsigned int enable_mask;
	unsigned int enable_val;
	unsigned int disable_val;
	bool enable_is_inverted;
	unsigned int bypass_reg;
	unsigned int bypass_mask;
	unsigned int bypass_val_on;
	unsigned int bypass_val_off;
	unsigned int active_discharge_on;
	unsigned int active_discharge_off;
	unsigned int active_discharge_mask;
	unsigned int active_discharge_reg;
	unsigned int soft_start_reg;
	unsigned int soft_start_mask;
	unsigned int soft_start_val_on;
	unsigned int pull_down_reg;
	unsigned int pull_down_mask;
	unsigned int pull_down_val_on;
	unsigned int ramp_reg;
	unsigned int ramp_mask;
	const unsigned int *ramp_delay_table;
	unsigned int n_ramp_values;
	unsigned int enable_time;
	unsigned int off_on_delay;
	unsigned int poll_enabled_time;
	unsigned int (*of_map_mode)(unsigned int);
};

struct regulator_config___2 {
	struct device___145 *dev;
	const struct regulator_init_data *init_data;
	void *driver_data;
	struct device_node___47 *of_node;
	struct regmap *regmap;
	struct gpio_desc *ena_gpiod;
};

struct palmas_pmic_driver_data___2;

struct palmas_pmic___2;

struct palmas_resource___2;

struct palmas_usb___2;

struct palmas___2 {
	struct device___145 *dev;
	struct i2c_client *i2c_clients[3];
	struct regmap *regmap[3];
	int id;
	unsigned int features;
	int irq;
	u32 irq_mask;
	struct mutex irq_lock;
	struct regmap_irq_chip_data *irq_data;
	struct palmas_pmic_driver_data___2 *pmic_ddata;
	struct palmas_pmic___2 *pmic;
	struct palmas_gpadc *gpadc;
	struct palmas_resource___2 *resource;
	struct palmas_usb___2 *usb;
	u8 gpio_muxed;
	u8 led_muxed;
	u8 pwm_muxed;
};

struct palmas_pmic_driver_data___2 {
	int smps_start;
	int smps_end;
	int ldo_begin;
	int ldo_end;
	int max_reg;
	bool has_regen3;
	struct palmas_regs_info *palmas_regs_info;
	struct of_regulator_match *palmas_matches;
	struct palmas_sleep_requestor_info *sleep_req_info;
	int (*smps_register)(struct palmas_pmic___2 *, struct palmas_pmic_driver_data___2 *, struct palmas_pmic_platform_data *, const char *, struct regulator_config___2);
	int (*ldo_register)(struct palmas_pmic___2 *, struct palmas_pmic_driver_data___2 *, struct palmas_pmic_platform_data *, const char *, struct regulator_config___2);
};

struct palmas_pmic___2 {
	struct palmas___2 *palmas;
	struct device___145 *dev;
	struct regulator_desc___2 desc[27];
	struct mutex mutex;
	int smps123;
	int smps457;
	int smps12;
	int range[10];
	unsigned int ramp_delay[10];
	unsigned int current_reg_mode[10];
};

struct palmas_resource___2 {
	struct palmas___2 *palmas;
	struct device___145 *dev;
};

struct palmas_usb___2 {
	struct palmas___2 *palmas;
	struct device___145 *dev;
	struct extcon_dev *edev;
	int id_otg_irq;
	int id_irq;
	int vbus_otg_irq;
	int vbus_irq;
	int gpio_id_irq;
	int gpio_vbus_irq;
	struct gpio_desc *id_gpiod;
	struct gpio_desc *vbus_gpiod;
	long unsigned int sw_debounce_jiffies;
	struct delayed_work wq_detectid;
	enum palmas_usb_state linkstat;
	int wakeup;
	bool enable_vbus_detection;
	bool enable_id_detection;
	bool enable_gpio_id_detection;
	bool enable_gpio_vbus_detection;
};

struct palmas_adc_wakeup_property {
	int adc_channel_number;
	int adc_high_threshold;
	int adc_low_threshold;
};

struct palmas_gpadc_platform_data {
	int ch3_current;
	int ch0_current;
	bool extended_delay;
	int bat_removal;
	int start_polarity;
	int auto_conversion_period_ms;
	struct palmas_adc_wakeup_property *adc_wakeup1_data;
	struct palmas_adc_wakeup_property *adc_wakeup2_data;
};

struct palmas_usb_platform_data {
	int wakeup;
};

struct palmas_resource_platform_data {
	int regen1_mode_sleep;
	int regen2_mode_sleep;
	int sysen1_mode_sleep;
	int sysen2_mode_sleep;
	u8 nsleep_res;
	u8 nsleep_smps;
	u8 nsleep_ldo1;
	u8 nsleep_ldo2;
	u8 enable1_res;
	u8 enable1_smps;
	u8 enable1_ldo1;
	u8 enable1_ldo2;
	u8 enable2_res;
	u8 enable2_smps;
	u8 enable2_ldo1;
	u8 enable2_ldo2;
};

struct palmas_clk_platform_data {
	int clk32kg_mode_sleep;
	int clk32kgaudio_mode_sleep;
};

struct palmas_platform_data {
	int irq_flags;
	int gpio_base;
	u8 power_ctrl;
	int mux_from_pdata;
	u8 pad1;
	u8 pad2;
	bool pm_off;
	struct palmas_pmic_platform_data *pmic_pdata;
	struct palmas_gpadc_platform_data *gpadc_pdata;
	struct palmas_usb_platform_data *usb_pdata;
	struct palmas_resource_platform_data *resource_pdata;
	struct palmas_clk_platform_data *clk_pdata;
};

enum palmas_irqs {
	PALMAS_CHARG_DET_N_VBUS_OVV_IRQ = 0,
	PALMAS_PWRON_IRQ = 1,
	PALMAS_LONG_PRESS_KEY_IRQ = 2,
	PALMAS_RPWRON_IRQ = 3,
	PALMAS_PWRDOWN_IRQ = 4,
	PALMAS_HOTDIE_IRQ = 5,
	PALMAS_VSYS_MON_IRQ = 6,
	PALMAS_VBAT_MON_IRQ = 7,
	PALMAS_RTC_ALARM_IRQ = 8,
	PALMAS_RTC_TIMER_IRQ = 9,
	PALMAS_WDT_IRQ = 10,
	PALMAS_BATREMOVAL_IRQ = 11,
	PALMAS_RESET_IN_IRQ = 12,
	PALMAS_FBI_BB_IRQ = 13,
	PALMAS_SHORT_IRQ = 14,
	PALMAS_VAC_ACOK_IRQ = 15,
	PALMAS_GPADC_AUTO_0_IRQ = 16,
	PALMAS_GPADC_AUTO_1_IRQ = 17,
	PALMAS_GPADC_EOC_SW_IRQ = 18,
	PALMAS_GPADC_EOC_RT_IRQ = 19,
	PALMAS_ID_OTG_IRQ = 20,
	PALMAS_ID_IRQ = 21,
	PALMAS_VBUS_OTG_IRQ = 22,
	PALMAS_VBUS_IRQ = 23,
	PALMAS_GPIO_0_IRQ = 24,
	PALMAS_GPIO_1_IRQ = 25,
	PALMAS_GPIO_2_IRQ = 26,
	PALMAS_GPIO_3_IRQ = 27,
	PALMAS_GPIO_4_IRQ = 28,
	PALMAS_GPIO_5_IRQ = 29,
	PALMAS_GPIO_6_IRQ = 30,
	PALMAS_GPIO_7_IRQ = 31,
	PALMAS_NUM_IRQ = 32,
};

struct palmas_gpio {
	struct gpio_chip___7 gpio_chip;
	struct palmas___2 *palmas;
};

struct palmas_device_data {
	int ngpio;
};

struct amba_id {
	unsigned int id;
	unsigned int mask;
	void *data;
};

struct amba_cs_uci_id {
	unsigned int devarch;
	unsigned int devarch_mask;
	unsigned int devtype;
	void *data;
};

struct amba_device {
	struct device___144 dev;
	struct resource res;
	struct clk *pclk;
	struct device_dma_parameters dma_parms;
	unsigned int periphid;
	unsigned int cid;
	struct amba_cs_uci_id uci;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver {
	struct device_driver___144 drv;
	int (*probe)(struct amba_device *, const struct amba_id *);
	void (*remove)(struct amba_device *);
	void (*shutdown)(struct amba_device *);
	const struct amba_id *id_table;
};

struct pl061_context_save_regs {
	u8 gpio_data;
	u8 gpio_dir;
	u8 gpio_is;
	u8 gpio_ibe;
	u8 gpio_iev;
	u8 gpio_ie;
};

struct pl061 {
	raw_spinlock_t lock;
	void *base;
	struct gpio_chip___4 gc;
	struct irq_chip___26 irq_chip;
	int parent_irq;
	struct pl061_context_save_regs csave_regs;
};

enum {
	RC5T583_IRQ_ONKEY = 0,
	RC5T583_IRQ_ACOK = 1,
	RC5T583_IRQ_LIDOPEN = 2,
	RC5T583_IRQ_PREOT = 3,
	RC5T583_IRQ_CLKSTP = 4,
	RC5T583_IRQ_ONKEY_OFF = 5,
	RC5T583_IRQ_WD = 6,
	RC5T583_IRQ_EN_PWRREQ1 = 7,
	RC5T583_IRQ_EN_PWRREQ2 = 8,
	RC5T583_IRQ_PRE_VINDET = 9,
	RC5T583_IRQ_DC0LIM = 10,
	RC5T583_IRQ_DC1LIM = 11,
	RC5T583_IRQ_DC2LIM = 12,
	RC5T583_IRQ_DC3LIM = 13,
	RC5T583_IRQ_CTC = 14,
	RC5T583_IRQ_YALE = 15,
	RC5T583_IRQ_DALE = 16,
	RC5T583_IRQ_WALE = 17,
	RC5T583_IRQ_AIN1L = 18,
	RC5T583_IRQ_AIN2L = 19,
	RC5T583_IRQ_AIN3L = 20,
	RC5T583_IRQ_VBATL = 21,
	RC5T583_IRQ_VIN3L = 22,
	RC5T583_IRQ_VIN8L = 23,
	RC5T583_IRQ_AIN1H = 24,
	RC5T583_IRQ_AIN2H = 25,
	RC5T583_IRQ_AIN3H = 26,
	RC5T583_IRQ_VBATH = 27,
	RC5T583_IRQ_VIN3H = 28,
	RC5T583_IRQ_VIN8H = 29,
	RC5T583_IRQ_ADCEND = 30,
	RC5T583_IRQ_GPIO0 = 31,
	RC5T583_IRQ_GPIO1 = 32,
	RC5T583_IRQ_GPIO2 = 33,
	RC5T583_IRQ_GPIO3 = 34,
	RC5T583_IRQ_GPIO4 = 35,
	RC5T583_IRQ_GPIO5 = 36,
	RC5T583_IRQ_GPIO6 = 37,
	RC5T583_IRQ_GPIO7 = 38,
	RC5T583_MAX_IRQS = 39,
};

enum {
	RC5T583_GPIO0 = 0,
	RC5T583_GPIO1 = 1,
	RC5T583_GPIO2 = 2,
	RC5T583_GPIO3 = 3,
	RC5T583_GPIO4 = 4,
	RC5T583_GPIO5 = 5,
	RC5T583_GPIO6 = 6,
	RC5T583_GPIO7 = 7,
	RC5T583_MAX_GPIO = 8,
};

enum {
	RC5T583_REGULATOR_DC0 = 0,
	RC5T583_REGULATOR_DC1 = 1,
	RC5T583_REGULATOR_DC2 = 2,
	RC5T583_REGULATOR_DC3 = 3,
	RC5T583_REGULATOR_LDO0 = 4,
	RC5T583_REGULATOR_LDO1 = 5,
	RC5T583_REGULATOR_LDO2 = 6,
	RC5T583_REGULATOR_LDO3 = 7,
	RC5T583_REGULATOR_LDO4 = 8,
	RC5T583_REGULATOR_LDO5 = 9,
	RC5T583_REGULATOR_LDO6 = 10,
	RC5T583_REGULATOR_LDO7 = 11,
	RC5T583_REGULATOR_LDO8 = 12,
	RC5T583_REGULATOR_LDO9 = 13,
	RC5T583_REGULATOR_MAX = 14,
};

struct rc5t583 {
	struct device___145 *dev;
	struct regmap *regmap;
	int chip_irq;
	int irq_base;
	struct mutex irq_lock;
	long unsigned int group_irq_en[5];
	uint8_t intc_inten_reg;
	uint8_t irq_en_reg[8];
	uint8_t gpedge_reg[2];
};

struct rc5t583_platform_data {
	int irq_base;
	int gpio_base;
	bool enable_shutdown;
	int regulator_deepsleep_slot[14];
	long unsigned int regulator_ext_pwr_control[14];
	struct regulator_init_data *reg_init_data[14];
};

struct rc5t583_gpio {
	struct gpio_chip___7 gpio_chip;
	struct rc5t583 *rc5t583;
};

struct sifive_gpio {
	void *base;
	struct gpio_chip___7 gc;
	struct regmap *regs;
	long unsigned int irq_state;
	unsigned int trigger[32];
	unsigned int irq_number[32];
};

enum stmpe_block {
	STMPE_BLOCK_GPIO = 1,
	STMPE_BLOCK_KEYPAD = 2,
	STMPE_BLOCK_TOUCHSCREEN = 4,
	STMPE_BLOCK_ADC = 8,
	STMPE_BLOCK_PWM = 16,
	STMPE_BLOCK_ROTATOR = 32,
};

enum stmpe_partnum {
	STMPE610 = 0,
	STMPE801 = 1,
	STMPE811 = 2,
	STMPE1600 = 3,
	STMPE1601 = 4,
	STMPE1801 = 5,
	STMPE2401 = 6,
	STMPE2403 = 7,
	STMPE_NBR_PARTS = 8,
};

enum {
	STMPE_IDX_CHIP_ID = 0,
	STMPE_IDX_SYS_CTRL = 1,
	STMPE_IDX_SYS_CTRL2 = 2,
	STMPE_IDX_ICR_LSB = 3,
	STMPE_IDX_IER_LSB = 4,
	STMPE_IDX_IER_MSB = 5,
	STMPE_IDX_ISR_LSB = 6,
	STMPE_IDX_ISR_MSB = 7,
	STMPE_IDX_GPMR_LSB = 8,
	STMPE_IDX_GPMR_CSB = 9,
	STMPE_IDX_GPMR_MSB = 10,
	STMPE_IDX_GPSR_LSB = 11,
	STMPE_IDX_GPSR_CSB = 12,
	STMPE_IDX_GPSR_MSB = 13,
	STMPE_IDX_GPCR_LSB = 14,
	STMPE_IDX_GPCR_CSB = 15,
	STMPE_IDX_GPCR_MSB = 16,
	STMPE_IDX_GPDR_LSB = 17,
	STMPE_IDX_GPDR_CSB = 18,
	STMPE_IDX_GPDR_MSB = 19,
	STMPE_IDX_GPEDR_LSB = 20,
	STMPE_IDX_GPEDR_CSB = 21,
	STMPE_IDX_GPEDR_MSB = 22,
	STMPE_IDX_GPRER_LSB = 23,
	STMPE_IDX_GPRER_CSB = 24,
	STMPE_IDX_GPRER_MSB = 25,
	STMPE_IDX_GPFER_LSB = 26,
	STMPE_IDX_GPFER_CSB = 27,
	STMPE_IDX_GPFER_MSB = 28,
	STMPE_IDX_GPPUR_LSB = 29,
	STMPE_IDX_GPPDR_LSB = 30,
	STMPE_IDX_GPAFR_U_MSB = 31,
	STMPE_IDX_IEGPIOR_LSB = 32,
	STMPE_IDX_IEGPIOR_CSB = 33,
	STMPE_IDX_IEGPIOR_MSB = 34,
	STMPE_IDX_ISGPIOR_LSB = 35,
	STMPE_IDX_ISGPIOR_CSB = 36,
	STMPE_IDX_ISGPIOR_MSB = 37,
	STMPE_IDX_MAX = 38,
};

struct stmpe_client_info;

struct stmpe_variant_info;

struct stmpe_platform_data;

struct stmpe {
	struct regulator *vcc;
	struct regulator *vio;
	struct mutex lock;
	struct mutex irq_lock;
	struct device___145 *dev;
	struct irq_domain___26 *domain;
	void *client;
	struct stmpe_client_info *ci;
	enum stmpe_partnum partnum;
	struct stmpe_variant_info *variant;
	const u8 *regs;
	int irq;
	int num_gpios;
	u8 ier[2];
	u8 oldier[2];
	struct stmpe_platform_data *pdata;
	u8 sample_time;
	u8 mod_12b;
	u8 ref_sel;
	u8 adc_freq;
};

enum {
	REG_RE = 0,
	REG_FE = 1,
	REG_IE = 2,
};

enum {
	LSB = 0,
	CSB = 1,
	MSB = 2,
};

struct stmpe_gpio {
	struct gpio_chip___7 chip;
	struct stmpe *stmpe;
	struct device___145 *dev;
	struct mutex irq_lock;
	u32 norequest_mask;
	u8 regs[9];
	u8 oldregs[9];
};

struct tc3589x_platform_data;

struct tc3589x {
	struct mutex lock;
	struct device___145 *dev;
	struct i2c_client *i2c;
	struct irq_domain___26 *domain;
	int irq_base;
	int num_gpio;
	struct tc3589x_platform_data *pdata;
};

struct tc3589x_platform_data {
	unsigned int block;
};

enum {
	REG_IBE = 0,
	REG_IEV = 1,
	REG_IS = 2,
	REG_IE___2 = 3,
	REG_DIRECT = 4,
};

struct tc3589x_gpio {
	struct gpio_chip___7 chip;
	struct tc3589x *tc3589x;
	struct device___145 *dev;
	struct mutex irq_lock;
	u8 regs[15];
	u8 oldregs[15];
};

struct tegra_gpio_port {
	const char *name;
	unsigned int bank;
	unsigned int port;
	unsigned int pins;
};

struct tegra186_pin_range {
	unsigned int offset;
	const char *group;
};

struct tegra_gpio_soc {
	const struct tegra_gpio_port *ports;
	unsigned int num_ports;
	const char *name;
	unsigned int instance;
	const struct tegra186_pin_range *pin_ranges;
	unsigned int num_pin_ranges;
	const char *pinmux;
};

struct tegra_gpio {
	struct gpio_chip___7 gpio;
	struct irq_chip___27 intc;
	unsigned int num_irq;
	unsigned int *irq;
	const struct tegra_gpio_soc *soc;
	void *secure;
	void *base;
};

struct tegra_gpio_bank {
	unsigned int bank;
	raw_spinlock_t lvl_lock[4];
	spinlock_t dbc_lock[4];
	u32 cnf[4];
	u32 out[4];
	u32 oe[4];
	u32 int_enb[4];
	u32 int_lvl[4];
	u32 wake_enb[4];
	u32 dbc_enb[4];
	u32 dbc_cnt[4];
};

struct tegra_gpio_soc_config {
	bool debounce_supported;
	u32 bank_stride;
	u32 upper_offset;
};

struct tegra_gpio_info {
	struct device___145 *dev;
	void *regs;
	struct tegra_gpio_bank *bank_info;
	const struct tegra_gpio_soc_config *soc;
	struct gpio_chip___7 gc;
	struct irq_chip___27 ic;
	u32 bank_count;
	unsigned int *irqs;
};

enum {
	TPS6586X_ID_SYS = 0,
	TPS6586X_ID_SM_0 = 1,
	TPS6586X_ID_SM_1 = 2,
	TPS6586X_ID_SM_2 = 3,
	TPS6586X_ID_LDO_0 = 4,
	TPS6586X_ID_LDO_1 = 5,
	TPS6586X_ID_LDO_2 = 6,
	TPS6586X_ID_LDO_3 = 7,
	TPS6586X_ID_LDO_4 = 8,
	TPS6586X_ID_LDO_5 = 9,
	TPS6586X_ID_LDO_6 = 10,
	TPS6586X_ID_LDO_7 = 11,
	TPS6586X_ID_LDO_8 = 12,
	TPS6586X_ID_LDO_9 = 13,
	TPS6586X_ID_LDO_RTC = 14,
	TPS6586X_ID_MAX_REGULATOR = 15,
};

enum {
	TPS6586X_INT_PLDO_0 = 0,
	TPS6586X_INT_PLDO_1 = 1,
	TPS6586X_INT_PLDO_2 = 2,
	TPS6586X_INT_PLDO_3 = 3,
	TPS6586X_INT_PLDO_4 = 4,
	TPS6586X_INT_PLDO_5 = 5,
	TPS6586X_INT_PLDO_6 = 6,
	TPS6586X_INT_PLDO_7 = 7,
	TPS6586X_INT_COMP_DET = 8,
	TPS6586X_INT_ADC = 9,
	TPS6586X_INT_PLDO_8 = 10,
	TPS6586X_INT_PLDO_9 = 11,
	TPS6586X_INT_PSM_0 = 12,
	TPS6586X_INT_PSM_1 = 13,
	TPS6586X_INT_PSM_2 = 14,
	TPS6586X_INT_PSM_3 = 15,
	TPS6586X_INT_RTC_ALM1 = 16,
	TPS6586X_INT_ACUSB_OVP = 17,
	TPS6586X_INT_USB_DET = 18,
	TPS6586X_INT_AC_DET = 19,
	TPS6586X_INT_BAT_DET = 20,
	TPS6586X_INT_CHG_STAT = 21,
	TPS6586X_INT_CHG_TEMP = 22,
	TPS6586X_INT_PP = 23,
	TPS6586X_INT_RESUME = 24,
	TPS6586X_INT_LOW_SYS = 25,
	TPS6586X_INT_RTC_ALM2 = 26,
};

struct tps6586x_subdev_info {
	int id;
	const char *name;
	void *platform_data;
	struct device_node___47 *of_node;
};

struct tps6586x_platform_data {
	int num_subdevs;
	struct tps6586x_subdev_info *subdevs;
	int gpio_base;
	int irq_base;
	bool pm_off;
	struct regulator_init_data *reg_init_data[15];
};

struct tps6586x_gpio {
	struct gpio_chip___7 gpio_chip;
	struct device___145 *parent;
};

struct dentry___189;

struct super_block___189;

struct module___173;

struct file_system_type___189 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___189 * (*mount)(struct file_system_type___189 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___189 *);
	struct module___173 *owner;
	struct file_system_type___189 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___189;

struct kiocb___189;

struct iov_iter___112;

struct poll_table_struct___123;

struct vm_area_struct___194;

struct inode___189;

struct file_lock___189;

struct page___194;

struct seq_file___165;

struct file_operations___190 {
	struct module___173 *owner;
	loff_t (*llseek)(struct file___189 *, loff_t, int);
	ssize_t (*read)(struct file___189 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___189 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___189 *, struct iov_iter___112 *);
	ssize_t (*write_iter)(struct kiocb___189 *, struct iov_iter___112 *);
	int (*iopoll)(struct kiocb___189 *, bool);
	int (*iterate)(struct file___189 *, struct dir_context *);
	int (*iterate_shared)(struct file___189 *, struct dir_context *);
	__poll_t (*poll)(struct file___189 *, struct poll_table_struct___123 *);
	long int (*unlocked_ioctl)(struct file___189 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___189 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___189 *, struct vm_area_struct___194 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___189 *, struct file___189 *);
	int (*flush)(struct file___189 *, fl_owner_t);
	int (*release)(struct inode___189 *, struct file___189 *);
	int (*fsync)(struct file___189 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___189 *, int);
	int (*lock)(struct file___189 *, int, struct file_lock___189 *);
	ssize_t (*sendpage)(struct file___189 *, struct page___194 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___189 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___189 *, long unsigned int);
	int (*flock)(struct file___189 *, int, struct file_lock___189 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___189 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___189 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___189 *, long int, struct file_lock___189 **, void **);
	long int (*fallocate)(struct file___189 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___165 *, struct file___189 *);
	ssize_t (*copy_file_range)(struct file___189 *, loff_t, struct file___189 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___189 *, loff_t, struct file___189 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___189 *, loff_t, loff_t, int);
};

struct vmacache___194 {
	u64 seqnum;
	struct vm_area_struct___194 *vmas[4];
};

struct page_frag___194 {
	struct page___194 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___195;

struct pid___167;

struct nsproxy___176;

struct signal_struct___190;

struct bio_list___94;

struct backing_dev_info___87;

struct io_context___94;

struct css_set___128;

struct mem_cgroup___78;

struct request_queue___94;

struct vm_struct___172;

struct task_struct___196 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___196 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___195 *mm;
	struct mm_struct___195 *active_mm;
	struct vmacache___194 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___196 *real_parent;
	struct task_struct___196 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___196 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___167 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___176 *nsproxy;
	struct signal_struct___190 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___196 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___94 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___87 *backing_dev_info;
	struct io_context___94 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___128 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___194 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___78 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___78 *active_memcg;
	struct request_queue___94 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___196 *oom_reaper_list;
	struct vm_struct___172 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___73 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___177;

struct kobj_type___177;

struct kernfs_node___177;

struct kobject___177 {
	const char *name;
	struct list_head entry;
	struct kobject___177 *parent;
	struct kset___177 *kset;
	struct kobj_type___177 *ktype;
	struct kernfs_node___177 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___173 {
	struct kobject___177 kobj;
	struct module___173 *mod;
	struct kobject___177 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___173 {
	struct module___173 *mod;
	struct latch_tree_node node;
};

struct module_layout___173 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___173 mtn;
};

struct module_attribute___173;

struct kernel_param___173;

struct module___173 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___173 mkobj;
	struct module_attribute___173 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___177 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___173 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___173 core_layout;
	struct module_layout___173 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___167;

struct upid___167 {
	int nr;
	struct pid_namespace___167 *ns;
};

struct pid_namespace___167 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___196 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___167 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___167 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___167 numbers[1];
};

typedef struct page___194 *pgtable_t___194;

struct address_space___189;

struct dev_pagemap___184;

struct page___194 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___189 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___194 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___194 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___195 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___184 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct rt_mutex_base___5 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___196 *owner;
};

struct rt_mutex___4 {
	struct rt_mutex_base___5 rtmutex;
};

struct vm_operations_struct___184;

struct vm_area_struct___194 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___194 *vm_next;
	struct vm_area_struct___194 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___195 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___184 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___189 *vm_file;
	struct file___189 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___190 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___196 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___196 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___167 *pids[4];
	struct pid___167 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___195 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___194;

struct mm_struct___195 {
	struct {
		struct vm_area_struct___194 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___189 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___194 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___196 *owner;
		struct user_namespace___25 *user_ns;
		struct file___189 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___128;

struct nsproxy___176 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___167 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___128 *cgroup_ns;
};

struct bio___94;

struct bio_list___94 {
	struct bio___94 *head;
	struct bio___94 *tail;
};

struct cgroup_subsys_state___128;

struct bdi_writeback___87 {
	struct backing_dev_info___87 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___128 *memcg_css;
	struct cgroup_subsys_state___128 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___147;

struct backing_dev_info___87 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___87 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___147 *dev;
	char dev_name[64];
	struct device___147 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___189 *debug_dir;
};

struct io_cq___94;

struct io_context___94 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___94 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___128;

struct css_set___128 {
	struct cgroup_subsys_state___128 *subsys[14];
	refcount_t refcount;
	struct css_set___128 *dom_cset;
	struct cgroup___128 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___128 *mg_src_cgrp;
	struct cgroup___128 *mg_dst_cgrp;
	struct css_set___128 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___128;

struct cgroup_subsys_state___128 {
	struct cgroup___128 *cgroup;
	struct cgroup_subsys___128 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___128 *parent;
};

struct cgroup_file___128 {
	struct kernfs_node___177 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___78;

struct mem_cgroup_per_node___78;

struct mem_cgroup___78 {
	struct cgroup_subsys_state___128 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___128 events_file;
	struct cgroup_file___128 events_local_file;
	struct cgroup_file___128 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___78 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___196 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___78 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___94;

struct blk_integrity___94 {
	const struct blk_integrity_profile___94 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___94 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___94 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___94;

struct elevator_queue___94;

struct blk_mq_ops___91;

struct blk_mq_hw_ctx___91;

struct gendisk___95;

struct blkcg_gq___89;

struct blk_mq_tag_set___91;

struct request_queue___94 {
	struct request___94 *last_merge;
	struct elevator_queue___94 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___91 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___91 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___95 *disk;
	struct kobject___177 kobj;
	struct kobject___177 *mq_kobj;
	struct blk_integrity___94 integrity;
	struct device___147 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___89 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___91 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___94 bio_split;
	struct dentry___189 *debugfs_dir;
	struct dentry___189 *sched_debugfs_dir;
	struct dentry___189 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___172 {
	struct vm_struct___172 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___194 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___189;

struct address_space___189 {
	struct inode___189 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___189 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___184;

struct dev_pagemap___184 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___184 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___189;

struct path___189 {
	struct vfsmount___189 *mnt;
	struct dentry___189 *dentry;
};

struct fown_struct___167 {
	rwlock_t lock;
	struct pid___167 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___189 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___189 f_path;
	struct inode___189 *f_inode;
	const struct file_operations___190 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___167 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___189 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___184;

struct vm_operations_struct___184 {
	void (*open)(struct vm_area_struct___194 *);
	void (*close)(struct vm_area_struct___194 *);
	int (*may_split)(struct vm_area_struct___194 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___194 *);
	int (*mprotect)(struct vm_area_struct___194 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___184 *);
	vm_fault_t (*huge_fault)(struct vm_fault___184 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___184 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___194 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___184 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___184 *);
	int (*access)(struct vm_area_struct___194 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___194 *);
	int (*set_policy)(struct vm_area_struct___194 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___194 *, long unsigned int);
	struct page___194 * (*find_special_page)(struct vm_area_struct___194 *, long unsigned int);
};

struct core_thread___194 {
	struct task_struct___196 *task;
	struct core_thread___194 *next;
};

struct core_state___194 {
	atomic_t nr_threads;
	struct core_thread___194 dumper;
	struct completion startup;
};

struct vm_fault___184 {
	const struct {
		struct vm_area_struct___194 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___194 *cow_page;
	struct page___194 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___194 prealloc_pte;
};

struct pglist_data___85;

struct lruvec___85 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___85 *pgdat;
};

struct zone___85 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___85 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___85 {
	struct zone___85 *zone;
	int zone_idx;
};

struct zonelist___85 {
	struct zoneref___85 _zonerefs[321];
};

struct pglist_data___85 {
	struct zone___85 node_zones[5];
	struct zonelist___85 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___196 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___196 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___85 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___177;

struct kernfs_elem_dir___177 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___177 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___177;

struct kernfs_root___177 {
	struct kernfs_node___177 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___177 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___177 {
	struct kernfs_node___177 *target_kn;
};

struct kernfs_ops___177;

struct kernfs_elem_attr___177 {
	const struct kernfs_ops___177 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___177 *notify_next;
};

struct kernfs_node___177 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___177 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___177 dir;
		struct kernfs_elem_symlink___177 symlink;
		struct kernfs_elem_attr___177 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___177;

struct kernfs_ops___177 {
	int (*open)(struct kernfs_open_file___177 *);
	void (*release)(struct kernfs_open_file___177 *);
	int (*seq_show)(struct seq_file___165 *, void *);
	void * (*seq_start)(struct seq_file___165 *, loff_t *);
	void * (*seq_next)(struct seq_file___165 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___165 *, void *);
	ssize_t (*read)(struct kernfs_open_file___177 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___177 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___177 *, struct poll_table_struct___123 *);
	int (*mmap)(struct kernfs_open_file___177 *, struct vm_area_struct___194 *);
};

struct kernfs_syscall_ops___177 {
	int (*show_options)(struct seq_file___165 *, struct kernfs_root___177 *);
	int (*mkdir)(struct kernfs_node___177 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___177 *);
	int (*rename)(struct kernfs_node___177 *, struct kernfs_node___177 *, const char *);
	int (*show_path)(struct seq_file___165 *, struct kernfs_node___177 *, struct kernfs_root___177 *);
};

struct seq_operations___165;

struct seq_file___165 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___165 *op;
	int poll_event;
	const struct file___189 *file;
	void *private;
};

struct kernfs_open_file___177 {
	struct kernfs_node___177 *kn;
	struct file___189 *file;
	struct seq_file___165 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___184 *vm_ops;
};

typedef void (*poll_queue_proc___128)(struct file___189 *, wait_queue_head_t *, struct poll_table_struct___123 *);

struct poll_table_struct___123 {
	poll_queue_proc___128 _qproc;
	__poll_t _key;
};

struct bin_attribute___177;

struct attribute_group___177 {
	const char *name;
	umode_t (*is_visible)(struct kobject___177 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___177 *, struct bin_attribute___177 *, int);
	struct attribute **attrs;
	struct bin_attribute___177 **bin_attrs;
};

struct bin_attribute___177 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___189 * (*f_mapping)();
	ssize_t (*read)(struct file___189 *, struct kobject___177 *, struct bin_attribute___177 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___189 *, struct kobject___177 *, struct bin_attribute___177 *, char *, loff_t, size_t);
	int (*mmap)(struct file___189 *, struct kobject___177 *, struct bin_attribute___177 *, struct vm_area_struct___194 *);
};

struct sysfs_ops___177 {
	ssize_t (*show)(struct kobject___177 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___177 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___177;

struct kset___177 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___177 kobj;
	const struct kset_uevent_ops___177 *uevent_ops;
};

struct kobj_type___177 {
	void (*release)(struct kobject___177 *);
	const struct sysfs_ops___177 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___177 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___177 *);
	const void * (*namespace)(struct kobject___177 *);
	void (*get_ownership)(struct kobject___177 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___177 {
	int (* const filter)(struct kset___177 *, struct kobject___177 *);
	const char * (* const name)(struct kset___177 *, struct kobject___177 *);
	int (* const uevent)(struct kset___177 *, struct kobject___177 *, struct kobj_uevent_env *);
};

struct wakeup_source___147;

struct dev_pm_info___147 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___147 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___147 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___147;

struct bus_type___147;

struct device_driver___147;

struct dev_pm_domain___147;

struct irq_domain___28;

struct device_node___49;

struct fwnode_handle___147;

struct class___147;

struct device___147 {
	struct kobject___177 kobj;
	struct device___147 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___147 *type;
	struct bus_type___147 *bus;
	struct device_driver___147 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___147 power;
	struct dev_pm_domain___147 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___28 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___49 *of_node;
	struct fwnode_handle___147 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___147 *class;
	const struct attribute_group___177 **groups;
	void (*release)(struct device___147 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___147 {
	int (*prepare)(struct device___147 *);
	void (*complete)(struct device___147 *);
	int (*suspend)(struct device___147 *);
	int (*resume)(struct device___147 *);
	int (*freeze)(struct device___147 *);
	int (*thaw)(struct device___147 *);
	int (*poweroff)(struct device___147 *);
	int (*restore)(struct device___147 *);
	int (*suspend_late)(struct device___147 *);
	int (*resume_early)(struct device___147 *);
	int (*freeze_late)(struct device___147 *);
	int (*thaw_early)(struct device___147 *);
	int (*poweroff_late)(struct device___147 *);
	int (*restore_early)(struct device___147 *);
	int (*suspend_noirq)(struct device___147 *);
	int (*resume_noirq)(struct device___147 *);
	int (*freeze_noirq)(struct device___147 *);
	int (*thaw_noirq)(struct device___147 *);
	int (*poweroff_noirq)(struct device___147 *);
	int (*restore_noirq)(struct device___147 *);
	int (*runtime_suspend)(struct device___147 *);
	int (*runtime_resume)(struct device___147 *);
	int (*runtime_idle)(struct device___147 *);
};

struct wakeup_source___147 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___147 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___147 {
	struct dev_pm_ops___147 ops;
	int (*start)(struct device___147 *);
	void (*detach)(struct device___147 *, bool);
	int (*activate)(struct device___147 *);
	void (*sync)(struct device___147 *);
	void (*dismiss)(struct device___147 *);
};

struct bus_type___147 {
	const char *name;
	const char *dev_name;
	struct device___147 *dev_root;
	const struct attribute_group___177 **bus_groups;
	const struct attribute_group___177 **dev_groups;
	const struct attribute_group___177 **drv_groups;
	int (*match)(struct device___147 *, struct device_driver___147 *);
	int (*uevent)(struct device___147 *, struct kobj_uevent_env *);
	int (*probe)(struct device___147 *);
	void (*sync_state)(struct device___147 *);
	void (*remove)(struct device___147 *);
	void (*shutdown)(struct device___147 *);
	int (*online)(struct device___147 *);
	int (*offline)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	int (*num_vf)(struct device___147 *);
	int (*dma_configure)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___147 {
	const char *name;
	struct bus_type___147 *bus;
	struct module___173 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___147 *);
	void (*sync_state)(struct device___147 *);
	int (*remove)(struct device___147 *);
	void (*shutdown)(struct device___147 *);
	int (*suspend)(struct device___147 *, pm_message_t);
	int (*resume)(struct device___147 *);
	const struct attribute_group___177 **groups;
	const struct attribute_group___177 **dev_groups;
	const struct dev_pm_ops___147 *pm;
	void (*coredump)(struct device___147 *);
	struct driver_private *p;
};

struct device_type___147 {
	const char *name;
	const struct attribute_group___177 **groups;
	int (*uevent)(struct device___147 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___147 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___147 *);
	const struct dev_pm_ops___147 *pm;
};

struct class___147 {
	const char *name;
	struct module___173 *owner;
	const struct attribute_group___177 **class_groups;
	const struct attribute_group___177 **dev_groups;
	struct kobject___177 *dev_kobj;
	int (*dev_uevent)(struct device___147 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___147 *, umode_t *);
	void (*class_release)(struct class___147 *);
	void (*dev_release)(struct device___147 *);
	int (*shutdown_pre)(struct device___147 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___147 *);
	void (*get_ownership)(struct device___147 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___147 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___28;

struct irq_domain_chip_generic___28;

struct irq_data___29;

struct irq_domain___28 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___28 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___147 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___28 *gc;
	struct irq_domain___28 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___29 *revmap[0];
};

struct fwnode_operations___147;

struct fwnode_handle___147 {
	struct fwnode_handle___147 *secondary;
	const struct fwnode_operations___147 *ops;
	struct device___147 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___39;

struct device_node___49 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___147 fwnode;
	struct property___39 *properties;
	struct property___39 *deadprops;
	struct device_node___49 *parent;
	struct device_node___49 *child;
	struct device_node___49 *sibling;
	struct kobject___177 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___30;

typedef void (*irq_flow_handler_t___30)(struct irq_desc___30 *);

struct irq_chip___29;

struct irq_data___29 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___29 *chip;
	struct irq_domain___28 *domain;
	struct irq_data___29 *parent_data;
	void *chip_data;
};

struct irqaction___20;

struct irq_desc___30 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___29 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___30 handle_irq;
	struct irqaction___20 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___177 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___173 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___147;

struct fwnode_endpoint___147;

struct fwnode_operations___147 {
	struct fwnode_handle___147 * (*get)(struct fwnode_handle___147 *);
	void (*put)(struct fwnode_handle___147 *);
	bool (*device_is_available)(const struct fwnode_handle___147 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___147 *, const struct device___147 *);
	bool (*property_present)(const struct fwnode_handle___147 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___147 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___147 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___147 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*get_parent)(const struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*get_next_child_node)(const struct fwnode_handle___147 *, struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*get_named_child_node)(const struct fwnode_handle___147 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___147 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___147 *);
	struct fwnode_handle___147 * (*graph_get_next_endpoint)(const struct fwnode_handle___147 *, struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*graph_get_remote_endpoint)(const struct fwnode_handle___147 *);
	struct fwnode_handle___147 * (*graph_get_port_parent)(struct fwnode_handle___147 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___147 *, struct fwnode_endpoint___147 *);
	int (*add_links)(struct fwnode_handle___147 *);
};

struct fwnode_endpoint___147 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___147 *local_fwnode;
};

struct fwnode_reference_args___147 {
	struct fwnode_handle___147 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___29 {
	struct device___147 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___29 *);
	void (*irq_shutdown)(struct irq_data___29 *);
	void (*irq_enable)(struct irq_data___29 *);
	void (*irq_disable)(struct irq_data___29 *);
	void (*irq_ack)(struct irq_data___29 *);
	void (*irq_mask)(struct irq_data___29 *);
	void (*irq_mask_ack)(struct irq_data___29 *);
	void (*irq_unmask)(struct irq_data___29 *);
	void (*irq_eoi)(struct irq_data___29 *);
	int (*irq_set_affinity)(struct irq_data___29 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___29 *);
	int (*irq_set_type)(struct irq_data___29 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___29 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___29 *);
	void (*irq_bus_sync_unlock)(struct irq_data___29 *);
	void (*irq_cpu_online)(struct irq_data___29 *);
	void (*irq_cpu_offline)(struct irq_data___29 *);
	void (*irq_suspend)(struct irq_data___29 *);
	void (*irq_resume)(struct irq_data___29 *);
	void (*irq_pm_shutdown)(struct irq_data___29 *);
	void (*irq_calc_mask)(struct irq_data___29 *);
	void (*irq_print_chip)(struct irq_data___29 *, struct seq_file___165 *);
	int (*irq_request_resources)(struct irq_data___29 *);
	void (*irq_release_resources)(struct irq_data___29 *);
	void (*irq_compose_msi_msg)(struct irq_data___29 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___29 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___29 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___29 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___29 *, void *);
	void (*ipi_send_single)(struct irq_data___29 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___29 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___29 *);
	void (*irq_nmi_teardown)(struct irq_data___29 *);
	long unsigned int flags;
};

struct irqaction___20 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___20 *next;
	irq_handler_t thread_fn;
	struct task_struct___196 *thread;
	struct irqaction___20 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___28 {
	struct irq_chip___29 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___30 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___28 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___28 *);
	void (*resume)(struct irq_chip_generic___28 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___28 *domain;
	struct list_head list;
	struct irq_chip_type___28 chip_types[0];
};

struct irq_domain_chip_generic___28 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___28 *gc[0];
};

struct property___39 {
	char *name;
	int length;
	void *value;
	struct property___39 *next;
	long unsigned int _flags;
	struct bin_attribute___177 attr;
};

struct of_phandle_args___16 {
	struct device_node___49 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___26 {
	struct fwnode_handle___147 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___28 {
	int (*match)(struct irq_domain___28 *, struct device_node___49 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___28 *, struct irq_fwspec___26 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___28 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___28 *, unsigned int);
	int (*xlate)(struct irq_domain___28 *, struct device_node___49 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___28 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___28 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___28 *, struct irq_data___29 *, bool);
	void (*deactivate)(struct irq_domain___28 *, struct irq_data___29 *);
	int (*translate)(struct irq_domain___28 *, struct irq_fwspec___26 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___189;

struct dentry___189 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___189 *d_parent;
	struct qstr d_name;
	struct inode___189 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___189 *d_op;
	struct super_block___189 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___189;

struct cdev___38;

struct inode___189 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___189 *i_op;
	struct super_block___189 *i_sb;
	struct address_space___189 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___87 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___190 *i_fop;
		void (*free_inode)(struct inode___189 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___189 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___38 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___189 {
	int (*d_revalidate)(struct dentry___189 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___189 *, unsigned int);
	int (*d_hash)(const struct dentry___189 *, struct qstr *);
	int (*d_compare)(const struct dentry___189 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___189 *);
	int (*d_init)(struct dentry___189 *);
	void (*d_release)(struct dentry___189 *);
	void (*d_prune)(struct dentry___189 *);
	void (*d_iput)(struct dentry___189 *, struct inode___189 *);
	char * (*d_dname)(struct dentry___189 *, char *, int);
	struct vfsmount___189 * (*d_automount)(struct path___189 *);
	int (*d_manage)(const struct path___189 *, bool);
	struct dentry___189 * (*d_real)(struct dentry___189 *, const struct inode___189 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___189;

struct mem_dqinfo___189 {
	struct quota_format_type___189 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___189;

struct quota_info___189 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___189 *files[3];
	struct mem_dqinfo___189 info[3];
	const struct quota_format_ops___189 *ops[3];
};

struct rcuwait___190 {
	struct task_struct___196 *task;
};

struct percpu_rw_semaphore___190 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___190 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___189 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___190 rw_sem[3];
};

struct shrink_control___78;

struct shrinker___78 {
	long unsigned int (*count_objects)(struct shrinker___78 *, struct shrink_control___78 *);
	long unsigned int (*scan_objects)(struct shrinker___78 *, struct shrink_control___78 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___189;

struct dquot_operations___189;

struct quotactl_ops___189;

struct block_device___95;

struct super_block___189 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___189 *s_type;
	const struct super_operations___189 *s_op;
	const struct dquot_operations___189 *dq_op;
	const struct quotactl_ops___189 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___189 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___95 *s_bdev;
	struct backing_dev_info___87 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___189 s_dquot;
	struct sb_writers___189 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___189 *s_d_op;
	int cleancache_poolid;
	struct shrinker___78 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___189 {
	struct dentry___189 *mnt_root;
	struct super_block___189 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___78 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___78 *memcg;
};

struct psi_group___128 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___196 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___128;

struct cgroup_rstat_cpu___128;

struct cgroup___128 {
	struct cgroup_subsys_state___128 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___177 *kn;
	struct cgroup_file___128 procs_file;
	struct cgroup_file___128 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___128 *subsys[14];
	struct cgroup_root___128 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___128 *dom_cgrp;
	struct cgroup___128 *old_dom_cgrp;
	struct cgroup_rstat_cpu___128 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___128 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___94 {
	struct request_queue___94 *q;
	struct io_context___94 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___87;

struct kiocb___189 {
	struct file___189 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___189 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___87 *ki_waitq;
	};
};

struct iattr___189 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___189 *ia_file;
};

struct dquot___189 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___189 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___189 {
	int qf_fmt_id;
	const struct quota_format_ops___189 *qf_ops;
	struct module___173 *qf_owner;
	struct quota_format_type___189 *qf_next;
};

struct quota_format_ops___189 {
	int (*check_quota_file)(struct super_block___189 *, int);
	int (*read_file_info)(struct super_block___189 *, int);
	int (*write_file_info)(struct super_block___189 *, int);
	int (*free_file_info)(struct super_block___189 *, int);
	int (*read_dqblk)(struct dquot___189 *);
	int (*commit_dqblk)(struct dquot___189 *);
	int (*release_dqblk)(struct dquot___189 *);
	int (*get_next_id)(struct super_block___189 *, struct kqid *);
};

struct dquot_operations___189 {
	int (*write_dquot)(struct dquot___189 *);
	struct dquot___189 * (*alloc_dquot)(struct super_block___189 *, int);
	void (*destroy_dquot)(struct dquot___189 *);
	int (*acquire_dquot)(struct dquot___189 *);
	int (*release_dquot)(struct dquot___189 *);
	int (*mark_dirty)(struct dquot___189 *);
	int (*write_info)(struct super_block___189 *, int);
	qsize_t * (*get_reserved_space)(struct inode___189 *);
	int (*get_projid)(struct inode___189 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___189 *, qsize_t *);
	int (*get_next_id)(struct super_block___189 *, struct kqid *);
};

struct quotactl_ops___189 {
	int (*quota_on)(struct super_block___189 *, int, int, const struct path___189 *);
	int (*quota_off)(struct super_block___189 *, int);
	int (*quota_enable)(struct super_block___189 *, unsigned int);
	int (*quota_disable)(struct super_block___189 *, unsigned int);
	int (*quota_sync)(struct super_block___189 *, int);
	int (*set_info)(struct super_block___189 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___189 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___189 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___189 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___189 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___189 *, unsigned int);
};

struct wait_page_queue___87 {
	struct page___194 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___87;

struct readahead_control___87;

struct swap_info_struct___46;

struct address_space_operations___189 {
	int (*writepage)(struct page___194 *, struct writeback_control___87 *);
	int (*readpage)(struct file___189 *, struct page___194 *);
	int (*writepages)(struct address_space___189 *, struct writeback_control___87 *);
	int (*set_page_dirty)(struct page___194 *);
	int (*readpages)(struct file___189 *, struct address_space___189 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___87 *);
	int (*write_begin)(struct file___189 *, struct address_space___189 *, loff_t, unsigned int, unsigned int, struct page___194 **, void **);
	int (*write_end)(struct file___189 *, struct address_space___189 *, loff_t, unsigned int, unsigned int, struct page___194 *, void *);
	sector_t (*bmap)(struct address_space___189 *, sector_t);
	void (*invalidatepage)(struct page___194 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___194 *, gfp_t);
	void (*freepage)(struct page___194 *);
	ssize_t (*direct_IO)(struct kiocb___189 *, struct iov_iter___112 *);
	int (*migratepage)(struct address_space___189 *, struct page___194 *, struct page___194 *, enum migrate_mode);
	bool (*isolate_page)(struct page___194 *, isolate_mode_t);
	void (*putback_page)(struct page___194 *);
	int (*launder_page)(struct page___194 *);
	int (*is_partially_uptodate)(struct page___194 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___194 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___189 *, struct page___194 *);
	int (*swap_activate)(struct swap_info_struct___46 *, struct file___189 *, sector_t *);
	void (*swap_deactivate)(struct file___189 *);
};

struct writeback_control___87 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___87 *wb;
	struct inode___189 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___87 {
	struct file___189 *file;
	struct address_space___189 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___110;

struct iov_iter___112 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___110 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___46 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___95 *bdev;
	struct file___189 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___38 {
	struct kobject___177 kobj;
	struct module___173 *owner;
	const struct file_operations___190 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___189 {
	struct dentry___189 * (*lookup)(struct inode___189 *, struct dentry___189 *, unsigned int);
	const char * (*get_link)(struct dentry___189 *, struct inode___189 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___189 *, int);
	struct posix_acl * (*get_acl)(struct inode___189 *, int, bool);
	int (*readlink)(struct dentry___189 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___189 *, struct dentry___189 *, umode_t, bool);
	int (*link)(struct dentry___189 *, struct inode___189 *, struct dentry___189 *);
	int (*unlink)(struct inode___189 *, struct dentry___189 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___189 *, struct dentry___189 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___189 *, struct dentry___189 *, umode_t);
	int (*rmdir)(struct inode___189 *, struct dentry___189 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___189 *, struct dentry___189 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___189 *, struct dentry___189 *, struct inode___189 *, struct dentry___189 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___189 *, struct iattr___189 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___189 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___189 *, char *, size_t);
	int (*fiemap)(struct inode___189 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___189 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___189 *, struct dentry___189 *, struct file___189 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___189 *, struct dentry___189 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___189 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___189 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___189 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___189 {
	void (*fl_copy_lock)(struct file_lock___189 *, struct file_lock___189 *);
	void (*fl_release_private)(struct file_lock___189 *);
};

struct fasync_struct___189;

struct lock_manager_operations___189;

struct file_lock___189 {
	struct file_lock___189 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___189 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___189 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___189 *fl_ops;
	const struct lock_manager_operations___189 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___189 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___189 *);
	int (*lm_grant)(struct file_lock___189 *, int);
	bool (*lm_break)(struct file_lock___189 *);
	int (*lm_change)(struct file_lock___189 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___189 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___189 *);
};

struct fasync_struct___189 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___189 *fa_next;
	struct file___189 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___189 {
	struct inode___189 * (*alloc_inode)(struct super_block___189 *);
	void (*destroy_inode)(struct inode___189 *);
	void (*free_inode)(struct inode___189 *);
	void (*dirty_inode)(struct inode___189 *, int);
	int (*write_inode)(struct inode___189 *, struct writeback_control___87 *);
	int (*drop_inode)(struct inode___189 *);
	void (*evict_inode)(struct inode___189 *);
	void (*put_super)(struct super_block___189 *);
	int (*sync_fs)(struct super_block___189 *, int);
	int (*freeze_super)(struct super_block___189 *);
	int (*freeze_fs)(struct super_block___189 *);
	int (*thaw_super)(struct super_block___189 *);
	int (*unfreeze_fs)(struct super_block___189 *);
	int (*statfs)(struct dentry___189 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___189 *, int *, char *);
	void (*umount_begin)(struct super_block___189 *);
	int (*show_options)(struct seq_file___165 *, struct dentry___189 *);
	int (*show_devname)(struct seq_file___165 *, struct dentry___189 *);
	int (*show_path)(struct seq_file___165 *, struct dentry___189 *);
	int (*show_stats)(struct seq_file___165 *, struct dentry___189 *);
	ssize_t (*quota_read)(struct super_block___189 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___189 *, int, const char *, size_t, loff_t);
	struct dquot___189 ** (*get_dquots)(struct inode___189 *);
	long int (*nr_cached_objects)(struct super_block___189 *, struct shrink_control___78 *);
	long int (*free_cached_objects)(struct super_block___189 *, struct shrink_control___78 *);
	struct file___189 * (*real_loop)(struct file___189 *);
};

struct block_device___95 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___189 *bd_inode;
	struct super_block___189 *bd_super;
	void *bd_claiming;
	struct device___147 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___177 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___95 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___189 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___94(struct bio___94 *);

struct bio_vec___110 {
	struct page___194 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___94;

struct bio___94 {
	struct bio___94 *bi_next;
	struct block_device___95 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___94 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___89 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___94 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___110 *bi_io_vec;
	struct bio_set___94 *bi_pool;
	struct bio_vec___110 bi_inline_vecs[0];
};

struct seq_operations___165 {
	void * (*start)(struct seq_file___165 *, loff_t *);
	void (*stop)(struct seq_file___165 *, void *);
	void * (*next)(struct seq_file___165 *, void *, loff_t *);
	int (*show)(struct seq_file___165 *, void *);
};

struct gpio_chip___9;

struct gpio_irq_chip___9 {
	struct irq_chip___29 *chip;
	struct irq_domain___28 *domain;
	const struct irq_domain_ops___28 *domain_ops;
	struct fwnode_handle___147 *fwnode;
	struct irq_domain___28 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___9 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___9 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___9 *, unsigned int);
	struct irq_domain_ops___28 child_irq_domain_ops;
	irq_flow_handler_t___30 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___30 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___9 *);
	void (*init_valid_mask)(struct gpio_chip___9 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___29 *);
	void (*irq_disable)(struct irq_data___29 *);
	void (*irq_unmask)(struct irq_data___29 *);
	void (*irq_mask)(struct irq_data___29 *);
};

struct gpio_chip___9 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___147 *parent;
	struct module___173 *owner;
	int (*request)(struct gpio_chip___9 *, unsigned int);
	void (*free)(struct gpio_chip___9 *, unsigned int);
	int (*get_direction)(struct gpio_chip___9 *, unsigned int);
	int (*direction_input)(struct gpio_chip___9 *, unsigned int);
	int (*direction_output)(struct gpio_chip___9 *, unsigned int, int);
	int (*get)(struct gpio_chip___9 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___9 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___9 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___9 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___9 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___9 *, unsigned int);
	void (*dbg_show)(struct seq_file___165 *, struct gpio_chip___9 *);
	int (*init_valid_mask)(struct gpio_chip___9 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___9 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___9 irq;
	long unsigned int *valid_mask;
	struct device_node___49 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___9 *, const struct of_phandle_args___16 *, u32 *);
};

struct kernel_param_ops___173 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___173 *);
	int (*get)(char *, const struct kernel_param___173 *);
	void (*free)(void *);
};

struct kparam_array___173;

struct kernel_param___173 {
	const char *name;
	struct module___173 *mod;
	const struct kernel_param_ops___173 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___173 *arr;
	};
};

struct kparam_array___173 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___173 *ops;
	void *elem;
};

struct module_attribute___173 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___173 *, struct module_kobject___173 *, char *);
	ssize_t (*store)(struct module_attribute___173 *, struct module_kobject___173 *, const char *, size_t);
	void (*setup)(struct module___173 *, const char *);
	int (*test)(struct module___173 *);
	void (*free)(struct module___173 *);
};

struct dev_pagemap_ops___184 {
	void (*page_free)(struct page___194 *);
	void (*kill)(struct dev_pagemap___184 *);
	void (*cleanup)(struct dev_pagemap___184 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___184 *);
};

struct cgroup_namespace___128 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___128 *root_cset;
};

struct cftype___128;

struct cgroup_subsys___128 {
	struct cgroup_subsys_state___128 * (*css_alloc)(struct cgroup_subsys_state___128 *);
	int (*css_online)(struct cgroup_subsys_state___128 *);
	void (*css_offline)(struct cgroup_subsys_state___128 *);
	void (*css_released)(struct cgroup_subsys_state___128 *);
	void (*css_free)(struct cgroup_subsys_state___128 *);
	void (*css_reset)(struct cgroup_subsys_state___128 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___128 *, int);
	int (*css_extra_stat_show)(struct seq_file___165 *, struct cgroup_subsys_state___128 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___196 *, struct css_set___128 *);
	void (*cancel_fork)(struct task_struct___196 *, struct css_set___128 *);
	void (*fork)(struct task_struct___196 *);
	void (*exit)(struct task_struct___196 *);
	void (*release)(struct task_struct___196 *);
	void (*bind)(struct cgroup_subsys_state___128 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___128 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___128 *dfl_cftypes;
	struct cftype___128 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___128 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___128 *updated_children;
	struct cgroup___128 *updated_next;
};

struct cgroup_root___128 {
	struct kernfs_root___177 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___128 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___128 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___128 *ss;
	struct list_head node;
	struct kernfs_ops___177 *kf_ops;
	int (*open)(struct kernfs_open_file___177 *);
	void (*release)(struct kernfs_open_file___177 *);
	u64 (*read_u64)(struct cgroup_subsys_state___128 *, struct cftype___128 *);
	s64 (*read_s64)(struct cgroup_subsys_state___128 *, struct cftype___128 *);
	int (*seq_show)(struct seq_file___165 *, void *);
	void * (*seq_start)(struct seq_file___165 *, loff_t *);
	void * (*seq_next)(struct seq_file___165 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___165 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___128 *, struct cftype___128 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___128 *, struct cftype___128 *, s64);
	ssize_t (*write)(struct kernfs_open_file___177 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___177 *, struct poll_table_struct___123 *);
};

struct block_device_operations___94;

struct gendisk___95 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___95 *part0;
	const struct block_device_operations___94 *fops;
	struct request_queue___94 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___87 *bdi;
	struct kobject___177 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___177 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___94 {
	struct bio___94 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___110 *bip_vec;
	struct bio_vec___110 bip_inline_vecs[0];
};

struct blkcg___89;

struct blkg_policy_data___89;

struct blkcg_gq___89 {
	struct request_queue___94 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___89 *blkcg;
	struct blkcg_gq___89 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___89 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___94 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___94(struct request___94 *);

typedef void integrity_complete_fn___94(struct request___94 *, unsigned int);

struct blk_integrity_profile___94 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___94 *prepare_fn;
	integrity_complete_fn___94 *complete_fn;
	const char *name;
};

struct block_device_operations___94 {
	blk_qc_t (*submit_bio)(struct bio___94 *);
	int (*open)(struct block_device___95 *, fmode_t);
	void (*release)(struct gendisk___95 *, fmode_t);
	int (*rw_page)(struct block_device___95 *, sector_t, struct page___194 *, unsigned int);
	int (*ioctl)(struct block_device___95 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___95 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___95 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___95 *);
	int (*getgeo)(struct block_device___95 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___95 *, bool);
	void (*swap_slot_free_notify)(struct block_device___95 *, long unsigned int);
	int (*report_zones)(struct gendisk___95 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___95 *, umode_t *);
	struct module___173 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___95 *, sector_t *);
};

typedef void rq_end_io_fn___94(struct request___94 *, blk_status_t);

struct request___94 {
	struct request_queue___94 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___91 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___94 *bio;
	struct bio___94 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___110 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___94 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___94 *saved_end_io;
		} flush;
	};
	struct gendisk___95 *rq_disk;
	struct block_device___95 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___94 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___91 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___94 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___177 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___189 *debugfs_dir;
	struct dentry___189 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___94;

struct elevator_mq_ops___94 {
	int (*init_sched)(struct request_queue___94 *, struct elevator_type___94 *);
	void (*exit_sched)(struct elevator_queue___94 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___91 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___91 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___91 *);
	bool (*allow_merge)(struct request_queue___94 *, struct request___94 *, struct bio___94 *);
	bool (*bio_merge)(struct request_queue___94 *, struct bio___94 *, unsigned int);
	int (*request_merge)(struct request_queue___94 *, struct request___94 **, struct bio___94 *);
	void (*request_merged)(struct request_queue___94 *, struct request___94 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___94 *, struct request___94 *, struct request___94 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___94 *);
	void (*finish_request)(struct request___94 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___91 *, struct list_head *, bool);
	struct request___94 * (*dispatch_request)(struct blk_mq_hw_ctx___91 *);
	bool (*has_work)(struct blk_mq_hw_ctx___91 *);
	void (*completed_request)(struct request___94 *, u64);
	void (*requeue_request)(struct request___94 *);
	struct request___94 * (*former_request)(struct request_queue___94 *, struct request___94 *);
	struct request___94 * (*next_request)(struct request_queue___94 *, struct request___94 *);
	void (*init_icq)(struct io_cq___94 *);
	void (*exit_icq)(struct io_cq___94 *);
};

struct elv_fs_entry___94;

struct elevator_type___94 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___94 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___94 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___173 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___94 {
	struct elevator_type___94 *type;
	void *elevator_data;
	struct kobject___177 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___94 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___94 *, char *);
	ssize_t (*store)(struct elevator_queue___94 *, const char *, size_t);
};

struct blk_mq_queue_data___91;

struct blk_mq_ops___91 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___91 *, const struct blk_mq_queue_data___91 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___91 *);
	int (*get_budget)(struct request_queue___94 *);
	void (*put_budget)(struct request_queue___94 *, int);
	void (*set_rq_budget_token)(struct request___94 *, int);
	int (*get_rq_budget_token)(struct request___94 *);
	enum blk_eh_timer_return (*timeout)(struct request___94 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___91 *);
	void (*complete)(struct request___94 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___91 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___91 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___91 *, struct request___94 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___91 *, struct request___94 *, unsigned int);
	void (*initialize_rq_fn)(struct request___94 *);
	void (*cleanup_rq)(struct request___94 *);
	bool (*busy)(struct request_queue___94 *);
	int (*map_queues)(struct blk_mq_tag_set___91 *);
	void (*show_rq)(struct seq_file___165 *, struct request___94 *);
};

struct blk_mq_tag_set___91 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___91 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___91 {
	struct request___94 *rq;
	bool last;
};

struct blkcg_policy_data___89;

struct blkcg___89 {
	struct cgroup_subsys_state___128 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___89 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___89 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___89 {
	struct blkcg___89 *blkcg;
	int plid;
};

struct blkg_policy_data___89 {
	struct blkcg_gq___89 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___78 {
	struct mem_cgroup___78 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___78 {
	struct lruvec___85 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___78 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___78 *memcg;
};

struct obj_cgroup___78 {
	struct percpu_ref refcnt;
	struct mem_cgroup___78 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct i2c_client___3;

typedef int (*i2c_slave_cb_t___2)(struct i2c_client___3 *, enum i2c_slave_event, u8 *);

struct i2c_adapter___2;

struct i2c_client___3 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter___2 *adapter;
	struct device___147 dev;
	int init_irq;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t___2 slave_cb;
	void *devres_group_id;
};

struct i2c_algorithm___2;

struct i2c_lock_operations___2;

struct i2c_bus_recovery_info___2;

struct i2c_adapter___2 {
	struct module___173 *owner;
	unsigned int class;
	const struct i2c_algorithm___2 *algo;
	void *algo_data;
	const struct i2c_lock_operations___2 *lock_ops;
	struct rt_mutex___4 bus_lock;
	struct rt_mutex___4 mux_lock;
	int timeout;
	int retries;
	struct device___147 dev;
	long unsigned int locked_flags;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info___2 *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___28 *host_notify_domain;
	struct regulator *bus_regulator;
};

struct i2c_algorithm___2 {
	int (*master_xfer)(struct i2c_adapter___2 *, struct i2c_msg *, int);
	int (*master_xfer_atomic)(struct i2c_adapter___2 *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter___2 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	int (*smbus_xfer_atomic)(struct i2c_adapter___2 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter___2 *);
	int (*reg_slave)(struct i2c_client___3 *);
	int (*unreg_slave)(struct i2c_client___3 *);
};

struct i2c_lock_operations___2 {
	void (*lock_bus)(struct i2c_adapter___2 *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter___2 *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter___2 *, unsigned int);
};

struct i2c_bus_recovery_info___2 {
	int (*recover_bus)(struct i2c_adapter___2 *);
	int (*get_scl)(struct i2c_adapter___2 *);
	void (*set_scl)(struct i2c_adapter___2 *, int);
	int (*get_sda)(struct i2c_adapter___2 *);
	void (*set_sda)(struct i2c_adapter___2 *, int);
	int (*get_bus_free)(struct i2c_adapter___2 *);
	void (*prepare_recovery)(struct i2c_adapter___2 *);
	void (*unprepare_recovery)(struct i2c_adapter___2 *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
	struct pinctrl___3 *pinctrl;
	struct pinctrl_state *pins_default;
	struct pinctrl_state *pins_gpio;
};

struct platform_device___16 {
	const char *name;
	int id;
	bool id_auto;
	struct device___147 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___15 {
	int (*probe)(struct platform_device___16 *);
	int (*remove)(struct platform_device___16 *);
	void (*shutdown)(struct platform_device___16 *);
	int (*suspend)(struct platform_device___16 *, pm_message_t);
	int (*resume)(struct platform_device___16 *);
	struct device_driver___147 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct tps65910_sleep_keepon_data {
	unsigned int therm_keepon: 1;
	unsigned int clkout32k_keepon: 1;
	unsigned int i2chs_keepon: 1;
};

struct tps65910_board {
	int gpio_base;
	int irq;
	int irq_base;
	int vmbch_threshold;
	int vmbch2_threshold;
	bool en_ck32k_xtal;
	bool en_dev_slp;
	bool pm_off;
	struct tps65910_sleep_keepon_data slp_keepon;
	bool en_gpio_sleep[9];
	long unsigned int regulator_ext_sleep_control[14];
	struct regulator_init_data *tps65910_pmic_init_data[14];
};

struct tps65910 {
	struct device___147 *dev;
	struct i2c_client___3 *i2c_client;
	struct regmap *regmap;
	long unsigned int id;
	struct tps65910_board *of_plat_data;
	int chip_irq;
	struct regmap_irq_chip_data *irq_data;
};

struct tps65910_gpio {
	struct gpio_chip___9 gpio_chip;
	struct tps65910 *tps65910;
};

struct xgene_gpio {
	struct gpio_chip___7 chip;
	void *base;
	spinlock_t lock;
	u32 set_dr_val[3];
};

struct xgpio_instance {
	struct gpio_chip___9 gc;
	void *regs;
	long unsigned int hw_map[1];
	long unsigned int sw_map[1];
	long unsigned int state[1];
	long unsigned int last_irq_read[1];
	long unsigned int dir[1];
	spinlock_t gpio_lock;
	int irq;
	struct irq_chip___29 irqchip;
	long unsigned int enable[1];
	long unsigned int rising_edge[1];
	long unsigned int falling_edge[1];
	struct clk *clk;
};

struct irq_desc___31;

typedef void (*irq_flow_handler_t___31)(struct irq_desc___31 *);

struct irq_chip___30;

struct irq_domain___29;

struct irq_data___30 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___30 *chip;
	struct irq_domain___29 *domain;
	struct irq_data___30 *parent_data;
	void *chip_data;
};

struct kset___178;

struct kobj_type___178;

struct kernfs_node___178;

struct kobject___178 {
	const char *name;
	struct list_head entry;
	struct kobject___178 *parent;
	struct kset___178 *kset;
	struct kobj_type___178 *ktype;
	struct kernfs_node___178 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___21;

struct module___174;

struct irq_desc___31 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___30 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___31 handle_irq;
	struct irqaction___21 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___178 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___174 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___190;

struct super_block___190;

struct file_system_type___190 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___190 * (*mount)(struct file_system_type___190 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___190 *);
	struct module___174 *owner;
	struct file_system_type___190 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___190;

struct kiocb___190;

struct poll_table_struct___124;

struct vm_area_struct___195;

struct inode___190;

struct file_lock___190;

struct page___195;

struct seq_file___166;

struct file_operations___191 {
	struct module___174 *owner;
	loff_t (*llseek)(struct file___190 *, loff_t, int);
	ssize_t (*read)(struct file___190 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___190 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___190 *, struct iov_iter___112 *);
	ssize_t (*write_iter)(struct kiocb___190 *, struct iov_iter___112 *);
	int (*iopoll)(struct kiocb___190 *, bool);
	int (*iterate)(struct file___190 *, struct dir_context *);
	int (*iterate_shared)(struct file___190 *, struct dir_context *);
	__poll_t (*poll)(struct file___190 *, struct poll_table_struct___124 *);
	long int (*unlocked_ioctl)(struct file___190 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___190 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___190 *, struct vm_area_struct___195 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___190 *, struct file___190 *);
	int (*flush)(struct file___190 *, fl_owner_t);
	int (*release)(struct inode___190 *, struct file___190 *);
	int (*fsync)(struct file___190 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___190 *, int);
	int (*lock)(struct file___190 *, int, struct file_lock___190 *);
	ssize_t (*sendpage)(struct file___190 *, struct page___195 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___190 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___190 *, long unsigned int);
	int (*flock)(struct file___190 *, int, struct file_lock___190 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___190 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___190 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___190 *, long int, struct file_lock___190 **, void **);
	long int (*fallocate)(struct file___190 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___166 *, struct file___190 *);
	ssize_t (*copy_file_range)(struct file___190 *, loff_t, struct file___190 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___190 *, loff_t, struct file___190 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___190 *, loff_t, loff_t, int);
};

struct vmacache___195 {
	u64 seqnum;
	struct vm_area_struct___195 *vmas[4];
};

struct page_frag___195 {
	struct page___195 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___74;

struct debug_info___74 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___74 *hbp_break[16];
	struct perf_event___74 *hbp_watch[16];
};

struct thread_struct___74 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___74 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___196;

struct pid___168;

struct nsproxy___177;

struct signal_struct___191;

struct css_set___129;

struct perf_event_context___74;

struct vm_struct___173;

struct task_struct___197 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___197 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___196 *mm;
	struct mm_struct___196 *active_mm;
	struct vmacache___195 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___197 *real_parent;
	struct task_struct___197 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___197 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___168 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___177 *nsproxy;
	struct signal_struct___191 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___197 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___94 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___129 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___74 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___195 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___197 *oom_reaper_list;
	struct vm_struct___173 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___174 {
	struct kobject___178 kobj;
	struct module___174 *mod;
	struct kobject___178 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___174 {
	struct module___174 *mod;
	struct latch_tree_node node;
};

struct module_layout___174 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___174 mtn;
};

struct module_attribute___174;

struct kernel_param___174;

struct trace_event_call___68;

struct module___174 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___174 mkobj;
	struct module_attribute___174 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___178 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___174 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___174 core_layout;
	struct module_layout___174 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___68 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___74 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___197 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___74)(struct perf_event___74 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___74;

struct fasync_struct___190;

struct pid_namespace___168;

struct perf_cgroup___74;

struct perf_event___74 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___74 *group_leader;
	struct pmu___74 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___74 hw;
	struct perf_event_context___74 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___74 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___197 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___190 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___74 *aux_event;
	void (*destroy)(struct perf_event___74 *);
	struct callback_head callback_head;
	struct pid_namespace___168 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___74 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___74 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___68 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___74 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___195 *pgtable_t___195;

struct address_space___190;

struct dev_pagemap___185;

struct page___195 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___190 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___195 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___195 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___196 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___185 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___185;

struct vm_area_struct___195 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___195 *vm_next;
	struct vm_area_struct___195 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___196 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___185 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___190 *vm_file;
	struct file___190 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___195;

struct mm_struct___196 {
	struct {
		struct vm_area_struct___195 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___190 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___195 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___197 *owner;
		struct user_namespace___25 *user_ns;
		struct file___190 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___190;

struct address_space___190 {
	struct inode___190 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___190 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___185;

struct dev_pagemap___185 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___185 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___190;

struct path___190 {
	struct vfsmount___190 *mnt;
	struct dentry___190 *dentry;
};

struct fown_struct___168 {
	rwlock_t lock;
	struct pid___168 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___190 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___190 f_path;
	struct inode___190 *f_inode;
	const struct file_operations___191 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___168 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___190 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___185;

struct vm_operations_struct___185 {
	void (*open)(struct vm_area_struct___195 *);
	void (*close)(struct vm_area_struct___195 *);
	int (*may_split)(struct vm_area_struct___195 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___195 *);
	int (*mprotect)(struct vm_area_struct___195 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___185 *);
	vm_fault_t (*huge_fault)(struct vm_fault___185 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___185 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___195 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___185 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___185 *);
	int (*access)(struct vm_area_struct___195 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___195 *);
	int (*set_policy)(struct vm_area_struct___195 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___195 *, long unsigned int);
	struct page___195 * (*find_special_page)(struct vm_area_struct___195 *, long unsigned int);
};

struct core_thread___195 {
	struct task_struct___197 *task;
	struct core_thread___195 *next;
};

struct core_state___195 {
	atomic_t nr_threads;
	struct core_thread___195 dumper;
	struct completion startup;
};

struct vm_fault___185 {
	const struct {
		struct vm_area_struct___195 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___195 *cow_page;
	struct page___195 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___195 prealloc_pte;
};

struct kernfs_root___178;

struct kernfs_elem_dir___178 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___178 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___178;

struct kernfs_root___178 {
	struct kernfs_node___178 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___178 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___178 {
	struct kernfs_node___178 *target_kn;
};

struct kernfs_ops___178;

struct kernfs_elem_attr___178 {
	const struct kernfs_ops___178 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___178 *notify_next;
};

struct kernfs_node___178 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___178 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___178 dir;
		struct kernfs_elem_symlink___178 symlink;
		struct kernfs_elem_attr___178 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___178;

struct kernfs_ops___178 {
	int (*open)(struct kernfs_open_file___178 *);
	void (*release)(struct kernfs_open_file___178 *);
	int (*seq_show)(struct seq_file___166 *, void *);
	void * (*seq_start)(struct seq_file___166 *, loff_t *);
	void * (*seq_next)(struct seq_file___166 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___166 *, void *);
	ssize_t (*read)(struct kernfs_open_file___178 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___178 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___178 *, struct poll_table_struct___124 *);
	int (*mmap)(struct kernfs_open_file___178 *, struct vm_area_struct___195 *);
};

struct kernfs_syscall_ops___178 {
	int (*show_options)(struct seq_file___166 *, struct kernfs_root___178 *);
	int (*mkdir)(struct kernfs_node___178 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___178 *);
	int (*rename)(struct kernfs_node___178 *, struct kernfs_node___178 *, const char *);
	int (*show_path)(struct seq_file___166 *, struct kernfs_node___178 *, struct kernfs_root___178 *);
};

struct seq_operations___166;

struct seq_file___166 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___166 *op;
	int poll_event;
	const struct file___190 *file;
	void *private;
};

struct kernfs_open_file___178 {
	struct kernfs_node___178 *kn;
	struct file___190 *file;
	struct seq_file___166 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___185 *vm_ops;
};

typedef void (*poll_queue_proc___129)(struct file___190 *, wait_queue_head_t *, struct poll_table_struct___124 *);

struct poll_table_struct___124 {
	poll_queue_proc___129 _qproc;
	__poll_t _key;
};

struct upid___168 {
	int nr;
	struct pid_namespace___168 *ns;
};

struct pid_namespace___168 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___197 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___168 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___168 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___168 numbers[1];
};

struct signal_struct___191 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___197 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___197 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___168 *pids[4];
	struct pid___168 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___196 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___129;

struct nsproxy___177 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___168 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___129 *cgroup_ns;
};

struct cgroup_subsys_state___129;

struct cgroup___129;

struct css_set___129 {
	struct cgroup_subsys_state___129 *subsys[14];
	refcount_t refcount;
	struct css_set___129 *dom_cset;
	struct cgroup___129 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___129 *mg_src_cgrp;
	struct cgroup___129 *mg_dst_cgrp;
	struct css_set___129 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___74 {
	struct pmu___74 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___197 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___74 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___173 {
	struct vm_struct___173 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___195 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___178;

struct attribute_group___178 {
	const char *name;
	umode_t (*is_visible)(struct kobject___178 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___178 *, struct bin_attribute___178 *, int);
	struct attribute **attrs;
	struct bin_attribute___178 **bin_attrs;
};

struct bin_attribute___178 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___190 * (*f_mapping)();
	ssize_t (*read)(struct file___190 *, struct kobject___178 *, struct bin_attribute___178 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___190 *, struct kobject___178 *, struct bin_attribute___178 *, char *, loff_t, size_t);
	int (*mmap)(struct file___190 *, struct kobject___178 *, struct bin_attribute___178 *, struct vm_area_struct___195 *);
};

struct sysfs_ops___178 {
	ssize_t (*show)(struct kobject___178 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___178 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___178;

struct kset___178 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___178 kobj;
	const struct kset_uevent_ops___178 *uevent_ops;
};

struct kobj_type___178 {
	void (*release)(struct kobject___178 *);
	const struct sysfs_ops___178 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___178 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___178 *);
	const void * (*namespace)(struct kobject___178 *);
	void (*get_ownership)(struct kobject___178 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___178 {
	int (* const filter)(struct kset___178 *, struct kobject___178 *);
	const char * (* const name)(struct kset___178 *, struct kobject___178 *);
	int (* const uevent)(struct kset___178 *, struct kobject___178 *, struct kobj_uevent_env *);
};

struct fwnode_operations___148;

struct device___148;

struct fwnode_handle___148 {
	struct fwnode_handle___148 *secondary;
	const struct fwnode_operations___148 *ops;
	struct device___148 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___148;

struct fwnode_endpoint___148;

struct fwnode_operations___148 {
	struct fwnode_handle___148 * (*get)(struct fwnode_handle___148 *);
	void (*put)(struct fwnode_handle___148 *);
	bool (*device_is_available)(const struct fwnode_handle___148 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___148 *, const struct device___148 *);
	bool (*property_present)(const struct fwnode_handle___148 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___148 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___148 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___148 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*get_parent)(const struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*get_next_child_node)(const struct fwnode_handle___148 *, struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*get_named_child_node)(const struct fwnode_handle___148 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___148 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___148 *);
	struct fwnode_handle___148 * (*graph_get_next_endpoint)(const struct fwnode_handle___148 *, struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*graph_get_remote_endpoint)(const struct fwnode_handle___148 *);
	struct fwnode_handle___148 * (*graph_get_port_parent)(struct fwnode_handle___148 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___148 *, struct fwnode_endpoint___148 *);
	int (*add_links)(struct fwnode_handle___148 *);
};

struct wakeup_source___148;

struct dev_pm_info___148 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___148 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___148 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___148;

struct bus_type___148;

struct device_driver___148;

struct dev_pm_domain___148;

struct device_node___50;

struct class___148;

struct device___148 {
	struct kobject___178 kobj;
	struct device___148 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___148 *type;
	struct bus_type___148 *bus;
	struct device_driver___148 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___148 power;
	struct dev_pm_domain___148 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___29 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___50 *of_node;
	struct fwnode_handle___148 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___148 *class;
	const struct attribute_group___178 **groups;
	void (*release)(struct device___148 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___148 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___148 *local_fwnode;
};

struct fwnode_reference_args___148 {
	struct fwnode_handle___148 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___40 {
	char *name;
	int length;
	void *value;
	struct property___40 *next;
	long unsigned int _flags;
	struct bin_attribute___178 attr;
};

struct device_node___50 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___148 fwnode;
	struct property___40 *properties;
	struct property___40 *deadprops;
	struct device_node___50 *parent;
	struct device_node___50 *child;
	struct device_node___50 *sibling;
	struct kobject___178 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___17 {
	struct device_node___50 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___27 {
	struct fwnode_handle___148 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___29 {
	int (*match)(struct irq_domain___29 *, struct device_node___50 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___29 *, struct irq_fwspec___27 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___29 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___29 *, unsigned int);
	int (*xlate)(struct irq_domain___29 *, struct device_node___50 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___29 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___29 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___29 *, struct irq_data___30 *, bool);
	void (*deactivate)(struct irq_domain___29 *, struct irq_data___30 *);
	int (*translate)(struct irq_domain___29 *, struct irq_fwspec___27 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___29;

struct irq_domain___29 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___29 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___148 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___29 *gc;
	struct irq_domain___29 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___30 *revmap[0];
};

struct irq_chip_generic___29;

struct irq_domain_chip_generic___29 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___29 *gc[0];
};

struct dev_pm_ops___148 {
	int (*prepare)(struct device___148 *);
	void (*complete)(struct device___148 *);
	int (*suspend)(struct device___148 *);
	int (*resume)(struct device___148 *);
	int (*freeze)(struct device___148 *);
	int (*thaw)(struct device___148 *);
	int (*poweroff)(struct device___148 *);
	int (*restore)(struct device___148 *);
	int (*suspend_late)(struct device___148 *);
	int (*resume_early)(struct device___148 *);
	int (*freeze_late)(struct device___148 *);
	int (*thaw_early)(struct device___148 *);
	int (*poweroff_late)(struct device___148 *);
	int (*restore_early)(struct device___148 *);
	int (*suspend_noirq)(struct device___148 *);
	int (*resume_noirq)(struct device___148 *);
	int (*freeze_noirq)(struct device___148 *);
	int (*thaw_noirq)(struct device___148 *);
	int (*poweroff_noirq)(struct device___148 *);
	int (*restore_noirq)(struct device___148 *);
	int (*runtime_suspend)(struct device___148 *);
	int (*runtime_resume)(struct device___148 *);
	int (*runtime_idle)(struct device___148 *);
};

struct wakeup_source___148 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___148 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___148 {
	struct dev_pm_ops___148 ops;
	int (*start)(struct device___148 *);
	void (*detach)(struct device___148 *, bool);
	int (*activate)(struct device___148 *);
	void (*sync)(struct device___148 *);
	void (*dismiss)(struct device___148 *);
};

struct bus_type___148 {
	const char *name;
	const char *dev_name;
	struct device___148 *dev_root;
	const struct attribute_group___178 **bus_groups;
	const struct attribute_group___178 **dev_groups;
	const struct attribute_group___178 **drv_groups;
	int (*match)(struct device___148 *, struct device_driver___148 *);
	int (*uevent)(struct device___148 *, struct kobj_uevent_env *);
	int (*probe)(struct device___148 *);
	void (*sync_state)(struct device___148 *);
	void (*remove)(struct device___148 *);
	void (*shutdown)(struct device___148 *);
	int (*online)(struct device___148 *);
	int (*offline)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	int (*num_vf)(struct device___148 *);
	int (*dma_configure)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___148 {
	const char *name;
	struct bus_type___148 *bus;
	struct module___174 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___148 *);
	void (*sync_state)(struct device___148 *);
	int (*remove)(struct device___148 *);
	void (*shutdown)(struct device___148 *);
	int (*suspend)(struct device___148 *, pm_message_t);
	int (*resume)(struct device___148 *);
	const struct attribute_group___178 **groups;
	const struct attribute_group___178 **dev_groups;
	const struct dev_pm_ops___148 *pm;
	void (*coredump)(struct device___148 *);
	struct driver_private *p;
};

struct device_type___148 {
	const char *name;
	const struct attribute_group___178 **groups;
	int (*uevent)(struct device___148 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___148 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___148 *);
	const struct dev_pm_ops___148 *pm;
};

struct class___148 {
	const char *name;
	struct module___174 *owner;
	const struct attribute_group___178 **class_groups;
	const struct attribute_group___178 **dev_groups;
	struct kobject___178 *dev_kobj;
	int (*dev_uevent)(struct device___148 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___148 *, umode_t *);
	void (*class_release)(struct class___148 *);
	void (*dev_release)(struct device___148 *);
	int (*shutdown_pre)(struct device___148 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___148 *);
	void (*get_ownership)(struct device___148 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___148 *pm;
	struct subsys_private *p;
};

struct device_link___9 {
	struct device___148 *supplier;
	struct list_head s_node;
	struct device___148 *consumer;
	struct list_head c_node;
	struct device___148 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct dentry_operations___190;

struct dentry___190 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___190 *d_parent;
	struct qstr d_name;
	struct inode___190 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___190 *d_op;
	struct super_block___190 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___190;

struct cdev___39;

struct inode___190 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___190 *i_op;
	struct super_block___190 *i_sb;
	struct address_space___190 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___191 *i_fop;
		void (*free_inode)(struct inode___190 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___190 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___39 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___190 {
	int (*d_revalidate)(struct dentry___190 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___190 *, unsigned int);
	int (*d_hash)(const struct dentry___190 *, struct qstr *);
	int (*d_compare)(const struct dentry___190 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___190 *);
	int (*d_init)(struct dentry___190 *);
	void (*d_release)(struct dentry___190 *);
	void (*d_prune)(struct dentry___190 *);
	void (*d_iput)(struct dentry___190 *, struct inode___190 *);
	char * (*d_dname)(struct dentry___190 *, char *, int);
	struct vfsmount___190 * (*d_automount)(struct path___190 *);
	int (*d_manage)(const struct path___190 *, bool);
	struct dentry___190 * (*d_real)(struct dentry___190 *, const struct inode___190 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___190;

struct mem_dqinfo___190 {
	struct quota_format_type___190 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___190;

struct quota_info___190 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___190 *files[3];
	struct mem_dqinfo___190 info[3];
	const struct quota_format_ops___190 *ops[3];
};

struct rcuwait___191 {
	struct task_struct___197 *task;
};

struct percpu_rw_semaphore___191 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___191 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___190 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___191 rw_sem[3];
};

struct super_operations___190;

struct dquot_operations___190;

struct quotactl_ops___190;

struct super_block___190 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___190 *s_type;
	const struct super_operations___190 *s_op;
	const struct dquot_operations___190 *dq_op;
	const struct quotactl_ops___190 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___190 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___190 s_dquot;
	struct sb_writers___190 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___190 *s_d_op;
	int cleancache_poolid;
	struct shrinker___78 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___190 {
	struct dentry___190 *mnt_root;
	struct super_block___190 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct cgroup_subsys___129;

struct cgroup_subsys_state___129 {
	struct cgroup___129 *cgroup;
	struct cgroup_subsys___129 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___129 *parent;
};

struct cgroup_file___129 {
	struct kernfs_node___178 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___129 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___197 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___129;

struct cgroup_rstat_cpu___129;

struct cgroup___129 {
	struct cgroup_subsys_state___129 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___178 *kn;
	struct cgroup_file___129 procs_file;
	struct cgroup_file___129 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___129 *subsys[14];
	struct cgroup_root___129 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___129 *dom_cgrp;
	struct cgroup___129 *old_dom_cgrp;
	struct cgroup_rstat_cpu___129 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___129 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___190 {
	struct file___190 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___190 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___87 *ki_waitq;
	};
};

struct iattr___190 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___190 *ia_file;
};

struct dquot___190 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___190 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___190 {
	int qf_fmt_id;
	const struct quota_format_ops___190 *qf_ops;
	struct module___174 *qf_owner;
	struct quota_format_type___190 *qf_next;
};

struct quota_format_ops___190 {
	int (*check_quota_file)(struct super_block___190 *, int);
	int (*read_file_info)(struct super_block___190 *, int);
	int (*write_file_info)(struct super_block___190 *, int);
	int (*free_file_info)(struct super_block___190 *, int);
	int (*read_dqblk)(struct dquot___190 *);
	int (*commit_dqblk)(struct dquot___190 *);
	int (*release_dqblk)(struct dquot___190 *);
	int (*get_next_id)(struct super_block___190 *, struct kqid *);
};

struct dquot_operations___190 {
	int (*write_dquot)(struct dquot___190 *);
	struct dquot___190 * (*alloc_dquot)(struct super_block___190 *, int);
	void (*destroy_dquot)(struct dquot___190 *);
	int (*acquire_dquot)(struct dquot___190 *);
	int (*release_dquot)(struct dquot___190 *);
	int (*mark_dirty)(struct dquot___190 *);
	int (*write_info)(struct super_block___190 *, int);
	qsize_t * (*get_reserved_space)(struct inode___190 *);
	int (*get_projid)(struct inode___190 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___190 *, qsize_t *);
	int (*get_next_id)(struct super_block___190 *, struct kqid *);
};

struct quotactl_ops___190 {
	int (*quota_on)(struct super_block___190 *, int, int, const struct path___190 *);
	int (*quota_off)(struct super_block___190 *, int);
	int (*quota_enable)(struct super_block___190 *, unsigned int);
	int (*quota_disable)(struct super_block___190 *, unsigned int);
	int (*quota_sync)(struct super_block___190 *, int);
	int (*set_info)(struct super_block___190 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___190 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___190 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___190 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___190 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___190 *, unsigned int);
};

struct address_space_operations___190 {
	int (*writepage)(struct page___195 *, struct writeback_control___3 *);
	int (*readpage)(struct file___190 *, struct page___195 *);
	int (*writepages)(struct address_space___190 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___195 *);
	int (*readpages)(struct file___190 *, struct address_space___190 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___190 *, struct address_space___190 *, loff_t, unsigned int, unsigned int, struct page___195 **, void **);
	int (*write_end)(struct file___190 *, struct address_space___190 *, loff_t, unsigned int, unsigned int, struct page___195 *, void *);
	sector_t (*bmap)(struct address_space___190 *, sector_t);
	void (*invalidatepage)(struct page___195 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___195 *, gfp_t);
	void (*freepage)(struct page___195 *);
	ssize_t (*direct_IO)(struct kiocb___190 *, struct iov_iter___112 *);
	int (*migratepage)(struct address_space___190 *, struct page___195 *, struct page___195 *, enum migrate_mode);
	bool (*isolate_page)(struct page___195 *, isolate_mode_t);
	void (*putback_page)(struct page___195 *);
	int (*launder_page)(struct page___195 *);
	int (*is_partially_uptodate)(struct page___195 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___195 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___190 *, struct page___195 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___190 *, sector_t *);
	void (*swap_deactivate)(struct file___190 *);
};

struct cdev___39 {
	struct kobject___178 kobj;
	struct module___174 *owner;
	const struct file_operations___191 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___190 {
	struct dentry___190 * (*lookup)(struct inode___190 *, struct dentry___190 *, unsigned int);
	const char * (*get_link)(struct dentry___190 *, struct inode___190 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___190 *, int);
	struct posix_acl * (*get_acl)(struct inode___190 *, int, bool);
	int (*readlink)(struct dentry___190 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___190 *, struct dentry___190 *, umode_t, bool);
	int (*link)(struct dentry___190 *, struct inode___190 *, struct dentry___190 *);
	int (*unlink)(struct inode___190 *, struct dentry___190 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___190 *, struct dentry___190 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___190 *, struct dentry___190 *, umode_t);
	int (*rmdir)(struct inode___190 *, struct dentry___190 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___190 *, struct dentry___190 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___190 *, struct dentry___190 *, struct inode___190 *, struct dentry___190 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___190 *, struct iattr___190 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___190 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___190 *, char *, size_t);
	int (*fiemap)(struct inode___190 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___190 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___190 *, struct dentry___190 *, struct file___190 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___190 *, struct dentry___190 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___190 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___190 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___190 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___190 {
	void (*fl_copy_lock)(struct file_lock___190 *, struct file_lock___190 *);
	void (*fl_release_private)(struct file_lock___190 *);
};

struct lock_manager_operations___190;

struct file_lock___190 {
	struct file_lock___190 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___190 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___190 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___190 *fl_ops;
	const struct lock_manager_operations___190 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___190 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___190 *);
	int (*lm_grant)(struct file_lock___190 *, int);
	bool (*lm_break)(struct file_lock___190 *);
	int (*lm_change)(struct file_lock___190 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___190 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___190 *);
};

struct fasync_struct___190 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___190 *fa_next;
	struct file___190 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___190 {
	struct inode___190 * (*alloc_inode)(struct super_block___190 *);
	void (*destroy_inode)(struct inode___190 *);
	void (*free_inode)(struct inode___190 *);
	void (*dirty_inode)(struct inode___190 *, int);
	int (*write_inode)(struct inode___190 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___190 *);
	void (*evict_inode)(struct inode___190 *);
	void (*put_super)(struct super_block___190 *);
	int (*sync_fs)(struct super_block___190 *, int);
	int (*freeze_super)(struct super_block___190 *);
	int (*freeze_fs)(struct super_block___190 *);
	int (*thaw_super)(struct super_block___190 *);
	int (*unfreeze_fs)(struct super_block___190 *);
	int (*statfs)(struct dentry___190 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___190 *, int *, char *);
	void (*umount_begin)(struct super_block___190 *);
	int (*show_options)(struct seq_file___166 *, struct dentry___190 *);
	int (*show_devname)(struct seq_file___166 *, struct dentry___190 *);
	int (*show_path)(struct seq_file___166 *, struct dentry___190 *);
	int (*show_stats)(struct seq_file___166 *, struct dentry___190 *);
	ssize_t (*quota_read)(struct super_block___190 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___190 *, int, const char *, size_t, loff_t);
	struct dquot___190 ** (*get_dquots)(struct inode___190 *);
	long int (*nr_cached_objects)(struct super_block___190 *, struct shrink_control___78 *);
	long int (*free_cached_objects)(struct super_block___190 *, struct shrink_control___78 *);
	struct file___190 * (*real_loop)(struct file___190 *);
};

struct kernel_param_ops___174 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___174 *);
	int (*get)(char *, const struct kernel_param___174 *);
	void (*free)(void *);
};

struct kparam_array___174;

struct kernel_param___174 {
	const char *name;
	struct module___174 *mod;
	const struct kernel_param_ops___174 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___174 *arr;
	};
};

struct kparam_array___174 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___174 *ops;
	void *elem;
};

struct module_attribute___174 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___174 *, struct module_kobject___174 *, char *);
	ssize_t (*store)(struct module_attribute___174 *, struct module_kobject___174 *, const char *, size_t);
	void (*setup)(struct module___174 *, const char *);
	int (*test)(struct module___174 *);
	void (*free)(struct module___174 *);
};

struct trace_event_class___68;

struct trace_event_call___68 {
	struct list_head list;
	struct trace_event_class___68 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___36 *prog_array;
	int (*perf_perm)(struct trace_event_call___68 *, struct perf_event___74 *);
};

struct irq_chip___30 {
	struct device___148 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___30 *);
	void (*irq_shutdown)(struct irq_data___30 *);
	void (*irq_enable)(struct irq_data___30 *);
	void (*irq_disable)(struct irq_data___30 *);
	void (*irq_ack)(struct irq_data___30 *);
	void (*irq_mask)(struct irq_data___30 *);
	void (*irq_mask_ack)(struct irq_data___30 *);
	void (*irq_unmask)(struct irq_data___30 *);
	void (*irq_eoi)(struct irq_data___30 *);
	int (*irq_set_affinity)(struct irq_data___30 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___30 *);
	int (*irq_set_type)(struct irq_data___30 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___30 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___30 *);
	void (*irq_bus_sync_unlock)(struct irq_data___30 *);
	void (*irq_cpu_online)(struct irq_data___30 *);
	void (*irq_cpu_offline)(struct irq_data___30 *);
	void (*irq_suspend)(struct irq_data___30 *);
	void (*irq_resume)(struct irq_data___30 *);
	void (*irq_pm_shutdown)(struct irq_data___30 *);
	void (*irq_calc_mask)(struct irq_data___30 *);
	void (*irq_print_chip)(struct irq_data___30 *, struct seq_file___166 *);
	int (*irq_request_resources)(struct irq_data___30 *);
	void (*irq_release_resources)(struct irq_data___30 *);
	void (*irq_compose_msi_msg)(struct irq_data___30 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___30 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___30 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___30 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___30 *, void *);
	void (*ipi_send_single)(struct irq_data___30 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___30 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___30 *);
	void (*irq_nmi_teardown)(struct irq_data___30 *);
	long unsigned int flags;
};

struct irqaction___21 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___21 *next;
	irq_handler_t thread_fn;
	struct task_struct___197 *thread;
	struct irqaction___21 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___29 {
	struct irq_chip___30 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___31 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___29 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___29 *);
	void (*resume)(struct irq_chip_generic___29 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___29 *domain;
	struct list_head list;
	struct irq_chip_type___29 chip_types[0];
};

struct seq_operations___166 {
	void * (*start)(struct seq_file___166 *, loff_t *);
	void (*stop)(struct seq_file___166 *, void *);
	void * (*next)(struct seq_file___166 *, void *, loff_t *);
	int (*show)(struct seq_file___166 *, void *);
};

struct dev_pagemap_ops___185 {
	void (*page_free)(struct page___195 *);
	void (*kill)(struct dev_pagemap___185 *);
	void (*cleanup)(struct dev_pagemap___185 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___185 *);
};

enum {
	PWMF_REQUESTED = 1,
	PWMF_EXPORTED = 2,
};

struct pwm_chip___2;

struct pwm_device___2 {
	const char *label;
	long unsigned int flags;
	unsigned int hwpwm;
	unsigned int pwm;
	struct pwm_chip___2 *chip;
	void *chip_data;
	struct pwm_args args;
	struct pwm_state state;
	struct pwm_state last;
};

struct pwm_ops___2;

struct pwm_chip___2 {
	struct device___148 *dev;
	const struct pwm_ops___2 *ops;
	int base;
	unsigned int npwm;
	struct pwm_device___2 * (*of_xlate)(struct pwm_chip___2 *, const struct of_phandle_args___17 *);
	unsigned int of_pwm_n_cells;
	struct list_head list;
	struct pwm_device___2 *pwms;
};

struct pwm_ops___2 {
	int (*request)(struct pwm_chip___2 *, struct pwm_device___2 *);
	void (*free)(struct pwm_chip___2 *, struct pwm_device___2 *);
	int (*capture)(struct pwm_chip___2 *, struct pwm_device___2 *, struct pwm_capture *, long unsigned int);
	int (*apply)(struct pwm_chip___2 *, struct pwm_device___2 *, const struct pwm_state *);
	void (*get_state)(struct pwm_chip___2 *, struct pwm_device___2 *, struct pwm_state *);
	struct module___174 *owner;
	int (*config)(struct pwm_chip___2 *, struct pwm_device___2 *, int, int);
	int (*set_polarity)(struct pwm_chip___2 *, struct pwm_device___2 *, enum pwm_polarity);
	int (*enable)(struct pwm_chip___2 *, struct pwm_device___2 *);
	void (*disable)(struct pwm_chip___2 *, struct pwm_device___2 *);
};

struct pwm_lookup {
	struct list_head list;
	const char *provider;
	unsigned int index;
	const char *dev_id;
	const char *con_id;
	unsigned int period;
	enum pwm_polarity polarity;
	const char *module;
};

struct cgroup_namespace___129 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___129 *root_cset;
};

struct cftype___129;

struct cgroup_subsys___129 {
	struct cgroup_subsys_state___129 * (*css_alloc)(struct cgroup_subsys_state___129 *);
	int (*css_online)(struct cgroup_subsys_state___129 *);
	void (*css_offline)(struct cgroup_subsys_state___129 *);
	void (*css_released)(struct cgroup_subsys_state___129 *);
	void (*css_free)(struct cgroup_subsys_state___129 *);
	void (*css_reset)(struct cgroup_subsys_state___129 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___129 *, int);
	int (*css_extra_stat_show)(struct seq_file___166 *, struct cgroup_subsys_state___129 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___197 *, struct css_set___129 *);
	void (*cancel_fork)(struct task_struct___197 *, struct css_set___129 *);
	void (*fork)(struct task_struct___197 *);
	void (*exit)(struct task_struct___197 *);
	void (*release)(struct task_struct___197 *);
	void (*bind)(struct cgroup_subsys_state___129 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___129 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___129 *dfl_cftypes;
	struct cftype___129 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___129 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___129 *updated_children;
	struct cgroup___129 *updated_next;
};

struct cgroup_root___129 {
	struct kernfs_root___178 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___129 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___129 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___129 *ss;
	struct list_head node;
	struct kernfs_ops___178 *kf_ops;
	int (*open)(struct kernfs_open_file___178 *);
	void (*release)(struct kernfs_open_file___178 *);
	u64 (*read_u64)(struct cgroup_subsys_state___129 *, struct cftype___129 *);
	s64 (*read_s64)(struct cgroup_subsys_state___129 *, struct cftype___129 *);
	int (*seq_show)(struct seq_file___166 *, void *);
	void * (*seq_start)(struct seq_file___166 *, loff_t *);
	void * (*seq_next)(struct seq_file___166 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___166 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___129 *, struct cftype___129 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___129 *, struct cftype___129 *, s64);
	ssize_t (*write)(struct kernfs_open_file___178 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___178 *, struct poll_table_struct___124 *);
};

struct perf_cpu_context___74;

struct perf_output_handle___74;

struct pmu___74 {
	struct list_head entry;
	struct module___174 *module;
	struct device___148 *dev;
	const struct attribute_group___178 **attr_groups;
	const struct attribute_group___178 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___74 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___74 *);
	void (*pmu_disable)(struct pmu___74 *);
	int (*event_init)(struct perf_event___74 *);
	void (*event_mapped)(struct perf_event___74 *, struct mm_struct___196 *);
	void (*event_unmapped)(struct perf_event___74 *, struct mm_struct___196 *);
	int (*add)(struct perf_event___74 *, int);
	void (*del)(struct perf_event___74 *, int);
	void (*start)(struct perf_event___74 *, int);
	void (*stop)(struct perf_event___74 *, int);
	void (*read)(struct perf_event___74 *);
	void (*start_txn)(struct pmu___74 *, unsigned int);
	int (*commit_txn)(struct pmu___74 *);
	void (*cancel_txn)(struct pmu___74 *);
	int (*event_idx)(struct perf_event___74 *);
	void (*sched_task)(struct perf_event_context___74 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___74 *, struct perf_event_context___74 *);
	void * (*setup_aux)(struct perf_event___74 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___74 *, struct perf_output_handle___74 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___74 *);
	int (*aux_output_match)(struct perf_event___74 *);
	int (*filter_match)(struct perf_event___74 *);
	int (*check_period)(struct perf_event___74 *, u64);
};

struct perf_cpu_context___74 {
	struct perf_event_context___74 ctx;
	struct perf_event_context___74 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___74 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___74 **heap;
	struct perf_event___74 *heap_default[2];
};

struct perf_output_handle___74 {
	struct perf_event___74 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___74 {
	struct cgroup_subsys_state___129 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___68 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___68 *);
	};
};

struct trace_event_class___68 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___68 *, enum trace_reg, void *);
	struct trace_event_fields___68 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___68 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___68 *);
};

struct trace_event_file___31;

struct trace_event_buffer___30 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___31 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___31 {
	struct list_head list;
	struct trace_event_call___68 *event_call;
	struct event_filter *filter;
	struct dentry___190 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_pwm {
	struct trace_entry ent;
	struct pwm_device___2 *pwm;
	u64 period;
	u64 duty_cycle;
	enum pwm_polarity polarity;
	bool enabled;
	char __data[0];
};

struct trace_event_data_offsets_pwm {};

typedef void (*btf_trace_pwm_apply)(void *, struct pwm_device___2 *, const struct pwm_state *);

typedef void (*btf_trace_pwm_get)(void *, struct pwm_device___2 *, const struct pwm_state *);

struct device_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct device___139 *, struct device_attribute___11 *, char *);
	ssize_t (*store)(struct device___139 *, struct device_attribute___11 *, const char *, size_t);
};

struct of_phandle_args___18 {
	struct device_node___41 *np;
	int args_count;
	uint32_t args[16];
};

struct pwm_chip___3;

struct pwm_device___3 {
	const char *label;
	long unsigned int flags;
	unsigned int hwpwm;
	unsigned int pwm;
	struct pwm_chip___3 *chip;
	void *chip_data;
	struct pwm_args args;
	struct pwm_state state;
	struct pwm_state last;
};

struct pwm_ops___3;

struct pwm_chip___3 {
	struct device___139 *dev;
	const struct pwm_ops___3 *ops;
	int base;
	unsigned int npwm;
	struct pwm_device___3 * (*of_xlate)(struct pwm_chip___3 *, const struct of_phandle_args___18 *);
	unsigned int of_pwm_n_cells;
	struct list_head list;
	struct pwm_device___3 *pwms;
};

struct pwm_ops___3 {
	int (*request)(struct pwm_chip___3 *, struct pwm_device___3 *);
	void (*free)(struct pwm_chip___3 *, struct pwm_device___3 *);
	int (*capture)(struct pwm_chip___3 *, struct pwm_device___3 *, struct pwm_capture *, long unsigned int);
	int (*apply)(struct pwm_chip___3 *, struct pwm_device___3 *, const struct pwm_state *);
	void (*get_state)(struct pwm_chip___3 *, struct pwm_device___3 *, struct pwm_state *);
	struct module___8 *owner;
	int (*config)(struct pwm_chip___3 *, struct pwm_device___3 *, int, int);
	int (*set_polarity)(struct pwm_chip___3 *, struct pwm_device___3 *, enum pwm_polarity);
	int (*enable)(struct pwm_chip___3 *, struct pwm_device___3 *);
	void (*disable)(struct pwm_chip___3 *, struct pwm_device___3 *);
};

struct pwm_export {
	struct device___139 child;
	struct pwm_device___3 *pwm;
	struct mutex lock;
	struct pwm_state suspend;
};

struct stmpe___2 {
	struct regulator *vcc;
	struct regulator *vio;
	struct mutex lock;
	struct mutex irq_lock;
	struct device___147 *dev;
	struct irq_domain___2 *domain;
	void *client;
	struct stmpe_client_info *ci;
	enum stmpe_partnum partnum;
	struct stmpe_variant_info *variant;
	const u8 *regs;
	int irq;
	int num_gpios;
	u8 ier[2];
	u8 oldier[2];
	struct stmpe_platform_data *pdata;
	u8 sample_time;
	u8 mod_12b;
	u8 ref_sel;
	u8 adc_freq;
};

struct pwm_chip___4;

struct pwm_device___4 {
	const char *label;
	long unsigned int flags;
	unsigned int hwpwm;
	unsigned int pwm;
	struct pwm_chip___4 *chip;
	void *chip_data;
	struct pwm_args args;
	struct pwm_state state;
	struct pwm_state last;
};

struct pwm_ops___4;

struct pwm_chip___4 {
	struct device___147 *dev;
	const struct pwm_ops___4 *ops;
	int base;
	unsigned int npwm;
	struct pwm_device___4 * (*of_xlate)(struct pwm_chip___4 *, const struct of_phandle_args___16 *);
	unsigned int of_pwm_n_cells;
	struct list_head list;
	struct pwm_device___4 *pwms;
};

struct pwm_ops___4 {
	int (*request)(struct pwm_chip___4 *, struct pwm_device___4 *);
	void (*free)(struct pwm_chip___4 *, struct pwm_device___4 *);
	int (*capture)(struct pwm_chip___4 *, struct pwm_device___4 *, struct pwm_capture *, long unsigned int);
	int (*apply)(struct pwm_chip___4 *, struct pwm_device___4 *, const struct pwm_state *);
	void (*get_state)(struct pwm_chip___4 *, struct pwm_device___4 *, struct pwm_state *);
	struct module___173 *owner;
	int (*config)(struct pwm_chip___4 *, struct pwm_device___4 *, int, int);
	int (*set_polarity)(struct pwm_chip___4 *, struct pwm_device___4 *, enum pwm_polarity);
	int (*enable)(struct pwm_chip___4 *, struct pwm_device___4 *);
	void (*disable)(struct pwm_chip___4 *, struct pwm_device___4 *);
};

struct stmpe_pwm {
	struct stmpe___2 *stmpe;
	struct pwm_chip___4 chip;
	u8 last_duty;
};

enum {
	pci_channel_io_normal = 1,
	pci_channel_io_frozen = 2,
	pci_channel_io_perm_failure = 3,
};

struct pci_sriov {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___4 *dev;
	struct pci_dev___4 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct rcec_ea {
	u8 nextbusn;
	u8 lastbusn;
	u32 bitmap;
};

struct pci_bus_resource {
	struct list_head list;
	struct resource *res;
	unsigned int flags;
};

typedef u64 pci_bus_addr_t;

struct pci_bus_region {
	pci_bus_addr_t start;
	pci_bus_addr_t end;
};

enum pci_fixup_pass {
	pci_fixup_early = 0,
	pci_fixup_header = 1,
	pci_fixup_final = 2,
	pci_fixup_enable = 3,
	pci_fixup_resume = 4,
	pci_fixup_suspend = 5,
	pci_fixup_resume_early = 6,
	pci_fixup_suspend_late = 7,
};

struct pci_bus___5;

struct pci_slot___5 {
	struct pci_bus___5 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___177 kobj;
};

struct pci_dev___5;

struct pci_ops___5;

struct pci_bus___5 {
	struct list_head node;
	struct pci_bus___5 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___5 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___5 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___147 *bridge;
	struct device___147 dev;
	struct bin_attribute___177 *legacy_io;
	struct bin_attribute___177 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hotplug_slot_ops;

struct hotplug_slot {
	const struct hotplug_slot_ops *ops;
	struct list_head slot_list;
	struct pci_slot___5 *pci_slot;
	struct module___173 *owner;
	const char *mod_name;
};

enum pci_dev_flags {
	PCI_DEV_FLAGS_MSI_INTX_DISABLE_BUG = 1,
	PCI_DEV_FLAGS_NO_D3 = 2,
	PCI_DEV_FLAGS_ASSIGNED = 4,
	PCI_DEV_FLAGS_ACS_ENABLED_QUIRK = 8,
	PCI_DEV_FLAG_PCIE_BRIDGE_ALIAS = 32,
	PCI_DEV_FLAGS_NO_BUS_RESET = 64,
	PCI_DEV_FLAGS_NO_PM_RESET = 128,
	PCI_DEV_FLAGS_VPD_REF_F0 = 256,
	PCI_DEV_FLAGS_BRIDGE_XLATE_ROOT = 512,
	PCI_DEV_FLAGS_NO_FLR_RESET = 1024,
	PCI_DEV_FLAGS_NO_RELAXED_ORDERING = 2048,
	PCI_DEV_FLAGS_ENABLE_ASPM = 4096,
	PCI_DEV_FLAGS_HAS_MSI_MASKING = 8192,
};

enum pci_bus_flags {
	PCI_BUS_FLAGS_NO_MSI = 1,
	PCI_BUS_FLAGS_NO_MMRBC = 2,
	PCI_BUS_FLAGS_NO_AERSID = 4,
	PCI_BUS_FLAGS_NO_EXTCFG = 8,
};

enum pci_bus_speed {
	PCI_SPEED_33MHz = 0,
	PCI_SPEED_66MHz = 1,
	PCI_SPEED_66MHz_PCIX = 2,
	PCI_SPEED_100MHz_PCIX = 3,
	PCI_SPEED_133MHz_PCIX = 4,
	PCI_SPEED_66MHz_PCIX_ECC = 5,
	PCI_SPEED_100MHz_PCIX_ECC = 6,
	PCI_SPEED_133MHz_PCIX_ECC = 7,
	PCI_SPEED_66MHz_PCIX_266 = 9,
	PCI_SPEED_100MHz_PCIX_266 = 10,
	PCI_SPEED_133MHz_PCIX_266 = 11,
	AGP_UNKNOWN = 12,
	AGP_1X = 13,
	AGP_2X = 14,
	AGP_4X = 15,
	AGP_8X = 16,
	PCI_SPEED_66MHz_PCIX_533 = 17,
	PCI_SPEED_100MHz_PCIX_533 = 18,
	PCI_SPEED_133MHz_PCIX_533 = 19,
	PCIE_SPEED_2_5GT = 20,
	PCIE_SPEED_5_0GT = 21,
	PCIE_SPEED_8_0GT = 22,
	PCIE_SPEED_16_0GT = 23,
	PCIE_SPEED_32_0GT = 24,
	PCIE_SPEED_64_0GT = 25,
	PCI_SPEED_UNKNOWN = 255,
};

struct pci_sriov___2 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___5 *dev;
	struct pci_dev___5 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___5;

struct pci_dev___5 {
	struct list_head bus_list;
	struct pci_bus___5 *bus;
	struct pci_bus___5 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___5 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___5 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___5 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___147 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___177 *res_attr[17];
	struct bin_attribute___177 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___177 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___2 *sriov;
		struct pci_dev___5 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___5;

struct pci_driver___5 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___5 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___5 *);
	int (*suspend)(struct pci_dev___5 *, pm_message_t);
	int (*resume)(struct pci_dev___5 *);
	void (*shutdown)(struct pci_dev___5 *);
	int (*sriov_configure)(struct pci_dev___5 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___5 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___5 *);
	const struct pci_error_handlers___5 *err_handler;
	const struct attribute_group___177 **groups;
	const struct attribute_group___177 **dev_groups;
	struct device_driver___147 driver;
	struct pci_dynids dynids;
};

struct pci_host_bridge___2 {
	struct device___147 dev;
	struct pci_bus___5 *bus;
	struct pci_ops___5 *ops;
	struct pci_ops___5 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___5 *, u8 *);
	int (*map_irq)(const struct pci_dev___5 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___2 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___5 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___5 {
	int (*add_bus)(struct pci_bus___5 *);
	void (*remove_bus)(struct pci_bus___5 *);
	void * (*map_bus)(struct pci_bus___5 *, unsigned int, int);
	int (*read)(struct pci_bus___5 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___5 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___5 {
	pci_ers_result_t (*error_detected)(struct pci_dev___5 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___5 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___5 *);
	void (*reset_prepare)(struct pci_dev___5 *);
	void (*reset_done)(struct pci_dev___5 *);
	void (*resume)(struct pci_dev___5 *);
};

enum {
	PCI_REASSIGN_ALL_RSRC = 1,
	PCI_REASSIGN_ALL_BUS = 2,
	PCI_PROBE_ONLY = 4,
	PCI_CAN_SKIP_ISA_ALIGN = 8,
	PCI_ENABLE_PROC_DOMAINS = 16,
	PCI_COMPAT_DOMAIN_0 = 32,
	PCI_SCAN_ALL_PCIE_DEVS = 64,
};

enum pcie_bus_config_types {
	PCIE_BUS_TUNE_OFF = 0,
	PCIE_BUS_DEFAULT = 1,
	PCIE_BUS_SAFE = 2,
	PCIE_BUS_PERFORMANCE = 3,
	PCIE_BUS_PEER2PEER = 4,
};

struct hotplug_slot_ops {
	int (*enable_slot)(struct hotplug_slot *);
	int (*disable_slot)(struct hotplug_slot *);
	int (*set_attention_status)(struct hotplug_slot *, u8);
	int (*hardware_test)(struct hotplug_slot *, u32);
	int (*get_power_status)(struct hotplug_slot *, u8 *);
	int (*get_attention_status)(struct hotplug_slot *, u8 *);
	int (*get_latch_status)(struct hotplug_slot *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot *, u8 *);
	int (*reset_slot)(struct hotplug_slot *, bool);
};

enum pci_bar_type {
	pci_bar_unknown = 0,
	pci_bar_io = 1,
	pci_bar_mem32 = 2,
	pci_bar_mem64 = 3,
};

struct pci_domain_busn_res {
	struct list_head list;
	struct resource res;
	int domain_nr;
};

enum pcie_reset_state {
	pcie_deassert_reset = 1,
	pcie_warm_reset = 2,
	pcie_hot_reset = 3,
};

enum pcie_link_width {
	PCIE_LNK_WIDTH_RESRV = 0,
	PCIE_LNK_X1 = 1,
	PCIE_LNK_X2 = 2,
	PCIE_LNK_X4 = 4,
	PCIE_LNK_X8 = 8,
	PCIE_LNK_X12 = 12,
	PCIE_LNK_X16 = 16,
	PCIE_LNK_X32 = 32,
	PCIE_LNK_WIDTH_UNKNOWN = 255,
};

typedef int (*arch_set_vga_state_t)(struct pci_dev___5 *, bool, unsigned int, u32);

struct pci_cap_saved_data {
	u16 cap_nr;
	bool cap_extended;
	unsigned int size;
	u32 data[0];
};

struct pci_cap_saved_state {
	struct hlist_node next;
	struct pci_cap_saved_data cap;
};

struct pci_platform_pm_ops {
	bool (*bridge_d3)(struct pci_dev___5 *);
	bool (*is_manageable)(struct pci_dev___5 *);
	int (*set_state)(struct pci_dev___5 *, pci_power_t);
	pci_power_t (*get_state)(struct pci_dev___5 *);
	void (*refresh_state)(struct pci_dev___5 *);
	pci_power_t (*choose_state)(struct pci_dev___5 *);
	int (*set_wakeup)(struct pci_dev___5 *, bool);
	bool (*need_resume)(struct pci_dev___5 *);
};

struct pci_reset_fn_method {
	int (*reset_fn)(struct pci_dev___5 *, bool);
	char *name;
};

struct pci_pme_device {
	struct list_head list;
	struct pci_dev___5 *dev;
};

struct pci_saved_state {
	u32 config_space[16];
	struct pci_cap_saved_data cap[0];
};

struct pci_devres {
	unsigned int enabled: 1;
	unsigned int pinned: 1;
	unsigned int orig_intx: 1;
	unsigned int restore_intx: 1;
	unsigned int mwi: 1;
	u32 region_mask;
};

struct dentry___191;

struct super_block___191;

struct module___175;

struct file_system_type___191 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___191 * (*mount)(struct file_system_type___191 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___191 *);
	struct module___175 *owner;
	struct file_system_type___191 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___191;

struct kiocb___191;

struct iov_iter___113;

struct poll_table_struct___125;

struct vm_area_struct___196;

struct inode___191;

struct file_lock___191;

struct page___196;

struct seq_file___167;

struct file_operations___192 {
	struct module___175 *owner;
	loff_t (*llseek)(struct file___191 *, loff_t, int);
	ssize_t (*read)(struct file___191 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___191 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___191 *, struct iov_iter___113 *);
	ssize_t (*write_iter)(struct kiocb___191 *, struct iov_iter___113 *);
	int (*iopoll)(struct kiocb___191 *, bool);
	int (*iterate)(struct file___191 *, struct dir_context *);
	int (*iterate_shared)(struct file___191 *, struct dir_context *);
	__poll_t (*poll)(struct file___191 *, struct poll_table_struct___125 *);
	long int (*unlocked_ioctl)(struct file___191 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___191 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___191 *, struct vm_area_struct___196 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___191 *, struct file___191 *);
	int (*flush)(struct file___191 *, fl_owner_t);
	int (*release)(struct inode___191 *, struct file___191 *);
	int (*fsync)(struct file___191 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___191 *, int);
	int (*lock)(struct file___191 *, int, struct file_lock___191 *);
	ssize_t (*sendpage)(struct file___191 *, struct page___196 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___191 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___191 *, long unsigned int);
	int (*flock)(struct file___191 *, int, struct file_lock___191 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___191 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___191 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___191 *, long int, struct file_lock___191 **, void **);
	long int (*fallocate)(struct file___191 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___167 *, struct file___191 *);
	ssize_t (*copy_file_range)(struct file___191 *, loff_t, struct file___191 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___191 *, loff_t, struct file___191 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___191 *, loff_t, loff_t, int);
};

struct vmacache___196 {
	u64 seqnum;
	struct vm_area_struct___196 *vmas[4];
};

struct page_frag___196 {
	struct page___196 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___197;

struct pid___169;

struct nsproxy___178;

struct signal_struct___192;

struct bio_list___95;

struct backing_dev_info___88;

struct io_context___95;

struct css_set___130;

struct mem_cgroup___79;

struct request_queue___95;

struct vm_struct___174;

struct task_struct___198 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___198 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___197 *mm;
	struct mm_struct___197 *active_mm;
	struct vmacache___196 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___198 *real_parent;
	struct task_struct___198 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___198 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___169 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___178 *nsproxy;
	struct signal_struct___192 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___198 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___95 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___88 *backing_dev_info;
	struct io_context___95 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___130 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___196 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___79 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___79 *active_memcg;
	struct request_queue___95 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___198 *oom_reaper_list;
	struct vm_struct___174 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___179;

struct kobj_type___179;

struct kernfs_node___179;

struct kobject___179 {
	const char *name;
	struct list_head entry;
	struct kobject___179 *parent;
	struct kset___179 *kset;
	struct kobj_type___179 *ktype;
	struct kernfs_node___179 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___175 {
	struct kobject___179 kobj;
	struct module___175 *mod;
	struct kobject___179 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___175 {
	struct module___175 *mod;
	struct latch_tree_node node;
};

struct module_layout___175 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___175 mtn;
};

struct module_attribute___175;

struct kernel_param___175;

struct module___175 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___175 mkobj;
	struct module_attribute___175 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___179 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___175 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___175 core_layout;
	struct module_layout___175 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___196 *pgtable_t___196;

struct address_space___191;

struct dev_pagemap___186;

struct page___196 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___191 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___196 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___196 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___197 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___186 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___186;

struct vm_area_struct___196 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___196 *vm_next;
	struct vm_area_struct___196 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___197 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___186 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___191 *vm_file;
	struct file___191 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___196;

struct mm_struct___197 {
	struct {
		struct vm_area_struct___196 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___191 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___196 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___198 *owner;
		struct user_namespace___25 *user_ns;
		struct file___191 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___191;

struct address_space___191 {
	struct inode___191 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___191 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___186;

struct dev_pagemap___186 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___186 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___191;

struct path___191 {
	struct vfsmount___191 *mnt;
	struct dentry___191 *dentry;
};

struct fown_struct___169 {
	rwlock_t lock;
	struct pid___169 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___191 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___191 f_path;
	struct inode___191 *f_inode;
	const struct file_operations___192 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___169 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___191 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___186;

struct vm_operations_struct___186 {
	void (*open)(struct vm_area_struct___196 *);
	void (*close)(struct vm_area_struct___196 *);
	int (*may_split)(struct vm_area_struct___196 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___196 *);
	int (*mprotect)(struct vm_area_struct___196 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___186 *);
	vm_fault_t (*huge_fault)(struct vm_fault___186 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___186 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___196 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___186 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___186 *);
	int (*access)(struct vm_area_struct___196 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___196 *);
	int (*set_policy)(struct vm_area_struct___196 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___196 *, long unsigned int);
	struct page___196 * (*find_special_page)(struct vm_area_struct___196 *, long unsigned int);
};

struct core_thread___196 {
	struct task_struct___198 *task;
	struct core_thread___196 *next;
};

struct core_state___196 {
	atomic_t nr_threads;
	struct core_thread___196 dumper;
	struct completion startup;
};

struct vm_fault___186 {
	const struct {
		struct vm_area_struct___196 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___196 *cow_page;
	struct page___196 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___196 prealloc_pte;
};

struct pglist_data___86;

struct lruvec___86 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___86 *pgdat;
};

struct zone___86 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___86 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___86 {
	struct zone___86 *zone;
	int zone_idx;
};

struct zonelist___86 {
	struct zoneref___86 _zonerefs[321];
};

struct pglist_data___86 {
	struct zone___86 node_zones[5];
	struct zonelist___86 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___198 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___198 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___86 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___179;

struct kernfs_elem_dir___179 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___179 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___179;

struct kernfs_root___179 {
	struct kernfs_node___179 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___179 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___179 {
	struct kernfs_node___179 *target_kn;
};

struct kernfs_ops___179;

struct kernfs_elem_attr___179 {
	const struct kernfs_ops___179 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___179 *notify_next;
};

struct kernfs_node___179 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___179 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___179 dir;
		struct kernfs_elem_symlink___179 symlink;
		struct kernfs_elem_attr___179 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___179;

struct kernfs_ops___179 {
	int (*open)(struct kernfs_open_file___179 *);
	void (*release)(struct kernfs_open_file___179 *);
	int (*seq_show)(struct seq_file___167 *, void *);
	void * (*seq_start)(struct seq_file___167 *, loff_t *);
	void * (*seq_next)(struct seq_file___167 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___167 *, void *);
	ssize_t (*read)(struct kernfs_open_file___179 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___179 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___179 *, struct poll_table_struct___125 *);
	int (*mmap)(struct kernfs_open_file___179 *, struct vm_area_struct___196 *);
};

struct kernfs_syscall_ops___179 {
	int (*show_options)(struct seq_file___167 *, struct kernfs_root___179 *);
	int (*mkdir)(struct kernfs_node___179 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___179 *);
	int (*rename)(struct kernfs_node___179 *, struct kernfs_node___179 *, const char *);
	int (*show_path)(struct seq_file___167 *, struct kernfs_node___179 *, struct kernfs_root___179 *);
};

struct seq_operations___167;

struct seq_file___167 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___167 *op;
	int poll_event;
	const struct file___191 *file;
	void *private;
};

struct kernfs_open_file___179 {
	struct kernfs_node___179 *kn;
	struct file___191 *file;
	struct seq_file___167 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___186 *vm_ops;
};

typedef void (*poll_queue_proc___130)(struct file___191 *, wait_queue_head_t *, struct poll_table_struct___125 *);

struct poll_table_struct___125 {
	poll_queue_proc___130 _qproc;
	__poll_t _key;
};

struct pid_namespace___169;

struct upid___169 {
	int nr;
	struct pid_namespace___169 *ns;
};

struct pid_namespace___169 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___198 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___169 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___169 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___169 numbers[1];
};

struct signal_struct___192 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___198 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___198 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___169 *pids[4];
	struct pid___169 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___197 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___130;

struct nsproxy___178 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___169 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___130 *cgroup_ns;
};

struct bio___95;

struct bio_list___95 {
	struct bio___95 *head;
	struct bio___95 *tail;
};

struct cgroup_subsys_state___130;

struct bdi_writeback___88 {
	struct backing_dev_info___88 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___130 *memcg_css;
	struct cgroup_subsys_state___130 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___149;

struct backing_dev_info___88 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___88 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___149 *dev;
	char dev_name[64];
	struct device___149 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___191 *debug_dir;
};

struct io_cq___95;

struct io_context___95 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___95 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___130;

struct css_set___130 {
	struct cgroup_subsys_state___130 *subsys[14];
	refcount_t refcount;
	struct css_set___130 *dom_cset;
	struct cgroup___130 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___130 *mg_src_cgrp;
	struct cgroup___130 *mg_dst_cgrp;
	struct css_set___130 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___130;

struct cgroup_subsys_state___130 {
	struct cgroup___130 *cgroup;
	struct cgroup_subsys___130 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___130 *parent;
};

struct cgroup_file___130 {
	struct kernfs_node___179 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___79;

struct mem_cgroup_per_node___79;

struct mem_cgroup___79 {
	struct cgroup_subsys_state___130 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___130 events_file;
	struct cgroup_file___130 events_local_file;
	struct cgroup_file___130 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___79 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___198 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___79 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___95;

struct blk_integrity___95 {
	const struct blk_integrity_profile___95 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___95 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___95 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___95;

struct elevator_queue___95;

struct blk_mq_ops___92;

struct blk_mq_hw_ctx___92;

struct gendisk___96;

struct blkcg_gq___90;

struct blk_mq_tag_set___92;

struct request_queue___95 {
	struct request___95 *last_merge;
	struct elevator_queue___95 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___92 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___92 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___96 *disk;
	struct kobject___179 kobj;
	struct kobject___179 *mq_kobj;
	struct blk_integrity___95 integrity;
	struct device___149 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___90 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___92 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___95 bio_split;
	struct dentry___191 *debugfs_dir;
	struct dentry___191 *sched_debugfs_dir;
	struct dentry___191 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___174 {
	struct vm_struct___174 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___196 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___179;

struct attribute_group___179 {
	const char *name;
	umode_t (*is_visible)(struct kobject___179 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___179 *, struct bin_attribute___179 *, int);
	struct attribute **attrs;
	struct bin_attribute___179 **bin_attrs;
};

struct bin_attribute___179 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___191 * (*f_mapping)();
	ssize_t (*read)(struct file___191 *, struct kobject___179 *, struct bin_attribute___179 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___191 *, struct kobject___179 *, struct bin_attribute___179 *, char *, loff_t, size_t);
	int (*mmap)(struct file___191 *, struct kobject___179 *, struct bin_attribute___179 *, struct vm_area_struct___196 *);
};

struct sysfs_ops___179 {
	ssize_t (*show)(struct kobject___179 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___179 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___179;

struct kset___179 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___179 kobj;
	const struct kset_uevent_ops___179 *uevent_ops;
};

struct kobj_type___179 {
	void (*release)(struct kobject___179 *);
	const struct sysfs_ops___179 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___179 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___179 *);
	const void * (*namespace)(struct kobject___179 *);
	void (*get_ownership)(struct kobject___179 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___179 {
	int (* const filter)(struct kset___179 *, struct kobject___179 *);
	const char * (* const name)(struct kset___179 *, struct kobject___179 *);
	int (* const uevent)(struct kset___179 *, struct kobject___179 *, struct kobj_uevent_env *);
};

struct wakeup_source___149;

struct dev_pm_info___149 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___149 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___149 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___149;

struct bus_type___149;

struct device_driver___149;

struct dev_pm_domain___149;

struct irq_domain___30;

struct dma_map_ops___5;

struct device_node___51;

struct fwnode_handle___149;

struct class___149;

struct device___149 {
	struct kobject___179 kobj;
	struct device___149 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___149 *type;
	struct bus_type___149 *bus;
	struct device_driver___149 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___149 power;
	struct dev_pm_domain___149 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___30 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___5 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___51 *of_node;
	struct fwnode_handle___149 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___149 *class;
	const struct attribute_group___179 **groups;
	void (*release)(struct device___149 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___149 {
	int (*prepare)(struct device___149 *);
	void (*complete)(struct device___149 *);
	int (*suspend)(struct device___149 *);
	int (*resume)(struct device___149 *);
	int (*freeze)(struct device___149 *);
	int (*thaw)(struct device___149 *);
	int (*poweroff)(struct device___149 *);
	int (*restore)(struct device___149 *);
	int (*suspend_late)(struct device___149 *);
	int (*resume_early)(struct device___149 *);
	int (*freeze_late)(struct device___149 *);
	int (*thaw_early)(struct device___149 *);
	int (*poweroff_late)(struct device___149 *);
	int (*restore_early)(struct device___149 *);
	int (*suspend_noirq)(struct device___149 *);
	int (*resume_noirq)(struct device___149 *);
	int (*freeze_noirq)(struct device___149 *);
	int (*thaw_noirq)(struct device___149 *);
	int (*poweroff_noirq)(struct device___149 *);
	int (*restore_noirq)(struct device___149 *);
	int (*runtime_suspend)(struct device___149 *);
	int (*runtime_resume)(struct device___149 *);
	int (*runtime_idle)(struct device___149 *);
};

struct wakeup_source___149 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___149 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___149 {
	struct dev_pm_ops___149 ops;
	int (*start)(struct device___149 *);
	void (*detach)(struct device___149 *, bool);
	int (*activate)(struct device___149 *);
	void (*sync)(struct device___149 *);
	void (*dismiss)(struct device___149 *);
};

struct bus_type___149 {
	const char *name;
	const char *dev_name;
	struct device___149 *dev_root;
	const struct attribute_group___179 **bus_groups;
	const struct attribute_group___179 **dev_groups;
	const struct attribute_group___179 **drv_groups;
	int (*match)(struct device___149 *, struct device_driver___149 *);
	int (*uevent)(struct device___149 *, struct kobj_uevent_env *);
	int (*probe)(struct device___149 *);
	void (*sync_state)(struct device___149 *);
	void (*remove)(struct device___149 *);
	void (*shutdown)(struct device___149 *);
	int (*online)(struct device___149 *);
	int (*offline)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	int (*num_vf)(struct device___149 *);
	int (*dma_configure)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___149 {
	const char *name;
	struct bus_type___149 *bus;
	struct module___175 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___149 *);
	void (*sync_state)(struct device___149 *);
	int (*remove)(struct device___149 *);
	void (*shutdown)(struct device___149 *);
	int (*suspend)(struct device___149 *, pm_message_t);
	int (*resume)(struct device___149 *);
	const struct attribute_group___179 **groups;
	const struct attribute_group___179 **dev_groups;
	const struct dev_pm_ops___149 *pm;
	void (*coredump)(struct device___149 *);
	struct driver_private *p;
};

struct device_type___149 {
	const char *name;
	const struct attribute_group___179 **groups;
	int (*uevent)(struct device___149 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___149 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___149 *);
	const struct dev_pm_ops___149 *pm;
};

struct class___149 {
	const char *name;
	struct module___175 *owner;
	const struct attribute_group___179 **class_groups;
	const struct attribute_group___179 **dev_groups;
	struct kobject___179 *dev_kobj;
	int (*dev_uevent)(struct device___149 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___149 *, umode_t *);
	void (*class_release)(struct class___149 *);
	void (*dev_release)(struct device___149 *);
	int (*shutdown_pre)(struct device___149 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___149 *);
	void (*get_ownership)(struct device___149 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___149 *pm;
	struct subsys_private *p;
};

struct driver_attribute {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___149 *, char *);
	ssize_t (*store)(struct device_driver___149 *, const char *, size_t);
};

struct irq_domain_ops___30;

struct irq_domain_chip_generic___30;

struct irq_data___31;

struct irq_domain___30 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___30 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___149 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___30 *gc;
	struct irq_domain___30 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___31 *revmap[0];
};

struct dma_map_ops___5 {
	void * (*alloc)(struct device___149 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___149 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___196 * (*alloc_pages)(struct device___149 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___149 *, size_t, struct page___196 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___149 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___149 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___149 *, struct vm_area_struct___196 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___149 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___149 *, struct page___196 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___149 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___149 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___149 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___149 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___149 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___149 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___149 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___149 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___149 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___149 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___149 *, u64);
	u64 (*get_required_mask)(struct device___149 *);
	size_t (*max_mapping_size)(struct device___149 *);
	long unsigned int (*get_merge_boundary)(struct device___149 *);
};

struct fwnode_operations___149;

struct fwnode_handle___149 {
	struct fwnode_handle___149 *secondary;
	const struct fwnode_operations___149 *ops;
	struct device___149 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___41;

struct device_node___51 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___149 fwnode;
	struct property___41 *properties;
	struct property___41 *deadprops;
	struct device_node___51 *parent;
	struct device_node___51 *child;
	struct device_node___51 *sibling;
	struct kobject___179 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___32;

typedef void (*irq_flow_handler_t___32)(struct irq_desc___32 *);

struct irq_chip___31;

struct irq_data___31 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___9 *common;
	struct irq_chip___31 *chip;
	struct irq_domain___30 *domain;
	struct irq_data___31 *parent_data;
	void *chip_data;
};

struct irqaction___22;

struct irq_desc___32 {
	struct irq_common_data___9 irq_common_data;
	struct irq_data___31 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___32 handle_irq;
	struct irqaction___22 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___179 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___175 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___149;

struct fwnode_endpoint___149;

struct fwnode_operations___149 {
	struct fwnode_handle___149 * (*get)(struct fwnode_handle___149 *);
	void (*put)(struct fwnode_handle___149 *);
	bool (*device_is_available)(const struct fwnode_handle___149 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___149 *, const struct device___149 *);
	bool (*property_present)(const struct fwnode_handle___149 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___149 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___149 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___149 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*get_parent)(const struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*get_next_child_node)(const struct fwnode_handle___149 *, struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*get_named_child_node)(const struct fwnode_handle___149 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___149 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___149 *);
	struct fwnode_handle___149 * (*graph_get_next_endpoint)(const struct fwnode_handle___149 *, struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*graph_get_remote_endpoint)(const struct fwnode_handle___149 *);
	struct fwnode_handle___149 * (*graph_get_port_parent)(struct fwnode_handle___149 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___149 *, struct fwnode_endpoint___149 *);
	int (*add_links)(struct fwnode_handle___149 *);
};

struct fwnode_endpoint___149 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___149 *local_fwnode;
};

struct fwnode_reference_args___149 {
	struct fwnode_handle___149 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___31 {
	struct device___149 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___31 *);
	void (*irq_shutdown)(struct irq_data___31 *);
	void (*irq_enable)(struct irq_data___31 *);
	void (*irq_disable)(struct irq_data___31 *);
	void (*irq_ack)(struct irq_data___31 *);
	void (*irq_mask)(struct irq_data___31 *);
	void (*irq_mask_ack)(struct irq_data___31 *);
	void (*irq_unmask)(struct irq_data___31 *);
	void (*irq_eoi)(struct irq_data___31 *);
	int (*irq_set_affinity)(struct irq_data___31 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___31 *);
	int (*irq_set_type)(struct irq_data___31 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___31 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___31 *);
	void (*irq_bus_sync_unlock)(struct irq_data___31 *);
	void (*irq_cpu_online)(struct irq_data___31 *);
	void (*irq_cpu_offline)(struct irq_data___31 *);
	void (*irq_suspend)(struct irq_data___31 *);
	void (*irq_resume)(struct irq_data___31 *);
	void (*irq_pm_shutdown)(struct irq_data___31 *);
	void (*irq_calc_mask)(struct irq_data___31 *);
	void (*irq_print_chip)(struct irq_data___31 *, struct seq_file___167 *);
	int (*irq_request_resources)(struct irq_data___31 *);
	void (*irq_release_resources)(struct irq_data___31 *);
	void (*irq_compose_msi_msg)(struct irq_data___31 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___31 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___31 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___31 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___31 *, void *);
	void (*ipi_send_single)(struct irq_data___31 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___31 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___31 *);
	void (*irq_nmi_teardown)(struct irq_data___31 *);
	long unsigned int flags;
};

struct irqaction___22 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___22 *next;
	irq_handler_t thread_fn;
	struct task_struct___198 *thread;
	struct irqaction___22 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___30 {
	struct irq_chip___31 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___32 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___30 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___30 *);
	void (*resume)(struct irq_chip_generic___30 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___30 *domain;
	struct list_head list;
	struct irq_chip_type___30 chip_types[0];
};

struct irq_domain_chip_generic___30 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___30 *gc[0];
};

struct pci_bus___6;

struct pci_slot___6 {
	struct pci_bus___6 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___179 kobj;
};

struct pci_dev___6;

struct pci_ops___6;

struct pci_bus___6 {
	struct list_head node;
	struct pci_bus___6 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___6 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___6 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___149 *bridge;
	struct device___149 dev;
	struct bin_attribute___179 *legacy_io;
	struct bin_attribute___179 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_sriov___3 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___6 *dev;
	struct pci_dev___6 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___6;

struct pci_dev___6 {
	struct list_head bus_list;
	struct pci_bus___6 *bus;
	struct pci_bus___6 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___6 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___6 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___6 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___149 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___179 *res_attr[17];
	struct bin_attribute___179 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___179 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___3 *sriov;
		struct pci_dev___6 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___6;

struct pci_driver___6 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___6 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___6 *);
	int (*suspend)(struct pci_dev___6 *, pm_message_t);
	int (*resume)(struct pci_dev___6 *);
	void (*shutdown)(struct pci_dev___6 *);
	int (*sriov_configure)(struct pci_dev___6 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___6 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___6 *);
	const struct pci_error_handlers___6 *err_handler;
	const struct attribute_group___179 **groups;
	const struct attribute_group___179 **dev_groups;
	struct device_driver___149 driver;
	struct pci_dynids dynids;
};

struct pci_ops___6 {
	int (*add_bus)(struct pci_bus___6 *);
	void (*remove_bus)(struct pci_bus___6 *);
	void * (*map_bus)(struct pci_bus___6 *, unsigned int, int);
	int (*read)(struct pci_bus___6 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___6 *, unsigned int, int, int, u32);
};

enum pci_ers_result {
	PCI_ERS_RESULT_NONE = 1,
	PCI_ERS_RESULT_CAN_RECOVER = 2,
	PCI_ERS_RESULT_NEED_RESET = 3,
	PCI_ERS_RESULT_DISCONNECT = 4,
	PCI_ERS_RESULT_RECOVERED = 5,
	PCI_ERS_RESULT_NO_AER_DRIVER = 6,
};

struct pci_error_handlers___6 {
	pci_ers_result_t (*error_detected)(struct pci_dev___6 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___6 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___6 *);
	void (*reset_prepare)(struct pci_dev___6 *);
	void (*reset_done)(struct pci_dev___6 *);
	void (*resume)(struct pci_dev___6 *);
};

struct shrink_control___79 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___79 *memcg;
};

struct shrinker___79 {
	long unsigned int (*count_objects)(struct shrinker___79 *, struct shrink_control___79 *);
	long unsigned int (*scan_objects)(struct shrinker___79 *, struct shrink_control___79 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___186 {
	void (*page_free)(struct page___196 *);
	void (*kill)(struct dev_pagemap___186 *);
	void (*cleanup)(struct dev_pagemap___186 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___186 *);
};

struct dentry_operations___191;

struct dentry___191 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___191 *d_parent;
	struct qstr d_name;
	struct inode___191 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___191 *d_op;
	struct super_block___191 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___191;

struct cdev___40;

struct inode___191 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___191 *i_op;
	struct super_block___191 *i_sb;
	struct address_space___191 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___88 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___192 *i_fop;
		void (*free_inode)(struct inode___191 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___191 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___40 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___191 {
	int (*d_revalidate)(struct dentry___191 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___191 *, unsigned int);
	int (*d_hash)(const struct dentry___191 *, struct qstr *);
	int (*d_compare)(const struct dentry___191 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___191 *);
	int (*d_init)(struct dentry___191 *);
	void (*d_release)(struct dentry___191 *);
	void (*d_prune)(struct dentry___191 *);
	void (*d_iput)(struct dentry___191 *, struct inode___191 *);
	char * (*d_dname)(struct dentry___191 *, char *, int);
	struct vfsmount___191 * (*d_automount)(struct path___191 *);
	int (*d_manage)(const struct path___191 *, bool);
	struct dentry___191 * (*d_real)(struct dentry___191 *, const struct inode___191 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___191;

struct mem_dqinfo___191 {
	struct quota_format_type___191 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___191;

struct quota_info___191 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___191 *files[3];
	struct mem_dqinfo___191 info[3];
	const struct quota_format_ops___191 *ops[3];
};

struct rcuwait___192 {
	struct task_struct___198 *task;
};

struct percpu_rw_semaphore___192 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___192 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___191 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___192 rw_sem[3];
};

struct super_operations___191;

struct dquot_operations___191;

struct quotactl_ops___191;

struct block_device___96;

struct super_block___191 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___191 *s_type;
	const struct super_operations___191 *s_op;
	const struct dquot_operations___191 *dq_op;
	const struct quotactl_ops___191 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___191 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___96 *s_bdev;
	struct backing_dev_info___88 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___191 s_dquot;
	struct sb_writers___191 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___191 *s_d_op;
	int cleancache_poolid;
	struct shrinker___79 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___191 {
	struct dentry___191 *mnt_root;
	struct super_block___191 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct psi_group___130 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___198 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___130;

struct cgroup_rstat_cpu___130;

struct cgroup___130 {
	struct cgroup_subsys_state___130 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___179 *kn;
	struct cgroup_file___130 procs_file;
	struct cgroup_file___130 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___130 *subsys[14];
	struct cgroup_root___130 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___130 *dom_cgrp;
	struct cgroup___130 *old_dom_cgrp;
	struct cgroup_rstat_cpu___130 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___130 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___95 {
	struct request_queue___95 *q;
	struct io_context___95 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___88;

struct kiocb___191 {
	struct file___191 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___191 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___88 *ki_waitq;
	};
};

struct iattr___191 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___191 *ia_file;
};

struct dquot___191 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___191 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___191 {
	int qf_fmt_id;
	const struct quota_format_ops___191 *qf_ops;
	struct module___175 *qf_owner;
	struct quota_format_type___191 *qf_next;
};

struct quota_format_ops___191 {
	int (*check_quota_file)(struct super_block___191 *, int);
	int (*read_file_info)(struct super_block___191 *, int);
	int (*write_file_info)(struct super_block___191 *, int);
	int (*free_file_info)(struct super_block___191 *, int);
	int (*read_dqblk)(struct dquot___191 *);
	int (*commit_dqblk)(struct dquot___191 *);
	int (*release_dqblk)(struct dquot___191 *);
	int (*get_next_id)(struct super_block___191 *, struct kqid *);
};

struct dquot_operations___191 {
	int (*write_dquot)(struct dquot___191 *);
	struct dquot___191 * (*alloc_dquot)(struct super_block___191 *, int);
	void (*destroy_dquot)(struct dquot___191 *);
	int (*acquire_dquot)(struct dquot___191 *);
	int (*release_dquot)(struct dquot___191 *);
	int (*mark_dirty)(struct dquot___191 *);
	int (*write_info)(struct super_block___191 *, int);
	qsize_t * (*get_reserved_space)(struct inode___191 *);
	int (*get_projid)(struct inode___191 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___191 *, qsize_t *);
	int (*get_next_id)(struct super_block___191 *, struct kqid *);
};

struct quotactl_ops___191 {
	int (*quota_on)(struct super_block___191 *, int, int, const struct path___191 *);
	int (*quota_off)(struct super_block___191 *, int);
	int (*quota_enable)(struct super_block___191 *, unsigned int);
	int (*quota_disable)(struct super_block___191 *, unsigned int);
	int (*quota_sync)(struct super_block___191 *, int);
	int (*set_info)(struct super_block___191 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___191 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___191 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___191 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___191 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___191 *, unsigned int);
};

struct wait_page_queue___88 {
	struct page___196 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___88;

struct readahead_control___88;

struct swap_info_struct___47;

struct address_space_operations___191 {
	int (*writepage)(struct page___196 *, struct writeback_control___88 *);
	int (*readpage)(struct file___191 *, struct page___196 *);
	int (*writepages)(struct address_space___191 *, struct writeback_control___88 *);
	int (*set_page_dirty)(struct page___196 *);
	int (*readpages)(struct file___191 *, struct address_space___191 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___88 *);
	int (*write_begin)(struct file___191 *, struct address_space___191 *, loff_t, unsigned int, unsigned int, struct page___196 **, void **);
	int (*write_end)(struct file___191 *, struct address_space___191 *, loff_t, unsigned int, unsigned int, struct page___196 *, void *);
	sector_t (*bmap)(struct address_space___191 *, sector_t);
	void (*invalidatepage)(struct page___196 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___196 *, gfp_t);
	void (*freepage)(struct page___196 *);
	ssize_t (*direct_IO)(struct kiocb___191 *, struct iov_iter___113 *);
	int (*migratepage)(struct address_space___191 *, struct page___196 *, struct page___196 *, enum migrate_mode);
	bool (*isolate_page)(struct page___196 *, isolate_mode_t);
	void (*putback_page)(struct page___196 *);
	int (*launder_page)(struct page___196 *);
	int (*is_partially_uptodate)(struct page___196 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___196 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___191 *, struct page___196 *);
	int (*swap_activate)(struct swap_info_struct___47 *, struct file___191 *, sector_t *);
	void (*swap_deactivate)(struct file___191 *);
};

struct writeback_control___88 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___88 *wb;
	struct inode___191 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___88 {
	struct file___191 *file;
	struct address_space___191 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___111;

struct iov_iter___113 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___111 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___47 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___96 *bdev;
	struct file___191 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___40 {
	struct kobject___179 kobj;
	struct module___175 *owner;
	const struct file_operations___192 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___191 {
	struct dentry___191 * (*lookup)(struct inode___191 *, struct dentry___191 *, unsigned int);
	const char * (*get_link)(struct dentry___191 *, struct inode___191 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___191 *, int);
	struct posix_acl * (*get_acl)(struct inode___191 *, int, bool);
	int (*readlink)(struct dentry___191 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___191 *, struct dentry___191 *, umode_t, bool);
	int (*link)(struct dentry___191 *, struct inode___191 *, struct dentry___191 *);
	int (*unlink)(struct inode___191 *, struct dentry___191 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___191 *, struct dentry___191 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___191 *, struct dentry___191 *, umode_t);
	int (*rmdir)(struct inode___191 *, struct dentry___191 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___191 *, struct dentry___191 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___191 *, struct dentry___191 *, struct inode___191 *, struct dentry___191 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___191 *, struct iattr___191 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___191 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___191 *, char *, size_t);
	int (*fiemap)(struct inode___191 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___191 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___191 *, struct dentry___191 *, struct file___191 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___191 *, struct dentry___191 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___191 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___191 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___191 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___191 {
	void (*fl_copy_lock)(struct file_lock___191 *, struct file_lock___191 *);
	void (*fl_release_private)(struct file_lock___191 *);
};

struct fasync_struct___191;

struct lock_manager_operations___191;

struct file_lock___191 {
	struct file_lock___191 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___191 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___191 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___191 *fl_ops;
	const struct lock_manager_operations___191 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___191 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___191 *);
	int (*lm_grant)(struct file_lock___191 *, int);
	bool (*lm_break)(struct file_lock___191 *);
	int (*lm_change)(struct file_lock___191 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___191 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___191 *);
};

struct fasync_struct___191 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___191 *fa_next;
	struct file___191 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___191 {
	struct inode___191 * (*alloc_inode)(struct super_block___191 *);
	void (*destroy_inode)(struct inode___191 *);
	void (*free_inode)(struct inode___191 *);
	void (*dirty_inode)(struct inode___191 *, int);
	int (*write_inode)(struct inode___191 *, struct writeback_control___88 *);
	int (*drop_inode)(struct inode___191 *);
	void (*evict_inode)(struct inode___191 *);
	void (*put_super)(struct super_block___191 *);
	int (*sync_fs)(struct super_block___191 *, int);
	int (*freeze_super)(struct super_block___191 *);
	int (*freeze_fs)(struct super_block___191 *);
	int (*thaw_super)(struct super_block___191 *);
	int (*unfreeze_fs)(struct super_block___191 *);
	int (*statfs)(struct dentry___191 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___191 *, int *, char *);
	void (*umount_begin)(struct super_block___191 *);
	int (*show_options)(struct seq_file___167 *, struct dentry___191 *);
	int (*show_devname)(struct seq_file___167 *, struct dentry___191 *);
	int (*show_path)(struct seq_file___167 *, struct dentry___191 *);
	int (*show_stats)(struct seq_file___167 *, struct dentry___191 *);
	ssize_t (*quota_read)(struct super_block___191 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___191 *, int, const char *, size_t, loff_t);
	struct dquot___191 ** (*get_dquots)(struct inode___191 *);
	long int (*nr_cached_objects)(struct super_block___191 *, struct shrink_control___79 *);
	long int (*free_cached_objects)(struct super_block___191 *, struct shrink_control___79 *);
	struct file___191 * (*real_loop)(struct file___191 *);
};

struct block_device___96 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___191 *bd_inode;
	struct super_block___191 *bd_super;
	void *bd_claiming;
	struct device___149 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___179 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___96 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___191 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___95(struct bio___95 *);

struct bio_vec___111 {
	struct page___196 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___95;

struct bio___95 {
	struct bio___95 *bi_next;
	struct block_device___96 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___95 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___90 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___95 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___111 *bi_io_vec;
	struct bio_set___95 *bi_pool;
	struct bio_vec___111 bi_inline_vecs[0];
};

struct kernel_param_ops___175 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___175 *);
	int (*get)(char *, const struct kernel_param___175 *);
	void (*free)(void *);
};

struct kparam_array___175;

struct kernel_param___175 {
	const char *name;
	struct module___175 *mod;
	const struct kernel_param_ops___175 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___175 *arr;
	};
};

struct kparam_array___175 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___175 *ops;
	void *elem;
};

struct module_attribute___175 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___175 *, struct module_kobject___175 *, char *);
	ssize_t (*store)(struct module_attribute___175 *, struct module_kobject___175 *, const char *, size_t);
	void (*setup)(struct module___175 *, const char *);
	int (*test)(struct module___175 *);
	void (*free)(struct module___175 *);
};

struct cgroup_namespace___130 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___130 *root_cset;
};

struct property___41 {
	char *name;
	int length;
	void *value;
	struct property___41 *next;
	long unsigned int _flags;
	struct bin_attribute___179 attr;
};

struct seq_operations___167 {
	void * (*start)(struct seq_file___167 *, loff_t *);
	void (*stop)(struct seq_file___167 *, void *);
	void * (*next)(struct seq_file___167 *, void *, loff_t *);
	int (*show)(struct seq_file___167 *, void *);
};

struct cftype___130;

struct cgroup_subsys___130 {
	struct cgroup_subsys_state___130 * (*css_alloc)(struct cgroup_subsys_state___130 *);
	int (*css_online)(struct cgroup_subsys_state___130 *);
	void (*css_offline)(struct cgroup_subsys_state___130 *);
	void (*css_released)(struct cgroup_subsys_state___130 *);
	void (*css_free)(struct cgroup_subsys_state___130 *);
	void (*css_reset)(struct cgroup_subsys_state___130 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___130 *, int);
	int (*css_extra_stat_show)(struct seq_file___167 *, struct cgroup_subsys_state___130 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___198 *, struct css_set___130 *);
	void (*cancel_fork)(struct task_struct___198 *, struct css_set___130 *);
	void (*fork)(struct task_struct___198 *);
	void (*exit)(struct task_struct___198 *);
	void (*release)(struct task_struct___198 *);
	void (*bind)(struct cgroup_subsys_state___130 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___130 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___130 *dfl_cftypes;
	struct cftype___130 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___130 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___130 *updated_children;
	struct cgroup___130 *updated_next;
};

struct cgroup_root___130 {
	struct kernfs_root___179 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___130 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___130 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___130 *ss;
	struct list_head node;
	struct kernfs_ops___179 *kf_ops;
	int (*open)(struct kernfs_open_file___179 *);
	void (*release)(struct kernfs_open_file___179 *);
	u64 (*read_u64)(struct cgroup_subsys_state___130 *, struct cftype___130 *);
	s64 (*read_s64)(struct cgroup_subsys_state___130 *, struct cftype___130 *);
	int (*seq_show)(struct seq_file___167 *, void *);
	void * (*seq_start)(struct seq_file___167 *, loff_t *);
	void * (*seq_next)(struct seq_file___167 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___167 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___130 *, struct cftype___130 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___130 *, struct cftype___130 *, s64);
	ssize_t (*write)(struct kernfs_open_file___179 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___179 *, struct poll_table_struct___125 *);
};

struct block_device_operations___95;

struct gendisk___96 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___96 *part0;
	const struct block_device_operations___95 *fops;
	struct request_queue___95 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___88 *bdi;
	struct kobject___179 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___179 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___95 {
	struct bio___95 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___111 *bip_vec;
	struct bio_vec___111 bip_inline_vecs[0];
};

struct blkcg___90;

struct blkg_policy_data___90;

struct blkcg_gq___90 {
	struct request_queue___95 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___90 *blkcg;
	struct blkcg_gq___90 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___90 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___95 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___95(struct request___95 *);

typedef void integrity_complete_fn___95(struct request___95 *, unsigned int);

struct blk_integrity_profile___95 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___95 *prepare_fn;
	integrity_complete_fn___95 *complete_fn;
	const char *name;
};

struct block_device_operations___95 {
	blk_qc_t (*submit_bio)(struct bio___95 *);
	int (*open)(struct block_device___96 *, fmode_t);
	void (*release)(struct gendisk___96 *, fmode_t);
	int (*rw_page)(struct block_device___96 *, sector_t, struct page___196 *, unsigned int);
	int (*ioctl)(struct block_device___96 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___96 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___96 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___96 *);
	int (*getgeo)(struct block_device___96 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___96 *, bool);
	void (*swap_slot_free_notify)(struct block_device___96 *, long unsigned int);
	int (*report_zones)(struct gendisk___96 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___96 *, umode_t *);
	struct module___175 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___96 *, sector_t *);
};

typedef void rq_end_io_fn___95(struct request___95 *, blk_status_t);

struct request___95 {
	struct request_queue___95 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___92 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___95 *bio;
	struct bio___95 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___111 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___95 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___95 *saved_end_io;
		} flush;
	};
	struct gendisk___96 *rq_disk;
	struct block_device___96 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___95 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___92 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___95 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___179 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___191 *debugfs_dir;
	struct dentry___191 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___95;

struct elevator_mq_ops___95 {
	int (*init_sched)(struct request_queue___95 *, struct elevator_type___95 *);
	void (*exit_sched)(struct elevator_queue___95 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___92 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___92 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___92 *);
	bool (*allow_merge)(struct request_queue___95 *, struct request___95 *, struct bio___95 *);
	bool (*bio_merge)(struct request_queue___95 *, struct bio___95 *, unsigned int);
	int (*request_merge)(struct request_queue___95 *, struct request___95 **, struct bio___95 *);
	void (*request_merged)(struct request_queue___95 *, struct request___95 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___95 *, struct request___95 *, struct request___95 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___95 *);
	void (*finish_request)(struct request___95 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___92 *, struct list_head *, bool);
	struct request___95 * (*dispatch_request)(struct blk_mq_hw_ctx___92 *);
	bool (*has_work)(struct blk_mq_hw_ctx___92 *);
	void (*completed_request)(struct request___95 *, u64);
	void (*requeue_request)(struct request___95 *);
	struct request___95 * (*former_request)(struct request_queue___95 *, struct request___95 *);
	struct request___95 * (*next_request)(struct request_queue___95 *, struct request___95 *);
	void (*init_icq)(struct io_cq___95 *);
	void (*exit_icq)(struct io_cq___95 *);
};

struct elv_fs_entry___95;

struct elevator_type___95 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___95 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___95 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___175 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___95 {
	struct elevator_type___95 *type;
	void *elevator_data;
	struct kobject___179 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___95 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___95 *, char *);
	ssize_t (*store)(struct elevator_queue___95 *, const char *, size_t);
};

struct blk_mq_queue_data___92;

struct blk_mq_ops___92 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___92 *, const struct blk_mq_queue_data___92 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___92 *);
	int (*get_budget)(struct request_queue___95 *);
	void (*put_budget)(struct request_queue___95 *, int);
	void (*set_rq_budget_token)(struct request___95 *, int);
	int (*get_rq_budget_token)(struct request___95 *);
	enum blk_eh_timer_return (*timeout)(struct request___95 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___92 *);
	void (*complete)(struct request___95 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___92 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___92 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___92 *, struct request___95 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___92 *, struct request___95 *, unsigned int);
	void (*initialize_rq_fn)(struct request___95 *);
	void (*cleanup_rq)(struct request___95 *);
	bool (*busy)(struct request_queue___95 *);
	int (*map_queues)(struct blk_mq_tag_set___92 *);
	void (*show_rq)(struct seq_file___167 *, struct request___95 *);
};

struct blk_mq_tag_set___92 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___92 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___92 {
	struct request___95 *rq;
	bool last;
};

struct blkcg_policy_data___90;

struct blkcg___90 {
	struct cgroup_subsys_state___130 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___90 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___90 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___90 {
	struct blkcg___90 *blkcg;
	int plid;
};

struct blkg_policy_data___90 {
	struct blkcg_gq___90 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___79 {
	struct mem_cgroup___79 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___79 {
	struct lruvec___86 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___79 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___79 *memcg;
};

struct obj_cgroup___79 {
	struct percpu_ref refcnt;
	struct mem_cgroup___79 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct irq_fwspec___28 {
	struct fwnode_handle___149 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___30 {
	int (*match)(struct irq_domain___30 *, struct device_node___51 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___30 *, struct irq_fwspec___28 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___30 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___30 *, unsigned int);
	int (*xlate)(struct irq_domain___30 *, struct device_node___51 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___30 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___30 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___30 *, struct irq_data___31 *, bool);
	void (*deactivate)(struct irq_domain___30 *, struct irq_data___31 *);
	int (*translate)(struct irq_domain___30 *, struct irq_fwspec___28 *, long unsigned int *, unsigned int *);
};

struct acpi_device___5;

struct acpi_hotplug_profile___5 {
	struct kobject___179 kobj;
	int (*scan_dependent)(struct acpi_device___5 *);
	void (*notify_online)(struct acpi_device___5 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___5 {
	void (*func)(struct acpi_device_wakeup_context___5 *);
	struct device___149 *dev;
};

struct acpi_device_wakeup___5 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___5 context;
	struct wakeup_source___149 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___5;

struct acpi_hotplug_context___5;

struct acpi_driver___5;

struct acpi_device___5 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___149 fwnode;
	struct acpi_device___5 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___5 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___5 *handler;
	struct acpi_hotplug_context___5 *hp;
	struct acpi_driver___5 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___149 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___5 *);
};

struct acpi_scan_handler___5 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___5 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___5 *);
	void (*bind)(struct device___149 *);
	void (*unbind)(struct device___149 *);
	struct acpi_hotplug_profile___5 hotplug;
};

struct acpi_hotplug_context___5 {
	struct acpi_device___5 *self;
	int (*notify)(struct acpi_device___5 *, u32);
	void (*uevent)(struct acpi_device___5 *, u32);
	void (*fixup)(struct acpi_device___5 *);
};

typedef int (*acpi_op_add___5)(struct acpi_device___5 *);

typedef int (*acpi_op_remove___5)(struct acpi_device___5 *);

typedef void (*acpi_op_notify___5)(struct acpi_device___5 *, u32);

struct acpi_device_ops___5 {
	acpi_op_add___5 add;
	acpi_op_remove___5 remove;
	acpi_op_notify___5 notify;
};

struct acpi_driver___5 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___5 ops;
	struct device_driver___149 drv;
	struct module___175 *owner;
};

struct pcie_device {
	int irq;
	struct pci_dev___6 *port;
	u32 service;
	void *priv_data;
	struct device___149 device;
};

struct pcie_port_service_driver {
	const char *name;
	int (*probe)(struct pcie_device *);
	void (*remove)(struct pcie_device *);
	int (*suspend)(struct pcie_device *);
	int (*resume_noirq)(struct pcie_device *);
	int (*resume)(struct pcie_device *);
	int (*runtime_suspend)(struct pcie_device *);
	int (*runtime_resume)(struct pcie_device *);
	void (*error_resume)(struct pci_dev___6 *);
	int port_type;
	u32 service;
	struct device_driver___149 driver;
};

struct pci_dynid {
	struct list_head node;
	struct pci_device_id id;
};

struct drv_dev_and_id {
	struct pci_driver___6 *drv;
	struct pci_dev___6 *dev;
	const struct pci_device_id *id;
};

struct bus_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___148 *, char *);
	ssize_t (*store)(struct bus_type___148 *, const char *, size_t);
};

enum pci_mmap_state {
	pci_mmap_io = 0,
	pci_mmap_mem = 1,
};

enum pci_mmap_api {
	PCI_MMAP_SYSFS = 0,
	PCI_MMAP_PROCFS = 1,
};

struct pci_dev_resource {
	struct list_head list;
	struct resource *res;
	struct pci_dev___6 *dev;
	resource_size_t start;
	resource_size_t end;
	resource_size_t add_size;
	resource_size_t min_align;
	long unsigned int flags;
};

enum release_type {
	leaf_only = 0,
	whole_subtree = 1,
};

enum enable_type {
	undefined = 0,
	user_disabled = 0,
	auto_disabled = 1,
	user_enabled = 2,
	auto_enabled = 3,
};

struct pci_bus___7;

struct pci_slot___7 {
	struct pci_bus___7 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___178 kobj;
};

struct pci_dev___7;

struct pci_ops___7;

struct pci_bus___7 {
	struct list_head node;
	struct pci_bus___7 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___7 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___7 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___136 *bridge;
	struct device___136 dev;
	struct bin_attribute___178 *legacy_io;
	struct bin_attribute___178 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_sriov___4 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___7 *dev;
	struct pci_dev___7 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___7;

struct pci_dev___7 {
	struct list_head bus_list;
	struct pci_bus___7 *bus;
	struct pci_bus___7 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___7 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___7 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___7 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___136 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___178 *res_attr[17];
	struct bin_attribute___178 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___178 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___4 *sriov;
		struct pci_dev___7 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___7;

struct pci_driver___7 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___7 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___7 *);
	int (*suspend)(struct pci_dev___7 *, pm_message_t);
	int (*resume)(struct pci_dev___7 *);
	void (*shutdown)(struct pci_dev___7 *);
	int (*sriov_configure)(struct pci_dev___7 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___7 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___7 *);
	const struct pci_error_handlers___7 *err_handler;
	const struct attribute_group___178 **groups;
	const struct attribute_group___178 **dev_groups;
	struct device_driver___136 driver;
	struct pci_dynids dynids;
};

struct pci_ops___7 {
	int (*add_bus)(struct pci_bus___7 *);
	void (*remove_bus)(struct pci_bus___7 *);
	void * (*map_bus)(struct pci_bus___7 *, unsigned int, int);
	int (*read)(struct pci_bus___7 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___7 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___7 {
	pci_ers_result_t (*error_detected)(struct pci_dev___7 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___7 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___7 *);
	void (*reset_prepare)(struct pci_dev___7 *);
	void (*reset_done)(struct pci_dev___7 *);
	void (*resume)(struct pci_dev___7 *);
};

struct msix_entry {
	u32 vector;
	u16 entry;
};

struct pcie_device___2 {
	int irq;
	struct pci_dev___7 *port;
	u32 service;
	void *priv_data;
	struct device___148 device;
};

struct pcie_port_service_driver___2 {
	const char *name;
	int (*probe)(struct pcie_device___2 *);
	void (*remove)(struct pcie_device___2 *);
	int (*suspend)(struct pcie_device___2 *);
	int (*resume_noirq)(struct pcie_device___2 *);
	int (*resume)(struct pcie_device___2 *);
	int (*runtime_suspend)(struct pcie_device___2 *);
	int (*runtime_resume)(struct pcie_device___2 *);
	void (*error_resume)(struct pci_dev___7 *);
	int port_type;
	u32 service;
	struct device_driver___148 driver;
};

struct portdrv_service_data {
	struct pcie_port_service_driver___2 *drv;
	struct device___148 *dev;
	u32 service;
};

typedef int (*pcie_pm_callback_t)(struct pcie_device___2 *);

struct walk_rcec_data {
	struct pci_dev___6 *rcec;
	int (*user_callback)(struct pci_dev___6 *, void *);
	void *user_data;
};

struct aspm_latency {
	u32 l0s;
	u32 l1;
};

struct pcie_link_state {
	struct pci_dev___6 *pdev;
	struct pci_dev___6 *downstream;
	struct pcie_link_state *root;
	struct pcie_link_state *parent;
	struct list_head sibling;
	u32 aspm_support: 7;
	u32 aspm_enabled: 7;
	u32 aspm_capable: 7;
	u32 aspm_default: 7;
	u32 aspm_disable: 7;
	u32 clkpm_capable: 1;
	u32 clkpm_enabled: 1;
	u32 clkpm_default: 1;
	u32 clkpm_disable: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct aspm_latency latency_up;
	struct aspm_latency latency_dw;
	struct aspm_latency acceptable[8];
};

enum {
	CPER_SEV_RECOVERABLE = 0,
	CPER_SEV_FATAL = 1,
	CPER_SEV_CORRECTED = 2,
	CPER_SEV_INFORMATIONAL = 3,
};

struct aer_stats {
	u64 dev_cor_errs[16];
	u64 dev_fatal_errs[27];
	u64 dev_nonfatal_errs[27];
	u64 dev_total_cor_errs;
	u64 dev_total_fatal_errs;
	u64 dev_total_nonfatal_errs;
	u64 rootport_total_cor_errs;
	u64 rootport_total_fatal_errs;
	u64 rootport_total_nonfatal_errs;
};

struct aer_header_log_regs {
	unsigned int dw0;
	unsigned int dw1;
	unsigned int dw2;
	unsigned int dw3;
};

struct aer_capability_regs {
	u32 header;
	u32 uncor_status;
	u32 uncor_mask;
	u32 uncor_severity;
	u32 cor_status;
	u32 cor_mask;
	u32 cap_control;
	struct aer_header_log_regs header_log;
	u32 root_command;
	u32 root_status;
	u16 cor_err_source;
	u16 uncor_err_source;
};

struct aer_err_info {
	struct pci_dev___7 *dev[5];
	int error_dev_num;
	unsigned int id: 16;
	unsigned int severity: 2;
	unsigned int __pad1: 5;
	unsigned int multi_error_valid: 1;
	unsigned int first_error: 5;
	unsigned int __pad2: 2;
	unsigned int tlp_header_valid: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int status;
	unsigned int mask;
	struct aer_header_log_regs tlp;
};

struct aer_err_source {
	unsigned int status;
	unsigned int id;
};

struct aer_rpc {
	struct pci_dev___7 *rpd;
	struct {
		union {
			struct __kfifo kfifo;
			struct aer_err_source *type;
			const struct aer_err_source *const_type;
			char (*rectype)[0];
			struct aer_err_source *ptr;
			const struct aer_err_source *ptr_const;
		};
		struct aer_err_source buf[128];
	} aer_fifo;
};

struct aer_recover_entry {
	u8 bus;
	u8 devfn;
	u16 domain;
	int severity;
	struct aer_capability_regs *regs;
};

struct pcie_pme_service_data {
	spinlock_t lock;
	struct pcie_device___2 *srv;
	struct work_struct work;
	bool noirq;
};

struct pci_slot_attribute {
	struct attribute attr;
	ssize_t (*show)(struct pci_slot___6 *, char *);
	ssize_t (*store)(struct pci_slot___6 *, const char *, size_t);
};

struct irq_desc___33;

typedef void (*irq_flow_handler_t___33)(struct irq_desc___33 *);

struct msi_desc___10;

struct irq_common_data___10 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___10 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___32;

struct irq_domain___31;

struct irq_data___32 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___10 *common;
	struct irq_chip___32 *chip;
	struct irq_domain___31 *domain;
	struct irq_data___32 *parent_data;
	void *chip_data;
};

struct irq_desc___33 {
	struct irq_common_data___10 irq_common_data;
	struct irq_data___32 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___33 handle_irq;
	struct irqaction___22 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___179 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___175 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___150;

struct device___150;

struct fwnode_handle___150 {
	struct fwnode_handle___150 *secondary;
	const struct fwnode_operations___150 *ops;
	struct device___150 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___150;

struct fwnode_endpoint___150;

struct fwnode_operations___150 {
	struct fwnode_handle___150 * (*get)(struct fwnode_handle___150 *);
	void (*put)(struct fwnode_handle___150 *);
	bool (*device_is_available)(const struct fwnode_handle___150 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___150 *, const struct device___150 *);
	bool (*property_present)(const struct fwnode_handle___150 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___150 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___150 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___150 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*get_parent)(const struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*get_next_child_node)(const struct fwnode_handle___150 *, struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*get_named_child_node)(const struct fwnode_handle___150 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___150 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___150 *);
	struct fwnode_handle___150 * (*graph_get_next_endpoint)(const struct fwnode_handle___150 *, struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*graph_get_remote_endpoint)(const struct fwnode_handle___150 *);
	struct fwnode_handle___150 * (*graph_get_port_parent)(struct fwnode_handle___150 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___150 *, struct fwnode_endpoint___150 *);
	int (*add_links)(struct fwnode_handle___150 *);
};

struct wakeup_source___150;

struct dev_pm_qos___10;

struct dev_pm_info___150 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___150 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___150 *, s32);
	struct dev_pm_qos___10 *qos;
};

struct device_type___150;

struct bus_type___150;

struct device_driver___150;

struct dev_pm_domain___150;

struct device_node___52;

struct class___150;

struct device___150 {
	struct kobject___179 kobj;
	struct device___150 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___150 *type;
	struct bus_type___150 *bus;
	struct device_driver___150 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___150 power;
	struct dev_pm_domain___150 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___31 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___52 *of_node;
	struct fwnode_handle___150 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___150 *class;
	const struct attribute_group___179 **groups;
	void (*release)(struct device___150 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___150 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___150 *local_fwnode;
};

struct fwnode_reference_args___150 {
	struct fwnode_handle___150 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___52 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___150 fwnode;
	struct property___41 *properties;
	struct property___41 *deadprops;
	struct device_node___52 *parent;
	struct device_node___52 *child;
	struct device_node___52 *sibling;
	struct kobject___179 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___29 {
	struct fwnode_handle___150 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___31 {
	int (*match)(struct irq_domain___31 *, struct device_node___52 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___31 *, struct irq_fwspec___29 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___31 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___31 *, unsigned int);
	int (*xlate)(struct irq_domain___31 *, struct device_node___52 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___31 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___31 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___31 *, struct irq_data___32 *, bool);
	void (*deactivate)(struct irq_domain___31 *, struct irq_data___32 *);
	int (*translate)(struct irq_domain___31 *, struct irq_fwspec___29 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___31;

struct irq_domain___31 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___31 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___150 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___31 *gc;
	struct irq_domain___31 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___32 *revmap[0];
};

struct irq_chip_generic___31;

struct irq_domain_chip_generic___31 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___31 *gc[0];
};

struct dev_pm_ops___150 {
	int (*prepare)(struct device___150 *);
	void (*complete)(struct device___150 *);
	int (*suspend)(struct device___150 *);
	int (*resume)(struct device___150 *);
	int (*freeze)(struct device___150 *);
	int (*thaw)(struct device___150 *);
	int (*poweroff)(struct device___150 *);
	int (*restore)(struct device___150 *);
	int (*suspend_late)(struct device___150 *);
	int (*resume_early)(struct device___150 *);
	int (*freeze_late)(struct device___150 *);
	int (*thaw_early)(struct device___150 *);
	int (*poweroff_late)(struct device___150 *);
	int (*restore_early)(struct device___150 *);
	int (*suspend_noirq)(struct device___150 *);
	int (*resume_noirq)(struct device___150 *);
	int (*freeze_noirq)(struct device___150 *);
	int (*thaw_noirq)(struct device___150 *);
	int (*poweroff_noirq)(struct device___150 *);
	int (*restore_noirq)(struct device___150 *);
	int (*runtime_suspend)(struct device___150 *);
	int (*runtime_resume)(struct device___150 *);
	int (*runtime_idle)(struct device___150 *);
};

struct wakeup_source___150 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___150 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___10;

struct dev_pm_qos___10 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___10 *resume_latency_req;
	struct dev_pm_qos_request___10 *latency_tolerance_req;
	struct dev_pm_qos_request___10 *flags_req;
};

struct dev_pm_domain___150 {
	struct dev_pm_ops___150 ops;
	int (*start)(struct device___150 *);
	void (*detach)(struct device___150 *, bool);
	int (*activate)(struct device___150 *);
	void (*sync)(struct device___150 *);
	void (*dismiss)(struct device___150 *);
};

struct bus_type___150 {
	const char *name;
	const char *dev_name;
	struct device___150 *dev_root;
	const struct attribute_group___179 **bus_groups;
	const struct attribute_group___179 **dev_groups;
	const struct attribute_group___179 **drv_groups;
	int (*match)(struct device___150 *, struct device_driver___150 *);
	int (*uevent)(struct device___150 *, struct kobj_uevent_env *);
	int (*probe)(struct device___150 *);
	void (*sync_state)(struct device___150 *);
	void (*remove)(struct device___150 *);
	void (*shutdown)(struct device___150 *);
	int (*online)(struct device___150 *);
	int (*offline)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	int (*num_vf)(struct device___150 *);
	int (*dma_configure)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___150 {
	const char *name;
	struct bus_type___150 *bus;
	struct module___175 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___150 *);
	void (*sync_state)(struct device___150 *);
	int (*remove)(struct device___150 *);
	void (*shutdown)(struct device___150 *);
	int (*suspend)(struct device___150 *, pm_message_t);
	int (*resume)(struct device___150 *);
	const struct attribute_group___179 **groups;
	const struct attribute_group___179 **dev_groups;
	const struct dev_pm_ops___150 *pm;
	void (*coredump)(struct device___150 *);
	struct driver_private *p;
};

struct device_type___150 {
	const char *name;
	const struct attribute_group___179 **groups;
	int (*uevent)(struct device___150 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___150 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___150 *);
	const struct dev_pm_ops___150 *pm;
};

struct class___150 {
	const char *name;
	struct module___175 *owner;
	const struct attribute_group___179 **class_groups;
	const struct attribute_group___179 **dev_groups;
	struct kobject___179 *dev_kobj;
	int (*dev_uevent)(struct device___150 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___150 *, umode_t *);
	void (*class_release)(struct class___150 *);
	void (*dev_release)(struct device___150 *);
	int (*shutdown_pre)(struct device___150 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___150 *);
	void (*get_ownership)(struct device___150 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___150 *pm;
	struct subsys_private *p;
};

struct msi_desc___10 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___150 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___10 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___32 {
	struct device___150 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___32 *);
	void (*irq_shutdown)(struct irq_data___32 *);
	void (*irq_enable)(struct irq_data___32 *);
	void (*irq_disable)(struct irq_data___32 *);
	void (*irq_ack)(struct irq_data___32 *);
	void (*irq_mask)(struct irq_data___32 *);
	void (*irq_mask_ack)(struct irq_data___32 *);
	void (*irq_unmask)(struct irq_data___32 *);
	void (*irq_eoi)(struct irq_data___32 *);
	int (*irq_set_affinity)(struct irq_data___32 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___32 *);
	int (*irq_set_type)(struct irq_data___32 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___32 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___32 *);
	void (*irq_bus_sync_unlock)(struct irq_data___32 *);
	void (*irq_cpu_online)(struct irq_data___32 *);
	void (*irq_cpu_offline)(struct irq_data___32 *);
	void (*irq_suspend)(struct irq_data___32 *);
	void (*irq_resume)(struct irq_data___32 *);
	void (*irq_pm_shutdown)(struct irq_data___32 *);
	void (*irq_calc_mask)(struct irq_data___32 *);
	void (*irq_print_chip)(struct irq_data___32 *, struct seq_file___167 *);
	int (*irq_request_resources)(struct irq_data___32 *);
	void (*irq_release_resources)(struct irq_data___32 *);
	void (*irq_compose_msi_msg)(struct irq_data___32 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___32 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___32 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___32 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___32 *, void *);
	void (*ipi_send_single)(struct irq_data___32 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___32 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___32 *);
	void (*irq_nmi_teardown)(struct irq_data___32 *);
	long unsigned int flags;
};

struct irq_chip_type___31 {
	struct irq_chip___32 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___33 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___31 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___31 *);
	void (*resume)(struct irq_chip_generic___31 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___31 *domain;
	struct list_head list;
	struct irq_chip_type___31 chip_types[0];
};

struct pci_bus___8;

struct hotplug_slot___2;

struct pci_slot___8 {
	struct pci_bus___8 *bus;
	struct list_head list;
	struct hotplug_slot___2 *hotplug;
	unsigned char number;
	struct kobject___179 kobj;
};

struct pci_dev___8;

struct pci_ops___8;

struct pci_bus___8 {
	struct list_head node;
	struct pci_bus___8 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___8 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___8 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___150 *bridge;
	struct device___150 dev;
	struct bin_attribute___179 *legacy_io;
	struct bin_attribute___179 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hotplug_slot_ops___2;

struct hotplug_slot___2 {
	const struct hotplug_slot_ops___2 *ops;
	struct list_head slot_list;
	struct pci_slot___8 *pci_slot;
	struct module___175 *owner;
	const char *mod_name;
};

struct pci_sriov___5 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___8 *dev;
	struct pci_dev___8 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___8;

struct pci_dev___8 {
	struct list_head bus_list;
	struct pci_bus___8 *bus;
	struct pci_bus___8 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___8 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___8 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___8 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___150 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___179 *res_attr[17];
	struct bin_attribute___179 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___179 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___5 *sriov;
		struct pci_dev___8 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___8;

struct pci_driver___8 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___8 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___8 *);
	int (*suspend)(struct pci_dev___8 *, pm_message_t);
	int (*resume)(struct pci_dev___8 *);
	void (*shutdown)(struct pci_dev___8 *);
	int (*sriov_configure)(struct pci_dev___8 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___8 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___8 *);
	const struct pci_error_handlers___8 *err_handler;
	const struct attribute_group___179 **groups;
	const struct attribute_group___179 **dev_groups;
	struct device_driver___150 driver;
	struct pci_dynids dynids;
};

struct pci_host_bridge___3 {
	struct device___150 dev;
	struct pci_bus___8 *bus;
	struct pci_ops___8 *ops;
	struct pci_ops___8 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___8 *, u8 *);
	int (*map_irq)(const struct pci_dev___8 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___3 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___8 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___8 {
	int (*add_bus)(struct pci_bus___8 *);
	void (*remove_bus)(struct pci_bus___8 *);
	void * (*map_bus)(struct pci_bus___8 *, unsigned int, int);
	int (*read)(struct pci_bus___8 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___8 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___8 {
	pci_ers_result_t (*error_detected)(struct pci_dev___8 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___8 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___8 *);
	void (*reset_prepare)(struct pci_dev___8 *);
	void (*reset_done)(struct pci_dev___8 *);
	void (*resume)(struct pci_dev___8 *);
};

struct hotplug_slot_ops___2 {
	int (*enable_slot)(struct hotplug_slot___2 *);
	int (*disable_slot)(struct hotplug_slot___2 *);
	int (*set_attention_status)(struct hotplug_slot___2 *, u8);
	int (*hardware_test)(struct hotplug_slot___2 *, u32);
	int (*get_power_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___2 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___2 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___2 *, bool);
};

typedef acpi_status (*acpi_walk_callback)(acpi_handle, u32, void *, void **);

struct acpi_device___6;

struct acpi_hotplug_profile___6 {
	struct kobject___179 kobj;
	int (*scan_dependent)(struct acpi_device___6 *);
	void (*notify_online)(struct acpi_device___6 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___6 {
	void (*func)(struct acpi_device_wakeup_context___6 *);
	struct device___150 *dev;
};

struct acpi_device_wakeup___6 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___6 context;
	struct wakeup_source___150 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___6;

struct acpi_hotplug_context___6;

struct acpi_driver___6;

struct acpi_device___6 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___150 fwnode;
	struct acpi_device___6 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___6 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___6 *handler;
	struct acpi_hotplug_context___6 *hp;
	struct acpi_driver___6 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___150 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___6 *);
};

struct acpi_scan_handler___6 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___6 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___6 *);
	void (*bind)(struct device___150 *);
	void (*unbind)(struct device___150 *);
	struct acpi_hotplug_profile___6 hotplug;
};

struct acpi_hotplug_context___6 {
	struct acpi_device___6 *self;
	int (*notify)(struct acpi_device___6 *, u32);
	void (*uevent)(struct acpi_device___6 *, u32);
	void (*fixup)(struct acpi_device___6 *);
};

typedef int (*acpi_op_add___6)(struct acpi_device___6 *);

typedef int (*acpi_op_remove___6)(struct acpi_device___6 *);

typedef void (*acpi_op_notify___6)(struct acpi_device___6 *, u32);

struct acpi_device_ops___6 {
	acpi_op_add___6 add;
	acpi_op_remove___6 remove;
	acpi_op_notify___6 notify;
};

struct acpi_driver___6 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___6 ops;
	struct device_driver___150 drv;
	struct module___175 *owner;
};

struct acpi_bus_type {
	struct list_head list;
	const char *name;
	bool (*match)(struct device___150 *);
	struct acpi_device___6 * (*find_companion)(struct device___150 *);
	void (*setup)(struct device___150 *);
	void (*cleanup)(struct device___150 *);
};

struct acpi_pci_root___2 {
	struct acpi_device___6 *device;
	struct pci_bus___8 *bus;
	u16 segment;
	struct resource secondary;
	u32 osc_support_set;
	u32 osc_control_set;
	phys_addr_t mcfg_addr;
};

enum pm_qos_flags_status {
	PM_QOS_FLAGS_UNDEFINED = 0,
	PM_QOS_FLAGS_NONE = 0,
	PM_QOS_FLAGS_SOME = 1,
	PM_QOS_FLAGS_ALL = 2,
};

struct dev_pm_qos_request___10 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___150 *dev;
};

struct pci_platform_pm_ops___2 {
	bool (*bridge_d3)(struct pci_dev___8 *);
	bool (*is_manageable)(struct pci_dev___8 *);
	int (*set_state)(struct pci_dev___8 *, pci_power_t);
	pci_power_t (*get_state)(struct pci_dev___8 *);
	void (*refresh_state)(struct pci_dev___8 *);
	pci_power_t (*choose_state)(struct pci_dev___8 *);
	int (*set_wakeup)(struct pci_dev___8 *, bool);
	bool (*need_resume)(struct pci_dev___8 *);
};

struct hpx_type0 {
	u32 revision;
	u8 cache_line_size;
	u8 latency_timer;
	u8 enable_serr;
	u8 enable_perr;
};

struct hpx_type1 {
	u32 revision;
	u8 max_mem_read;
	u8 avg_max_split;
	u16 tot_max_split;
};

struct hpx_type2 {
	u32 revision;
	u32 unc_err_mask_and;
	u32 unc_err_mask_or;
	u32 unc_err_sever_and;
	u32 unc_err_sever_or;
	u32 cor_err_mask_and;
	u32 cor_err_mask_or;
	u32 adv_err_cap_and;
	u32 adv_err_cap_or;
	u16 pci_exp_devctl_and;
	u16 pci_exp_devctl_or;
	u16 pci_exp_lnkctl_and;
	u16 pci_exp_lnkctl_or;
	u32 sec_unc_err_sever_and;
	u32 sec_unc_err_sever_or;
	u32 sec_unc_err_mask_and;
	u32 sec_unc_err_mask_or;
};

struct hpx_type3 {
	u16 device_type;
	u16 function_type;
	u16 config_space_location;
	u16 pci_exp_cap_id;
	u16 pci_exp_cap_ver;
	u16 pci_exp_vendor_id;
	u16 dvsec_id;
	u16 dvsec_rev;
	u16 match_offset;
	u32 match_mask_and;
	u32 match_value;
	u16 reg_offset;
	u32 reg_mask_and;
	u32 reg_mask_or;
};

enum hpx_type3_dev_type {
	HPX_TYPE_ENDPOINT = 1,
	HPX_TYPE_LEG_END = 2,
	HPX_TYPE_RC_END = 4,
	HPX_TYPE_RC_EC = 8,
	HPX_TYPE_ROOT_PORT = 16,
	HPX_TYPE_UPSTREAM = 32,
	HPX_TYPE_DOWNSTREAM = 64,
	HPX_TYPE_PCI_BRIDGE = 128,
	HPX_TYPE_PCIE_BRIDGE = 256,
};

enum hpx_type3_fn_type {
	HPX_FN_NORMAL = 1,
	HPX_FN_SRIOV_PHYS = 2,
	HPX_FN_SRIOV_VIRT = 4,
};

enum hpx_type3_cfg_loc {
	HPX_CFG_PCICFG = 0,
	HPX_CFG_PCIE_CAP = 1,
	HPX_CFG_PCIE_CAP_EXT = 2,
	HPX_CFG_VEND_CAP = 3,
	HPX_CFG_DVSEC = 4,
	HPX_CFG_MAX = 5,
};

struct of_bus;

struct of_pci_range_parser {
	struct device_node___52 *node;
	struct of_bus *bus;
	const __be32 *range;
	const __be32 *end;
	int na;
	int ns;
	int pna;
	bool dma;
};

struct of_pci_range {
	union {
		u64 pci_addr;
		u64 bus_addr;
	};
	u64 cpu_addr;
	u64 size;
	u32 flags;
};

struct device_link___10 {
	struct device___149 *supplier;
	struct list_head s_node;
	struct device___149 *consumer;
	struct list_head c_node;
	struct device___149 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct pci_fixup {
	u16 vendor;
	u16 device;
	u32 class;
	unsigned int class_shift;
	int hook_offset;
};

enum {
	NVME_REG_CAP = 0,
	NVME_REG_VS = 8,
	NVME_REG_INTMS = 12,
	NVME_REG_INTMC = 16,
	NVME_REG_CC = 20,
	NVME_REG_CSTS = 28,
	NVME_REG_NSSR = 32,
	NVME_REG_AQA = 36,
	NVME_REG_ASQ = 40,
	NVME_REG_ACQ = 48,
	NVME_REG_CMBLOC = 56,
	NVME_REG_CMBSZ = 60,
	NVME_REG_BPINFO = 64,
	NVME_REG_BPRSEL = 68,
	NVME_REG_BPMBL = 72,
	NVME_REG_CMBMSC = 80,
	NVME_REG_PMRCAP = 3584,
	NVME_REG_PMRCTL = 3588,
	NVME_REG_PMRSTS = 3592,
	NVME_REG_PMREBS = 3596,
	NVME_REG_PMRSWTP = 3600,
	NVME_REG_DBS = 4096,
};

enum {
	NVME_CC_ENABLE = 1,
	NVME_CC_EN_SHIFT = 0,
	NVME_CC_CSS_SHIFT = 4,
	NVME_CC_MPS_SHIFT = 7,
	NVME_CC_AMS_SHIFT = 11,
	NVME_CC_SHN_SHIFT = 14,
	NVME_CC_IOSQES_SHIFT = 16,
	NVME_CC_IOCQES_SHIFT = 20,
	NVME_CC_CSS_NVM = 0,
	NVME_CC_CSS_CSI = 96,
	NVME_CC_CSS_MASK = 112,
	NVME_CC_AMS_RR = 0,
	NVME_CC_AMS_WRRU = 2048,
	NVME_CC_AMS_VS = 14336,
	NVME_CC_SHN_NONE = 0,
	NVME_CC_SHN_NORMAL = 16384,
	NVME_CC_SHN_ABRUPT = 32768,
	NVME_CC_SHN_MASK = 49152,
	NVME_CC_IOSQES = 393216,
	NVME_CC_IOCQES = 4194304,
	NVME_CAP_CSS_NVM = 1,
	NVME_CAP_CSS_CSI = 64,
	NVME_CSTS_RDY = 1,
	NVME_CSTS_CFS = 2,
	NVME_CSTS_NSSRO = 16,
	NVME_CSTS_PP = 32,
	NVME_CSTS_SHST_NORMAL = 0,
	NVME_CSTS_SHST_OCCUR = 4,
	NVME_CSTS_SHST_CMPLT = 8,
	NVME_CSTS_SHST_MASK = 12,
	NVME_CMBMSC_CRE = 1,
	NVME_CMBMSC_CMSE = 2,
};

enum {
	NVME_AEN_BIT_NS_ATTR = 8,
	NVME_AEN_BIT_FW_ACT = 9,
	NVME_AEN_BIT_ANA_CHANGE = 11,
	NVME_AEN_BIT_DISC_CHANGE = 31,
};

enum {
	SWITCHTEC_GAS_MRPC_OFFSET = 0,
	SWITCHTEC_GAS_TOP_CFG_OFFSET = 4096,
	SWITCHTEC_GAS_SW_EVENT_OFFSET = 6144,
	SWITCHTEC_GAS_SYS_INFO_OFFSET = 8192,
	SWITCHTEC_GAS_FLASH_INFO_OFFSET = 8704,
	SWITCHTEC_GAS_PART_CFG_OFFSET = 16384,
	SWITCHTEC_GAS_NTB_OFFSET = 65536,
	SWITCHTEC_GAS_PFF_CSR_OFFSET = 1261568,
};

enum {
	SWITCHTEC_NTB_REG_INFO_OFFSET = 0,
	SWITCHTEC_NTB_REG_CTRL_OFFSET = 16384,
	SWITCHTEC_NTB_REG_DBMSG_OFFSET = 409600,
};

struct nt_partition_info {
	u32 xlink_enabled;
	u32 target_part_low;
	u32 target_part_high;
	u32 reserved;
};

struct ntb_info_regs {
	u8 partition_count;
	u8 partition_id;
	u16 reserved1;
	u64 ep_map;
	u16 requester_id;
	u16 reserved2;
	u32 reserved3[4];
	struct nt_partition_info ntp_info[48];
} __attribute__((packed));

struct ntb_ctrl_regs {
	u32 partition_status;
	u32 partition_op;
	u32 partition_ctrl;
	u32 bar_setup;
	u32 bar_error;
	u16 lut_table_entries;
	u16 lut_table_offset;
	u32 lut_error;
	u16 req_id_table_size;
	u16 req_id_table_offset;
	u32 req_id_error;
	u32 reserved1[7];
	struct {
		u32 ctl;
		u32 win_size;
		u64 xlate_addr;
	} bar_entry[6];
	struct {
		u32 win_size;
		u32 reserved[3];
	} bar_ext_entry[6];
	u32 reserved2[192];
	u32 req_id_table[512];
	u32 reserved3[256];
	u64 lut_entry[512];
};

struct pci_dev_reset_methods {
	u16 vendor;
	u16 device;
	int (*reset)(struct pci_dev___8 *, bool);
};

struct pci_dev_acs_enabled {
	u16 vendor;
	u16 device;
	int (*acs_enabled)(struct pci_dev___8 *, u16);
};

struct pci_dev_acs_ops {
	u16 vendor;
	u16 device;
	int (*enable_acs)(struct pci_dev___8 *);
	int (*disable_acs_redir)(struct pci_dev___8 *);
};

struct pci_bus___9;

struct hotplug_slot___3;

struct pci_slot___9 {
	struct pci_bus___9 *bus;
	struct list_head list;
	struct hotplug_slot___3 *hotplug;
	unsigned char number;
	struct kobject___175 kobj;
};

struct pci_dev___9;

struct pci_ops___9;

struct pci_bus___9 {
	struct list_head node;
	struct pci_bus___9 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___9 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___9 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___145 *bridge;
	struct device___145 dev;
	struct bin_attribute___175 *legacy_io;
	struct bin_attribute___175 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hotplug_slot_ops___3;

struct hotplug_slot___3 {
	const struct hotplug_slot_ops___3 *ops;
	struct list_head slot_list;
	struct pci_slot___9 *pci_slot;
	struct module___171 *owner;
	const char *mod_name;
};

struct pci_sriov___6 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___9 *dev;
	struct pci_dev___9 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___9;

struct pci_dev___9 {
	struct list_head bus_list;
	struct pci_bus___9 *bus;
	struct pci_bus___9 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___9 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___9 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___9 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___145 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___175 *res_attr[17];
	struct bin_attribute___175 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___175 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___6 *sriov;
		struct pci_dev___9 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___9;

struct pci_driver___9 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___9 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___9 *);
	int (*suspend)(struct pci_dev___9 *, pm_message_t);
	int (*resume)(struct pci_dev___9 *);
	void (*shutdown)(struct pci_dev___9 *);
	int (*sriov_configure)(struct pci_dev___9 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___9 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___9 *);
	const struct pci_error_handlers___9 *err_handler;
	const struct attribute_group___175 **groups;
	const struct attribute_group___175 **dev_groups;
	struct device_driver___145 driver;
	struct pci_dynids dynids;
};

struct pci_ops___9 {
	int (*add_bus)(struct pci_bus___9 *);
	void (*remove_bus)(struct pci_bus___9 *);
	void * (*map_bus)(struct pci_bus___9 *, unsigned int, int);
	int (*read)(struct pci_bus___9 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___9 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___9 {
	pci_ers_result_t (*error_detected)(struct pci_dev___9 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___9 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___9 *);
	void (*reset_prepare)(struct pci_dev___9 *);
	void (*reset_done)(struct pci_dev___9 *);
	void (*resume)(struct pci_dev___9 *);
};

struct hotplug_slot_ops___3 {
	int (*enable_slot)(struct hotplug_slot___3 *);
	int (*disable_slot)(struct hotplug_slot___3 *);
	int (*set_attention_status)(struct hotplug_slot___3 *, u8);
	int (*hardware_test)(struct hotplug_slot___3 *, u32);
	int (*get_power_status)(struct hotplug_slot___3 *, u8 *);
	int (*get_attention_status)(struct hotplug_slot___3 *, u8 *);
	int (*get_latch_status)(struct hotplug_slot___3 *, u8 *);
	int (*get_adapter_status)(struct hotplug_slot___3 *, u8 *);
	int (*reset_slot)(struct hotplug_slot___3 *, bool);
};

struct pci_slot_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct pci_slot___9 *, char *);
	ssize_t (*store)(struct pci_slot___9 *, const char *, size_t);
};

struct slot {
	u8 number;
	unsigned int devfn;
	struct pci_bus___9 *bus;
	struct pci_dev___9 *dev;
	unsigned int latch_status: 1;
	unsigned int adapter_status: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	unsigned int extracting;
	struct hotplug_slot___3 hotplug_slot;
	struct list_head slot_list;
};

struct cpci_hp_controller_ops {
	int (*query_enum)();
	int (*enable_irq)();
	int (*disable_irq)();
	int (*check_irq)(void *);
	int (*hardware_test)(struct slot *, u32);
	u8 (*get_power)(struct slot *);
	int (*set_power)(struct slot *, int);
};

struct cpci_hp_controller {
	unsigned int irq;
	long unsigned int irq_flags;
	char *devname;
	void *dev_id;
	char *name;
	struct cpci_hp_controller_ops *ops;
};

struct controller {
	struct pcie_device *pcie;
	u32 slot_cap;
	unsigned int inband_presence_disabled: 1;
	long: 47;
	long: 64;
	u16 slot_ctrl;
	struct mutex ctrl_lock;
	long unsigned int cmd_started;
	unsigned int cmd_busy: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	wait_queue_head_t queue;
	atomic_t pending_events;
	unsigned int notification_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int power_fault_detected;
	struct task_struct___198 *poll_thread;
	u8 state;
	struct mutex state_lock;
	struct delayed_work button_work;
	struct hotplug_slot___2 hotplug_slot;
	struct rw_semaphore reset_lock;
	unsigned int depth;
	unsigned int ist_running;
	int request_result;
	wait_queue_head_t requester;
};

struct pcie_device___3 {
	int irq;
	struct pci_dev___9 *port;
	u32 service;
	void *priv_data;
	struct device___148 device;
};

struct controller___2 {
	struct pcie_device___3 *pcie;
	u32 slot_cap;
	unsigned int inband_presence_disabled: 1;
	long: 47;
	long: 64;
	u16 slot_ctrl;
	struct mutex ctrl_lock;
	long unsigned int cmd_started;
	unsigned int cmd_busy;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	wait_queue_head_t queue;
	atomic_t pending_events;
	unsigned int notification_enabled;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int power_fault_detected;
	struct task_struct___197 *poll_thread;
	u8 state;
	struct mutex state_lock;
	struct delayed_work button_work;
	struct hotplug_slot___3 hotplug_slot;
	struct rw_semaphore reset_lock;
	unsigned int depth;
	unsigned int ist_running;
	int request_result;
	wait_queue_head_t requester;
};

struct controller___3;

struct hpc_ops;

struct slot___2 {
	u8 bus;
	u8 device;
	u16 status;
	u32 number;
	u8 is_a_board;
	u8 state;
	u8 attention_save;
	u8 presence_save;
	u8 latch_save;
	u8 pwr_save;
	struct controller___3 *ctrl;
	const struct hpc_ops *hpc_ops;
	struct hotplug_slot___3 hotplug_slot;
	struct list_head slot_list;
	struct delayed_work work;
	struct mutex lock;
	struct workqueue_struct *wq;
	u8 hp_slot;
};

struct controller___3 {
	struct mutex crit_sect;
	struct mutex cmd_lock;
	int num_slots;
	int slot_num_inc;
	struct pci_dev___9 *pci_dev;
	struct list_head slot_list;
	const struct hpc_ops *hpc_ops;
	wait_queue_head_t queue;
	u8 slot_device_offset;
	u32 pcix_misc2_reg;
	u32 first_slot;
	u32 cap_offset;
	long unsigned int mmio_base;
	long unsigned int mmio_size;
	void *creg;
	struct timer_list poll_timer;
};

struct hpc_ops {
	int (*power_on_slot)(struct slot___2 *);
	int (*slot_enable)(struct slot___2 *);
	int (*slot_disable)(struct slot___2 *);
	int (*set_bus_speed_mode)(struct slot___2 *, enum pci_bus_speed);
	int (*get_power_status)(struct slot___2 *, u8 *);
	int (*get_attention_status)(struct slot___2 *, u8 *);
	int (*set_attention_status)(struct slot___2 *, u8);
	int (*get_latch_status)(struct slot___2 *, u8 *);
	int (*get_adapter_status)(struct slot___2 *, u8 *);
	int (*get_adapter_speed)(struct slot___2 *, enum pci_bus_speed *);
	int (*get_mode1_ECC_cap)(struct slot___2 *, u8 *);
	int (*get_prog_int)(struct slot___2 *, u8 *);
	int (*query_power_fault)(struct slot___2 *);
	void (*green_led_on)(struct slot___2 *);
	void (*green_led_off)(struct slot___2 *);
	void (*green_led_blink)(struct slot___2 *);
	void (*release_ctlr)(struct controller___3 *);
	int (*check_cmd_status)(struct controller___3 *);
};

struct event_info {
	u32 event_type;
	struct slot___2 *p_slot;
	struct work_struct work;
};

struct pushbutton_work_info {
	struct slot___2 *p_slot;
	struct work_struct work;
};

enum ctrl_offsets {
	BASE_OFFSET = 0,
	SLOT_AVAIL1 = 4,
	SLOT_AVAIL2 = 8,
	SLOT_CONFIG = 12,
	SEC_BUS_CONFIG = 16,
	MSI_CTRL = 18,
	PROG_INTERFACE = 19,
	CMD = 20,
	CMD_STATUS = 22,
	INTR_LOC = 24,
	SERR_LOC = 28,
	SERR_INTR_ENABLE = 32,
	SLOT1 = 36,
};

struct acpiphp_slot;

struct slot___3 {
	struct hotplug_slot___2 hotplug_slot;
	struct acpiphp_slot *acpi_slot;
	unsigned int sun;
};

struct acpiphp_slot {
	struct list_head node;
	struct pci_bus___8 *bus;
	struct list_head funcs;
	struct slot___3 *slot;
	u8 device;
	u32 flags;
};

struct acpiphp_attention_info {
	int (*set_attn)(struct hotplug_slot___2 *, u8);
	int (*get_attn)(struct hotplug_slot___2 *, u8 *);
	struct module___175 *owner;
};

struct acpiphp_context;

struct acpiphp_bridge {
	struct list_head list;
	struct list_head slots;
	struct kref ref;
	struct acpiphp_context *context;
	int nr_slots;
	struct pci_bus___8 *pci_bus;
	struct pci_dev___8 *pci_dev;
	bool is_going_away;
};

struct acpiphp_func {
	struct acpiphp_bridge *parent;
	struct acpiphp_slot *slot;
	struct list_head sibling;
	u8 function;
	u32 flags;
};

struct acpiphp_context {
	struct acpi_hotplug_context___6 hp;
	struct acpiphp_func func;
	struct acpiphp_bridge *bridge;
	unsigned int refcount;
};

struct acpiphp_root_context {
	struct acpi_hotplug_context___6 hp;
	struct acpiphp_bridge *root_bridge;
};

struct pci_bridge_emul_conf {
	__le16 vendor;
	__le16 device;
	__le16 command;
	__le16 status;
	__le32 class_revision;
	u8 cache_line_size;
	u8 latency_timer;
	u8 header_type;
	u8 bist;
	__le32 bar[2];
	u8 primary_bus;
	u8 secondary_bus;
	u8 subordinate_bus;
	u8 secondary_latency_timer;
	u8 iobase;
	u8 iolimit;
	__le16 secondary_status;
	__le16 membase;
	__le16 memlimit;
	__le16 pref_mem_base;
	__le16 pref_mem_limit;
	__le32 prefbaseupper;
	__le32 preflimitupper;
	__le16 iobaseupper;
	__le16 iolimitupper;
	u8 capabilities_pointer;
	u8 reserve[3];
	__le32 romaddr;
	u8 intline;
	u8 intpin;
	__le16 bridgectrl;
};

struct pci_bridge_emul_pcie_conf {
	u8 cap_id;
	u8 next;
	__le16 cap;
	__le32 devcap;
	__le16 devctl;
	__le16 devsta;
	__le32 lnkcap;
	__le16 lnkctl;
	__le16 lnksta;
	__le32 slotcap;
	__le16 slotctl;
	__le16 slotsta;
	__le16 rootctl;
	__le16 rootcap;
	__le32 rootsta;
	__le32 devcap2;
	__le16 devctl2;
	__le16 devsta2;
	__le32 lnkcap2;
	__le16 lnkctl2;
	__le16 lnksta2;
	__le32 slotcap2;
	__le16 slotctl2;
	__le16 slotsta2;
};

typedef enum {
	PCI_BRIDGE_EMUL_HANDLED = 0,
	PCI_BRIDGE_EMUL_NOT_HANDLED = 1,
} pci_bridge_emul_read_status_t;

struct pci_bridge_emul;

struct pci_bridge_emul_ops {
	pci_bridge_emul_read_status_t (*read_base)(struct pci_bridge_emul *, int, u32 *);
	pci_bridge_emul_read_status_t (*read_pcie)(struct pci_bridge_emul *, int, u32 *);
	void (*write_base)(struct pci_bridge_emul *, int, u32, u32, u32);
	void (*write_pcie)(struct pci_bridge_emul *, int, u32, u32, u32);
};

struct pci_bridge_reg_behavior;

struct pci_bridge_emul {
	struct pci_bridge_emul_conf conf;
	struct pci_bridge_emul_pcie_conf pcie_conf;
	struct pci_bridge_emul_ops *ops;
	struct pci_bridge_reg_behavior *pci_regs_behavior;
	struct pci_bridge_reg_behavior *pcie_cap_regs_behavior;
	void *data;
	bool has_pcie;
};

struct pci_bridge_reg_behavior {
	u32 ro;
	u32 rw;
	u32 w1c;
};

enum {
	PCI_BRIDGE_EMUL_NO_PREFETCHABLE_BAR = 1,
};

enum dmi_device_type {
	DMI_DEV_TYPE_ANY = 0,
	DMI_DEV_TYPE_OTHER = 1,
	DMI_DEV_TYPE_UNKNOWN = 2,
	DMI_DEV_TYPE_VIDEO = 3,
	DMI_DEV_TYPE_SCSI = 4,
	DMI_DEV_TYPE_ETHERNET = 5,
	DMI_DEV_TYPE_TOKENRING = 6,
	DMI_DEV_TYPE_SOUND = 7,
	DMI_DEV_TYPE_PATA = 8,
	DMI_DEV_TYPE_SATA = 9,
	DMI_DEV_TYPE_SAS = 10,
	DMI_DEV_TYPE_IPMI = 4294967295,
	DMI_DEV_TYPE_OEM_STRING = 4294967294,
	DMI_DEV_TYPE_DEV_ONBOARD = 4294967293,
	DMI_DEV_TYPE_DEV_SLOT = 4294967292,
};

struct dmi_device {
	struct list_head list;
	int type;
	const char *name;
	void *device_data;
};

struct dmi_dev_onboard {
	struct dmi_device dev;
	int instance;
	int segment;
	int bus;
	int devfn;
};

enum smbios_attr_enum {
	SMBIOS_ATTR_NONE = 0,
	SMBIOS_ATTR_LABEL_SHOW = 1,
	SMBIOS_ATTR_INSTANCE_SHOW = 2,
};

enum acpi_attr_enum {
	ACPI_ATTR_LABEL_SHOW = 0,
	ACPI_ATTR_INDEX_SHOW = 1,
};

struct pci_epf_device_id {
	char name[20];
	kernel_ulong_t driver_data;
};

enum pci_interrupt_pin {
	PCI_INTERRUPT_UNKNOWN = 0,
	PCI_INTERRUPT_INTA = 1,
	PCI_INTERRUPT_INTB = 2,
	PCI_INTERRUPT_INTC = 3,
	PCI_INTERRUPT_INTD = 4,
};

enum pci_barno {
	NO_BAR = 4294967295,
	BAR_0 = 0,
	BAR_1 = 1,
	BAR_2 = 2,
	BAR_3 = 3,
	BAR_4 = 4,
	BAR_5 = 5,
};

struct pci_epf_header {
	u16 vendorid;
	u16 deviceid;
	u8 revid;
	u8 progif_code;
	u8 subclass_code;
	u8 baseclass_code;
	u8 cache_line_size;
	u16 subsys_vendor_id;
	u16 subsys_id;
	enum pci_interrupt_pin interrupt_pin;
};

struct pci_epf;

struct pci_epf_ops {
	int (*bind)(struct pci_epf *);
	void (*unbind)(struct pci_epf *);
	struct config_group * (*add_cfs)(struct pci_epf *, struct config_group *);
};

struct pci_epf_bar {
	dma_addr_t phys_addr;
	void *addr;
	size_t size;
	enum pci_barno barno;
	int flags;
};

struct pci_epc;

struct pci_epf_driver;

struct pci_epf {
	struct device___148 dev;
	const char *name;
	struct pci_epf_header *header;
	struct pci_epf_bar bar[6];
	u8 msi_interrupts;
	u16 msix_interrupts;
	u8 func_no;
	u8 vfunc_no;
	struct pci_epc *epc;
	struct pci_epf *epf_pf;
	struct pci_epf_driver *driver;
	struct list_head list;
	struct notifier_block nb;
	struct mutex lock;
	struct pci_epc *sec_epc;
	struct list_head sec_epc_list;
	struct pci_epf_bar sec_epc_bar[6];
	u8 sec_epc_func_no;
	struct config_group *group;
	unsigned int is_bound;
	unsigned int is_vf;
	long unsigned int vfunction_num_map;
	struct list_head pci_vepf;
};

struct pci_epf_driver {
	int (*probe)(struct pci_epf *);
	void (*remove)(struct pci_epf *);
	struct device_driver___148 driver;
	struct pci_epf_ops *ops;
	struct module___174 *owner;
	struct list_head epf_group;
	const struct pci_epf_device_id *id_table;
};

struct pci_epc_ops;

struct pci_epc_mem;

struct pci_epc {
	struct device___148 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

enum pci_epc_interface_type {
	UNKNOWN_INTERFACE = 4294967295,
	PRIMARY_INTERFACE = 0,
	SECONDARY_INTERFACE = 1,
};

enum pci_epc_irq_type {
	PCI_EPC_IRQ_UNKNOWN = 0,
	PCI_EPC_IRQ_LEGACY = 1,
	PCI_EPC_IRQ_MSI = 2,
	PCI_EPC_IRQ_MSIX = 3,
};

struct pci_epc_features;

struct pci_epc_ops {
	int (*write_header)(struct pci_epc *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc *, u8, u8, struct pci_epf_bar *);
	void (*clear_bar)(struct pci_epc *, u8, u8, struct pci_epf_bar *);
	int (*map_addr)(struct pci_epc *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc *, u8, u8, u8);
	int (*get_msi)(struct pci_epc *, u8, u8);
	int (*set_msix)(struct pci_epc *, u8, u8, u16, enum pci_barno, u32);
	int (*get_msix)(struct pci_epc *, u8, u8);
	int (*raise_irq)(struct pci_epc *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc *);
	void (*stop)(struct pci_epc *);
	const struct pci_epc_features * (*get_features)(struct pci_epc *, u8, u8);
	struct module___174 *owner;
};

struct pci_epc_features {
	unsigned int linkup_notifier: 1;
	unsigned int core_init_notifier: 1;
	unsigned int msi_capable: 1;
	unsigned int msix_capable: 1;
	u8 reserved_bar;
	u8 bar_fixed_64bit;
	u64 bar_fixed_size[6];
	size_t align;
};

struct pci_epc_mem_window {
	phys_addr_t phys_base;
	size_t size;
	size_t page_size;
};

struct pci_epc_mem {
	struct pci_epc_mem_window window;
	long unsigned int *bitmap;
	int pages;
	struct mutex lock;
};

struct pci_epf_group {
	struct config_group group;
	struct config_group primary_epc_group;
	struct config_group secondary_epc_group;
	struct delayed_work cfs_work;
	struct pci_epf *epf;
	int index;
};

struct pci_epc_group {
	struct config_group group;
	struct pci_epc *epc;
	bool start;
};

typedef void (*dr_release_t___12)(struct device___148 *, void *);

typedef int (*dr_match_t___11)(struct device___148 *, void *, void *);

enum pci_notify_event {
	CORE_INIT = 0,
	LINK_UP = 1,
};

enum pci_barno___2 {
	NO_BAR___2 = 0,
	BAR_0___2 = 0,
	BAR_1___2 = 1,
	BAR_2___2 = 2,
	BAR_3___2 = 3,
	BAR_4___2 = 4,
	BAR_5___2 = 5,
};

struct pci_epf___2;

struct pci_epf_ops___2 {
	int (*bind)(struct pci_epf___2 *);
	void (*unbind)(struct pci_epf___2 *);
	struct config_group * (*add_cfs)(struct pci_epf___2 *, struct config_group *);
};

struct pci_epf_bar___2 {
	dma_addr_t phys_addr;
	void *addr;
	size_t size;
	enum pci_barno___2 barno;
	int flags;
};

struct pci_epc___2;

struct pci_epf_driver___2;

struct pci_epf___2 {
	struct device___148 dev;
	const char *name;
	struct pci_epf_header *header;
	struct pci_epf_bar___2 bar[6];
	u8 msi_interrupts;
	u16 msix_interrupts;
	u8 func_no;
	u8 vfunc_no;
	struct pci_epc___2 *epc;
	struct pci_epf___2 *epf_pf;
	struct pci_epf_driver___2 *driver;
	struct list_head list;
	struct notifier_block nb;
	struct mutex lock;
	struct pci_epc___2 *sec_epc;
	struct list_head sec_epc_list;
	struct pci_epf_bar___2 sec_epc_bar[6];
	u8 sec_epc_func_no;
	struct config_group *group;
	unsigned int is_bound;
	unsigned int is_vf;
	long unsigned int vfunction_num_map;
	struct list_head pci_vepf;
};

struct pci_epf_driver___2 {
	int (*probe)(struct pci_epf___2 *);
	void (*remove)(struct pci_epf___2 *);
	struct device_driver___148 driver;
	struct pci_epf_ops___2 *ops;
	struct module___174 *owner;
	struct list_head epf_group;
	const struct pci_epf_device_id *id_table;
};

struct pci_epc_ops___2;

struct pci_epc___2 {
	struct device___148 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___2 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

enum pci_epc_interface_type___2 {
	UNKNOWN_INTERFACE___2 = 0,
	PRIMARY_INTERFACE___2 = 0,
	SECONDARY_INTERFACE___2 = 1,
};

struct pci_epc_ops___2 {
	int (*write_header)(struct pci_epc___2 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___2 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___2 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___2 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___2 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___2 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___2 *, u8, u8);
	int (*set_msix)(struct pci_epc___2 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___2 *, u8, u8);
	int (*raise_irq)(struct pci_epc___2 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___2 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___2 *);
	void (*stop)(struct pci_epc___2 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___2 *, u8, u8);
	struct module___174 *owner;
};

struct device_link___11 {
	struct device___145 *supplier;
	struct list_head s_node;
	struct device___145 *consumer;
	struct list_head c_node;
	struct device___145 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct cdns_pcie;

struct cdns_pcie_ops {
	int (*start_link)(struct cdns_pcie *);
	void (*stop_link)(struct cdns_pcie *);
	bool (*link_up)(struct cdns_pcie *);
	u64 (*cpu_addr_fixup)(struct cdns_pcie *, u64);
};

struct cdns_pcie {
	void *reg_base;
	struct resource *mem_res;
	struct device___145 *dev;
	bool is_rc;
	int phy_count;
	struct phy___4 **phy;
	struct device_link___11 **link;
	const struct cdns_pcie_ops *ops;
};

enum cdns_pcie_rp_bar {
	RP_BAR_UNDEFINED = 0,
	RP_BAR0 = 0,
	RP_BAR1 = 1,
	RP_NO_BAR = 2,
};

struct cdns_pcie___2;

struct cdns_pcie_ops___2 {
	int (*start_link)(struct cdns_pcie___2 *);
	void (*stop_link)(struct cdns_pcie___2 *);
	bool (*link_up)(struct cdns_pcie___2 *);
	u64 (*cpu_addr_fixup)(struct cdns_pcie___2 *, u64);
};

struct cdns_pcie___2 {
	void *reg_base;
	struct resource *mem_res;
	struct device___149 *dev;
	bool is_rc;
	int phy_count;
	struct phy **phy;
	struct device_link___10 **link;
	const struct cdns_pcie_ops___2 *ops;
};

struct cdns_pcie_rc {
	struct cdns_pcie___2 pcie;
	struct resource *cfg_res;
	void *cfg_base;
	u32 vendor_id;
	u32 device_id;
	bool avail_ib_bar[3];
	unsigned int quirk_retrain_flag: 1;
	unsigned int quirk_detect_quiet_flag: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct config_group___3;

struct config_item_type___3;

struct config_item___3 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___3 *ci_parent;
	struct config_group___3 *ci_group;
	const struct config_item_type___3 *ci_type;
	struct dentry___187 *ci_dentry;
};

struct configfs_subsystem___3;

struct config_group___3 {
	struct config_item___3 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___3 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___3;

struct configfs_group_operations___3;

struct configfs_attribute___3;

struct configfs_bin_attribute___3;

struct config_item_type___3 {
	struct module___171 *ct_owner;
	struct configfs_item_operations___3 *ct_item_ops;
	struct configfs_group_operations___3 *ct_group_ops;
	struct configfs_attribute___3 **ct_attrs;
	struct configfs_bin_attribute___3 **ct_bin_attrs;
};

struct configfs_item_operations___3 {
	void (*release)(struct config_item___3 *);
	int (*allow_link)(struct config_item___3 *, struct config_item___3 *);
	void (*drop_link)(struct config_item___3 *, struct config_item___3 *);
};

struct configfs_group_operations___3 {
	struct config_item___3 * (*make_item)(struct config_group___3 *, const char *);
	struct config_group___3 * (*make_group)(struct config_group___3 *, const char *);
	int (*commit_item)(struct config_item___3 *);
	void (*disconnect_notify)(struct config_group___3 *, struct config_item___3 *);
	void (*drop_item)(struct config_group___3 *, struct config_item___3 *);
};

struct configfs_attribute___3 {
	const char *ca_name;
	struct module___171 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___3 *, char *);
	ssize_t (*store)(struct config_item___3 *, const char *, size_t);
};

struct configfs_bin_attribute___3 {
	struct configfs_attribute___3 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___3 *, void *, size_t);
	ssize_t (*write)(struct config_item___3 *, const void *, size_t);
};

struct configfs_subsystem___3 {
	struct config_group___3 su_group;
	struct mutex su_mutex;
};

struct pci_epc_ops___3;

struct pci_epc___3 {
	struct device___145 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___3 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group___3 *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

struct pci_epf_msix_tbl {
	u64 msg_addr;
	u32 msg_data;
	u32 vector_ctrl;
};

struct pci_epc_ops___3 {
	int (*write_header)(struct pci_epc___3 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___3 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___3 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___3 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___3 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___3 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___3 *, u8, u8);
	int (*set_msix)(struct pci_epc___3 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___3 *, u8, u8);
	int (*raise_irq)(struct pci_epc___3 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___3 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___3 *);
	void (*stop)(struct pci_epc___3 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___3 *, u8, u8);
	struct module___171 *owner;
};

enum cdns_pcie_msg_code {
	MSG_CODE_ASSERT_INTA = 32,
	MSG_CODE_ASSERT_INTB = 33,
	MSG_CODE_ASSERT_INTC = 34,
	MSG_CODE_ASSERT_INTD = 35,
	MSG_CODE_DEASSERT_INTA = 36,
	MSG_CODE_DEASSERT_INTB = 37,
	MSG_CODE_DEASSERT_INTC = 38,
	MSG_CODE_DEASSERT_INTD = 39,
};

enum cdns_pcie_msg_routing {
	MSG_ROUTING_TO_RC = 0,
	MSG_ROUTING_BY_ADDR = 1,
	MSG_ROUTING_BY_ID = 2,
	MSG_ROUTING_BCAST = 3,
	MSG_ROUTING_LOCAL = 4,
	MSG_ROUTING_GATHER = 5,
};

struct cdns_pcie_epf {
	struct cdns_pcie_epf *epf;
	struct pci_epf_bar___2 *epf_bar[6];
};

struct cdns_pcie_ep {
	struct cdns_pcie pcie;
	u32 max_regions;
	long unsigned int ob_region_map;
	phys_addr_t *ob_addr;
	phys_addr_t irq_phys_addr;
	void *irq_cpu_addr;
	u64 irq_pci_addr;
	u8 irq_pci_fn;
	u8 irq_pending;
	spinlock_t lock;
	struct cdns_pcie_epf *epf;
	unsigned int quirk_detect_quiet_flag: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cdns_pcie_ep___2 {
	struct cdns_pcie___2 pcie;
	u32 max_regions;
	long unsigned int ob_region_map;
	phys_addr_t *ob_addr;
	phys_addr_t irq_phys_addr;
	void *irq_cpu_addr;
	u64 irq_pci_addr;
	u8 irq_pci_fn;
	u8 irq_pending;
	spinlock_t lock;
	struct cdns_pcie_epf *epf;
	unsigned int quirk_detect_quiet_flag: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct cdns_plat_pcie {
	struct cdns_pcie___2 *pcie;
	bool is_rc;
};

struct cdns_plat_pcie_of_data {
	bool is_rc;
};

struct pci_host_bridge___4 {
	struct device___145 dev;
	struct pci_bus___9 *bus;
	struct pci_ops___9 *ops;
	struct pci_ops___9 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___9 *, u8 *);
	int (*map_irq)(const struct pci_dev___9 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___4 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___9 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct cdns_pcie_rc___2 {
	struct cdns_pcie pcie;
	struct resource *cfg_res;
	void *cfg_base;
	u32 vendor_id;
	u32 device_id;
	bool avail_ib_bar[3];
	unsigned int quirk_retrain_flag: 1;
	unsigned int quirk_detect_quiet_flag: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum link_status {
	NO_RECEIVERS_DETECTED = 0,
	LINK_TRAINING_IN_PROGRESS = 1,
	LINK_UP_DL_IN_PROGRESS = 2,
	LINK_UP_DL_COMPLETED = 3,
};

struct j721e_pcie {
	struct device___145 *dev;
	struct clk *refclk;
	u32 mode;
	u32 num_lanes;
	struct cdns_pcie *cdns_pcie;
	void *user_cfg_base;
	void *intd_cfg_base;
	u32 linkdown_irq_regfield;
};

enum j721e_pcie_mode {
	PCI_MODE_RC = 0,
	PCI_MODE_EP = 1,
};

struct j721e_pcie_data {
	enum j721e_pcie_mode mode;
	unsigned int quirk_retrain_flag: 1;
	unsigned int quirk_detect_quiet_flag: 1;
	long: 63;
	u32 linkdown_irq_regfield;
	unsigned int byte_access_allowed: 1;
	long: 63;
	long: 64;
};

struct faraday_pci_variant {
	bool cascaded_irq;
};

struct faraday_pci {
	struct device___150 *dev;
	void *base;
	struct irq_domain___31 *irqdomain;
	struct pci_bus___8 *bus;
	struct clk *bus_clk;
};

struct dentry___192;

struct super_block___192;

struct module___176;

struct file_system_type___192 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___192 * (*mount)(struct file_system_type___192 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___192 *);
	struct module___176 *owner;
	struct file_system_type___192 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___192;

struct kiocb___192;

struct iov_iter___114;

struct vm_area_struct___197;

struct inode___192;

struct file_lock___192;

struct page___197;

struct seq_file___168;

struct file_operations___193 {
	struct module___176 *owner;
	loff_t (*llseek)(struct file___192 *, loff_t, int);
	ssize_t (*read)(struct file___192 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___192 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___192 *, struct iov_iter___114 *);
	ssize_t (*write_iter)(struct kiocb___192 *, struct iov_iter___114 *);
	int (*iopoll)(struct kiocb___192 *, bool);
	int (*iterate)(struct file___192 *, struct dir_context *);
	int (*iterate_shared)(struct file___192 *, struct dir_context *);
	__poll_t (*poll)(struct file___192 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___192 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___192 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___192 *, struct vm_area_struct___197 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___192 *, struct file___192 *);
	int (*flush)(struct file___192 *, fl_owner_t);
	int (*release)(struct inode___192 *, struct file___192 *);
	int (*fsync)(struct file___192 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___192 *, int);
	int (*lock)(struct file___192 *, int, struct file_lock___192 *);
	ssize_t (*sendpage)(struct file___192 *, struct page___197 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___192 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___192 *, long unsigned int);
	int (*flock)(struct file___192 *, int, struct file_lock___192 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___192 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___192 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___192 *, long int, struct file_lock___192 **, void **);
	long int (*fallocate)(struct file___192 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___168 *, struct file___192 *);
	ssize_t (*copy_file_range)(struct file___192 *, loff_t, struct file___192 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___192 *, loff_t, struct file___192 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___192 *, loff_t, loff_t, int);
};

struct vmacache___197 {
	u64 seqnum;
	struct vm_area_struct___197 *vmas[4];
};

struct page_frag___197 {
	struct page___197 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___198;

struct pid___170;

struct nsproxy___179;

struct signal_struct___193;

struct bio_list___96;

struct backing_dev_info___89;

struct io_context___96;

struct css_set___131;

struct mem_cgroup___80;

struct request_queue___96;

struct vm_struct___175;

struct task_struct___199 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___199 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___198 *mm;
	struct mm_struct___198 *active_mm;
	struct vmacache___197 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___199 *real_parent;
	struct task_struct___199 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___199 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___170 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___179 *nsproxy;
	struct signal_struct___193 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___199 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___96 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___89 *backing_dev_info;
	struct io_context___96 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___131 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___197 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___80 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___80 *active_memcg;
	struct request_queue___96 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___199 *oom_reaper_list;
	struct vm_struct___175 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___180;

struct kobj_type___180;

struct kernfs_node___180;

struct kobject___180 {
	const char *name;
	struct list_head entry;
	struct kobject___180 *parent;
	struct kset___180 *kset;
	struct kobj_type___180 *ktype;
	struct kernfs_node___180 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___176 {
	struct kobject___180 kobj;
	struct module___176 *mod;
	struct kobject___180 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___176 {
	struct module___176 *mod;
	struct latch_tree_node node;
};

struct module_layout___176 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___176 mtn;
};

struct module_attribute___176;

struct kernel_param___176;

struct module___176 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___176 mkobj;
	struct module_attribute___176 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___180 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___176 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___176 core_layout;
	struct module_layout___176 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___170;

struct upid___170 {
	int nr;
	struct pid_namespace___170 *ns;
};

struct pid_namespace___170 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___199 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___170 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___170 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___170 numbers[1];
};

typedef struct page___197 *pgtable_t___197;

struct address_space___192;

struct dev_pagemap___187;

struct page___197 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___192 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___197 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___197 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___198 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___187 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___187;

struct vm_area_struct___197 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___197 *vm_next;
	struct vm_area_struct___197 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___198 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___187 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___192 *vm_file;
	struct file___192 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___193 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___199 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___199 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___170 *pids[4];
	struct pid___170 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___198 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___197;

struct mm_struct___198 {
	struct {
		struct vm_area_struct___197 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___192 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___197 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___199 *owner;
		struct user_namespace___25 *user_ns;
		struct file___192 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___131;

struct nsproxy___179 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___170 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___131 *cgroup_ns;
};

struct bio___96;

struct bio_list___96 {
	struct bio___96 *head;
	struct bio___96 *tail;
};

struct cgroup_subsys_state___131;

struct bdi_writeback___89 {
	struct backing_dev_info___89 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___131 *memcg_css;
	struct cgroup_subsys_state___131 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___151;

struct backing_dev_info___89 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___89 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___151 *dev;
	char dev_name[64];
	struct device___151 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___192 *debug_dir;
};

struct io_cq___96;

struct io_context___96 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___96 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___131;

struct css_set___131 {
	struct cgroup_subsys_state___131 *subsys[14];
	refcount_t refcount;
	struct css_set___131 *dom_cset;
	struct cgroup___131 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___131 *mg_src_cgrp;
	struct cgroup___131 *mg_dst_cgrp;
	struct css_set___131 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___131;

struct cgroup_subsys_state___131 {
	struct cgroup___131 *cgroup;
	struct cgroup_subsys___131 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___131 *parent;
};

struct cgroup_file___131 {
	struct kernfs_node___180 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___80;

struct mem_cgroup_per_node___80;

struct mem_cgroup___80 {
	struct cgroup_subsys_state___131 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___131 events_file;
	struct cgroup_file___131 events_local_file;
	struct cgroup_file___131 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___80 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___199 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___80 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___96;

struct blk_integrity___96 {
	const struct blk_integrity_profile___96 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___96 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___96 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___96;

struct elevator_queue___96;

struct blk_mq_ops___93;

struct blk_mq_hw_ctx___93;

struct gendisk___97;

struct blkcg_gq___91;

struct blk_mq_tag_set___93;

struct request_queue___96 {
	struct request___96 *last_merge;
	struct elevator_queue___96 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___93 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___93 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___97 *disk;
	struct kobject___180 kobj;
	struct kobject___180 *mq_kobj;
	struct blk_integrity___96 integrity;
	struct device___151 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___91 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___93 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___96 bio_split;
	struct dentry___192 *debugfs_dir;
	struct dentry___192 *sched_debugfs_dir;
	struct dentry___192 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___175 {
	struct vm_struct___175 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___197 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct irq_desc___34;

typedef void (*irq_flow_handler_t___34)(struct irq_desc___34 *);

struct msi_desc___11;

struct irq_common_data___11 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___11 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___33;

struct irq_domain___32;

struct irq_data___33 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___11 *common;
	struct irq_chip___33 *chip;
	struct irq_domain___32 *domain;
	struct irq_data___33 *parent_data;
	void *chip_data;
};

struct irqaction___23;

struct irq_desc___34 {
	struct irq_common_data___11 irq_common_data;
	struct irq_data___33 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___34 handle_irq;
	struct irqaction___23 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___180 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___176 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___192;

struct address_space___192 {
	struct inode___192 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___192 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___187;

struct dev_pagemap___187 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___187 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___192;

struct path___192 {
	struct vfsmount___192 *mnt;
	struct dentry___192 *dentry;
};

struct fown_struct___170 {
	rwlock_t lock;
	struct pid___170 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___192 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___192 f_path;
	struct inode___192 *f_inode;
	const struct file_operations___193 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___170 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___192 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___187;

struct vm_operations_struct___187 {
	void (*open)(struct vm_area_struct___197 *);
	void (*close)(struct vm_area_struct___197 *);
	int (*may_split)(struct vm_area_struct___197 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___197 *);
	int (*mprotect)(struct vm_area_struct___197 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___187 *);
	vm_fault_t (*huge_fault)(struct vm_fault___187 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___187 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___197 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___187 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___187 *);
	int (*access)(struct vm_area_struct___197 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___197 *);
	int (*set_policy)(struct vm_area_struct___197 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___197 *, long unsigned int);
	struct page___197 * (*find_special_page)(struct vm_area_struct___197 *, long unsigned int);
};

struct core_thread___197 {
	struct task_struct___199 *task;
	struct core_thread___197 *next;
};

struct core_state___197 {
	atomic_t nr_threads;
	struct core_thread___197 dumper;
	struct completion startup;
};

struct vm_fault___187 {
	const struct {
		struct vm_area_struct___197 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___197 *cow_page;
	struct page___197 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___197 prealloc_pte;
};

struct pglist_data___87;

struct lruvec___87 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___87 *pgdat;
};

struct zone___87 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___87 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___87 {
	struct zone___87 *zone;
	int zone_idx;
};

struct zonelist___87 {
	struct zoneref___87 _zonerefs[321];
};

struct pglist_data___87 {
	struct zone___87 node_zones[5];
	struct zonelist___87 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___199 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___199 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___87 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct fwnode_operations___151;

struct fwnode_handle___151 {
	struct fwnode_handle___151 *secondary;
	const struct fwnode_operations___151 *ops;
	struct device___151 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___151;

struct fwnode_endpoint___151;

struct fwnode_operations___151 {
	struct fwnode_handle___151 * (*get)(struct fwnode_handle___151 *);
	void (*put)(struct fwnode_handle___151 *);
	bool (*device_is_available)(const struct fwnode_handle___151 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___151 *, const struct device___151 *);
	bool (*property_present)(const struct fwnode_handle___151 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___151 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___151 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___151 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*get_parent)(const struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*get_next_child_node)(const struct fwnode_handle___151 *, struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*get_named_child_node)(const struct fwnode_handle___151 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___151 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___151 *);
	struct fwnode_handle___151 * (*graph_get_next_endpoint)(const struct fwnode_handle___151 *, struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*graph_get_remote_endpoint)(const struct fwnode_handle___151 *);
	struct fwnode_handle___151 * (*graph_get_port_parent)(struct fwnode_handle___151 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___151 *, struct fwnode_endpoint___151 *);
	int (*add_links)(struct fwnode_handle___151 *);
};

struct wakeup_source___151;

struct dev_pm_info___151 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___151 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___151 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___151;

struct bus_type___151;

struct device_driver___151;

struct dev_pm_domain___151;

struct device_node___53;

struct class___151;

struct attribute_group___180;

struct device___151 {
	struct kobject___180 kobj;
	struct device___151 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___151 *type;
	struct bus_type___151 *bus;
	struct device_driver___151 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___151 power;
	struct dev_pm_domain___151 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___32 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___53 *of_node;
	struct fwnode_handle___151 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___151 *class;
	const struct attribute_group___180 **groups;
	void (*release)(struct device___151 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___151 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___151 *local_fwnode;
};

struct fwnode_reference_args___151 {
	struct fwnode_handle___151 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msi_desc___11 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___151 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___11 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___33 {
	struct device___151 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___33 *);
	void (*irq_shutdown)(struct irq_data___33 *);
	void (*irq_enable)(struct irq_data___33 *);
	void (*irq_disable)(struct irq_data___33 *);
	void (*irq_ack)(struct irq_data___33 *);
	void (*irq_mask)(struct irq_data___33 *);
	void (*irq_mask_ack)(struct irq_data___33 *);
	void (*irq_unmask)(struct irq_data___33 *);
	void (*irq_eoi)(struct irq_data___33 *);
	int (*irq_set_affinity)(struct irq_data___33 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___33 *);
	int (*irq_set_type)(struct irq_data___33 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___33 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___33 *);
	void (*irq_bus_sync_unlock)(struct irq_data___33 *);
	void (*irq_cpu_online)(struct irq_data___33 *);
	void (*irq_cpu_offline)(struct irq_data___33 *);
	void (*irq_suspend)(struct irq_data___33 *);
	void (*irq_resume)(struct irq_data___33 *);
	void (*irq_pm_shutdown)(struct irq_data___33 *);
	void (*irq_calc_mask)(struct irq_data___33 *);
	void (*irq_print_chip)(struct irq_data___33 *, struct seq_file___168 *);
	int (*irq_request_resources)(struct irq_data___33 *);
	void (*irq_release_resources)(struct irq_data___33 *);
	void (*irq_compose_msi_msg)(struct irq_data___33 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___33 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___33 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___33 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___33 *, void *);
	void (*ipi_send_single)(struct irq_data___33 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___33 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___33 *);
	void (*irq_nmi_teardown)(struct irq_data___33 *);
	long unsigned int flags;
};

struct irq_domain_ops___32;

struct irq_domain_chip_generic___32;

struct irq_domain___32 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___32 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___151 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___32 *gc;
	struct irq_domain___32 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___33 *revmap[0];
};

struct seq_operations___168;

struct seq_file___168 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___168 *op;
	int poll_event;
	const struct file___192 *file;
	void *private;
};

struct kernfs_root___180;

struct kernfs_elem_dir___180 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___180 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___180;

struct kernfs_root___180 {
	struct kernfs_node___180 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___180 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___180 {
	struct kernfs_node___180 *target_kn;
};

struct kernfs_ops___180;

struct kernfs_elem_attr___180 {
	const struct kernfs_ops___180 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___180 *notify_next;
};

struct kernfs_node___180 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___180 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___180 dir;
		struct kernfs_elem_symlink___180 symlink;
		struct kernfs_elem_attr___180 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___180;

struct kernfs_ops___180 {
	int (*open)(struct kernfs_open_file___180 *);
	void (*release)(struct kernfs_open_file___180 *);
	int (*seq_show)(struct seq_file___168 *, void *);
	void * (*seq_start)(struct seq_file___168 *, loff_t *);
	void * (*seq_next)(struct seq_file___168 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___168 *, void *);
	ssize_t (*read)(struct kernfs_open_file___180 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___180 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___180 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___180 *, struct vm_area_struct___197 *);
};

struct kernfs_syscall_ops___180 {
	int (*show_options)(struct seq_file___168 *, struct kernfs_root___180 *);
	int (*mkdir)(struct kernfs_node___180 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___180 *);
	int (*rename)(struct kernfs_node___180 *, struct kernfs_node___180 *, const char *);
	int (*show_path)(struct seq_file___168 *, struct kernfs_node___180 *, struct kernfs_root___180 *);
};

struct kernfs_open_file___180 {
	struct kernfs_node___180 *kn;
	struct file___192 *file;
	struct seq_file___168 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___187 *vm_ops;
};

struct bin_attribute___180;

struct attribute_group___180 {
	const char *name;
	umode_t (*is_visible)(struct kobject___180 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___180 *, struct bin_attribute___180 *, int);
	struct attribute **attrs;
	struct bin_attribute___180 **bin_attrs;
};

struct bin_attribute___180 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___192 * (*f_mapping)();
	ssize_t (*read)(struct file___192 *, struct kobject___180 *, struct bin_attribute___180 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___192 *, struct kobject___180 *, struct bin_attribute___180 *, char *, loff_t, size_t);
	int (*mmap)(struct file___192 *, struct kobject___180 *, struct bin_attribute___180 *, struct vm_area_struct___197 *);
};

struct sysfs_ops___180 {
	ssize_t (*show)(struct kobject___180 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___180 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___180;

struct kset___180 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___180 kobj;
	const struct kset_uevent_ops___180 *uevent_ops;
};

struct kobj_type___180 {
	void (*release)(struct kobject___180 *);
	const struct sysfs_ops___180 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___180 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___180 *);
	const void * (*namespace)(struct kobject___180 *);
	void (*get_ownership)(struct kobject___180 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___180 {
	int (* const filter)(struct kset___180 *, struct kobject___180 *);
	const char * (* const name)(struct kset___180 *, struct kobject___180 *);
	int (* const uevent)(struct kset___180 *, struct kobject___180 *, struct kobj_uevent_env *);
};

struct irqaction___23 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___23 *next;
	irq_handler_t thread_fn;
	struct task_struct___199 *thread;
	struct irqaction___23 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___32 {
	struct irq_chip___33 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___34 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___32 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___32 *);
	void (*resume)(struct irq_chip_generic___32 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___32 *domain;
	struct list_head list;
	struct irq_chip_type___32 chip_types[0];
};

struct irq_domain_chip_generic___32 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___32 *gc[0];
};

struct property___42 {
	char *name;
	int length;
	void *value;
	struct property___42 *next;
	long unsigned int _flags;
	struct bin_attribute___180 attr;
};

struct device_node___53 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___151 fwnode;
	struct property___42 *properties;
	struct property___42 *deadprops;
	struct device_node___53 *parent;
	struct device_node___53 *child;
	struct device_node___53 *sibling;
	struct kobject___180 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___30 {
	struct fwnode_handle___151 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___32 {
	int (*match)(struct irq_domain___32 *, struct device_node___53 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___32 *, struct irq_fwspec___30 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___32 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___32 *, unsigned int);
	int (*xlate)(struct irq_domain___32 *, struct device_node___53 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___32 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___32 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___32 *, struct irq_data___33 *, bool);
	void (*deactivate)(struct irq_domain___32 *, struct irq_data___33 *);
	int (*translate)(struct irq_domain___32 *, struct irq_fwspec___30 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___192;

struct dentry___192 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___192 *d_parent;
	struct qstr d_name;
	struct inode___192 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___192 *d_op;
	struct super_block___192 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___192;

struct inode___192 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___192 *i_op;
	struct super_block___192 *i_sb;
	struct address_space___192 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___89 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___193 *i_fop;
		void (*free_inode)(struct inode___192 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___192 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___40 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___192 {
	int (*d_revalidate)(struct dentry___192 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___192 *, unsigned int);
	int (*d_hash)(const struct dentry___192 *, struct qstr *);
	int (*d_compare)(const struct dentry___192 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___192 *);
	int (*d_init)(struct dentry___192 *);
	void (*d_release)(struct dentry___192 *);
	void (*d_prune)(struct dentry___192 *);
	void (*d_iput)(struct dentry___192 *, struct inode___192 *);
	char * (*d_dname)(struct dentry___192 *, char *, int);
	struct vfsmount___192 * (*d_automount)(struct path___192 *);
	int (*d_manage)(const struct path___192 *, bool);
	struct dentry___192 * (*d_real)(struct dentry___192 *, const struct inode___192 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___192;

struct mem_dqinfo___192 {
	struct quota_format_type___192 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___192;

struct quota_info___192 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___192 *files[3];
	struct mem_dqinfo___192 info[3];
	const struct quota_format_ops___192 *ops[3];
};

struct rcuwait___193 {
	struct task_struct___199 *task;
};

struct percpu_rw_semaphore___193 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___193 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___192 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___193 rw_sem[3];
};

struct shrink_control___80;

struct shrinker___80 {
	long unsigned int (*count_objects)(struct shrinker___80 *, struct shrink_control___80 *);
	long unsigned int (*scan_objects)(struct shrinker___80 *, struct shrink_control___80 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___192;

struct dquot_operations___192;

struct quotactl_ops___192;

struct block_device___97;

struct super_block___192 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___192 *s_type;
	const struct super_operations___192 *s_op;
	const struct dquot_operations___192 *dq_op;
	const struct quotactl_ops___192 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___192 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___97 *s_bdev;
	struct backing_dev_info___89 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___192 s_dquot;
	struct sb_writers___192 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___192 *s_d_op;
	int cleancache_poolid;
	struct shrinker___80 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___192 {
	struct dentry___192 *mnt_root;
	struct super_block___192 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___80 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___80 *memcg;
};

struct psi_group___131 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___199 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___131;

struct cgroup_rstat_cpu___131;

struct cgroup___131 {
	struct cgroup_subsys_state___131 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___180 *kn;
	struct cgroup_file___131 procs_file;
	struct cgroup_file___131 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___131 *subsys[14];
	struct cgroup_root___131 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___131 *dom_cgrp;
	struct cgroup___131 *old_dom_cgrp;
	struct cgroup_rstat_cpu___131 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___131 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___96 {
	struct request_queue___96 *q;
	struct io_context___96 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___89;

struct kiocb___192 {
	struct file___192 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___192 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___89 *ki_waitq;
	};
};

struct iattr___192 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___192 *ia_file;
};

struct dquot___192 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___192 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___192 {
	int qf_fmt_id;
	const struct quota_format_ops___192 *qf_ops;
	struct module___176 *qf_owner;
	struct quota_format_type___192 *qf_next;
};

struct quota_format_ops___192 {
	int (*check_quota_file)(struct super_block___192 *, int);
	int (*read_file_info)(struct super_block___192 *, int);
	int (*write_file_info)(struct super_block___192 *, int);
	int (*free_file_info)(struct super_block___192 *, int);
	int (*read_dqblk)(struct dquot___192 *);
	int (*commit_dqblk)(struct dquot___192 *);
	int (*release_dqblk)(struct dquot___192 *);
	int (*get_next_id)(struct super_block___192 *, struct kqid *);
};

struct dquot_operations___192 {
	int (*write_dquot)(struct dquot___192 *);
	struct dquot___192 * (*alloc_dquot)(struct super_block___192 *, int);
	void (*destroy_dquot)(struct dquot___192 *);
	int (*acquire_dquot)(struct dquot___192 *);
	int (*release_dquot)(struct dquot___192 *);
	int (*mark_dirty)(struct dquot___192 *);
	int (*write_info)(struct super_block___192 *, int);
	qsize_t * (*get_reserved_space)(struct inode___192 *);
	int (*get_projid)(struct inode___192 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___192 *, qsize_t *);
	int (*get_next_id)(struct super_block___192 *, struct kqid *);
};

struct quotactl_ops___192 {
	int (*quota_on)(struct super_block___192 *, int, int, const struct path___192 *);
	int (*quota_off)(struct super_block___192 *, int);
	int (*quota_enable)(struct super_block___192 *, unsigned int);
	int (*quota_disable)(struct super_block___192 *, unsigned int);
	int (*quota_sync)(struct super_block___192 *, int);
	int (*set_info)(struct super_block___192 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___192 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___192 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___192 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___192 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___192 *, unsigned int);
};

struct wait_page_queue___89 {
	struct page___197 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___89;

struct readahead_control___89;

struct swap_info_struct___48;

struct address_space_operations___192 {
	int (*writepage)(struct page___197 *, struct writeback_control___89 *);
	int (*readpage)(struct file___192 *, struct page___197 *);
	int (*writepages)(struct address_space___192 *, struct writeback_control___89 *);
	int (*set_page_dirty)(struct page___197 *);
	int (*readpages)(struct file___192 *, struct address_space___192 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___89 *);
	int (*write_begin)(struct file___192 *, struct address_space___192 *, loff_t, unsigned int, unsigned int, struct page___197 **, void **);
	int (*write_end)(struct file___192 *, struct address_space___192 *, loff_t, unsigned int, unsigned int, struct page___197 *, void *);
	sector_t (*bmap)(struct address_space___192 *, sector_t);
	void (*invalidatepage)(struct page___197 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___197 *, gfp_t);
	void (*freepage)(struct page___197 *);
	ssize_t (*direct_IO)(struct kiocb___192 *, struct iov_iter___114 *);
	int (*migratepage)(struct address_space___192 *, struct page___197 *, struct page___197 *, enum migrate_mode);
	bool (*isolate_page)(struct page___197 *, isolate_mode_t);
	void (*putback_page)(struct page___197 *);
	int (*launder_page)(struct page___197 *);
	int (*is_partially_uptodate)(struct page___197 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___197 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___192 *, struct page___197 *);
	int (*swap_activate)(struct swap_info_struct___48 *, struct file___192 *, sector_t *);
	void (*swap_deactivate)(struct file___192 *);
};

struct writeback_control___89 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___89 *wb;
	struct inode___192 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___89 {
	struct file___192 *file;
	struct address_space___192 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___112;

struct iov_iter___114 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___112 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___48 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___97 *bdev;
	struct file___192 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___192 {
	struct dentry___192 * (*lookup)(struct inode___192 *, struct dentry___192 *, unsigned int);
	const char * (*get_link)(struct dentry___192 *, struct inode___192 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___192 *, int);
	struct posix_acl * (*get_acl)(struct inode___192 *, int, bool);
	int (*readlink)(struct dentry___192 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___192 *, struct dentry___192 *, umode_t, bool);
	int (*link)(struct dentry___192 *, struct inode___192 *, struct dentry___192 *);
	int (*unlink)(struct inode___192 *, struct dentry___192 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___192 *, struct dentry___192 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___192 *, struct dentry___192 *, umode_t);
	int (*rmdir)(struct inode___192 *, struct dentry___192 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___192 *, struct dentry___192 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___192 *, struct dentry___192 *, struct inode___192 *, struct dentry___192 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___192 *, struct iattr___192 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___192 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___192 *, char *, size_t);
	int (*fiemap)(struct inode___192 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___192 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___192 *, struct dentry___192 *, struct file___192 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___192 *, struct dentry___192 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___192 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___192 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___192 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___192 {
	void (*fl_copy_lock)(struct file_lock___192 *, struct file_lock___192 *);
	void (*fl_release_private)(struct file_lock___192 *);
};

struct fasync_struct___192;

struct lock_manager_operations___192;

struct file_lock___192 {
	struct file_lock___192 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___192 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___192 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___192 *fl_ops;
	const struct lock_manager_operations___192 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___192 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___192 *);
	int (*lm_grant)(struct file_lock___192 *, int);
	bool (*lm_break)(struct file_lock___192 *);
	int (*lm_change)(struct file_lock___192 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___192 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___192 *);
};

struct fasync_struct___192 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___192 *fa_next;
	struct file___192 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___192 {
	struct inode___192 * (*alloc_inode)(struct super_block___192 *);
	void (*destroy_inode)(struct inode___192 *);
	void (*free_inode)(struct inode___192 *);
	void (*dirty_inode)(struct inode___192 *, int);
	int (*write_inode)(struct inode___192 *, struct writeback_control___89 *);
	int (*drop_inode)(struct inode___192 *);
	void (*evict_inode)(struct inode___192 *);
	void (*put_super)(struct super_block___192 *);
	int (*sync_fs)(struct super_block___192 *, int);
	int (*freeze_super)(struct super_block___192 *);
	int (*freeze_fs)(struct super_block___192 *);
	int (*thaw_super)(struct super_block___192 *);
	int (*unfreeze_fs)(struct super_block___192 *);
	int (*statfs)(struct dentry___192 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___192 *, int *, char *);
	void (*umount_begin)(struct super_block___192 *);
	int (*show_options)(struct seq_file___168 *, struct dentry___192 *);
	int (*show_devname)(struct seq_file___168 *, struct dentry___192 *);
	int (*show_path)(struct seq_file___168 *, struct dentry___192 *);
	int (*show_stats)(struct seq_file___168 *, struct dentry___192 *);
	ssize_t (*quota_read)(struct super_block___192 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___192 *, int, const char *, size_t, loff_t);
	struct dquot___192 ** (*get_dquots)(struct inode___192 *);
	long int (*nr_cached_objects)(struct super_block___192 *, struct shrink_control___80 *);
	long int (*free_cached_objects)(struct super_block___192 *, struct shrink_control___80 *);
	struct file___192 * (*real_loop)(struct file___192 *);
};

struct block_device___97 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___192 *bd_inode;
	struct super_block___192 *bd_super;
	void *bd_claiming;
	struct device___151 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___180 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___97 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___192 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___96(struct bio___96 *);

struct bio_vec___112 {
	struct page___197 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___96;

struct bio___96 {
	struct bio___96 *bi_next;
	struct block_device___97 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___96 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___91 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___96 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___112 *bi_io_vec;
	struct bio_set___96 *bi_pool;
	struct bio_vec___112 bi_inline_vecs[0];
};

struct kernel_param_ops___176 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___176 *);
	int (*get)(char *, const struct kernel_param___176 *);
	void (*free)(void *);
};

struct kparam_array___176;

struct kernel_param___176 {
	const char *name;
	struct module___176 *mod;
	const struct kernel_param_ops___176 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___176 *arr;
	};
};

struct kparam_array___176 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___176 *ops;
	void *elem;
};

struct module_attribute___176 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___176 *, struct module_kobject___176 *, char *);
	ssize_t (*store)(struct module_attribute___176 *, struct module_kobject___176 *, const char *, size_t);
	void (*setup)(struct module___176 *, const char *);
	int (*test)(struct module___176 *);
	void (*free)(struct module___176 *);
};

struct dev_pm_ops___151 {
	int (*prepare)(struct device___151 *);
	void (*complete)(struct device___151 *);
	int (*suspend)(struct device___151 *);
	int (*resume)(struct device___151 *);
	int (*freeze)(struct device___151 *);
	int (*thaw)(struct device___151 *);
	int (*poweroff)(struct device___151 *);
	int (*restore)(struct device___151 *);
	int (*suspend_late)(struct device___151 *);
	int (*resume_early)(struct device___151 *);
	int (*freeze_late)(struct device___151 *);
	int (*thaw_early)(struct device___151 *);
	int (*poweroff_late)(struct device___151 *);
	int (*restore_early)(struct device___151 *);
	int (*suspend_noirq)(struct device___151 *);
	int (*resume_noirq)(struct device___151 *);
	int (*freeze_noirq)(struct device___151 *);
	int (*thaw_noirq)(struct device___151 *);
	int (*poweroff_noirq)(struct device___151 *);
	int (*restore_noirq)(struct device___151 *);
	int (*runtime_suspend)(struct device___151 *);
	int (*runtime_resume)(struct device___151 *);
	int (*runtime_idle)(struct device___151 *);
};

struct wakeup_source___151 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___151 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___151 {
	struct dev_pm_ops___151 ops;
	int (*start)(struct device___151 *);
	void (*detach)(struct device___151 *, bool);
	int (*activate)(struct device___151 *);
	void (*sync)(struct device___151 *);
	void (*dismiss)(struct device___151 *);
};

struct bus_type___151 {
	const char *name;
	const char *dev_name;
	struct device___151 *dev_root;
	const struct attribute_group___180 **bus_groups;
	const struct attribute_group___180 **dev_groups;
	const struct attribute_group___180 **drv_groups;
	int (*match)(struct device___151 *, struct device_driver___151 *);
	int (*uevent)(struct device___151 *, struct kobj_uevent_env *);
	int (*probe)(struct device___151 *);
	void (*sync_state)(struct device___151 *);
	void (*remove)(struct device___151 *);
	void (*shutdown)(struct device___151 *);
	int (*online)(struct device___151 *);
	int (*offline)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	int (*num_vf)(struct device___151 *);
	int (*dma_configure)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___151 {
	const char *name;
	struct bus_type___151 *bus;
	struct module___176 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___151 *);
	void (*sync_state)(struct device___151 *);
	int (*remove)(struct device___151 *);
	void (*shutdown)(struct device___151 *);
	int (*suspend)(struct device___151 *, pm_message_t);
	int (*resume)(struct device___151 *);
	const struct attribute_group___180 **groups;
	const struct attribute_group___180 **dev_groups;
	const struct dev_pm_ops___151 *pm;
	void (*coredump)(struct device___151 *);
	struct driver_private *p;
};

struct device_type___151 {
	const char *name;
	const struct attribute_group___180 **groups;
	int (*uevent)(struct device___151 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___151 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___151 *);
	const struct dev_pm_ops___151 *pm;
};

struct class___151 {
	const char *name;
	struct module___176 *owner;
	const struct attribute_group___180 **class_groups;
	const struct attribute_group___180 **dev_groups;
	struct kobject___180 *dev_kobj;
	int (*dev_uevent)(struct device___151 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___151 *, umode_t *);
	void (*class_release)(struct class___151 *);
	void (*dev_release)(struct device___151 *);
	int (*shutdown_pre)(struct device___151 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___151 *);
	void (*get_ownership)(struct device___151 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___151 *pm;
	struct subsys_private *p;
};

struct pci_bus___10;

struct pci_slot___10 {
	struct pci_bus___10 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___180 kobj;
};

struct pci_dev___10;

struct pci_ops___10;

struct pci_bus___10 {
	struct list_head node;
	struct pci_bus___10 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___10 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___10 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___151 *bridge;
	struct device___151 dev;
	struct bin_attribute___180 *legacy_io;
	struct bin_attribute___180 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_sriov___7 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___10 *dev;
	struct pci_dev___10 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___10;

struct pci_dev___10 {
	struct list_head bus_list;
	struct pci_bus___10 *bus;
	struct pci_bus___10 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___10 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___10 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___10 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___151 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___180 *res_attr[17];
	struct bin_attribute___180 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___180 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___7 *sriov;
		struct pci_dev___10 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___10;

struct pci_driver___10 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___10 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___10 *);
	int (*suspend)(struct pci_dev___10 *, pm_message_t);
	int (*resume)(struct pci_dev___10 *);
	void (*shutdown)(struct pci_dev___10 *);
	int (*sriov_configure)(struct pci_dev___10 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___10 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___10 *);
	const struct pci_error_handlers___10 *err_handler;
	const struct attribute_group___180 **groups;
	const struct attribute_group___180 **dev_groups;
	struct device_driver___151 driver;
	struct pci_dynids dynids;
};

struct pci_host_bridge___5 {
	struct device___151 dev;
	struct pci_bus___10 *bus;
	struct pci_ops___10 *ops;
	struct pci_ops___10 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___10 *, u8 *);
	int (*map_irq)(const struct pci_dev___10 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___5 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___10 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___10 {
	int (*add_bus)(struct pci_bus___10 *);
	void (*remove_bus)(struct pci_bus___10 *);
	void * (*map_bus)(struct pci_bus___10 *, unsigned int, int);
	int (*read)(struct pci_bus___10 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___10 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___10 {
	pci_ers_result_t (*error_detected)(struct pci_dev___10 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___10 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___10 *);
	void (*reset_prepare)(struct pci_dev___10 *);
	void (*reset_done)(struct pci_dev___10 *);
	void (*resume)(struct pci_dev___10 *);
};

struct dev_pagemap_ops___187 {
	void (*page_free)(struct page___197 *);
	void (*kill)(struct dev_pagemap___187 *);
	void (*cleanup)(struct dev_pagemap___187 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___187 *);
};

struct platform_device___17 {
	const char *name;
	int id;
	bool id_auto;
	struct device___151 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___16 {
	int (*probe)(struct platform_device___17 *);
	int (*remove)(struct platform_device___17 *);
	void (*shutdown)(struct platform_device___17 *);
	int (*suspend)(struct platform_device___17 *, pm_message_t);
	int (*resume)(struct platform_device___17 *);
	struct device_driver___151 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct seq_operations___168 {
	void * (*start)(struct seq_file___168 *, loff_t *);
	void (*stop)(struct seq_file___168 *, void *);
	void * (*next)(struct seq_file___168 *, void *, loff_t *);
	int (*show)(struct seq_file___168 *, void *);
};

struct cgroup_namespace___131 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___131 *root_cset;
};

struct cftype___131;

struct cgroup_subsys___131 {
	struct cgroup_subsys_state___131 * (*css_alloc)(struct cgroup_subsys_state___131 *);
	int (*css_online)(struct cgroup_subsys_state___131 *);
	void (*css_offline)(struct cgroup_subsys_state___131 *);
	void (*css_released)(struct cgroup_subsys_state___131 *);
	void (*css_free)(struct cgroup_subsys_state___131 *);
	void (*css_reset)(struct cgroup_subsys_state___131 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___131 *, int);
	int (*css_extra_stat_show)(struct seq_file___168 *, struct cgroup_subsys_state___131 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___199 *, struct css_set___131 *);
	void (*cancel_fork)(struct task_struct___199 *, struct css_set___131 *);
	void (*fork)(struct task_struct___199 *);
	void (*exit)(struct task_struct___199 *);
	void (*release)(struct task_struct___199 *);
	void (*bind)(struct cgroup_subsys_state___131 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___131 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___131 *dfl_cftypes;
	struct cftype___131 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___131 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___131 *updated_children;
	struct cgroup___131 *updated_next;
};

struct cgroup_root___131 {
	struct kernfs_root___180 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___131 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___131 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___131 *ss;
	struct list_head node;
	struct kernfs_ops___180 *kf_ops;
	int (*open)(struct kernfs_open_file___180 *);
	void (*release)(struct kernfs_open_file___180 *);
	u64 (*read_u64)(struct cgroup_subsys_state___131 *, struct cftype___131 *);
	s64 (*read_s64)(struct cgroup_subsys_state___131 *, struct cftype___131 *);
	int (*seq_show)(struct seq_file___168 *, void *);
	void * (*seq_start)(struct seq_file___168 *, loff_t *);
	void * (*seq_next)(struct seq_file___168 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___168 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___131 *, struct cftype___131 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___131 *, struct cftype___131 *, s64);
	ssize_t (*write)(struct kernfs_open_file___180 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___180 *, struct poll_table_struct___5 *);
};

struct block_device_operations___96;

struct gendisk___97 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___97 *part0;
	const struct block_device_operations___96 *fops;
	struct request_queue___96 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___89 *bdi;
	struct kobject___180 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___180 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___96 {
	struct bio___96 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___112 *bip_vec;
	struct bio_vec___112 bip_inline_vecs[0];
};

struct blkcg___91;

struct blkg_policy_data___91;

struct blkcg_gq___91 {
	struct request_queue___96 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___91 *blkcg;
	struct blkcg_gq___91 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___91 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___96 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___96(struct request___96 *);

typedef void integrity_complete_fn___96(struct request___96 *, unsigned int);

struct blk_integrity_profile___96 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___96 *prepare_fn;
	integrity_complete_fn___96 *complete_fn;
	const char *name;
};

struct block_device_operations___96 {
	blk_qc_t (*submit_bio)(struct bio___96 *);
	int (*open)(struct block_device___97 *, fmode_t);
	void (*release)(struct gendisk___97 *, fmode_t);
	int (*rw_page)(struct block_device___97 *, sector_t, struct page___197 *, unsigned int);
	int (*ioctl)(struct block_device___97 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___97 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___97 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___97 *);
	int (*getgeo)(struct block_device___97 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___97 *, bool);
	void (*swap_slot_free_notify)(struct block_device___97 *, long unsigned int);
	int (*report_zones)(struct gendisk___97 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___97 *, umode_t *);
	struct module___176 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___97 *, sector_t *);
};

typedef void rq_end_io_fn___96(struct request___96 *, blk_status_t);

struct request___96 {
	struct request_queue___96 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___93 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___96 *bio;
	struct bio___96 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___112 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___96 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___96 *saved_end_io;
		} flush;
	};
	struct gendisk___97 *rq_disk;
	struct block_device___97 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___96 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___93 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___96 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___180 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___192 *debugfs_dir;
	struct dentry___192 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___96;

struct elevator_mq_ops___96 {
	int (*init_sched)(struct request_queue___96 *, struct elevator_type___96 *);
	void (*exit_sched)(struct elevator_queue___96 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___93 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___93 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___93 *);
	bool (*allow_merge)(struct request_queue___96 *, struct request___96 *, struct bio___96 *);
	bool (*bio_merge)(struct request_queue___96 *, struct bio___96 *, unsigned int);
	int (*request_merge)(struct request_queue___96 *, struct request___96 **, struct bio___96 *);
	void (*request_merged)(struct request_queue___96 *, struct request___96 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___96 *, struct request___96 *, struct request___96 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___96 *);
	void (*finish_request)(struct request___96 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___93 *, struct list_head *, bool);
	struct request___96 * (*dispatch_request)(struct blk_mq_hw_ctx___93 *);
	bool (*has_work)(struct blk_mq_hw_ctx___93 *);
	void (*completed_request)(struct request___96 *, u64);
	void (*requeue_request)(struct request___96 *);
	struct request___96 * (*former_request)(struct request_queue___96 *, struct request___96 *);
	struct request___96 * (*next_request)(struct request_queue___96 *, struct request___96 *);
	void (*init_icq)(struct io_cq___96 *);
	void (*exit_icq)(struct io_cq___96 *);
};

struct elv_fs_entry___96;

struct elevator_type___96 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___96 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___96 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___176 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___96 {
	struct elevator_type___96 *type;
	void *elevator_data;
	struct kobject___180 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___96 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___96 *, char *);
	ssize_t (*store)(struct elevator_queue___96 *, const char *, size_t);
};

struct blk_mq_queue_data___93;

struct blk_mq_ops___93 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___93 *, const struct blk_mq_queue_data___93 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___93 *);
	int (*get_budget)(struct request_queue___96 *);
	void (*put_budget)(struct request_queue___96 *, int);
	void (*set_rq_budget_token)(struct request___96 *, int);
	int (*get_rq_budget_token)(struct request___96 *);
	enum blk_eh_timer_return (*timeout)(struct request___96 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___93 *);
	void (*complete)(struct request___96 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___93 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___93 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___93 *, struct request___96 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___93 *, struct request___96 *, unsigned int);
	void (*initialize_rq_fn)(struct request___96 *);
	void (*cleanup_rq)(struct request___96 *);
	bool (*busy)(struct request_queue___96 *);
	int (*map_queues)(struct blk_mq_tag_set___93 *);
	void (*show_rq)(struct seq_file___168 *, struct request___96 *);
};

struct blk_mq_tag_set___93 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___93 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___93 {
	struct request___96 *rq;
	bool last;
};

struct blkcg_policy_data___91;

struct blkcg___91 {
	struct cgroup_subsys_state___131 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___91 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___91 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___91 {
	struct blkcg___91 *blkcg;
	int plid;
};

struct blkg_policy_data___91 {
	struct blkcg_gq___91 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___80 {
	struct mem_cgroup___80 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___80 {
	struct lruvec___87 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___80 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___80 *memcg;
};

struct obj_cgroup___80 {
	struct percpu_ref refcnt;
	struct mem_cgroup___80 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct phy___5;

struct phy_ops___5 {
	int (*init)(struct phy___5 *);
	int (*exit)(struct phy___5 *);
	int (*power_on)(struct phy___5 *);
	int (*power_off)(struct phy___5 *);
	int (*set_mode)(struct phy___5 *, enum phy_mode, int);
	int (*set_media)(struct phy___5 *, enum phy_media);
	int (*set_speed)(struct phy___5 *, int);
	int (*configure)(struct phy___5 *, union phy_configure_opts *);
	int (*validate)(struct phy___5 *, enum phy_mode, int, union phy_configure_opts *);
	int (*reset)(struct phy___5 *);
	int (*calibrate)(struct phy___5 *);
	void (*release)(struct phy___5 *);
	struct module___176 *owner;
};

struct phy___5 {
	struct device___151 dev;
	int id;
	const struct phy_ops___5 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct msi_alloc_info___6 {
	struct msi_desc___11 *desc;
	irq_hw_number_t hwirq;
	long unsigned int flags;
	union {
		long unsigned int ul;
		void *ptr;
	} scratchpad[2];
};

typedef struct msi_alloc_info___6 msi_alloc_info_t___6;

struct msi_domain_info___6;

struct msi_domain_ops___6 {
	irq_hw_number_t (*get_hwirq)(struct msi_domain_info___6 *, msi_alloc_info_t___6 *);
	int (*msi_init)(struct irq_domain___32 *, struct msi_domain_info___6 *, unsigned int, irq_hw_number_t, msi_alloc_info_t___6 *);
	void (*msi_free)(struct irq_domain___32 *, struct msi_domain_info___6 *, unsigned int);
	int (*msi_check)(struct irq_domain___32 *, struct msi_domain_info___6 *, struct device___151 *);
	int (*msi_prepare)(struct irq_domain___32 *, struct device___151 *, int, msi_alloc_info_t___6 *);
	void (*msi_finish)(msi_alloc_info_t___6 *, int);
	void (*set_desc)(msi_alloc_info_t___6 *, struct msi_desc___11 *);
	int (*handle_error)(struct irq_domain___32 *, struct msi_desc___11 *, int);
	int (*domain_alloc_irqs)(struct irq_domain___32 *, struct device___151 *, int);
	void (*domain_free_irqs)(struct irq_domain___32 *, struct device___151 *);
};

struct msi_domain_info___6 {
	u32 flags;
	struct msi_domain_ops___6 *ops;
	struct irq_chip___33 *chip;
	void *chip_data;
	irq_flow_handler_t___34 handler;
	void *handler_data;
	const char *handler_name;
	void *data;
};

enum {
	LTSSM_DETECT_QUIET = 0,
	LTSSM_DETECT_ACTIVE = 1,
	LTSSM_POLLING_ACTIVE = 2,
	LTSSM_POLLING_COMPLIANCE = 3,
	LTSSM_POLLING_CONFIGURATION = 4,
	LTSSM_CONFIG_LINKWIDTH_START = 5,
	LTSSM_CONFIG_LINKWIDTH_ACCEPT = 6,
	LTSSM_CONFIG_LANENUM_ACCEPT = 7,
	LTSSM_CONFIG_LANENUM_WAIT = 8,
	LTSSM_CONFIG_COMPLETE = 9,
	LTSSM_CONFIG_IDLE = 10,
	LTSSM_RECOVERY_RCVR_LOCK = 11,
	LTSSM_RECOVERY_SPEED = 12,
	LTSSM_RECOVERY_RCVR_CFG = 13,
	LTSSM_RECOVERY_IDLE = 14,
	LTSSM_L0 = 16,
	LTSSM_RX_L0S_ENTRY = 17,
	LTSSM_RX_L0S_IDLE = 18,
	LTSSM_RX_L0S_FTS = 19,
	LTSSM_TX_L0S_ENTRY = 20,
	LTSSM_TX_L0S_IDLE = 21,
	LTSSM_TX_L0S_FTS = 22,
	LTSSM_L1_ENTRY = 23,
	LTSSM_L1_IDLE = 24,
	LTSSM_L2_IDLE = 25,
	LTSSM_L2_TRANSMIT_WAKE = 26,
	LTSSM_DISABLED = 32,
	LTSSM_LOOPBACK_ENTRY_MASTER = 33,
	LTSSM_LOOPBACK_ACTIVE_MASTER = 34,
	LTSSM_LOOPBACK_EXIT_MASTER = 35,
	LTSSM_LOOPBACK_ENTRY_SLAVE = 36,
	LTSSM_LOOPBACK_ACTIVE_SLAVE = 37,
	LTSSM_LOOPBACK_EXIT_SLAVE = 38,
	LTSSM_HOT_RESET = 39,
	LTSSM_RECOVERY_EQUALIZATION_PHASE0 = 40,
	LTSSM_RECOVERY_EQUALIZATION_PHASE1 = 41,
	LTSSM_RECOVERY_EQUALIZATION_PHASE2 = 42,
	LTSSM_RECOVERY_EQUALIZATION_PHASE3 = 43,
};

struct advk_pcie {
	struct platform_device___17 *pdev;
	void *base;
	struct {
		phys_addr_t match;
		phys_addr_t remap;
		phys_addr_t mask;
		u32 actions;
	} wins[8];
	u8 wins_count;
	struct irq_domain___32 *irq_domain;
	struct irq_chip___33 irq_chip;
	raw_spinlock_t irq_lock;
	struct irq_domain___32 *msi_domain;
	struct irq_domain___32 *msi_inner_domain;
	struct irq_chip___33 msi_bottom_irq_chip;
	struct irq_chip___33 msi_irq_chip;
	struct msi_domain_info___6 msi_domain_info;
	long unsigned int msi_used[1];
	struct mutex msi_used_lock;
	u16 msi_msg;
	int link_gen;
	struct pci_bridge_emul bridge;
	struct gpio_desc *reset_gpio;
	struct phy___5 *phy;
};

struct regulator_bulk_data {
	const char *supply;
	struct regulator *consumer;
	int ret;
};

struct tegra_msi {
	long unsigned int used[4];
	struct irq_domain___32 *domain;
	struct mutex map_lock;
	spinlock_t mask_lock;
	void *virt;
	dma_addr_t phys;
	int irq;
};

struct tegra_pcie_port_soc {
	struct {
		u8 turnoff_bit;
		u8 ack_bit;
	} pme;
};

struct tegra_pcie_soc {
	unsigned int num_ports;
	const struct tegra_pcie_port_soc *ports;
	unsigned int msi_base_shift;
	long unsigned int afi_pex2_ctrl;
	u32 pads_pll_ctl;
	u32 tx_ref_sel;
	u32 pads_refclk_cfg0;
	u32 pads_refclk_cfg1;
	u32 update_fc_threshold;
	bool has_pex_clkreq_en;
	bool has_pex_bias_ctrl;
	bool has_intr_prsnt_sense;
	bool has_cml_clk;
	bool has_gen2;
	bool force_pca_enable;
	bool program_uphy;
	bool update_clamp_threshold;
	bool program_deskew_time;
	bool update_fc_timer;
	bool has_cache_bars;
	struct {
		struct {
			u32 rp_ectl_2_r1;
			u32 rp_ectl_4_r1;
			u32 rp_ectl_5_r1;
			u32 rp_ectl_6_r1;
			u32 rp_ectl_2_r2;
			u32 rp_ectl_4_r2;
			u32 rp_ectl_5_r2;
			u32 rp_ectl_6_r2;
		} regs;
		bool enable;
	} ectl;
};

struct tegra_pcie {
	struct device___151 *dev;
	void *pads;
	void *afi;
	void *cfg;
	int irq;
	struct resource cs;
	struct clk *pex_clk;
	struct clk *afi_clk;
	struct clk *pll_e;
	struct clk *cml_clk;
	struct reset_control *pex_rst;
	struct reset_control *afi_rst;
	struct reset_control *pcie_xrst;
	bool legacy_phy;
	struct phy___5 *phy;
	struct tegra_msi msi;
	struct list_head ports;
	u32 xbar_config;
	struct regulator_bulk_data *supplies;
	unsigned int num_supplies;
	const struct tegra_pcie_soc *soc;
	struct dentry___192 *debugfs;
};

struct tegra_pcie_port {
	struct tegra_pcie *pcie;
	struct device_node___53 *np;
	struct list_head list;
	struct resource regs;
	void *base;
	unsigned int index;
	unsigned int lanes;
	struct phy___5 **phys;
	struct gpio_desc *reset_gpio;
};

struct rcar_pcie {
	struct device___148 *dev;
	void *base;
};

struct rcar_pcie___2 {
	struct device___151 *dev;
	void *base;
};

enum {
	RCAR_PCI_ACCESS_READ = 0,
	RCAR_PCI_ACCESS_WRITE = 1,
};

struct rcar_msi {
	long unsigned int used[1];
	struct irq_domain___32 *domain;
	struct mutex map_lock;
	spinlock_t mask_lock;
	int irq1;
	int irq2;
};

struct rcar_pcie_host {
	struct rcar_pcie___2 pcie;
	struct phy___5 *phy;
	struct clk *bus_clk;
	struct rcar_msi msi;
	int (*phy_init_fn)(struct rcar_pcie_host *);
};

struct rcar_pcie___3 {
	struct device___145 *dev;
	void *base;
};

struct rcar_pcie_endpoint {
	struct rcar_pcie___3 pcie;
	phys_addr_t *ob_mapped_addr;
	struct pci_epc_mem_window *ob_window;
	u8 max_functions;
	unsigned int bar_to_atu[6];
	long unsigned int *ib_window_map;
	u32 num_ib_windows;
	u32 num_ob_windows;
};

struct pci_config_window___2;

struct pci_ecam_ops___2 {
	unsigned int bus_shift;
	struct pci_ops___10 pci_ops;
	int (*init)(struct pci_config_window___2 *);
};

struct pci_config_window___2 {
	struct resource res;
	struct resource busr;
	unsigned int bus_shift;
	void *priv;
	const struct pci_ecam_ops___2 *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___151 *parent;
};

struct thunder_pem_pci {
	u32 ea_entry[3];
	void *pem_reg_base;
};

struct xilinx_pcie_port {
	void *reg_base;
	struct device___151 *dev;
	long unsigned int msi_map[2];
	struct mutex map_lock;
	struct irq_domain___32 *msi_domain;
	struct irq_domain___32 *leg_domain;
	struct list_head resources;
};

struct pci_host_bridge___6 {
	struct device___137 dev;
	struct pci_bus___7 *bus;
	struct pci_ops___7 *ops;
	struct pci_ops___7 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___7 *, u8 *);
	int (*map_irq)(const struct pci_dev___7 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___6 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___7 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct nwl_msi {
	struct irq_domain___19 *msi_domain;
	long unsigned int *bitmap;
	struct irq_domain___19 *dev_domain;
	struct mutex lock;
	int irq_msi0;
	int irq_msi1;
};

struct nwl_pcie {
	struct device___137 *dev;
	void *breg_base;
	void *pcireg_base;
	void *ecam_base;
	phys_addr_t phys_breg_base;
	phys_addr_t phys_pcie_reg_base;
	phys_addr_t phys_ecam_base;
	u32 breg_size;
	u32 pcie_reg_size;
	u32 ecam_size;
	int irq_intx;
	int irq_misc;
	u32 ecam_value;
	u8 last_busno;
	struct nwl_msi msi;
	struct irq_domain___19 *legacy_irq_domain;
	struct clk *clk;
	raw_spinlock_t leg_mask_lock;
};

struct pci_config_window___3;

struct pci_ecam_ops___3 {
	unsigned int bus_shift;
	struct pci_ops___8 pci_ops;
	int (*init)(struct pci_config_window___3 *);
};

struct pci_config_window___3 {
	struct resource res;
	struct resource busr;
	unsigned int bus_shift;
	void *priv;
	const struct pci_ecam_ops___3 *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___150 *parent;
};

struct xilinx_cpm_pcie_port {
	void *reg_base;
	void *cpm_base;
	struct device___150 *dev;
	struct irq_domain___31 *intx_domain;
	struct irq_domain___31 *cpm_domain;
	struct pci_config_window___3 *cfg;
	int intx_irq;
	int irq;
	raw_spinlock_t lock;
};

struct xgene_pcie_port {
	struct device_node___52 *node;
	struct device___150 *dev;
	struct clk *clk;
	void *csr_base;
	void *cfg_base;
	long unsigned int cfg_addr;
	bool link_up;
	u32 version;
};

struct xgene_msi;

struct xgene_msi_group {
	struct xgene_msi *msi;
	int gic_irq;
	u32 msi_grp;
};

struct xgene_msi {
	struct device_node___39 *node;
	struct irq_domain___19 *inner_domain;
	struct irq_domain___19 *msi_domain;
	u64 msi_addr;
	void *msi_regs;
	long unsigned int *bitmap;
	struct mutex bitmap_lock;
	struct xgene_msi_group *msi_groups;
	int num_cpus;
};

enum iproc_pcie_type {
	IPROC_PCIE_PAXB_BCMA = 0,
	IPROC_PCIE_PAXB = 1,
	IPROC_PCIE_PAXB_V2 = 2,
	IPROC_PCIE_PAXC = 3,
	IPROC_PCIE_PAXC_V2 = 4,
};

struct iproc_pcie_ob {
	resource_size_t axi_offset;
	unsigned int nr_windows;
};

struct iproc_pcie_ib {
	unsigned int nr_regions;
};

struct phy___6;

struct iproc_pcie_ob_map;

struct iproc_pcie_ib_map;

struct iproc_msi;

struct iproc_pcie {
	struct device___137 *dev;
	enum iproc_pcie_type type;
	u16 *reg_offsets;
	void *base;
	phys_addr_t base_addr;
	struct resource mem;
	struct phy___6 *phy;
	int (*map_irq)(const struct pci_dev___7 *, u8, u8);
	bool ep_is_internal;
	bool iproc_cfg_read;
	bool rej_unconfig_pf;
	bool has_apb_err_disable;
	bool fix_paxc_cap;
	bool need_ob_cfg;
	struct iproc_pcie_ob ob;
	const struct iproc_pcie_ob_map *ob_map;
	bool need_ib_cfg;
	struct iproc_pcie_ib ib;
	const struct iproc_pcie_ib_map *ib_map;
	bool need_msi_steer;
	struct iproc_msi *msi;
};

struct iproc_msi_grp;

struct iproc_msi {
	struct iproc_pcie *pcie;
	const u16 (*reg_offsets)[8];
	struct iproc_msi_grp *grps;
	int nr_irqs;
	int nr_cpus;
	bool has_inten_reg;
	long unsigned int *bitmap;
	struct mutex bitmap_lock;
	unsigned int nr_msi_vecs;
	struct irq_domain___19 *inner_domain;
	struct irq_domain___19 *msi_domain;
	unsigned int nr_eq_region;
	unsigned int nr_msi_region;
	void *eq_cpu;
	dma_addr_t eq_dma;
	phys_addr_t msi_addr;
};

enum iproc_msi_reg {
	IPROC_MSI_EQ_PAGE = 0,
	IPROC_MSI_EQ_PAGE_UPPER = 1,
	IPROC_MSI_PAGE = 2,
	IPROC_MSI_PAGE_UPPER = 3,
	IPROC_MSI_CTRL = 4,
	IPROC_MSI_EQ_HEAD = 5,
	IPROC_MSI_EQ_TAIL = 6,
	IPROC_MSI_INTS_EN = 7,
	IPROC_MSI_REG_SIZE = 8,
};

struct iproc_msi_grp {
	struct iproc_msi *msi;
	int gic_irq;
	unsigned int eq;
};

enum altera_pcie_version {
	ALTERA_PCIE_V1 = 0,
	ALTERA_PCIE_V2 = 1,
};

struct altera_pcie_data;

struct altera_pcie {
	struct platform_device___14 *pdev;
	void *cra_base;
	void *hip_base;
	int irq;
	u8 root_bus_nr;
	struct irq_domain___29 *irq_domain;
	struct resource bus_range;
	const struct altera_pcie_data *pcie_data;
};

struct altera_pcie_ops;

struct altera_pcie_data {
	const struct altera_pcie_ops *ops;
	enum altera_pcie_version version;
	u32 cap_offset;
	u32 cfgrd0;
	u32 cfgrd1;
	u32 cfgwr0;
	u32 cfgwr1;
};

struct altera_pcie_ops {
	int (*tlp_read_pkt)(struct altera_pcie *, u32 *);
	void (*tlp_write_pkt)(struct altera_pcie *, u32 *, u32, bool);
	bool (*get_link_status)(struct altera_pcie *);
	int (*rp_read_cfg)(struct altera_pcie *, int, int, u32 *);
	int (*rp_write_cfg)(struct altera_pcie *, u8, int, int, u32);
};

struct tlp_rp_regpair_t {
	u32 ctrl;
	u32 reg0;
	u32 reg1;
};

struct altera_msi {
	long unsigned int used[1];
	struct mutex lock;
	struct platform_device___17 *pdev;
	struct irq_domain___32 *msi_domain;
	struct irq_domain___32 *inner_domain;
	void *csr_base;
	void *vector_base;
	phys_addr_t vector_phy;
	u32 num_of_vectors;
	int irq;
};

struct rockchip_pcie {
	void *reg_base;
	void *apb_base;
	bool legacy_phy;
	struct phy___5 *phys[4];
	struct reset_control *core_rst;
	struct reset_control *mgmt_rst;
	struct reset_control *mgmt_sticky_rst;
	struct reset_control *pipe_rst;
	struct reset_control *pm_rst;
	struct reset_control *aclk_rst;
	struct reset_control *pclk_rst;
	struct clk *aclk_pcie;
	struct clk *aclk_perf_pcie;
	struct clk *hclk_pcie;
	struct clk *clk_pcie_pm;
	struct regulator *vpcie12v;
	struct regulator *vpcie3v3;
	struct regulator *vpcie1v8;
	struct regulator *vpcie0v9;
	struct gpio_desc *ep_gpio;
	u32 lanes;
	u8 lanes_map;
	int link_gen;
	struct device___151 *dev;
	struct irq_domain___2 *irq_domain;
	int offset;
	void *msg_region;
	phys_addr_t msg_bus_addr;
	bool is_rc;
	struct resource *mem_res;
};

struct rockchip_pcie___2 {
	void *reg_base;
	void *apb_base;
	bool legacy_phy;
	struct phy___6 *phys[4];
	struct reset_control *core_rst;
	struct reset_control *mgmt_rst;
	struct reset_control *mgmt_sticky_rst;
	struct reset_control *pipe_rst;
	struct reset_control *pm_rst;
	struct reset_control *aclk_rst;
	struct reset_control *pclk_rst;
	struct clk *aclk_pcie;
	struct clk *aclk_perf_pcie;
	struct clk *hclk_pcie;
	struct clk *clk_pcie_pm;
	struct regulator *vpcie12v;
	struct regulator *vpcie3v3;
	struct regulator *vpcie1v8;
	struct regulator *vpcie0v9;
	struct gpio_desc *ep_gpio;
	u32 lanes;
	u8 lanes_map;
	int link_gen;
	struct device___148 *dev;
	struct irq_domain___2 *irq_domain;
	int offset;
	void *msg_region;
	phys_addr_t msg_bus_addr;
	bool is_rc;
	struct resource *mem_res;
};

struct rockchip_pcie_ep {
	struct rockchip_pcie___2 rockchip;
	struct pci_epc___2 *epc;
	u32 max_regions;
	long unsigned int ob_region_map;
	phys_addr_t *ob_addr;
	phys_addr_t irq_phys_addr;
	void *irq_cpu_addr;
	u64 irq_pci_addr;
	u8 irq_pci_fn;
	u8 irq_pending;
};

struct mtk_pcie_port;

struct mtk_pcie_soc {
	bool need_fix_class_id;
	bool need_fix_device_id;
	bool no_msi;
	unsigned int device_id;
	struct pci_ops___10 *ops;
	int (*startup)(struct mtk_pcie_port *);
	int (*setup_irq)(struct mtk_pcie_port *, struct device_node___53 *);
};

struct mtk_pcie;

struct mtk_pcie_port {
	void *base;
	struct list_head list;
	struct mtk_pcie *pcie;
	struct reset_control *reset;
	struct clk *sys_ck;
	struct clk *ahb_ck;
	struct clk *axi_ck;
	struct clk *aux_ck;
	struct clk *obff_ck;
	struct clk *pipe_ck;
	struct phy___5 *phy;
	u32 slot;
	int irq;
	struct irq_domain___32 *irq_domain;
	struct irq_domain___32 *inner_domain;
	struct irq_domain___32 *msi_domain;
	struct mutex lock;
	long unsigned int msi_irq_in_use[1];
};

struct mtk_pcie {
	struct device___151 *dev;
	void *base;
	struct regmap *cfg;
	struct clk *free_ck;
	struct list_head ports;
	const struct mtk_pcie_soc *soc;
};

struct event_map {
	u32 reg_mask;
	u32 event_bit;
};

struct mc_msi {
	struct mutex lock;
	struct irq_domain___32 *msi_domain;
	struct irq_domain___32 *dev_domain;
	u32 num_vectors;
	u64 vector_phy;
	long unsigned int used[1];
};

struct mc_port {
	void *axi_base_addr;
	struct device___151 *dev;
	struct irq_domain___32 *intx_domain;
	struct irq_domain___32 *event_domain;
	raw_spinlock_t lock;
	struct mc_msi msi;
};

struct cause {
	const char *sym;
	const char *str;
};

struct acpi_hest_generic_data {
	u8 section_type[16];
	u32 error_severity;
	u16 revision;
	u8 validation_bits;
	u8 flags;
	u32 error_data_length;
	u8 fru_id[16];
	u8 fru_text[20];
};

struct acpi_hest_generic_data_v300 {
	u8 section_type[16];
	u32 error_severity;
	u16 revision;
	u8 validation_bits;
	u8 flags;
	u32 error_data_length;
	u8 fru_id[16];
	u8 fru_text[20];
	u64 time_stamp;
};

struct hisi_pcie_error_data {
	u64 val_bits;
	u8 version;
	u8 soc_id;
	u8 socket_id;
	u8 nimbus_id;
	u8 sub_module_id;
	u8 core_id;
	u8 port_id;
	u8 err_severity;
	u16 err_type;
	u8 reserv[2];
	u32 err_misc[33];
};

struct hisi_pcie_error_private {
	struct notifier_block nb;
	struct device___148 *dev;
};

enum hisi_pcie_submodule_id {
	HISI_PCIE_SUB_MODULE_ID_AP = 0,
	HISI_PCIE_SUB_MODULE_ID_TL = 1,
	HISI_PCIE_SUB_MODULE_ID_MAC = 2,
	HISI_PCIE_SUB_MODULE_ID_DL = 3,
	HISI_PCIE_SUB_MODULE_ID_SDI = 4,
};

enum hisi_pcie_err_severity {
	HISI_PCIE_ERR_SEV_RECOVERABLE = 0,
	HISI_PCIE_ERR_SEV_FATAL = 1,
	HISI_PCIE_ERR_SEV_CORRECTED = 2,
	HISI_PCIE_ERR_SEV_NONE = 3,
};

struct config_group___4;

struct config_item_type___4;

struct config_item___4 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___4 *ci_parent;
	struct config_group___4 *ci_group;
	const struct config_item_type___4 *ci_type;
	struct dentry___192 *ci_dentry;
};

struct configfs_subsystem___4;

struct config_group___4 {
	struct config_item___4 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___4 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___4;

struct configfs_group_operations___4;

struct configfs_attribute___4;

struct configfs_bin_attribute___4;

struct config_item_type___4 {
	struct module___8 *ct_owner;
	struct configfs_item_operations___4 *ct_item_ops;
	struct configfs_group_operations___4 *ct_group_ops;
	struct configfs_attribute___4 **ct_attrs;
	struct configfs_bin_attribute___4 **ct_bin_attrs;
};

struct configfs_item_operations___4 {
	void (*release)(struct config_item___4 *);
	int (*allow_link)(struct config_item___4 *, struct config_item___4 *);
	void (*drop_link)(struct config_item___4 *, struct config_item___4 *);
};

struct configfs_group_operations___4 {
	struct config_item___4 * (*make_item)(struct config_group___4 *, const char *);
	struct config_group___4 * (*make_group)(struct config_group___4 *, const char *);
	int (*commit_item)(struct config_item___4 *);
	void (*disconnect_notify)(struct config_group___4 *, struct config_item___4 *);
	void (*drop_item)(struct config_group___4 *, struct config_item___4 *);
};

struct configfs_attribute___4 {
	const char *ca_name;
	struct module___8 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___4 *, char *);
	ssize_t (*store)(struct config_item___4 *, const char *, size_t);
};

struct configfs_bin_attribute___4 {
	struct configfs_attribute___4 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___4 *, void *, size_t);
	ssize_t (*write)(struct config_item___4 *, const void *, size_t);
};

struct configfs_subsystem___4 {
	struct config_group___4 su_group;
	struct mutex su_mutex;
};

struct pci_epc_ops___4;

struct pci_epc___4 {
	struct device___151 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___4 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group___4 *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

struct pci_epc_ops___4 {
	int (*write_header)(struct pci_epc___4 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___4 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___4 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___4 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___4 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___4 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___4 *, u8, u8);
	int (*set_msix)(struct pci_epc___4 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___4 *, u8, u8);
	int (*raise_irq)(struct pci_epc___4 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___4 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___4 *);
	void (*stop)(struct pci_epc___4 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___4 *, u8, u8);
	struct module___8 *owner;
};

enum dw_pcie_region_type {
	DW_PCIE_REGION_UNKNOWN = 0,
	DW_PCIE_REGION_INBOUND = 1,
	DW_PCIE_REGION_OUTBOUND = 2,
};

struct pcie_port;

struct dw_pcie_host_ops {
	int (*host_init)(struct pcie_port *);
	int (*msi_host_init)(struct pcie_port *);
};

struct pcie_port {
	bool has_msi_ctrl: 1;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	int irq;
	const struct dw_pcie_host_ops *ops;
	int msi_irq;
	struct irq_domain___2 *irq_domain;
	struct irq_domain___2 *msi_domain;
	u16 msi_msg;
	dma_addr_t msi_data;
	struct irq_chip___33 *msi_irq_chip;
	u32 num_vectors;
	u32 irq_mask[8];
	struct pci_host_bridge___5 *bridge;
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

enum dw_pcie_as_type {
	DW_PCIE_AS_UNKNOWN = 0,
	DW_PCIE_AS_MEM = 1,
	DW_PCIE_AS_IO = 2,
};

struct dw_pcie_ep;

struct dw_pcie_ep_ops {
	void (*ep_init)(struct dw_pcie_ep *);
	int (*raise_irq)(struct dw_pcie_ep *, u8, enum pci_epc_irq_type, u16);
	const struct pci_epc_features * (*get_features)(struct dw_pcie_ep *);
	unsigned int (*func_conf_select)(struct dw_pcie_ep *, u8);
};

struct dw_pcie_ep {
	struct pci_epc___4 *epc;
	struct list_head func_list;
	const struct dw_pcie_ep_ops *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	struct pci_epf_bar___2 *epf_bar[6];
};

struct dw_pcie;

struct dw_pcie_ops {
	u64 (*cpu_addr_fixup)(struct dw_pcie *, u64);
	u32 (*read_dbi)(struct dw_pcie *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie *, void *, u32, size_t, u32);
	void (*write_dbi2)(struct dw_pcie *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie *);
	int (*start_link)(struct dw_pcie *);
	void (*stop_link)(struct dw_pcie *);
};

struct dw_pcie {
	struct device___151 *dev;
	void *dbi_base;
	void *dbi_base2;
	void *atu_base;
	size_t atu_size;
	u32 num_ib_windows;
	u32 num_ob_windows;
	struct pcie_port pp;
	struct dw_pcie_ep ep;
	const struct dw_pcie_ops *ops;
	unsigned int version;
	int num_lanes;
	int link_gen;
	u8 n_fts[2];
	bool iatu_unroll_enabled: 1;
	bool io_cfg_atu_shared: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pcie_port___2;

struct dw_pcie_host_ops___2 {
	int (*host_init)(struct pcie_port___2 *);
	int (*msi_host_init)(struct pcie_port___2 *);
};

struct pcie_port___2 {
	bool has_msi_ctrl: 1;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	int irq;
	const struct dw_pcie_host_ops___2 *ops;
	int msi_irq;
	struct irq_domain___32 *irq_domain;
	struct irq_domain___32 *msi_domain;
	u16 msi_msg;
	dma_addr_t msi_data;
	struct irq_chip___33 *msi_irq_chip;
	u32 num_vectors;
	u32 irq_mask[8];
	struct pci_host_bridge___5 *bridge;
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

struct dw_pcie___2;

struct dw_pcie_ops___2 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___2 *, u64);
	u32 (*read_dbi)(struct dw_pcie___2 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___2 *, void *, u32, size_t, u32);
	void (*write_dbi2)(struct dw_pcie___2 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___2 *);
	int (*start_link)(struct dw_pcie___2 *);
	void (*stop_link)(struct dw_pcie___2 *);
};

struct dw_pcie___2 {
	struct device___151 *dev;
	void *dbi_base;
	void *dbi_base2;
	void *atu_base;
	size_t atu_size;
	u32 num_ib_windows;
	u32 num_ob_windows;
	struct pcie_port___2 pp;
	struct dw_pcie_ep ep;
	const struct dw_pcie_ops___2 *ops;
	unsigned int version;
	int num_lanes;
	int link_gen;
	u8 n_fts[2];
	bool iatu_unroll_enabled: 1;
	bool io_cfg_atu_shared: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dw_pcie_ep_func {
	struct list_head list;
	u8 func_no;
	u8 msi_cap;
	u8 msix_cap;
};

struct pci_host_bridge___7 {
	struct device___136 dev;
	struct pci_bus___7 *bus;
	struct pci_ops___7 *ops;
	struct pci_ops___7 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___7 *, u8 *);
	int (*map_irq)(const struct pci_dev___7 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___7 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___7 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_epc_ops___5;

struct pci_epc___5 {
	struct device___136 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___5 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group___3 *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

struct pci_epc_ops___5 {
	int (*write_header)(struct pci_epc___5 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___5 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___5 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___5 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___5 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___5 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___5 *, u8, u8);
	int (*set_msix)(struct pci_epc___5 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___5 *, u8, u8);
	int (*raise_irq)(struct pci_epc___5 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___5 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___5 *);
	void (*stop)(struct pci_epc___5 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___5 *, u8, u8);
	struct module___8 *owner;
};

enum dw_pcie_device_mode {
	DW_PCIE_UNKNOWN_TYPE = 0,
	DW_PCIE_EP_TYPE = 1,
	DW_PCIE_LEG_EP_TYPE = 2,
	DW_PCIE_RC_TYPE = 3,
};

struct pcie_port___3;

struct dw_pcie_host_ops___3 {
	int (*host_init)(struct pcie_port___3 *);
	int (*msi_host_init)(struct pcie_port___3 *);
};

struct pcie_port___3 {
	bool has_msi_ctrl: 1;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	int irq;
	const struct dw_pcie_host_ops___3 *ops;
	int msi_irq;
	struct irq_domain___18 *irq_domain;
	struct irq_domain___18 *msi_domain;
	u16 msi_msg;
	dma_addr_t msi_data;
	struct irq_chip___19 *msi_irq_chip;
	u32 num_vectors;
	u32 irq_mask[8];
	struct pci_host_bridge___7 *bridge;
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

struct dw_pcie_ep___2;

struct dw_pcie_ep_ops___2 {
	void (*ep_init)(struct dw_pcie_ep___2 *);
	int (*raise_irq)(struct dw_pcie_ep___2 *, u8, enum pci_epc_irq_type, u16);
	const struct pci_epc_features * (*get_features)(struct dw_pcie_ep___2 *);
	unsigned int (*func_conf_select)(struct dw_pcie_ep___2 *, u8);
};

struct dw_pcie_ep___2 {
	struct pci_epc___5 *epc;
	struct list_head func_list;
	const struct dw_pcie_ep_ops___2 *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	struct pci_epf_bar___2 *epf_bar[6];
};

struct dw_pcie___3;

struct dw_pcie_ops___3 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___3 *, u64);
	u32 (*read_dbi)(struct dw_pcie___3 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___3 *, void *, u32, size_t, u32);
	void (*write_dbi2)(struct dw_pcie___3 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___3 *);
	int (*start_link)(struct dw_pcie___3 *);
	void (*stop_link)(struct dw_pcie___3 *);
};

struct dw_pcie___3 {
	struct device___136 *dev;
	void *dbi_base;
	void *dbi_base2;
	void *atu_base;
	size_t atu_size;
	u32 num_ib_windows;
	u32 num_ob_windows;
	struct pcie_port___3 pp;
	struct dw_pcie_ep___2 ep;
	const struct dw_pcie_ops___3 *ops;
	unsigned int version;
	int num_lanes;
	int link_gen;
	u8 n_fts[2];
	bool iatu_unroll_enabled: 1;
	bool io_cfg_atu_shared: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dw_plat_pcie {
	struct dw_pcie___3 *pci;
	struct regmap *regmap;
	enum dw_pcie_device_mode mode;
};

struct dw_plat_pcie_of_data {
	enum dw_pcie_device_mode mode;
};

struct pm_domain_data {
	struct list_head list_node;
	struct device___151 *dev;
};

struct device_link___12 {
	struct device___151 *supplier;
	struct list_head s_node;
	struct device___151 *consumer;
	struct list_head c_node;
	struct device___151 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct config_group___5;

struct config_item_type___5;

struct config_item___5 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___5 *ci_parent;
	struct config_group___5 *ci_group;
	const struct config_item_type___5 *ci_type;
	struct dentry___192 *ci_dentry;
};

struct configfs_subsystem___5;

struct config_group___5 {
	struct config_item___5 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___5 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___5;

struct configfs_group_operations___5;

struct configfs_attribute___5;

struct configfs_bin_attribute___5;

struct config_item_type___5 {
	struct module___176 *ct_owner;
	struct configfs_item_operations___5 *ct_item_ops;
	struct configfs_group_operations___5 *ct_group_ops;
	struct configfs_attribute___5 **ct_attrs;
	struct configfs_bin_attribute___5 **ct_bin_attrs;
};

struct configfs_item_operations___5 {
	void (*release)(struct config_item___5 *);
	int (*allow_link)(struct config_item___5 *, struct config_item___5 *);
	void (*drop_link)(struct config_item___5 *, struct config_item___5 *);
};

struct configfs_group_operations___5 {
	struct config_item___5 * (*make_item)(struct config_group___5 *, const char *);
	struct config_group___5 * (*make_group)(struct config_group___5 *, const char *);
	int (*commit_item)(struct config_item___5 *);
	void (*disconnect_notify)(struct config_group___5 *, struct config_item___5 *);
	void (*drop_item)(struct config_group___5 *, struct config_item___5 *);
};

struct configfs_attribute___5 {
	const char *ca_name;
	struct module___176 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___5 *, char *);
	ssize_t (*store)(struct config_item___5 *, const char *, size_t);
};

struct configfs_bin_attribute___5 {
	struct configfs_attribute___5 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___5 *, void *, size_t);
	ssize_t (*write)(struct config_item___5 *, const void *, size_t);
};

struct configfs_subsystem___5 {
	struct config_group___5 su_group;
	struct mutex su_mutex;
};

struct pci_epc_ops___6;

struct pci_epc___6 {
	struct device___151 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___6 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group___5 *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

struct pci_epc_ops___6 {
	int (*write_header)(struct pci_epc___6 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___6 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___6 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___6 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___6 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___6 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___6 *, u8, u8);
	int (*set_msix)(struct pci_epc___6 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___6 *, u8, u8);
	int (*raise_irq)(struct pci_epc___6 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___6 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___6 *);
	void (*stop)(struct pci_epc___6 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___6 *, u8, u8);
	struct module___176 *owner;
};

struct dw_pcie_ep___3;

struct dw_pcie_ep_ops___3 {
	void (*ep_init)(struct dw_pcie_ep___3 *);
	int (*raise_irq)(struct dw_pcie_ep___3 *, u8, enum pci_epc_irq_type, u16);
	const struct pci_epc_features * (*get_features)(struct dw_pcie_ep___3 *);
	unsigned int (*func_conf_select)(struct dw_pcie_ep___3 *, u8);
};

struct dw_pcie_ep___3 {
	struct pci_epc___6 *epc;
	struct list_head func_list;
	const struct dw_pcie_ep_ops___3 *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	struct pci_epf_bar___2 *epf_bar[6];
};

struct dw_pcie___4;

struct dw_pcie_ops___4 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___4 *, u64);
	u32 (*read_dbi)(struct dw_pcie___4 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___4 *, void *, u32, size_t, u32);
	void (*write_dbi2)(struct dw_pcie___4 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___4 *);
	int (*start_link)(struct dw_pcie___4 *);
	void (*stop_link)(struct dw_pcie___4 *);
};

struct dw_pcie___4 {
	struct device___151 *dev;
	void *dbi_base;
	void *dbi_base2;
	void *atu_base;
	size_t atu_size;
	u32 num_ib_windows;
	u32 num_ob_windows;
	struct pcie_port___2 pp;
	struct dw_pcie_ep___3 ep;
	const struct dw_pcie_ops___4 *ops;
	unsigned int version;
	int num_lanes;
	int link_gen;
	u8 n_fts[2];
	bool iatu_unroll_enabled: 1;
	bool io_cfg_atu_shared: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum imx6_pcie_variants {
	IMX6Q = 0,
	IMX6SX = 1,
	IMX6QP = 2,
	IMX7D = 3,
	IMX8MQ = 4,
};

struct imx6_pcie_drvdata {
	enum imx6_pcie_variants variant;
	u32 flags;
	int dbi_length;
};

struct imx6_pcie {
	struct dw_pcie___4 *pci;
	int reset_gpio;
	bool gpio_active_high;
	struct clk *pcie_bus;
	struct clk *pcie_phy;
	struct clk *pcie_inbound_axi;
	struct clk *pcie;
	struct clk *pcie_aux;
	struct regmap *iomuxc_gpr;
	u32 controller_id;
	struct reset_control *pciephy_reset;
	struct reset_control *apps_reset;
	struct reset_control *turnoff_reset;
	u32 tx_deemph_gen1;
	u32 tx_deemph_gen2_3p5db;
	u32 tx_deemph_gen2_6db;
	u32 tx_swing_full;
	u32 tx_swing_low;
	struct regulator *vpcie;
	struct regulator *vph;
	void *phy_base;
	struct device___151 *pd_pcie;
	struct device___151 *pd_pcie_phy;
	const struct imx6_pcie_drvdata *drvdata;
};

struct ks_pcie_of_data {
	enum dw_pcie_device_mode mode;
	const struct dw_pcie_host_ops___2 *host_ops;
	const struct dw_pcie_ep_ops___3 *ep_ops;
	unsigned int version;
};

struct keystone_pcie {
	struct dw_pcie___4 *pci;
	u32 device_id;
	int legacy_host_irqs[4];
	struct device_node___53 *legacy_intc_np;
	int msi_host_irq;
	int num_lanes;
	u32 num_viewport;
	struct phy___5 **phy;
	struct device_link___12 **link;
	struct device_node___53 *msi_intc_np;
	struct irq_domain___32 *legacy_irq_domain;
	struct device_node___53 *np;
	void *va_app_base;
	struct resource app;
	bool is_am6;
};

struct ls_pcie_drvdata {
	u32 lut_offset;
	u32 ltssm_shift;
	u32 lut_dbg;
	const struct dw_pcie_host_ops___3 *ops;
	const struct dw_pcie_ops___3 *dw_pcie_ops;
};

struct ls_pcie {
	struct dw_pcie___3 *pci;
	void *lut;
	struct regmap *scfg;
	const struct ls_pcie_drvdata *drvdata;
	int index;
};

struct ls_pcie_ep_drvdata {
	u32 func_offset;
	const struct dw_pcie_ep_ops___2 *ops;
	const struct dw_pcie_ops___3 *dw_pcie_ops;
};

struct ls_pcie_ep {
	struct dw_pcie___3 *pci;
	struct pci_epc_features *ls_epc;
	const struct ls_pcie_ep_drvdata *drvdata;
};

struct dentry___193;

struct super_block___193;

struct module___177;

struct file_system_type___193 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___193 * (*mount)(struct file_system_type___193 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___193 *);
	struct module___177 *owner;
	struct file_system_type___193 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___193;

struct kiocb___193;

struct iov_iter___115;

struct vm_area_struct___198;

struct inode___193;

struct file_lock___193;

struct page___198;

struct seq_file___169;

struct file_operations___194 {
	struct module___177 *owner;
	loff_t (*llseek)(struct file___193 *, loff_t, int);
	ssize_t (*read)(struct file___193 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___193 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___193 *, struct iov_iter___115 *);
	ssize_t (*write_iter)(struct kiocb___193 *, struct iov_iter___115 *);
	int (*iopoll)(struct kiocb___193 *, bool);
	int (*iterate)(struct file___193 *, struct dir_context *);
	int (*iterate_shared)(struct file___193 *, struct dir_context *);
	__poll_t (*poll)(struct file___193 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___193 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___193 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___193 *, struct vm_area_struct___198 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___193 *, struct file___193 *);
	int (*flush)(struct file___193 *, fl_owner_t);
	int (*release)(struct inode___193 *, struct file___193 *);
	int (*fsync)(struct file___193 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___193 *, int);
	int (*lock)(struct file___193 *, int, struct file_lock___193 *);
	ssize_t (*sendpage)(struct file___193 *, struct page___198 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___193 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___193 *, long unsigned int);
	int (*flock)(struct file___193 *, int, struct file_lock___193 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___193 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___193 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___193 *, long int, struct file_lock___193 **, void **);
	long int (*fallocate)(struct file___193 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___169 *, struct file___193 *);
	ssize_t (*copy_file_range)(struct file___193 *, loff_t, struct file___193 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___193 *, loff_t, struct file___193 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___193 *, loff_t, loff_t, int);
};

struct vmacache___198 {
	u64 seqnum;
	struct vm_area_struct___198 *vmas[4];
};

struct page_frag___198 {
	struct page___198 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___199;

struct pid___171;

struct nsproxy___180;

struct signal_struct___194;

struct bio_list___97;

struct backing_dev_info___90;

struct io_context___97;

struct css_set___132;

struct mem_cgroup___81;

struct request_queue___97;

struct vm_struct___176;

struct task_struct___200 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___200 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___199 *mm;
	struct mm_struct___199 *active_mm;
	struct vmacache___198 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___200 *real_parent;
	struct task_struct___200 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___200 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___171 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___180 *nsproxy;
	struct signal_struct___194 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___200 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___97 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___90 *backing_dev_info;
	struct io_context___97 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___132 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___198 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___81 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___81 *active_memcg;
	struct request_queue___97 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___200 *oom_reaper_list;
	struct vm_struct___176 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___181;

struct kobj_type___181;

struct kernfs_node___181;

struct kobject___181 {
	const char *name;
	struct list_head entry;
	struct kobject___181 *parent;
	struct kset___181 *kset;
	struct kobj_type___181 *ktype;
	struct kernfs_node___181 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___177 {
	struct kobject___181 kobj;
	struct module___177 *mod;
	struct kobject___181 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___177 {
	struct module___177 *mod;
	struct latch_tree_node node;
};

struct module_layout___177 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___177 mtn;
};

struct module_attribute___177;

struct kernel_param___177;

struct module___177 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___177 mkobj;
	struct module_attribute___177 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___181 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___177 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___177 core_layout;
	struct module_layout___177 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___171;

struct upid___171 {
	int nr;
	struct pid_namespace___171 *ns;
};

struct pid_namespace___171 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___200 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___171 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___171 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___171 numbers[1];
};

typedef struct page___198 *pgtable_t___198;

struct address_space___193;

struct dev_pagemap___188;

struct page___198 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___193 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___198 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___198 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___199 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___188 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___188;

struct vm_area_struct___198 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___198 *vm_next;
	struct vm_area_struct___198 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___199 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___188 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___193 *vm_file;
	struct file___193 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___194 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___200 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___200 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___171 *pids[4];
	struct pid___171 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___199 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___198;

struct mm_struct___199 {
	struct {
		struct vm_area_struct___198 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___193 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___198 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___200 *owner;
		struct user_namespace___25 *user_ns;
		struct file___193 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___132;

struct nsproxy___180 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___171 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___132 *cgroup_ns;
};

struct bio___97;

struct bio_list___97 {
	struct bio___97 *head;
	struct bio___97 *tail;
};

struct cgroup_subsys_state___132;

struct bdi_writeback___90 {
	struct backing_dev_info___90 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___132 *memcg_css;
	struct cgroup_subsys_state___132 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___152;

struct backing_dev_info___90 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___90 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___152 *dev;
	char dev_name[64];
	struct device___152 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___193 *debug_dir;
};

struct io_cq___97;

struct io_context___97 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___97 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___132;

struct css_set___132 {
	struct cgroup_subsys_state___132 *subsys[14];
	refcount_t refcount;
	struct css_set___132 *dom_cset;
	struct cgroup___132 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___132 *mg_src_cgrp;
	struct cgroup___132 *mg_dst_cgrp;
	struct css_set___132 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___132;

struct cgroup_subsys_state___132 {
	struct cgroup___132 *cgroup;
	struct cgroup_subsys___132 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___132 *parent;
};

struct cgroup_file___132 {
	struct kernfs_node___181 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___81;

struct mem_cgroup_per_node___81;

struct mem_cgroup___81 {
	struct cgroup_subsys_state___132 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___132 events_file;
	struct cgroup_file___132 events_local_file;
	struct cgroup_file___132 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___81 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___200 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___81 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___97;

struct blk_integrity___97 {
	const struct blk_integrity_profile___97 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___97 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___97 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___97;

struct elevator_queue___97;

struct blk_mq_ops___94;

struct blk_mq_hw_ctx___94;

struct gendisk___98;

struct blkcg_gq___92;

struct blk_mq_tag_set___94;

struct request_queue___97 {
	struct request___97 *last_merge;
	struct elevator_queue___97 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___94 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___94 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___98 *disk;
	struct kobject___181 kobj;
	struct kobject___181 *mq_kobj;
	struct blk_integrity___97 integrity;
	struct device___152 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___92 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___94 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___97 bio_split;
	struct dentry___193 *debugfs_dir;
	struct dentry___193 *sched_debugfs_dir;
	struct dentry___193 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___176 {
	struct vm_struct___176 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___198 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct irq_desc___35;

typedef void (*irq_flow_handler_t___35)(struct irq_desc___35 *);

struct msi_desc___12;

struct irq_common_data___12 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___12 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___34;

struct irq_domain___33;

struct irq_data___34 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___34 *chip;
	struct irq_domain___33 *domain;
	struct irq_data___34 *parent_data;
	void *chip_data;
};

struct irqaction___24;

struct irq_desc___35 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___34 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___35 handle_irq;
	struct irqaction___24 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___181 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___177 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___193;

struct address_space___193 {
	struct inode___193 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___193 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___188;

struct dev_pagemap___188 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___188 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___193;

struct path___193 {
	struct vfsmount___193 *mnt;
	struct dentry___193 *dentry;
};

struct fown_struct___171 {
	rwlock_t lock;
	struct pid___171 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___193 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___193 f_path;
	struct inode___193 *f_inode;
	const struct file_operations___194 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___171 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___193 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___188;

struct vm_operations_struct___188 {
	void (*open)(struct vm_area_struct___198 *);
	void (*close)(struct vm_area_struct___198 *);
	int (*may_split)(struct vm_area_struct___198 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___198 *);
	int (*mprotect)(struct vm_area_struct___198 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___188 *);
	vm_fault_t (*huge_fault)(struct vm_fault___188 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___188 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___198 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___188 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___188 *);
	int (*access)(struct vm_area_struct___198 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___198 *);
	int (*set_policy)(struct vm_area_struct___198 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___198 *, long unsigned int);
	struct page___198 * (*find_special_page)(struct vm_area_struct___198 *, long unsigned int);
};

struct core_thread___198 {
	struct task_struct___200 *task;
	struct core_thread___198 *next;
};

struct core_state___198 {
	atomic_t nr_threads;
	struct core_thread___198 dumper;
	struct completion startup;
};

struct vm_fault___188 {
	const struct {
		struct vm_area_struct___198 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___198 *cow_page;
	struct page___198 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___198 prealloc_pte;
};

struct pglist_data___88;

struct lruvec___88 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___88 *pgdat;
};

struct zone___88 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___88 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___88 {
	struct zone___88 *zone;
	int zone_idx;
};

struct zonelist___88 {
	struct zoneref___88 _zonerefs[321];
};

struct pglist_data___88 {
	struct zone___88 node_zones[5];
	struct zonelist___88 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___200 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___200 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___88 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct fwnode_operations___152;

struct fwnode_handle___152 {
	struct fwnode_handle___152 *secondary;
	const struct fwnode_operations___152 *ops;
	struct device___152 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___152;

struct fwnode_endpoint___152;

struct fwnode_operations___152 {
	struct fwnode_handle___152 * (*get)(struct fwnode_handle___152 *);
	void (*put)(struct fwnode_handle___152 *);
	bool (*device_is_available)(const struct fwnode_handle___152 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___152 *, const struct device___152 *);
	bool (*property_present)(const struct fwnode_handle___152 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___152 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___152 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___152 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*get_parent)(const struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*get_next_child_node)(const struct fwnode_handle___152 *, struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*get_named_child_node)(const struct fwnode_handle___152 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___152 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___152 *);
	struct fwnode_handle___152 * (*graph_get_next_endpoint)(const struct fwnode_handle___152 *, struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*graph_get_remote_endpoint)(const struct fwnode_handle___152 *);
	struct fwnode_handle___152 * (*graph_get_port_parent)(struct fwnode_handle___152 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___152 *, struct fwnode_endpoint___152 *);
	int (*add_links)(struct fwnode_handle___152 *);
};

struct wakeup_source___152;

struct dev_pm_info___152 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___152 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___152 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___152;

struct bus_type___152;

struct device_driver___152;

struct dev_pm_domain___152;

struct device_node___54;

struct class___152;

struct attribute_group___181;

struct device___152 {
	struct kobject___181 kobj;
	struct device___152 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___152 *type;
	struct bus_type___152 *bus;
	struct device_driver___152 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___152 power;
	struct dev_pm_domain___152 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___33 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___54 *of_node;
	struct fwnode_handle___152 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___152 *class;
	const struct attribute_group___181 **groups;
	void (*release)(struct device___152 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___152 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___152 *local_fwnode;
};

struct fwnode_reference_args___152 {
	struct fwnode_handle___152 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msi_desc___12 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___152 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___12 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___34 {
	struct device___152 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___34 *);
	void (*irq_shutdown)(struct irq_data___34 *);
	void (*irq_enable)(struct irq_data___34 *);
	void (*irq_disable)(struct irq_data___34 *);
	void (*irq_ack)(struct irq_data___34 *);
	void (*irq_mask)(struct irq_data___34 *);
	void (*irq_mask_ack)(struct irq_data___34 *);
	void (*irq_unmask)(struct irq_data___34 *);
	void (*irq_eoi)(struct irq_data___34 *);
	int (*irq_set_affinity)(struct irq_data___34 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___34 *);
	int (*irq_set_type)(struct irq_data___34 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___34 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___34 *);
	void (*irq_bus_sync_unlock)(struct irq_data___34 *);
	void (*irq_cpu_online)(struct irq_data___34 *);
	void (*irq_cpu_offline)(struct irq_data___34 *);
	void (*irq_suspend)(struct irq_data___34 *);
	void (*irq_resume)(struct irq_data___34 *);
	void (*irq_pm_shutdown)(struct irq_data___34 *);
	void (*irq_calc_mask)(struct irq_data___34 *);
	void (*irq_print_chip)(struct irq_data___34 *, struct seq_file___169 *);
	int (*irq_request_resources)(struct irq_data___34 *);
	void (*irq_release_resources)(struct irq_data___34 *);
	void (*irq_compose_msi_msg)(struct irq_data___34 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___34 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___34 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___34 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___34 *, void *);
	void (*ipi_send_single)(struct irq_data___34 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___34 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___34 *);
	void (*irq_nmi_teardown)(struct irq_data___34 *);
	long unsigned int flags;
};

struct irq_domain_ops___33;

struct irq_domain_chip_generic___33;

struct irq_domain___33 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___33 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___152 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___33 *gc;
	struct irq_domain___33 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___34 *revmap[0];
};

struct seq_operations___169;

struct seq_file___169 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___169 *op;
	int poll_event;
	const struct file___193 *file;
	void *private;
};

struct kernfs_root___181;

struct kernfs_elem_dir___181 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___181 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___181;

struct kernfs_root___181 {
	struct kernfs_node___181 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___181 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___181 {
	struct kernfs_node___181 *target_kn;
};

struct kernfs_ops___181;

struct kernfs_elem_attr___181 {
	const struct kernfs_ops___181 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___181 *notify_next;
};

struct kernfs_node___181 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___181 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___181 dir;
		struct kernfs_elem_symlink___181 symlink;
		struct kernfs_elem_attr___181 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___181;

struct kernfs_ops___181 {
	int (*open)(struct kernfs_open_file___181 *);
	void (*release)(struct kernfs_open_file___181 *);
	int (*seq_show)(struct seq_file___169 *, void *);
	void * (*seq_start)(struct seq_file___169 *, loff_t *);
	void * (*seq_next)(struct seq_file___169 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___169 *, void *);
	ssize_t (*read)(struct kernfs_open_file___181 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___181 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___181 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___181 *, struct vm_area_struct___198 *);
};

struct kernfs_syscall_ops___181 {
	int (*show_options)(struct seq_file___169 *, struct kernfs_root___181 *);
	int (*mkdir)(struct kernfs_node___181 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___181 *);
	int (*rename)(struct kernfs_node___181 *, struct kernfs_node___181 *, const char *);
	int (*show_path)(struct seq_file___169 *, struct kernfs_node___181 *, struct kernfs_root___181 *);
};

struct kernfs_open_file___181 {
	struct kernfs_node___181 *kn;
	struct file___193 *file;
	struct seq_file___169 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___188 *vm_ops;
};

struct bin_attribute___181;

struct attribute_group___181 {
	const char *name;
	umode_t (*is_visible)(struct kobject___181 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___181 *, struct bin_attribute___181 *, int);
	struct attribute **attrs;
	struct bin_attribute___181 **bin_attrs;
};

struct bin_attribute___181 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___193 * (*f_mapping)();
	ssize_t (*read)(struct file___193 *, struct kobject___181 *, struct bin_attribute___181 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___193 *, struct kobject___181 *, struct bin_attribute___181 *, char *, loff_t, size_t);
	int (*mmap)(struct file___193 *, struct kobject___181 *, struct bin_attribute___181 *, struct vm_area_struct___198 *);
};

struct sysfs_ops___181 {
	ssize_t (*show)(struct kobject___181 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___181 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___181;

struct kset___181 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___181 kobj;
	const struct kset_uevent_ops___181 *uevent_ops;
};

struct kobj_type___181 {
	void (*release)(struct kobject___181 *);
	const struct sysfs_ops___181 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___181 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___181 *);
	const void * (*namespace)(struct kobject___181 *);
	void (*get_ownership)(struct kobject___181 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___181 {
	int (* const filter)(struct kset___181 *, struct kobject___181 *);
	const char * (* const name)(struct kset___181 *, struct kobject___181 *);
	int (* const uevent)(struct kset___181 *, struct kobject___181 *, struct kobj_uevent_env *);
};

struct irqaction___24 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___24 *next;
	irq_handler_t thread_fn;
	struct task_struct___200 *thread;
	struct irqaction___24 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___33 {
	struct irq_chip___34 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___35 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___33 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___33 *);
	void (*resume)(struct irq_chip_generic___33 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___33 *domain;
	struct list_head list;
	struct irq_chip_type___33 chip_types[0];
};

struct irq_domain_chip_generic___33 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___33 *gc[0];
};

struct dev_pm_ops___152 {
	int (*prepare)(struct device___152 *);
	void (*complete)(struct device___152 *);
	int (*suspend)(struct device___152 *);
	int (*resume)(struct device___152 *);
	int (*freeze)(struct device___152 *);
	int (*thaw)(struct device___152 *);
	int (*poweroff)(struct device___152 *);
	int (*restore)(struct device___152 *);
	int (*suspend_late)(struct device___152 *);
	int (*resume_early)(struct device___152 *);
	int (*freeze_late)(struct device___152 *);
	int (*thaw_early)(struct device___152 *);
	int (*poweroff_late)(struct device___152 *);
	int (*restore_early)(struct device___152 *);
	int (*suspend_noirq)(struct device___152 *);
	int (*resume_noirq)(struct device___152 *);
	int (*freeze_noirq)(struct device___152 *);
	int (*thaw_noirq)(struct device___152 *);
	int (*poweroff_noirq)(struct device___152 *);
	int (*restore_noirq)(struct device___152 *);
	int (*runtime_suspend)(struct device___152 *);
	int (*runtime_resume)(struct device___152 *);
	int (*runtime_idle)(struct device___152 *);
};

struct wakeup_source___152 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___152 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___152 {
	struct dev_pm_ops___152 ops;
	int (*start)(struct device___152 *);
	void (*detach)(struct device___152 *, bool);
	int (*activate)(struct device___152 *);
	void (*sync)(struct device___152 *);
	void (*dismiss)(struct device___152 *);
};

struct bus_type___152 {
	const char *name;
	const char *dev_name;
	struct device___152 *dev_root;
	const struct attribute_group___181 **bus_groups;
	const struct attribute_group___181 **dev_groups;
	const struct attribute_group___181 **drv_groups;
	int (*match)(struct device___152 *, struct device_driver___152 *);
	int (*uevent)(struct device___152 *, struct kobj_uevent_env *);
	int (*probe)(struct device___152 *);
	void (*sync_state)(struct device___152 *);
	void (*remove)(struct device___152 *);
	void (*shutdown)(struct device___152 *);
	int (*online)(struct device___152 *);
	int (*offline)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	int (*num_vf)(struct device___152 *);
	int (*dma_configure)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___152 {
	const char *name;
	struct bus_type___152 *bus;
	struct module___177 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___152 *);
	void (*sync_state)(struct device___152 *);
	int (*remove)(struct device___152 *);
	void (*shutdown)(struct device___152 *);
	int (*suspend)(struct device___152 *, pm_message_t);
	int (*resume)(struct device___152 *);
	const struct attribute_group___181 **groups;
	const struct attribute_group___181 **dev_groups;
	const struct dev_pm_ops___152 *pm;
	void (*coredump)(struct device___152 *);
	struct driver_private *p;
};

struct device_type___152 {
	const char *name;
	const struct attribute_group___181 **groups;
	int (*uevent)(struct device___152 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___152 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___152 *);
	const struct dev_pm_ops___152 *pm;
};

struct class___152 {
	const char *name;
	struct module___177 *owner;
	const struct attribute_group___181 **class_groups;
	const struct attribute_group___181 **dev_groups;
	struct kobject___181 *dev_kobj;
	int (*dev_uevent)(struct device___152 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___152 *, umode_t *);
	void (*class_release)(struct class___152 *);
	void (*dev_release)(struct device___152 *);
	int (*shutdown_pre)(struct device___152 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___152 *);
	void (*get_ownership)(struct device___152 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___152 *pm;
	struct subsys_private *p;
};

struct property___43;

struct device_node___54 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___152 fwnode;
	struct property___43 *properties;
	struct property___43 *deadprops;
	struct device_node___54 *parent;
	struct device_node___54 *child;
	struct device_node___54 *sibling;
	struct kobject___181 kobj;
	long unsigned int _flags;
	void *data;
};

struct platform_device___18 {
	const char *name;
	int id;
	bool id_auto;
	struct device___152 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___17 {
	int (*probe)(struct platform_device___18 *);
	int (*remove)(struct platform_device___18 *);
	void (*shutdown)(struct platform_device___18 *);
	int (*suspend)(struct platform_device___18 *, pm_message_t);
	int (*resume)(struct platform_device___18 *);
	struct device_driver___152 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct property___43 {
	char *name;
	int length;
	void *value;
	struct property___43 *next;
	long unsigned int _flags;
	struct bin_attribute___181 attr;
};

struct irq_fwspec___31 {
	struct fwnode_handle___152 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___33 {
	int (*match)(struct irq_domain___33 *, struct device_node___54 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___33 *, struct irq_fwspec___31 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___33 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___33 *, unsigned int);
	int (*xlate)(struct irq_domain___33 *, struct device_node___54 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___33 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___33 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___33 *, struct irq_data___34 *, bool);
	void (*deactivate)(struct irq_domain___33 *, struct irq_data___34 *);
	int (*translate)(struct irq_domain___33 *, struct irq_fwspec___31 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___193;

struct dentry___193 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___193 *d_parent;
	struct qstr d_name;
	struct inode___193 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___193 *d_op;
	struct super_block___193 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___193;

struct inode___193 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___193 *i_op;
	struct super_block___193 *i_sb;
	struct address_space___193 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___90 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___194 *i_fop;
		void (*free_inode)(struct inode___193 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___193 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___40 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___193 {
	int (*d_revalidate)(struct dentry___193 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___193 *, unsigned int);
	int (*d_hash)(const struct dentry___193 *, struct qstr *);
	int (*d_compare)(const struct dentry___193 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___193 *);
	int (*d_init)(struct dentry___193 *);
	void (*d_release)(struct dentry___193 *);
	void (*d_prune)(struct dentry___193 *);
	void (*d_iput)(struct dentry___193 *, struct inode___193 *);
	char * (*d_dname)(struct dentry___193 *, char *, int);
	struct vfsmount___193 * (*d_automount)(struct path___193 *);
	int (*d_manage)(const struct path___193 *, bool);
	struct dentry___193 * (*d_real)(struct dentry___193 *, const struct inode___193 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___193;

struct mem_dqinfo___193 {
	struct quota_format_type___193 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___193;

struct quota_info___193 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___193 *files[3];
	struct mem_dqinfo___193 info[3];
	const struct quota_format_ops___193 *ops[3];
};

struct rcuwait___194 {
	struct task_struct___200 *task;
};

struct percpu_rw_semaphore___194 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___194 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___193 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___194 rw_sem[3];
};

struct shrink_control___81;

struct shrinker___81 {
	long unsigned int (*count_objects)(struct shrinker___81 *, struct shrink_control___81 *);
	long unsigned int (*scan_objects)(struct shrinker___81 *, struct shrink_control___81 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___193;

struct dquot_operations___193;

struct quotactl_ops___193;

struct block_device___98;

struct super_block___193 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___193 *s_type;
	const struct super_operations___193 *s_op;
	const struct dquot_operations___193 *dq_op;
	const struct quotactl_ops___193 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___193 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___98 *s_bdev;
	struct backing_dev_info___90 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___193 s_dquot;
	struct sb_writers___193 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___193 *s_d_op;
	int cleancache_poolid;
	struct shrinker___81 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___193 {
	struct dentry___193 *mnt_root;
	struct super_block___193 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___81 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___81 *memcg;
};

struct psi_group___132 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___200 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___132;

struct cgroup_rstat_cpu___132;

struct cgroup___132 {
	struct cgroup_subsys_state___132 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___181 *kn;
	struct cgroup_file___132 procs_file;
	struct cgroup_file___132 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___132 *subsys[14];
	struct cgroup_root___132 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___132 *dom_cgrp;
	struct cgroup___132 *old_dom_cgrp;
	struct cgroup_rstat_cpu___132 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___132 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___97 {
	struct request_queue___97 *q;
	struct io_context___97 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___90;

struct kiocb___193 {
	struct file___193 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___193 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___90 *ki_waitq;
	};
};

struct iattr___193 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___193 *ia_file;
};

struct dquot___193 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___193 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___193 {
	int qf_fmt_id;
	const struct quota_format_ops___193 *qf_ops;
	struct module___177 *qf_owner;
	struct quota_format_type___193 *qf_next;
};

struct quota_format_ops___193 {
	int (*check_quota_file)(struct super_block___193 *, int);
	int (*read_file_info)(struct super_block___193 *, int);
	int (*write_file_info)(struct super_block___193 *, int);
	int (*free_file_info)(struct super_block___193 *, int);
	int (*read_dqblk)(struct dquot___193 *);
	int (*commit_dqblk)(struct dquot___193 *);
	int (*release_dqblk)(struct dquot___193 *);
	int (*get_next_id)(struct super_block___193 *, struct kqid *);
};

struct dquot_operations___193 {
	int (*write_dquot)(struct dquot___193 *);
	struct dquot___193 * (*alloc_dquot)(struct super_block___193 *, int);
	void (*destroy_dquot)(struct dquot___193 *);
	int (*acquire_dquot)(struct dquot___193 *);
	int (*release_dquot)(struct dquot___193 *);
	int (*mark_dirty)(struct dquot___193 *);
	int (*write_info)(struct super_block___193 *, int);
	qsize_t * (*get_reserved_space)(struct inode___193 *);
	int (*get_projid)(struct inode___193 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___193 *, qsize_t *);
	int (*get_next_id)(struct super_block___193 *, struct kqid *);
};

struct quotactl_ops___193 {
	int (*quota_on)(struct super_block___193 *, int, int, const struct path___193 *);
	int (*quota_off)(struct super_block___193 *, int);
	int (*quota_enable)(struct super_block___193 *, unsigned int);
	int (*quota_disable)(struct super_block___193 *, unsigned int);
	int (*quota_sync)(struct super_block___193 *, int);
	int (*set_info)(struct super_block___193 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___193 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___193 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___193 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___193 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___193 *, unsigned int);
};

struct wait_page_queue___90 {
	struct page___198 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___90;

struct readahead_control___90;

struct swap_info_struct___49;

struct address_space_operations___193 {
	int (*writepage)(struct page___198 *, struct writeback_control___90 *);
	int (*readpage)(struct file___193 *, struct page___198 *);
	int (*writepages)(struct address_space___193 *, struct writeback_control___90 *);
	int (*set_page_dirty)(struct page___198 *);
	int (*readpages)(struct file___193 *, struct address_space___193 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___90 *);
	int (*write_begin)(struct file___193 *, struct address_space___193 *, loff_t, unsigned int, unsigned int, struct page___198 **, void **);
	int (*write_end)(struct file___193 *, struct address_space___193 *, loff_t, unsigned int, unsigned int, struct page___198 *, void *);
	sector_t (*bmap)(struct address_space___193 *, sector_t);
	void (*invalidatepage)(struct page___198 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___198 *, gfp_t);
	void (*freepage)(struct page___198 *);
	ssize_t (*direct_IO)(struct kiocb___193 *, struct iov_iter___115 *);
	int (*migratepage)(struct address_space___193 *, struct page___198 *, struct page___198 *, enum migrate_mode);
	bool (*isolate_page)(struct page___198 *, isolate_mode_t);
	void (*putback_page)(struct page___198 *);
	int (*launder_page)(struct page___198 *);
	int (*is_partially_uptodate)(struct page___198 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___198 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___193 *, struct page___198 *);
	int (*swap_activate)(struct swap_info_struct___49 *, struct file___193 *, sector_t *);
	void (*swap_deactivate)(struct file___193 *);
};

struct writeback_control___90 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___90 *wb;
	struct inode___193 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___90 {
	struct file___193 *file;
	struct address_space___193 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___113;

struct iov_iter___115 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___113 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___49 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___98 *bdev;
	struct file___193 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___193 {
	struct dentry___193 * (*lookup)(struct inode___193 *, struct dentry___193 *, unsigned int);
	const char * (*get_link)(struct dentry___193 *, struct inode___193 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___193 *, int);
	struct posix_acl * (*get_acl)(struct inode___193 *, int, bool);
	int (*readlink)(struct dentry___193 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___193 *, struct dentry___193 *, umode_t, bool);
	int (*link)(struct dentry___193 *, struct inode___193 *, struct dentry___193 *);
	int (*unlink)(struct inode___193 *, struct dentry___193 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___193 *, struct dentry___193 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___193 *, struct dentry___193 *, umode_t);
	int (*rmdir)(struct inode___193 *, struct dentry___193 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___193 *, struct dentry___193 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___193 *, struct dentry___193 *, struct inode___193 *, struct dentry___193 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___193 *, struct iattr___193 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___193 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___193 *, char *, size_t);
	int (*fiemap)(struct inode___193 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___193 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___193 *, struct dentry___193 *, struct file___193 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___193 *, struct dentry___193 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___193 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___193 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___193 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___193 {
	void (*fl_copy_lock)(struct file_lock___193 *, struct file_lock___193 *);
	void (*fl_release_private)(struct file_lock___193 *);
};

struct fasync_struct___193;

struct lock_manager_operations___193;

struct file_lock___193 {
	struct file_lock___193 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___193 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___193 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___193 *fl_ops;
	const struct lock_manager_operations___193 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___193 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___193 *);
	int (*lm_grant)(struct file_lock___193 *, int);
	bool (*lm_break)(struct file_lock___193 *);
	int (*lm_change)(struct file_lock___193 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___193 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___193 *);
};

struct fasync_struct___193 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___193 *fa_next;
	struct file___193 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___193 {
	struct inode___193 * (*alloc_inode)(struct super_block___193 *);
	void (*destroy_inode)(struct inode___193 *);
	void (*free_inode)(struct inode___193 *);
	void (*dirty_inode)(struct inode___193 *, int);
	int (*write_inode)(struct inode___193 *, struct writeback_control___90 *);
	int (*drop_inode)(struct inode___193 *);
	void (*evict_inode)(struct inode___193 *);
	void (*put_super)(struct super_block___193 *);
	int (*sync_fs)(struct super_block___193 *, int);
	int (*freeze_super)(struct super_block___193 *);
	int (*freeze_fs)(struct super_block___193 *);
	int (*thaw_super)(struct super_block___193 *);
	int (*unfreeze_fs)(struct super_block___193 *);
	int (*statfs)(struct dentry___193 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___193 *, int *, char *);
	void (*umount_begin)(struct super_block___193 *);
	int (*show_options)(struct seq_file___169 *, struct dentry___193 *);
	int (*show_devname)(struct seq_file___169 *, struct dentry___193 *);
	int (*show_path)(struct seq_file___169 *, struct dentry___193 *);
	int (*show_stats)(struct seq_file___169 *, struct dentry___193 *);
	ssize_t (*quota_read)(struct super_block___193 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___193 *, int, const char *, size_t, loff_t);
	struct dquot___193 ** (*get_dquots)(struct inode___193 *);
	long int (*nr_cached_objects)(struct super_block___193 *, struct shrink_control___81 *);
	long int (*free_cached_objects)(struct super_block___193 *, struct shrink_control___81 *);
	struct file___193 * (*real_loop)(struct file___193 *);
};

struct block_device___98 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___193 *bd_inode;
	struct super_block___193 *bd_super;
	void *bd_claiming;
	struct device___152 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___181 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___98 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___193 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___97(struct bio___97 *);

struct bio_vec___113 {
	struct page___198 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___97;

struct bio___97 {
	struct bio___97 *bi_next;
	struct block_device___98 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___97 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___92 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___97 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___113 *bi_io_vec;
	struct bio_set___97 *bi_pool;
	struct bio_vec___113 bi_inline_vecs[0];
};

struct seq_operations___169 {
	void * (*start)(struct seq_file___169 *, loff_t *);
	void (*stop)(struct seq_file___169 *, void *);
	void * (*next)(struct seq_file___169 *, void *, loff_t *);
	int (*show)(struct seq_file___169 *, void *);
};

struct pci_bus___11;

struct pci_slot___11 {
	struct pci_bus___11 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___181 kobj;
};

struct pci_dev___11;

struct pci_ops___11;

struct pci_bus___11 {
	struct list_head node;
	struct pci_bus___11 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___11 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___11 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___152 *bridge;
	struct device___152 dev;
	struct bin_attribute___181 *legacy_io;
	struct bin_attribute___181 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_sriov___8 {
	int pos;
	int nres;
	u32 cap;
	u16 ctrl;
	u16 total_VFs;
	u16 initial_VFs;
	u16 num_VFs;
	u16 offset;
	u16 stride;
	u16 vf_device;
	u32 pgsz;
	u8 link;
	u8 max_VF_buses;
	u16 driver_max_VFs;
	struct pci_dev___11 *dev;
	struct pci_dev___11 *self;
	u32 class;
	u8 hdr_type;
	u16 subsystem_vendor;
	u16 subsystem_device;
	resource_size_t barsz[6];
	bool drivers_autoprobe;
};

struct pci_driver___11;

struct pci_dev___11 {
	struct list_head bus_list;
	struct pci_bus___11 *bus;
	struct pci_bus___11 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___11 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___11 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___11 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___152 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___181 *res_attr[17];
	struct bin_attribute___181 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___181 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov___8 *sriov;
		struct pci_dev___11 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___11;

struct pci_driver___11 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___11 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___11 *);
	int (*suspend)(struct pci_dev___11 *, pm_message_t);
	int (*resume)(struct pci_dev___11 *);
	void (*shutdown)(struct pci_dev___11 *);
	int (*sriov_configure)(struct pci_dev___11 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___11 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___11 *);
	const struct pci_error_handlers___11 *err_handler;
	const struct attribute_group___181 **groups;
	const struct attribute_group___181 **dev_groups;
	struct device_driver___152 driver;
	struct pci_dynids dynids;
};

struct pci_host_bridge___8 {
	struct device___152 dev;
	struct pci_bus___11 *bus;
	struct pci_ops___11 *ops;
	struct pci_ops___11 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___11 *, u8 *);
	int (*map_irq)(const struct pci_dev___11 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___8 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___11 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___11 {
	int (*add_bus)(struct pci_bus___11 *);
	void (*remove_bus)(struct pci_bus___11 *);
	void * (*map_bus)(struct pci_bus___11 *, unsigned int, int);
	int (*read)(struct pci_bus___11 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___11 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___11 {
	pci_ers_result_t (*error_detected)(struct pci_dev___11 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___11 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___11 *);
	void (*reset_prepare)(struct pci_dev___11 *);
	void (*reset_done)(struct pci_dev___11 *);
	void (*resume)(struct pci_dev___11 *);
};

struct dev_pagemap_ops___188 {
	void (*page_free)(struct page___198 *);
	void (*kill)(struct dev_pagemap___188 *);
	void (*cleanup)(struct dev_pagemap___188 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___188 *);
};

struct cgroup_namespace___132 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___132 *root_cset;
};

struct kernel_param_ops___177 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___177 *);
	int (*get)(char *, const struct kernel_param___177 *);
	void (*free)(void *);
};

struct kparam_array___177;

struct kernel_param___177 {
	const char *name;
	struct module___177 *mod;
	const struct kernel_param_ops___177 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___177 *arr;
	};
};

struct kparam_array___177 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___177 *ops;
	void *elem;
};

struct module_attribute___177 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___177 *, struct module_kobject___177 *, char *);
	ssize_t (*store)(struct module_attribute___177 *, struct module_kobject___177 *, const char *, size_t);
	void (*setup)(struct module___177 *, const char *);
	int (*test)(struct module___177 *);
	void (*free)(struct module___177 *);
};

struct cftype___132;

struct cgroup_subsys___132 {
	struct cgroup_subsys_state___132 * (*css_alloc)(struct cgroup_subsys_state___132 *);
	int (*css_online)(struct cgroup_subsys_state___132 *);
	void (*css_offline)(struct cgroup_subsys_state___132 *);
	void (*css_released)(struct cgroup_subsys_state___132 *);
	void (*css_free)(struct cgroup_subsys_state___132 *);
	void (*css_reset)(struct cgroup_subsys_state___132 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___132 *, int);
	int (*css_extra_stat_show)(struct seq_file___169 *, struct cgroup_subsys_state___132 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___200 *, struct css_set___132 *);
	void (*cancel_fork)(struct task_struct___200 *, struct css_set___132 *);
	void (*fork)(struct task_struct___200 *);
	void (*exit)(struct task_struct___200 *);
	void (*release)(struct task_struct___200 *);
	void (*bind)(struct cgroup_subsys_state___132 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___132 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___132 *dfl_cftypes;
	struct cftype___132 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___132 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___132 *updated_children;
	struct cgroup___132 *updated_next;
};

struct cgroup_root___132 {
	struct kernfs_root___181 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___132 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___132 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___132 *ss;
	struct list_head node;
	struct kernfs_ops___181 *kf_ops;
	int (*open)(struct kernfs_open_file___181 *);
	void (*release)(struct kernfs_open_file___181 *);
	u64 (*read_u64)(struct cgroup_subsys_state___132 *, struct cftype___132 *);
	s64 (*read_s64)(struct cgroup_subsys_state___132 *, struct cftype___132 *);
	int (*seq_show)(struct seq_file___169 *, void *);
	void * (*seq_start)(struct seq_file___169 *, loff_t *);
	void * (*seq_next)(struct seq_file___169 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___169 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___132 *, struct cftype___132 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___132 *, struct cftype___132 *, s64);
	ssize_t (*write)(struct kernfs_open_file___181 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___181 *, struct poll_table_struct___5 *);
};

struct block_device_operations___97;

struct gendisk___98 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___98 *part0;
	const struct block_device_operations___97 *fops;
	struct request_queue___97 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___90 *bdi;
	struct kobject___181 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___181 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___97 {
	struct bio___97 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___113 *bip_vec;
	struct bio_vec___113 bip_inline_vecs[0];
};

struct blkcg___92;

struct blkg_policy_data___92;

struct blkcg_gq___92 {
	struct request_queue___97 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___92 *blkcg;
	struct blkcg_gq___92 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___92 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___97 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___97(struct request___97 *);

typedef void integrity_complete_fn___97(struct request___97 *, unsigned int);

struct blk_integrity_profile___97 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___97 *prepare_fn;
	integrity_complete_fn___97 *complete_fn;
	const char *name;
};

struct block_device_operations___97 {
	blk_qc_t (*submit_bio)(struct bio___97 *);
	int (*open)(struct block_device___98 *, fmode_t);
	void (*release)(struct gendisk___98 *, fmode_t);
	int (*rw_page)(struct block_device___98 *, sector_t, struct page___198 *, unsigned int);
	int (*ioctl)(struct block_device___98 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___98 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___98 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___98 *);
	int (*getgeo)(struct block_device___98 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___98 *, bool);
	void (*swap_slot_free_notify)(struct block_device___98 *, long unsigned int);
	int (*report_zones)(struct gendisk___98 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___98 *, umode_t *);
	struct module___177 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___98 *, sector_t *);
};

typedef void rq_end_io_fn___97(struct request___97 *, blk_status_t);

struct request___97 {
	struct request_queue___97 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___94 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___97 *bio;
	struct bio___97 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___113 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___97 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___97 *saved_end_io;
		} flush;
	};
	struct gendisk___98 *rq_disk;
	struct block_device___98 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___97 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___94 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___97 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___181 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___193 *debugfs_dir;
	struct dentry___193 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___97;

struct elevator_mq_ops___97 {
	int (*init_sched)(struct request_queue___97 *, struct elevator_type___97 *);
	void (*exit_sched)(struct elevator_queue___97 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___94 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___94 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___94 *);
	bool (*allow_merge)(struct request_queue___97 *, struct request___97 *, struct bio___97 *);
	bool (*bio_merge)(struct request_queue___97 *, struct bio___97 *, unsigned int);
	int (*request_merge)(struct request_queue___97 *, struct request___97 **, struct bio___97 *);
	void (*request_merged)(struct request_queue___97 *, struct request___97 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___97 *, struct request___97 *, struct request___97 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___97 *);
	void (*finish_request)(struct request___97 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___94 *, struct list_head *, bool);
	struct request___97 * (*dispatch_request)(struct blk_mq_hw_ctx___94 *);
	bool (*has_work)(struct blk_mq_hw_ctx___94 *);
	void (*completed_request)(struct request___97 *, u64);
	void (*requeue_request)(struct request___97 *);
	struct request___97 * (*former_request)(struct request_queue___97 *, struct request___97 *);
	struct request___97 * (*next_request)(struct request_queue___97 *, struct request___97 *);
	void (*init_icq)(struct io_cq___97 *);
	void (*exit_icq)(struct io_cq___97 *);
};

struct elv_fs_entry___97;

struct elevator_type___97 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___97 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___97 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___177 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___97 {
	struct elevator_type___97 *type;
	void *elevator_data;
	struct kobject___181 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___97 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___97 *, char *);
	ssize_t (*store)(struct elevator_queue___97 *, const char *, size_t);
};

struct blk_mq_queue_data___94;

struct blk_mq_ops___94 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___94 *, const struct blk_mq_queue_data___94 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___94 *);
	int (*get_budget)(struct request_queue___97 *);
	void (*put_budget)(struct request_queue___97 *, int);
	void (*set_rq_budget_token)(struct request___97 *, int);
	int (*get_rq_budget_token)(struct request___97 *);
	enum blk_eh_timer_return (*timeout)(struct request___97 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___94 *);
	void (*complete)(struct request___97 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___94 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___94 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___94 *, struct request___97 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___94 *, struct request___97 *, unsigned int);
	void (*initialize_rq_fn)(struct request___97 *);
	void (*cleanup_rq)(struct request___97 *);
	bool (*busy)(struct request_queue___97 *);
	int (*map_queues)(struct blk_mq_tag_set___94 *);
	void (*show_rq)(struct seq_file___169 *, struct request___97 *);
};

struct blk_mq_tag_set___94 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___94 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___94 {
	struct request___97 *rq;
	bool last;
};

struct blkcg_policy_data___92;

struct blkcg___92 {
	struct cgroup_subsys_state___132 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___92 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___92 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___92 {
	struct blkcg___92 *blkcg;
	int plid;
};

struct blkg_policy_data___92 {
	struct blkcg_gq___92 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___81 {
	struct mem_cgroup___81 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___81 {
	struct lruvec___88 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___81 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___81 *memcg;
};

struct obj_cgroup___81 {
	struct percpu_ref refcnt;
	struct mem_cgroup___81 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct phy___7;

struct phy_ops___6 {
	int (*init)(struct phy___7 *);
	int (*exit)(struct phy___7 *);
	int (*power_on)(struct phy___7 *);
	int (*power_off)(struct phy___7 *);
	int (*set_mode)(struct phy___7 *, enum phy_mode, int);
	int (*set_media)(struct phy___7 *, enum phy_media);
	int (*set_speed)(struct phy___7 *, int);
	int (*configure)(struct phy___7 *, union phy_configure_opts___2 *);
	int (*validate)(struct phy___7 *, enum phy_mode, int, union phy_configure_opts___2 *);
	int (*reset)(struct phy___7 *);
	int (*calibrate)(struct phy___7 *);
	void (*release)(struct phy___7 *);
	struct module___177 *owner;
};

struct phy___7 {
	struct device___152 dev;
	int id;
	const struct phy_ops___6 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct config_group___6;

struct config_item_type___6;

struct config_item___6 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___6 *ci_parent;
	struct config_group___6 *ci_group;
	const struct config_item_type___6 *ci_type;
	struct dentry___193 *ci_dentry;
};

struct configfs_subsystem___6;

struct config_group___6 {
	struct config_item___6 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___6 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___6;

struct configfs_group_operations___6;

struct configfs_attribute___6;

struct configfs_bin_attribute___6;

struct config_item_type___6 {
	struct module___177 *ct_owner;
	struct configfs_item_operations___6 *ct_item_ops;
	struct configfs_group_operations___6 *ct_group_ops;
	struct configfs_attribute___6 **ct_attrs;
	struct configfs_bin_attribute___6 **ct_bin_attrs;
};

struct configfs_item_operations___6 {
	void (*release)(struct config_item___6 *);
	int (*allow_link)(struct config_item___6 *, struct config_item___6 *);
	void (*drop_link)(struct config_item___6 *, struct config_item___6 *);
};

struct configfs_group_operations___6 {
	struct config_item___6 * (*make_item)(struct config_group___6 *, const char *);
	struct config_group___6 * (*make_group)(struct config_group___6 *, const char *);
	int (*commit_item)(struct config_item___6 *);
	void (*disconnect_notify)(struct config_group___6 *, struct config_item___6 *);
	void (*drop_item)(struct config_group___6 *, struct config_item___6 *);
};

struct configfs_attribute___6 {
	const char *ca_name;
	struct module___177 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___6 *, char *);
	ssize_t (*store)(struct config_item___6 *, const char *, size_t);
};

struct configfs_bin_attribute___6 {
	struct configfs_attribute___6 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___6 *, void *, size_t);
	ssize_t (*write)(struct config_item___6 *, const void *, size_t);
};

struct configfs_subsystem___6 {
	struct config_group___6 su_group;
	struct mutex su_mutex;
};

struct pci_epc_ops___7;

struct pci_epc___7 {
	struct device___152 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___7 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group___6 *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

struct pci_epc_ops___7 {
	int (*write_header)(struct pci_epc___7 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___7 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___7 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___7 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___7 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___7 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___7 *, u8, u8);
	int (*set_msix)(struct pci_epc___7 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___7 *, u8, u8);
	int (*raise_irq)(struct pci_epc___7 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___7 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___7 *);
	void (*stop)(struct pci_epc___7 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___7 *, u8, u8);
	struct module___177 *owner;
};

struct pcie_port___4;

struct dw_pcie_host_ops___4 {
	int (*host_init)(struct pcie_port___4 *);
	int (*msi_host_init)(struct pcie_port___4 *);
};

struct pcie_port___4 {
	bool has_msi_ctrl: 1;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	int irq;
	const struct dw_pcie_host_ops___4 *ops;
	int msi_irq;
	struct irq_domain___33 *irq_domain;
	struct irq_domain___33 *msi_domain;
	u16 msi_msg;
	dma_addr_t msi_data;
	struct irq_chip___34 *msi_irq_chip;
	u32 num_vectors;
	u32 irq_mask[8];
	struct pci_host_bridge___8 *bridge;
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

struct dw_pcie_ep___4;

struct dw_pcie_ep_ops___4 {
	void (*ep_init)(struct dw_pcie_ep___4 *);
	int (*raise_irq)(struct dw_pcie_ep___4 *, u8, enum pci_epc_irq_type, u16);
	const struct pci_epc_features * (*get_features)(struct dw_pcie_ep___4 *);
	unsigned int (*func_conf_select)(struct dw_pcie_ep___4 *, u8);
};

struct dw_pcie_ep___4 {
	struct pci_epc___7 *epc;
	struct list_head func_list;
	const struct dw_pcie_ep_ops___4 *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	struct pci_epf_bar___2 *epf_bar[6];
};

struct dw_pcie___5;

struct dw_pcie_ops___5 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___5 *, u64);
	u32 (*read_dbi)(struct dw_pcie___5 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___5 *, void *, u32, size_t, u32);
	void (*write_dbi2)(struct dw_pcie___5 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___5 *);
	int (*start_link)(struct dw_pcie___5 *);
	void (*stop_link)(struct dw_pcie___5 *);
};

struct dw_pcie___5 {
	struct device___152 *dev;
	void *dbi_base;
	void *dbi_base2;
	void *atu_base;
	size_t atu_size;
	u32 num_ib_windows;
	u32 num_ob_windows;
	struct pcie_port___4 pp;
	struct dw_pcie_ep___4 ep;
	const struct dw_pcie_ops___5 *ops;
	unsigned int version;
	int num_lanes;
	int link_gen;
	u8 n_fts[2];
	bool iatu_unroll_enabled: 1;
	bool io_cfg_atu_shared: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct qcom_pcie_resources_2_1_0 {
	struct clk_bulk_data clks[5];
	struct reset_control *pci_reset;
	struct reset_control *axi_reset;
	struct reset_control *ahb_reset;
	struct reset_control *por_reset;
	struct reset_control *phy_reset;
	struct reset_control *ext_reset;
	struct regulator_bulk_data supplies[3];
};

struct qcom_pcie_resources_1_0_0 {
	struct clk *iface;
	struct clk *aux;
	struct clk *master_bus;
	struct clk *slave_bus;
	struct reset_control *core;
	struct regulator *vdda;
};

struct qcom_pcie_resources_2_3_2 {
	struct clk *aux_clk;
	struct clk *master_clk;
	struct clk *slave_clk;
	struct clk *cfg_clk;
	struct clk *pipe_clk;
	struct regulator_bulk_data supplies[2];
};

struct qcom_pcie_resources_2_4_0 {
	struct clk_bulk_data clks[4];
	int num_clks;
	struct reset_control *axi_m_reset;
	struct reset_control *axi_s_reset;
	struct reset_control *pipe_reset;
	struct reset_control *axi_m_vmid_reset;
	struct reset_control *axi_s_xpu_reset;
	struct reset_control *parf_reset;
	struct reset_control *phy_reset;
	struct reset_control *axi_m_sticky_reset;
	struct reset_control *pipe_sticky_reset;
	struct reset_control *pwr_reset;
	struct reset_control *ahb_reset;
	struct reset_control *phy_ahb_reset;
};

struct qcom_pcie_resources_2_3_3 {
	struct clk *iface;
	struct clk *axi_m_clk;
	struct clk *axi_s_clk;
	struct clk *ahb_clk;
	struct clk *aux_clk;
	struct reset_control *rst[7];
};

struct qcom_pcie_resources_2_7_0 {
	struct clk_bulk_data clks[7];
	int num_clks;
	struct regulator_bulk_data supplies[2];
	struct reset_control *pci_reset;
	struct clk *pipe_clk;
};

union qcom_pcie_resources {
	struct qcom_pcie_resources_1_0_0 v1_0_0;
	struct qcom_pcie_resources_2_1_0 v2_1_0;
	struct qcom_pcie_resources_2_3_2 v2_3_2;
	struct qcom_pcie_resources_2_3_3 v2_3_3;
	struct qcom_pcie_resources_2_4_0 v2_4_0;
	struct qcom_pcie_resources_2_7_0 v2_7_0;
};

struct qcom_pcie;

struct qcom_pcie_ops {
	int (*get_resources)(struct qcom_pcie *);
	int (*init)(struct qcom_pcie *);
	int (*post_init)(struct qcom_pcie *);
	void (*deinit)(struct qcom_pcie *);
	void (*post_deinit)(struct qcom_pcie *);
	void (*ltssm_enable)(struct qcom_pcie *);
	int (*config_sid)(struct qcom_pcie *);
};

struct qcom_pcie {
	struct dw_pcie___5 *pci;
	void *parf;
	void *elbi;
	union qcom_pcie_resources res;
	struct phy___7 *phy;
	struct gpio_desc *reset;
	const struct qcom_pcie_ops *ops;
};

struct armada8k_pcie {
	struct dw_pcie___4 *pci;
	struct clk *clk;
	struct clk *clk_reg;
	struct phy___5 *phy[4];
	unsigned int phy_count;
};

struct rockchip_pcie___3 {
	struct dw_pcie___5 pci;
	void *apb_base;
	struct phy___7 *phy;
	struct clk_bulk_data *clks;
	unsigned int clk_cnt;
	struct reset_control *rst;
	struct gpio_desc *rst_gpio;
	struct regulator *vpcie3v3;
};

struct keembay_pcie {
	struct dw_pcie___5 pci;
	void *apb_base;
	enum dw_pcie_device_mode mode;
	struct clk *clk_master;
	struct clk *clk_aux;
	struct gpio_desc *reset;
};

struct keembay_pcie_of_data {
	enum dw_pcie_device_mode mode;
};

struct kirin_pcie {
	struct dw_pcie___5 *pci;
	void *apb_base;
	void *phy_base;
	struct regmap *crgctrl;
	struct regmap *sysctrl;
	struct clk *apb_sys_clk;
	struct clk *apb_phy_clk;
	struct clk *phy_ref_clk;
	struct clk *pcie_aclk;
	struct clk *pcie_aux_clk;
	int gpio_id_reset;
};

struct histb_pcie {
	struct dw_pcie___5 *pci;
	struct clk *aux_clk;
	struct clk *pipe_clk;
	struct clk *sys_clk;
	struct clk *bus_clk;
	struct phy___7 *phy;
	struct reset_control *soft_reset;
	struct reset_control *sys_reset;
	struct reset_control *bus_reset;
	void *ctrl;
	int reset_gpio;
	struct regulator *vpcie;
};

struct visconti_pcie {
	struct dw_pcie___5 pci;
	void *ulreg_base;
	void *smu_base;
	void *mpu_base;
	struct clk *refclk;
	struct clk *coreclk;
	struct clk *auxclk;
};

struct al_pcie_acpi {
	void *dbi_base;
};

struct config_group___7;

struct config_item_type___7;

struct config_item___7 {
	char *ci_name;
	char ci_namebuf[20];
	struct kref ci_kref;
	struct list_head ci_entry;
	struct config_item___7 *ci_parent;
	struct config_group___7 *ci_group;
	const struct config_item_type___7 *ci_type;
	struct dentry___191 *ci_dentry;
};

struct configfs_subsystem___7;

struct config_group___7 {
	struct config_item___7 cg_item;
	struct list_head cg_children;
	struct configfs_subsystem___7 *cg_subsys;
	struct list_head default_groups;
	struct list_head group_entry;
};

struct configfs_item_operations___7;

struct configfs_group_operations___7;

struct configfs_attribute___7;

struct configfs_bin_attribute___7;

struct config_item_type___7 {
	struct module___175 *ct_owner;
	struct configfs_item_operations___7 *ct_item_ops;
	struct configfs_group_operations___7 *ct_group_ops;
	struct configfs_attribute___7 **ct_attrs;
	struct configfs_bin_attribute___7 **ct_bin_attrs;
};

struct configfs_item_operations___7 {
	void (*release)(struct config_item___7 *);
	int (*allow_link)(struct config_item___7 *, struct config_item___7 *);
	void (*drop_link)(struct config_item___7 *, struct config_item___7 *);
};

struct configfs_group_operations___7 {
	struct config_item___7 * (*make_item)(struct config_group___7 *, const char *);
	struct config_group___7 * (*make_group)(struct config_group___7 *, const char *);
	int (*commit_item)(struct config_item___7 *);
	void (*disconnect_notify)(struct config_group___7 *, struct config_item___7 *);
	void (*drop_item)(struct config_group___7 *, struct config_item___7 *);
};

struct configfs_attribute___7 {
	const char *ca_name;
	struct module___175 *ca_owner;
	umode_t ca_mode;
	ssize_t (*show)(struct config_item___7 *, char *);
	ssize_t (*store)(struct config_item___7 *, const char *, size_t);
};

struct configfs_bin_attribute___7 {
	struct configfs_attribute___7 cb_attr;
	void *cb_private;
	size_t cb_max_size;
	ssize_t (*read)(struct config_item___7 *, void *, size_t);
	ssize_t (*write)(struct config_item___7 *, const void *, size_t);
};

struct configfs_subsystem___7 {
	struct config_group___7 su_group;
	struct mutex su_mutex;
};

struct pci_epc_ops___8;

struct pci_epc___8 {
	struct device___150 dev;
	struct list_head pci_epf;
	const struct pci_epc_ops___8 *ops;
	struct pci_epc_mem **windows;
	struct pci_epc_mem *mem;
	unsigned int num_windows;
	u8 max_functions;
	u8 *max_vfs;
	struct config_group___7 *group;
	struct mutex lock;
	long unsigned int function_num_map;
	struct atomic_notifier_head notifier;
};

struct pci_epc_ops___8 {
	int (*write_header)(struct pci_epc___8 *, u8, u8, struct pci_epf_header *);
	int (*set_bar)(struct pci_epc___8 *, u8, u8, struct pci_epf_bar___2 *);
	void (*clear_bar)(struct pci_epc___8 *, u8, u8, struct pci_epf_bar___2 *);
	int (*map_addr)(struct pci_epc___8 *, u8, u8, phys_addr_t, u64, size_t);
	void (*unmap_addr)(struct pci_epc___8 *, u8, u8, phys_addr_t);
	int (*set_msi)(struct pci_epc___8 *, u8, u8, u8);
	int (*get_msi)(struct pci_epc___8 *, u8, u8);
	int (*set_msix)(struct pci_epc___8 *, u8, u8, u16, enum pci_barno___2, u32);
	int (*get_msix)(struct pci_epc___8 *, u8, u8);
	int (*raise_irq)(struct pci_epc___8 *, u8, u8, enum pci_epc_irq_type, u16);
	int (*map_msi_irq)(struct pci_epc___8 *, u8, u8, phys_addr_t, u8, u32, u32 *, u32 *);
	int (*start)(struct pci_epc___8 *);
	void (*stop)(struct pci_epc___8 *);
	const struct pci_epc_features * (*get_features)(struct pci_epc___8 *, u8, u8);
	struct module___175 *owner;
};

struct pcie_port___5;

struct dw_pcie_host_ops___5 {
	int (*host_init)(struct pcie_port___5 *);
	int (*msi_host_init)(struct pcie_port___5 *);
};

struct pcie_port___5 {
	bool has_msi_ctrl: 1;
	u64 cfg0_base;
	void *va_cfg0_base;
	u32 cfg0_size;
	resource_size_t io_base;
	phys_addr_t io_bus_addr;
	u32 io_size;
	int irq;
	const struct dw_pcie_host_ops___5 *ops;
	int msi_irq;
	struct irq_domain___31 *irq_domain;
	struct irq_domain___31 *msi_domain;
	u16 msi_msg;
	dma_addr_t msi_data;
	struct irq_chip___32 *msi_irq_chip;
	u32 num_vectors;
	u32 irq_mask[8];
	struct pci_host_bridge___3 *bridge;
	raw_spinlock_t lock;
	long unsigned int msi_irq_in_use[4];
};

struct dw_pcie_ep___5;

struct dw_pcie_ep_ops___5 {
	void (*ep_init)(struct dw_pcie_ep___5 *);
	int (*raise_irq)(struct dw_pcie_ep___5 *, u8, enum pci_epc_irq_type, u16);
	const struct pci_epc_features * (*get_features)(struct dw_pcie_ep___5 *);
	unsigned int (*func_conf_select)(struct dw_pcie_ep___5 *, u8);
};

struct dw_pcie_ep___5 {
	struct pci_epc___8 *epc;
	struct list_head func_list;
	const struct dw_pcie_ep_ops___5 *ops;
	phys_addr_t phys_base;
	size_t addr_size;
	size_t page_size;
	u8 bar_to_atu[6];
	phys_addr_t *outbound_addr;
	long unsigned int *ib_window_map;
	long unsigned int *ob_window_map;
	void *msi_mem;
	phys_addr_t msi_mem_phys;
	struct pci_epf_bar___2 *epf_bar[6];
};

struct dw_pcie___6;

struct dw_pcie_ops___6 {
	u64 (*cpu_addr_fixup)(struct dw_pcie___6 *, u64);
	u32 (*read_dbi)(struct dw_pcie___6 *, void *, u32, size_t);
	void (*write_dbi)(struct dw_pcie___6 *, void *, u32, size_t, u32);
	void (*write_dbi2)(struct dw_pcie___6 *, void *, u32, size_t, u32);
	int (*link_up)(struct dw_pcie___6 *);
	int (*start_link)(struct dw_pcie___6 *);
	void (*stop_link)(struct dw_pcie___6 *);
};

struct dw_pcie___6 {
	struct device___150 *dev;
	void *dbi_base;
	void *dbi_base2;
	void *atu_base;
	size_t atu_size;
	u32 num_ib_windows;
	u32 num_ob_windows;
	struct pcie_port___5 pp;
	struct dw_pcie_ep___5 ep;
	const struct dw_pcie_ops___6 *ops;
	unsigned int version;
	int num_lanes;
	int link_gen;
	u8 n_fts[2];
	bool iatu_unroll_enabled: 1;
	bool io_cfg_atu_shared: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct al_pcie_reg_offsets {
	unsigned int ob_ctrl;
};

struct al_pcie_target_bus_cfg {
	u8 reg_val;
	u8 reg_mask;
	u8 ecam_mask;
};

struct al_pcie {
	struct dw_pcie___6 *pci;
	void *controller_base;
	struct device___150 *dev;
	resource_size_t ecam_size;
	unsigned int controller_rev_id;
	struct al_pcie_reg_offsets reg_offsets;
	struct al_pcie_target_bus_cfg target_bus_cfg;
};

struct pci_config_window___4;

struct pci_ecam_ops___4 {
	unsigned int bus_shift;
	struct pci_ops___7 pci_ops;
	int (*init)(struct pci_config_window___4 *);
};

struct pci_config_window___4 {
	struct resource res;
	struct resource busr;
	unsigned int bus_shift;
	void *priv;
	const struct pci_ecam_ops___4 *ops;
	union {
		void *win;
		void **winp;
	};
	struct device___136 *parent;
};

struct tegra194_pcie_ecam {
	void *config_base;
	void *iatu_base;
	void *dbi_base;
};

struct rio_device_id {
	__u16 did;
	__u16 vid;
	__u16 asm_did;
	__u16 asm_vid;
};

typedef s32 dma_cookie_t;

enum dma_status {
	DMA_COMPLETE = 0,
	DMA_IN_PROGRESS = 1,
	DMA_PAUSED = 2,
	DMA_ERROR = 3,
	DMA_OUT_OF_ORDER = 4,
};

enum dma_transaction_type {
	DMA_MEMCPY = 0,
	DMA_XOR = 1,
	DMA_PQ = 2,
	DMA_XOR_VAL = 3,
	DMA_PQ_VAL = 4,
	DMA_MEMSET = 5,
	DMA_MEMSET_SG = 6,
	DMA_INTERRUPT = 7,
	DMA_PRIVATE = 8,
	DMA_ASYNC_TX = 9,
	DMA_SLAVE = 10,
	DMA_CYCLIC = 11,
	DMA_INTERLEAVE = 12,
	DMA_COMPLETION_NO_ORDER = 13,
	DMA_REPEAT = 14,
	DMA_LOAD_EOT = 15,
	DMA_TX_TYPE_END = 16,
};

enum dma_transfer_direction {
	DMA_MEM_TO_MEM = 0,
	DMA_MEM_TO_DEV = 1,
	DMA_DEV_TO_MEM = 2,
	DMA_DEV_TO_DEV = 3,
	DMA_TRANS_NONE = 4,
};

struct data_chunk {
	size_t size;
	size_t icg;
	size_t dst_icg;
	size_t src_icg;
};

struct dma_interleaved_template {
	dma_addr_t src_start;
	dma_addr_t dst_start;
	enum dma_transfer_direction dir;
	bool src_inc;
	bool dst_inc;
	bool src_sgl;
	bool dst_sgl;
	size_t numf;
	size_t frame_size;
	struct data_chunk sgl[0];
};

enum dma_ctrl_flags {
	DMA_PREP_INTERRUPT = 1,
	DMA_CTRL_ACK = 2,
	DMA_PREP_PQ_DISABLE_P = 4,
	DMA_PREP_PQ_DISABLE_Q = 8,
	DMA_PREP_CONTINUE = 16,
	DMA_PREP_FENCE = 32,
	DMA_CTRL_REUSE = 64,
	DMA_PREP_CMD = 128,
	DMA_PREP_REPEAT = 256,
	DMA_PREP_LOAD_EOT = 512,
};

enum sum_check_bits {
	SUM_CHECK_P = 0,
	SUM_CHECK_Q = 1,
};

enum sum_check_flags {
	SUM_CHECK_P_RESULT = 1,
	SUM_CHECK_Q_RESULT = 2,
};

typedef struct {
	long unsigned int bits[1];
} dma_cap_mask_t;

enum dma_desc_metadata_mode {
	DESC_METADATA_NONE = 0,
	DESC_METADATA_CLIENT = 1,
	DESC_METADATA_ENGINE = 2,
};

struct dma_chan_percpu {
	long unsigned int memcpy_count;
	long unsigned int bytes_transferred;
};

struct dma_router {
	struct device___151 *dev;
	void (*route_free)(struct device___151 *, void *);
};

struct dma_device;

struct dma_chan_dev;

struct dma_chan {
	struct dma_device *device;
	struct device___151 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn)(struct dma_chan *, void *);

struct dma_slave_map;

struct dma_filter {
	dma_filter_fn fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

enum dmaengine_alignment {
	DMAENGINE_ALIGN_1_BYTE = 0,
	DMAENGINE_ALIGN_2_BYTES = 1,
	DMAENGINE_ALIGN_4_BYTES = 2,
	DMAENGINE_ALIGN_8_BYTES = 3,
	DMAENGINE_ALIGN_16_BYTES = 4,
	DMAENGINE_ALIGN_32_BYTES = 5,
	DMAENGINE_ALIGN_64_BYTES = 6,
	DMAENGINE_ALIGN_128_BYTES = 7,
	DMAENGINE_ALIGN_256_BYTES = 8,
};

enum dma_residue_granularity {
	DMA_RESIDUE_GRANULARITY_DESCRIPTOR = 0,
	DMA_RESIDUE_GRANULARITY_SEGMENT = 1,
	DMA_RESIDUE_GRANULARITY_BURST = 2,
};

struct dma_async_tx_descriptor;

struct dma_slave_caps;

struct dma_slave_config;

struct dma_tx_state;

struct dma_device {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___151 *dev;
	struct module___176 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan *);
	int (*device_router_config)(struct dma_chan *);
	void (*device_free_chan_resources)(struct dma_chan *);
	struct dma_async_tx_descriptor * (*device_prep_dma_memcpy)(struct dma_chan *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_xor)(struct dma_chan *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_xor_val)(struct dma_chan *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_pq)(struct dma_chan *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_pq_val)(struct dma_chan *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_memset)(struct dma_chan *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_memset_sg)(struct dma_chan *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_interrupt)(struct dma_chan *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_slave_sg)(struct dma_chan *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor * (*device_prep_dma_cyclic)(struct dma_chan *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_interleaved_dma)(struct dma_chan *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor * (*device_prep_dma_imm_data)(struct dma_chan *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan *);
	int (*device_resume)(struct dma_chan *);
	int (*device_terminate_all)(struct dma_chan *);
	void (*device_synchronize)(struct dma_chan *);
	enum dma_status (*device_tx_status)(struct dma_chan *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan *);
	void (*device_release)(struct dma_device *);
	void (*dbg_summary_show)(struct seq_file___9 *, struct dma_device *);
	struct dentry___192 *dbg_dev_root;
};

struct dma_chan_dev {
	struct dma_chan *chan;
	struct device___151 device;
	int dev_id;
	bool chan_dma_dev;
};

enum dma_slave_buswidth {
	DMA_SLAVE_BUSWIDTH_UNDEFINED = 0,
	DMA_SLAVE_BUSWIDTH_1_BYTE = 1,
	DMA_SLAVE_BUSWIDTH_2_BYTES = 2,
	DMA_SLAVE_BUSWIDTH_3_BYTES = 3,
	DMA_SLAVE_BUSWIDTH_4_BYTES = 4,
	DMA_SLAVE_BUSWIDTH_8_BYTES = 8,
	DMA_SLAVE_BUSWIDTH_16_BYTES = 16,
	DMA_SLAVE_BUSWIDTH_32_BYTES = 32,
	DMA_SLAVE_BUSWIDTH_64_BYTES = 64,
	DMA_SLAVE_BUSWIDTH_128_BYTES = 128,
};

struct dma_slave_config {
	enum dma_transfer_direction direction;
	phys_addr_t src_addr;
	phys_addr_t dst_addr;
	enum dma_slave_buswidth src_addr_width;
	enum dma_slave_buswidth dst_addr_width;
	u32 src_maxburst;
	u32 dst_maxburst;
	u32 src_port_window_size;
	u32 dst_port_window_size;
	bool device_fc;
	unsigned int slave_id;
	void *peripheral_config;
	size_t peripheral_size;
};

struct dma_slave_caps {
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool cmd_pause;
	bool cmd_resume;
	bool cmd_terminate;
	enum dma_residue_granularity residue_granularity;
	bool descriptor_reuse;
};

typedef void (*dma_async_tx_callback)(void *);

enum dmaengine_tx_result {
	DMA_TRANS_NOERROR = 0,
	DMA_TRANS_READ_FAILED = 1,
	DMA_TRANS_WRITE_FAILED = 2,
	DMA_TRANS_ABORTED = 3,
};

struct dmaengine_result {
	enum dmaengine_tx_result result;
	u32 residue;
};

typedef void (*dma_async_tx_callback_result)(void *, const struct dmaengine_result *);

struct dmaengine_unmap_data {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___151 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops {
	int (*attach)(struct dma_async_tx_descriptor *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor *, size_t);
};

struct dma_async_tx_descriptor {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor *);
	int (*desc_free)(struct dma_async_tx_descriptor *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops *metadata_ops;
	struct dma_async_tx_descriptor *next;
	struct dma_async_tx_descriptor *parent;
	spinlock_t lock;
};

struct dma_tx_state {
	dma_cookie_t last;
	dma_cookie_t used;
	u32 residue;
	u32 in_flight_bytes;
};

struct dma_slave_map {
	const char *devname;
	const char *slave;
	void *param;
};

struct rio_switch_ops;

struct rio_dev;

struct rio_switch {
	struct list_head node;
	u8 *route_table;
	u32 port_ok;
	struct rio_switch_ops *ops;
	spinlock_t lock;
	struct rio_dev *nextdev[0];
};

struct rio_mport;

struct rio_switch_ops {
	struct module___176 *owner;
	int (*add_entry)(struct rio_mport *, u16, u8, u16, u16, u8);
	int (*get_entry)(struct rio_mport *, u16, u8, u16, u16, u8 *);
	int (*clr_table)(struct rio_mport *, u16, u8, u16);
	int (*set_domain)(struct rio_mport *, u16, u8, u8);
	int (*get_domain)(struct rio_mport *, u16, u8, u8 *);
	int (*em_init)(struct rio_dev *);
	int (*em_handle)(struct rio_dev *, u8);
};

struct rio_net;

struct rio_driver;

union rio_pw_msg;

struct rio_dev {
	struct list_head global_list;
	struct list_head net_list;
	struct rio_net *net;
	bool do_enum;
	u16 did;
	u16 vid;
	u32 device_rev;
	u16 asm_did;
	u16 asm_vid;
	u16 asm_rev;
	u16 efptr;
	u32 pef;
	u32 swpinfo;
	u32 src_ops;
	u32 dst_ops;
	u32 comp_tag;
	u32 phys_efptr;
	u32 phys_rmap;
	u32 em_efptr;
	u64 dma_mask;
	struct rio_driver *driver;
	struct device___151 dev;
	struct resource riores[16];
	int (*pwcback)(struct rio_dev *, union rio_pw_msg *, int);
	u16 destid;
	u8 hopcount;
	struct rio_dev *prev;
	atomic_t state;
	struct rio_switch rswitch[0];
};

struct rio_msg {
	struct resource *res;
	void (*mcback)(struct rio_mport *, void *, int, int);
};

struct rio_ops;

struct rio_scan;

struct rio_mport {
	struct list_head dbells;
	struct list_head pwrites;
	struct list_head node;
	struct list_head nnode;
	struct rio_net *net;
	struct mutex lock;
	struct resource iores;
	struct resource riores[16];
	struct rio_msg inb_msg[4];
	struct rio_msg outb_msg[4];
	int host_deviceid;
	struct rio_ops *ops;
	unsigned char id;
	unsigned char index;
	unsigned int sys_size;
	u32 phys_efptr;
	u32 phys_rmap;
	unsigned char name[40];
	struct device___151 dev;
	void *priv;
	struct dma_device dma;
	struct rio_scan *nscan;
	atomic_t state;
	unsigned int pwe_refcnt;
};

enum rio_device_state {
	RIO_DEVICE_INITIALIZING = 0,
	RIO_DEVICE_RUNNING = 1,
	RIO_DEVICE_GONE = 2,
	RIO_DEVICE_SHUTDOWN = 3,
};

struct rio_net {
	struct list_head node;
	struct list_head devices;
	struct list_head switches;
	struct list_head mports;
	struct rio_mport *hport;
	unsigned char id;
	struct device___151 dev;
	void *enum_data;
	void (*release)(struct rio_net *);
};

struct rio_driver {
	struct list_head node;
	char *name;
	const struct rio_device_id *id_table;
	int (*probe)(struct rio_dev *, const struct rio_device_id *);
	void (*remove)(struct rio_dev *);
	void (*shutdown)(struct rio_dev *);
	int (*suspend)(struct rio_dev *, u32);
	int (*resume)(struct rio_dev *);
	int (*enable_wake)(struct rio_dev *, u32, int);
	struct device_driver___151 driver;
};

union rio_pw_msg {
	struct {
		u32 comptag;
		u32 errdetect;
		u32 is_port;
		u32 ltlerrdet;
		u32 padding[12];
	} em;
	u32 raw[16];
};

struct rio_dbell {
	struct list_head node;
	struct resource *res;
	void (*dinb)(struct rio_mport *, void *, u16, u16, u16);
	void *dev_id;
};

struct rio_mport_attr;

struct rio_ops {
	int (*lcread)(struct rio_mport *, int, u32, int, u32 *);
	int (*lcwrite)(struct rio_mport *, int, u32, int, u32);
	int (*cread)(struct rio_mport *, int, u16, u8, u32, int, u32 *);
	int (*cwrite)(struct rio_mport *, int, u16, u8, u32, int, u32);
	int (*dsend)(struct rio_mport *, int, u16, u16);
	int (*pwenable)(struct rio_mport *, int);
	int (*open_outb_mbox)(struct rio_mport *, void *, int, int);
	void (*close_outb_mbox)(struct rio_mport *, int);
	int (*open_inb_mbox)(struct rio_mport *, void *, int, int);
	void (*close_inb_mbox)(struct rio_mport *, int);
	int (*add_outb_message)(struct rio_mport *, struct rio_dev *, int, void *, size_t);
	int (*add_inb_buffer)(struct rio_mport *, int, void *);
	void * (*get_inb_message)(struct rio_mport *, int);
	int (*map_inb)(struct rio_mport *, dma_addr_t, u64, u64, u32);
	void (*unmap_inb)(struct rio_mport *, dma_addr_t);
	int (*query_mport)(struct rio_mport *, struct rio_mport_attr *);
	int (*map_outb)(struct rio_mport *, u16, u64, u32, u32, dma_addr_t *);
	void (*unmap_outb)(struct rio_mport *, u16, u64);
};

struct rio_scan {
	struct module___176 *owner;
	int (*enumerate)(struct rio_mport *, u32);
	int (*discover)(struct rio_mport *, u32);
};

struct rio_mport_attr {
	int flags;
	int link_speed;
	int link_width;
	int dma_max_sge;
	int dma_max_size;
	int dma_align;
};

enum rio_write_type {
	RDW_DEFAULT = 0,
	RDW_ALL_NWRITE = 1,
	RDW_ALL_NWRITE_R = 2,
	RDW_LAST_NWRITE_R = 3,
};

struct rio_dma_ext {
	u16 destid;
	u64 rio_addr;
	u8 rio_addr_u;
	enum rio_write_type wr_type;
};

struct rio_dma_data {
	struct scatterlist *sg;
	unsigned int sg_len;
	u64 rio_addr;
	u8 rio_addr_u;
	enum rio_write_type wr_type;
};

struct rio_scan_node {
	int mport_id;
	struct list_head node;
	struct rio_scan *ops;
};

struct rio_pwrite {
	struct list_head node;
	int (*pwcback)(struct rio_mport *, void *, union rio_pw_msg *, int);
	void *context;
};

struct rio_disc_work {
	struct work_struct work;
	struct rio_mport *mport;
};

struct dma_router___2 {
	struct device___152 *dev;
	void (*route_free)(struct device___152 *, void *);
};

struct dma_device___2;

struct dma_chan_dev___2;

struct dma_chan___2 {
	struct dma_device___2 *device;
	struct device___152 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___2 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___2 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___2)(struct dma_chan___2 *, void *);

struct dma_filter___2 {
	dma_filter_fn___2 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___2;

struct dma_device___2 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___2 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___152 *dev;
	struct module___177 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___2 *);
	int (*device_router_config)(struct dma_chan___2 *);
	void (*device_free_chan_resources)(struct dma_chan___2 *);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memcpy)(struct dma_chan___2 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_xor)(struct dma_chan___2 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_xor_val)(struct dma_chan___2 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_pq)(struct dma_chan___2 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_pq_val)(struct dma_chan___2 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memset)(struct dma_chan___2 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_memset_sg)(struct dma_chan___2 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_interrupt)(struct dma_chan___2 *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_slave_sg)(struct dma_chan___2 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_cyclic)(struct dma_chan___2 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_interleaved_dma)(struct dma_chan___2 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___2 * (*device_prep_dma_imm_data)(struct dma_chan___2 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___2 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___2 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___2 *);
	int (*device_resume)(struct dma_chan___2 *);
	int (*device_terminate_all)(struct dma_chan___2 *);
	void (*device_synchronize)(struct dma_chan___2 *);
	enum dma_status (*device_tx_status)(struct dma_chan___2 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___2 *);
	void (*device_release)(struct dma_device___2 *);
	void (*dbg_summary_show)(struct seq_file___9 *, struct dma_device___2 *);
	struct dentry___193 *dbg_dev_root;
};

struct dma_chan_dev___2 {
	struct dma_chan___2 *chan;
	struct device___152 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___2 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___152 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___2 {
	int (*attach)(struct dma_async_tx_descriptor___2 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___2 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___2 *, size_t);
};

struct dma_async_tx_descriptor___2 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___2 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___2 *);
	int (*desc_free)(struct dma_async_tx_descriptor___2 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___2 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___2 *metadata_ops;
	struct dma_async_tx_descriptor___2 *next;
	struct dma_async_tx_descriptor___2 *parent;
	spinlock_t lock;
};

struct rio_switch_ops___2;

struct rio_dev___2;

struct rio_switch___2 {
	struct list_head node;
	u8 *route_table;
	u32 port_ok;
	struct rio_switch_ops___2 *ops;
	spinlock_t lock;
	struct rio_dev___2 *nextdev[0];
};

struct rio_mport___2;

struct rio_switch_ops___2 {
	struct module___177 *owner;
	int (*add_entry)(struct rio_mport___2 *, u16, u8, u16, u16, u8);
	int (*get_entry)(struct rio_mport___2 *, u16, u8, u16, u16, u8 *);
	int (*clr_table)(struct rio_mport___2 *, u16, u8, u16);
	int (*set_domain)(struct rio_mport___2 *, u16, u8, u8);
	int (*get_domain)(struct rio_mport___2 *, u16, u8, u8 *);
	int (*em_init)(struct rio_dev___2 *);
	int (*em_handle)(struct rio_dev___2 *, u8);
};

struct rio_net___2;

struct rio_driver___2;

struct rio_dev___2 {
	struct list_head global_list;
	struct list_head net_list;
	struct rio_net___2 *net;
	bool do_enum;
	u16 did;
	u16 vid;
	u32 device_rev;
	u16 asm_did;
	u16 asm_vid;
	u16 asm_rev;
	u16 efptr;
	u32 pef;
	u32 swpinfo;
	u32 src_ops;
	u32 dst_ops;
	u32 comp_tag;
	u32 phys_efptr;
	u32 phys_rmap;
	u32 em_efptr;
	u64 dma_mask;
	struct rio_driver___2 *driver;
	struct device___152 dev;
	struct resource riores[16];
	int (*pwcback)(struct rio_dev___2 *, union rio_pw_msg *, int);
	u16 destid;
	u8 hopcount;
	struct rio_dev___2 *prev;
	atomic_t state;
	struct rio_switch___2 rswitch[0];
};

struct rio_msg___2 {
	struct resource *res;
	void (*mcback)(struct rio_mport___2 *, void *, int, int);
};

struct rio_ops___2;

struct rio_scan___2;

struct rio_mport___2 {
	struct list_head dbells;
	struct list_head pwrites;
	struct list_head node;
	struct list_head nnode;
	struct rio_net___2 *net;
	struct mutex lock;
	struct resource iores;
	struct resource riores[16];
	struct rio_msg___2 inb_msg[4];
	struct rio_msg___2 outb_msg[4];
	int host_deviceid;
	struct rio_ops___2 *ops;
	unsigned char id;
	unsigned char index;
	unsigned int sys_size;
	u32 phys_efptr;
	u32 phys_rmap;
	unsigned char name[40];
	struct device___152 dev;
	void *priv;
	struct dma_device___2 dma;
	struct rio_scan___2 *nscan;
	atomic_t state;
	unsigned int pwe_refcnt;
};

struct rio_net___2 {
	struct list_head node;
	struct list_head devices;
	struct list_head switches;
	struct list_head mports;
	struct rio_mport___2 *hport;
	unsigned char id;
	struct device___152 dev;
	void *enum_data;
	void (*release)(struct rio_net___2 *);
};

struct rio_driver___2 {
	struct list_head node;
	char *name;
	const struct rio_device_id *id_table;
	int (*probe)(struct rio_dev___2 *, const struct rio_device_id *);
	void (*remove)(struct rio_dev___2 *);
	void (*shutdown)(struct rio_dev___2 *);
	int (*suspend)(struct rio_dev___2 *, u32);
	int (*resume)(struct rio_dev___2 *);
	int (*enable_wake)(struct rio_dev___2 *, u32, int);
	struct device_driver___152 driver;
};

struct rio_ops___2 {
	int (*lcread)(struct rio_mport___2 *, int, u32, int, u32 *);
	int (*lcwrite)(struct rio_mport___2 *, int, u32, int, u32);
	int (*cread)(struct rio_mport___2 *, int, u16, u8, u32, int, u32 *);
	int (*cwrite)(struct rio_mport___2 *, int, u16, u8, u32, int, u32);
	int (*dsend)(struct rio_mport___2 *, int, u16, u16);
	int (*pwenable)(struct rio_mport___2 *, int);
	int (*open_outb_mbox)(struct rio_mport___2 *, void *, int, int);
	void (*close_outb_mbox)(struct rio_mport___2 *, int);
	int (*open_inb_mbox)(struct rio_mport___2 *, void *, int, int);
	void (*close_inb_mbox)(struct rio_mport___2 *, int);
	int (*add_outb_message)(struct rio_mport___2 *, struct rio_dev___2 *, int, void *, size_t);
	int (*add_inb_buffer)(struct rio_mport___2 *, int, void *);
	void * (*get_inb_message)(struct rio_mport___2 *, int);
	int (*map_inb)(struct rio_mport___2 *, dma_addr_t, u64, u64, u32);
	void (*unmap_inb)(struct rio_mport___2 *, dma_addr_t);
	int (*query_mport)(struct rio_mport___2 *, struct rio_mport_attr *);
	int (*map_outb)(struct rio_mport___2 *, u16, u64, u32, u32, dma_addr_t *);
	void (*unmap_outb)(struct rio_mport___2 *, u16, u64);
};

struct rio_scan___2 {
	struct module___177 *owner;
	int (*enumerate)(struct rio_mport___2 *, u32);
	int (*discover)(struct rio_mport___2 *, u32);
};

enum hdmi_infoframe_type {
	HDMI_INFOFRAME_TYPE_VENDOR = 129,
	HDMI_INFOFRAME_TYPE_AVI = 130,
	HDMI_INFOFRAME_TYPE_SPD = 131,
	HDMI_INFOFRAME_TYPE_AUDIO = 132,
	HDMI_INFOFRAME_TYPE_DRM = 135,
};

struct hdmi_any_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
};

enum hdmi_colorspace {
	HDMI_COLORSPACE_RGB = 0,
	HDMI_COLORSPACE_YUV422 = 1,
	HDMI_COLORSPACE_YUV444 = 2,
	HDMI_COLORSPACE_YUV420 = 3,
	HDMI_COLORSPACE_RESERVED4 = 4,
	HDMI_COLORSPACE_RESERVED5 = 5,
	HDMI_COLORSPACE_RESERVED6 = 6,
	HDMI_COLORSPACE_IDO_DEFINED = 7,
};

enum hdmi_scan_mode {
	HDMI_SCAN_MODE_NONE = 0,
	HDMI_SCAN_MODE_OVERSCAN = 1,
	HDMI_SCAN_MODE_UNDERSCAN = 2,
	HDMI_SCAN_MODE_RESERVED = 3,
};

enum hdmi_colorimetry {
	HDMI_COLORIMETRY_NONE = 0,
	HDMI_COLORIMETRY_ITU_601 = 1,
	HDMI_COLORIMETRY_ITU_709 = 2,
	HDMI_COLORIMETRY_EXTENDED = 3,
};

enum hdmi_picture_aspect {
	HDMI_PICTURE_ASPECT_NONE = 0,
	HDMI_PICTURE_ASPECT_4_3 = 1,
	HDMI_PICTURE_ASPECT_16_9 = 2,
	HDMI_PICTURE_ASPECT_64_27 = 3,
	HDMI_PICTURE_ASPECT_256_135 = 4,
	HDMI_PICTURE_ASPECT_RESERVED = 5,
};

enum hdmi_active_aspect {
	HDMI_ACTIVE_ASPECT_16_9_TOP = 2,
	HDMI_ACTIVE_ASPECT_14_9_TOP = 3,
	HDMI_ACTIVE_ASPECT_16_9_CENTER = 4,
	HDMI_ACTIVE_ASPECT_PICTURE = 8,
	HDMI_ACTIVE_ASPECT_4_3 = 9,
	HDMI_ACTIVE_ASPECT_16_9 = 10,
	HDMI_ACTIVE_ASPECT_14_9 = 11,
	HDMI_ACTIVE_ASPECT_4_3_SP_14_9 = 13,
	HDMI_ACTIVE_ASPECT_16_9_SP_14_9 = 14,
	HDMI_ACTIVE_ASPECT_16_9_SP_4_3 = 15,
};

enum hdmi_extended_colorimetry {
	HDMI_EXTENDED_COLORIMETRY_XV_YCC_601 = 0,
	HDMI_EXTENDED_COLORIMETRY_XV_YCC_709 = 1,
	HDMI_EXTENDED_COLORIMETRY_S_YCC_601 = 2,
	HDMI_EXTENDED_COLORIMETRY_OPYCC_601 = 3,
	HDMI_EXTENDED_COLORIMETRY_OPRGB = 4,
	HDMI_EXTENDED_COLORIMETRY_BT2020_CONST_LUM = 5,
	HDMI_EXTENDED_COLORIMETRY_BT2020 = 6,
	HDMI_EXTENDED_COLORIMETRY_RESERVED = 7,
};

enum hdmi_quantization_range {
	HDMI_QUANTIZATION_RANGE_DEFAULT = 0,
	HDMI_QUANTIZATION_RANGE_LIMITED = 1,
	HDMI_QUANTIZATION_RANGE_FULL = 2,
	HDMI_QUANTIZATION_RANGE_RESERVED = 3,
};

enum hdmi_nups {
	HDMI_NUPS_UNKNOWN = 0,
	HDMI_NUPS_HORIZONTAL = 1,
	HDMI_NUPS_VERTICAL = 2,
	HDMI_NUPS_BOTH = 3,
};

enum hdmi_ycc_quantization_range {
	HDMI_YCC_QUANTIZATION_RANGE_LIMITED = 0,
	HDMI_YCC_QUANTIZATION_RANGE_FULL = 1,
};

enum hdmi_content_type {
	HDMI_CONTENT_TYPE_GRAPHICS = 0,
	HDMI_CONTENT_TYPE_PHOTO = 1,
	HDMI_CONTENT_TYPE_CINEMA = 2,
	HDMI_CONTENT_TYPE_GAME = 3,
};

enum hdmi_metadata_type {
	HDMI_STATIC_METADATA_TYPE1 = 0,
};

enum hdmi_eotf {
	HDMI_EOTF_TRADITIONAL_GAMMA_SDR = 0,
	HDMI_EOTF_TRADITIONAL_GAMMA_HDR = 1,
	HDMI_EOTF_SMPTE_ST2084 = 2,
	HDMI_EOTF_BT_2100_HLG = 3,
};

struct hdmi_avi_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	enum hdmi_colorspace colorspace;
	enum hdmi_scan_mode scan_mode;
	enum hdmi_colorimetry colorimetry;
	enum hdmi_picture_aspect picture_aspect;
	enum hdmi_active_aspect active_aspect;
	bool itc;
	enum hdmi_extended_colorimetry extended_colorimetry;
	enum hdmi_quantization_range quantization_range;
	enum hdmi_nups nups;
	unsigned char video_code;
	enum hdmi_ycc_quantization_range ycc_quantization_range;
	enum hdmi_content_type content_type;
	unsigned char pixel_repeat;
	short unsigned int top_bar;
	short unsigned int bottom_bar;
	short unsigned int left_bar;
	short unsigned int right_bar;
};

struct hdmi_drm_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	enum hdmi_eotf eotf;
	enum hdmi_metadata_type metadata_type;
	struct {
		u16 x;
		u16 y;
	} display_primaries[3];
	struct {
		u16 x;
		u16 y;
	} white_point;
	u16 max_display_mastering_luminance;
	u16 min_display_mastering_luminance;
	u16 max_cll;
	u16 max_fall;
};

enum hdmi_spd_sdi {
	HDMI_SPD_SDI_UNKNOWN = 0,
	HDMI_SPD_SDI_DSTB = 1,
	HDMI_SPD_SDI_DVDP = 2,
	HDMI_SPD_SDI_DVHS = 3,
	HDMI_SPD_SDI_HDDVR = 4,
	HDMI_SPD_SDI_DVC = 5,
	HDMI_SPD_SDI_DSC = 6,
	HDMI_SPD_SDI_VCD = 7,
	HDMI_SPD_SDI_GAME = 8,
	HDMI_SPD_SDI_PC = 9,
	HDMI_SPD_SDI_BD = 10,
	HDMI_SPD_SDI_SACD = 11,
	HDMI_SPD_SDI_HDDVD = 12,
	HDMI_SPD_SDI_PMP = 13,
};

struct hdmi_spd_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	char vendor[8];
	char product[16];
	enum hdmi_spd_sdi sdi;
};

enum hdmi_audio_coding_type {
	HDMI_AUDIO_CODING_TYPE_STREAM = 0,
	HDMI_AUDIO_CODING_TYPE_PCM = 1,
	HDMI_AUDIO_CODING_TYPE_AC3 = 2,
	HDMI_AUDIO_CODING_TYPE_MPEG1 = 3,
	HDMI_AUDIO_CODING_TYPE_MP3 = 4,
	HDMI_AUDIO_CODING_TYPE_MPEG2 = 5,
	HDMI_AUDIO_CODING_TYPE_AAC_LC = 6,
	HDMI_AUDIO_CODING_TYPE_DTS = 7,
	HDMI_AUDIO_CODING_TYPE_ATRAC = 8,
	HDMI_AUDIO_CODING_TYPE_DSD = 9,
	HDMI_AUDIO_CODING_TYPE_EAC3 = 10,
	HDMI_AUDIO_CODING_TYPE_DTS_HD = 11,
	HDMI_AUDIO_CODING_TYPE_MLP = 12,
	HDMI_AUDIO_CODING_TYPE_DST = 13,
	HDMI_AUDIO_CODING_TYPE_WMA_PRO = 14,
	HDMI_AUDIO_CODING_TYPE_CXT = 15,
};

enum hdmi_audio_sample_size {
	HDMI_AUDIO_SAMPLE_SIZE_STREAM = 0,
	HDMI_AUDIO_SAMPLE_SIZE_16 = 1,
	HDMI_AUDIO_SAMPLE_SIZE_20 = 2,
	HDMI_AUDIO_SAMPLE_SIZE_24 = 3,
};

enum hdmi_audio_sample_frequency {
	HDMI_AUDIO_SAMPLE_FREQUENCY_STREAM = 0,
	HDMI_AUDIO_SAMPLE_FREQUENCY_32000 = 1,
	HDMI_AUDIO_SAMPLE_FREQUENCY_44100 = 2,
	HDMI_AUDIO_SAMPLE_FREQUENCY_48000 = 3,
	HDMI_AUDIO_SAMPLE_FREQUENCY_88200 = 4,
	HDMI_AUDIO_SAMPLE_FREQUENCY_96000 = 5,
	HDMI_AUDIO_SAMPLE_FREQUENCY_176400 = 6,
	HDMI_AUDIO_SAMPLE_FREQUENCY_192000 = 7,
};

enum hdmi_audio_coding_type_ext {
	HDMI_AUDIO_CODING_TYPE_EXT_CT = 0,
	HDMI_AUDIO_CODING_TYPE_EXT_HE_AAC = 1,
	HDMI_AUDIO_CODING_TYPE_EXT_HE_AAC_V2 = 2,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG_SURROUND = 3,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_HE_AAC = 4,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_HE_AAC_V2 = 5,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_AAC_LC = 6,
	HDMI_AUDIO_CODING_TYPE_EXT_DRA = 7,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_HE_AAC_SURROUND = 8,
	HDMI_AUDIO_CODING_TYPE_EXT_MPEG4_AAC_LC_SURROUND = 10,
};

struct hdmi_audio_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	unsigned char channels;
	enum hdmi_audio_coding_type coding_type;
	enum hdmi_audio_sample_size sample_size;
	enum hdmi_audio_sample_frequency sample_frequency;
	enum hdmi_audio_coding_type_ext coding_type_ext;
	unsigned char channel_allocation;
	unsigned char level_shift_value;
	bool downmix_inhibit;
};

enum hdmi_3d_structure {
	HDMI_3D_STRUCTURE_INVALID = 0,
	HDMI_3D_STRUCTURE_FRAME_PACKING = 0,
	HDMI_3D_STRUCTURE_FIELD_ALTERNATIVE = 1,
	HDMI_3D_STRUCTURE_LINE_ALTERNATIVE = 2,
	HDMI_3D_STRUCTURE_SIDE_BY_SIDE_FULL = 3,
	HDMI_3D_STRUCTURE_L_DEPTH = 4,
	HDMI_3D_STRUCTURE_L_DEPTH_GFX_GFX_DEPTH = 5,
	HDMI_3D_STRUCTURE_TOP_AND_BOTTOM = 6,
	HDMI_3D_STRUCTURE_SIDE_BY_SIDE_HALF = 8,
};

struct hdmi_vendor_infoframe {
	enum hdmi_infoframe_type type;
	unsigned char version;
	unsigned char length;
	unsigned int oui;
	u8 vic;
	enum hdmi_3d_structure s3d_struct;
	unsigned int s3d_ext_data;
};

union hdmi_vendor_any_infoframe {
	struct {
		enum hdmi_infoframe_type type;
		unsigned char version;
		unsigned char length;
		unsigned int oui;
	} any;
	struct hdmi_vendor_infoframe hdmi;
};

union hdmi_infoframe {
	struct hdmi_any_infoframe any;
	struct hdmi_avi_infoframe avi;
	struct hdmi_spd_infoframe spd;
	union hdmi_vendor_any_infoframe vendor;
	struct hdmi_audio_infoframe audio;
	struct hdmi_drm_infoframe drm;
};

enum con_scroll {
	SM_UP = 0,
	SM_DOWN = 1,
};

enum vc_intensity {
	VCI_HALF_BRIGHT = 0,
	VCI_NORMAL = 1,
	VCI_BOLD = 2,
	VCI_MASK = 3,
};

struct vc_data;

struct console_font;

struct consw {
	struct module___168 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data *, int);
	void (*con_deinit)(struct vc_data *);
	void (*con_clear)(struct vc_data *, int, int, int, int);
	void (*con_putc)(struct vc_data *, int, int, int);
	void (*con_putcs)(struct vc_data *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data *, int);
	bool (*con_scroll)(struct vc_data *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data *);
	int (*con_blank)(struct vc_data *, int, int);
	int (*con_font_set)(struct vc_data *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data *, struct console_font *);
	int (*con_font_default)(struct vc_data *, struct console_font *, char *);
	int (*con_resize)(struct vc_data *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data *, int);
	int (*con_set_origin)(struct vc_data *);
	void (*con_save_screen)(struct vc_data *);
	u8 (*con_build_attr)(struct vc_data *, u8, enum vc_intensity, bool, bool, bool, bool);
	void (*con_invert_region)(struct vc_data *, u16 *, int);
	u16 * (*con_screen_pos)(const struct vc_data *, int);
	long unsigned int (*con_getxy)(struct vc_data *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data *);
	int (*con_debug_enter)(struct vc_data *);
	int (*con_debug_leave)(struct vc_data *);
};

struct vc_state {
	unsigned int x;
	unsigned int y;
	unsigned char color;
	unsigned char Gx_charset[2];
	unsigned int charset: 1;
	long: 31;
	long: 64;
	enum vc_intensity intensity;
	bool italic;
	bool underline;
	bool blink;
	bool reverse;
};

struct console_font {
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	unsigned char *data;
};

struct vt_mode {
	char mode;
	char waitv;
	short int relsig;
	short int acqsig;
	short int frsig;
};

struct uni_pagedir;

struct uni_screen;

struct vc_data {
	struct tty_port___15 port;
	struct vc_state state;
	struct vc_state saved_state;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	unsigned int vc_cell_height;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___163 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_priv: 3;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned char vc_utf_count;
	int vc_utf_char;
	long unsigned int vc_tab_stop[4];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
	struct uni_screen *vc_uni_screen;
};

struct device_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct device___149 *, struct device_attribute___12 *, char *);
	ssize_t (*store)(struct device___149 *, struct device_attribute___12 *, const char *, size_t);
};

typedef void (*dr_release_t___13)(struct device___149 *, void *);

typedef int (*dr_match_t___12)(struct device___149 *, void *, void *);

struct fb_fix_screeninfo {
	char id[16];
	long unsigned int smem_start;
	__u32 smem_len;
	__u32 type;
	__u32 type_aux;
	__u32 visual;
	__u16 xpanstep;
	__u16 ypanstep;
	__u16 ywrapstep;
	__u32 line_length;
	long unsigned int mmio_start;
	__u32 mmio_len;
	__u32 accel;
	__u16 capabilities;
	__u16 reserved[2];
};

struct fb_bitfield {
	__u32 offset;
	__u32 length;
	__u32 msb_right;
};

struct fb_var_screeninfo {
	__u32 xres;
	__u32 yres;
	__u32 xres_virtual;
	__u32 yres_virtual;
	__u32 xoffset;
	__u32 yoffset;
	__u32 bits_per_pixel;
	__u32 grayscale;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	__u32 nonstd;
	__u32 activate;
	__u32 height;
	__u32 width;
	__u32 accel_flags;
	__u32 pixclock;
	__u32 left_margin;
	__u32 right_margin;
	__u32 upper_margin;
	__u32 lower_margin;
	__u32 hsync_len;
	__u32 vsync_len;
	__u32 sync;
	__u32 vmode;
	__u32 rotate;
	__u32 colorspace;
	__u32 reserved[4];
};

struct fb_cmap {
	__u32 start;
	__u32 len;
	__u16 *red;
	__u16 *green;
	__u16 *blue;
	__u16 *transp;
};

enum {
	FB_BLANK_UNBLANK = 0,
	FB_BLANK_NORMAL = 1,
	FB_BLANK_VSYNC_SUSPEND = 2,
	FB_BLANK_HSYNC_SUSPEND = 3,
	FB_BLANK_POWERDOWN = 4,
};

struct fb_copyarea {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 sx;
	__u32 sy;
};

struct fb_fillrect {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 color;
	__u32 rop;
};

struct fb_image {
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
	__u32 fg_color;
	__u32 bg_color;
	__u8 depth;
	const char *data;
	struct fb_cmap cmap;
};

struct fbcurpos {
	__u16 x;
	__u16 y;
};

struct fb_cursor {
	__u16 set;
	__u16 enable;
	__u16 rop;
	const char *mask;
	struct fbcurpos hot;
	struct fb_image image;
};

struct fb_chroma {
	__u32 redx;
	__u32 greenx;
	__u32 bluex;
	__u32 whitex;
	__u32 redy;
	__u32 greeny;
	__u32 bluey;
	__u32 whitey;
};

struct fb_videomode;

struct fb_monspecs {
	struct fb_chroma chroma;
	struct fb_videomode *modedb;
	__u8 manufacturer[4];
	__u8 monitor[14];
	__u8 serial_no[14];
	__u8 ascii[14];
	__u32 modedb_len;
	__u32 model;
	__u32 serial;
	__u32 year;
	__u32 week;
	__u32 hfmin;
	__u32 hfmax;
	__u32 dclkmin;
	__u32 dclkmax;
	__u16 input;
	__u16 dpms;
	__u16 signal;
	__u16 vfmin;
	__u16 vfmax;
	__u16 gamma;
	__u16 gtf: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 misc;
	__u8 version;
	__u8 revision;
	__u8 max_x;
	__u8 max_y;
};

struct fb_videomode {
	const char *name;
	u32 refresh;
	u32 xres;
	u32 yres;
	u32 pixclock;
	u32 left_margin;
	u32 right_margin;
	u32 upper_margin;
	u32 lower_margin;
	u32 hsync_len;
	u32 vsync_len;
	u32 sync;
	u32 vmode;
	u32 flag;
};

struct fb_info;

struct fb_event {
	struct fb_info *info;
	void *data;
};

struct fb_pixmap {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info *, void *, void *, unsigned int);
	void (*readio)(struct fb_info *, void *, void *, unsigned int);
};

struct backlight_device;

struct fb_deferred_io;

struct fb_ops;

struct fb_tile_ops;

struct apertures_struct;

struct fb_info {
	refcount_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap pixmap;
	struct fb_pixmap sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io *fbdefio;
	const struct fb_ops *fbops;
	struct device___149 *device;
	struct device___149 *dev;
	int class_flag;
	struct fb_tile_ops *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
	bool forced_out;
};

struct fb_blit_caps {
	u32 x;
	u32 y;
	u32 len;
	u32 flags;
};

struct fb_deferred_io {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info *);
	void (*deferred_io)(struct fb_info *, struct list_head *);
};

struct fb_ops {
	struct module___175 *owner;
	int (*fb_open)(struct fb_info *, int);
	int (*fb_release)(struct fb_info *, int);
	ssize_t (*fb_read)(struct fb_info *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info *);
	int (*fb_set_par)(struct fb_info *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info *);
	int (*fb_blank)(int, struct fb_info *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info *);
	void (*fb_fillrect)(struct fb_info *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info *);
	int (*fb_ioctl)(struct fb_info *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info *, struct vm_area_struct___196 *);
	void (*fb_get_caps)(struct fb_info *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info *);
	int (*fb_debug_enter)(struct fb_info *);
	int (*fb_debug_leave)(struct fb_info *);
};

struct fb_tilemap {
	__u32 width;
	__u32 height;
	__u32 depth;
	__u32 length;
	const __u8 *data;
};

struct fb_tilerect {
	__u32 sx;
	__u32 sy;
	__u32 width;
	__u32 height;
	__u32 index;
	__u32 fg;
	__u32 bg;
	__u32 rop;
};

struct fb_tilearea {
	__u32 sx;
	__u32 sy;
	__u32 dx;
	__u32 dy;
	__u32 width;
	__u32 height;
};

struct fb_tileblit {
	__u32 sx;
	__u32 sy;
	__u32 width;
	__u32 height;
	__u32 fg;
	__u32 bg;
	__u32 length;
	__u32 *indices;
};

struct fb_tilecursor {
	__u32 sx;
	__u32 sy;
	__u32 mode;
	__u32 shape;
	__u32 fg;
	__u32 bg;
};

struct fb_tile_ops {
	void (*fb_settile)(struct fb_info *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info *);
};

struct aperture {
	resource_size_t base;
	resource_size_t size;
};

struct apertures_struct {
	unsigned int count;
	struct aperture ranges[0];
};

enum backlight_type {
	BACKLIGHT_RAW = 1,
	BACKLIGHT_PLATFORM = 2,
	BACKLIGHT_FIRMWARE = 3,
	BACKLIGHT_TYPE_MAX = 4,
};

enum backlight_scale {
	BACKLIGHT_SCALE_UNKNOWN = 0,
	BACKLIGHT_SCALE_LINEAR = 1,
	BACKLIGHT_SCALE_NON_LINEAR = 2,
};

struct backlight_properties {
	int brightness;
	int max_brightness;
	int power;
	int fb_blank;
	enum backlight_type type;
	unsigned int state;
	enum backlight_scale scale;
};

struct backlight_ops;

struct backlight_device {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___149 dev;
	bool fb_bl_on[32];
	int use_count;
};

enum backlight_update_reason {
	BACKLIGHT_UPDATE_HOTKEY = 0,
	BACKLIGHT_UPDATE_SYSFS = 1,
};

enum backlight_notification {
	BACKLIGHT_REGISTERED = 0,
	BACKLIGHT_UNREGISTERED = 1,
};

struct backlight_ops {
	unsigned int options;
	int (*update_status)(struct backlight_device *);
	int (*get_brightness)(struct backlight_device *);
	int (*check_fb)(struct backlight_device *, struct fb_info *);
};

struct fb_cmap_user {
	__u32 start;
	__u32 len;
	__u16 *red;
	__u16 *green;
	__u16 *blue;
	__u16 *transp;
};

struct fb_modelist {
	struct list_head list;
	struct fb_videomode mode;
};

struct fb_fix_screeninfo32 {
	char id[16];
	compat_caddr_t smem_start;
	u32 smem_len;
	u32 type;
	u32 type_aux;
	u32 visual;
	u16 xpanstep;
	u16 ypanstep;
	u16 ywrapstep;
	u32 line_length;
	compat_caddr_t mmio_start;
	u32 mmio_len;
	u32 accel;
	u16 reserved[3];
};

struct fb_cmap32 {
	u32 start;
	u32 len;
	compat_caddr_t red;
	compat_caddr_t green;
	compat_caddr_t blue;
	compat_caddr_t transp;
};

struct dmt_videomode {
	u32 dmt_id;
	u32 std_2byte_code;
	u32 cvt_3byte_code;
	const struct fb_videomode *mode;
};

enum display_flags {
	DISPLAY_FLAGS_HSYNC_LOW = 1,
	DISPLAY_FLAGS_HSYNC_HIGH = 2,
	DISPLAY_FLAGS_VSYNC_LOW = 4,
	DISPLAY_FLAGS_VSYNC_HIGH = 8,
	DISPLAY_FLAGS_DE_LOW = 16,
	DISPLAY_FLAGS_DE_HIGH = 32,
	DISPLAY_FLAGS_PIXDATA_POSEDGE = 64,
	DISPLAY_FLAGS_PIXDATA_NEGEDGE = 128,
	DISPLAY_FLAGS_INTERLACED = 256,
	DISPLAY_FLAGS_DOUBLESCAN = 512,
	DISPLAY_FLAGS_DOUBLECLK = 1024,
	DISPLAY_FLAGS_SYNC_POSEDGE = 2048,
	DISPLAY_FLAGS_SYNC_NEGEDGE = 4096,
};

struct videomode {
	long unsigned int pixelclock;
	u32 hactive;
	u32 hfront_porch;
	u32 hback_porch;
	u32 hsync_len;
	u32 vactive;
	u32 vfront_porch;
	u32 vback_porch;
	u32 vsync_len;
	enum display_flags flags;
};

struct broken_edid {
	u8 manufacturer[4];
	u32 model;
	u32 fix;
};

struct __fb_timings {
	u32 dclk;
	u32 hfreq;
	u32 vfreq;
	u32 hactive;
	u32 vactive;
	u32 hblank;
	u32 vblank;
	u32 htotal;
	u32 vtotal;
};

typedef unsigned int u_int;

struct backlight_device___2;

struct fb_info___2;

struct backlight_ops___2 {
	unsigned int options;
	int (*update_status)(struct backlight_device___2 *);
	int (*get_brightness)(struct backlight_device___2 *);
	int (*check_fb)(struct backlight_device___2 *, struct fb_info___2 *);
};

struct backlight_device___2 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___2 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___145 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___2 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___2 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___2 *, void *, void *, unsigned int);
};

struct fb_deferred_io___2;

struct fb_ops___2;

struct fb_tile_ops___2;

struct fb_info___2 {
	refcount_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___2 pixmap;
	struct fb_pixmap___2 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___2 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___2 *fbdefio;
	const struct fb_ops___2 *fbops;
	struct device___145 *device;
	struct device___145 *dev;
	int class_flag;
	struct fb_tile_ops___2 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
	bool forced_out;
};

struct fb_deferred_io___2 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___2 *);
	void (*deferred_io)(struct fb_info___2 *, struct list_head *);
};

struct fb_ops___2 {
	struct module___171 *owner;
	int (*fb_open)(struct fb_info___2 *, int);
	int (*fb_release)(struct fb_info___2 *, int);
	ssize_t (*fb_read)(struct fb_info___2 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___2 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___2 *);
	int (*fb_set_par)(struct fb_info___2 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___2 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___2 *);
	int (*fb_blank)(int, struct fb_info___2 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___2 *);
	void (*fb_fillrect)(struct fb_info___2 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___2 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___2 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___2 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___2 *);
	int (*fb_ioctl)(struct fb_info___2 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___2 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___2 *, struct vm_area_struct___192 *);
	void (*fb_get_caps)(struct fb_info___2 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___2 *);
	int (*fb_debug_enter)(struct fb_info___2 *);
	int (*fb_debug_leave)(struct fb_info___2 *);
};

struct fb_tile_ops___2 {
	void (*fb_settile)(struct fb_info___2 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___2 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___2 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___2 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___2 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___2 *);
};

struct device_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct device___145 *, struct device_attribute___13 *, char *);
	ssize_t (*store)(struct device___145 *, struct device_attribute___13 *, const char *, size_t);
};

struct fb_cvt_data {
	u32 xres;
	u32 yres;
	u32 refresh;
	u32 f_refresh;
	u32 pixclock;
	u32 hperiod;
	u32 hblank;
	u32 hfreq;
	u32 htotal;
	u32 vtotal;
	u32 vsync;
	u32 hsync;
	u32 h_front_porch;
	u32 h_back_porch;
	u32 v_front_porch;
	u32 v_back_porch;
	u32 h_margin;
	u32 v_margin;
	u32 interlace;
	u32 aspect_ratio;
	u32 active_pixels;
	u32 flags;
	u32 status;
};

typedef unsigned char u_char;

struct dentry___194;

struct super_block___194;

struct module___178;

struct file_system_type___194 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___194 * (*mount)(struct file_system_type___194 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___194 *);
	struct module___178 *owner;
	struct file_system_type___194 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___194;

struct kiocb___194;

struct iov_iter___116;

struct poll_table_struct___126;

struct vm_area_struct___199;

struct inode___194;

struct file_lock___194;

struct page___199;

struct seq_file___170;

struct file_operations___195 {
	struct module___178 *owner;
	loff_t (*llseek)(struct file___194 *, loff_t, int);
	ssize_t (*read)(struct file___194 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___194 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___194 *, struct iov_iter___116 *);
	ssize_t (*write_iter)(struct kiocb___194 *, struct iov_iter___116 *);
	int (*iopoll)(struct kiocb___194 *, bool);
	int (*iterate)(struct file___194 *, struct dir_context *);
	int (*iterate_shared)(struct file___194 *, struct dir_context *);
	__poll_t (*poll)(struct file___194 *, struct poll_table_struct___126 *);
	long int (*unlocked_ioctl)(struct file___194 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___194 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___194 *, struct vm_area_struct___199 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___194 *, struct file___194 *);
	int (*flush)(struct file___194 *, fl_owner_t);
	int (*release)(struct inode___194 *, struct file___194 *);
	int (*fsync)(struct file___194 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___194 *, int);
	int (*lock)(struct file___194 *, int, struct file_lock___194 *);
	ssize_t (*sendpage)(struct file___194 *, struct page___199 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___194 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___194 *, long unsigned int);
	int (*flock)(struct file___194 *, int, struct file_lock___194 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___194 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___194 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___194 *, long int, struct file_lock___194 **, void **);
	long int (*fallocate)(struct file___194 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___170 *, struct file___194 *);
	ssize_t (*copy_file_range)(struct file___194 *, loff_t, struct file___194 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___194 *, loff_t, struct file___194 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___194 *, loff_t, loff_t, int);
};

struct vmacache___199 {
	u64 seqnum;
	struct vm_area_struct___199 *vmas[4];
};

struct page_frag___199 {
	struct page___199 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___200;

struct pid___172;

struct nsproxy___181;

struct signal_struct___195;

struct bio_list___98;

struct backing_dev_info___91;

struct io_context___98;

struct css_set___133;

struct mem_cgroup___82;

struct request_queue___98;

struct vm_struct___177;

struct task_struct___201 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___201 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___200 *mm;
	struct mm_struct___200 *active_mm;
	struct vmacache___199 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___201 *real_parent;
	struct task_struct___201 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___201 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___172 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___181 *nsproxy;
	struct signal_struct___195 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___201 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___98 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___91 *backing_dev_info;
	struct io_context___98 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___133 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___199 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___82 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___82 *active_memcg;
	struct request_queue___98 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___201 *oom_reaper_list;
	struct vm_struct___177 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___182;

struct kobj_type___182;

struct kernfs_node___182;

struct kobject___182 {
	const char *name;
	struct list_head entry;
	struct kobject___182 *parent;
	struct kset___182 *kset;
	struct kobj_type___182 *ktype;
	struct kernfs_node___182 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___178 {
	struct kobject___182 kobj;
	struct module___178 *mod;
	struct kobject___182 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___178 {
	struct module___178 *mod;
	struct latch_tree_node node;
};

struct module_layout___178 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___178 mtn;
};

struct module_attribute___178;

struct kernel_param___178;

struct module___178 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___178 mkobj;
	struct module_attribute___178 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___182 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___178 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___178 core_layout;
	struct module_layout___178 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___172;

struct upid___172 {
	int nr;
	struct pid_namespace___172 *ns;
};

struct pid_namespace___172 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___201 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___172 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___172 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___172 numbers[1];
};

typedef struct page___199 *pgtable_t___199;

struct address_space___194;

struct dev_pagemap___189;

struct page___199 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___194 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___199 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___199 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___200 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___189 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___189;

struct vm_area_struct___199 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___199 *vm_next;
	struct vm_area_struct___199 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___200 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___189 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___194 *vm_file;
	struct file___194 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___15;

struct signal_struct___195 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___201 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___201 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___172 *pids[4];
	struct pid___172 *tty_old_pgrp;
	int leader;
	struct tty_struct___15 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___200 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___199;

struct mm_struct___200 {
	struct {
		struct vm_area_struct___199 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___194 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___199 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___201 *owner;
		struct user_namespace___25 *user_ns;
		struct file___194 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___133;

struct nsproxy___181 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___172 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___133 *cgroup_ns;
};

struct bio___98;

struct bio_list___98 {
	struct bio___98 *head;
	struct bio___98 *tail;
};

struct cgroup_subsys_state___133;

struct bdi_writeback___91 {
	struct backing_dev_info___91 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___133 *memcg_css;
	struct cgroup_subsys_state___133 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___153;

struct backing_dev_info___91 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___91 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___153 *dev;
	char dev_name[64];
	struct device___153 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___194 *debug_dir;
};

struct io_cq___98;

struct io_context___98 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___98 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___133;

struct css_set___133 {
	struct cgroup_subsys_state___133 *subsys[14];
	refcount_t refcount;
	struct css_set___133 *dom_cset;
	struct cgroup___133 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___133 *mg_src_cgrp;
	struct cgroup___133 *mg_dst_cgrp;
	struct css_set___133 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___133;

struct cgroup_subsys_state___133 {
	struct cgroup___133 *cgroup;
	struct cgroup_subsys___133 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___133 *parent;
};

struct cgroup_file___133 {
	struct kernfs_node___182 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___82;

struct mem_cgroup_per_node___82;

struct mem_cgroup___82 {
	struct cgroup_subsys_state___133 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___133 events_file;
	struct cgroup_file___133 events_local_file;
	struct cgroup_file___133 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___82 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___201 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___82 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___98;

struct blk_integrity___98 {
	const struct blk_integrity_profile___98 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___98 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___98 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___98;

struct elevator_queue___98;

struct blk_mq_ops___95;

struct blk_mq_hw_ctx___95;

struct gendisk___99;

struct blkcg_gq___93;

struct blk_mq_tag_set___95;

struct request_queue___98 {
	struct request___98 *last_merge;
	struct elevator_queue___98 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___95 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___95 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___99 *disk;
	struct kobject___182 kobj;
	struct kobject___182 *mq_kobj;
	struct blk_integrity___98 integrity;
	struct device___153 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___93 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___95 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___98 bio_split;
	struct dentry___194 *debugfs_dir;
	struct dentry___194 *sched_debugfs_dir;
	struct dentry___194 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___177 {
	struct vm_struct___177 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___199 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___194;

struct address_space___194 {
	struct inode___194 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___194 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___189;

struct dev_pagemap___189 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___189 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___194;

struct path___194 {
	struct vfsmount___194 *mnt;
	struct dentry___194 *dentry;
};

struct fown_struct___172 {
	rwlock_t lock;
	struct pid___172 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___194 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___194 f_path;
	struct inode___194 *f_inode;
	const struct file_operations___195 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___172 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___194 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___189;

struct vm_operations_struct___189 {
	void (*open)(struct vm_area_struct___199 *);
	void (*close)(struct vm_area_struct___199 *);
	int (*may_split)(struct vm_area_struct___199 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___199 *);
	int (*mprotect)(struct vm_area_struct___199 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___189 *);
	vm_fault_t (*huge_fault)(struct vm_fault___189 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___189 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___199 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___189 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___189 *);
	int (*access)(struct vm_area_struct___199 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___199 *);
	int (*set_policy)(struct vm_area_struct___199 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___199 *, long unsigned int);
	struct page___199 * (*find_special_page)(struct vm_area_struct___199 *, long unsigned int);
};

struct core_thread___199 {
	struct task_struct___201 *task;
	struct core_thread___199 *next;
};

struct core_state___199 {
	atomic_t nr_threads;
	struct core_thread___199 dumper;
	struct completion startup;
};

struct vm_fault___189 {
	const struct {
		struct vm_area_struct___199 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___199 *cow_page;
	struct page___199 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___199 prealloc_pte;
};

struct pglist_data___89;

struct lruvec___89 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___89 *pgdat;
};

struct zone___89 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___89 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___89 {
	struct zone___89 *zone;
	int zone_idx;
};

struct zonelist___89 {
	struct zoneref___89 _zonerefs[321];
};

struct pglist_data___89 {
	struct zone___89 node_zones[5];
	struct zonelist___89 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___201 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___201 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___89 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___194;

struct dentry___194 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___194 *d_parent;
	struct qstr d_name;
	struct inode___194 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___194 *d_op;
	struct super_block___194 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___194;

struct cdev___41;

struct inode___194 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___194 *i_op;
	struct super_block___194 *i_sb;
	struct address_space___194 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___91 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___195 *i_fop;
		void (*free_inode)(struct inode___194 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___194 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___41 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___194 {
	int (*d_revalidate)(struct dentry___194 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___194 *, unsigned int);
	int (*d_hash)(const struct dentry___194 *, struct qstr *);
	int (*d_compare)(const struct dentry___194 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___194 *);
	int (*d_init)(struct dentry___194 *);
	void (*d_release)(struct dentry___194 *);
	void (*d_prune)(struct dentry___194 *);
	void (*d_iput)(struct dentry___194 *, struct inode___194 *);
	char * (*d_dname)(struct dentry___194 *, char *, int);
	struct vfsmount___194 * (*d_automount)(struct path___194 *);
	int (*d_manage)(const struct path___194 *, bool);
	struct dentry___194 * (*d_real)(struct dentry___194 *, const struct inode___194 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___194;

struct mem_dqinfo___194 {
	struct quota_format_type___194 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___194;

struct quota_info___194 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___194 *files[3];
	struct mem_dqinfo___194 info[3];
	const struct quota_format_ops___194 *ops[3];
};

struct rcuwait___195 {
	struct task_struct___201 *task;
};

struct percpu_rw_semaphore___195 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___195 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___194 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___195 rw_sem[3];
};

struct shrink_control___82;

struct shrinker___82 {
	long unsigned int (*count_objects)(struct shrinker___82 *, struct shrink_control___82 *);
	long unsigned int (*scan_objects)(struct shrinker___82 *, struct shrink_control___82 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___194;

struct dquot_operations___194;

struct quotactl_ops___194;

struct block_device___99;

struct super_block___194 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___194 *s_type;
	const struct super_operations___194 *s_op;
	const struct dquot_operations___194 *dq_op;
	const struct quotactl_ops___194 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___194 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___99 *s_bdev;
	struct backing_dev_info___91 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___194 s_dquot;
	struct sb_writers___194 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___194 *s_d_op;
	int cleancache_poolid;
	struct shrinker___82 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___194 {
	struct dentry___194 *mnt_root;
	struct super_block___194 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___82 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___82 *memcg;
};

struct psi_group___133 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___201 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___133;

struct cgroup_rstat_cpu___133;

struct cgroup___133 {
	struct cgroup_subsys_state___133 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___182 *kn;
	struct cgroup_file___133 procs_file;
	struct cgroup_file___133 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___133 *subsys[14];
	struct cgroup_root___133 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___133 *dom_cgrp;
	struct cgroup___133 *old_dom_cgrp;
	struct cgroup_rstat_cpu___133 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___133 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___16;

struct tty_operations___16;

struct tty_ldisc___15;

struct fasync_struct___194;

struct tty_port___16;

struct tty_struct___15 {
	int magic;
	struct kref kref;
	struct device___153 *dev;
	struct tty_driver___16 *driver;
	const struct tty_operations___16 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___15 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___172 *pgrp;
		struct pid___172 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___15 *link;
	struct fasync_struct___194 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___16 *port;
};

struct io_cq___98 {
	struct request_queue___98 *q;
	struct io_context___98 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___91;

struct kiocb___194 {
	struct file___194 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___194 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___91 *ki_waitq;
	};
};

struct iattr___194 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___194 *ia_file;
};

struct dquot___194 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___194 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___194 {
	int qf_fmt_id;
	const struct quota_format_ops___194 *qf_ops;
	struct module___178 *qf_owner;
	struct quota_format_type___194 *qf_next;
};

struct quota_format_ops___194 {
	int (*check_quota_file)(struct super_block___194 *, int);
	int (*read_file_info)(struct super_block___194 *, int);
	int (*write_file_info)(struct super_block___194 *, int);
	int (*free_file_info)(struct super_block___194 *, int);
	int (*read_dqblk)(struct dquot___194 *);
	int (*commit_dqblk)(struct dquot___194 *);
	int (*release_dqblk)(struct dquot___194 *);
	int (*get_next_id)(struct super_block___194 *, struct kqid *);
};

struct dquot_operations___194 {
	int (*write_dquot)(struct dquot___194 *);
	struct dquot___194 * (*alloc_dquot)(struct super_block___194 *, int);
	void (*destroy_dquot)(struct dquot___194 *);
	int (*acquire_dquot)(struct dquot___194 *);
	int (*release_dquot)(struct dquot___194 *);
	int (*mark_dirty)(struct dquot___194 *);
	int (*write_info)(struct super_block___194 *, int);
	qsize_t * (*get_reserved_space)(struct inode___194 *);
	int (*get_projid)(struct inode___194 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___194 *, qsize_t *);
	int (*get_next_id)(struct super_block___194 *, struct kqid *);
};

struct quotactl_ops___194 {
	int (*quota_on)(struct super_block___194 *, int, int, const struct path___194 *);
	int (*quota_off)(struct super_block___194 *, int);
	int (*quota_enable)(struct super_block___194 *, unsigned int);
	int (*quota_disable)(struct super_block___194 *, unsigned int);
	int (*quota_sync)(struct super_block___194 *, int);
	int (*set_info)(struct super_block___194 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___194 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___194 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___194 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___194 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___194 *, unsigned int);
};

struct wait_page_queue___91 {
	struct page___199 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___91;

struct readahead_control___91;

struct swap_info_struct___50;

struct address_space_operations___194 {
	int (*writepage)(struct page___199 *, struct writeback_control___91 *);
	int (*readpage)(struct file___194 *, struct page___199 *);
	int (*writepages)(struct address_space___194 *, struct writeback_control___91 *);
	int (*set_page_dirty)(struct page___199 *);
	int (*readpages)(struct file___194 *, struct address_space___194 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___91 *);
	int (*write_begin)(struct file___194 *, struct address_space___194 *, loff_t, unsigned int, unsigned int, struct page___199 **, void **);
	int (*write_end)(struct file___194 *, struct address_space___194 *, loff_t, unsigned int, unsigned int, struct page___199 *, void *);
	sector_t (*bmap)(struct address_space___194 *, sector_t);
	void (*invalidatepage)(struct page___199 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___199 *, gfp_t);
	void (*freepage)(struct page___199 *);
	ssize_t (*direct_IO)(struct kiocb___194 *, struct iov_iter___116 *);
	int (*migratepage)(struct address_space___194 *, struct page___199 *, struct page___199 *, enum migrate_mode);
	bool (*isolate_page)(struct page___199 *, isolate_mode_t);
	void (*putback_page)(struct page___199 *);
	int (*launder_page)(struct page___199 *);
	int (*is_partially_uptodate)(struct page___199 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___199 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___194 *, struct page___199 *);
	int (*swap_activate)(struct swap_info_struct___50 *, struct file___194 *, sector_t *);
	void (*swap_deactivate)(struct file___194 *);
};

struct writeback_control___91 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___91 *wb;
	struct inode___194 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___91 {
	struct file___194 *file;
	struct address_space___194 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___114;

struct iov_iter___116 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___114 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___50 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___99 *bdev;
	struct file___194 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___41 {
	struct kobject___182 kobj;
	struct module___178 *owner;
	const struct file_operations___195 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___194 {
	struct dentry___194 * (*lookup)(struct inode___194 *, struct dentry___194 *, unsigned int);
	const char * (*get_link)(struct dentry___194 *, struct inode___194 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___194 *, int);
	struct posix_acl * (*get_acl)(struct inode___194 *, int, bool);
	int (*readlink)(struct dentry___194 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___194 *, struct dentry___194 *, umode_t, bool);
	int (*link)(struct dentry___194 *, struct inode___194 *, struct dentry___194 *);
	int (*unlink)(struct inode___194 *, struct dentry___194 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___194 *, struct dentry___194 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___194 *, struct dentry___194 *, umode_t);
	int (*rmdir)(struct inode___194 *, struct dentry___194 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___194 *, struct dentry___194 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___194 *, struct dentry___194 *, struct inode___194 *, struct dentry___194 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___194 *, struct iattr___194 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___194 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___194 *, char *, size_t);
	int (*fiemap)(struct inode___194 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___194 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___194 *, struct dentry___194 *, struct file___194 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___194 *, struct dentry___194 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___194 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___194 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___194 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___194 {
	void (*fl_copy_lock)(struct file_lock___194 *, struct file_lock___194 *);
	void (*fl_release_private)(struct file_lock___194 *);
};

struct lock_manager_operations___194;

struct file_lock___194 {
	struct file_lock___194 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___194 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___194 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___194 *fl_ops;
	const struct lock_manager_operations___194 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___194 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___194 *);
	int (*lm_grant)(struct file_lock___194 *, int);
	bool (*lm_break)(struct file_lock___194 *);
	int (*lm_change)(struct file_lock___194 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___194 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___194 *);
};

struct fasync_struct___194 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___194 *fa_next;
	struct file___194 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___194 {
	struct inode___194 * (*alloc_inode)(struct super_block___194 *);
	void (*destroy_inode)(struct inode___194 *);
	void (*free_inode)(struct inode___194 *);
	void (*dirty_inode)(struct inode___194 *, int);
	int (*write_inode)(struct inode___194 *, struct writeback_control___91 *);
	int (*drop_inode)(struct inode___194 *);
	void (*evict_inode)(struct inode___194 *);
	void (*put_super)(struct super_block___194 *);
	int (*sync_fs)(struct super_block___194 *, int);
	int (*freeze_super)(struct super_block___194 *);
	int (*freeze_fs)(struct super_block___194 *);
	int (*thaw_super)(struct super_block___194 *);
	int (*unfreeze_fs)(struct super_block___194 *);
	int (*statfs)(struct dentry___194 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___194 *, int *, char *);
	void (*umount_begin)(struct super_block___194 *);
	int (*show_options)(struct seq_file___170 *, struct dentry___194 *);
	int (*show_devname)(struct seq_file___170 *, struct dentry___194 *);
	int (*show_path)(struct seq_file___170 *, struct dentry___194 *);
	int (*show_stats)(struct seq_file___170 *, struct dentry___194 *);
	ssize_t (*quota_read)(struct super_block___194 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___194 *, int, const char *, size_t, loff_t);
	struct dquot___194 ** (*get_dquots)(struct inode___194 *);
	long int (*nr_cached_objects)(struct super_block___194 *, struct shrink_control___82 *);
	long int (*free_cached_objects)(struct super_block___194 *, struct shrink_control___82 *);
	struct file___194 * (*real_loop)(struct file___194 *);
};

struct wakeup_source___153;

struct dev_pm_info___153 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___153 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___153 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___153;

struct bus_type___153;

struct device_driver___153;

struct dev_pm_domain___153;

struct irq_domain___34;

struct device_node___55;

struct fwnode_handle___153;

struct class___153;

struct attribute_group___182;

struct device___153 {
	struct kobject___182 kobj;
	struct device___153 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___153 *type;
	struct bus_type___153 *bus;
	struct device_driver___153 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___153 power;
	struct dev_pm_domain___153 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___34 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___55 *of_node;
	struct fwnode_handle___153 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___153 *class;
	const struct attribute_group___182 **groups;
	void (*release)(struct device___153 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___99 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___194 *bd_inode;
	struct super_block___194 *bd_super;
	void *bd_claiming;
	struct device___153 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___182 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___99 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___194 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___131)(struct file___194 *, wait_queue_head_t *, struct poll_table_struct___126 *);

struct poll_table_struct___126 {
	poll_queue_proc___131 _qproc;
	__poll_t _key;
};

struct seq_operations___170;

struct seq_file___170 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___170 *op;
	int poll_event;
	const struct file___194 *file;
	void *private;
};

typedef void bio_end_io_t___98(struct bio___98 *);

struct bio_vec___114 {
	struct page___199 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___98;

struct bio___98 {
	struct bio___98 *bi_next;
	struct block_device___99 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___98 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___93 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___98 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___114 *bi_io_vec;
	struct bio_set___98 *bi_pool;
	struct bio_vec___114 bi_inline_vecs[0];
};

struct kernfs_root___182;

struct kernfs_elem_dir___182 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___182 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___182;

struct kernfs_root___182 {
	struct kernfs_node___182 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___182 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___182 {
	struct kernfs_node___182 *target_kn;
};

struct kernfs_ops___182;

struct kernfs_elem_attr___182 {
	const struct kernfs_ops___182 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___182 *notify_next;
};

struct kernfs_node___182 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___182 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___182 dir;
		struct kernfs_elem_symlink___182 symlink;
		struct kernfs_elem_attr___182 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___182;

struct kernfs_ops___182 {
	int (*open)(struct kernfs_open_file___182 *);
	void (*release)(struct kernfs_open_file___182 *);
	int (*seq_show)(struct seq_file___170 *, void *);
	void * (*seq_start)(struct seq_file___170 *, loff_t *);
	void * (*seq_next)(struct seq_file___170 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___170 *, void *);
	ssize_t (*read)(struct kernfs_open_file___182 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___182 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___182 *, struct poll_table_struct___126 *);
	int (*mmap)(struct kernfs_open_file___182 *, struct vm_area_struct___199 *);
};

struct kernfs_syscall_ops___182 {
	int (*show_options)(struct seq_file___170 *, struct kernfs_root___182 *);
	int (*mkdir)(struct kernfs_node___182 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___182 *);
	int (*rename)(struct kernfs_node___182 *, struct kernfs_node___182 *, const char *);
	int (*show_path)(struct seq_file___170 *, struct kernfs_node___182 *, struct kernfs_root___182 *);
};

struct kernfs_open_file___182 {
	struct kernfs_node___182 *kn;
	struct file___194 *file;
	struct seq_file___170 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___189 *vm_ops;
};

struct bin_attribute___182;

struct attribute_group___182 {
	const char *name;
	umode_t (*is_visible)(struct kobject___182 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___182 *, struct bin_attribute___182 *, int);
	struct attribute **attrs;
	struct bin_attribute___182 **bin_attrs;
};

struct bin_attribute___182 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___194 * (*f_mapping)();
	ssize_t (*read)(struct file___194 *, struct kobject___182 *, struct bin_attribute___182 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___194 *, struct kobject___182 *, struct bin_attribute___182 *, char *, loff_t, size_t);
	int (*mmap)(struct file___194 *, struct kobject___182 *, struct bin_attribute___182 *, struct vm_area_struct___199 *);
};

struct sysfs_ops___182 {
	ssize_t (*show)(struct kobject___182 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___182 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___182;

struct kset___182 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___182 kobj;
	const struct kset_uevent_ops___182 *uevent_ops;
};

struct kobj_type___182 {
	void (*release)(struct kobject___182 *);
	const struct sysfs_ops___182 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___182 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___182 *);
	const void * (*namespace)(struct kobject___182 *);
	void (*get_ownership)(struct kobject___182 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___182 {
	int (* const filter)(struct kset___182 *, struct kobject___182 *);
	const char * (* const name)(struct kset___182 *, struct kobject___182 *);
	int (* const uevent)(struct kset___182 *, struct kobject___182 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___178 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___178 *);
	int (*get)(char *, const struct kernel_param___178 *);
	void (*free)(void *);
};

struct kparam_array___178;

struct kernel_param___178 {
	const char *name;
	struct module___178 *mod;
	const struct kernel_param_ops___178 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___178 *arr;
	};
};

struct kparam_array___178 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___178 *ops;
	void *elem;
};

struct module_attribute___178 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___178 *, struct module_kobject___178 *, char *);
	ssize_t (*store)(struct module_attribute___178 *, struct module_kobject___178 *, const char *, size_t);
	void (*setup)(struct module___178 *, const char *);
	int (*test)(struct module___178 *);
	void (*free)(struct module___178 *);
};

struct vc_data___2;

struct consw___2 {
	struct module___178 *owner;
	const char * (*con_startup)();
	void (*con_init)(struct vc_data___2 *, int);
	void (*con_deinit)(struct vc_data___2 *);
	void (*con_clear)(struct vc_data___2 *, int, int, int, int);
	void (*con_putc)(struct vc_data___2 *, int, int, int);
	void (*con_putcs)(struct vc_data___2 *, const short unsigned int *, int, int, int);
	void (*con_cursor)(struct vc_data___2 *, int);
	bool (*con_scroll)(struct vc_data___2 *, unsigned int, unsigned int, enum con_scroll, unsigned int);
	int (*con_switch)(struct vc_data___2 *);
	int (*con_blank)(struct vc_data___2 *, int, int);
	int (*con_font_set)(struct vc_data___2 *, struct console_font *, unsigned int);
	int (*con_font_get)(struct vc_data___2 *, struct console_font *);
	int (*con_font_default)(struct vc_data___2 *, struct console_font *, char *);
	int (*con_resize)(struct vc_data___2 *, unsigned int, unsigned int, unsigned int);
	void (*con_set_palette)(struct vc_data___2 *, const unsigned char *);
	void (*con_scrolldelta)(struct vc_data___2 *, int);
	int (*con_set_origin)(struct vc_data___2 *);
	void (*con_save_screen)(struct vc_data___2 *);
	u8 (*con_build_attr)(struct vc_data___2 *, u8, enum vc_intensity, bool, bool, bool, bool);
	void (*con_invert_region)(struct vc_data___2 *, u16 *, int);
	u16 * (*con_screen_pos)(const struct vc_data___2 *, int);
	long unsigned int (*con_getxy)(struct vc_data___2 *, long unsigned int, int *, int *);
	void (*con_flush_scrollback)(struct vc_data___2 *);
	int (*con_debug_enter)(struct vc_data___2 *);
	int (*con_debug_leave)(struct vc_data___2 *);
};

struct tty_port_operations___15;

struct tty_port_client_operations___15;

struct tty_port___16 {
	struct tty_bufhead buf;
	struct tty_struct___15 *tty;
	struct tty_struct___15 *itty;
	const struct tty_port_operations___15 *ops;
	const struct tty_port_client_operations___15 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct vc_data___2 {
	struct tty_port___16 port;
	struct vc_state state;
	struct vc_state saved_state;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	unsigned int vc_cell_height;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___2 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___172 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_priv: 3;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned char vc_utf_count;
	int vc_utf_char;
	long unsigned int vc_tab_stop[4];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___2 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
	struct uni_screen *vc_uni_screen;
};

struct tty_driver___16 {
	int magic;
	struct kref kref;
	struct cdev___41 **cdevs;
	struct module___178 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___16 *other;
	struct tty_struct___15 **ttys;
	struct tty_port___16 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___16 *ops;
	struct list_head tty_drivers;
};

struct irq_desc___36;

typedef void (*irq_flow_handler_t___36)(struct irq_desc___36 *);

struct irq_chip___35;

struct irq_data___35 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___35 *chip;
	struct irq_domain___34 *domain;
	struct irq_data___35 *parent_data;
	void *chip_data;
};

struct irqaction___25;

struct irq_desc___36 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___35 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___36 handle_irq;
	struct irqaction___25 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___182 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___178 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___153;

struct fwnode_handle___153 {
	struct fwnode_handle___153 *secondary;
	const struct fwnode_operations___153 *ops;
	struct device___153 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___153;

struct fwnode_endpoint___153;

struct fwnode_operations___153 {
	struct fwnode_handle___153 * (*get)(struct fwnode_handle___153 *);
	void (*put)(struct fwnode_handle___153 *);
	bool (*device_is_available)(const struct fwnode_handle___153 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___153 *, const struct device___153 *);
	bool (*property_present)(const struct fwnode_handle___153 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___153 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___153 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___153 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*get_parent)(const struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*get_next_child_node)(const struct fwnode_handle___153 *, struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*get_named_child_node)(const struct fwnode_handle___153 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___153 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___153 *);
	struct fwnode_handle___153 * (*graph_get_next_endpoint)(const struct fwnode_handle___153 *, struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*graph_get_remote_endpoint)(const struct fwnode_handle___153 *);
	struct fwnode_handle___153 * (*graph_get_port_parent)(struct fwnode_handle___153 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___153 *, struct fwnode_endpoint___153 *);
	int (*add_links)(struct fwnode_handle___153 *);
};

struct fwnode_endpoint___153 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___153 *local_fwnode;
};

struct fwnode_reference_args___153 {
	struct fwnode_handle___153 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___35 {
	struct device___153 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___35 *);
	void (*irq_shutdown)(struct irq_data___35 *);
	void (*irq_enable)(struct irq_data___35 *);
	void (*irq_disable)(struct irq_data___35 *);
	void (*irq_ack)(struct irq_data___35 *);
	void (*irq_mask)(struct irq_data___35 *);
	void (*irq_mask_ack)(struct irq_data___35 *);
	void (*irq_unmask)(struct irq_data___35 *);
	void (*irq_eoi)(struct irq_data___35 *);
	int (*irq_set_affinity)(struct irq_data___35 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___35 *);
	int (*irq_set_type)(struct irq_data___35 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___35 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___35 *);
	void (*irq_bus_sync_unlock)(struct irq_data___35 *);
	void (*irq_cpu_online)(struct irq_data___35 *);
	void (*irq_cpu_offline)(struct irq_data___35 *);
	void (*irq_suspend)(struct irq_data___35 *);
	void (*irq_resume)(struct irq_data___35 *);
	void (*irq_pm_shutdown)(struct irq_data___35 *);
	void (*irq_calc_mask)(struct irq_data___35 *);
	void (*irq_print_chip)(struct irq_data___35 *, struct seq_file___170 *);
	int (*irq_request_resources)(struct irq_data___35 *);
	void (*irq_release_resources)(struct irq_data___35 *);
	void (*irq_compose_msi_msg)(struct irq_data___35 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___35 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___35 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___35 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___35 *, void *);
	void (*ipi_send_single)(struct irq_data___35 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___35 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___35 *);
	void (*irq_nmi_teardown)(struct irq_data___35 *);
	long unsigned int flags;
};

struct irq_domain_ops___34;

struct irq_domain_chip_generic___34;

struct irq_domain___34 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___34 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___153 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___34 *gc;
	struct irq_domain___34 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___35 *revmap[0];
};

struct irqaction___25 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___25 *next;
	irq_handler_t thread_fn;
	struct task_struct___201 *thread;
	struct irqaction___25 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___34 {
	struct irq_chip___35 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___36 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___34 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___34 *);
	void (*resume)(struct irq_chip_generic___34 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___34 *domain;
	struct list_head list;
	struct irq_chip_type___34 chip_types[0];
};

struct irq_domain_chip_generic___34 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___34 *gc[0];
};

struct dev_pagemap_ops___189 {
	void (*page_free)(struct page___199 *);
	void (*kill)(struct dev_pagemap___189 *);
	void (*cleanup)(struct dev_pagemap___189 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___189 *);
};

struct cgroup_namespace___133 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___133 *root_cset;
};

struct property___44 {
	char *name;
	int length;
	void *value;
	struct property___44 *next;
	long unsigned int _flags;
	struct bin_attribute___182 attr;
};

struct device_node___55 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___153 fwnode;
	struct property___44 *properties;
	struct property___44 *deadprops;
	struct device_node___55 *parent;
	struct device_node___55 *child;
	struct device_node___55 *sibling;
	struct kobject___182 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___32 {
	struct fwnode_handle___153 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___34 {
	int (*match)(struct irq_domain___34 *, struct device_node___55 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___34 *, struct irq_fwspec___32 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___34 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___34 *, unsigned int);
	int (*xlate)(struct irq_domain___34 *, struct device_node___55 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___34 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___34 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___34 *, struct irq_data___35 *, bool);
	void (*deactivate)(struct irq_domain___34 *, struct irq_data___35 *);
	int (*translate)(struct irq_domain___34 *, struct irq_fwspec___32 *, long unsigned int *, unsigned int *);
};

struct dev_pm_ops___153 {
	int (*prepare)(struct device___153 *);
	void (*complete)(struct device___153 *);
	int (*suspend)(struct device___153 *);
	int (*resume)(struct device___153 *);
	int (*freeze)(struct device___153 *);
	int (*thaw)(struct device___153 *);
	int (*poweroff)(struct device___153 *);
	int (*restore)(struct device___153 *);
	int (*suspend_late)(struct device___153 *);
	int (*resume_early)(struct device___153 *);
	int (*freeze_late)(struct device___153 *);
	int (*thaw_early)(struct device___153 *);
	int (*poweroff_late)(struct device___153 *);
	int (*restore_early)(struct device___153 *);
	int (*suspend_noirq)(struct device___153 *);
	int (*resume_noirq)(struct device___153 *);
	int (*freeze_noirq)(struct device___153 *);
	int (*thaw_noirq)(struct device___153 *);
	int (*poweroff_noirq)(struct device___153 *);
	int (*restore_noirq)(struct device___153 *);
	int (*runtime_suspend)(struct device___153 *);
	int (*runtime_resume)(struct device___153 *);
	int (*runtime_idle)(struct device___153 *);
};

struct wakeup_source___153 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___153 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___153 {
	struct dev_pm_ops___153 ops;
	int (*start)(struct device___153 *);
	void (*detach)(struct device___153 *, bool);
	int (*activate)(struct device___153 *);
	void (*sync)(struct device___153 *);
	void (*dismiss)(struct device___153 *);
};

struct bus_type___153 {
	const char *name;
	const char *dev_name;
	struct device___153 *dev_root;
	const struct attribute_group___182 **bus_groups;
	const struct attribute_group___182 **dev_groups;
	const struct attribute_group___182 **drv_groups;
	int (*match)(struct device___153 *, struct device_driver___153 *);
	int (*uevent)(struct device___153 *, struct kobj_uevent_env *);
	int (*probe)(struct device___153 *);
	void (*sync_state)(struct device___153 *);
	void (*remove)(struct device___153 *);
	void (*shutdown)(struct device___153 *);
	int (*online)(struct device___153 *);
	int (*offline)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	int (*num_vf)(struct device___153 *);
	int (*dma_configure)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___153 {
	const char *name;
	struct bus_type___153 *bus;
	struct module___178 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___153 *);
	void (*sync_state)(struct device___153 *);
	int (*remove)(struct device___153 *);
	void (*shutdown)(struct device___153 *);
	int (*suspend)(struct device___153 *, pm_message_t);
	int (*resume)(struct device___153 *);
	const struct attribute_group___182 **groups;
	const struct attribute_group___182 **dev_groups;
	const struct dev_pm_ops___153 *pm;
	void (*coredump)(struct device___153 *);
	struct driver_private *p;
};

struct device_type___153 {
	const char *name;
	const struct attribute_group___182 **groups;
	int (*uevent)(struct device___153 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___153 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___153 *);
	const struct dev_pm_ops___153 *pm;
};

struct class___153 {
	const char *name;
	struct module___178 *owner;
	const struct attribute_group___182 **class_groups;
	const struct attribute_group___182 **dev_groups;
	struct kobject___182 *dev_kobj;
	int (*dev_uevent)(struct device___153 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___153 *, umode_t *);
	void (*class_release)(struct class___153 *);
	void (*dev_release)(struct device___153 *);
	int (*shutdown_pre)(struct device___153 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___153 *);
	void (*get_ownership)(struct device___153 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___153 *pm;
	struct subsys_private *p;
};

struct device_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct device___153 *, struct device_attribute___14 *, char *);
	ssize_t (*store)(struct device___153 *, struct device_attribute___14 *, const char *, size_t);
};

struct seq_operations___170 {
	void * (*start)(struct seq_file___170 *, loff_t *);
	void (*stop)(struct seq_file___170 *, void *);
	void * (*next)(struct seq_file___170 *, void *, loff_t *);
	int (*show)(struct seq_file___170 *, void *);
};

struct cftype___133;

struct cgroup_subsys___133 {
	struct cgroup_subsys_state___133 * (*css_alloc)(struct cgroup_subsys_state___133 *);
	int (*css_online)(struct cgroup_subsys_state___133 *);
	void (*css_offline)(struct cgroup_subsys_state___133 *);
	void (*css_released)(struct cgroup_subsys_state___133 *);
	void (*css_free)(struct cgroup_subsys_state___133 *);
	void (*css_reset)(struct cgroup_subsys_state___133 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___133 *, int);
	int (*css_extra_stat_show)(struct seq_file___170 *, struct cgroup_subsys_state___133 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___201 *, struct css_set___133 *);
	void (*cancel_fork)(struct task_struct___201 *, struct css_set___133 *);
	void (*fork)(struct task_struct___201 *);
	void (*exit)(struct task_struct___201 *);
	void (*release)(struct task_struct___201 *);
	void (*bind)(struct cgroup_subsys_state___133 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___133 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___133 *dfl_cftypes;
	struct cftype___133 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___133 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___133 *updated_children;
	struct cgroup___133 *updated_next;
};

struct cgroup_root___133 {
	struct kernfs_root___182 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___133 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___133 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___133 *ss;
	struct list_head node;
	struct kernfs_ops___182 *kf_ops;
	int (*open)(struct kernfs_open_file___182 *);
	void (*release)(struct kernfs_open_file___182 *);
	u64 (*read_u64)(struct cgroup_subsys_state___133 *, struct cftype___133 *);
	s64 (*read_s64)(struct cgroup_subsys_state___133 *, struct cftype___133 *);
	int (*seq_show)(struct seq_file___170 *, void *);
	void * (*seq_start)(struct seq_file___170 *, loff_t *);
	void * (*seq_next)(struct seq_file___170 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___170 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___133 *, struct cftype___133 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___133 *, struct cftype___133 *, s64);
	ssize_t (*write)(struct kernfs_open_file___182 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___182 *, struct poll_table_struct___126 *);
};

struct block_device_operations___98;

struct gendisk___99 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___99 *part0;
	const struct block_device_operations___98 *fops;
	struct request_queue___98 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___91 *bdi;
	struct kobject___182 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___182 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___98 {
	struct bio___98 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___114 *bip_vec;
	struct bio_vec___114 bip_inline_vecs[0];
};

struct blkcg___93;

struct blkg_policy_data___93;

struct blkcg_gq___93 {
	struct request_queue___98 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___93 *blkcg;
	struct blkcg_gq___93 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___93 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___98 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___98(struct request___98 *);

typedef void integrity_complete_fn___98(struct request___98 *, unsigned int);

struct blk_integrity_profile___98 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___98 *prepare_fn;
	integrity_complete_fn___98 *complete_fn;
	const char *name;
};

struct block_device_operations___98 {
	blk_qc_t (*submit_bio)(struct bio___98 *);
	int (*open)(struct block_device___99 *, fmode_t);
	void (*release)(struct gendisk___99 *, fmode_t);
	int (*rw_page)(struct block_device___99 *, sector_t, struct page___199 *, unsigned int);
	int (*ioctl)(struct block_device___99 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___99 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___99 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___99 *);
	int (*getgeo)(struct block_device___99 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___99 *, bool);
	void (*swap_slot_free_notify)(struct block_device___99 *, long unsigned int);
	int (*report_zones)(struct gendisk___99 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___99 *, umode_t *);
	struct module___178 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___99 *, sector_t *);
};

typedef void rq_end_io_fn___98(struct request___98 *, blk_status_t);

struct request___98 {
	struct request_queue___98 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___95 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___98 *bio;
	struct bio___98 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___114 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___98 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___98 *saved_end_io;
		} flush;
	};
	struct gendisk___99 *rq_disk;
	struct block_device___99 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___98 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___95 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___98 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___182 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___194 *debugfs_dir;
	struct dentry___194 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___98;

struct elevator_mq_ops___98 {
	int (*init_sched)(struct request_queue___98 *, struct elevator_type___98 *);
	void (*exit_sched)(struct elevator_queue___98 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___95 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___95 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___95 *);
	bool (*allow_merge)(struct request_queue___98 *, struct request___98 *, struct bio___98 *);
	bool (*bio_merge)(struct request_queue___98 *, struct bio___98 *, unsigned int);
	int (*request_merge)(struct request_queue___98 *, struct request___98 **, struct bio___98 *);
	void (*request_merged)(struct request_queue___98 *, struct request___98 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___98 *, struct request___98 *, struct request___98 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___98 *);
	void (*finish_request)(struct request___98 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___95 *, struct list_head *, bool);
	struct request___98 * (*dispatch_request)(struct blk_mq_hw_ctx___95 *);
	bool (*has_work)(struct blk_mq_hw_ctx___95 *);
	void (*completed_request)(struct request___98 *, u64);
	void (*requeue_request)(struct request___98 *);
	struct request___98 * (*former_request)(struct request_queue___98 *, struct request___98 *);
	struct request___98 * (*next_request)(struct request_queue___98 *, struct request___98 *);
	void (*init_icq)(struct io_cq___98 *);
	void (*exit_icq)(struct io_cq___98 *);
};

struct elv_fs_entry___98;

struct elevator_type___98 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___98 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___98 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___178 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___98 {
	struct elevator_type___98 *type;
	void *elevator_data;
	struct kobject___182 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___98 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___98 *, char *);
	ssize_t (*store)(struct elevator_queue___98 *, const char *, size_t);
};

struct blk_mq_queue_data___95;

struct blk_mq_ops___95 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___95 *, const struct blk_mq_queue_data___95 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___95 *);
	int (*get_budget)(struct request_queue___98 *);
	void (*put_budget)(struct request_queue___98 *, int);
	void (*set_rq_budget_token)(struct request___98 *, int);
	int (*get_rq_budget_token)(struct request___98 *);
	enum blk_eh_timer_return (*timeout)(struct request___98 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___95 *);
	void (*complete)(struct request___98 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___95 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___95 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___95 *, struct request___98 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___95 *, struct request___98 *, unsigned int);
	void (*initialize_rq_fn)(struct request___98 *);
	void (*cleanup_rq)(struct request___98 *);
	bool (*busy)(struct request_queue___98 *);
	int (*map_queues)(struct blk_mq_tag_set___95 *);
	void (*show_rq)(struct seq_file___170 *, struct request___98 *);
};

struct blk_mq_tag_set___95 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___95 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___95 {
	struct request___98 *rq;
	bool last;
};

struct blkcg_policy_data___93;

struct blkcg___93 {
	struct cgroup_subsys_state___133 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___93 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___93 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___93 {
	struct blkcg___93 *blkcg;
	int plid;
};

struct blkg_policy_data___93 {
	struct blkcg_gq___93 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___82 {
	struct mem_cgroup___82 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___82 {
	struct lruvec___89 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___82 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___82 *memcg;
};

struct obj_cgroup___82 {
	struct percpu_ref refcnt;
	struct mem_cgroup___82 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fb_con2fbmap {
	__u32 console;
	__u32 framebuffer;
};

struct backlight_device___3;

struct fb_info___3;

struct backlight_ops___3 {
	unsigned int options;
	int (*update_status)(struct backlight_device___3 *);
	int (*get_brightness)(struct backlight_device___3 *);
	int (*check_fb)(struct backlight_device___3 *, struct fb_info___3 *);
};

struct backlight_device___3 {
	struct backlight_properties props;
	struct mutex update_lock;
	struct mutex ops_lock;
	const struct backlight_ops___3 *ops;
	struct notifier_block fb_notif;
	struct list_head entry;
	struct device___153 dev;
	bool fb_bl_on[32];
	int use_count;
};

struct fb_pixmap___3 {
	u8 *addr;
	u32 size;
	u32 offset;
	u32 buf_align;
	u32 scan_align;
	u32 access_align;
	u32 flags;
	u32 blit_x;
	u32 blit_y;
	void (*writeio)(struct fb_info___3 *, void *, void *, unsigned int);
	void (*readio)(struct fb_info___3 *, void *, void *, unsigned int);
};

struct fb_deferred_io___3;

struct fb_ops___3;

struct fb_tile_ops___3;

struct fb_info___3 {
	refcount_t count;
	int node;
	int flags;
	int fbcon_rotate_hint;
	struct mutex lock;
	struct mutex mm_lock;
	struct fb_var_screeninfo var;
	struct fb_fix_screeninfo fix;
	struct fb_monspecs monspecs;
	struct work_struct queue;
	struct fb_pixmap___3 pixmap;
	struct fb_pixmap___3 sprite;
	struct fb_cmap cmap;
	struct list_head modelist;
	struct fb_videomode *mode;
	struct backlight_device___3 *bl_dev;
	struct mutex bl_curve_mutex;
	u8 bl_curve[128];
	struct delayed_work deferred_work;
	struct fb_deferred_io___3 *fbdefio;
	const struct fb_ops___3 *fbops;
	struct device___153 *device;
	struct device___153 *dev;
	int class_flag;
	struct fb_tile_ops___3 *tileops;
	union {
		char *screen_base;
		char *screen_buffer;
	};
	long unsigned int screen_size;
	void *pseudo_palette;
	u32 state;
	void *fbcon_par;
	void *par;
	struct apertures_struct *apertures;
	bool skip_vt_switch;
	bool forced_out;
};

struct fb_deferred_io___3 {
	long unsigned int delay;
	struct mutex lock;
	struct list_head pagelist;
	void (*first_io)(struct fb_info___3 *);
	void (*deferred_io)(struct fb_info___3 *, struct list_head *);
};

struct fb_ops___3 {
	struct module___178 *owner;
	int (*fb_open)(struct fb_info___3 *, int);
	int (*fb_release)(struct fb_info___3 *, int);
	ssize_t (*fb_read)(struct fb_info___3 *, char *, size_t, loff_t *);
	ssize_t (*fb_write)(struct fb_info___3 *, const char *, size_t, loff_t *);
	int (*fb_check_var)(struct fb_var_screeninfo *, struct fb_info___3 *);
	int (*fb_set_par)(struct fb_info___3 *);
	int (*fb_setcolreg)(unsigned int, unsigned int, unsigned int, unsigned int, unsigned int, struct fb_info___3 *);
	int (*fb_setcmap)(struct fb_cmap *, struct fb_info___3 *);
	int (*fb_blank)(int, struct fb_info___3 *);
	int (*fb_pan_display)(struct fb_var_screeninfo *, struct fb_info___3 *);
	void (*fb_fillrect)(struct fb_info___3 *, const struct fb_fillrect *);
	void (*fb_copyarea)(struct fb_info___3 *, const struct fb_copyarea *);
	void (*fb_imageblit)(struct fb_info___3 *, const struct fb_image *);
	int (*fb_cursor)(struct fb_info___3 *, struct fb_cursor *);
	int (*fb_sync)(struct fb_info___3 *);
	int (*fb_ioctl)(struct fb_info___3 *, unsigned int, long unsigned int);
	int (*fb_compat_ioctl)(struct fb_info___3 *, unsigned int, long unsigned int);
	int (*fb_mmap)(struct fb_info___3 *, struct vm_area_struct___199 *);
	void (*fb_get_caps)(struct fb_info___3 *, struct fb_blit_caps *, struct fb_var_screeninfo *);
	void (*fb_destroy)(struct fb_info___3 *);
	int (*fb_debug_enter)(struct fb_info___3 *);
	int (*fb_debug_leave)(struct fb_info___3 *);
};

struct fb_tile_ops___3 {
	void (*fb_settile)(struct fb_info___3 *, struct fb_tilemap *);
	void (*fb_tilecopy)(struct fb_info___3 *, struct fb_tilearea *);
	void (*fb_tilefill)(struct fb_info___3 *, struct fb_tilerect *);
	void (*fb_tileblit)(struct fb_info___3 *, struct fb_tileblit *);
	void (*fb_tilecursor)(struct fb_info___3 *, struct fb_tilecursor *);
	int (*fb_get_tilemax)(struct fb_info___3 *);
};

struct tty_operations___16 {
	struct tty_struct___15 * (*lookup)(struct tty_driver___16 *, struct file___194 *, int);
	int (*install)(struct tty_driver___16 *, struct tty_struct___15 *);
	void (*remove)(struct tty_driver___16 *, struct tty_struct___15 *);
	int (*open)(struct tty_struct___15 *, struct file___194 *);
	void (*close)(struct tty_struct___15 *, struct file___194 *);
	void (*shutdown)(struct tty_struct___15 *);
	void (*cleanup)(struct tty_struct___15 *);
	int (*write)(struct tty_struct___15 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___15 *, unsigned char);
	void (*flush_chars)(struct tty_struct___15 *);
	unsigned int (*write_room)(struct tty_struct___15 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___15 *);
	int (*ioctl)(struct tty_struct___15 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___15 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___15 *, struct ktermios *);
	void (*throttle)(struct tty_struct___15 *);
	void (*unthrottle)(struct tty_struct___15 *);
	void (*stop)(struct tty_struct___15 *);
	void (*start)(struct tty_struct___15 *);
	void (*hangup)(struct tty_struct___15 *);
	int (*break_ctl)(struct tty_struct___15 *, int);
	void (*flush_buffer)(struct tty_struct___15 *);
	void (*set_ldisc)(struct tty_struct___15 *);
	void (*wait_until_sent)(struct tty_struct___15 *, int);
	void (*send_xchar)(struct tty_struct___15 *, char);
	int (*tiocmget)(struct tty_struct___15 *);
	int (*tiocmset)(struct tty_struct___15 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___15 *, struct winsize *);
	int (*get_icount)(struct tty_struct___15 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___15 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___15 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___15 *, struct seq_file___170 *);
	int (*poll_init)(struct tty_driver___16 *, int, char *);
	int (*poll_get_char)(struct tty_driver___16 *, int);
	void (*poll_put_char)(struct tty_driver___16 *, int, char);
	int (*proc_show)(struct seq_file___170 *, void *);
};

struct tty_ldisc_ops___15 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___15 *);
	void (*close)(struct tty_struct___15 *);
	void (*flush_buffer)(struct tty_struct___15 *);
	ssize_t (*read)(struct tty_struct___15 *, struct file___194 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___15 *, struct file___194 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___15 *, struct file___194 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___15 *, struct file___194 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___15 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___15 *, struct file___194 *, struct poll_table_struct___126 *);
	int (*hangup)(struct tty_struct___15 *);
	void (*receive_buf)(struct tty_struct___15 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___15 *);
	void (*dcd_change)(struct tty_struct___15 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___15 *, const unsigned char *, const char *, int);
	struct module___178 *owner;
};

struct tty_ldisc___15 {
	struct tty_ldisc_ops___15 *ops;
	struct tty_struct___15 *tty;
};

struct tty_port_operations___15 {
	int (*carrier_raised)(struct tty_port___16 *);
	void (*dtr_rts)(struct tty_port___16 *, int);
	void (*shutdown)(struct tty_port___16 *);
	int (*activate)(struct tty_port___16 *, struct tty_struct___15 *);
	void (*destruct)(struct tty_port___16 *);
};

struct tty_port_client_operations___15 {
	int (*receive_buf)(struct tty_port___16 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___16 *);
};

struct vc {
	struct vc_data___2 *d;
	struct work_struct SAK_work;
};

struct fbcon_display {
	const u_char *fontdata;
	int userfont;
	u_short inverse;
	short int yscroll;
	int vrows;
	int cursor_shape;
	int con_rotate;
	u32 xres_virtual;
	u32 yres_virtual;
	u32 height;
	u32 width;
	u32 bits_per_pixel;
	u32 grayscale;
	u32 nonstd;
	u32 accel_flags;
	u32 rotate;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	const struct fb_videomode *mode;
};

struct fbcon_ops {
	void (*bmove)(struct vc_data___2 *, struct fb_info___3 *, int, int, int, int, int, int);
	void (*clear)(struct vc_data___2 *, struct fb_info___3 *, int, int, int, int);
	void (*putcs)(struct vc_data___2 *, struct fb_info___3 *, const short unsigned int *, int, int, int, int, int);
	void (*clear_margins)(struct vc_data___2 *, struct fb_info___3 *, int, int);
	void (*cursor)(struct vc_data___2 *, struct fb_info___3 *, int, int, int);
	int (*update_start)(struct fb_info___3 *);
	int (*rotate_font)(struct fb_info___3 *, struct vc_data___2 *);
	struct fb_var_screeninfo var;
	struct timer_list cursor_timer;
	struct fb_cursor cursor_state;
	struct fbcon_display *p;
	struct fb_info___3 *info;
	int currcon;
	int cur_blink_jiffies;
	int cursor_flash;
	int cursor_reset;
	int blank_state;
	int graphics;
	int save_graphics;
	int flags;
	int rotate;
	int cur_rotate;
	char *cursor_data;
	u8 *fontbuffer;
	u8 *fontdata;
	u8 *cursor_src;
	u32 cursor_size;
	u32 fd_size;
};

enum {
	FBCON_LOGO_CANSHOW = 4294967295,
	FBCON_LOGO_DRAW = 4294967294,
	FBCON_LOGO_DONTSHOW = 4294967293,
};

typedef long unsigned int u_long;

enum {
	S1SA = 0,
	S2SA = 1,
	SP = 2,
	DSA = 3,
	CNT = 4,
	DP_OCTL = 5,
	CLR = 6,
	BI = 8,
	MBC = 9,
	BLTCTL = 10,
	HES = 12,
	HEB = 13,
	HSB = 14,
	HT = 15,
	VES = 16,
	VEB = 17,
	VSB = 18,
	VT = 19,
	HCIV = 20,
	VCIV = 21,
	TCDR = 22,
	VIL = 23,
	STGCTL = 24,
	SSR = 25,
	HRIR = 26,
	SPR = 27,
	CMR = 28,
	SRGCTL = 29,
	RRCIV = 30,
	RRSC = 31,
	RRCR = 34,
	GIOE = 32,
	GIO = 33,
	SCR = 35,
	SSTATUS = 36,
	PRC = 37,
};

enum {
	PADDRW = 0,
	PDATA = 4,
	PPMASK = 8,
	PADDRR = 12,
	PIDXLO = 16,
	PIDXHI = 20,
	PIDXDATA = 24,
	PIDXCTL = 28,
};

enum {
	CLKCTL = 2,
	SYNCCTL = 3,
	HSYNCPOS = 4,
	PWRMNGMT = 5,
	DACOP = 6,
	PALETCTL = 7,
	SYSCLKCTL = 8,
	PIXFMT = 10,
	BPP8 = 11,
	BPP16 = 12,
	BPP24 = 13,
	BPP32 = 14,
	PIXCTL1 = 16,
	PIXCTL2 = 17,
	SYSCLKN = 21,
	SYSCLKM = 22,
	SYSCLKP = 23,
	SYSCLKC = 24,
	PIXM0 = 32,
	PIXN0 = 33,
	PIXP0 = 34,
	PIXC0 = 35,
	CURSCTL = 48,
	CURSXLO = 49,
	CURSXHI = 50,
	CURSYLO = 51,
	CURSYHI = 52,
	CURSHOTX = 53,
	CURSHOTY = 54,
	CURSACCTL = 55,
	CURSACATTR = 56,
	CURS1R = 64,
	CURS1G = 65,
	CURS1B = 66,
	CURS2R = 67,
	CURS2G = 68,
	CURS2B = 69,
	CURS3R = 70,
	CURS3G = 71,
	CURS3B = 72,
	BORDR = 96,
	BORDG = 97,
	BORDB = 98,
	MISCTL1 = 112,
	MISCTL2 = 113,
	MISCTL3 = 114,
	KEYCTL = 120,
};

enum {
	TVPADDRW = 0,
	TVPPDATA = 4,
	TVPPMASK = 8,
	TVPPADRR = 12,
	TVPCADRW = 16,
	TVPCDATA = 20,
	TVPCADRR = 28,
	TVPDCCTL = 36,
	TVPIDATA = 40,
	TVPCRDAT = 44,
	TVPCXPOL = 48,
	TVPCXPOH = 52,
	TVPCYPOL = 56,
	TVPCYPOH = 60,
};

enum {
	TVPIRREV = 1,
	TVPIRICC = 6,
	TVPIRBRC = 7,
	TVPIRLAC = 15,
	TVPIRTCC = 24,
	TVPIRMXC = 25,
	TVPIRCLS = 26,
	TVPIRPPG = 28,
	TVPIRGEC = 29,
	TVPIRMIC = 30,
	TVPIRPLA = 44,
	TVPIRPPD = 45,
	TVPIRMPD = 46,
	TVPIRLPD = 47,
	TVPIRCKL = 48,
	TVPIRCKH = 49,
	TVPIRCRL = 50,
	TVPIRCRH = 51,
	TVPIRCGL = 52,
	TVPIRCGH = 53,
	TVPIRCBL = 54,
	TVPIRCBH = 55,
	TVPIRCKC = 56,
	TVPIRMLC = 57,
	TVPIRSEN = 58,
	TVPIRTMD = 59,
	TVPIRRML = 60,
	TVPIRRMM = 61,
	TVPIRRMS = 62,
	TVPIRDID = 63,
	TVPIRRES = 255,
};

struct initvalues {
	__u8 addr;
	__u8 value;
};

struct imstt_regvals {
	__u32 pitch;
	__u16 hes;
	__u16 heb;
	__u16 hsb;
	__u16 ht;
	__u16 ves;
	__u16 veb;
	__u16 vsb;
	__u16 vt;
	__u16 vil;
	__u8 pclk_m;
	__u8 pclk_n;
	__u8 pclk_p;
	__u8 mlc[3];
	__u8 lckl_p[3];
};

struct imstt_par {
	struct imstt_regvals init;
	__u32 *dc_regs;
	long unsigned int cmap_regs_phys;
	__u8 *cmap_regs;
	__u32 ramdac;
	__u32 palette[16];
};

enum {
	IBM = 0,
	TVP = 1,
};

struct chips_init_reg {
	unsigned char addr;
	unsigned char data;
};

struct acpi_table_bgrt {
	struct acpi_table_header header;
	u16 version;
	u8 status;
	u8 image_type;
	u64 image_address;
	u32 image_offset_x;
	u32 image_offset_y;
};

enum drm_panel_orientation {
	DRM_MODE_PANEL_ORIENTATION_UNKNOWN = 0,
	DRM_MODE_PANEL_ORIENTATION_NORMAL = 0,
	DRM_MODE_PANEL_ORIENTATION_BOTTOM_UP = 1,
	DRM_MODE_PANEL_ORIENTATION_LEFT_UP = 2,
	DRM_MODE_PANEL_ORIENTATION_RIGHT_UP = 3,
};

struct bmp_file_header {
	u16 id;
	u32 file_size;
	u32 reserved;
	u32 bitmap_offset;
} __attribute__((packed));

struct bmp_dib_header {
	u32 dib_header_size;
	s32 width;
	s32 height;
	u16 planes;
	u16 bpp;
	u32 compression;
	u32 bitmap_size;
	u32 horz_resolution;
	u32 vert_resolution;
	u32 colors_used;
	u32 colors_important;
};

struct dma_router___3 {
	struct device___153 *dev;
	void (*route_free)(struct device___153 *, void *);
};

struct dma_device___3;

struct dma_chan_dev___3;

struct dma_chan___3 {
	struct dma_device___3 *device;
	struct device___153 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___3 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___3 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___3)(struct dma_chan___3 *, void *);

struct dma_filter___3 {
	dma_filter_fn___3 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___3;

struct dma_device___3 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___3 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___153 *dev;
	struct module___178 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___3 *);
	int (*device_router_config)(struct dma_chan___3 *);
	void (*device_free_chan_resources)(struct dma_chan___3 *);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memcpy)(struct dma_chan___3 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_xor)(struct dma_chan___3 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_xor_val)(struct dma_chan___3 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_pq)(struct dma_chan___3 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_pq_val)(struct dma_chan___3 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memset)(struct dma_chan___3 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_memset_sg)(struct dma_chan___3 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_interrupt)(struct dma_chan___3 *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_slave_sg)(struct dma_chan___3 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_cyclic)(struct dma_chan___3 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_interleaved_dma)(struct dma_chan___3 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___3 * (*device_prep_dma_imm_data)(struct dma_chan___3 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___3 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___3 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___3 *);
	int (*device_resume)(struct dma_chan___3 *);
	int (*device_terminate_all)(struct dma_chan___3 *);
	void (*device_synchronize)(struct dma_chan___3 *);
	enum dma_status (*device_tx_status)(struct dma_chan___3 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___3 *);
	void (*device_release)(struct dma_device___3 *);
	void (*dbg_summary_show)(struct seq_file___170 *, struct dma_device___3 *);
	struct dentry___194 *dbg_dev_root;
};

struct dma_chan_dev___3 {
	struct dma_chan___3 *chan;
	struct device___153 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___3 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___153 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___3 {
	int (*attach)(struct dma_async_tx_descriptor___3 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___3 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___3 *, size_t);
};

struct dma_async_tx_descriptor___3 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___3 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___3 *);
	int (*desc_free)(struct dma_async_tx_descriptor___3 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___3 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___3 *metadata_ops;
	struct dma_async_tx_descriptor___3 *next;
	struct dma_async_tx_descriptor___3 *parent;
	spinlock_t lock;
};

enum ipu_channel {
	IDMAC_IC_0 = 0,
	IDMAC_IC_1 = 1,
	IDMAC_ADC_0 = 1,
	IDMAC_IC_2 = 2,
	IDMAC_ADC_1 = 2,
	IDMAC_IC_3 = 3,
	IDMAC_IC_4 = 4,
	IDMAC_IC_5 = 5,
	IDMAC_IC_6 = 6,
	IDMAC_IC_7 = 7,
	IDMAC_IC_8 = 8,
	IDMAC_IC_9 = 9,
	IDMAC_IC_10 = 10,
	IDMAC_IC_11 = 11,
	IDMAC_IC_12 = 12,
	IDMAC_IC_13 = 13,
	IDMAC_SDC_0 = 14,
	IDMAC_SDC_1 = 15,
	IDMAC_SDC_2 = 16,
	IDMAC_SDC_3 = 17,
	IDMAC_ADC_2 = 18,
	IDMAC_ADC_3 = 19,
	IDMAC_ADC_4 = 20,
	IDMAC_ADC_5 = 21,
	IDMAC_ADC_6 = 22,
	IDMAC_ADC_7 = 23,
	IDMAC_PF_0 = 24,
	IDMAC_PF_1 = 25,
	IDMAC_PF_2 = 26,
	IDMAC_PF_3 = 27,
	IDMAC_PF_4 = 28,
	IDMAC_PF_5 = 29,
	IDMAC_PF_6 = 30,
	IDMAC_PF_7 = 31,
};

enum ipu_channel_status {
	IPU_CHANNEL_FREE = 0,
	IPU_CHANNEL_INITIALIZED = 1,
	IPU_CHANNEL_READY = 2,
	IPU_CHANNEL_ENABLED = 3,
};

enum pixel_fmt {
	IPU_PIX_FMT_GENERIC = 0,
	IPU_PIX_FMT_RGB332 = 1,
	IPU_PIX_FMT_YUV420P = 2,
	IPU_PIX_FMT_YUV422P = 3,
	IPU_PIX_FMT_YUV420P2 = 4,
	IPU_PIX_FMT_YVU422P = 5,
	IPU_PIX_FMT_RGB565 = 6,
	IPU_PIX_FMT_RGB666 = 7,
	IPU_PIX_FMT_BGR666 = 8,
	IPU_PIX_FMT_YUYV = 9,
	IPU_PIX_FMT_UYVY = 10,
	IPU_PIX_FMT_RGB24 = 11,
	IPU_PIX_FMT_BGR24 = 12,
	IPU_PIX_FMT_GENERIC_32 = 13,
	IPU_PIX_FMT_RGB32 = 14,
	IPU_PIX_FMT_BGR32 = 15,
	IPU_PIX_FMT_ABGR32 = 16,
	IPU_PIX_FMT_BGRA32 = 17,
	IPU_PIX_FMT_RGBA32 = 18,
};

enum display_port {
	DISP0 = 0,
	DISP1 = 1,
	DISP2 = 2,
	DISP3 = 3,
};

struct idmac_video_param {
	short unsigned int in_width;
	short unsigned int in_height;
	uint32_t in_pixel_fmt;
	short unsigned int out_width;
	short unsigned int out_height;
	uint32_t out_pixel_fmt;
	short unsigned int out_stride;
	bool graphics_combine_en;
	bool global_alpha_en;
	bool key_color_en;
	enum display_port disp;
	short unsigned int out_left;
	short unsigned int out_top;
};

union ipu_channel_param {
	struct idmac_video_param video;
};

struct idmac_tx_desc {
	struct dma_async_tx_descriptor___3 txd;
	struct scatterlist *sg;
	unsigned int sg_len;
	struct list_head list;
};

struct idmac_channel {
	struct dma_chan___3 dma_chan;
	dma_cookie_t completed;
	union ipu_channel_param params;
	enum ipu_channel link;
	enum ipu_channel_status status;
	void *client;
	unsigned int n_tx_desc;
	struct idmac_tx_desc *desc;
	struct scatterlist *sg[2];
	struct list_head free_list;
	struct list_head queue;
	spinlock_t lock;
	struct mutex chan_mutex;
	bool sec_chan_en;
	int active_buffer;
	unsigned int eof_irq;
	char eof_name[16];
};

enum disp_data_mapping {
	IPU_DISP_DATA_MAPPING_RGB666 = 0,
	IPU_DISP_DATA_MAPPING_RGB565 = 1,
	IPU_DISP_DATA_MAPPING_RGB888 = 2,
};

struct mx3fb_platform_data {
	struct device___153 *dma_dev;
	const char *name;
	const struct fb_videomode *mode;
	int num_modes;
	enum disp_data_mapping disp_data_fmt;
};

enum ipu_panel {
	IPU_PANEL_SHARP_TFT = 0,
	IPU_PANEL_TFT = 1,
};

struct ipu_di_signal_cfg {
	unsigned int datamask_en: 1;
	unsigned int clksel_en: 1;
	unsigned int clkidle_en: 1;
	unsigned int data_pol: 1;
	unsigned int clk_pol: 1;
	unsigned int enable_pol: 1;
	unsigned int Hsync_pol: 1;
	unsigned int Vsync_pol: 1;
};

struct mx3fb_data {
	struct fb_info___3 *fbi;
	int backlight_level;
	void *reg_base;
	spinlock_t lock;
	struct device___153 *dev;
	struct backlight_device___3 *bl;
	uint32_t h_start_width;
	uint32_t v_start_width;
	enum disp_data_mapping disp_data_fmt;
};

struct dma_chan_request {
	struct mx3fb_data *mx3fb;
	enum ipu_channel id;
};

struct mx3fb_info {
	int blank;
	enum ipu_channel ipu_ch;
	uint32_t cur_ipu_buf;
	u32 pseudo_palette[16];
	struct completion flip_cmpl;
	struct mutex mutex;
	struct mx3fb_data *mx3fb;
	struct idmac_channel *idmac_channel;
	struct dma_async_tx_descriptor___3 *txd;
	dma_cookie_t cookie;
	struct scatterlist sg[2];
	struct fb_var_screeninfo cur_var;
};

struct di_mapping {
	uint32_t b0;
	uint32_t b1;
	uint32_t b2;
};

struct timing_entry {
	u32 min;
	u32 typ;
	u32 max;
};

struct display_timing {
	struct timing_entry pixelclock;
	struct timing_entry hactive;
	struct timing_entry hfront_porch;
	struct timing_entry hback_porch;
	struct timing_entry hsync_len;
	struct timing_entry vactive;
	struct timing_entry vfront_porch;
	struct timing_entry vback_porch;
	struct timing_entry vsync_len;
	enum display_flags flags;
};

struct display_timings {
	unsigned int num_timings;
	unsigned int native_mode;
	struct display_timing **timings;
};

struct property___45 {
	char *name;
	int length;
	void *value;
	struct property___45 *next;
	long unsigned int _flags;
	struct bin_attribute___170 attr;
};

struct device_node___56 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___153 fwnode;
	struct property___45 *properties;
	struct property___45 *deadprops;
	struct device_node___56 *parent;
	struct device_node___56 *child;
	struct device_node___56 *sibling;
	struct kobject___170 kobj;
	long unsigned int _flags;
	void *data;
};

enum ipmi_addr_src {
	SI_INVALID = 0,
	SI_HOTMOD = 1,
	SI_HARDCODED = 2,
	SI_SPMI = 3,
	SI_ACPI = 4,
	SI_SMBIOS = 5,
	SI_PCI = 6,
	SI_DEVICETREE = 7,
	SI_PLATFORM = 8,
	SI_LAST = 9,
};

struct dmi_header {
	u8 type;
	u8 length;
	u16 handle;
};

enum si_type {
	SI_TYPE_INVALID = 0,
	SI_KCS = 1,
	SI_SMIC = 2,
	SI_BT = 3,
	SI_TYPE_MAX = 4,
};

enum ipmi_addr_space {
	IPMI_IO_ADDR_SPACE = 0,
	IPMI_MEM_ADDR_SPACE = 1,
};

enum ipmi_plat_interface_type {
	IPMI_PLAT_IF_SI = 0,
	IPMI_PLAT_IF_SSIF = 1,
};

struct ipmi_plat_data {
	enum ipmi_plat_interface_type iftype;
	unsigned int type;
	unsigned int space;
	long unsigned int addr;
	unsigned int regspacing;
	unsigned int regsize;
	unsigned int regshift;
	unsigned int irq;
	unsigned int slave_addr;
	enum ipmi_addr_src addr_source;
};

struct ipmi_dmi_info {
	enum si_type si_type;
	unsigned int space;
	long unsigned int addr;
	u8 slave_addr;
	struct ipmi_dmi_info *next;
};

typedef u16 acpi_owner_id;

union acpi_name_union {
	u32 integer;
	char ascii[4];
};

struct acpi_table_desc {
	acpi_physical_address address;
	struct acpi_table_header *pointer;
	u32 length;
	union acpi_name_union signature;
	acpi_owner_id owner_id;
	u8 flags;
	u16 validation_count;
};

struct acpi_madt_local_apic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u32 lapic_flags;
};

struct acpi_madt_io_apic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 address;
	u32 global_irq_base;
};

struct acpi_madt_interrupt_override {
	struct acpi_subtable_header header;
	u8 bus;
	u8 source_irq;
	u32 global_irq;
	u16 inti_flags;
} __attribute__((packed));

struct acpi_madt_nmi_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 global_irq;
};

struct acpi_madt_local_apic_nmi {
	struct acpi_subtable_header header;
	u8 processor_id;
	u16 inti_flags;
	u8 lint;
} __attribute__((packed));

struct acpi_madt_local_apic_override {
	struct acpi_subtable_header header;
	u16 reserved;
	u64 address;
} __attribute__((packed));

struct acpi_madt_io_sapic {
	struct acpi_subtable_header header;
	u8 id;
	u8 reserved;
	u32 global_irq_base;
	u64 address;
};

struct acpi_madt_local_sapic {
	struct acpi_subtable_header header;
	u8 processor_id;
	u8 id;
	u8 eid;
	u8 reserved[3];
	u32 lapic_flags;
	u32 uid;
	char uid_string[1];
} __attribute__((packed));

struct acpi_madt_interrupt_source {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u8 type;
	u8 id;
	u8 eid;
	u8 io_sapic_vector;
	u32 global_irq;
	u32 flags;
};

struct acpi_madt_local_x2apic {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 local_apic_id;
	u32 lapic_flags;
	u32 uid;
};

struct acpi_madt_local_x2apic_nmi {
	struct acpi_subtable_header header;
	u16 inti_flags;
	u32 uid;
	u8 lint;
	u8 reserved[3];
};

struct acpi_subtable_proc {
	int id;
	acpi_tbl_entry_handler handler;
	int count;
};

enum acpi_subtable_type {
	ACPI_SUBTABLE_COMMON = 0,
	ACPI_SUBTABLE_HMAT = 1,
	ACPI_SUBTABLE_PRMT = 2,
};

struct acpi_subtable_entry {
	union acpi_subtable_headers *hdr;
	enum acpi_subtable_type type;
};

typedef u32 (*acpi_interface_handler)(acpi_string, u32);

struct acpi_osi_entry {
	char string[64];
	bool enable;
};

struct acpi_osi_config {
	u8 default_disabling;
	unsigned int linux_enable;
	unsigned int linux_dmi;
	unsigned int linux_cmdline;
	unsigned int darwin_enable;
	unsigned int darwin_dmi;
	unsigned int darwin_cmdline;
};

struct acpi_predefined_names {
	const char *name;
	u8 type;
	char *val;
};

typedef u32 (*acpi_osd_handler)(void *);

typedef void (*acpi_osd_exec_callback)(void *);

typedef u32 (*acpi_gpe_handler)(acpi_handle, u32, void *);

typedef void (*acpi_notify_handler)(acpi_handle, u32, void *);

struct acpi_pci_id {
	u16 segment;
	u16 bus;
	u16 device;
	u16 function;
};

struct acpi_mem_mapping {
	acpi_physical_address physical_address;
	u8 *logical_address;
	acpi_size length;
	struct acpi_mem_mapping *next_mm;
};

struct acpi_mem_space_context {
	u32 length;
	acpi_physical_address address;
	struct acpi_mem_mapping *cur_mm;
	struct acpi_mem_mapping *first_mm;
};

typedef enum {
	OSL_GLOBAL_LOCK_HANDLER = 0,
	OSL_NOTIFY_HANDLER = 1,
	OSL_GPE_HANDLER = 2,
	OSL_DEBUGGER_MAIN_THREAD = 3,
	OSL_DEBUGGER_EXEC_THREAD = 4,
	OSL_EC_POLL_HANDLER = 5,
	OSL_EC_BURST_HANDLER = 6,
} acpi_execute_type;

union acpi_operand_object;

struct acpi_namespace_node {
	union acpi_operand_object *object;
	u8 descriptor_type;
	u8 type;
	u16 flags;
	union acpi_name_union name;
	struct acpi_namespace_node *parent;
	struct acpi_namespace_node *child;
	struct acpi_namespace_node *peer;
	acpi_owner_id owner_id;
};

struct acpi_object_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
};

struct acpi_object_integer {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 fill[3];
	u64 value;
};

struct acpi_object_string {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	char *pointer;
	u32 length;
};

struct acpi_object_buffer {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 *pointer;
	u32 length;
	u32 aml_length;
	u8 *aml_start;
	struct acpi_namespace_node *node;
};

struct acpi_object_package {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *node;
	union acpi_operand_object **elements;
	u8 *aml_start;
	u32 aml_length;
	u32 count;
};

struct acpi_object_event {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	void *os_semaphore;
};

struct acpi_walk_state;

typedef acpi_status (*acpi_internal_method)(struct acpi_walk_state *);

struct acpi_object_method {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 info_flags;
	u8 param_count;
	u8 sync_level;
	union acpi_operand_object *mutex;
	union acpi_operand_object *node;
	u8 *aml_start;
	union {
		acpi_internal_method implementation;
		union acpi_operand_object *handler;
	} dispatch;
	u32 aml_length;
	acpi_owner_id owner_id;
	u8 thread_count;
};

struct acpi_thread_state;

struct acpi_object_mutex {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 sync_level;
	u16 acquisition_depth;
	void *os_mutex;
	u64 thread_id;
	struct acpi_thread_state *owner_thread;
	union acpi_operand_object *prev;
	union acpi_operand_object *next;
	struct acpi_namespace_node *node;
	u8 original_sync_level;
};

struct acpi_object_region {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 space_id;
	struct acpi_namespace_node *node;
	union acpi_operand_object *handler;
	union acpi_operand_object *next;
	acpi_physical_address address;
	u32 length;
};

struct acpi_object_notify_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
};

struct acpi_gpe_block_info;

struct acpi_object_device {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	struct acpi_gpe_block_info *gpe_block;
};

struct acpi_object_power_resource {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	u32 system_level;
	u32 resource_order;
};

struct acpi_object_processor {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 proc_id;
	u8 length;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
	acpi_io_address address;
};

struct acpi_object_thermal_zone {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *notify_list[2];
	union acpi_operand_object *handler;
};

struct acpi_object_field_common {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *region_obj;
};

struct acpi_object_region_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	u16 resource_length;
	union acpi_operand_object *region_obj;
	u8 *resource_buffer;
	u16 pin_number_index;
	u8 *internal_pcc_buffer;
};

struct acpi_object_buffer_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	u8 is_create_field;
	union acpi_operand_object *buffer_obj;
};

struct acpi_object_bank_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *region_obj;
	union acpi_operand_object *bank_obj;
};

struct acpi_object_index_field {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 field_flags;
	u8 attribute;
	u8 access_byte_width;
	struct acpi_namespace_node *node;
	u32 bit_length;
	u32 base_byte_offset;
	u32 value;
	u8 start_field_bit_offset;
	u8 access_length;
	union acpi_operand_object *index_obj;
	union acpi_operand_object *data_obj;
};

struct acpi_object_notify_handler {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *node;
	u32 handler_type;
	acpi_notify_handler handler;
	void *context;
	union acpi_operand_object *next[2];
};

struct acpi_object_addr_handler {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 space_id;
	u8 handler_flags;
	acpi_adr_space_handler handler;
	struct acpi_namespace_node *node;
	void *context;
	void *context_mutex;
	acpi_adr_space_setup setup;
	union acpi_operand_object *region_list;
	union acpi_operand_object *next;
};

struct acpi_object_reference {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	u8 class;
	u8 target_type;
	u8 resolved;
	void *object;
	struct acpi_namespace_node *node;
	union acpi_operand_object **where;
	u8 *index_pointer;
	u8 *aml;
	u32 value;
};

struct acpi_object_extra {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	struct acpi_namespace_node *method_REG;
	struct acpi_namespace_node *scope_node;
	void *region_context;
	u8 *aml_start;
	u32 aml_length;
};

struct acpi_object_data {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	acpi_object_handler handler;
	void *pointer;
};

struct acpi_object_cache_list {
	union acpi_operand_object *next_object;
	u8 descriptor_type;
	u8 type;
	u16 reference_count;
	u8 flags;
	union acpi_operand_object *next;
};

union acpi_operand_object {
	struct acpi_object_common common;
	struct acpi_object_integer integer;
	struct acpi_object_string string;
	struct acpi_object_buffer buffer;
	struct acpi_object_package package;
	struct acpi_object_event event;
	struct acpi_object_method method;
	struct acpi_object_mutex mutex;
	struct acpi_object_region region;
	struct acpi_object_notify_common common_notify;
	struct acpi_object_device device;
	struct acpi_object_power_resource power_resource;
	struct acpi_object_processor processor;
	struct acpi_object_thermal_zone thermal_zone;
	struct acpi_object_field_common common_field;
	struct acpi_object_region_field field;
	struct acpi_object_buffer_field buffer_field;
	struct acpi_object_bank_field bank_field;
	struct acpi_object_index_field index_field;
	struct acpi_object_notify_handler notify;
	struct acpi_object_addr_handler address_space;
	struct acpi_object_reference reference;
	struct acpi_object_extra extra;
	struct acpi_object_data data;
	struct acpi_object_cache_list cache;
	struct acpi_namespace_node node;
};

union acpi_parse_object;

union acpi_generic_state;

struct acpi_parse_state {
	u8 *aml_start;
	u8 *aml;
	u8 *aml_end;
	u8 *pkg_start;
	u8 *pkg_end;
	union acpi_parse_object *start_op;
	struct acpi_namespace_node *start_node;
	union acpi_generic_state *scope;
	union acpi_parse_object *start_scope;
	u32 aml_size;
};

typedef acpi_status (*acpi_parse_downwards)(struct acpi_walk_state *, union acpi_parse_object **);

typedef acpi_status (*acpi_parse_upwards)(struct acpi_walk_state *);

struct acpi_opcode_info;

struct acpi_walk_state {
	struct acpi_walk_state *next;
	u8 descriptor_type;
	u8 walk_type;
	u16 opcode;
	u8 next_op_info;
	u8 num_operands;
	u8 operand_index;
	acpi_owner_id owner_id;
	u8 last_predicate;
	u8 current_result;
	u8 return_used;
	u8 scope_depth;
	u8 pass_number;
	u8 namespace_override;
	u8 result_size;
	u8 result_count;
	u8 *aml;
	u32 arg_types;
	u32 method_breakpoint;
	u32 user_breakpoint;
	u32 parse_flags;
	struct acpi_parse_state parser_state;
	u32 prev_arg_types;
	u32 arg_count;
	u16 method_nesting_depth;
	u8 method_is_nested;
	struct acpi_namespace_node arguments[7];
	struct acpi_namespace_node local_variables[8];
	union acpi_operand_object *operands[9];
	union acpi_operand_object **params;
	u8 *aml_last_while;
	union acpi_operand_object **caller_return_desc;
	union acpi_generic_state *control_state;
	struct acpi_namespace_node *deferred_node;
	union acpi_operand_object *implicit_return_obj;
	struct acpi_namespace_node *method_call_node;
	union acpi_parse_object *method_call_op;
	union acpi_operand_object *method_desc;
	struct acpi_namespace_node *method_node;
	char *method_pathname;
	union acpi_parse_object *op;
	const struct acpi_opcode_info *op_info;
	union acpi_parse_object *origin;
	union acpi_operand_object *result_obj;
	union acpi_generic_state *results;
	union acpi_operand_object *return_desc;
	union acpi_generic_state *scope_info;
	union acpi_parse_object *prev_op;
	union acpi_parse_object *next_op;
	struct acpi_thread_state *thread;
	acpi_parse_downwards descending_callback;
	acpi_parse_upwards ascending_callback;
};

struct acpi_gpe_handler_info {
	acpi_gpe_handler address;
	void *context;
	struct acpi_namespace_node *method_node;
	u8 original_flags;
	u8 originally_enabled;
};

struct acpi_gpe_notify_info {
	struct acpi_namespace_node *device_node;
	struct acpi_gpe_notify_info *next;
};

union acpi_gpe_dispatch_info {
	struct acpi_namespace_node *method_node;
	struct acpi_gpe_handler_info *handler;
	struct acpi_gpe_notify_info *notify_list;
};

struct acpi_gpe_register_info;

struct acpi_gpe_event_info {
	union acpi_gpe_dispatch_info dispatch;
	struct acpi_gpe_register_info *register_info;
	u8 flags;
	u8 gpe_number;
	u8 runtime_count;
	u8 disable_for_dispatch;
};

struct acpi_gpe_address {
	u8 space_id;
	u64 address;
};

struct acpi_gpe_register_info {
	struct acpi_gpe_address status_address;
	struct acpi_gpe_address enable_address;
	u16 base_gpe_number;
	u8 enable_for_wake;
	u8 enable_for_run;
	u8 mask_for_run;
	u8 enable_mask;
};

struct acpi_gpe_xrupt_info;

struct acpi_gpe_block_info {
	struct acpi_namespace_node *node;
	struct acpi_gpe_block_info *previous;
	struct acpi_gpe_block_info *next;
	struct acpi_gpe_xrupt_info *xrupt_block;
	struct acpi_gpe_register_info *register_info;
	struct acpi_gpe_event_info *event_info;
	u64 address;
	u32 register_count;
	u16 gpe_count;
	u16 block_base_number;
	u8 space_id;
	u8 initialized;
};

struct acpi_gpe_xrupt_info {
	struct acpi_gpe_xrupt_info *previous;
	struct acpi_gpe_xrupt_info *next;
	struct acpi_gpe_block_info *gpe_block_list_head;
	u32 interrupt_number;
};

struct acpi_common_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
};

struct acpi_update_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	union acpi_operand_object *object;
};

struct acpi_pkg_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u32 index;
	union acpi_operand_object *source_object;
	union acpi_operand_object *dest_object;
	struct acpi_walk_state *walk_state;
	void *this_target_obj;
	u32 num_packages;
};

struct acpi_control_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u16 opcode;
	union acpi_parse_object *predicate_op;
	u8 *aml_predicate_start;
	u8 *package_end;
	u64 loop_timeout;
};

union acpi_parse_value {
	u64 integer;
	u32 size;
	char *string;
	u8 *buffer;
	char *name;
	union acpi_parse_object *arg;
};

struct acpi_parse_obj_common {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u8 *aml;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
};

struct acpi_parse_obj_named {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u8 *aml;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
	char *path;
	u8 *data;
	u32 length;
	u32 name;
};

struct acpi_parse_obj_asl {
	union acpi_parse_object *parent;
	u8 descriptor_type;
	u8 flags;
	u16 aml_opcode;
	u8 *aml;
	union acpi_parse_object *next;
	struct acpi_namespace_node *node;
	union acpi_parse_value value;
	u8 arg_list_length;
	union acpi_parse_object *child;
	union acpi_parse_object *parent_method;
	char *filename;
	u8 file_changed;
	char *parent_filename;
	char *external_name;
	char *namepath;
	char name_seg[4];
	u32 extra_value;
	u32 column;
	u32 line_number;
	u32 logical_line_number;
	u32 logical_byte_offset;
	u32 end_line;
	u32 end_logical_line;
	u32 acpi_btype;
	u32 aml_length;
	u32 aml_subtree_length;
	u32 final_aml_length;
	u32 final_aml_offset;
	u32 compile_flags;
	u16 parse_opcode;
	u8 aml_opcode_length;
	u8 aml_pkg_len_bytes;
	u8 extra;
	char parse_op_name[20];
};

union acpi_parse_object {
	struct acpi_parse_obj_common common;
	struct acpi_parse_obj_named named;
	struct acpi_parse_obj_asl asl;
};

struct acpi_scope_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	struct acpi_namespace_node *node;
};

struct acpi_pscope_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u32 arg_count;
	union acpi_parse_object *op;
	u8 *arg_end;
	u8 *pkg_end;
	u32 arg_list;
};

struct acpi_thread_state {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u8 current_sync_level;
	struct acpi_walk_state *walk_state_list;
	union acpi_operand_object *acquired_mutex_list;
	u64 thread_id;
};

struct acpi_result_values {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	union acpi_operand_object *obj_desc[8];
};

struct acpi_global_notify_handler {
	acpi_notify_handler handler;
	void *context;
};

struct acpi_notify_info {
	void *next;
	u8 descriptor_type;
	u8 flags;
	u16 value;
	u16 state;
	u8 handler_list_id;
	struct acpi_namespace_node *node;
	union acpi_operand_object *handler_list_head;
	struct acpi_global_notify_handler *global;
};

union acpi_generic_state {
	struct acpi_common_state common;
	struct acpi_control_state control;
	struct acpi_update_state update;
	struct acpi_scope_state scope;
	struct acpi_pscope_state parse_scope;
	struct acpi_pkg_state pkg;
	struct acpi_thread_state thread;
	struct acpi_result_values results;
	struct acpi_notify_info notify;
};

struct acpi_opcode_info {
	u32 parse_args;
	u32 runtime_args;
	u16 flags;
	u8 object_type;
	u8 class;
	u8 type;
};

struct acpi_os_dpc {
	acpi_osd_exec_callback function;
	void *context;
	struct work_struct work;
};

struct acpi_ioremap {
	struct list_head list;
	void *virt;
	acpi_physical_address phys;
	acpi_size size;
	union {
		long unsigned int refcount;
		struct rcu_work rwork;
	} track;
};

struct acpi_hp_work {
	struct work_struct work;
	struct acpi_device___5 *adev;
	u32 src;
};

struct acpi_pld_info {
	u8 revision;
	u8 ignore_color;
	u8 red;
	u8 green;
	u8 blue;
	u16 width;
	u16 height;
	u8 user_visible;
	u8 dock;
	u8 lid;
	u8 panel;
	u8 vertical_position;
	u8 horizontal_position;
	u8 shape;
	u8 group_orientation;
	u8 group_token;
	u8 group_position;
	u8 bay;
	u8 ejectable;
	u8 ospm_eject_required;
	u8 cabinet_number;
	u8 card_cage_number;
	u8 reference;
	u8 rotation;
	u8 order;
	u8 reserved;
	u16 vertical_offset;
	u16 horizontal_offset;
};

struct acpi_handle_list {
	u32 count;
	acpi_handle handles[10];
};

enum acpi_predicate {
	all_versions = 0,
	less_than_or_equal = 1,
	equal = 2,
	greater_than_or_equal = 3,
};

struct acpi_platform_list {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
	char *table;
	enum acpi_predicate pred;
	char *reason;
	u32 data;
};

struct acpi_device_bus_id {
	const char *bus_id;
	struct ida instance_ida;
	struct list_head node;
};

struct acpi_dev_match_info {
	struct acpi_device_id hid[2];
	const char *uid;
	s64 hrv;
};

struct nvs_region {
	__u64 phys_start;
	__u64 size;
	struct list_head node;
};

struct acpi_wakeup_handler {
	struct list_head list_node;
	bool (*wakeup)(void *);
	void *context;
};

struct acpi_hardware_id {
	struct list_head list;
	const char *id;
};

struct acpi_data_node {
	const char *name;
	acpi_handle handle;
	struct fwnode_handle___148 fwnode;
	struct fwnode_handle___148 *parent;
	struct acpi_device_data data;
	struct list_head sibling;
	struct kobject___178 kobj;
	struct completion kobj_done;
};

struct acpi_data_node_attr {
	struct attribute attr;
	ssize_t (*show)(struct acpi_data_node *, char *);
	ssize_t (*store)(struct acpi_data_node *, const char *, size_t);
};

struct irq_desc___37;

typedef void (*irq_flow_handler_t___37)(struct irq_desc___37 *);

struct irq_chip___36;

struct irq_domain___35;

struct irq_data___36 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___36 *chip;
	struct irq_domain___35 *domain;
	struct irq_data___36 *parent_data;
	void *chip_data;
};

struct kset___183;

struct kobj_type___183;

struct kernfs_node___183;

struct kobject___183 {
	const char *name;
	struct list_head entry;
	struct kobject___183 *parent;
	struct kset___183 *kset;
	struct kobj_type___183 *ktype;
	struct kernfs_node___183 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___26;

struct module___179;

struct irq_desc___37 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___36 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___37 handle_irq;
	struct irqaction___26 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___183 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___179 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___195;

struct super_block___195;

struct file_system_type___195 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___195 * (*mount)(struct file_system_type___195 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___195 *);
	struct module___179 *owner;
	struct file_system_type___195 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___195;

struct kiocb___195;

struct iov_iter___117;

struct poll_table_struct___127;

struct vm_area_struct___200;

struct inode___195;

struct file_lock___195;

struct page___200;

struct seq_file___171;

struct file_operations___196 {
	struct module___179 *owner;
	loff_t (*llseek)(struct file___195 *, loff_t, int);
	ssize_t (*read)(struct file___195 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___195 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___195 *, struct iov_iter___117 *);
	ssize_t (*write_iter)(struct kiocb___195 *, struct iov_iter___117 *);
	int (*iopoll)(struct kiocb___195 *, bool);
	int (*iterate)(struct file___195 *, struct dir_context *);
	int (*iterate_shared)(struct file___195 *, struct dir_context *);
	__poll_t (*poll)(struct file___195 *, struct poll_table_struct___127 *);
	long int (*unlocked_ioctl)(struct file___195 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___195 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___195 *, struct vm_area_struct___200 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___195 *, struct file___195 *);
	int (*flush)(struct file___195 *, fl_owner_t);
	int (*release)(struct inode___195 *, struct file___195 *);
	int (*fsync)(struct file___195 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___195 *, int);
	int (*lock)(struct file___195 *, int, struct file_lock___195 *);
	ssize_t (*sendpage)(struct file___195 *, struct page___200 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___195 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___195 *, long unsigned int);
	int (*flock)(struct file___195 *, int, struct file_lock___195 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___195 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___195 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___195 *, long int, struct file_lock___195 **, void **);
	long int (*fallocate)(struct file___195 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___171 *, struct file___195 *);
	ssize_t (*copy_file_range)(struct file___195 *, loff_t, struct file___195 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___195 *, loff_t, struct file___195 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___195 *, loff_t, loff_t, int);
};

struct vmacache___200 {
	u64 seqnum;
	struct vm_area_struct___200 *vmas[4];
};

struct page_frag___200 {
	struct page___200 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___201;

struct pid___173;

struct nsproxy___182;

struct signal_struct___196;

struct bio_list___99;

struct backing_dev_info___92;

struct io_context___99;

struct css_set___134;

struct mem_cgroup___83;

struct request_queue___99;

struct vm_struct___178;

struct task_struct___202 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___202 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___201 *mm;
	struct mm_struct___201 *active_mm;
	struct vmacache___200 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___202 *real_parent;
	struct task_struct___202 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___202 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___173 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___182 *nsproxy;
	struct signal_struct___196 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___202 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___99 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___92 *backing_dev_info;
	struct io_context___99 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___134 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___200 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___83 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___83 *active_memcg;
	struct request_queue___99 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___202 *oom_reaper_list;
	struct vm_struct___178 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___179 {
	struct kobject___183 kobj;
	struct module___179 *mod;
	struct kobject___183 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___179 {
	struct module___179 *mod;
	struct latch_tree_node node;
};

struct module_layout___179 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___179 mtn;
};

struct module_attribute___179;

struct kernel_param___179;

struct module___179 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___179 mkobj;
	struct module_attribute___179 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___183 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___179 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___179 core_layout;
	struct module_layout___179 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___200 *pgtable_t___200;

struct address_space___195;

struct dev_pagemap___190;

struct page___200 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___195 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___200 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___200 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___201 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___190 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___190;

struct vm_area_struct___200 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___200 *vm_next;
	struct vm_area_struct___200 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___201 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___190 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___195 *vm_file;
	struct file___195 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___200;

struct mm_struct___201 {
	struct {
		struct vm_area_struct___200 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___195 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___200 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___202 *owner;
		struct user_namespace___25 *user_ns;
		struct file___195 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___195;

struct address_space___195 {
	struct inode___195 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___195 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___190;

struct dev_pagemap___190 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___190 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___195;

struct path___195 {
	struct vfsmount___195 *mnt;
	struct dentry___195 *dentry;
};

struct fown_struct___173 {
	rwlock_t lock;
	struct pid___173 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___195 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___195 f_path;
	struct inode___195 *f_inode;
	const struct file_operations___196 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___173 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___195 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___190;

struct vm_operations_struct___190 {
	void (*open)(struct vm_area_struct___200 *);
	void (*close)(struct vm_area_struct___200 *);
	int (*may_split)(struct vm_area_struct___200 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___200 *);
	int (*mprotect)(struct vm_area_struct___200 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___190 *);
	vm_fault_t (*huge_fault)(struct vm_fault___190 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___190 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___200 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___190 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___190 *);
	int (*access)(struct vm_area_struct___200 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___200 *);
	int (*set_policy)(struct vm_area_struct___200 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___200 *, long unsigned int);
	struct page___200 * (*find_special_page)(struct vm_area_struct___200 *, long unsigned int);
};

struct core_thread___200 {
	struct task_struct___202 *task;
	struct core_thread___200 *next;
};

struct core_state___200 {
	atomic_t nr_threads;
	struct core_thread___200 dumper;
	struct completion startup;
};

struct vm_fault___190 {
	const struct {
		struct vm_area_struct___200 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___200 *cow_page;
	struct page___200 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___200 prealloc_pte;
};

struct pglist_data___90;

struct lruvec___90 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___90 *pgdat;
};

struct zone___90 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___90 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___90 {
	struct zone___90 *zone;
	int zone_idx;
};

struct zonelist___90 {
	struct zoneref___90 _zonerefs[321];
};

struct pglist_data___90 {
	struct zone___90 node_zones[5];
	struct zonelist___90 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___202 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___202 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___90 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___183;

struct kernfs_elem_dir___183 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___183 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___183;

struct kernfs_root___183 {
	struct kernfs_node___183 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___183 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___183 {
	struct kernfs_node___183 *target_kn;
};

struct kernfs_ops___183;

struct kernfs_elem_attr___183 {
	const struct kernfs_ops___183 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___183 *notify_next;
};

struct kernfs_node___183 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___183 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___183 dir;
		struct kernfs_elem_symlink___183 symlink;
		struct kernfs_elem_attr___183 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___183;

struct kernfs_ops___183 {
	int (*open)(struct kernfs_open_file___183 *);
	void (*release)(struct kernfs_open_file___183 *);
	int (*seq_show)(struct seq_file___171 *, void *);
	void * (*seq_start)(struct seq_file___171 *, loff_t *);
	void * (*seq_next)(struct seq_file___171 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___171 *, void *);
	ssize_t (*read)(struct kernfs_open_file___183 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___183 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___183 *, struct poll_table_struct___127 *);
	int (*mmap)(struct kernfs_open_file___183 *, struct vm_area_struct___200 *);
};

struct kernfs_syscall_ops___183 {
	int (*show_options)(struct seq_file___171 *, struct kernfs_root___183 *);
	int (*mkdir)(struct kernfs_node___183 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___183 *);
	int (*rename)(struct kernfs_node___183 *, struct kernfs_node___183 *, const char *);
	int (*show_path)(struct seq_file___171 *, struct kernfs_node___183 *, struct kernfs_root___183 *);
};

struct seq_operations___171;

struct seq_file___171 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___171 *op;
	int poll_event;
	const struct file___195 *file;
	void *private;
};

struct kernfs_open_file___183 {
	struct kernfs_node___183 *kn;
	struct file___195 *file;
	struct seq_file___171 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___190 *vm_ops;
};

typedef void (*poll_queue_proc___132)(struct file___195 *, wait_queue_head_t *, struct poll_table_struct___127 *);

struct poll_table_struct___127 {
	poll_queue_proc___132 _qproc;
	__poll_t _key;
};

struct pid_namespace___173;

struct upid___173 {
	int nr;
	struct pid_namespace___173 *ns;
};

struct pid_namespace___173 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___202 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___173 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___173 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___173 numbers[1];
};

struct signal_struct___196 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___202 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___202 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___173 *pids[4];
	struct pid___173 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___201 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___134;

struct nsproxy___182 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___173 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___134 *cgroup_ns;
};

struct bio___99;

struct bio_list___99 {
	struct bio___99 *head;
	struct bio___99 *tail;
};

struct cgroup_subsys_state___134;

struct bdi_writeback___92 {
	struct backing_dev_info___92 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___134 *memcg_css;
	struct cgroup_subsys_state___134 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___154;

struct backing_dev_info___92 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___92 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___154 *dev;
	char dev_name[64];
	struct device___154 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___195 *debug_dir;
};

struct io_cq___99;

struct io_context___99 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___99 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___134;

struct css_set___134 {
	struct cgroup_subsys_state___134 *subsys[14];
	refcount_t refcount;
	struct css_set___134 *dom_cset;
	struct cgroup___134 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___134 *mg_src_cgrp;
	struct cgroup___134 *mg_dst_cgrp;
	struct css_set___134 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___134;

struct cgroup_subsys_state___134 {
	struct cgroup___134 *cgroup;
	struct cgroup_subsys___134 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___134 *parent;
};

struct cgroup_file___134 {
	struct kernfs_node___183 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___83;

struct mem_cgroup_per_node___83;

struct mem_cgroup___83 {
	struct cgroup_subsys_state___134 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___134 events_file;
	struct cgroup_file___134 events_local_file;
	struct cgroup_file___134 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___83 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___202 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___83 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___99;

struct blk_integrity___99 {
	const struct blk_integrity_profile___99 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___99 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___99 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___99;

struct elevator_queue___99;

struct blk_mq_ops___96;

struct blk_mq_hw_ctx___96;

struct gendisk___100;

struct blkcg_gq___94;

struct blk_mq_tag_set___96;

struct request_queue___99 {
	struct request___99 *last_merge;
	struct elevator_queue___99 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___96 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___96 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___100 *disk;
	struct kobject___183 kobj;
	struct kobject___183 *mq_kobj;
	struct blk_integrity___99 integrity;
	struct device___154 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___94 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___96 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___99 bio_split;
	struct dentry___195 *debugfs_dir;
	struct dentry___195 *sched_debugfs_dir;
	struct dentry___195 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___178 {
	struct vm_struct___178 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___200 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___183;

struct attribute_group___183 {
	const char *name;
	umode_t (*is_visible)(struct kobject___183 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___183 *, struct bin_attribute___183 *, int);
	struct attribute **attrs;
	struct bin_attribute___183 **bin_attrs;
};

struct bin_attribute___183 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___195 * (*f_mapping)();
	ssize_t (*read)(struct file___195 *, struct kobject___183 *, struct bin_attribute___183 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___195 *, struct kobject___183 *, struct bin_attribute___183 *, char *, loff_t, size_t);
	int (*mmap)(struct file___195 *, struct kobject___183 *, struct bin_attribute___183 *, struct vm_area_struct___200 *);
};

struct sysfs_ops___183 {
	ssize_t (*show)(struct kobject___183 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___183 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___183;

struct kset___183 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___183 kobj;
	const struct kset_uevent_ops___183 *uevent_ops;
};

struct kobj_type___183 {
	void (*release)(struct kobject___183 *);
	const struct sysfs_ops___183 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___183 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___183 *);
	const void * (*namespace)(struct kobject___183 *);
	void (*get_ownership)(struct kobject___183 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___183 {
	int (* const filter)(struct kset___183 *, struct kobject___183 *);
	const char * (* const name)(struct kset___183 *, struct kobject___183 *);
	int (* const uevent)(struct kset___183 *, struct kobject___183 *, struct kobj_uevent_env *);
};

struct fwnode_operations___154;

struct fwnode_handle___154 {
	struct fwnode_handle___154 *secondary;
	const struct fwnode_operations___154 *ops;
	struct device___154 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___154;

struct fwnode_endpoint___154;

struct fwnode_operations___154 {
	struct fwnode_handle___154 * (*get)(struct fwnode_handle___154 *);
	void (*put)(struct fwnode_handle___154 *);
	bool (*device_is_available)(const struct fwnode_handle___154 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___154 *, const struct device___154 *);
	bool (*property_present)(const struct fwnode_handle___154 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___154 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___154 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___154 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*get_parent)(const struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*get_next_child_node)(const struct fwnode_handle___154 *, struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*get_named_child_node)(const struct fwnode_handle___154 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___154 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___154 *);
	struct fwnode_handle___154 * (*graph_get_next_endpoint)(const struct fwnode_handle___154 *, struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*graph_get_remote_endpoint)(const struct fwnode_handle___154 *);
	struct fwnode_handle___154 * (*graph_get_port_parent)(struct fwnode_handle___154 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___154 *, struct fwnode_endpoint___154 *);
	int (*add_links)(struct fwnode_handle___154 *);
};

struct wakeup_source___154;

struct pm_subsys_data___2;

struct dev_pm_qos___11;

struct dev_pm_info___154 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___154 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___154 *, s32);
	struct dev_pm_qos___11 *qos;
};

struct device_type___154;

struct bus_type___154;

struct device_driver___154;

struct dev_pm_domain___154;

struct device_node___57;

struct class___154;

struct device___154 {
	struct kobject___183 kobj;
	struct device___154 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___154 *type;
	struct bus_type___154 *bus;
	struct device_driver___154 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___154 power;
	struct dev_pm_domain___154 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___35 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___57 *of_node;
	struct fwnode_handle___154 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___154 *class;
	const struct attribute_group___183 **groups;
	void (*release)(struct device___154 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___154 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___154 *local_fwnode;
};

struct fwnode_reference_args___154 {
	struct fwnode_handle___154 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___46 {
	char *name;
	int length;
	void *value;
	struct property___46 *next;
	long unsigned int _flags;
	struct bin_attribute___183 attr;
};

struct device_node___57 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___154 fwnode;
	struct property___46 *properties;
	struct property___46 *deadprops;
	struct device_node___57 *parent;
	struct device_node___57 *child;
	struct device_node___57 *sibling;
	struct kobject___183 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___33 {
	struct fwnode_handle___154 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___35 {
	int (*match)(struct irq_domain___35 *, struct device_node___57 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___35 *, struct irq_fwspec___33 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___35 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___35 *, unsigned int);
	int (*xlate)(struct irq_domain___35 *, struct device_node___57 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___35 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___35 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___35 *, struct irq_data___36 *, bool);
	void (*deactivate)(struct irq_domain___35 *, struct irq_data___36 *);
	int (*translate)(struct irq_domain___35 *, struct irq_fwspec___33 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___35;

struct irq_domain___35 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___35 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___154 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___35 *gc;
	struct irq_domain___35 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___36 *revmap[0];
};

struct irq_chip_generic___35;

struct irq_domain_chip_generic___35 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___35 *gc[0];
};

struct dev_pm_ops___154 {
	int (*prepare)(struct device___154 *);
	void (*complete)(struct device___154 *);
	int (*suspend)(struct device___154 *);
	int (*resume)(struct device___154 *);
	int (*freeze)(struct device___154 *);
	int (*thaw)(struct device___154 *);
	int (*poweroff)(struct device___154 *);
	int (*restore)(struct device___154 *);
	int (*suspend_late)(struct device___154 *);
	int (*resume_early)(struct device___154 *);
	int (*freeze_late)(struct device___154 *);
	int (*thaw_early)(struct device___154 *);
	int (*poweroff_late)(struct device___154 *);
	int (*restore_early)(struct device___154 *);
	int (*suspend_noirq)(struct device___154 *);
	int (*resume_noirq)(struct device___154 *);
	int (*freeze_noirq)(struct device___154 *);
	int (*thaw_noirq)(struct device___154 *);
	int (*poweroff_noirq)(struct device___154 *);
	int (*restore_noirq)(struct device___154 *);
	int (*runtime_suspend)(struct device___154 *);
	int (*runtime_resume)(struct device___154 *);
	int (*runtime_idle)(struct device___154 *);
};

struct pm_domain_data___2;

struct pm_subsys_data___2 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___2 *domain_data;
};

struct pm_domain_data___2 {
	struct list_head list_node;
	struct device___154 *dev;
};

struct wakeup_source___154 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___154 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___11;

struct dev_pm_qos___11 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___11 *resume_latency_req;
	struct dev_pm_qos_request___11 *latency_tolerance_req;
	struct dev_pm_qos_request___11 *flags_req;
};

struct dev_pm_domain___154 {
	struct dev_pm_ops___154 ops;
	int (*start)(struct device___154 *);
	void (*detach)(struct device___154 *, bool);
	int (*activate)(struct device___154 *);
	void (*sync)(struct device___154 *);
	void (*dismiss)(struct device___154 *);
};

struct bus_type___154 {
	const char *name;
	const char *dev_name;
	struct device___154 *dev_root;
	const struct attribute_group___183 **bus_groups;
	const struct attribute_group___183 **dev_groups;
	const struct attribute_group___183 **drv_groups;
	int (*match)(struct device___154 *, struct device_driver___154 *);
	int (*uevent)(struct device___154 *, struct kobj_uevent_env *);
	int (*probe)(struct device___154 *);
	void (*sync_state)(struct device___154 *);
	void (*remove)(struct device___154 *);
	void (*shutdown)(struct device___154 *);
	int (*online)(struct device___154 *);
	int (*offline)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	int (*num_vf)(struct device___154 *);
	int (*dma_configure)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___154 {
	const char *name;
	struct bus_type___154 *bus;
	struct module___179 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___154 *);
	void (*sync_state)(struct device___154 *);
	int (*remove)(struct device___154 *);
	void (*shutdown)(struct device___154 *);
	int (*suspend)(struct device___154 *, pm_message_t);
	int (*resume)(struct device___154 *);
	const struct attribute_group___183 **groups;
	const struct attribute_group___183 **dev_groups;
	const struct dev_pm_ops___154 *pm;
	void (*coredump)(struct device___154 *);
	struct driver_private *p;
};

struct device_type___154 {
	const char *name;
	const struct attribute_group___183 **groups;
	int (*uevent)(struct device___154 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___154 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___154 *);
	const struct dev_pm_ops___154 *pm;
};

struct class___154 {
	const char *name;
	struct module___179 *owner;
	const struct attribute_group___183 **class_groups;
	const struct attribute_group___183 **dev_groups;
	struct kobject___183 *dev_kobj;
	int (*dev_uevent)(struct device___154 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___154 *, umode_t *);
	void (*class_release)(struct class___154 *);
	void (*dev_release)(struct device___154 *);
	int (*shutdown_pre)(struct device___154 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___154 *);
	void (*get_ownership)(struct device___154 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___154 *pm;
	struct subsys_private *p;
};

struct dentry_operations___195;

struct dentry___195 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___195 *d_parent;
	struct qstr d_name;
	struct inode___195 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___195 *d_op;
	struct super_block___195 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___195;

struct cdev___42;

struct inode___195 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___195 *i_op;
	struct super_block___195 *i_sb;
	struct address_space___195 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___92 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___196 *i_fop;
		void (*free_inode)(struct inode___195 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___195 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___42 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___195 {
	int (*d_revalidate)(struct dentry___195 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___195 *, unsigned int);
	int (*d_hash)(const struct dentry___195 *, struct qstr *);
	int (*d_compare)(const struct dentry___195 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___195 *);
	int (*d_init)(struct dentry___195 *);
	void (*d_release)(struct dentry___195 *);
	void (*d_prune)(struct dentry___195 *);
	void (*d_iput)(struct dentry___195 *, struct inode___195 *);
	char * (*d_dname)(struct dentry___195 *, char *, int);
	struct vfsmount___195 * (*d_automount)(struct path___195 *);
	int (*d_manage)(const struct path___195 *, bool);
	struct dentry___195 * (*d_real)(struct dentry___195 *, const struct inode___195 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___195;

struct mem_dqinfo___195 {
	struct quota_format_type___195 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___195;

struct quota_info___195 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___195 *files[3];
	struct mem_dqinfo___195 info[3];
	const struct quota_format_ops___195 *ops[3];
};

struct rcuwait___196 {
	struct task_struct___202 *task;
};

struct percpu_rw_semaphore___196 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___196 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___195 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___196 rw_sem[3];
};

struct shrink_control___83;

struct shrinker___83 {
	long unsigned int (*count_objects)(struct shrinker___83 *, struct shrink_control___83 *);
	long unsigned int (*scan_objects)(struct shrinker___83 *, struct shrink_control___83 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___195;

struct dquot_operations___195;

struct quotactl_ops___195;

struct block_device___100;

struct super_block___195 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___195 *s_type;
	const struct super_operations___195 *s_op;
	const struct dquot_operations___195 *dq_op;
	const struct quotactl_ops___195 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___195 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___100 *s_bdev;
	struct backing_dev_info___92 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___195 s_dquot;
	struct sb_writers___195 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___195 *s_d_op;
	int cleancache_poolid;
	struct shrinker___83 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___195 {
	struct dentry___195 *mnt_root;
	struct super_block___195 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___83 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___83 *memcg;
};

struct psi_group___134 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___202 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___134;

struct cgroup_rstat_cpu___134;

struct cgroup___134 {
	struct cgroup_subsys_state___134 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___183 *kn;
	struct cgroup_file___134 procs_file;
	struct cgroup_file___134 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___134 *subsys[14];
	struct cgroup_root___134 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___134 *dom_cgrp;
	struct cgroup___134 *old_dom_cgrp;
	struct cgroup_rstat_cpu___134 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___134 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___99 {
	struct request_queue___99 *q;
	struct io_context___99 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___92;

struct kiocb___195 {
	struct file___195 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___195 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___92 *ki_waitq;
	};
};

struct iattr___195 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___195 *ia_file;
};

struct dquot___195 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___195 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___195 {
	int qf_fmt_id;
	const struct quota_format_ops___195 *qf_ops;
	struct module___179 *qf_owner;
	struct quota_format_type___195 *qf_next;
};

struct quota_format_ops___195 {
	int (*check_quota_file)(struct super_block___195 *, int);
	int (*read_file_info)(struct super_block___195 *, int);
	int (*write_file_info)(struct super_block___195 *, int);
	int (*free_file_info)(struct super_block___195 *, int);
	int (*read_dqblk)(struct dquot___195 *);
	int (*commit_dqblk)(struct dquot___195 *);
	int (*release_dqblk)(struct dquot___195 *);
	int (*get_next_id)(struct super_block___195 *, struct kqid *);
};

struct dquot_operations___195 {
	int (*write_dquot)(struct dquot___195 *);
	struct dquot___195 * (*alloc_dquot)(struct super_block___195 *, int);
	void (*destroy_dquot)(struct dquot___195 *);
	int (*acquire_dquot)(struct dquot___195 *);
	int (*release_dquot)(struct dquot___195 *);
	int (*mark_dirty)(struct dquot___195 *);
	int (*write_info)(struct super_block___195 *, int);
	qsize_t * (*get_reserved_space)(struct inode___195 *);
	int (*get_projid)(struct inode___195 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___195 *, qsize_t *);
	int (*get_next_id)(struct super_block___195 *, struct kqid *);
};

struct quotactl_ops___195 {
	int (*quota_on)(struct super_block___195 *, int, int, const struct path___195 *);
	int (*quota_off)(struct super_block___195 *, int);
	int (*quota_enable)(struct super_block___195 *, unsigned int);
	int (*quota_disable)(struct super_block___195 *, unsigned int);
	int (*quota_sync)(struct super_block___195 *, int);
	int (*set_info)(struct super_block___195 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___195 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___195 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___195 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___195 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___195 *, unsigned int);
};

struct wait_page_queue___92 {
	struct page___200 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___92;

struct readahead_control___92;

struct swap_info_struct___51;

struct address_space_operations___195 {
	int (*writepage)(struct page___200 *, struct writeback_control___92 *);
	int (*readpage)(struct file___195 *, struct page___200 *);
	int (*writepages)(struct address_space___195 *, struct writeback_control___92 *);
	int (*set_page_dirty)(struct page___200 *);
	int (*readpages)(struct file___195 *, struct address_space___195 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___92 *);
	int (*write_begin)(struct file___195 *, struct address_space___195 *, loff_t, unsigned int, unsigned int, struct page___200 **, void **);
	int (*write_end)(struct file___195 *, struct address_space___195 *, loff_t, unsigned int, unsigned int, struct page___200 *, void *);
	sector_t (*bmap)(struct address_space___195 *, sector_t);
	void (*invalidatepage)(struct page___200 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___200 *, gfp_t);
	void (*freepage)(struct page___200 *);
	ssize_t (*direct_IO)(struct kiocb___195 *, struct iov_iter___117 *);
	int (*migratepage)(struct address_space___195 *, struct page___200 *, struct page___200 *, enum migrate_mode);
	bool (*isolate_page)(struct page___200 *, isolate_mode_t);
	void (*putback_page)(struct page___200 *);
	int (*launder_page)(struct page___200 *);
	int (*is_partially_uptodate)(struct page___200 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___200 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___195 *, struct page___200 *);
	int (*swap_activate)(struct swap_info_struct___51 *, struct file___195 *, sector_t *);
	void (*swap_deactivate)(struct file___195 *);
};

struct writeback_control___92 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___92 *wb;
	struct inode___195 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___92 {
	struct file___195 *file;
	struct address_space___195 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___115;

struct iov_iter___117 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___115 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___51 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___100 *bdev;
	struct file___195 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___42 {
	struct kobject___183 kobj;
	struct module___179 *owner;
	const struct file_operations___196 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___195 {
	struct dentry___195 * (*lookup)(struct inode___195 *, struct dentry___195 *, unsigned int);
	const char * (*get_link)(struct dentry___195 *, struct inode___195 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___195 *, int);
	struct posix_acl * (*get_acl)(struct inode___195 *, int, bool);
	int (*readlink)(struct dentry___195 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___195 *, struct dentry___195 *, umode_t, bool);
	int (*link)(struct dentry___195 *, struct inode___195 *, struct dentry___195 *);
	int (*unlink)(struct inode___195 *, struct dentry___195 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___195 *, struct dentry___195 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___195 *, struct dentry___195 *, umode_t);
	int (*rmdir)(struct inode___195 *, struct dentry___195 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___195 *, struct dentry___195 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___195 *, struct dentry___195 *, struct inode___195 *, struct dentry___195 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___195 *, struct iattr___195 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___195 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___195 *, char *, size_t);
	int (*fiemap)(struct inode___195 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___195 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___195 *, struct dentry___195 *, struct file___195 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___195 *, struct dentry___195 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___195 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___195 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___195 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___195 {
	void (*fl_copy_lock)(struct file_lock___195 *, struct file_lock___195 *);
	void (*fl_release_private)(struct file_lock___195 *);
};

struct fasync_struct___195;

struct lock_manager_operations___195;

struct file_lock___195 {
	struct file_lock___195 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___195 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___195 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___195 *fl_ops;
	const struct lock_manager_operations___195 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___195 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___195 *);
	int (*lm_grant)(struct file_lock___195 *, int);
	bool (*lm_break)(struct file_lock___195 *);
	int (*lm_change)(struct file_lock___195 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___195 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___195 *);
};

struct fasync_struct___195 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___195 *fa_next;
	struct file___195 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___195 {
	struct inode___195 * (*alloc_inode)(struct super_block___195 *);
	void (*destroy_inode)(struct inode___195 *);
	void (*free_inode)(struct inode___195 *);
	void (*dirty_inode)(struct inode___195 *, int);
	int (*write_inode)(struct inode___195 *, struct writeback_control___92 *);
	int (*drop_inode)(struct inode___195 *);
	void (*evict_inode)(struct inode___195 *);
	void (*put_super)(struct super_block___195 *);
	int (*sync_fs)(struct super_block___195 *, int);
	int (*freeze_super)(struct super_block___195 *);
	int (*freeze_fs)(struct super_block___195 *);
	int (*thaw_super)(struct super_block___195 *);
	int (*unfreeze_fs)(struct super_block___195 *);
	int (*statfs)(struct dentry___195 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___195 *, int *, char *);
	void (*umount_begin)(struct super_block___195 *);
	int (*show_options)(struct seq_file___171 *, struct dentry___195 *);
	int (*show_devname)(struct seq_file___171 *, struct dentry___195 *);
	int (*show_path)(struct seq_file___171 *, struct dentry___195 *);
	int (*show_stats)(struct seq_file___171 *, struct dentry___195 *);
	ssize_t (*quota_read)(struct super_block___195 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___195 *, int, const char *, size_t, loff_t);
	struct dquot___195 ** (*get_dquots)(struct inode___195 *);
	long int (*nr_cached_objects)(struct super_block___195 *, struct shrink_control___83 *);
	long int (*free_cached_objects)(struct super_block___195 *, struct shrink_control___83 *);
	struct file___195 * (*real_loop)(struct file___195 *);
};

struct block_device___100 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___195 *bd_inode;
	struct super_block___195 *bd_super;
	void *bd_claiming;
	struct device___154 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___183 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___100 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___195 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___99(struct bio___99 *);

struct bio_vec___115 {
	struct page___200 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___99;

struct bio___99 {
	struct bio___99 *bi_next;
	struct block_device___100 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___99 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___94 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___99 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___115 *bi_io_vec;
	struct bio_set___99 *bi_pool;
	struct bio_vec___115 bi_inline_vecs[0];
};

struct kernel_param_ops___179 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___179 *);
	int (*get)(char *, const struct kernel_param___179 *);
	void (*free)(void *);
};

struct kparam_array___179;

struct kernel_param___179 {
	const char *name;
	struct module___179 *mod;
	const struct kernel_param_ops___179 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___179 *arr;
	};
};

struct kparam_array___179 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___179 *ops;
	void *elem;
};

struct module_attribute___179 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___179 *, struct module_kobject___179 *, char *);
	ssize_t (*store)(struct module_attribute___179 *, struct module_kobject___179 *, const char *, size_t);
	void (*setup)(struct module___179 *, const char *);
	int (*test)(struct module___179 *);
	void (*free)(struct module___179 *);
};

struct acpi_device___7;

struct acpi_hotplug_profile___7 {
	struct kobject___183 kobj;
	int (*scan_dependent)(struct acpi_device___7 *);
	void (*notify_online)(struct acpi_device___7 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___7 {
	void (*func)(struct acpi_device_wakeup_context___7 *);
	struct device___154 *dev;
};

struct acpi_device_wakeup___7 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___7 context;
	struct wakeup_source___154 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___7;

struct acpi_hotplug_context___7;

struct acpi_driver___7;

struct acpi_device___7 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___154 fwnode;
	struct acpi_device___7 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___7 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___7 *handler;
	struct acpi_hotplug_context___7 *hp;
	struct acpi_driver___7 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___154 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___7 *);
};

struct acpi_scan_handler___7 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___7 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___7 *);
	void (*bind)(struct device___154 *);
	void (*unbind)(struct device___154 *);
	struct acpi_hotplug_profile___7 hotplug;
};

struct acpi_hotplug_context___7 {
	struct acpi_device___7 *self;
	int (*notify)(struct acpi_device___7 *, u32);
	void (*uevent)(struct acpi_device___7 *, u32);
	void (*fixup)(struct acpi_device___7 *);
};

typedef int (*acpi_op_add___7)(struct acpi_device___7 *);

typedef int (*acpi_op_remove___7)(struct acpi_device___7 *);

typedef void (*acpi_op_notify___7)(struct acpi_device___7 *, u32);

struct acpi_device_ops___7 {
	acpi_op_add___7 add;
	acpi_op_remove___7 remove;
	acpi_op_notify___7 notify;
};

struct acpi_driver___7 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___7 ops;
	struct device_driver___154 drv;
	struct module___179 *owner;
};

struct irq_chip___36 {
	struct device___154 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___36 *);
	void (*irq_shutdown)(struct irq_data___36 *);
	void (*irq_enable)(struct irq_data___36 *);
	void (*irq_disable)(struct irq_data___36 *);
	void (*irq_ack)(struct irq_data___36 *);
	void (*irq_mask)(struct irq_data___36 *);
	void (*irq_mask_ack)(struct irq_data___36 *);
	void (*irq_unmask)(struct irq_data___36 *);
	void (*irq_eoi)(struct irq_data___36 *);
	int (*irq_set_affinity)(struct irq_data___36 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___36 *);
	int (*irq_set_type)(struct irq_data___36 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___36 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___36 *);
	void (*irq_bus_sync_unlock)(struct irq_data___36 *);
	void (*irq_cpu_online)(struct irq_data___36 *);
	void (*irq_cpu_offline)(struct irq_data___36 *);
	void (*irq_suspend)(struct irq_data___36 *);
	void (*irq_resume)(struct irq_data___36 *);
	void (*irq_pm_shutdown)(struct irq_data___36 *);
	void (*irq_calc_mask)(struct irq_data___36 *);
	void (*irq_print_chip)(struct irq_data___36 *, struct seq_file___171 *);
	int (*irq_request_resources)(struct irq_data___36 *);
	void (*irq_release_resources)(struct irq_data___36 *);
	void (*irq_compose_msi_msg)(struct irq_data___36 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___36 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___36 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___36 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___36 *, void *);
	void (*ipi_send_single)(struct irq_data___36 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___36 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___36 *);
	void (*irq_nmi_teardown)(struct irq_data___36 *);
	long unsigned int flags;
};

struct irqaction___26 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___26 *next;
	irq_handler_t thread_fn;
	struct task_struct___202 *thread;
	struct irqaction___26 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___35 {
	struct irq_chip___36 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___37 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___35 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___35 *);
	void (*resume)(struct irq_chip_generic___35 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___35 *domain;
	struct list_head list;
	struct irq_chip_type___35 chip_types[0];
};

struct seq_operations___171 {
	void * (*start)(struct seq_file___171 *, loff_t *);
	void (*stop)(struct seq_file___171 *, void *);
	void * (*next)(struct seq_file___171 *, void *, loff_t *);
	int (*show)(struct seq_file___171 *, void *);
};

struct dev_pagemap_ops___190 {
	void (*page_free)(struct page___200 *);
	void (*kill)(struct dev_pagemap___190 *);
	void (*cleanup)(struct dev_pagemap___190 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___190 *);
};

struct dev_pm_qos_request___11 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___154 *dev;
};

struct cgroup_namespace___134 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___134 *root_cset;
};

struct cftype___134;

struct cgroup_subsys___134 {
	struct cgroup_subsys_state___134 * (*css_alloc)(struct cgroup_subsys_state___134 *);
	int (*css_online)(struct cgroup_subsys_state___134 *);
	void (*css_offline)(struct cgroup_subsys_state___134 *);
	void (*css_released)(struct cgroup_subsys_state___134 *);
	void (*css_free)(struct cgroup_subsys_state___134 *);
	void (*css_reset)(struct cgroup_subsys_state___134 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___134 *, int);
	int (*css_extra_stat_show)(struct seq_file___171 *, struct cgroup_subsys_state___134 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___202 *, struct css_set___134 *);
	void (*cancel_fork)(struct task_struct___202 *, struct css_set___134 *);
	void (*fork)(struct task_struct___202 *);
	void (*exit)(struct task_struct___202 *);
	void (*release)(struct task_struct___202 *);
	void (*bind)(struct cgroup_subsys_state___134 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___134 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___134 *dfl_cftypes;
	struct cftype___134 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___134 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___134 *updated_children;
	struct cgroup___134 *updated_next;
};

struct cgroup_root___134 {
	struct kernfs_root___183 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___134 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___134 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___134 *ss;
	struct list_head node;
	struct kernfs_ops___183 *kf_ops;
	int (*open)(struct kernfs_open_file___183 *);
	void (*release)(struct kernfs_open_file___183 *);
	u64 (*read_u64)(struct cgroup_subsys_state___134 *, struct cftype___134 *);
	s64 (*read_s64)(struct cgroup_subsys_state___134 *, struct cftype___134 *);
	int (*seq_show)(struct seq_file___171 *, void *);
	void * (*seq_start)(struct seq_file___171 *, loff_t *);
	void * (*seq_next)(struct seq_file___171 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___171 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___134 *, struct cftype___134 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___134 *, struct cftype___134 *, s64);
	ssize_t (*write)(struct kernfs_open_file___183 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___183 *, struct poll_table_struct___127 *);
};

struct block_device_operations___99;

struct gendisk___100 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___100 *part0;
	const struct block_device_operations___99 *fops;
	struct request_queue___99 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___92 *bdi;
	struct kobject___183 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___183 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___99 {
	struct bio___99 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___115 *bip_vec;
	struct bio_vec___115 bip_inline_vecs[0];
};

struct blkcg___94;

struct blkg_policy_data___94;

struct blkcg_gq___94 {
	struct request_queue___99 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___94 *blkcg;
	struct blkcg_gq___94 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___94 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___99 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___99(struct request___99 *);

typedef void integrity_complete_fn___99(struct request___99 *, unsigned int);

struct blk_integrity_profile___99 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___99 *prepare_fn;
	integrity_complete_fn___99 *complete_fn;
	const char *name;
};

struct block_device_operations___99 {
	blk_qc_t (*submit_bio)(struct bio___99 *);
	int (*open)(struct block_device___100 *, fmode_t);
	void (*release)(struct gendisk___100 *, fmode_t);
	int (*rw_page)(struct block_device___100 *, sector_t, struct page___200 *, unsigned int);
	int (*ioctl)(struct block_device___100 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___100 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___100 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___100 *);
	int (*getgeo)(struct block_device___100 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___100 *, bool);
	void (*swap_slot_free_notify)(struct block_device___100 *, long unsigned int);
	int (*report_zones)(struct gendisk___100 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___100 *, umode_t *);
	struct module___179 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___100 *, sector_t *);
};

typedef void rq_end_io_fn___99(struct request___99 *, blk_status_t);

struct request___99 {
	struct request_queue___99 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___96 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___99 *bio;
	struct bio___99 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___115 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___99 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___99 *saved_end_io;
		} flush;
	};
	struct gendisk___100 *rq_disk;
	struct block_device___100 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___99 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___96 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___99 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___183 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___195 *debugfs_dir;
	struct dentry___195 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___99;

struct elevator_mq_ops___99 {
	int (*init_sched)(struct request_queue___99 *, struct elevator_type___99 *);
	void (*exit_sched)(struct elevator_queue___99 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___96 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___96 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___96 *);
	bool (*allow_merge)(struct request_queue___99 *, struct request___99 *, struct bio___99 *);
	bool (*bio_merge)(struct request_queue___99 *, struct bio___99 *, unsigned int);
	int (*request_merge)(struct request_queue___99 *, struct request___99 **, struct bio___99 *);
	void (*request_merged)(struct request_queue___99 *, struct request___99 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___99 *, struct request___99 *, struct request___99 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___99 *);
	void (*finish_request)(struct request___99 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___96 *, struct list_head *, bool);
	struct request___99 * (*dispatch_request)(struct blk_mq_hw_ctx___96 *);
	bool (*has_work)(struct blk_mq_hw_ctx___96 *);
	void (*completed_request)(struct request___99 *, u64);
	void (*requeue_request)(struct request___99 *);
	struct request___99 * (*former_request)(struct request_queue___99 *, struct request___99 *);
	struct request___99 * (*next_request)(struct request_queue___99 *, struct request___99 *);
	void (*init_icq)(struct io_cq___99 *);
	void (*exit_icq)(struct io_cq___99 *);
};

struct elv_fs_entry___99;

struct elevator_type___99 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___99 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___99 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___179 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___99 {
	struct elevator_type___99 *type;
	void *elevator_data;
	struct kobject___183 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___99 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___99 *, char *);
	ssize_t (*store)(struct elevator_queue___99 *, const char *, size_t);
};

struct blk_mq_queue_data___96;

struct blk_mq_ops___96 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___96 *, const struct blk_mq_queue_data___96 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___96 *);
	int (*get_budget)(struct request_queue___99 *);
	void (*put_budget)(struct request_queue___99 *, int);
	void (*set_rq_budget_token)(struct request___99 *, int);
	int (*get_rq_budget_token)(struct request___99 *);
	enum blk_eh_timer_return (*timeout)(struct request___99 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___96 *);
	void (*complete)(struct request___99 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___96 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___96 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___96 *, struct request___99 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___96 *, struct request___99 *, unsigned int);
	void (*initialize_rq_fn)(struct request___99 *);
	void (*cleanup_rq)(struct request___99 *);
	bool (*busy)(struct request_queue___99 *);
	int (*map_queues)(struct blk_mq_tag_set___96 *);
	void (*show_rq)(struct seq_file___171 *, struct request___99 *);
};

struct blk_mq_tag_set___96 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___96 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___96 {
	struct request___99 *rq;
	bool last;
};

struct blkcg_policy_data___94;

struct blkcg___94 {
	struct cgroup_subsys_state___134 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___94 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___94 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___94 {
	struct blkcg___94 *blkcg;
	int plid;
};

struct blkg_policy_data___94 {
	struct blkcg_gq___94 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___83 {
	struct mem_cgroup___83 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___83 {
	struct lruvec___90 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___83 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___83 *memcg;
};

struct obj_cgroup___83 {
	struct percpu_ref refcnt;
	struct mem_cgroup___83 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

typedef u32 (*acpi_event_handler)(void *);

typedef acpi_status (*acpi_table_handler)(u32, void *, void *);

enum acpi_bus_device_type {
	ACPI_BUS_TYPE_DEVICE = 0,
	ACPI_BUS_TYPE_POWER = 1,
	ACPI_BUS_TYPE_PROCESSOR = 2,
	ACPI_BUS_TYPE_THERMAL = 3,
	ACPI_BUS_TYPE_POWER_BUTTON = 4,
	ACPI_BUS_TYPE_SLEEP_BUTTON = 5,
	ACPI_BUS_TYPE_ECDT_EC = 6,
	ACPI_BUS_DEVICE_TYPE_COUNT = 7,
};

struct acpi_device_physical_node {
	unsigned int node_id;
	struct list_head node;
	struct device___154 *dev;
	bool put_online: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_osc_context {
	char *uuid_str;
	int rev;
	struct acpi_buffer cap;
	struct acpi_buffer ret;
};

struct irq_desc___38;

typedef void (*irq_flow_handler_t___38)(struct irq_desc___38 *);

struct irq_chip___37;

struct irq_domain___36;

struct irq_data___37 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___37 *chip;
	struct irq_domain___36 *domain;
	struct irq_data___37 *parent_data;
	void *chip_data;
};

struct irq_desc___38 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___37 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___38 handle_irq;
	struct irqaction___26 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___183 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___179 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___155;

struct device___155;

struct fwnode_handle___155 {
	struct fwnode_handle___155 *secondary;
	const struct fwnode_operations___155 *ops;
	struct device___155 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___155;

struct fwnode_endpoint___155;

struct fwnode_operations___155 {
	struct fwnode_handle___155 * (*get)(struct fwnode_handle___155 *);
	void (*put)(struct fwnode_handle___155 *);
	bool (*device_is_available)(const struct fwnode_handle___155 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___155 *, const struct device___155 *);
	bool (*property_present)(const struct fwnode_handle___155 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___155 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___155 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___155 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*get_parent)(const struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*get_next_child_node)(const struct fwnode_handle___155 *, struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*get_named_child_node)(const struct fwnode_handle___155 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___155 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___155 *);
	struct fwnode_handle___155 * (*graph_get_next_endpoint)(const struct fwnode_handle___155 *, struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*graph_get_remote_endpoint)(const struct fwnode_handle___155 *);
	struct fwnode_handle___155 * (*graph_get_port_parent)(struct fwnode_handle___155 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___155 *, struct fwnode_endpoint___155 *);
	int (*add_links)(struct fwnode_handle___155 *);
};

struct wakeup_source___155;

struct dev_pm_info___155 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___155 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___2 *subsys_data;
	void (*set_latency_tolerance)(struct device___155 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___155;

struct bus_type___155;

struct device_driver___155;

struct dev_pm_domain___155;

struct dma_map_ops___6;

struct device_node___58;

struct class___155;

struct dev_iommu___6;

struct device___155 {
	struct kobject___183 kobj;
	struct device___155 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___155 *type;
	struct bus_type___155 *bus;
	struct device_driver___155 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___155 power;
	struct dev_pm_domain___155 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___36 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___6 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___58 *of_node;
	struct fwnode_handle___155 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___155 *class;
	const struct attribute_group___183 **groups;
	void (*release)(struct device___155 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___6 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___155 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___155 *local_fwnode;
};

struct fwnode_reference_args___155 {
	struct fwnode_handle___155 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___58 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___155 fwnode;
	struct property___46 *properties;
	struct property___46 *deadprops;
	struct device_node___58 *parent;
	struct device_node___58 *child;
	struct device_node___58 *sibling;
	struct kobject___183 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___19 {
	struct device_node___58 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___34 {
	struct fwnode_handle___155 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___36 {
	int (*match)(struct irq_domain___36 *, struct device_node___58 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___36 *, struct irq_fwspec___34 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___36 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___36 *, unsigned int);
	int (*xlate)(struct irq_domain___36 *, struct device_node___58 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___36 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___36 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___36 *, struct irq_data___37 *, bool);
	void (*deactivate)(struct irq_domain___36 *, struct irq_data___37 *);
	int (*translate)(struct irq_domain___36 *, struct irq_fwspec___34 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___36;

struct irq_domain___36 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___36 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___155 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___36 *gc;
	struct irq_domain___36 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___37 *revmap[0];
};

struct irq_chip_generic___36;

struct irq_domain_chip_generic___36 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___36 *gc[0];
};

struct dev_pm_ops___155 {
	int (*prepare)(struct device___155 *);
	void (*complete)(struct device___155 *);
	int (*suspend)(struct device___155 *);
	int (*resume)(struct device___155 *);
	int (*freeze)(struct device___155 *);
	int (*thaw)(struct device___155 *);
	int (*poweroff)(struct device___155 *);
	int (*restore)(struct device___155 *);
	int (*suspend_late)(struct device___155 *);
	int (*resume_early)(struct device___155 *);
	int (*freeze_late)(struct device___155 *);
	int (*thaw_early)(struct device___155 *);
	int (*poweroff_late)(struct device___155 *);
	int (*restore_early)(struct device___155 *);
	int (*suspend_noirq)(struct device___155 *);
	int (*resume_noirq)(struct device___155 *);
	int (*freeze_noirq)(struct device___155 *);
	int (*thaw_noirq)(struct device___155 *);
	int (*poweroff_noirq)(struct device___155 *);
	int (*restore_noirq)(struct device___155 *);
	int (*runtime_suspend)(struct device___155 *);
	int (*runtime_resume)(struct device___155 *);
	int (*runtime_idle)(struct device___155 *);
};

struct wakeup_source___155 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___155 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___155 {
	struct dev_pm_ops___155 ops;
	int (*start)(struct device___155 *);
	void (*detach)(struct device___155 *, bool);
	int (*activate)(struct device___155 *);
	void (*sync)(struct device___155 *);
	void (*dismiss)(struct device___155 *);
};

struct iommu_ops___6;

struct bus_type___155 {
	const char *name;
	const char *dev_name;
	struct device___155 *dev_root;
	const struct attribute_group___183 **bus_groups;
	const struct attribute_group___183 **dev_groups;
	const struct attribute_group___183 **drv_groups;
	int (*match)(struct device___155 *, struct device_driver___155 *);
	int (*uevent)(struct device___155 *, struct kobj_uevent_env *);
	int (*probe)(struct device___155 *);
	void (*sync_state)(struct device___155 *);
	void (*remove)(struct device___155 *);
	void (*shutdown)(struct device___155 *);
	int (*online)(struct device___155 *);
	int (*offline)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	int (*num_vf)(struct device___155 *);
	int (*dma_configure)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
	const struct iommu_ops___6 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___155 {
	const char *name;
	struct bus_type___155 *bus;
	struct module___179 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___155 *);
	void (*sync_state)(struct device___155 *);
	int (*remove)(struct device___155 *);
	void (*shutdown)(struct device___155 *);
	int (*suspend)(struct device___155 *, pm_message_t);
	int (*resume)(struct device___155 *);
	const struct attribute_group___183 **groups;
	const struct attribute_group___183 **dev_groups;
	const struct dev_pm_ops___155 *pm;
	void (*coredump)(struct device___155 *);
	struct driver_private *p;
};

struct iommu_domain___6;

struct iommu_device___6;

struct iommu_sva___6;

struct iommu_ops___6 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___6 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___6 *);
	int (*attach_dev)(struct iommu_domain___6 *, struct device___155 *);
	void (*detach_dev)(struct iommu_domain___6 *, struct device___155 *);
	int (*map)(struct iommu_domain___6 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___6 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___6 *, long unsigned int, size_t, struct iommu_iotlb_gather___4 *);
	size_t (*unmap_pages)(struct iommu_domain___6 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___4 *);
	void (*flush_iotlb_all)(struct iommu_domain___6 *);
	void (*iotlb_sync_map)(struct iommu_domain___6 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___6 *, struct iommu_iotlb_gather___4 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___6 *, dma_addr_t);
	struct iommu_device___6 * (*probe_device)(struct device___155 *);
	void (*release_device)(struct device___155 *);
	void (*probe_finalize)(struct device___155 *);
	struct iommu_group * (*device_group)(struct device___155 *);
	int (*enable_nesting)(struct iommu_domain___6 *);
	int (*set_pgtable_quirks)(struct iommu_domain___6 *, long unsigned int);
	void (*get_resv_regions)(struct device___155 *, struct list_head *);
	void (*put_resv_regions)(struct device___155 *, struct list_head *);
	void (*apply_resv_region)(struct device___155 *, struct iommu_domain___6 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___155 *, struct of_phandle_args___19 *);
	bool (*is_attach_deferred)(struct iommu_domain___6 *, struct device___155 *);
	bool (*dev_has_feat)(struct device___155 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___155 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___155 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___155 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___6 *, struct device___155 *);
	void (*aux_detach_dev)(struct iommu_domain___6 *, struct device___155 *);
	int (*aux_get_pasid)(struct iommu_domain___6 *, struct device___155 *);
	struct iommu_sva___6 * (*sva_bind)(struct device___155 *, struct mm_struct___201 *, void *);
	void (*sva_unbind)(struct iommu_sva___6 *);
	u32 (*sva_get_pasid)(struct iommu_sva___6 *);
	int (*page_response)(struct device___155 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___6 *, struct device___155 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___6 *, struct device___155 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___155 *, u32);
	int (*def_domain_type)(struct device___155 *);
	long unsigned int pgsize_bitmap;
	struct module___179 *owner;
};

struct device_type___155 {
	const char *name;
	const struct attribute_group___183 **groups;
	int (*uevent)(struct device___155 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___155 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___155 *);
	const struct dev_pm_ops___155 *pm;
};

struct class___155 {
	const char *name;
	struct module___179 *owner;
	const struct attribute_group___183 **class_groups;
	const struct attribute_group___183 **dev_groups;
	struct kobject___183 *dev_kobj;
	int (*dev_uevent)(struct device___155 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___155 *, umode_t *);
	void (*class_release)(struct class___155 *);
	void (*dev_release)(struct device___155 *);
	int (*shutdown_pre)(struct device___155 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___155 *);
	void (*get_ownership)(struct device___155 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___155 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___6 {
	void * (*alloc)(struct device___155 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___155 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___200 * (*alloc_pages)(struct device___155 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___155 *, size_t, struct page___200 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___155 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___155 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___155 *, struct vm_area_struct___200 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___155 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___155 *, struct page___200 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___155 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___155 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___155 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___155 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___155 *, u64);
	u64 (*get_required_mask)(struct device___155 *);
	size_t (*max_mapping_size)(struct device___155 *);
	long unsigned int (*get_merge_boundary)(struct device___155 *);
};

struct iommu_fwspec___6;

struct dev_iommu___6 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___6 *fwspec;
	struct iommu_device___6 *iommu_dev;
	void *priv;
};

struct acpi_pnp_device_id {
	u32 length;
	char *string;
};

struct acpi_pnp_device_id_list {
	u32 count;
	u32 list_size;
	struct acpi_pnp_device_id ids[0];
};

struct acpi_device_info {
	u32 info_size;
	u32 name;
	acpi_object_type type;
	u8 param_count;
	u16 valid;
	u8 flags;
	u8 highest_dstates[4];
	u8 lowest_dstates[5];
	u64 address;
	struct acpi_pnp_device_id hardware_id;
	struct acpi_pnp_device_id unique_id;
	struct acpi_pnp_device_id class_code;
	struct acpi_pnp_device_id_list compatible_id_list;
};

struct acpi_table_spcr {
	struct acpi_table_header header;
	u8 interface_type;
	u8 reserved[3];
	struct acpi_generic_address serial_port;
	u8 interrupt_type;
	u8 pc_interrupt;
	u32 interrupt;
	u8 baud_rate;
	u8 parity;
	u8 stop_bits;
	u8 flow_control;
	u8 terminal_type;
	u8 reserved1;
	u16 pci_device_id;
	u16 pci_vendor_id;
	u8 pci_bus;
	u8 pci_device;
	u8 pci_function;
	u32 pci_flags;
	u8 pci_segment;
	u32 reserved2;
} __attribute__((packed));

struct acpi_table_stao {
	struct acpi_table_header header;
	u8 ignore_uart;
} __attribute__((packed));

struct acpi_device___8;

struct acpi_hotplug_profile___8 {
	struct kobject___183 kobj;
	int (*scan_dependent)(struct acpi_device___8 *);
	void (*notify_online)(struct acpi_device___8 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___8 {
	void (*func)(struct acpi_device_wakeup_context___8 *);
	struct device___155 *dev;
};

struct acpi_device_wakeup___8 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___8 context;
	struct wakeup_source___155 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___8;

struct acpi_hotplug_context___8;

struct acpi_driver___8;

struct acpi_device___8 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___155 fwnode;
	struct acpi_device___8 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___8 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___8 *handler;
	struct acpi_hotplug_context___8 *hp;
	struct acpi_driver___8 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___155 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___8 *);
};

struct acpi_scan_handler___8 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___8 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___8 *);
	void (*bind)(struct device___155 *);
	void (*unbind)(struct device___155 *);
	struct acpi_hotplug_profile___8 hotplug;
};

struct acpi_hotplug_context___8 {
	struct acpi_device___8 *self;
	int (*notify)(struct acpi_device___8 *, u32);
	void (*uevent)(struct acpi_device___8 *, u32);
	void (*fixup)(struct acpi_device___8 *);
};

typedef int (*acpi_op_add___8)(struct acpi_device___8 *);

typedef int (*acpi_op_remove___8)(struct acpi_device___8 *);

typedef void (*acpi_op_notify___8)(struct acpi_device___8 *, u32);

struct acpi_device_ops___8 {
	acpi_op_add___8 add;
	acpi_op_remove___8 remove;
	acpi_op_notify___8 notify;
};

struct acpi_driver___8 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___8 ops;
	struct device_driver___155 drv;
	struct module___179 *owner;
};

struct acpi_dep_data {
	struct list_head node;
	acpi_handle supplier;
	acpi_handle consumer;
};

struct acpi_device_physical_node___2 {
	unsigned int node_id;
	struct list_head node;
	struct device___155 *dev;
	bool put_online: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___37 {
	struct device___155 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___37 *);
	void (*irq_shutdown)(struct irq_data___37 *);
	void (*irq_enable)(struct irq_data___37 *);
	void (*irq_disable)(struct irq_data___37 *);
	void (*irq_ack)(struct irq_data___37 *);
	void (*irq_mask)(struct irq_data___37 *);
	void (*irq_mask_ack)(struct irq_data___37 *);
	void (*irq_unmask)(struct irq_data___37 *);
	void (*irq_eoi)(struct irq_data___37 *);
	int (*irq_set_affinity)(struct irq_data___37 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___37 *);
	int (*irq_set_type)(struct irq_data___37 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___37 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___37 *);
	void (*irq_bus_sync_unlock)(struct irq_data___37 *);
	void (*irq_cpu_online)(struct irq_data___37 *);
	void (*irq_cpu_offline)(struct irq_data___37 *);
	void (*irq_suspend)(struct irq_data___37 *);
	void (*irq_resume)(struct irq_data___37 *);
	void (*irq_pm_shutdown)(struct irq_data___37 *);
	void (*irq_calc_mask)(struct irq_data___37 *);
	void (*irq_print_chip)(struct irq_data___37 *, struct seq_file___171 *);
	int (*irq_request_resources)(struct irq_data___37 *);
	void (*irq_release_resources)(struct irq_data___37 *);
	void (*irq_compose_msi_msg)(struct irq_data___37 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___37 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___37 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___37 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___37 *, void *);
	void (*ipi_send_single)(struct irq_data___37 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___37 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___37 *);
	void (*irq_nmi_teardown)(struct irq_data___37 *);
	long unsigned int flags;
};

struct irq_chip_type___36 {
	struct irq_chip___37 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___38 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___36 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___36 *);
	void (*resume)(struct irq_chip_generic___36 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___36 *domain;
	struct list_head list;
	struct irq_chip_type___36 chip_types[0];
};

enum acpi_reconfig_event {
	ACPI_RECONFIG_DEVICE_ADD = 0,
	ACPI_RECONFIG_DEVICE_REMOVE = 1,
};

typedef int (*iommu_fault_handler_t___6)(struct iommu_domain___6 *, struct device___155 *, long unsigned int, int, void *);

struct iommu_domain___6 {
	unsigned int type;
	const struct iommu_ops___6 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___6 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_device___6 {
	struct list_head list;
	const struct iommu_ops___6 *ops;
	struct fwnode_handle___155 *fwnode;
	struct device___155 *dev;
};

struct iommu_sva___6 {
	struct device___155 *dev;
};

struct iommu_fwspec___6 {
	const struct iommu_ops___6 *ops;
	struct fwnode_handle___155 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct acpi_scan_clear_dep_work {
	struct work_struct work;
	struct acpi_device___8 *adev;
};

struct resource_win {
	struct resource res;
	resource_size_t offset;
};

struct irq_override_cmp {
	const struct dmi_system_id *system;
	unsigned char irq;
	unsigned char triggering;
	unsigned char polarity;
	unsigned char shareable;
};

struct res_proc_context {
	struct list_head *list;
	int (*preproc)(struct acpi_resource *, void *);
	void *preproc_data;
	int count;
	int error;
};

struct acpi_processor___2;

struct acpi_processor_throttling___2 {
	unsigned int state;
	unsigned int platform_limit;
	struct acpi_pct_register control_register;
	struct acpi_pct_register status_register;
	short: 16;
	unsigned int state_count;
	int: 32;
	struct acpi_processor_tx_tss *states_tss;
	struct acpi_tsd_package domain_info;
	cpumask_var_t shared_cpu_map;
	int (*acpi_processor_get_throttling)(struct acpi_processor___2 *);
	int (*acpi_processor_set_throttling)(struct acpi_processor___2 *, int, bool);
	u32 address;
	u8 duty_offset;
	u8 duty_width;
	u8 tsd_valid_flag;
	char: 8;
	unsigned int shared_type;
	struct acpi_processor_tx states[16];
	int: 32;
} __attribute__((packed));

struct acpi_processor___2 {
	acpi_handle handle;
	u32 acpi_id;
	phys_cpuid_t phys_id;
	u32 id;
	u32 pblk;
	int performance_platform_limit;
	int throttling_platform_limit;
	struct acpi_processor_flags flags;
	struct acpi_processor_power power;
	struct acpi_processor_performance *performance;
	struct acpi_processor_throttling___2 throttling;
	struct acpi_processor_limit limit;
	struct thermal_cooling_device *cdev;
	struct device___154 *dev;
	struct freq_qos_request perflib_req;
	struct freq_qos_request thermal_req;
};

struct acpi_processor_errata {
	u8 smp;
	struct {
		u8 throttle: 1;
		u8 fdma: 1;
		u8 reserved: 6;
		u32 bmisx;
	} piix4;
};

typedef u32 acpi_event_status;

struct acpi_table_ecdt {
	struct acpi_table_header header;
	struct acpi_generic_address control;
	struct acpi_generic_address data;
	u32 uid;
	u8 gpe;
	u8 id[1];
} __attribute__((packed));

struct transaction;

struct acpi_ec {
	acpi_handle handle;
	int gpe;
	int irq;
	long unsigned int command_addr;
	long unsigned int data_addr;
	bool global_lock;
	long unsigned int flags;
	long unsigned int reference_count;
	struct mutex mutex;
	wait_queue_head_t wait;
	struct list_head list;
	struct transaction *curr;
	spinlock_t lock;
	struct work_struct work;
	long unsigned int timestamp;
	long unsigned int nr_pending_queries;
	unsigned int events_in_progress;
	unsigned int queries_in_progress;
	bool busy_polling;
	unsigned int polling_guard;
};

struct transaction {
	const u8 *wdata;
	u8 *rdata;
	short unsigned int irq_count;
	u8 command;
	u8 wi;
	u8 ri;
	u8 wlen;
	u8 rlen;
	u8 flags;
};

typedef int (*acpi_ec_query_func)(void *);

enum ec_command {
	ACPI_EC_COMMAND_READ = 128,
	ACPI_EC_COMMAND_WRITE = 129,
	ACPI_EC_BURST_ENABLE = 130,
	ACPI_EC_BURST_DISABLE = 131,
	ACPI_EC_COMMAND_QUERY = 132,
};

enum {
	EC_FLAGS_QUERY_ENABLED = 0,
	EC_FLAGS_QUERY_PENDING = 1,
	EC_FLAGS_QUERY_GUARDING = 2,
	EC_FLAGS_EVENT_HANDLER_INSTALLED = 3,
	EC_FLAGS_EC_HANDLER_INSTALLED = 4,
	EC_FLAGS_QUERY_METHODS_INSTALLED = 5,
	EC_FLAGS_STARTED = 6,
	EC_FLAGS_STOPPED = 7,
	EC_FLAGS_EVENTS_MASKED = 8,
};

struct acpi_ec_query_handler {
	struct list_head node;
	acpi_ec_query_func func;
	acpi_handle handle;
	void *data;
	u8 query_bit;
	struct kref kref;
};

struct acpi_ec_query {
	struct transaction transaction;
	struct work_struct work;
	struct acpi_ec_query_handler *handler;
	struct acpi_ec *ec;
};

struct platform_device_info___2 {
	struct device___155 *parent;
	struct fwnode_handle___155 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct dock_station {
	acpi_handle handle;
	long unsigned int last_dock_time;
	u32 flags;
	struct list_head dependent_devices;
	struct list_head sibling;
	struct platform_device___16 *dock_device;
};

struct dock_dependent_device {
	struct list_head list;
	struct acpi_device___8 *adev;
};

enum dock_callback_type {
	DOCK_CALL_HANDLER = 0,
	DOCK_CALL_FIXUP = 1,
	DOCK_CALL_UEVENT = 2,
};

struct acpi_pci_root_ops___2;

struct acpi_pci_root_info___2 {
	struct acpi_pci_root___2 *root;
	struct acpi_device___8 *bridge;
	struct acpi_pci_root_ops___2 *ops;
	struct list_head resources;
	char name[16];
};

struct acpi_pci_root_ops___2 {
	struct pci_ops___8 *pci_ops;
	int (*init_info)(struct acpi_pci_root_info___2 *);
	void (*release_info)(struct acpi_pci_root_info___2 *);
	int (*prepare_resources)(struct acpi_pci_root_info___2 *);
};

struct pci_osc_bit_struct {
	u32 bit;
	char *desc;
};

struct acpi_handle_node {
	struct list_head node;
	acpi_handle handle;
};

struct acpi_pci_link_irq {
	u32 active;
	u8 triggering;
	u8 polarity;
	u8 resource_type;
	u8 possible_count;
	u32 possible[16];
	u8 initialized: 1;
	u8 reserved: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_pci_link {
	struct list_head list;
	struct acpi_device___8 *device;
	struct acpi_pci_link_irq irq;
	int refcnt;
};

struct acpi_pci_routing_table {
	u32 length;
	u32 pin;
	u64 address;
	u32 source_index;
	char source[4];
};

struct acpi_prt_entry {
	struct acpi_pci_id id;
	u8 pin;
	acpi_handle link;
	u32 index;
};

struct prt_quirk {
	const struct dmi_system_id *system;
	unsigned int segment;
	unsigned int bus;
	unsigned int device;
	unsigned char pin;
	const char *source;
	const char *actual_source;
};

struct irq_desc___39;

typedef void (*irq_flow_handler_t___39)(struct irq_desc___39 *);

struct irq_chip___38;

struct irq_domain___37;

struct irq_data___38 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___38 *chip;
	struct irq_domain___37 *domain;
	struct irq_data___38 *parent_data;
	void *chip_data;
};

struct kset___184;

struct kobj_type___184;

struct kernfs_node___184;

struct kobject___184 {
	const char *name;
	struct list_head entry;
	struct kobject___184 *parent;
	struct kset___184 *kset;
	struct kobj_type___184 *ktype;
	struct kernfs_node___184 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___27;

struct module___180;

struct irq_desc___39 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___38 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___39 handle_irq;
	struct irqaction___27 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___184 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___180 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___196;

struct super_block___196;

struct file_system_type___196 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___196 * (*mount)(struct file_system_type___196 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___196 *);
	struct module___180 *owner;
	struct file_system_type___196 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___196;

struct kiocb___196;

struct iov_iter___118;

struct poll_table_struct___128;

struct vm_area_struct___201;

struct inode___196;

struct file_lock___196;

struct page___201;

struct seq_file___172;

struct file_operations___197 {
	struct module___180 *owner;
	loff_t (*llseek)(struct file___196 *, loff_t, int);
	ssize_t (*read)(struct file___196 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___196 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___196 *, struct iov_iter___118 *);
	ssize_t (*write_iter)(struct kiocb___196 *, struct iov_iter___118 *);
	int (*iopoll)(struct kiocb___196 *, bool);
	int (*iterate)(struct file___196 *, struct dir_context *);
	int (*iterate_shared)(struct file___196 *, struct dir_context *);
	__poll_t (*poll)(struct file___196 *, struct poll_table_struct___128 *);
	long int (*unlocked_ioctl)(struct file___196 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___196 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___196 *, struct vm_area_struct___201 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___196 *, struct file___196 *);
	int (*flush)(struct file___196 *, fl_owner_t);
	int (*release)(struct inode___196 *, struct file___196 *);
	int (*fsync)(struct file___196 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___196 *, int);
	int (*lock)(struct file___196 *, int, struct file_lock___196 *);
	ssize_t (*sendpage)(struct file___196 *, struct page___201 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___196 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___196 *, long unsigned int);
	int (*flock)(struct file___196 *, int, struct file_lock___196 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___196 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___196 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___196 *, long int, struct file_lock___196 **, void **);
	long int (*fallocate)(struct file___196 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___172 *, struct file___196 *);
	ssize_t (*copy_file_range)(struct file___196 *, loff_t, struct file___196 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___196 *, loff_t, struct file___196 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___196 *, loff_t, loff_t, int);
};

struct vmacache___201 {
	u64 seqnum;
	struct vm_area_struct___201 *vmas[4];
};

struct page_frag___201 {
	struct page___201 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___202;

struct pid___174;

struct nsproxy___183;

struct signal_struct___197;

struct bio_list___100;

struct backing_dev_info___93;

struct io_context___100;

struct css_set___135;

struct mem_cgroup___84;

struct request_queue___100;

struct vm_struct___179;

struct task_struct___203 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___203 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___202 *mm;
	struct mm_struct___202 *active_mm;
	struct vmacache___201 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___203 *real_parent;
	struct task_struct___203 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___203 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___174 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___183 *nsproxy;
	struct signal_struct___197 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___203 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___100 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___93 *backing_dev_info;
	struct io_context___100 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___135 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___201 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___84 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___84 *active_memcg;
	struct request_queue___100 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___203 *oom_reaper_list;
	struct vm_struct___179 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___180 {
	struct kobject___184 kobj;
	struct module___180 *mod;
	struct kobject___184 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___180 {
	struct module___180 *mod;
	struct latch_tree_node node;
};

struct module_layout___180 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___180 mtn;
};

struct module_attribute___180;

struct kernel_param___180;

struct module___180 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___180 mkobj;
	struct module_attribute___180 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___184 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___180 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___180 core_layout;
	struct module_layout___180 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___201 *pgtable_t___201;

struct address_space___196;

struct dev_pagemap___191;

struct page___201 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___196 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___201 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___201 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___202 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___191 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___191;

struct vm_area_struct___201 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___201 *vm_next;
	struct vm_area_struct___201 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___202 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___191 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___196 *vm_file;
	struct file___196 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___201;

struct mm_struct___202 {
	struct {
		struct vm_area_struct___201 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___196 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___201 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___203 *owner;
		struct user_namespace___25 *user_ns;
		struct file___196 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___196;

struct address_space___196 {
	struct inode___196 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___196 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___191;

struct dev_pagemap___191 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___191 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___196;

struct path___196 {
	struct vfsmount___196 *mnt;
	struct dentry___196 *dentry;
};

struct fown_struct___174 {
	rwlock_t lock;
	struct pid___174 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___196 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___196 f_path;
	struct inode___196 *f_inode;
	const struct file_operations___197 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___174 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___196 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___191;

struct vm_operations_struct___191 {
	void (*open)(struct vm_area_struct___201 *);
	void (*close)(struct vm_area_struct___201 *);
	int (*may_split)(struct vm_area_struct___201 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___201 *);
	int (*mprotect)(struct vm_area_struct___201 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___191 *);
	vm_fault_t (*huge_fault)(struct vm_fault___191 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___191 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___201 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___191 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___191 *);
	int (*access)(struct vm_area_struct___201 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___201 *);
	int (*set_policy)(struct vm_area_struct___201 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___201 *, long unsigned int);
	struct page___201 * (*find_special_page)(struct vm_area_struct___201 *, long unsigned int);
};

struct core_thread___201 {
	struct task_struct___203 *task;
	struct core_thread___201 *next;
};

struct core_state___201 {
	atomic_t nr_threads;
	struct core_thread___201 dumper;
	struct completion startup;
};

struct vm_fault___191 {
	const struct {
		struct vm_area_struct___201 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___201 *cow_page;
	struct page___201 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___201 prealloc_pte;
};

struct pglist_data___91;

struct lruvec___91 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___91 *pgdat;
};

struct zone___91 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___91 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___91 {
	struct zone___91 *zone;
	int zone_idx;
};

struct zonelist___91 {
	struct zoneref___91 _zonerefs[321];
};

struct pglist_data___91 {
	struct zone___91 node_zones[5];
	struct zonelist___91 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___203 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___203 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___91 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___184;

struct kernfs_elem_dir___184 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___184 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___184;

struct kernfs_root___184 {
	struct kernfs_node___184 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___184 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___184 {
	struct kernfs_node___184 *target_kn;
};

struct kernfs_ops___184;

struct kernfs_elem_attr___184 {
	const struct kernfs_ops___184 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___184 *notify_next;
};

struct kernfs_node___184 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___184 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___184 dir;
		struct kernfs_elem_symlink___184 symlink;
		struct kernfs_elem_attr___184 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___184;

struct kernfs_ops___184 {
	int (*open)(struct kernfs_open_file___184 *);
	void (*release)(struct kernfs_open_file___184 *);
	int (*seq_show)(struct seq_file___172 *, void *);
	void * (*seq_start)(struct seq_file___172 *, loff_t *);
	void * (*seq_next)(struct seq_file___172 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___172 *, void *);
	ssize_t (*read)(struct kernfs_open_file___184 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___184 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___184 *, struct poll_table_struct___128 *);
	int (*mmap)(struct kernfs_open_file___184 *, struct vm_area_struct___201 *);
};

struct kernfs_syscall_ops___184 {
	int (*show_options)(struct seq_file___172 *, struct kernfs_root___184 *);
	int (*mkdir)(struct kernfs_node___184 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___184 *);
	int (*rename)(struct kernfs_node___184 *, struct kernfs_node___184 *, const char *);
	int (*show_path)(struct seq_file___172 *, struct kernfs_node___184 *, struct kernfs_root___184 *);
};

struct seq_operations___172;

struct seq_file___172 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___172 *op;
	int poll_event;
	const struct file___196 *file;
	void *private;
};

struct kernfs_open_file___184 {
	struct kernfs_node___184 *kn;
	struct file___196 *file;
	struct seq_file___172 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___191 *vm_ops;
};

typedef void (*poll_queue_proc___133)(struct file___196 *, wait_queue_head_t *, struct poll_table_struct___128 *);

struct poll_table_struct___128 {
	poll_queue_proc___133 _qproc;
	__poll_t _key;
};

struct pid_namespace___174;

struct upid___174 {
	int nr;
	struct pid_namespace___174 *ns;
};

struct pid_namespace___174 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___203 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___174 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___174 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___174 numbers[1];
};

struct signal_struct___197 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___203 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___203 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___174 *pids[4];
	struct pid___174 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___202 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___135;

struct nsproxy___183 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___174 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___135 *cgroup_ns;
};

struct bio___100;

struct bio_list___100 {
	struct bio___100 *head;
	struct bio___100 *tail;
};

struct cgroup_subsys_state___135;

struct bdi_writeback___93 {
	struct backing_dev_info___93 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___135 *memcg_css;
	struct cgroup_subsys_state___135 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___156;

struct backing_dev_info___93 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___93 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___156 *dev;
	char dev_name[64];
	struct device___156 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___196 *debug_dir;
};

struct io_cq___100;

struct io_context___100 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___100 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___135;

struct css_set___135 {
	struct cgroup_subsys_state___135 *subsys[14];
	refcount_t refcount;
	struct css_set___135 *dom_cset;
	struct cgroup___135 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___135 *mg_src_cgrp;
	struct cgroup___135 *mg_dst_cgrp;
	struct css_set___135 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___135;

struct cgroup_subsys_state___135 {
	struct cgroup___135 *cgroup;
	struct cgroup_subsys___135 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___135 *parent;
};

struct cgroup_file___135 {
	struct kernfs_node___184 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___84;

struct mem_cgroup_per_node___84;

struct mem_cgroup___84 {
	struct cgroup_subsys_state___135 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___135 events_file;
	struct cgroup_file___135 events_local_file;
	struct cgroup_file___135 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___84 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___203 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___84 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___100;

struct blk_integrity___100 {
	const struct blk_integrity_profile___100 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___100 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___100 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___100;

struct elevator_queue___100;

struct blk_mq_ops___97;

struct blk_mq_hw_ctx___97;

struct gendisk___101;

struct blkcg_gq___95;

struct blk_mq_tag_set___97;

struct request_queue___100 {
	struct request___100 *last_merge;
	struct elevator_queue___100 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___97 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___97 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___101 *disk;
	struct kobject___184 kobj;
	struct kobject___184 *mq_kobj;
	struct blk_integrity___100 integrity;
	struct device___156 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___95 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___97 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___100 bio_split;
	struct dentry___196 *debugfs_dir;
	struct dentry___196 *sched_debugfs_dir;
	struct dentry___196 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___179 {
	struct vm_struct___179 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___201 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___184;

struct attribute_group___184 {
	const char *name;
	umode_t (*is_visible)(struct kobject___184 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___184 *, struct bin_attribute___184 *, int);
	struct attribute **attrs;
	struct bin_attribute___184 **bin_attrs;
};

struct bin_attribute___184 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___196 * (*f_mapping)();
	ssize_t (*read)(struct file___196 *, struct kobject___184 *, struct bin_attribute___184 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___196 *, struct kobject___184 *, struct bin_attribute___184 *, char *, loff_t, size_t);
	int (*mmap)(struct file___196 *, struct kobject___184 *, struct bin_attribute___184 *, struct vm_area_struct___201 *);
};

struct sysfs_ops___184 {
	ssize_t (*show)(struct kobject___184 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___184 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___184;

struct kset___184 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___184 kobj;
	const struct kset_uevent_ops___184 *uevent_ops;
};

struct kobj_type___184 {
	void (*release)(struct kobject___184 *);
	const struct sysfs_ops___184 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___184 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___184 *);
	const void * (*namespace)(struct kobject___184 *);
	void (*get_ownership)(struct kobject___184 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___184 {
	int (* const filter)(struct kset___184 *, struct kobject___184 *);
	const char * (* const name)(struct kset___184 *, struct kobject___184 *);
	int (* const uevent)(struct kset___184 *, struct kobject___184 *, struct kobj_uevent_env *);
};

struct fwnode_operations___156;

struct fwnode_handle___156 {
	struct fwnode_handle___156 *secondary;
	const struct fwnode_operations___156 *ops;
	struct device___156 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___156;

struct fwnode_endpoint___156;

struct fwnode_operations___156 {
	struct fwnode_handle___156 * (*get)(struct fwnode_handle___156 *);
	void (*put)(struct fwnode_handle___156 *);
	bool (*device_is_available)(const struct fwnode_handle___156 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___156 *, const struct device___156 *);
	bool (*property_present)(const struct fwnode_handle___156 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___156 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___156 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___156 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*get_parent)(const struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*get_next_child_node)(const struct fwnode_handle___156 *, struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*get_named_child_node)(const struct fwnode_handle___156 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___156 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___156 *);
	struct fwnode_handle___156 * (*graph_get_next_endpoint)(const struct fwnode_handle___156 *, struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*graph_get_remote_endpoint)(const struct fwnode_handle___156 *);
	struct fwnode_handle___156 * (*graph_get_port_parent)(struct fwnode_handle___156 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___156 *, struct fwnode_endpoint___156 *);
	int (*add_links)(struct fwnode_handle___156 *);
};

struct wakeup_source___156;

struct pm_subsys_data___3;

struct dev_pm_info___156 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___156 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___156 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___156;

struct bus_type___156;

struct device_driver___156;

struct dev_pm_domain___156;

struct device_node___59;

struct class___156;

struct device___156 {
	struct kobject___184 kobj;
	struct device___156 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___156 *type;
	struct bus_type___156 *bus;
	struct device_driver___156 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___156 power;
	struct dev_pm_domain___156 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___37 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___59 *of_node;
	struct fwnode_handle___156 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___156 *class;
	const struct attribute_group___184 **groups;
	void (*release)(struct device___156 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___156 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___156 *local_fwnode;
};

struct fwnode_reference_args___156 {
	struct fwnode_handle___156 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___47 {
	char *name;
	int length;
	void *value;
	struct property___47 *next;
	long unsigned int _flags;
	struct bin_attribute___184 attr;
};

struct device_node___59 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___156 fwnode;
	struct property___47 *properties;
	struct property___47 *deadprops;
	struct device_node___59 *parent;
	struct device_node___59 *child;
	struct device_node___59 *sibling;
	struct kobject___184 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___35 {
	struct fwnode_handle___156 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___37 {
	int (*match)(struct irq_domain___37 *, struct device_node___59 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___37 *, struct irq_fwspec___35 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___37 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___37 *, unsigned int);
	int (*xlate)(struct irq_domain___37 *, struct device_node___59 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___37 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___37 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___37 *, struct irq_data___38 *, bool);
	void (*deactivate)(struct irq_domain___37 *, struct irq_data___38 *);
	int (*translate)(struct irq_domain___37 *, struct irq_fwspec___35 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___37;

struct irq_domain___37 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___37 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___156 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___37 *gc;
	struct irq_domain___37 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___38 *revmap[0];
};

struct irq_chip_generic___37;

struct irq_domain_chip_generic___37 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___37 *gc[0];
};

struct dev_pm_ops___156 {
	int (*prepare)(struct device___156 *);
	void (*complete)(struct device___156 *);
	int (*suspend)(struct device___156 *);
	int (*resume)(struct device___156 *);
	int (*freeze)(struct device___156 *);
	int (*thaw)(struct device___156 *);
	int (*poweroff)(struct device___156 *);
	int (*restore)(struct device___156 *);
	int (*suspend_late)(struct device___156 *);
	int (*resume_early)(struct device___156 *);
	int (*freeze_late)(struct device___156 *);
	int (*thaw_early)(struct device___156 *);
	int (*poweroff_late)(struct device___156 *);
	int (*restore_early)(struct device___156 *);
	int (*suspend_noirq)(struct device___156 *);
	int (*resume_noirq)(struct device___156 *);
	int (*freeze_noirq)(struct device___156 *);
	int (*thaw_noirq)(struct device___156 *);
	int (*poweroff_noirq)(struct device___156 *);
	int (*restore_noirq)(struct device___156 *);
	int (*runtime_suspend)(struct device___156 *);
	int (*runtime_resume)(struct device___156 *);
	int (*runtime_idle)(struct device___156 *);
};

struct pm_domain_data___3;

struct pm_subsys_data___3 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___3 *domain_data;
};

struct pm_domain_data___3 {
	struct list_head list_node;
	struct device___156 *dev;
};

struct wakeup_source___156 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___156 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___156 {
	struct dev_pm_ops___156 ops;
	int (*start)(struct device___156 *);
	void (*detach)(struct device___156 *, bool);
	int (*activate)(struct device___156 *);
	void (*sync)(struct device___156 *);
	void (*dismiss)(struct device___156 *);
};

struct bus_type___156 {
	const char *name;
	const char *dev_name;
	struct device___156 *dev_root;
	const struct attribute_group___184 **bus_groups;
	const struct attribute_group___184 **dev_groups;
	const struct attribute_group___184 **drv_groups;
	int (*match)(struct device___156 *, struct device_driver___156 *);
	int (*uevent)(struct device___156 *, struct kobj_uevent_env *);
	int (*probe)(struct device___156 *);
	void (*sync_state)(struct device___156 *);
	void (*remove)(struct device___156 *);
	void (*shutdown)(struct device___156 *);
	int (*online)(struct device___156 *);
	int (*offline)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	int (*num_vf)(struct device___156 *);
	int (*dma_configure)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___156 {
	const char *name;
	struct bus_type___156 *bus;
	struct module___180 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___156 *);
	void (*sync_state)(struct device___156 *);
	int (*remove)(struct device___156 *);
	void (*shutdown)(struct device___156 *);
	int (*suspend)(struct device___156 *, pm_message_t);
	int (*resume)(struct device___156 *);
	const struct attribute_group___184 **groups;
	const struct attribute_group___184 **dev_groups;
	const struct dev_pm_ops___156 *pm;
	void (*coredump)(struct device___156 *);
	struct driver_private *p;
};

struct device_type___156 {
	const char *name;
	const struct attribute_group___184 **groups;
	int (*uevent)(struct device___156 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___156 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___156 *);
	const struct dev_pm_ops___156 *pm;
};

struct class___156 {
	const char *name;
	struct module___180 *owner;
	const struct attribute_group___184 **class_groups;
	const struct attribute_group___184 **dev_groups;
	struct kobject___184 *dev_kobj;
	int (*dev_uevent)(struct device___156 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___156 *, umode_t *);
	void (*class_release)(struct class___156 *);
	void (*dev_release)(struct device___156 *);
	int (*shutdown_pre)(struct device___156 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___156 *);
	void (*get_ownership)(struct device___156 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___156 *pm;
	struct subsys_private *p;
};

struct dentry_operations___196;

struct dentry___196 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___196 *d_parent;
	struct qstr d_name;
	struct inode___196 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___196 *d_op;
	struct super_block___196 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___196;

struct cdev___43;

struct inode___196 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___196 *i_op;
	struct super_block___196 *i_sb;
	struct address_space___196 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___93 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___197 *i_fop;
		void (*free_inode)(struct inode___196 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___196 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___43 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___196 {
	int (*d_revalidate)(struct dentry___196 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___196 *, unsigned int);
	int (*d_hash)(const struct dentry___196 *, struct qstr *);
	int (*d_compare)(const struct dentry___196 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___196 *);
	int (*d_init)(struct dentry___196 *);
	void (*d_release)(struct dentry___196 *);
	void (*d_prune)(struct dentry___196 *);
	void (*d_iput)(struct dentry___196 *, struct inode___196 *);
	char * (*d_dname)(struct dentry___196 *, char *, int);
	struct vfsmount___196 * (*d_automount)(struct path___196 *);
	int (*d_manage)(const struct path___196 *, bool);
	struct dentry___196 * (*d_real)(struct dentry___196 *, const struct inode___196 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___196;

struct mem_dqinfo___196 {
	struct quota_format_type___196 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___196;

struct quota_info___196 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___196 *files[3];
	struct mem_dqinfo___196 info[3];
	const struct quota_format_ops___196 *ops[3];
};

struct rcuwait___197 {
	struct task_struct___203 *task;
};

struct percpu_rw_semaphore___197 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___197 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___196 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___197 rw_sem[3];
};

struct shrink_control___84;

struct shrinker___84 {
	long unsigned int (*count_objects)(struct shrinker___84 *, struct shrink_control___84 *);
	long unsigned int (*scan_objects)(struct shrinker___84 *, struct shrink_control___84 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___196;

struct dquot_operations___196;

struct quotactl_ops___196;

struct block_device___101;

struct super_block___196 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___196 *s_type;
	const struct super_operations___196 *s_op;
	const struct dquot_operations___196 *dq_op;
	const struct quotactl_ops___196 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___196 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___101 *s_bdev;
	struct backing_dev_info___93 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___196 s_dquot;
	struct sb_writers___196 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___196 *s_d_op;
	int cleancache_poolid;
	struct shrinker___84 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___196 {
	struct dentry___196 *mnt_root;
	struct super_block___196 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___84 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___84 *memcg;
};

struct psi_group___135 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___203 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___135;

struct cgroup_rstat_cpu___135;

struct cgroup___135 {
	struct cgroup_subsys_state___135 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___184 *kn;
	struct cgroup_file___135 procs_file;
	struct cgroup_file___135 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___135 *subsys[14];
	struct cgroup_root___135 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___135 *dom_cgrp;
	struct cgroup___135 *old_dom_cgrp;
	struct cgroup_rstat_cpu___135 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___135 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___100 {
	struct request_queue___100 *q;
	struct io_context___100 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___93;

struct kiocb___196 {
	struct file___196 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___196 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___93 *ki_waitq;
	};
};

struct iattr___196 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___196 *ia_file;
};

struct dquot___196 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___196 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___196 {
	int qf_fmt_id;
	const struct quota_format_ops___196 *qf_ops;
	struct module___180 *qf_owner;
	struct quota_format_type___196 *qf_next;
};

struct quota_format_ops___196 {
	int (*check_quota_file)(struct super_block___196 *, int);
	int (*read_file_info)(struct super_block___196 *, int);
	int (*write_file_info)(struct super_block___196 *, int);
	int (*free_file_info)(struct super_block___196 *, int);
	int (*read_dqblk)(struct dquot___196 *);
	int (*commit_dqblk)(struct dquot___196 *);
	int (*release_dqblk)(struct dquot___196 *);
	int (*get_next_id)(struct super_block___196 *, struct kqid *);
};

struct dquot_operations___196 {
	int (*write_dquot)(struct dquot___196 *);
	struct dquot___196 * (*alloc_dquot)(struct super_block___196 *, int);
	void (*destroy_dquot)(struct dquot___196 *);
	int (*acquire_dquot)(struct dquot___196 *);
	int (*release_dquot)(struct dquot___196 *);
	int (*mark_dirty)(struct dquot___196 *);
	int (*write_info)(struct super_block___196 *, int);
	qsize_t * (*get_reserved_space)(struct inode___196 *);
	int (*get_projid)(struct inode___196 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___196 *, qsize_t *);
	int (*get_next_id)(struct super_block___196 *, struct kqid *);
};

struct quotactl_ops___196 {
	int (*quota_on)(struct super_block___196 *, int, int, const struct path___196 *);
	int (*quota_off)(struct super_block___196 *, int);
	int (*quota_enable)(struct super_block___196 *, unsigned int);
	int (*quota_disable)(struct super_block___196 *, unsigned int);
	int (*quota_sync)(struct super_block___196 *, int);
	int (*set_info)(struct super_block___196 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___196 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___196 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___196 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___196 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___196 *, unsigned int);
};

struct wait_page_queue___93 {
	struct page___201 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___93;

struct readahead_control___93;

struct swap_info_struct___52;

struct address_space_operations___196 {
	int (*writepage)(struct page___201 *, struct writeback_control___93 *);
	int (*readpage)(struct file___196 *, struct page___201 *);
	int (*writepages)(struct address_space___196 *, struct writeback_control___93 *);
	int (*set_page_dirty)(struct page___201 *);
	int (*readpages)(struct file___196 *, struct address_space___196 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___93 *);
	int (*write_begin)(struct file___196 *, struct address_space___196 *, loff_t, unsigned int, unsigned int, struct page___201 **, void **);
	int (*write_end)(struct file___196 *, struct address_space___196 *, loff_t, unsigned int, unsigned int, struct page___201 *, void *);
	sector_t (*bmap)(struct address_space___196 *, sector_t);
	void (*invalidatepage)(struct page___201 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___201 *, gfp_t);
	void (*freepage)(struct page___201 *);
	ssize_t (*direct_IO)(struct kiocb___196 *, struct iov_iter___118 *);
	int (*migratepage)(struct address_space___196 *, struct page___201 *, struct page___201 *, enum migrate_mode);
	bool (*isolate_page)(struct page___201 *, isolate_mode_t);
	void (*putback_page)(struct page___201 *);
	int (*launder_page)(struct page___201 *);
	int (*is_partially_uptodate)(struct page___201 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___201 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___196 *, struct page___201 *);
	int (*swap_activate)(struct swap_info_struct___52 *, struct file___196 *, sector_t *);
	void (*swap_deactivate)(struct file___196 *);
};

struct writeback_control___93 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___93 *wb;
	struct inode___196 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___93 {
	struct file___196 *file;
	struct address_space___196 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___116;

struct iov_iter___118 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___116 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___52 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___101 *bdev;
	struct file___196 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___43 {
	struct kobject___184 kobj;
	struct module___180 *owner;
	const struct file_operations___197 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___196 {
	struct dentry___196 * (*lookup)(struct inode___196 *, struct dentry___196 *, unsigned int);
	const char * (*get_link)(struct dentry___196 *, struct inode___196 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___196 *, int);
	struct posix_acl * (*get_acl)(struct inode___196 *, int, bool);
	int (*readlink)(struct dentry___196 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___196 *, struct dentry___196 *, umode_t, bool);
	int (*link)(struct dentry___196 *, struct inode___196 *, struct dentry___196 *);
	int (*unlink)(struct inode___196 *, struct dentry___196 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___196 *, struct dentry___196 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___196 *, struct dentry___196 *, umode_t);
	int (*rmdir)(struct inode___196 *, struct dentry___196 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___196 *, struct dentry___196 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___196 *, struct dentry___196 *, struct inode___196 *, struct dentry___196 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___196 *, struct iattr___196 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___196 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___196 *, char *, size_t);
	int (*fiemap)(struct inode___196 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___196 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___196 *, struct dentry___196 *, struct file___196 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___196 *, struct dentry___196 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___196 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___196 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___196 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___196 {
	void (*fl_copy_lock)(struct file_lock___196 *, struct file_lock___196 *);
	void (*fl_release_private)(struct file_lock___196 *);
};

struct fasync_struct___196;

struct lock_manager_operations___196;

struct file_lock___196 {
	struct file_lock___196 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___196 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___196 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___196 *fl_ops;
	const struct lock_manager_operations___196 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___196 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___196 *);
	int (*lm_grant)(struct file_lock___196 *, int);
	bool (*lm_break)(struct file_lock___196 *);
	int (*lm_change)(struct file_lock___196 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___196 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___196 *);
};

struct fasync_struct___196 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___196 *fa_next;
	struct file___196 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___196 {
	struct inode___196 * (*alloc_inode)(struct super_block___196 *);
	void (*destroy_inode)(struct inode___196 *);
	void (*free_inode)(struct inode___196 *);
	void (*dirty_inode)(struct inode___196 *, int);
	int (*write_inode)(struct inode___196 *, struct writeback_control___93 *);
	int (*drop_inode)(struct inode___196 *);
	void (*evict_inode)(struct inode___196 *);
	void (*put_super)(struct super_block___196 *);
	int (*sync_fs)(struct super_block___196 *, int);
	int (*freeze_super)(struct super_block___196 *);
	int (*freeze_fs)(struct super_block___196 *);
	int (*thaw_super)(struct super_block___196 *);
	int (*unfreeze_fs)(struct super_block___196 *);
	int (*statfs)(struct dentry___196 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___196 *, int *, char *);
	void (*umount_begin)(struct super_block___196 *);
	int (*show_options)(struct seq_file___172 *, struct dentry___196 *);
	int (*show_devname)(struct seq_file___172 *, struct dentry___196 *);
	int (*show_path)(struct seq_file___172 *, struct dentry___196 *);
	int (*show_stats)(struct seq_file___172 *, struct dentry___196 *);
	ssize_t (*quota_read)(struct super_block___196 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___196 *, int, const char *, size_t, loff_t);
	struct dquot___196 ** (*get_dquots)(struct inode___196 *);
	long int (*nr_cached_objects)(struct super_block___196 *, struct shrink_control___84 *);
	long int (*free_cached_objects)(struct super_block___196 *, struct shrink_control___84 *);
	struct file___196 * (*real_loop)(struct file___196 *);
};

struct block_device___101 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___196 *bd_inode;
	struct super_block___196 *bd_super;
	void *bd_claiming;
	struct device___156 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___184 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___101 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___196 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___100(struct bio___100 *);

struct bio_vec___116 {
	struct page___201 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___100;

struct bio___100 {
	struct bio___100 *bi_next;
	struct block_device___101 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___100 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___95 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___100 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___116 *bi_io_vec;
	struct bio_set___100 *bi_pool;
	struct bio_vec___116 bi_inline_vecs[0];
};

struct kernel_param_ops___180 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___180 *);
	int (*get)(char *, const struct kernel_param___180 *);
	void (*free)(void *);
};

struct kparam_array___180;

struct kernel_param___180 {
	const char *name;
	struct module___180 *mod;
	const struct kernel_param_ops___180 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___180 *arr;
	};
};

struct kparam_array___180 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___180 *ops;
	void *elem;
};

struct module_attribute___180 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___180 *, struct module_kobject___180 *, char *);
	ssize_t (*store)(struct module_attribute___180 *, struct module_kobject___180 *, const char *, size_t);
	void (*setup)(struct module___180 *, const char *);
	int (*test)(struct module___180 *);
	void (*free)(struct module___180 *);
};

struct acpi_device___9;

struct acpi_hotplug_profile___9 {
	struct kobject___184 kobj;
	int (*scan_dependent)(struct acpi_device___9 *);
	void (*notify_online)(struct acpi_device___9 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___9 {
	void (*func)(struct acpi_device_wakeup_context___9 *);
	struct device___156 *dev;
};

struct acpi_device_wakeup___9 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___9 context;
	struct wakeup_source___156 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___9;

struct acpi_hotplug_context___9;

struct acpi_driver___9;

struct acpi_device___9 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___156 fwnode;
	struct acpi_device___9 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___9 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___9 *handler;
	struct acpi_hotplug_context___9 *hp;
	struct acpi_driver___9 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___156 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___9 *);
};

struct acpi_scan_handler___9 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___9 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___9 *);
	void (*bind)(struct device___156 *);
	void (*unbind)(struct device___156 *);
	struct acpi_hotplug_profile___9 hotplug;
};

struct acpi_hotplug_context___9 {
	struct acpi_device___9 *self;
	int (*notify)(struct acpi_device___9 *, u32);
	void (*uevent)(struct acpi_device___9 *, u32);
	void (*fixup)(struct acpi_device___9 *);
};

typedef int (*acpi_op_add___9)(struct acpi_device___9 *);

typedef int (*acpi_op_remove___9)(struct acpi_device___9 *);

typedef void (*acpi_op_notify___9)(struct acpi_device___9 *, u32);

struct acpi_device_ops___9 {
	acpi_op_add___9 add;
	acpi_op_remove___9 remove;
	acpi_op_notify___9 notify;
};

struct acpi_driver___9 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___9 ops;
	struct device_driver___156 drv;
	struct module___180 *owner;
};

struct irq_chip___38 {
	struct device___156 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___38 *);
	void (*irq_shutdown)(struct irq_data___38 *);
	void (*irq_enable)(struct irq_data___38 *);
	void (*irq_disable)(struct irq_data___38 *);
	void (*irq_ack)(struct irq_data___38 *);
	void (*irq_mask)(struct irq_data___38 *);
	void (*irq_mask_ack)(struct irq_data___38 *);
	void (*irq_unmask)(struct irq_data___38 *);
	void (*irq_eoi)(struct irq_data___38 *);
	int (*irq_set_affinity)(struct irq_data___38 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___38 *);
	int (*irq_set_type)(struct irq_data___38 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___38 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___38 *);
	void (*irq_bus_sync_unlock)(struct irq_data___38 *);
	void (*irq_cpu_online)(struct irq_data___38 *);
	void (*irq_cpu_offline)(struct irq_data___38 *);
	void (*irq_suspend)(struct irq_data___38 *);
	void (*irq_resume)(struct irq_data___38 *);
	void (*irq_pm_shutdown)(struct irq_data___38 *);
	void (*irq_calc_mask)(struct irq_data___38 *);
	void (*irq_print_chip)(struct irq_data___38 *, struct seq_file___172 *);
	int (*irq_request_resources)(struct irq_data___38 *);
	void (*irq_release_resources)(struct irq_data___38 *);
	void (*irq_compose_msi_msg)(struct irq_data___38 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___38 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___38 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___38 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___38 *, void *);
	void (*ipi_send_single)(struct irq_data___38 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___38 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___38 *);
	void (*irq_nmi_teardown)(struct irq_data___38 *);
	long unsigned int flags;
};

struct irqaction___27 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___27 *next;
	irq_handler_t thread_fn;
	struct task_struct___203 *thread;
	struct irqaction___27 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___37 {
	struct irq_chip___38 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___39 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___37 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___37 *);
	void (*resume)(struct irq_chip_generic___37 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___37 *domain;
	struct list_head list;
	struct irq_chip_type___37 chip_types[0];
};

struct seq_operations___172 {
	void * (*start)(struct seq_file___172 *, loff_t *);
	void (*stop)(struct seq_file___172 *, void *);
	void * (*next)(struct seq_file___172 *, void *, loff_t *);
	int (*show)(struct seq_file___172 *, void *);
};

struct dev_pagemap_ops___191 {
	void (*page_free)(struct page___201 *);
	void (*kill)(struct dev_pagemap___191 *);
	void (*cleanup)(struct dev_pagemap___191 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___191 *);
};

struct cgroup_namespace___135 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___135 *root_cset;
};

struct cftype___135;

struct cgroup_subsys___135 {
	struct cgroup_subsys_state___135 * (*css_alloc)(struct cgroup_subsys_state___135 *);
	int (*css_online)(struct cgroup_subsys_state___135 *);
	void (*css_offline)(struct cgroup_subsys_state___135 *);
	void (*css_released)(struct cgroup_subsys_state___135 *);
	void (*css_free)(struct cgroup_subsys_state___135 *);
	void (*css_reset)(struct cgroup_subsys_state___135 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___135 *, int);
	int (*css_extra_stat_show)(struct seq_file___172 *, struct cgroup_subsys_state___135 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___203 *, struct css_set___135 *);
	void (*cancel_fork)(struct task_struct___203 *, struct css_set___135 *);
	void (*fork)(struct task_struct___203 *);
	void (*exit)(struct task_struct___203 *);
	void (*release)(struct task_struct___203 *);
	void (*bind)(struct cgroup_subsys_state___135 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___135 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___135 *dfl_cftypes;
	struct cftype___135 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___135 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___135 *updated_children;
	struct cgroup___135 *updated_next;
};

struct cgroup_root___135 {
	struct kernfs_root___184 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___135 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___135 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___135 *ss;
	struct list_head node;
	struct kernfs_ops___184 *kf_ops;
	int (*open)(struct kernfs_open_file___184 *);
	void (*release)(struct kernfs_open_file___184 *);
	u64 (*read_u64)(struct cgroup_subsys_state___135 *, struct cftype___135 *);
	s64 (*read_s64)(struct cgroup_subsys_state___135 *, struct cftype___135 *);
	int (*seq_show)(struct seq_file___172 *, void *);
	void * (*seq_start)(struct seq_file___172 *, loff_t *);
	void * (*seq_next)(struct seq_file___172 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___172 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___135 *, struct cftype___135 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___135 *, struct cftype___135 *, s64);
	ssize_t (*write)(struct kernfs_open_file___184 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___184 *, struct poll_table_struct___128 *);
};

struct block_device_operations___100;

struct gendisk___101 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___101 *part0;
	const struct block_device_operations___100 *fops;
	struct request_queue___100 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___93 *bdi;
	struct kobject___184 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___184 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___100 {
	struct bio___100 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___116 *bip_vec;
	struct bio_vec___116 bip_inline_vecs[0];
};

struct blkcg___95;

struct blkg_policy_data___95;

struct blkcg_gq___95 {
	struct request_queue___100 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___95 *blkcg;
	struct blkcg_gq___95 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___95 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___100 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___100(struct request___100 *);

typedef void integrity_complete_fn___100(struct request___100 *, unsigned int);

struct blk_integrity_profile___100 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___100 *prepare_fn;
	integrity_complete_fn___100 *complete_fn;
	const char *name;
};

struct block_device_operations___100 {
	blk_qc_t (*submit_bio)(struct bio___100 *);
	int (*open)(struct block_device___101 *, fmode_t);
	void (*release)(struct gendisk___101 *, fmode_t);
	int (*rw_page)(struct block_device___101 *, sector_t, struct page___201 *, unsigned int);
	int (*ioctl)(struct block_device___101 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___101 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___101 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___101 *);
	int (*getgeo)(struct block_device___101 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___101 *, bool);
	void (*swap_slot_free_notify)(struct block_device___101 *, long unsigned int);
	int (*report_zones)(struct gendisk___101 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___101 *, umode_t *);
	struct module___180 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___101 *, sector_t *);
};

typedef void rq_end_io_fn___100(struct request___100 *, blk_status_t);

struct request___100 {
	struct request_queue___100 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___97 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___100 *bio;
	struct bio___100 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___116 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___100 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___100 *saved_end_io;
		} flush;
	};
	struct gendisk___101 *rq_disk;
	struct block_device___101 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___100 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___97 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___100 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___184 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___196 *debugfs_dir;
	struct dentry___196 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___100;

struct elevator_mq_ops___100 {
	int (*init_sched)(struct request_queue___100 *, struct elevator_type___100 *);
	void (*exit_sched)(struct elevator_queue___100 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___97 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___97 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___97 *);
	bool (*allow_merge)(struct request_queue___100 *, struct request___100 *, struct bio___100 *);
	bool (*bio_merge)(struct request_queue___100 *, struct bio___100 *, unsigned int);
	int (*request_merge)(struct request_queue___100 *, struct request___100 **, struct bio___100 *);
	void (*request_merged)(struct request_queue___100 *, struct request___100 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___100 *, struct request___100 *, struct request___100 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___100 *);
	void (*finish_request)(struct request___100 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___97 *, struct list_head *, bool);
	struct request___100 * (*dispatch_request)(struct blk_mq_hw_ctx___97 *);
	bool (*has_work)(struct blk_mq_hw_ctx___97 *);
	void (*completed_request)(struct request___100 *, u64);
	void (*requeue_request)(struct request___100 *);
	struct request___100 * (*former_request)(struct request_queue___100 *, struct request___100 *);
	struct request___100 * (*next_request)(struct request_queue___100 *, struct request___100 *);
	void (*init_icq)(struct io_cq___100 *);
	void (*exit_icq)(struct io_cq___100 *);
};

struct elv_fs_entry___100;

struct elevator_type___100 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___100 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___100 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___180 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___100 {
	struct elevator_type___100 *type;
	void *elevator_data;
	struct kobject___184 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___100 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___100 *, char *);
	ssize_t (*store)(struct elevator_queue___100 *, const char *, size_t);
};

struct blk_mq_queue_data___97;

struct blk_mq_ops___97 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___97 *, const struct blk_mq_queue_data___97 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___97 *);
	int (*get_budget)(struct request_queue___100 *);
	void (*put_budget)(struct request_queue___100 *, int);
	void (*set_rq_budget_token)(struct request___100 *, int);
	int (*get_rq_budget_token)(struct request___100 *);
	enum blk_eh_timer_return (*timeout)(struct request___100 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___97 *);
	void (*complete)(struct request___100 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___97 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___97 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___97 *, struct request___100 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___97 *, struct request___100 *, unsigned int);
	void (*initialize_rq_fn)(struct request___100 *);
	void (*cleanup_rq)(struct request___100 *);
	bool (*busy)(struct request_queue___100 *);
	int (*map_queues)(struct blk_mq_tag_set___97 *);
	void (*show_rq)(struct seq_file___172 *, struct request___100 *);
};

struct blk_mq_tag_set___97 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___97 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___97 {
	struct request___100 *rq;
	bool last;
};

struct blkcg_policy_data___95;

struct blkcg___95 {
	struct cgroup_subsys_state___135 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___95 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___95 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___95 {
	struct blkcg___95 *blkcg;
	int plid;
};

struct blkg_policy_data___95 {
	struct blkcg_gq___95 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___84 {
	struct mem_cgroup___84 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___84 {
	struct lruvec___91 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___84 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___84 *memcg;
};

struct obj_cgroup___84 {
	struct percpu_ref refcnt;
	struct mem_cgroup___84 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct apd_private_data;

struct apd_device_desc {
	unsigned int fixed_clk_rate;
	struct property_entry *properties;
	int (*setup)(struct apd_private_data *);
};

struct apd_private_data {
	struct clk *clk;
	struct acpi_device___9 *adev;
	const struct apd_device_desc *dev_desc;
};

struct amba_device___2 {
	struct device___156 dev;
	struct resource res;
	struct clk *pclk;
	struct device_dma_parameters dma_parms;
	unsigned int periphid;
	unsigned int cid;
	struct amba_cs_uci_id uci;
	unsigned int irq[9];
	char *driver_override;
};

struct acpi_power_dependent_device {
	struct device___155 *dev;
	struct list_head node;
};

struct acpi_power_resource {
	struct acpi_device___8 device;
	struct list_head list_node;
	u32 system_level;
	u32 order;
	unsigned int ref_count;
	u8 state;
	struct mutex resource_lock;
	struct list_head dependents;
};

struct acpi_power_resource_entry {
	struct list_head node;
	struct acpi_power_resource *resource;
};

struct acpi_device___10;

struct acpi_hotplug_profile___10 {
	struct kobject___26 kobj;
	int (*scan_dependent)(struct acpi_device___10 *);
	void (*notify_online)(struct acpi_device___10 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___10 {
	void (*func)(struct acpi_device_wakeup_context___10 *);
	struct device___24 *dev;
};

struct acpi_device_wakeup___10 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___10 context;
	struct wakeup_source___24 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___10;

struct acpi_hotplug_context___10;

struct acpi_driver___10;

struct acpi_device___10 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___24 fwnode;
	struct acpi_device___10 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___10 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___10 *handler;
	struct acpi_hotplug_context___10 *hp;
	struct acpi_driver___10 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___24 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___10 *);
};

struct acpi_scan_handler___10 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___10 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___10 *);
	void (*bind)(struct device___24 *);
	void (*unbind)(struct device___24 *);
	struct acpi_hotplug_profile___10 hotplug;
};

struct acpi_hotplug_context___10 {
	struct acpi_device___10 *self;
	int (*notify)(struct acpi_device___10 *, u32);
	void (*uevent)(struct acpi_device___10 *, u32);
	void (*fixup)(struct acpi_device___10 *);
};

typedef int (*acpi_op_add___10)(struct acpi_device___10 *);

typedef int (*acpi_op_remove___10)(struct acpi_device___10 *);

typedef void (*acpi_op_notify___10)(struct acpi_device___10 *, u32);

struct acpi_device_ops___10 {
	acpi_op_add___10 add;
	acpi_op_remove___10 remove;
	acpi_op_notify___10 notify;
};

struct acpi_driver___10 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___10 ops;
	struct device_driver___24 drv;
	struct module___28 *owner;
};

struct acpi_bus_event {
	struct list_head node;
	acpi_device_class device_class;
	acpi_bus_id bus_id;
	u32 type;
	u32 data;
};

struct genl_ops___2;

struct genl_small_ops___2;

struct genl_family___2 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___2 *, struct sk_buff___5 *, struct genl_info *);
	void (*post_doit)(const struct genl_ops___2 *, struct sk_buff___5 *, struct genl_info *);
	const struct genl_ops___2 *ops;
	const struct genl_small_ops___2 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___28 *module;
};

struct genl_ops___2 {
	int (*doit)(struct sk_buff___5 *, struct genl_info *);
	int (*start)(struct netlink_callback___3 *);
	int (*dumpit)(struct sk_buff___5 *, struct netlink_callback___3 *);
	int (*done)(struct netlink_callback___3 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_small_ops___2 {
	int (*doit)(struct sk_buff___5 *, struct genl_info *);
	int (*dumpit)(struct sk_buff___5 *, struct netlink_callback___3 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct acpi_genl_event {
	acpi_device_class device_class;
	char bus_id[15];
	u32 type;
	u32 data;
};

enum {
	ACPI_GENL_ATTR_UNSPEC = 0,
	ACPI_GENL_ATTR_EVENT = 1,
	__ACPI_GENL_ATTR_MAX = 2,
};

enum {
	ACPI_GENL_CMD_UNSPEC = 0,
	ACPI_GENL_CMD_EVENT = 1,
	__ACPI_GENL_CMD_MAX = 2,
};

struct acpi_ged_device {
	struct device___155 *dev;
	struct list_head event_list;
};

struct acpi_ged_event {
	struct list_head node;
	struct device___155 *dev;
	unsigned int gsi;
	unsigned int irq;
	acpi_handle handle;
};

struct kobj_attribute___10 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___183 *, struct kobj_attribute___10 *, char *);
	ssize_t (*store)(struct kobject___183 *, struct kobj_attribute___10 *, const char *, size_t);
};

typedef void (*acpi_gbl_event_handler)(u32, acpi_handle, u32, void *);

struct acpi_table_bert {
	struct acpi_table_header header;
	u32 region_length;
	u64 address;
};

struct acpi_table_attr {
	struct bin_attribute___183 attr;
	char name[4];
	int instance;
	char filename[8];
	struct list_head node;
};

struct acpi_data_attr {
	struct bin_attribute___183 attr;
	u64 addr;
};

struct acpi_data_obj {
	char *name;
	int (*fn)(void *, struct acpi_data_attr *);
};

struct event_counter {
	u32 count;
	u32 flags;
};

struct acpi_device_properties {
	const guid_t *guid;
	const union acpi_object *properties;
	struct list_head list;
};

struct acpi_data_node___2 {
	const char *name;
	acpi_handle handle;
	struct fwnode_handle___155 fwnode;
	struct fwnode_handle___155 *parent;
	struct acpi_device_data data;
	struct list_head sibling;
	struct kobject___183 kobj;
	struct completion kobj_done;
};

struct acpi_object_list___2 {
	u32 count;
	union acpi_object *pointer;
};

struct acpi_buffer___2 {
	acpi_size length;
	void *pointer;
};

struct acpi_lpat {
	int temp;
	int raw;
};

struct acpi_lpat_conversion_table {
	struct acpi_lpat *lpat;
	int lpat_count;
};

struct acpi_irq_parse_one_ctx {
	int rc;
	unsigned int index;
	long unsigned int *res_flags;
	struct irq_fwspec___35 *fwspec;
};

struct acpi_table_wdat {
	struct acpi_table_header header;
	u32 header_length;
	u16 pci_segment;
	u8 pci_bus;
	u8 pci_device;
	u8 pci_function;
	u8 reserved[3];
	u32 timer_period;
	u32 max_count;
	u32 min_count;
	u8 flags;
	u8 reserved2[3];
	u32 entries;
};

struct acpi_wdat_entry {
	u8 action;
	u8 instruction;
	u16 reserved;
	struct acpi_generic_address register_region;
	u32 value;
	u32 mask;
} __attribute__((packed));

struct acpi_name_info {
	char name[4];
	u16 argument_list;
	u8 expected_btypes;
} __attribute__((packed));

struct acpi_package_info {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 object_type2;
	u8 count2;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info2 {
	u8 type;
	u8 count;
	u8 object_type[4];
	u8 reserved;
};

struct acpi_package_info3 {
	u8 type;
	u8 count;
	u8 object_type[2];
	u8 tail_object_type;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info4 {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 sub_object_types;
	u8 pkg_count;
	u16 reserved;
} __attribute__((packed));

union acpi_predefined_info {
	struct acpi_name_info info;
	struct acpi_package_info ret_info;
	struct acpi_package_info2 ret_info2;
	struct acpi_package_info3 ret_info3;
	struct acpi_package_info4 ret_info4;
};

struct acpi_evaluate_info {
	struct acpi_namespace_node *prefix_node;
	const char *relative_pathname;
	union acpi_operand_object **parameters;
	struct acpi_namespace_node *node;
	union acpi_operand_object *obj_desc;
	char *full_pathname;
	const union acpi_predefined_info *predefined;
	union acpi_operand_object *return_object;
	union acpi_operand_object *parent_package;
	u32 return_flags;
	u32 return_btype;
	u16 param_count;
	u16 node_flags;
	u8 pass_number;
	u8 return_object_type;
	u8 flags;
};

enum {
	ACPI_REFCLASS_LOCAL = 0,
	ACPI_REFCLASS_ARG = 1,
	ACPI_REFCLASS_REFOF = 2,
	ACPI_REFCLASS_INDEX = 3,
	ACPI_REFCLASS_TABLE = 4,
	ACPI_REFCLASS_NAME = 5,
	ACPI_REFCLASS_DEBUG = 6,
	ACPI_REFCLASS_MAX = 6,
};

struct acpi_common_descriptor {
	void *common_pointer;
	u8 descriptor_type;
};

union acpi_descriptor {
	struct acpi_common_descriptor common;
	union acpi_operand_object object;
	struct acpi_namespace_node node;
	union acpi_parse_object op;
};

typedef enum {
	ACPI_IMODE_LOAD_PASS1 = 1,
	ACPI_IMODE_LOAD_PASS2 = 2,
	ACPI_IMODE_EXECUTE = 3,
} acpi_interpreter_mode;

struct acpi_create_field_info {
	struct acpi_namespace_node *region_node;
	struct acpi_namespace_node *field_node;
	struct acpi_namespace_node *register_node;
	struct acpi_namespace_node *data_register_node;
	struct acpi_namespace_node *connection_node;
	u8 *resource_buffer;
	u32 bank_value;
	u32 field_bit_position;
	u32 field_bit_length;
	u16 resource_length;
	u16 pin_number_index;
	u8 field_flags;
	u8 attribute;
	u8 field_type;
	u8 access_length;
};

struct acpi_init_walk_info {
	u32 table_index;
	u32 object_count;
	u32 method_count;
	u32 serial_method_count;
	u32 non_serial_method_count;
	u32 serialized_method_count;
	u32 device_count;
	u32 op_region_count;
	u32 field_count;
	u32 buffer_count;
	u32 package_count;
	u32 op_region_init;
	u32 field_init;
	u32 buffer_init;
	u32 package_init;
	acpi_owner_id owner_id;
};

typedef u32 acpi_name;

typedef acpi_status (*acpi_exception_handler)(acpi_status, acpi_name, u16, u32, void *);

enum {
	AML_FIELD_ACCESS_ANY = 0,
	AML_FIELD_ACCESS_BYTE = 1,
	AML_FIELD_ACCESS_WORD = 2,
	AML_FIELD_ACCESS_DWORD = 3,
	AML_FIELD_ACCESS_QWORD = 4,
	AML_FIELD_ACCESS_BUFFER = 5,
};

typedef acpi_status (*acpi_execute_op)(struct acpi_walk_state *);

typedef u32 acpi_mutex_handle;

struct acpi_reg_walk_info {
	u32 function;
	u32 reg_run_count;
	acpi_adr_space_type space_id;
};

enum {
	AML_FIELD_UPDATE_PRESERVE = 0,
	AML_FIELD_UPDATE_WRITE_AS_ONES = 32,
	AML_FIELD_UPDATE_WRITE_AS_ZEROS = 64,
};

struct acpi_signal_fatal_info {
	u32 type;
	u32 code;
	u32 argument;
};

enum {
	MATCH_MTR = 0,
	MATCH_MEQ = 1,
	MATCH_MLE = 2,
	MATCH_MLT = 3,
	MATCH_MGE = 4,
	MATCH_MGT = 5,
};

enum {
	AML_FIELD_ATTRIB_QUICK = 2,
	AML_FIELD_ATTRIB_SEND_RECEIVE = 4,
	AML_FIELD_ATTRIB_BYTE = 6,
	AML_FIELD_ATTRIB_WORD = 8,
	AML_FIELD_ATTRIB_BLOCK = 10,
	AML_FIELD_ATTRIB_BYTES = 11,
	AML_FIELD_ATTRIB_PROCESS_CALL = 12,
	AML_FIELD_ATTRIB_BLOCK_PROCESS_CALL = 13,
	AML_FIELD_ATTRIB_RAW_BYTES = 14,
	AML_FIELD_ATTRIB_RAW_PROCESS_BYTES = 15,
};

typedef enum {
	ACPI_TRACE_AML_METHOD = 0,
	ACPI_TRACE_AML_OPCODE = 1,
	ACPI_TRACE_AML_REGION = 2,
} acpi_trace_event_type;

struct acpi_port_info {
	char *name;
	u16 start;
	u16 end;
	u8 osi_dependency;
};

struct acpi_pci_device {
	acpi_handle device;
	struct acpi_pci_device *next;
};

typedef acpi_status (*acpi_init_handler)(acpi_handle, u32);

struct acpi_device_walk_info {
	struct acpi_table_desc *table_desc;
	struct acpi_evaluate_info *evaluate_info;
	u32 device_count;
	u32 num_STA;
	u32 num_INI;
};

typedef acpi_status (*acpi_pkg_callback)(u8, union acpi_operand_object *, union acpi_generic_state *, void *);

struct acpi_table_list {
	struct acpi_table_desc *tables;
	u32 current_table_count;
	u32 max_table_count;
	u8 flags;
};

enum acpi_return_package_types {
	ACPI_PTYPE1_FIXED = 1,
	ACPI_PTYPE1_VAR = 2,
	ACPI_PTYPE1_OPTION = 3,
	ACPI_PTYPE2 = 4,
	ACPI_PTYPE2_COUNT = 5,
	ACPI_PTYPE2_PKG_COUNT = 6,
	ACPI_PTYPE2_FIXED = 7,
	ACPI_PTYPE2_MIN = 8,
	ACPI_PTYPE2_REV_FIXED = 9,
	ACPI_PTYPE2_FIX_VAR = 10,
	ACPI_PTYPE2_VAR_VAR = 11,
	ACPI_PTYPE2_UUID_PAIR = 12,
	ACPI_PTYPE_CUSTOM = 13,
};

typedef acpi_status (*acpi_object_converter)(struct acpi_namespace_node *, union acpi_operand_object *, union acpi_operand_object **);

struct acpi_simple_repair_info {
	char name[4];
	u32 unexpected_btypes;
	u32 package_index;
	acpi_object_converter object_converter;
};

typedef acpi_status (*acpi_repair_function)(struct acpi_evaluate_info *, union acpi_operand_object **);

struct acpi_repair_info {
	char name[4];
	acpi_repair_function repair_function;
};

struct acpi_namestring_info {
	const char *external_name;
	const char *next_external_char;
	char *internal_name;
	u32 length;
	u32 num_segments;
	u32 num_carats;
	u8 fully_qualified;
};

struct acpi_rw_lock {
	void *writer_mutex;
	void *reader_mutex;
	u32 num_readers;
};

struct acpi_get_devices_info {
	acpi_walk_callback user_function;
	void *context;
	const char *hid;
};

struct aml_resource_small_header {
	u8 descriptor_type;
};

struct aml_resource_irq {
	u8 descriptor_type;
	u16 irq_mask;
	u8 flags;
} __attribute__((packed));

struct aml_resource_dma {
	u8 descriptor_type;
	u8 dma_channel_mask;
	u8 flags;
};

struct aml_resource_start_dependent {
	u8 descriptor_type;
	u8 flags;
};

struct aml_resource_end_dependent {
	u8 descriptor_type;
};

struct aml_resource_io {
	u8 descriptor_type;
	u8 flags;
	u16 minimum;
	u16 maximum;
	u8 alignment;
	u8 address_length;
};

struct aml_resource_fixed_io {
	u8 descriptor_type;
	u16 address;
	u8 address_length;
} __attribute__((packed));

struct aml_resource_vendor_small {
	u8 descriptor_type;
};

struct aml_resource_end_tag {
	u8 descriptor_type;
	u8 checksum;
};

struct aml_resource_fixed_dma {
	u8 descriptor_type;
	u16 request_lines;
	u16 channels;
	u8 width;
} __attribute__((packed));

struct aml_resource_large_header {
	u8 descriptor_type;
	u16 resource_length;
} __attribute__((packed));

struct aml_resource_memory24 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u16 minimum;
	u16 maximum;
	u16 alignment;
	u16 address_length;
} __attribute__((packed));

struct aml_resource_vendor_large {
	u8 descriptor_type;
	u16 resource_length;
} __attribute__((packed));

struct aml_resource_memory32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u32 minimum;
	u32 maximum;
	u32 alignment;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_fixed_memory32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u32 address;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_address {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
} __attribute__((packed));

struct aml_resource_extended_address64 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u8 revision_ID;
	u8 reserved;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
	u64 type_specific;
} __attribute__((packed));

struct aml_resource_address64 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u64 granularity;
	u64 minimum;
	u64 maximum;
	u64 translation_offset;
	u64 address_length;
} __attribute__((packed));

struct aml_resource_address32 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u32 granularity;
	u32 minimum;
	u32 maximum;
	u32 translation_offset;
	u32 address_length;
} __attribute__((packed));

struct aml_resource_address16 {
	u8 descriptor_type;
	u16 resource_length;
	u8 resource_type;
	u8 flags;
	u8 specific_flags;
	u16 granularity;
	u16 minimum;
	u16 maximum;
	u16 translation_offset;
	u16 address_length;
} __attribute__((packed));

struct aml_resource_extended_irq {
	u8 descriptor_type;
	u16 resource_length;
	u8 flags;
	u8 interrupt_count;
	u32 interrupts[1];
} __attribute__((packed));

struct aml_resource_generic_register {
	u8 descriptor_type;
	u16 resource_length;
	u8 address_space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct aml_resource_gpio {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 connection_type;
	u16 flags;
	u16 int_flags;
	u8 pin_config;
	u16 drive_strength;
	u16 debounce_timeout;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_common_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
} __attribute__((packed));

struct aml_resource_csi2_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
} __attribute__((packed));

struct aml_resource_i2c_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 connection_speed;
	u16 slave_address;
} __attribute__((packed));

struct aml_resource_spi_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 connection_speed;
	u8 data_bit_length;
	u8 clock_phase;
	u8 clock_polarity;
	u16 device_selection;
} __attribute__((packed));

struct aml_resource_uart_serialbus {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u8 res_source_index;
	u8 type;
	u8 flags;
	u16 type_specific_flags;
	u8 type_revision_id;
	u16 type_data_length;
	u32 default_baud_rate;
	u16 rx_fifo_size;
	u16 tx_fifo_size;
	u8 parity;
	u8 lines_enabled;
} __attribute__((packed));

struct aml_resource_pin_function {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u8 pin_config;
	u16 function_number;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_config {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u8 pin_config_type;
	u32 pin_config_value;
	u16 pin_table_offset;
	u8 res_source_index;
	u16 res_source_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_group {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u16 pin_table_offset;
	u16 label_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_group_function {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u16 function_number;
	u8 res_source_index;
	u16 res_source_offset;
	u16 res_source_label_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

struct aml_resource_pin_group_config {
	u8 descriptor_type;
	u16 resource_length;
	u8 revision_id;
	u16 flags;
	u8 pin_config_type;
	u32 pin_config_value;
	u8 res_source_index;
	u16 res_source_offset;
	u16 res_source_label_offset;
	u16 vendor_offset;
	u16 vendor_length;
} __attribute__((packed));

union aml_resource {
	u8 descriptor_type;
	struct aml_resource_small_header small_header;
	struct aml_resource_large_header large_header;
	struct aml_resource_irq irq;
	struct aml_resource_dma dma;
	struct aml_resource_start_dependent start_dpf;
	struct aml_resource_end_dependent end_dpf;
	struct aml_resource_io io;
	struct aml_resource_fixed_io fixed_io;
	struct aml_resource_fixed_dma fixed_dma;
	struct aml_resource_vendor_small vendor_small;
	struct aml_resource_end_tag end_tag;
	struct aml_resource_memory24 memory24;
	struct aml_resource_generic_register generic_reg;
	struct aml_resource_vendor_large vendor_large;
	struct aml_resource_memory32 memory32;
	struct aml_resource_fixed_memory32 fixed_memory32;
	struct aml_resource_address16 address16;
	struct aml_resource_address32 address32;
	struct aml_resource_address64 address64;
	struct aml_resource_extended_address64 ext_address64;
	struct aml_resource_extended_irq extended_irq;
	struct aml_resource_gpio gpio;
	struct aml_resource_i2c_serialbus i2c_serial_bus;
	struct aml_resource_spi_serialbus spi_serial_bus;
	struct aml_resource_uart_serialbus uart_serial_bus;
	struct aml_resource_csi2_serialbus csi2_serial_bus;
	struct aml_resource_common_serialbus common_serial_bus;
	struct aml_resource_pin_function pin_function;
	struct aml_resource_pin_config pin_config;
	struct aml_resource_pin_group pin_group;
	struct aml_resource_pin_group_function pin_group_function;
	struct aml_resource_pin_group_config pin_group_config;
	struct aml_resource_address address;
	u32 dword_item;
	u16 word_item;
	u8 byte_item;
};

struct acpi_rsconvert_info {
	u8 opcode;
	u8 resource_offset;
	u8 aml_offset;
	u8 value;
};

enum {
	ACPI_RSC_INITGET = 0,
	ACPI_RSC_INITSET = 1,
	ACPI_RSC_FLAGINIT = 2,
	ACPI_RSC_1BITFLAG = 3,
	ACPI_RSC_2BITFLAG = 4,
	ACPI_RSC_3BITFLAG = 5,
	ACPI_RSC_6BITFLAG = 6,
	ACPI_RSC_ADDRESS = 7,
	ACPI_RSC_BITMASK = 8,
	ACPI_RSC_BITMASK16 = 9,
	ACPI_RSC_COUNT = 10,
	ACPI_RSC_COUNT16 = 11,
	ACPI_RSC_COUNT_GPIO_PIN = 12,
	ACPI_RSC_COUNT_GPIO_RES = 13,
	ACPI_RSC_COUNT_GPIO_VEN = 14,
	ACPI_RSC_COUNT_SERIAL_RES = 15,
	ACPI_RSC_COUNT_SERIAL_VEN = 16,
	ACPI_RSC_DATA8 = 17,
	ACPI_RSC_EXIT_EQ = 18,
	ACPI_RSC_EXIT_LE = 19,
	ACPI_RSC_EXIT_NE = 20,
	ACPI_RSC_LENGTH = 21,
	ACPI_RSC_MOVE_GPIO_PIN = 22,
	ACPI_RSC_MOVE_GPIO_RES = 23,
	ACPI_RSC_MOVE_SERIAL_RES = 24,
	ACPI_RSC_MOVE_SERIAL_VEN = 25,
	ACPI_RSC_MOVE8 = 26,
	ACPI_RSC_MOVE16 = 27,
	ACPI_RSC_MOVE32 = 28,
	ACPI_RSC_MOVE64 = 29,
	ACPI_RSC_SET8 = 30,
	ACPI_RSC_SOURCE = 31,
	ACPI_RSC_SOURCEX = 32,
};

typedef u16 acpi_rs_length;

typedef acpi_status (*acpi_walk_aml_callback)(u8 *, u32, u32, u8, void **);

typedef u32 acpi_rsdesc_size;

struct acpi_vendor_uuid {
	u8 subtype;
	u8 data[16];
};

struct acpi_vendor_walk_info {
	struct acpi_vendor_uuid *uuid;
	struct acpi_buffer *buffer;
	acpi_status status;
};

struct acpi_fadt_info {
	const char *name;
	u16 address64;
	u16 address32;
	u16 length;
	u8 default_length;
	u8 flags;
};

struct acpi_fadt_pm_info {
	struct acpi_generic_address *target;
	u16 source;
	u8 register_num;
};

struct acpi_table_header___2 {
	char signature[4];
	u32 length;
	u8 revision;
	u8 checksum;
	char oem_id[6];
	char oem_table_id[8];
	u32 oem_revision;
	char asl_compiler_id[4];
	u32 asl_compiler_revision;
};

struct acpi_table_rsdp {
	char signature[8];
	u8 checksum;
	char oem_id[6];
	u8 revision;
	u32 rsdt_physical_address;
	u32 length;
	u64 xsdt_physical_address;
	u8 extended_checksum;
	u8 reserved[3];
};

struct acpi_table_rsdp___2 {
	char signature[8];
	u8 checksum;
	char oem_id[6];
	u8 revision;
	u32 rsdt_physical_address;
	u32 length;
	u64 xsdt_physical_address;
	u8 extended_checksum;
	u8 reserved[3];
} __attribute__((packed));

struct acpi_address_range {
	struct acpi_address_range *next;
	struct acpi_namespace_node *region_node;
	acpi_physical_address start_address;
	acpi_physical_address end_address;
};

struct acpi_pkg_info {
	u8 *free_space;
	acpi_size length;
	u32 object_space;
	u32 num_packages;
};

struct acpi_exception_info {
	char *name;
};

typedef u32 (*acpi_sci_handler)(void *);

struct acpi_mutex_info {
	void *mutex;
	u32 use_count;
	u64 thread_id;
};

struct acpi_sci_handler_info {
	struct acpi_sci_handler_info *next;
	acpi_sci_handler address;
	void *context;
};

struct acpi_comment_node {
	char *comment;
	struct acpi_comment_node *next;
};

struct acpi_interface_info {
	char *name;
	struct acpi_interface_info *next;
	u8 flags;
	u8 value;
};

struct acpi_name_info___2 {
	char name[4];
	u16 argument_list;
	u8 expected_btypes;
};

struct acpi_package_info___2 {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 object_type2;
	u8 count2;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info2___2 {
	u8 type;
	u8 count;
	u8 object_type[4];
	u8 reserved;
};

struct acpi_package_info3___2 {
	u8 type;
	u8 count;
	u8 object_type[2];
	u8 tail_object_type;
	u16 reserved;
} __attribute__((packed));

struct acpi_package_info4___2 {
	u8 type;
	u8 object_type1;
	u8 count1;
	u8 sub_object_types;
	u8 pkg_count;
	u16 reserved;
} __attribute__((packed));

union acpi_predefined_info___2 {
	struct acpi_name_info___2 info;
	struct acpi_package_info___2 ret_info;
	struct acpi_package_info2___2 ret_info2;
	struct acpi_package_info3___2 ret_info3;
	struct acpi_package_info4___2 ret_info4;
};

struct acpi_table_mcfg {
	struct acpi_table_header header;
	u8 reserved[8];
};

struct acpi_mcfg_allocation {
	u64 address;
	u16 pci_segment;
	u8 start_bus_number;
	u8 end_bus_number;
	u32 reserved;
};

struct mcfg_entry {
	struct list_head list;
	phys_addr_t addr;
	u16 segment;
	u8 bus_start;
	u8 bus_end;
};

struct mcfg_fixup {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
	u16 segment;
	struct resource bus_range;
	const struct pci_ecam_ops___3 *ops;
	struct resource cfgres;
};

enum led_brightness {
	LED_OFF = 0,
	LED_ON = 1,
	LED_HALF = 127,
	LED_FULL = 255,
};

struct led_hw_trigger_type {
	int dummy;
};

struct led_pattern;

struct led_trigger;

struct led_classdev {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev *);
	int (*blink_set)(struct led_classdev *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev *);
	struct device___155 *dev;
	const struct attribute_group___183 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___183 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_pattern {
	u32 delta_t;
	int brightness;
};

struct led_trigger {
	const char *name;
	int (*activate)(struct led_classdev *);
	void (*deactivate)(struct led_classdev *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___183 **groups;
};

enum power_supply_property {
	POWER_SUPPLY_PROP_STATUS = 0,
	POWER_SUPPLY_PROP_CHARGE_TYPE = 1,
	POWER_SUPPLY_PROP_HEALTH = 2,
	POWER_SUPPLY_PROP_PRESENT = 3,
	POWER_SUPPLY_PROP_ONLINE = 4,
	POWER_SUPPLY_PROP_AUTHENTIC = 5,
	POWER_SUPPLY_PROP_TECHNOLOGY = 6,
	POWER_SUPPLY_PROP_CYCLE_COUNT = 7,
	POWER_SUPPLY_PROP_VOLTAGE_MAX = 8,
	POWER_SUPPLY_PROP_VOLTAGE_MIN = 9,
	POWER_SUPPLY_PROP_VOLTAGE_MAX_DESIGN = 10,
	POWER_SUPPLY_PROP_VOLTAGE_MIN_DESIGN = 11,
	POWER_SUPPLY_PROP_VOLTAGE_NOW = 12,
	POWER_SUPPLY_PROP_VOLTAGE_AVG = 13,
	POWER_SUPPLY_PROP_VOLTAGE_OCV = 14,
	POWER_SUPPLY_PROP_VOLTAGE_BOOT = 15,
	POWER_SUPPLY_PROP_CURRENT_MAX = 16,
	POWER_SUPPLY_PROP_CURRENT_NOW = 17,
	POWER_SUPPLY_PROP_CURRENT_AVG = 18,
	POWER_SUPPLY_PROP_CURRENT_BOOT = 19,
	POWER_SUPPLY_PROP_POWER_NOW = 20,
	POWER_SUPPLY_PROP_POWER_AVG = 21,
	POWER_SUPPLY_PROP_CHARGE_FULL_DESIGN = 22,
	POWER_SUPPLY_PROP_CHARGE_EMPTY_DESIGN = 23,
	POWER_SUPPLY_PROP_CHARGE_FULL = 24,
	POWER_SUPPLY_PROP_CHARGE_EMPTY = 25,
	POWER_SUPPLY_PROP_CHARGE_NOW = 26,
	POWER_SUPPLY_PROP_CHARGE_AVG = 27,
	POWER_SUPPLY_PROP_CHARGE_COUNTER = 28,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_CURRENT = 29,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_CURRENT_MAX = 30,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_VOLTAGE = 31,
	POWER_SUPPLY_PROP_CONSTANT_CHARGE_VOLTAGE_MAX = 32,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_LIMIT = 33,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_LIMIT_MAX = 34,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_START_THRESHOLD = 35,
	POWER_SUPPLY_PROP_CHARGE_CONTROL_END_THRESHOLD = 36,
	POWER_SUPPLY_PROP_INPUT_CURRENT_LIMIT = 37,
	POWER_SUPPLY_PROP_INPUT_VOLTAGE_LIMIT = 38,
	POWER_SUPPLY_PROP_INPUT_POWER_LIMIT = 39,
	POWER_SUPPLY_PROP_ENERGY_FULL_DESIGN = 40,
	POWER_SUPPLY_PROP_ENERGY_EMPTY_DESIGN = 41,
	POWER_SUPPLY_PROP_ENERGY_FULL = 42,
	POWER_SUPPLY_PROP_ENERGY_EMPTY = 43,
	POWER_SUPPLY_PROP_ENERGY_NOW = 44,
	POWER_SUPPLY_PROP_ENERGY_AVG = 45,
	POWER_SUPPLY_PROP_CAPACITY = 46,
	POWER_SUPPLY_PROP_CAPACITY_ALERT_MIN = 47,
	POWER_SUPPLY_PROP_CAPACITY_ALERT_MAX = 48,
	POWER_SUPPLY_PROP_CAPACITY_ERROR_MARGIN = 49,
	POWER_SUPPLY_PROP_CAPACITY_LEVEL = 50,
	POWER_SUPPLY_PROP_TEMP = 51,
	POWER_SUPPLY_PROP_TEMP_MAX = 52,
	POWER_SUPPLY_PROP_TEMP_MIN = 53,
	POWER_SUPPLY_PROP_TEMP_ALERT_MIN = 54,
	POWER_SUPPLY_PROP_TEMP_ALERT_MAX = 55,
	POWER_SUPPLY_PROP_TEMP_AMBIENT = 56,
	POWER_SUPPLY_PROP_TEMP_AMBIENT_ALERT_MIN = 57,
	POWER_SUPPLY_PROP_TEMP_AMBIENT_ALERT_MAX = 58,
	POWER_SUPPLY_PROP_TIME_TO_EMPTY_NOW = 59,
	POWER_SUPPLY_PROP_TIME_TO_EMPTY_AVG = 60,
	POWER_SUPPLY_PROP_TIME_TO_FULL_NOW = 61,
	POWER_SUPPLY_PROP_TIME_TO_FULL_AVG = 62,
	POWER_SUPPLY_PROP_TYPE = 63,
	POWER_SUPPLY_PROP_USB_TYPE = 64,
	POWER_SUPPLY_PROP_SCOPE = 65,
	POWER_SUPPLY_PROP_PRECHARGE_CURRENT = 66,
	POWER_SUPPLY_PROP_CHARGE_TERM_CURRENT = 67,
	POWER_SUPPLY_PROP_CALIBRATE = 68,
	POWER_SUPPLY_PROP_MANUFACTURE_YEAR = 69,
	POWER_SUPPLY_PROP_MANUFACTURE_MONTH = 70,
	POWER_SUPPLY_PROP_MANUFACTURE_DAY = 71,
	POWER_SUPPLY_PROP_MODEL_NAME = 72,
	POWER_SUPPLY_PROP_MANUFACTURER = 73,
	POWER_SUPPLY_PROP_SERIAL_NUMBER = 74,
};

enum power_supply_type {
	POWER_SUPPLY_TYPE_UNKNOWN = 0,
	POWER_SUPPLY_TYPE_BATTERY = 1,
	POWER_SUPPLY_TYPE_UPS = 2,
	POWER_SUPPLY_TYPE_MAINS = 3,
	POWER_SUPPLY_TYPE_USB = 4,
	POWER_SUPPLY_TYPE_USB_DCP = 5,
	POWER_SUPPLY_TYPE_USB_CDP = 6,
	POWER_SUPPLY_TYPE_USB_ACA = 7,
	POWER_SUPPLY_TYPE_USB_TYPE_C = 8,
	POWER_SUPPLY_TYPE_USB_PD = 9,
	POWER_SUPPLY_TYPE_USB_PD_DRP = 10,
	POWER_SUPPLY_TYPE_APPLE_BRICK_ID = 11,
	POWER_SUPPLY_TYPE_WIRELESS = 12,
};

enum power_supply_usb_type {
	POWER_SUPPLY_USB_TYPE_UNKNOWN = 0,
	POWER_SUPPLY_USB_TYPE_SDP = 1,
	POWER_SUPPLY_USB_TYPE_DCP = 2,
	POWER_SUPPLY_USB_TYPE_CDP = 3,
	POWER_SUPPLY_USB_TYPE_ACA = 4,
	POWER_SUPPLY_USB_TYPE_C = 5,
	POWER_SUPPLY_USB_TYPE_PD = 6,
	POWER_SUPPLY_USB_TYPE_PD_DRP = 7,
	POWER_SUPPLY_USB_TYPE_PD_PPS = 8,
	POWER_SUPPLY_USB_TYPE_APPLE_BRICK_ID = 9,
};

union power_supply_propval {
	int intval;
	const char *strval;
};

struct power_supply_config {
	struct device_node___58 *of_node;
	struct fwnode_handle___155 *fwnode;
	void *drv_data;
	const struct attribute_group___183 **attr_grp;
	char **supplied_to;
	size_t num_supplicants;
};

struct power_supply;

struct power_supply_desc {
	const char *name;
	enum power_supply_type type;
	const enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	const enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply *);
	void (*set_charged)(struct power_supply *);
	bool no_thermal;
	int use_for_apm;
};

struct thermal_zone_device;

struct power_supply {
	const struct power_supply_desc *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___58 *of_node;
	void *drv_data;
	struct device___155 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device___3 *tcd;
	struct led_trigger *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger *charging_trig;
	char *charging_trig_name;
	struct led_trigger *full_trig;
	char *full_trig_name;
	struct led_trigger *online_trig;
	char *online_trig_name;
	struct led_trigger *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct acpi_ac_bl {
	const char *hid;
	int hrv;
};

struct acpi_ac {
	struct power_supply *charger;
	struct power_supply_desc charger_desc;
	struct acpi_device___8 *device;
	long long unsigned int state;
	struct notifier_block battery_nb;
};

struct input_id {
	__u16 bustype;
	__u16 vendor;
	__u16 product;
	__u16 version;
};

struct input_absinfo {
	__s32 value;
	__s32 minimum;
	__s32 maximum;
	__s32 fuzz;
	__s32 flat;
	__s32 resolution;
};

struct input_keymap_entry {
	__u8 flags;
	__u8 len;
	__u16 index;
	__u32 keycode;
	__u8 scancode[32];
};

struct ff_replay {
	__u16 length;
	__u16 delay;
};

struct ff_trigger {
	__u16 button;
	__u16 interval;
};

struct ff_envelope {
	__u16 attack_length;
	__u16 attack_level;
	__u16 fade_length;
	__u16 fade_level;
};

struct ff_constant_effect {
	__s16 level;
	struct ff_envelope envelope;
};

struct ff_ramp_effect {
	__s16 start_level;
	__s16 end_level;
	struct ff_envelope envelope;
};

struct ff_condition_effect {
	__u16 right_saturation;
	__u16 left_saturation;
	__s16 right_coeff;
	__s16 left_coeff;
	__u16 deadband;
	__s16 center;
};

struct ff_periodic_effect {
	__u16 waveform;
	__u16 period;
	__s16 magnitude;
	__s16 offset;
	__u16 phase;
	struct ff_envelope envelope;
	__u32 custom_len;
	__s16 *custom_data;
};

struct ff_rumble_effect {
	__u16 strong_magnitude;
	__u16 weak_magnitude;
};

struct ff_effect {
	__u16 type;
	__s16 id;
	__u16 direction;
	struct ff_trigger trigger;
	struct ff_replay replay;
	union {
		struct ff_constant_effect constant;
		struct ff_ramp_effect ramp;
		struct ff_periodic_effect periodic;
		struct ff_condition_effect condition[2];
		struct ff_rumble_effect rumble;
	} u;
};

struct input_device_id {
	kernel_ulong_t flags;
	__u16 bustype;
	__u16 vendor;
	__u16 product;
	__u16 version;
	kernel_ulong_t evbit[1];
	kernel_ulong_t keybit[12];
	kernel_ulong_t relbit[1];
	kernel_ulong_t absbit[1];
	kernel_ulong_t mscbit[1];
	kernel_ulong_t ledbit[1];
	kernel_ulong_t sndbit[1];
	kernel_ulong_t ffbit[2];
	kernel_ulong_t swbit[1];
	kernel_ulong_t propbit[1];
	kernel_ulong_t driver_info;
};

struct input_value {
	__u16 type;
	__u16 code;
	__s32 value;
};

enum input_clock_type {
	INPUT_CLK_REAL = 0,
	INPUT_CLK_MONO = 1,
	INPUT_CLK_BOOT = 2,
	INPUT_CLK_MAX = 3,
};

struct ff_device;

struct input_dev_poller;

struct input_mt;

struct input_handle;

struct input_dev {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev *, struct input_keymap_entry *);
	struct ff_device *ff;
	struct input_dev_poller *poller;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev *);
	void (*close)(struct input_dev *);
	int (*flush)(struct input_dev *, struct file___195 *);
	int (*event)(struct input_dev *, unsigned int, unsigned int, int);
	struct input_handle *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___155 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
	ktime_t timestamp[3];
	bool inhibited;
};

struct ff_device {
	int (*upload)(struct input_dev *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev *, int);
	int (*playback)(struct input_dev *, int, int);
	void (*set_gain)(struct input_dev *, u16);
	void (*set_autocenter)(struct input_dev *, u16);
	void (*destroy)(struct ff_device *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___195 *effect_owners[0];
};

struct input_handler;

struct input_handle {
	void *private;
	int open;
	const char *name;
	struct input_dev *dev;
	struct input_handler *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler {
	void *private;
	void (*event)(struct input_handle *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler *, struct input_dev *);
	int (*connect)(struct input_handler *, struct input_dev *, const struct input_device_id *);
	void (*disconnect)(struct input_handle *);
	void (*start)(struct input_handle *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

enum {
	ACPI_BUTTON_LID_INIT_IGNORE = 0,
	ACPI_BUTTON_LID_INIT_OPEN = 1,
	ACPI_BUTTON_LID_INIT_METHOD = 2,
	ACPI_BUTTON_LID_INIT_DISABLED = 3,
};

struct acpi_button {
	unsigned int type;
	struct input_dev *input;
	char phys[32];
	long unsigned int pushed;
	int last_state;
	ktime_t last_time;
	bool suspended;
	bool lid_state_initialized;
};

struct acpi_fan_fps {
	u64 control;
	u64 trip_point;
	u64 speed;
	u64 noise_level;
	u64 power;
	char name[20];
	struct device_attribute___14 dev_attr;
};

struct acpi_fan_fif {
	u64 revision;
	u64 fine_grain_ctrl;
	u64 step_size;
	u64 low_speed_notification;
};

struct acpi_fan {
	bool acpi4;
	struct acpi_fan_fif fif;
	struct acpi_fan_fps *fps;
	int fps_count;
	struct thermal_cooling_device *cdev;
};

struct acpi_pci_slot {
	struct pci_slot___8 *pci_slot;
	struct list_head list;
};

struct cpuidle_driver___4;

struct cpuidle_state___4 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___4 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___4 *, int);
};

struct cpuidle_driver___4 {
	const char *name;
	struct module___179 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___4 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct acpi_power_register {
	u8 descriptor;
	u16 length;
	u8 space_id;
	u8 bit_width;
	u8 bit_offset;
	u8 access_size;
	u64 address;
} __attribute__((packed));

struct acpi_lpi_states_array {
	unsigned int size;
	unsigned int composite_states_size;
	struct acpi_lpi_state *entries;
	struct acpi_lpi_state *composite_states[8];
};

struct container_dev {
	struct device___156 dev;
	int (*offline)(struct container_dev *);
};

enum thermal_device_mode {
	THERMAL_DEVICE_DISABLED = 0,
	THERMAL_DEVICE_ENABLED = 1,
};

enum thermal_trip_type {
	THERMAL_TRIP_ACTIVE = 0,
	THERMAL_TRIP_PASSIVE = 1,
	THERMAL_TRIP_HOT = 2,
	THERMAL_TRIP_CRITICAL = 3,
};

enum thermal_trend {
	THERMAL_TREND_STABLE = 0,
	THERMAL_TREND_RAISING = 1,
	THERMAL_TREND_DROPPING = 2,
	THERMAL_TREND_RAISE_FULL = 3,
	THERMAL_TREND_DROP_FULL = 4,
};

enum thermal_notify_event {
	THERMAL_EVENT_UNSPECIFIED = 0,
	THERMAL_EVENT_TEMP_SAMPLE = 1,
	THERMAL_TRIP_VIOLATED = 2,
	THERMAL_TRIP_CHANGED = 3,
	THERMAL_DEVICE_DOWN = 4,
	THERMAL_DEVICE_UP = 5,
	THERMAL_DEVICE_POWER_CAPABILITY_CHANGED = 6,
	THERMAL_TABLE_CHANGED = 7,
	THERMAL_EVENT_KEEP_ALIVE = 8,
};

struct thermal_zone_device___2;

struct thermal_zone_device_ops {
	int (*bind)(struct thermal_zone_device___2 *, struct thermal_cooling_device *);
	int (*unbind)(struct thermal_zone_device___2 *, struct thermal_cooling_device *);
	int (*get_temp)(struct thermal_zone_device___2 *, int *);
	int (*set_trips)(struct thermal_zone_device___2 *, int, int);
	int (*change_mode)(struct thermal_zone_device___2 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___2 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___2 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___2 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___2 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___2 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___2 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___2 *, int);
	int (*get_trend)(struct thermal_zone_device___2 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___2 *);
	void (*critical)(struct thermal_zone_device___2 *);
};

struct thermal_attr;

struct thermal_zone_params;

struct thermal_governor;

struct thermal_zone_device___2 {
	int id;
	char type[20];
	struct device___155 device;
	struct attribute_group___183 trips_attribute_group;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops *ops;
	struct thermal_zone_params *tzp;
	struct thermal_governor *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_bind_params;

struct thermal_zone_params {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___2 *);
	void (*unbind_from_tz)(struct thermal_zone_device___2 *);
	int (*throttle)(struct thermal_zone_device___2 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params {
	struct thermal_cooling_device *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___2 *, struct thermal_cooling_device *);
};

struct acpi_thermal_state {
	u8 critical: 1;
	u8 hot: 1;
	u8 passive: 1;
	u8 active: 1;
	u8 reserved: 4;
	int active_index;
};

struct acpi_thermal_state_flags {
	u8 valid: 1;
	u8 enabled: 1;
	u8 reserved: 6;
};

struct acpi_thermal_critical {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
};

struct acpi_thermal_hot {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
};

struct acpi_thermal_passive {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
	long unsigned int tc1;
	long unsigned int tc2;
	long unsigned int tsp;
	struct acpi_handle_list devices;
};

struct acpi_thermal_active {
	struct acpi_thermal_state_flags flags;
	long unsigned int temperature;
	struct acpi_handle_list devices;
};

struct acpi_thermal_trips {
	struct acpi_thermal_critical critical;
	struct acpi_thermal_hot hot;
	struct acpi_thermal_passive passive;
	struct acpi_thermal_active active[10];
};

struct acpi_thermal_flags {
	u8 cooling_mode: 1;
	u8 devices: 1;
	u8 reserved: 6;
};

struct acpi_thermal {
	struct acpi_device___8 *device;
	acpi_bus_id name;
	long unsigned int temperature;
	long unsigned int last_temperature;
	long unsigned int polling_frequency;
	volatile u8 zombie;
	struct acpi_thermal_flags flags;
	struct acpi_thermal_state state;
	struct acpi_thermal_trips trips;
	struct acpi_handle_list devices;
	struct thermal_zone_device___2 *thermal_zone;
	int kelvin_offset;
	struct work_struct thermal_check_work;
	struct mutex thermal_check_lock;
	refcount_t thermal_check_count;
};

struct acpi_table_slit {
	struct acpi_table_header header;
	u64 locality_count;
	u8 entry[1];
} __attribute__((packed));

struct acpi_table_srat {
	struct acpi_table_header header;
	u32 table_revision;
	u64 reserved;
};

struct acpi_srat_cpu_affinity {
	struct acpi_subtable_header header;
	u8 proximity_domain_lo;
	u8 apic_id;
	u32 flags;
	u8 local_sapic_eid;
	u8 proximity_domain_hi[3];
	u32 clock_domain;
};

struct acpi_srat_mem_affinity {
	struct acpi_subtable_header header;
	u32 proximity_domain;
	u16 reserved;
	u64 base_address;
	u64 length;
	u32 reserved1;
	u32 flags;
	u64 reserved2;
} __attribute__((packed));

struct acpi_srat_x2apic_cpu_affinity {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 proximity_domain;
	u32 apic_id;
	u32 flags;
	u32 clock_domain;
	u32 reserved2;
};

struct acpi_srat_generic_affinity {
	struct acpi_subtable_header header;
	u8 reserved;
	u8 device_handle_type;
	u32 proximity_domain;
	u8 device_handle[16];
	u32 flags;
	u32 reserved1;
};

enum acpi_hmat_type {
	ACPI_HMAT_TYPE_PROXIMITY = 0,
	ACPI_HMAT_TYPE_LOCALITY = 1,
	ACPI_HMAT_TYPE_CACHE = 2,
	ACPI_HMAT_TYPE_RESERVED = 3,
};

struct acpi_hmat_proximity_domain {
	struct acpi_hmat_structure header;
	u16 flags;
	u16 reserved1;
	u32 processor_PD;
	u32 memory_PD;
	u32 reserved2;
	u64 reserved3;
	u64 reserved4;
};

struct acpi_hmat_locality {
	struct acpi_hmat_structure header;
	u8 flags;
	u8 data_type;
	u8 min_transfer_size;
	u8 reserved1;
	u32 number_of_initiator_Pds;
	u32 number_of_target_Pds;
	u32 reserved2;
	u64 entry_base_unit;
};

struct acpi_hmat_cache {
	struct acpi_hmat_structure header;
	u32 memory_PD;
	u32 reserved1;
	u64 cache_size;
	u32 cache_attributes;
	u16 reserved2;
	u16 number_of_SMBIOShandles;
};

struct node_hmem_attrs {
	unsigned int read_bandwidth;
	unsigned int write_bandwidth;
	unsigned int read_latency;
	unsigned int write_latency;
};

enum cache_indexing {
	NODE_CACHE_DIRECT_MAP = 0,
	NODE_CACHE_INDEXED = 1,
	NODE_CACHE_OTHER = 2,
};

enum cache_write_policy {
	NODE_CACHE_WRITE_BACK = 0,
	NODE_CACHE_WRITE_THROUGH = 1,
	NODE_CACHE_WRITE_OTHER = 2,
};

struct node_cache_attrs {
	enum cache_indexing indexing;
	enum cache_write_policy write_policy;
	u64 size;
	u16 line_size;
	u8 level;
};

enum locality_types {
	WRITE_LATENCY = 0,
	READ_LATENCY = 1,
	WRITE_BANDWIDTH = 2,
	READ_BANDWIDTH = 3,
};

struct memory_locality {
	struct list_head node;
	struct acpi_hmat_locality *hmat_loc;
};

struct target_cache {
	struct list_head node;
	struct node_cache_attrs cache_attrs;
};

struct memory_target {
	struct list_head node;
	unsigned int memory_pxm;
	unsigned int processor_pxm;
	struct resource memregions;
	struct node_hmem_attrs hmem_attrs[2];
	struct list_head caches;
	struct node_cache_attrs cache_attrs;
	bool registered;
};

struct memory_initiator {
	struct list_head node;
	unsigned int processor_pxm;
	bool has_cpu;
};

struct memory_block___2 {
	long unsigned int start_section_nr;
	long unsigned int state;
	int online_type;
	int nid;
	struct device___155 dev;
	long unsigned int nr_vmemmap_pages;
	struct memory_group *group;
	struct list_head group_next;
};

typedef int (*walk_memory_blocks_func_t___2)(struct memory_block___2 *, void *);

struct acpi_memory_info {
	struct list_head list;
	u64 start_addr;
	u64 length;
	short unsigned int caching;
	short unsigned int write_protect;
	unsigned int enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_memory_device {
	struct acpi_device___8 *device;
	struct list_head res_list;
	int mgid;
};

enum dmi_entry_type {
	DMI_ENTRY_BIOS = 0,
	DMI_ENTRY_SYSTEM = 1,
	DMI_ENTRY_BASEBOARD = 2,
	DMI_ENTRY_CHASSIS = 3,
	DMI_ENTRY_PROCESSOR = 4,
	DMI_ENTRY_MEM_CONTROLLER = 5,
	DMI_ENTRY_MEM_MODULE = 6,
	DMI_ENTRY_CACHE = 7,
	DMI_ENTRY_PORT_CONNECTOR = 8,
	DMI_ENTRY_SYSTEM_SLOT = 9,
	DMI_ENTRY_ONBOARD_DEVICE = 10,
	DMI_ENTRY_OEMSTRINGS = 11,
	DMI_ENTRY_SYSCONF = 12,
	DMI_ENTRY_BIOS_LANG = 13,
	DMI_ENTRY_GROUP_ASSOC = 14,
	DMI_ENTRY_SYSTEM_EVENT_LOG = 15,
	DMI_ENTRY_PHYS_MEM_ARRAY = 16,
	DMI_ENTRY_MEM_DEVICE = 17,
	DMI_ENTRY_32_MEM_ERROR = 18,
	DMI_ENTRY_MEM_ARRAY_MAPPED_ADDR = 19,
	DMI_ENTRY_MEM_DEV_MAPPED_ADDR = 20,
	DMI_ENTRY_BUILTIN_POINTING_DEV = 21,
	DMI_ENTRY_PORTABLE_BATTERY = 22,
	DMI_ENTRY_SYSTEM_RESET = 23,
	DMI_ENTRY_HW_SECURITY = 24,
	DMI_ENTRY_SYSTEM_POWER_CONTROLS = 25,
	DMI_ENTRY_VOLTAGE_PROBE = 26,
	DMI_ENTRY_COOLING_DEV = 27,
	DMI_ENTRY_TEMP_PROBE = 28,
	DMI_ENTRY_ELECTRICAL_CURRENT_PROBE = 29,
	DMI_ENTRY_OOB_REMOTE_ACCESS = 30,
	DMI_ENTRY_BIS_ENTRY = 31,
	DMI_ENTRY_SYSTEM_BOOT = 32,
	DMI_ENTRY_MGMT_DEV = 33,
	DMI_ENTRY_MGMT_DEV_COMPONENT = 34,
	DMI_ENTRY_MGMT_DEV_THRES = 35,
	DMI_ENTRY_MEM_CHANNEL = 36,
	DMI_ENTRY_IPMI_DEV = 37,
	DMI_ENTRY_SYS_POWER_SUPPLY = 38,
	DMI_ENTRY_ADDITIONAL = 39,
	DMI_ENTRY_ONBOARD_DEV_EXT = 40,
	DMI_ENTRY_MGMT_CONTROLLER_HOST = 41,
	DMI_ENTRY_INACTIVE = 126,
	DMI_ENTRY_END_OF_TABLE = 127,
};

enum {
	POWER_SUPPLY_STATUS_UNKNOWN = 0,
	POWER_SUPPLY_STATUS_CHARGING = 1,
	POWER_SUPPLY_STATUS_DISCHARGING = 2,
	POWER_SUPPLY_STATUS_NOT_CHARGING = 3,
	POWER_SUPPLY_STATUS_FULL = 4,
};

enum {
	POWER_SUPPLY_TECHNOLOGY_UNKNOWN = 0,
	POWER_SUPPLY_TECHNOLOGY_NiMH = 1,
	POWER_SUPPLY_TECHNOLOGY_LION = 2,
	POWER_SUPPLY_TECHNOLOGY_LIPO = 3,
	POWER_SUPPLY_TECHNOLOGY_LiFe = 4,
	POWER_SUPPLY_TECHNOLOGY_NiCd = 5,
	POWER_SUPPLY_TECHNOLOGY_LiMn = 6,
};

enum {
	POWER_SUPPLY_CAPACITY_LEVEL_UNKNOWN = 0,
	POWER_SUPPLY_CAPACITY_LEVEL_CRITICAL = 1,
	POWER_SUPPLY_CAPACITY_LEVEL_LOW = 2,
	POWER_SUPPLY_CAPACITY_LEVEL_NORMAL = 3,
	POWER_SUPPLY_CAPACITY_LEVEL_HIGH = 4,
	POWER_SUPPLY_CAPACITY_LEVEL_FULL = 5,
};

struct acpi_battery_hook {
	const char *name;
	int (*add_battery)(struct power_supply *);
	int (*remove_battery)(struct power_supply *);
	struct list_head list;
};

enum {
	ACPI_BATTERY_ALARM_PRESENT = 0,
	ACPI_BATTERY_XINFO_PRESENT = 1,
	ACPI_BATTERY_QUIRK_PERCENTAGE_CAPACITY = 2,
	ACPI_BATTERY_QUIRK_THINKPAD_MAH = 3,
	ACPI_BATTERY_QUIRK_DEGRADED_FULL_CHARGE = 4,
};

struct acpi_battery {
	struct mutex lock;
	struct mutex sysfs_lock;
	struct power_supply *bat;
	struct power_supply_desc bat_desc;
	struct acpi_device___8 *device;
	struct notifier_block pm_nb;
	struct list_head list;
	long unsigned int update_time;
	int revision;
	int rate_now;
	int capacity_now;
	int voltage_now;
	int design_capacity;
	int full_charge_capacity;
	int technology;
	int design_voltage;
	int design_capacity_warning;
	int design_capacity_low;
	int cycle_count;
	int measurement_accuracy;
	int max_sampling_time;
	int min_sampling_time;
	int max_averaging_interval;
	int min_averaging_interval;
	int capacity_granularity_1;
	int capacity_granularity_2;
	int alarm;
	char model_number[32];
	char serial_number[32];
	char type[32];
	char oem_info[32];
	int state;
	int power_unit;
	long unsigned int flags;
};

struct acpi_offsets {
	size_t offset;
	u8 mode;
};

struct kobj_attribute___11 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___158 *, struct kobj_attribute___11 *, char *);
	ssize_t (*store)(struct kobject___158 *, struct kobj_attribute___11 *, const char *, size_t);
};

struct of_phandle_args___20 {
	struct device_node___57 *np;
	int args_count;
	uint32_t args[16];
};

struct acpi_pcct_hw_reduced {
	struct acpi_subtable_header header;
	u32 platform_interrupt;
	u8 flags;
	u8 reserved;
	u64 base_address;
	u64 length;
	struct acpi_generic_address doorbell_register;
	u64 preserve_mask;
	u64 write_mask;
	u32 latency;
	u32 max_access_rate;
	u16 min_turnaround_time;
} __attribute__((packed));

struct acpi_pcct_shared_memory {
	u32 signature;
	u16 command;
	u16 status;
};

struct mbox_chan;

struct mbox_chan_ops {
	int (*send_data)(struct mbox_chan *, void *);
	int (*flush)(struct mbox_chan *, long unsigned int);
	int (*startup)(struct mbox_chan *);
	void (*shutdown)(struct mbox_chan *);
	bool (*last_tx_done)(struct mbox_chan *);
	bool (*peek_data)(struct mbox_chan *);
};

struct mbox_controller;

struct mbox_client;

struct mbox_chan {
	struct mbox_controller *mbox;
	unsigned int txdone_method;
	struct mbox_client *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller {
	struct device___154 *dev;
	const struct mbox_chan_ops *ops;
	struct mbox_chan *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan * (*of_xlate)(struct mbox_controller *, const struct of_phandle_args___20 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct mbox_client {
	struct device___154 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client *, void *);
	void (*tx_prepare)(struct mbox_client *, void *);
	void (*tx_done)(struct mbox_client *, void *, int);
};

struct cpc_register_resource {
	acpi_object_type type;
	u64 *sys_mem_vaddr;
	union {
		struct cpc_reg reg;
		u64 int_value;
	} cpc_entry;
};

struct cpc_desc {
	int num_entries;
	int version;
	int cpu_id;
	int write_cmd_status;
	int write_cmd_id;
	struct cpc_register_resource cpc_regs[21];
	struct acpi_psd_package domain_info;
	struct kobject___183 kobj;
};

enum cppc_regs {
	HIGHEST_PERF = 0,
	NOMINAL_PERF = 1,
	LOW_NON_LINEAR_PERF = 2,
	LOWEST_PERF = 3,
	GUARANTEED_PERF = 4,
	DESIRED_PERF = 5,
	MIN_PERF = 6,
	MAX_PERF = 7,
	PERF_REDUC_TOLERANCE = 8,
	TIME_WINDOW = 9,
	CTR_WRAP_TIME = 10,
	REFERENCE_CTR = 11,
	DELIVERED_CTR = 12,
	PERF_LIMITED = 13,
	ENABLE = 14,
	AUTO_SEL_ENABLE = 15,
	AUTO_ACT_WINDOW = 16,
	ENERGY_PERF = 17,
	REFERENCE_PERF = 18,
	LOWEST_FREQ = 19,
	NOMINAL_FREQ = 20,
};

struct cppc_perf_caps {
	u32 guaranteed_perf;
	u32 highest_perf;
	u32 nominal_perf;
	u32 lowest_perf;
	u32 lowest_nonlinear_perf;
	u32 lowest_freq;
	u32 nominal_freq;
};

struct cppc_perf_ctrls {
	u32 max_perf;
	u32 min_perf;
	u32 desired_perf;
};

struct cppc_perf_fb_ctrs {
	u64 reference;
	u64 delivered;
	u64 reference_perf;
	u64 wraparound_time;
};

struct cppc_cpudata {
	struct list_head node;
	struct cppc_perf_caps perf_caps;
	struct cppc_perf_ctrls perf_ctrls;
	struct cppc_perf_fb_ctrs perf_fb_ctrs;
	unsigned int shared_type;
	cpumask_var_t shared_cpu_map;
};

struct cppc_pcc_data {
	struct mbox_chan *pcc_channel;
	void *pcc_comm_addr;
	bool pcc_channel_acquired;
	unsigned int deadline_us;
	unsigned int pcc_mpar;
	unsigned int pcc_mrtt;
	unsigned int pcc_nominal;
	bool pending_pcc_write_cmd;
	bool platform_owns_pcc;
	unsigned int pcc_write_cnt;
	struct rw_semaphore pcc_lock;
	wait_queue_head_t pcc_write_wait_q;
	ktime_t last_cmd_cmpl_time;
	ktime_t last_mpar_reset;
	int mpar_count;
	int refcount;
};

enum acpi_pptt_type {
	ACPI_PPTT_TYPE_PROCESSOR = 0,
	ACPI_PPTT_TYPE_CACHE = 1,
	ACPI_PPTT_TYPE_ID = 2,
	ACPI_PPTT_TYPE_RESERVED = 3,
};

struct acpi_pptt_processor {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 flags;
	u32 parent;
	u32 acpi_processor_id;
	u32 number_of_priv_resources;
};

struct acpi_pptt_cache {
	struct acpi_subtable_header header;
	u16 reserved;
	u32 flags;
	u32 next_level_of_cache;
	u32 size;
	u32 number_of_sets;
	u8 associativity;
	u8 attributes;
	u16 line_size;
};

struct acpi_pptt_cache_v1 {
	u32 cache_id;
};

struct acpi_whea_header {
	u8 action;
	u8 instruction;
	u8 flags;
	u8 reserved;
	struct acpi_generic_address register_region;
	u64 value;
	u64 mask;
} __attribute__((packed));

struct acpi_hest_header {
	u16 type;
	u16 source_id;
};

struct cper_sec_mem_err {
	u64 validation_bits;
	u64 error_status;
	u64 physical_addr;
	u64 physical_addr_mask;
	u16 node;
	u16 card;
	u16 module;
	u16 bank;
	u16 device;
	u16 row;
	u16 column;
	u16 bit_pos;
	u64 requestor_id;
	u64 responder_id;
	u64 target_id;
	u8 error_type;
	u8 extended;
	u16 rank;
	u16 mem_array_handle;
	u16 mem_dev_handle;
};

struct apei_exec_context;

typedef int (*apei_exec_ins_func_t)(struct apei_exec_context *, struct acpi_whea_header *);

struct apei_exec_ins_type;

struct apei_exec_context {
	u32 ip;
	u64 value;
	u64 var1;
	u64 var2;
	u64 src_base;
	u64 dst_base;
	struct apei_exec_ins_type *ins_table;
	u32 instructions;
	struct acpi_whea_header *action_table;
	u32 entries;
};

struct apei_exec_ins_type {
	u32 flags;
	apei_exec_ins_func_t run;
};

struct apei_resources {
	struct list_head iomem;
	struct list_head ioport;
};

typedef int (*apei_exec_entry_func_t)(struct apei_exec_context *, struct acpi_whea_header *, void *);

struct apei_res {
	struct list_head list;
	long unsigned int start;
	long unsigned int end;
};

struct acpi_table_hest {
	struct acpi_table_header header;
	u32 error_source_count;
};

enum acpi_hest_types {
	ACPI_HEST_TYPE_IA32_CHECK = 0,
	ACPI_HEST_TYPE_IA32_CORRECTED_CHECK = 1,
	ACPI_HEST_TYPE_IA32_NMI = 2,
	ACPI_HEST_TYPE_NOT_USED3 = 3,
	ACPI_HEST_TYPE_NOT_USED4 = 4,
	ACPI_HEST_TYPE_NOT_USED5 = 5,
	ACPI_HEST_TYPE_AER_ROOT_PORT = 6,
	ACPI_HEST_TYPE_AER_ENDPOINT = 7,
	ACPI_HEST_TYPE_AER_BRIDGE = 8,
	ACPI_HEST_TYPE_GENERIC_ERROR = 9,
	ACPI_HEST_TYPE_GENERIC_ERROR_V2 = 10,
	ACPI_HEST_TYPE_IA32_DEFERRED_CHECK = 11,
	ACPI_HEST_TYPE_RESERVED = 12,
};

struct acpi_hest_notify {
	u8 type;
	u8 length;
	u16 config_write_enable;
	u32 poll_interval;
	u32 vector;
	u32 polling_threshold_value;
	u32 polling_threshold_window;
	u32 error_threshold_value;
	u32 error_threshold_window;
};

struct acpi_hest_ia_machine_check {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u64 global_capability_data;
	u64 global_control_data;
	u8 num_hardware_banks;
	u8 reserved3[7];
};

struct acpi_hest_ia_corrected {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	struct acpi_hest_notify notify;
	u8 num_hardware_banks;
	u8 reserved2[3];
};

struct acpi_hest_generic {
	struct acpi_hest_header header;
	u16 related_source_id;
	u8 reserved;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 max_raw_data_length;
	struct acpi_generic_address error_status_address;
	struct acpi_hest_notify notify;
	u32 error_block_length;
} __attribute__((packed));

struct acpi_hest_ia_deferred_check {
	struct acpi_hest_header header;
	u16 reserved1;
	u8 flags;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	struct acpi_hest_notify notify;
	u8 num_hardware_banks;
	u8 reserved2[3];
};

enum hest_status {
	HEST_ENABLED = 0,
	HEST_DISABLED = 1,
	HEST_NOT_FOUND = 2,
};

typedef int (*apei_hest_func_t)(struct acpi_hest_header *, void *);

struct ghes_arr {
	struct platform_device **ghes_devs;
	unsigned int count;
};

struct acpi_table_erst {
	struct acpi_table_header header;
	u32 header_length;
	u32 reserved;
	u32 entries;
};

enum acpi_erst_actions {
	ACPI_ERST_BEGIN_WRITE = 0,
	ACPI_ERST_BEGIN_READ = 1,
	ACPI_ERST_BEGIN_CLEAR = 2,
	ACPI_ERST_END = 3,
	ACPI_ERST_SET_RECORD_OFFSET = 4,
	ACPI_ERST_EXECUTE_OPERATION = 5,
	ACPI_ERST_CHECK_BUSY_STATUS = 6,
	ACPI_ERST_GET_COMMAND_STATUS = 7,
	ACPI_ERST_GET_RECORD_ID = 8,
	ACPI_ERST_SET_RECORD_ID = 9,
	ACPI_ERST_GET_RECORD_COUNT = 10,
	ACPI_ERST_BEGIN_DUMMY_WRIITE = 11,
	ACPI_ERST_NOT_USED = 12,
	ACPI_ERST_GET_ERROR_RANGE = 13,
	ACPI_ERST_GET_ERROR_LENGTH = 14,
	ACPI_ERST_GET_ERROR_ATTRIBUTES = 15,
	ACPI_ERST_EXECUTE_TIMINGS = 16,
	ACPI_ERST_ACTION_RESERVED = 17,
};

enum acpi_erst_instructions {
	ACPI_ERST_READ_REGISTER = 0,
	ACPI_ERST_READ_REGISTER_VALUE = 1,
	ACPI_ERST_WRITE_REGISTER = 2,
	ACPI_ERST_WRITE_REGISTER_VALUE = 3,
	ACPI_ERST_NOOP = 4,
	ACPI_ERST_LOAD_VAR1 = 5,
	ACPI_ERST_LOAD_VAR2 = 6,
	ACPI_ERST_STORE_VAR1 = 7,
	ACPI_ERST_ADD = 8,
	ACPI_ERST_SUBTRACT = 9,
	ACPI_ERST_ADD_VALUE = 10,
	ACPI_ERST_SUBTRACT_VALUE = 11,
	ACPI_ERST_STALL = 12,
	ACPI_ERST_STALL_WHILE_TRUE = 13,
	ACPI_ERST_SKIP_NEXT_IF_TRUE = 14,
	ACPI_ERST_GOTO = 15,
	ACPI_ERST_SET_SRC_ADDRESS_BASE = 16,
	ACPI_ERST_SET_DST_ADDRESS_BASE = 17,
	ACPI_ERST_MOVE_DATA = 18,
	ACPI_ERST_INSTRUCTION_RESERVED = 19,
};

struct pstore_info___3;

struct pstore_record___3 {
	struct pstore_info___3 *psi;
	enum pstore_type_id type;
	u64 id;
	struct timespec64 time;
	char *buf;
	ssize_t size;
	ssize_t ecc_notice_size;
	int count;
	enum kmsg_dump_reason reason;
	unsigned int part;
	bool compressed;
};

struct pstore_info___3 {
	struct module___156 *owner;
	const char *name;
	spinlock_t buf_lock;
	char *buf;
	size_t bufsize;
	struct mutex read_mutex;
	int flags;
	int max_reason;
	void *data;
	int (*open)(struct pstore_info___3 *);
	int (*close)(struct pstore_info___3 *);
	ssize_t (*read)(struct pstore_record___3 *);
	int (*write)(struct pstore_record___3 *);
	int (*write_user)(struct pstore_record___3 *, const char *);
	int (*erase)(struct pstore_record___3 *);
};

struct cper_record_header {
	char signature[4];
	u16 revision;
	u32 signature_end;
	u16 section_count;
	u32 error_severity;
	u32 validation_bits;
	u32 record_length;
	u64 timestamp;
	guid_t platform_id;
	guid_t partition_id;
	guid_t creator_id;
	guid_t notification_type;
	u64 record_id;
	u32 flags;
	u64 persistence_information;
	u8 reserved[12];
} __attribute__((packed));

struct cper_section_descriptor {
	u32 section_offset;
	u32 section_length;
	u16 revision;
	u8 validation_bits;
	u8 reserved;
	u32 flags;
	guid_t section_type;
	guid_t fru_id;
	u32 section_severity;
	u8 fru_text[20];
};

struct erst_erange {
	u64 base;
	u64 size;
	void *vaddr;
	u32 attr;
};

struct erst_record_id_cache {
	struct mutex lock;
	u64 *entries;
	int len;
	int size;
	int refcount;
};

struct cper_pstore_record {
	struct cper_record_header hdr;
	struct cper_section_descriptor sec_hdr;
	char data[0];
};

struct acpi_bert_region {
	u32 block_status;
	u32 raw_data_offset;
	u32 raw_data_length;
	u32 data_length;
	u32 error_severity;
};

struct acpi_hest_generic_status {
	u32 block_status;
	u32 raw_data_offset;
	u32 raw_data_length;
	u32 data_length;
	u32 error_severity;
};

enum acpi_hest_notify_types {
	ACPI_HEST_NOTIFY_POLLED = 0,
	ACPI_HEST_NOTIFY_EXTERNAL = 1,
	ACPI_HEST_NOTIFY_LOCAL = 2,
	ACPI_HEST_NOTIFY_SCI = 3,
	ACPI_HEST_NOTIFY_NMI = 4,
	ACPI_HEST_NOTIFY_CMCI = 5,
	ACPI_HEST_NOTIFY_MCE = 6,
	ACPI_HEST_NOTIFY_GPIO = 7,
	ACPI_HEST_NOTIFY_SEA = 8,
	ACPI_HEST_NOTIFY_SEI = 9,
	ACPI_HEST_NOTIFY_GSIV = 10,
	ACPI_HEST_NOTIFY_SOFTWARE_DELEGATED = 11,
	ACPI_HEST_NOTIFY_RESERVED = 12,
};

struct acpi_hest_generic_v2 {
	struct acpi_hest_header header;
	u16 related_source_id;
	u8 reserved;
	u8 enabled;
	u32 records_to_preallocate;
	u32 max_sections_per_record;
	u32 max_raw_data_length;
	struct acpi_generic_address error_status_address;
	struct acpi_hest_notify notify;
	u32 error_block_length;
	struct acpi_generic_address read_ack_register;
	u64 read_ack_preserve;
	u64 read_ack_write;
} __attribute__((packed));

struct cper_sec_proc_arm {
	u32 validation_bits;
	u16 err_info_num;
	u16 context_info_num;
	u32 section_length;
	u8 affinity_level;
	u8 reserved[3];
	u64 mpidr;
	u64 midr;
	u32 running_state;
	u32 psci_state;
};

struct cper_arm_err_info {
	u8 version;
	u8 length;
	u16 validation_bits;
	u8 type;
	u16 multiple_error;
	u8 flags;
	u64 error_info;
	u64 virt_fault_addr;
	u64 physical_fault_addr;
} __attribute__((packed));

struct cper_sec_pcie {
	u64 validation_bits;
	u32 port_type;
	struct {
		u8 minor;
		u8 major;
		u8 reserved[2];
	} version;
	u16 command;
	u16 status;
	u32 reserved;
	struct {
		u16 vendor_id;
		u16 device_id;
		u8 class_code[3];
		u8 function;
		u8 device;
		u16 segment;
		u8 bus;
		u8 secondary_bus;
		u16 slot;
		u8 reserved;
	} __attribute__((packed)) device_id;
	struct {
		u32 lower;
		u32 upper;
	} serial_number;
	struct {
		u16 secondary_status;
		u16 control;
	} bridge;
	u8 capability[60];
	u8 aer_info[96];
};

struct ghes {
	union {
		struct acpi_hest_generic *generic;
		struct acpi_hest_generic_v2 *generic_v2;
	};
	struct acpi_hest_generic_status *estatus;
	long unsigned int flags;
	union {
		struct list_head list;
		struct timer_list timer;
		unsigned int irq;
	};
};

struct ghes_estatus_node {
	struct llist_node llnode;
	struct acpi_hest_generic *generic;
	struct ghes *ghes;
	int task_work_cpu;
	struct callback_head task_work;
};

struct ghes_estatus_cache {
	u32 estatus_len;
	atomic_t count;
	struct acpi_hest_generic *generic;
	long long unsigned int time_in;
	struct callback_head rcu;
};

enum {
	GHES_SEV_NO = 0,
	GHES_SEV_CORRECTED = 1,
	GHES_SEV_RECOVERABLE = 2,
	GHES_SEV_PANIC = 3,
};

typedef int sdei_event_callback___2(u32, struct pt_regs *, void *);

struct ghes_vendor_record_entry {
	struct work_struct work;
	int error_severity;
	char vendor_record[0];
};

struct irq_desc___40;

typedef void (*irq_flow_handler_t___40)(struct irq_desc___40 *);

struct irq_chip___39;

struct irq_domain___38;

struct irq_data___39 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___39 *chip;
	struct irq_domain___38 *domain;
	struct irq_data___39 *parent_data;
	void *chip_data;
};

struct irq_desc___40 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___39 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___40 handle_irq;
	struct irqaction___27 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___184 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___180 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___157;

struct device___157;

struct fwnode_handle___157 {
	struct fwnode_handle___157 *secondary;
	const struct fwnode_operations___157 *ops;
	struct device___157 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___157;

struct fwnode_endpoint___157;

struct fwnode_operations___157 {
	struct fwnode_handle___157 * (*get)(struct fwnode_handle___157 *);
	void (*put)(struct fwnode_handle___157 *);
	bool (*device_is_available)(const struct fwnode_handle___157 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___157 *, const struct device___157 *);
	bool (*property_present)(const struct fwnode_handle___157 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___157 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___157 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___157 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*get_parent)(const struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*get_next_child_node)(const struct fwnode_handle___157 *, struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*get_named_child_node)(const struct fwnode_handle___157 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___157 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___157 *);
	struct fwnode_handle___157 * (*graph_get_next_endpoint)(const struct fwnode_handle___157 *, struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*graph_get_remote_endpoint)(const struct fwnode_handle___157 *);
	struct fwnode_handle___157 * (*graph_get_port_parent)(struct fwnode_handle___157 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___157 *, struct fwnode_endpoint___157 *);
	int (*add_links)(struct fwnode_handle___157 *);
};

struct wakeup_source___157;

struct dev_pm_info___157 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___157 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___157 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___157;

struct bus_type___157;

struct device_driver___157;

struct dev_pm_domain___157;

struct dma_map_ops___7;

struct device_node___60;

struct class___157;

struct dev_iommu___7;

struct device___157 {
	struct kobject___184 kobj;
	struct device___157 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___157 *type;
	struct bus_type___157 *bus;
	struct device_driver___157 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___157 power;
	struct dev_pm_domain___157 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___38 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___7 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___60 *of_node;
	struct fwnode_handle___157 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___157 *class;
	const struct attribute_group___184 **groups;
	void (*release)(struct device___157 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___7 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___157 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___157 *local_fwnode;
};

struct fwnode_reference_args___157 {
	struct fwnode_handle___157 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___60 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___157 fwnode;
	struct property___47 *properties;
	struct property___47 *deadprops;
	struct device_node___60 *parent;
	struct device_node___60 *child;
	struct device_node___60 *sibling;
	struct kobject___184 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___21 {
	struct device_node___60 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___36 {
	struct fwnode_handle___157 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___38 {
	int (*match)(struct irq_domain___38 *, struct device_node___60 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___38 *, struct irq_fwspec___36 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___38 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___38 *, unsigned int);
	int (*xlate)(struct irq_domain___38 *, struct device_node___60 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___38 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___38 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___38 *, struct irq_data___39 *, bool);
	void (*deactivate)(struct irq_domain___38 *, struct irq_data___39 *);
	int (*translate)(struct irq_domain___38 *, struct irq_fwspec___36 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___38;

struct irq_domain___38 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___38 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___157 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___38 *gc;
	struct irq_domain___38 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___39 *revmap[0];
};

struct irq_chip_generic___38;

struct irq_domain_chip_generic___38 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___38 *gc[0];
};

struct dev_pm_ops___157 {
	int (*prepare)(struct device___157 *);
	void (*complete)(struct device___157 *);
	int (*suspend)(struct device___157 *);
	int (*resume)(struct device___157 *);
	int (*freeze)(struct device___157 *);
	int (*thaw)(struct device___157 *);
	int (*poweroff)(struct device___157 *);
	int (*restore)(struct device___157 *);
	int (*suspend_late)(struct device___157 *);
	int (*resume_early)(struct device___157 *);
	int (*freeze_late)(struct device___157 *);
	int (*thaw_early)(struct device___157 *);
	int (*poweroff_late)(struct device___157 *);
	int (*restore_early)(struct device___157 *);
	int (*suspend_noirq)(struct device___157 *);
	int (*resume_noirq)(struct device___157 *);
	int (*freeze_noirq)(struct device___157 *);
	int (*thaw_noirq)(struct device___157 *);
	int (*poweroff_noirq)(struct device___157 *);
	int (*restore_noirq)(struct device___157 *);
	int (*runtime_suspend)(struct device___157 *);
	int (*runtime_resume)(struct device___157 *);
	int (*runtime_idle)(struct device___157 *);
};

struct wakeup_source___157 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___157 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___157 {
	struct dev_pm_ops___157 ops;
	int (*start)(struct device___157 *);
	void (*detach)(struct device___157 *, bool);
	int (*activate)(struct device___157 *);
	void (*sync)(struct device___157 *);
	void (*dismiss)(struct device___157 *);
};

struct iommu_ops___7;

struct bus_type___157 {
	const char *name;
	const char *dev_name;
	struct device___157 *dev_root;
	const struct attribute_group___184 **bus_groups;
	const struct attribute_group___184 **dev_groups;
	const struct attribute_group___184 **drv_groups;
	int (*match)(struct device___157 *, struct device_driver___157 *);
	int (*uevent)(struct device___157 *, struct kobj_uevent_env *);
	int (*probe)(struct device___157 *);
	void (*sync_state)(struct device___157 *);
	void (*remove)(struct device___157 *);
	void (*shutdown)(struct device___157 *);
	int (*online)(struct device___157 *);
	int (*offline)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	int (*num_vf)(struct device___157 *);
	int (*dma_configure)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
	const struct iommu_ops___7 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___157 {
	const char *name;
	struct bus_type___157 *bus;
	struct module___180 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___157 *);
	void (*sync_state)(struct device___157 *);
	int (*remove)(struct device___157 *);
	void (*shutdown)(struct device___157 *);
	int (*suspend)(struct device___157 *, pm_message_t);
	int (*resume)(struct device___157 *);
	const struct attribute_group___184 **groups;
	const struct attribute_group___184 **dev_groups;
	const struct dev_pm_ops___157 *pm;
	void (*coredump)(struct device___157 *);
	struct driver_private *p;
};

struct iommu_domain___7;

struct iommu_device___7;

struct iommu_sva___7;

struct iommu_ops___7 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___7 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___7 *);
	int (*attach_dev)(struct iommu_domain___7 *, struct device___157 *);
	void (*detach_dev)(struct iommu_domain___7 *, struct device___157 *);
	int (*map)(struct iommu_domain___7 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___7 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___7 *, long unsigned int, size_t, struct iommu_iotlb_gather___3 *);
	size_t (*unmap_pages)(struct iommu_domain___7 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___3 *);
	void (*flush_iotlb_all)(struct iommu_domain___7 *);
	void (*iotlb_sync_map)(struct iommu_domain___7 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___7 *, struct iommu_iotlb_gather___3 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___7 *, dma_addr_t);
	struct iommu_device___7 * (*probe_device)(struct device___157 *);
	void (*release_device)(struct device___157 *);
	void (*probe_finalize)(struct device___157 *);
	struct iommu_group * (*device_group)(struct device___157 *);
	int (*enable_nesting)(struct iommu_domain___7 *);
	int (*set_pgtable_quirks)(struct iommu_domain___7 *, long unsigned int);
	void (*get_resv_regions)(struct device___157 *, struct list_head *);
	void (*put_resv_regions)(struct device___157 *, struct list_head *);
	void (*apply_resv_region)(struct device___157 *, struct iommu_domain___7 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___157 *, struct of_phandle_args___21 *);
	bool (*is_attach_deferred)(struct iommu_domain___7 *, struct device___157 *);
	bool (*dev_has_feat)(struct device___157 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___157 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___157 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___157 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___7 *, struct device___157 *);
	void (*aux_detach_dev)(struct iommu_domain___7 *, struct device___157 *);
	int (*aux_get_pasid)(struct iommu_domain___7 *, struct device___157 *);
	struct iommu_sva___7 * (*sva_bind)(struct device___157 *, struct mm_struct___202 *, void *);
	void (*sva_unbind)(struct iommu_sva___7 *);
	u32 (*sva_get_pasid)(struct iommu_sva___7 *);
	int (*page_response)(struct device___157 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___7 *, struct device___157 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___7 *, struct device___157 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___157 *, u32);
	int (*def_domain_type)(struct device___157 *);
	long unsigned int pgsize_bitmap;
	struct module___180 *owner;
};

struct device_type___157 {
	const char *name;
	const struct attribute_group___184 **groups;
	int (*uevent)(struct device___157 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___157 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___157 *);
	const struct dev_pm_ops___157 *pm;
};

struct class___157 {
	const char *name;
	struct module___180 *owner;
	const struct attribute_group___184 **class_groups;
	const struct attribute_group___184 **dev_groups;
	struct kobject___184 *dev_kobj;
	int (*dev_uevent)(struct device___157 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___157 *, umode_t *);
	void (*class_release)(struct class___157 *);
	void (*dev_release)(struct device___157 *);
	int (*shutdown_pre)(struct device___157 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___157 *);
	void (*get_ownership)(struct device___157 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___157 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___7 {
	void * (*alloc)(struct device___157 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___157 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___201 * (*alloc_pages)(struct device___157 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___157 *, size_t, struct page___201 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___157 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___157 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___157 *, struct vm_area_struct___201 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___157 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___157 *, struct page___201 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___157 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___157 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___157 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___157 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___157 *, u64);
	u64 (*get_required_mask)(struct device___157 *);
	size_t (*max_mapping_size)(struct device___157 *);
	long unsigned int (*get_merge_boundary)(struct device___157 *);
};

struct iommu_fwspec___7;

struct dev_iommu___7 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___7 *fwspec;
	struct iommu_device___7 *iommu_dev;
	void *priv;
};

struct acpi_table_iort {
	struct acpi_table_header header;
	u32 node_count;
	u32 node_offset;
	u32 reserved;
};

struct acpi_iort_node {
	u8 type;
	u16 length;
	u8 revision;
	u32 identifier;
	u32 mapping_count;
	u32 mapping_offset;
	char node_data[1];
} __attribute__((packed));

enum acpi_iort_node_type {
	ACPI_IORT_NODE_ITS_GROUP = 0,
	ACPI_IORT_NODE_NAMED_COMPONENT = 1,
	ACPI_IORT_NODE_PCI_ROOT_COMPLEX = 2,
	ACPI_IORT_NODE_SMMU = 3,
	ACPI_IORT_NODE_SMMU_V3 = 4,
	ACPI_IORT_NODE_PMCG = 5,
	ACPI_IORT_NODE_RMR = 6,
};

struct acpi_iort_id_mapping {
	u32 input_base;
	u32 id_count;
	u32 output_base;
	u32 output_reference;
	u32 flags;
};

struct acpi_iort_its_group {
	u32 its_count;
	u32 identifiers[1];
};

struct acpi_iort_named_component {
	u32 node_flags;
	u64 memory_properties;
	u8 memory_address_limit;
	char device_name[1];
} __attribute__((packed));

struct acpi_iort_root_complex {
	u64 memory_properties;
	u32 ats_attribute;
	u32 pci_segment_number;
	u8 memory_address_limit;
	u8 reserved[3];
} __attribute__((packed));

struct acpi_iort_smmu {
	u64 base_address;
	u64 span;
	u32 model;
	u32 flags;
	u32 global_interrupt_offset;
	u32 context_interrupt_count;
	u32 context_interrupt_offset;
	u32 pmu_interrupt_count;
	u32 pmu_interrupt_offset;
	u64 interrupts[1];
} __attribute__((packed));

struct acpi_iort_smmu_v3 {
	u64 base_address;
	u32 flags;
	u32 reserved;
	u64 vatos_address;
	u32 model;
	u32 event_gsiv;
	u32 pri_gsiv;
	u32 gerr_gsiv;
	u32 sync_gsiv;
	u32 pxm;
	u32 id_mapping_index;
} __attribute__((packed));

struct acpi_iort_pmcg {
	u64 page0_base_address;
	u32 overflow_gsiv;
	u32 node_reference;
	u64 page1_base_address;
};

struct acpi_device___11;

struct acpi_hotplug_profile___11 {
	struct kobject___184 kobj;
	int (*scan_dependent)(struct acpi_device___11 *);
	void (*notify_online)(struct acpi_device___11 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___11 {
	void (*func)(struct acpi_device_wakeup_context___11 *);
	struct device___157 *dev;
};

struct acpi_device_wakeup___11 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___11 context;
	struct wakeup_source___157 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___11;

struct acpi_hotplug_context___11;

struct acpi_driver___11;

struct acpi_device___11 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___157 fwnode;
	struct acpi_device___11 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___11 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___11 *handler;
	struct acpi_hotplug_context___11 *hp;
	struct acpi_driver___11 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___157 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___11 *);
};

struct acpi_scan_handler___11 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___11 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___11 *);
	void (*bind)(struct device___157 *);
	void (*unbind)(struct device___157 *);
	struct acpi_hotplug_profile___11 hotplug;
};

struct acpi_hotplug_context___11 {
	struct acpi_device___11 *self;
	int (*notify)(struct acpi_device___11 *, u32);
	void (*uevent)(struct acpi_device___11 *, u32);
	void (*fixup)(struct acpi_device___11 *);
};

typedef int (*acpi_op_add___11)(struct acpi_device___11 *);

typedef int (*acpi_op_remove___11)(struct acpi_device___11 *);

typedef void (*acpi_op_notify___11)(struct acpi_device___11 *, u32);

struct acpi_device_ops___11 {
	acpi_op_add___11 add;
	acpi_op_remove___11 remove;
	acpi_op_notify___11 notify;
};

struct acpi_driver___11 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___11 ops;
	struct device_driver___157 drv;
	struct module___180 *owner;
};

struct pci_dev___12;

struct pci_ops___12;

struct pci_bus___12 {
	struct list_head node;
	struct pci_bus___12 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___12 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___12 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___157 *bridge;
	struct device___157 dev;
	struct bin_attribute___184 *legacy_io;
	struct bin_attribute___184 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___39 {
	struct device___157 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___39 *);
	void (*irq_shutdown)(struct irq_data___39 *);
	void (*irq_enable)(struct irq_data___39 *);
	void (*irq_disable)(struct irq_data___39 *);
	void (*irq_ack)(struct irq_data___39 *);
	void (*irq_mask)(struct irq_data___39 *);
	void (*irq_mask_ack)(struct irq_data___39 *);
	void (*irq_unmask)(struct irq_data___39 *);
	void (*irq_eoi)(struct irq_data___39 *);
	int (*irq_set_affinity)(struct irq_data___39 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___39 *);
	int (*irq_set_type)(struct irq_data___39 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___39 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___39 *);
	void (*irq_bus_sync_unlock)(struct irq_data___39 *);
	void (*irq_cpu_online)(struct irq_data___39 *);
	void (*irq_cpu_offline)(struct irq_data___39 *);
	void (*irq_suspend)(struct irq_data___39 *);
	void (*irq_resume)(struct irq_data___39 *);
	void (*irq_pm_shutdown)(struct irq_data___39 *);
	void (*irq_calc_mask)(struct irq_data___39 *);
	void (*irq_print_chip)(struct irq_data___39 *, struct seq_file___172 *);
	int (*irq_request_resources)(struct irq_data___39 *);
	void (*irq_release_resources)(struct irq_data___39 *);
	void (*irq_compose_msi_msg)(struct irq_data___39 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___39 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___39 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___39 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___39 *, void *);
	void (*ipi_send_single)(struct irq_data___39 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___39 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___39 *);
	void (*irq_nmi_teardown)(struct irq_data___39 *);
	long unsigned int flags;
};

struct irq_chip_type___38 {
	struct irq_chip___39 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___40 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___38 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___38 *);
	void (*resume)(struct irq_chip_generic___38 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___38 *domain;
	struct list_head list;
	struct irq_chip_type___38 chip_types[0];
};

typedef int (*iommu_fault_handler_t___7)(struct iommu_domain___7 *, struct device___157 *, long unsigned int, int, void *);

struct iommu_domain___7 {
	unsigned int type;
	const struct iommu_ops___7 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___7 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_device___7 {
	struct list_head list;
	const struct iommu_ops___7 *ops;
	struct fwnode_handle___157 *fwnode;
	struct device___157 *dev;
};

struct iommu_sva___7 {
	struct device___157 *dev;
};

struct iommu_fwspec___7 {
	const struct iommu_ops___7 *ops;
	struct fwnode_handle___157 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct pci_slot___12 {
	struct pci_bus___12 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___184 kobj;
};

struct pci_driver___12;

struct pci_dev___12 {
	struct list_head bus_list;
	struct pci_bus___12 *bus;
	struct pci_bus___12 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___12 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___12 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___12 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___157 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___184 *res_attr[17];
	struct bin_attribute___184 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___184 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___12 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___12;

struct pci_driver___12 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___12 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___12 *);
	int (*suspend)(struct pci_dev___12 *, pm_message_t);
	int (*resume)(struct pci_dev___12 *);
	void (*shutdown)(struct pci_dev___12 *);
	int (*sriov_configure)(struct pci_dev___12 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___12 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___12 *);
	const struct pci_error_handlers___12 *err_handler;
	const struct attribute_group___184 **groups;
	const struct attribute_group___184 **dev_groups;
	struct device_driver___157 driver;
	struct pci_dynids dynids;
};

struct pci_ops___12 {
	int (*add_bus)(struct pci_bus___12 *);
	void (*remove_bus)(struct pci_bus___12 *);
	void * (*map_bus)(struct pci_bus___12 *, unsigned int, int);
	int (*read)(struct pci_bus___12 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___12 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___12 {
	pci_ers_result_t (*error_detected)(struct pci_dev___12 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___12 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___12 *);
	void (*reset_prepare)(struct pci_dev___12 *);
	void (*reset_done)(struct pci_dev___12 *);
	void (*resume)(struct pci_dev___12 *);
};

struct platform_device___19 {
	const char *name;
	int id;
	bool id_auto;
	struct device___157 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct iort_its_msi_chip {
	struct list_head list;
	struct fwnode_handle___157 *fw_node;
	phys_addr_t base_addr;
	u32 translation_id;
};

struct iort_fwnode {
	struct list_head list;
	struct acpi_iort_node *iort_node;
	struct fwnode_handle___157 *fwnode;
};

typedef acpi_status (*iort_find_node_callback)(struct acpi_iort_node *, void *);

struct iort_pci_alias_info {
	struct device___157 *dev;
	struct acpi_iort_node *node;
};

struct iort_dev_config {
	const char *name;
	int (*dev_init)(struct acpi_iort_node *);
	void (*dev_dma_configure)(struct device___157 *, struct acpi_iort_node *);
	int (*dev_count_resources)(struct acpi_iort_node *);
	void (*dev_init_resources)(struct resource *, struct acpi_iort_node *);
	int (*dev_set_proximity)(struct device___157 *, struct acpi_iort_node *);
	int (*dev_add_platdata)(struct platform_device___19 *);
};

enum arch_timer_ppi_nr {
	ARCH_TIMER_PHYS_SECURE_PPI = 0,
	ARCH_TIMER_PHYS_NONSECURE_PPI = 1,
	ARCH_TIMER_VIRT_PPI = 2,
	ARCH_TIMER_HYP_PPI = 3,
	ARCH_TIMER_HYP_VIRT_PPI = 4,
	ARCH_TIMER_MAX_TIMER_PPI = 5,
};

struct arch_timer_mem_frame {
	bool valid;
	phys_addr_t cntbase;
	size_t size;
	int phys_irq;
	int virt_irq;
};

struct arch_timer_mem {
	phys_addr_t cntctlbase;
	size_t size;
	struct arch_timer_mem_frame frame[8];
};

struct acpi_table_gtdt {
	struct acpi_table_header header;
	u64 counter_block_addresss;
	u32 reserved;
	u32 secure_el1_interrupt;
	u32 secure_el1_flags;
	u32 non_secure_el1_interrupt;
	u32 non_secure_el1_flags;
	u32 virtual_timer_interrupt;
	u32 virtual_timer_flags;
	u32 non_secure_el2_interrupt;
	u32 non_secure_el2_flags;
	u64 counter_read_block_address;
	u32 platform_timer_count;
	u32 platform_timer_offset;
} __attribute__((packed));

struct acpi_gtdt_header {
	u8 type;
	u16 length;
} __attribute__((packed));

enum acpi_gtdt_type {
	ACPI_GTDT_TYPE_TIMER_BLOCK = 0,
	ACPI_GTDT_TYPE_WATCHDOG = 1,
	ACPI_GTDT_TYPE_RESERVED = 2,
};

struct acpi_gtdt_timer_block {
	struct acpi_gtdt_header header;
	u8 reserved;
	u64 block_address;
	u32 timer_count;
	u32 timer_offset;
} __attribute__((packed));

struct acpi_gtdt_timer_entry {
	u8 frame_number;
	u8 reserved[3];
	u64 base_address;
	u64 el0_base_address;
	u32 timer_interrupt;
	u32 timer_flags;
	u32 virtual_timer_interrupt;
	u32 virtual_timer_flags;
	u32 common_flags;
} __attribute__((packed));

struct acpi_gtdt_watchdog {
	struct acpi_gtdt_header header;
	u8 reserved;
	u64 refresh_frame_address;
	u64 control_frame_address;
	u32 timer_interrupt;
	u32 timer_flags;
} __attribute__((packed));

struct acpi_gtdt_descriptor {
	struct acpi_table_gtdt *gtdt;
	void *gtdt_end;
	void *platform_timer;
};

struct irq_desc___41;

typedef void (*irq_flow_handler_t___41)(struct irq_desc___41 *);

struct irq_chip___40;

struct irq_domain___39;

struct irq_data___40 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___40 *chip;
	struct irq_domain___39 *domain;
	struct irq_data___40 *parent_data;
	void *chip_data;
};

struct irq_desc___41 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___40 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___41 handle_irq;
	struct irqaction___26 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___183 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___179 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___158;

struct device___158;

struct fwnode_handle___158 {
	struct fwnode_handle___158 *secondary;
	const struct fwnode_operations___158 *ops;
	struct device___158 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___158;

struct fwnode_endpoint___158;

struct fwnode_operations___158 {
	struct fwnode_handle___158 * (*get)(struct fwnode_handle___158 *);
	void (*put)(struct fwnode_handle___158 *);
	bool (*device_is_available)(const struct fwnode_handle___158 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___158 *, const struct device___158 *);
	bool (*property_present)(const struct fwnode_handle___158 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___158 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___158 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___158 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*get_parent)(const struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*get_next_child_node)(const struct fwnode_handle___158 *, struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*get_named_child_node)(const struct fwnode_handle___158 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___158 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___158 *);
	struct fwnode_handle___158 * (*graph_get_next_endpoint)(const struct fwnode_handle___158 *, struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*graph_get_remote_endpoint)(const struct fwnode_handle___158 *);
	struct fwnode_handle___158 * (*graph_get_port_parent)(struct fwnode_handle___158 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___158 *, struct fwnode_endpoint___158 *);
	int (*add_links)(struct fwnode_handle___158 *);
};

struct wakeup_source___158;

struct dev_pm_info___158 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___158 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___3 *subsys_data;
	void (*set_latency_tolerance)(struct device___158 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___158;

struct bus_type___158;

struct device_driver___158;

struct dev_pm_domain___158;

struct dma_map_ops___8;

struct io_tlb_mem___4;

struct device_node___61;

struct class___158;

struct device___158 {
	struct kobject___183 kobj;
	struct device___158 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___158 *type;
	struct bus_type___158 *bus;
	struct device_driver___158 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___158 power;
	struct dev_pm_domain___158 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___39 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___8 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem___4 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___61 *of_node;
	struct fwnode_handle___158 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___158 *class;
	const struct attribute_group___183 **groups;
	void (*release)(struct device___158 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___158 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___158 *local_fwnode;
};

struct fwnode_reference_args___158 {
	struct fwnode_handle___158 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___61 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___158 fwnode;
	struct property___46 *properties;
	struct property___46 *deadprops;
	struct device_node___61 *parent;
	struct device_node___61 *child;
	struct device_node___61 *sibling;
	struct kobject___183 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___37 {
	struct fwnode_handle___158 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___39 {
	int (*match)(struct irq_domain___39 *, struct device_node___61 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___39 *, struct irq_fwspec___37 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___39 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___39 *, unsigned int);
	int (*xlate)(struct irq_domain___39 *, struct device_node___61 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___39 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___39 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___39 *, struct irq_data___40 *, bool);
	void (*deactivate)(struct irq_domain___39 *, struct irq_data___40 *);
	int (*translate)(struct irq_domain___39 *, struct irq_fwspec___37 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___39;

struct irq_domain___39 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___39 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___158 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___39 *gc;
	struct irq_domain___39 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___40 *revmap[0];
};

struct irq_chip_generic___39;

struct irq_domain_chip_generic___39 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___39 *gc[0];
};

struct dev_pm_ops___158 {
	int (*prepare)(struct device___158 *);
	void (*complete)(struct device___158 *);
	int (*suspend)(struct device___158 *);
	int (*resume)(struct device___158 *);
	int (*freeze)(struct device___158 *);
	int (*thaw)(struct device___158 *);
	int (*poweroff)(struct device___158 *);
	int (*restore)(struct device___158 *);
	int (*suspend_late)(struct device___158 *);
	int (*resume_early)(struct device___158 *);
	int (*freeze_late)(struct device___158 *);
	int (*thaw_early)(struct device___158 *);
	int (*poweroff_late)(struct device___158 *);
	int (*restore_early)(struct device___158 *);
	int (*suspend_noirq)(struct device___158 *);
	int (*resume_noirq)(struct device___158 *);
	int (*freeze_noirq)(struct device___158 *);
	int (*thaw_noirq)(struct device___158 *);
	int (*poweroff_noirq)(struct device___158 *);
	int (*restore_noirq)(struct device___158 *);
	int (*runtime_suspend)(struct device___158 *);
	int (*runtime_resume)(struct device___158 *);
	int (*runtime_idle)(struct device___158 *);
};

struct wakeup_source___158 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___158 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___158 {
	struct dev_pm_ops___158 ops;
	int (*start)(struct device___158 *);
	void (*detach)(struct device___158 *, bool);
	int (*activate)(struct device___158 *);
	void (*sync)(struct device___158 *);
	void (*dismiss)(struct device___158 *);
};

struct bus_type___158 {
	const char *name;
	const char *dev_name;
	struct device___158 *dev_root;
	const struct attribute_group___183 **bus_groups;
	const struct attribute_group___183 **dev_groups;
	const struct attribute_group___183 **drv_groups;
	int (*match)(struct device___158 *, struct device_driver___158 *);
	int (*uevent)(struct device___158 *, struct kobj_uevent_env *);
	int (*probe)(struct device___158 *);
	void (*sync_state)(struct device___158 *);
	void (*remove)(struct device___158 *);
	void (*shutdown)(struct device___158 *);
	int (*online)(struct device___158 *);
	int (*offline)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	int (*num_vf)(struct device___158 *);
	int (*dma_configure)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___158 {
	const char *name;
	struct bus_type___158 *bus;
	struct module___179 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___158 *);
	void (*sync_state)(struct device___158 *);
	int (*remove)(struct device___158 *);
	void (*shutdown)(struct device___158 *);
	int (*suspend)(struct device___158 *, pm_message_t);
	int (*resume)(struct device___158 *);
	const struct attribute_group___183 **groups;
	const struct attribute_group___183 **dev_groups;
	const struct dev_pm_ops___158 *pm;
	void (*coredump)(struct device___158 *);
	struct driver_private *p;
};

struct device_type___158 {
	const char *name;
	const struct attribute_group___183 **groups;
	int (*uevent)(struct device___158 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___158 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___158 *);
	const struct dev_pm_ops___158 *pm;
};

struct class___158 {
	const char *name;
	struct module___179 *owner;
	const struct attribute_group___183 **class_groups;
	const struct attribute_group___183 **dev_groups;
	struct kobject___183 *dev_kobj;
	int (*dev_uevent)(struct device___158 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___158 *, umode_t *);
	void (*class_release)(struct class___158 *);
	void (*dev_release)(struct device___158 *);
	int (*shutdown_pre)(struct device___158 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___158 *);
	void (*get_ownership)(struct device___158 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___158 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___8 {
	void * (*alloc)(struct device___158 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___158 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___200 * (*alloc_pages)(struct device___158 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___158 *, size_t, struct page___200 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___158 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___158 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___158 *, struct vm_area_struct___200 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___158 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___158 *, struct page___200 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___158 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___158 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___158 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___158 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___158 *, u64);
	u64 (*get_required_mask)(struct device___158 *);
	size_t (*max_mapping_size)(struct device___158 *);
	long unsigned int (*get_merge_boundary)(struct device___158 *);
};

struct io_tlb_mem___4 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___195 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct irq_chip___40 {
	struct device___158 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___40 *);
	void (*irq_shutdown)(struct irq_data___40 *);
	void (*irq_enable)(struct irq_data___40 *);
	void (*irq_disable)(struct irq_data___40 *);
	void (*irq_ack)(struct irq_data___40 *);
	void (*irq_mask)(struct irq_data___40 *);
	void (*irq_mask_ack)(struct irq_data___40 *);
	void (*irq_unmask)(struct irq_data___40 *);
	void (*irq_eoi)(struct irq_data___40 *);
	int (*irq_set_affinity)(struct irq_data___40 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___40 *);
	int (*irq_set_type)(struct irq_data___40 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___40 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___40 *);
	void (*irq_bus_sync_unlock)(struct irq_data___40 *);
	void (*irq_cpu_online)(struct irq_data___40 *);
	void (*irq_cpu_offline)(struct irq_data___40 *);
	void (*irq_suspend)(struct irq_data___40 *);
	void (*irq_resume)(struct irq_data___40 *);
	void (*irq_pm_shutdown)(struct irq_data___40 *);
	void (*irq_calc_mask)(struct irq_data___40 *);
	void (*irq_print_chip)(struct irq_data___40 *, struct seq_file___171 *);
	int (*irq_request_resources)(struct irq_data___40 *);
	void (*irq_release_resources)(struct irq_data___40 *);
	void (*irq_compose_msi_msg)(struct irq_data___40 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___40 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___40 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___40 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___40 *, void *);
	void (*ipi_send_single)(struct irq_data___40 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___40 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___40 *);
	void (*irq_nmi_teardown)(struct irq_data___40 *);
	long unsigned int flags;
};

struct irq_chip_type___39 {
	struct irq_chip___40 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___41 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___39 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___39 *);
	void (*resume)(struct irq_chip_generic___39 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___39 *domain;
	struct list_head list;
	struct irq_chip_type___39 chip_types[0];
};

struct acpi_table_viot {
	struct acpi_table_header header;
	u16 node_count;
	u16 node_offset;
	u8 reserved[8];
};

struct acpi_viot_header {
	u8 type;
	u8 reserved;
	u16 length;
};

enum acpi_viot_node_type {
	ACPI_VIOT_NODE_PCI_RANGE = 1,
	ACPI_VIOT_NODE_MMIO = 2,
	ACPI_VIOT_NODE_VIRTIO_IOMMU_PCI = 3,
	ACPI_VIOT_NODE_VIRTIO_IOMMU_MMIO = 4,
	ACPI_VIOT_RESERVED = 5,
};

struct acpi_viot_pci_range {
	struct acpi_viot_header header;
	u32 endpoint_start;
	u16 segment_start;
	u16 segment_end;
	u16 bdf_start;
	u16 bdf_end;
	u16 output_node;
	u8 reserved[6];
};

struct acpi_viot_mmio {
	struct acpi_viot_header header;
	u32 endpoint;
	u64 base_address;
	u16 output_node;
	u8 reserved[6];
};

struct acpi_viot_virtio_iommu_pci {
	struct acpi_viot_header header;
	u16 segment;
	u16 bdf;
	u8 reserved[8];
};

struct acpi_viot_virtio_iommu_mmio {
	struct acpi_viot_header header;
	u8 reserved[4];
	u64 base_address;
};

struct platform_device___20 {
	const char *name;
	int id;
	bool id_auto;
	struct device___136 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct viot_iommu {
	unsigned int offset;
	struct fwnode_handle___136 *fwnode;
	struct list_head list;
};

struct viot_endpoint {
	union {
		struct {
			u16 segment_start;
			u16 segment_end;
			u16 bdf_start;
			u16 bdf_end;
		};
		u64 address;
	};
	u32 endpoint_id;
	struct viot_iommu *viommu;
	struct list_head list;
};

struct pnp_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
};

struct pnp_card_device_id {
	__u8 id[8];
	kernel_ulong_t driver_data;
	struct {
		__u8 id[8];
	} devs[8];
};

struct pnp_protocol;

struct pnp_id;

struct pnp_card {
	struct device___158 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev;

struct pnp_protocol {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev *);
	int (*set)(struct pnp_dev *);
	int (*disable)(struct pnp_dev *);
	bool (*can_wakeup)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	unsigned char number;
	struct device___158 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_id {
	char id[8];
	struct pnp_id *next;
};

struct pnp_card_driver;

struct pnp_card_link {
	struct pnp_card *card;
	struct pnp_card_driver *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver {
	const char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev *);
	void (*shutdown)(struct pnp_dev *);
	int (*suspend)(struct pnp_dev *, pm_message_t);
	int (*resume)(struct pnp_dev *);
	struct device_driver___158 driver;
};

struct pnp_card_driver {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link *);
	int (*suspend)(struct pnp_card_link *, pm_message_t);
	int (*resume)(struct pnp_card_link *);
	struct pnp_driver link;
};

struct pnp_dev {
	struct device___158 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol *protocol;
	struct pnp_card *card;
	struct pnp_driver *driver;
	struct pnp_card_link *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_resource {
	struct list_head list;
	struct resource res;
};

struct pnp_protocol___2;

struct pnp_card___2 {
	struct device___157 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___2 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___2;

struct pnp_protocol___2 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___2 *);
	int (*set)(struct pnp_dev___2 *);
	int (*disable)(struct pnp_dev___2 *);
	bool (*can_wakeup)(struct pnp_dev___2 *);
	int (*suspend)(struct pnp_dev___2 *, pm_message_t);
	int (*resume)(struct pnp_dev___2 *);
	unsigned char number;
	struct device___157 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___2;

struct pnp_card_link___2 {
	struct pnp_card___2 *card;
	struct pnp_card_driver___2 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___2 {
	const char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___2 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___2 *);
	void (*shutdown)(struct pnp_dev___2 *);
	int (*suspend)(struct pnp_dev___2 *, pm_message_t);
	int (*resume)(struct pnp_dev___2 *);
	struct device_driver___157 driver;
};

struct pnp_card_driver___2 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___2 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___2 *);
	int (*suspend)(struct pnp_card_link___2 *, pm_message_t);
	int (*resume)(struct pnp_card_link___2 *);
	struct pnp_driver___2 link;
};

struct pnp_dev___2 {
	struct device___157 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___2 *protocol;
	struct pnp_card___2 *card;
	struct pnp_driver___2 *driver;
	struct pnp_card_link___2 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_port {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t size;
	unsigned char flags;
};

typedef struct {
	long unsigned int bits[4];
} pnp_irq_mask_t;

struct pnp_irq {
	pnp_irq_mask_t map;
	unsigned char flags;
};

struct pnp_dma {
	unsigned char map;
	unsigned char flags;
};

struct pnp_mem {
	resource_size_t min;
	resource_size_t max;
	resource_size_t align;
	resource_size_t size;
	unsigned char flags;
};

struct pnp_option {
	struct list_head list;
	unsigned int flags;
	long unsigned int type;
	union {
		struct pnp_port port;
		struct pnp_irq irq;
		struct pnp_dma dma;
		struct pnp_mem mem;
	} u;
};

struct pnp_protocol___3;

struct pnp_card___3 {
	struct device___139 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___3 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___3;

struct pnp_protocol___3 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___3 *);
	int (*set)(struct pnp_dev___3 *);
	int (*disable)(struct pnp_dev___3 *);
	bool (*can_wakeup)(struct pnp_dev___3 *);
	int (*suspend)(struct pnp_dev___3 *, pm_message_t);
	int (*resume)(struct pnp_dev___3 *);
	unsigned char number;
	struct device___139 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___3;

struct pnp_card_link___3 {
	struct pnp_card___3 *card;
	struct pnp_card_driver___3 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___3 {
	const char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___3 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___3 *);
	void (*shutdown)(struct pnp_dev___3 *);
	int (*suspend)(struct pnp_dev___3 *, pm_message_t);
	int (*resume)(struct pnp_dev___3 *);
	struct device_driver___139 driver;
};

struct pnp_card_driver___3 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___3 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___3 *);
	int (*suspend)(struct pnp_card_link___3 *, pm_message_t);
	int (*resume)(struct pnp_card_link___3 *);
	struct pnp_driver___3 link;
};

struct pnp_dev___3 {
	struct device___139 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___3 *protocol;
	struct pnp_card___3 *card;
	struct pnp_driver___3 *driver;
	struct pnp_card_link___3 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct pnp_info_buffer {
	char *buffer;
	char *curr;
	long unsigned int size;
	long unsigned int len;
	int stop;
	int error;
};

typedef struct pnp_info_buffer pnp_info_buffer_t;

struct pnp_fixup {
	char id[7];
	void (*quirk_function)(struct pnp_dev___2 *);
};

struct acpipnp_parse_option_s {
	struct pnp_dev___2 *dev;
	unsigned int option_flags;
};

struct device_attribute___15 {
	struct attribute attr;
	ssize_t (*show)(struct device___156 *, struct device_attribute___15 *, char *);
	ssize_t (*store)(struct device___156 *, struct device_attribute___15 *, const char *, size_t);
};

struct amba_driver___2 {
	struct device_driver___156 drv;
	int (*probe)(struct amba_device___2 *, const struct amba_id *);
	void (*remove)(struct amba_device___2 *);
	void (*shutdown)(struct amba_device___2 *);
	const struct amba_id *id_table;
};

struct deferred_device {
	struct amba_device___2 *dev;
	struct resource *parent;
	struct list_head node;
};

struct find_data {
	struct amba_device___2 *dev;
	struct device___156 *parent;
	const char *busid;
	unsigned int id;
	unsigned int mask;
};

struct tegra_ahb {
	void *regs;
	struct device___157 *dev;
	u32 ctx[0];
};

typedef void (*dr_release_t___14)(struct device___139 *, void *);

typedef int (*dr_match_t___13)(struct device___139 *, void *, void *);

struct clk_bulk_devres {
	struct clk_bulk_data *clks;
	int num_clks;
};

typedef void (*dr_release_t___15)(struct device___157 *, void *);

typedef int (*dr_match_t___14)(struct device___157 *, void *, void *);

struct clk_hw;

struct clk_lookup {
	struct list_head node;
	const char *dev_id;
	const char *con_id;
	struct clk *clk;
	struct clk_hw *clk_hw;
};

struct clk_core___2;

struct clk_init_data;

struct clk_hw {
	struct clk_core___2 *core;
	struct clk *clk;
	const struct clk_init_data *init;
};

struct clk_rate_request {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw *best_parent_hw;
};

struct clk_duty {
	unsigned int num;
	unsigned int den;
};

struct clk_ops {
	int (*prepare)(struct clk_hw *);
	void (*unprepare)(struct clk_hw *);
	int (*is_prepared)(struct clk_hw *);
	void (*unprepare_unused)(struct clk_hw *);
	int (*enable)(struct clk_hw *);
	void (*disable)(struct clk_hw *);
	int (*is_enabled)(struct clk_hw *);
	void (*disable_unused)(struct clk_hw *);
	int (*save_context)(struct clk_hw *);
	void (*restore_context)(struct clk_hw *);
	long unsigned int (*recalc_rate)(struct clk_hw *, long unsigned int);
	long int (*round_rate)(struct clk_hw *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw *, struct clk_rate_request *);
	int (*set_parent)(struct clk_hw *, u8);
	u8 (*get_parent)(struct clk_hw *);
	int (*set_rate)(struct clk_hw *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw *, long unsigned int);
	int (*get_phase)(struct clk_hw *);
	int (*set_phase)(struct clk_hw *, int);
	int (*get_duty_cycle)(struct clk_hw *, struct clk_duty *);
	int (*set_duty_cycle)(struct clk_hw *, struct clk_duty *);
	int (*init)(struct clk_hw *);
	void (*terminate)(struct clk_hw *);
	void (*debug_init)(struct clk_hw *, struct dentry___196 *);
};

struct clk_parent_data {
	const struct clk_hw *hw;
	const char *fw_name;
	const char *name;
	int index;
};

struct clk_init_data {
	const char *name;
	const struct clk_ops *ops;
	const char * const *parent_names;
	const struct clk_parent_data *parent_data;
	const struct clk_hw **parent_hws;
	u8 num_parents;
	long unsigned int flags;
};

struct clk_lookup_alloc {
	struct clk_lookup cl;
	char dev_id[20];
	char con_id[16];
};

struct clk_notifier {
	struct clk *clk;
	struct srcu_notifier_head notifier_head;
	struct list_head node;
};

struct clk_notifier_data {
	struct clk *clk;
	long unsigned int old_rate;
	long unsigned int new_rate;
};

struct of_phandle_args___22 {
	struct device_node *np;
	int args_count;
	uint32_t args[16];
};

struct clk_hw___2;

struct clk_rate_request___2 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___2 *best_parent_hw;
};

struct clk_init_data___2;

struct clk_hw___2 {
	struct clk_core *core;
	struct clk *clk;
	const struct clk_init_data___2 *init;
};

struct clk_ops___2 {
	int (*prepare)(struct clk_hw___2 *);
	void (*unprepare)(struct clk_hw___2 *);
	int (*is_prepared)(struct clk_hw___2 *);
	void (*unprepare_unused)(struct clk_hw___2 *);
	int (*enable)(struct clk_hw___2 *);
	void (*disable)(struct clk_hw___2 *);
	int (*is_enabled)(struct clk_hw___2 *);
	void (*disable_unused)(struct clk_hw___2 *);
	int (*save_context)(struct clk_hw___2 *);
	void (*restore_context)(struct clk_hw___2 *);
	long unsigned int (*recalc_rate)(struct clk_hw___2 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___2 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___2 *, struct clk_rate_request___2 *);
	int (*set_parent)(struct clk_hw___2 *, u8);
	u8 (*get_parent)(struct clk_hw___2 *);
	int (*set_rate)(struct clk_hw___2 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___2 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___2 *, long unsigned int);
	int (*get_phase)(struct clk_hw___2 *);
	int (*set_phase)(struct clk_hw___2 *, int);
	int (*get_duty_cycle)(struct clk_hw___2 *, struct clk_duty *);
	int (*set_duty_cycle)(struct clk_hw___2 *, struct clk_duty *);
	int (*init)(struct clk_hw___2 *);
	void (*terminate)(struct clk_hw___2 *);
	void (*debug_init)(struct clk_hw___2 *, struct dentry *);
};

struct clk_parent_data___2 {
	const struct clk_hw___2 *hw;
	const char *fw_name;
	const char *name;
	int index;
};

struct clk_init_data___2 {
	const char *name;
	const struct clk_ops___2 *ops;
	const char * const *parent_names;
	const struct clk_parent_data___2 *parent_data;
	const struct clk_hw___2 **parent_hws;
	u8 num_parents;
	long unsigned int flags;
};

struct clk_parent_map;

struct clk_core {
	const char *name;
	const struct clk_ops___2 *ops;
	struct clk_hw___2 *hw;
	struct module *owner;
	struct device *dev;
	struct device_node *of_node;
	struct clk_core *parent;
	struct clk_parent_map *parents;
	u8 num_parents;
	u8 new_parent_index;
	long unsigned int rate;
	long unsigned int req_rate;
	long unsigned int new_rate;
	struct clk_core *new_parent;
	struct clk_core *new_child;
	long unsigned int flags;
	bool orphan;
	bool rpm_enabled;
	unsigned int enable_count;
	unsigned int prepare_count;
	unsigned int protect_count;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int accuracy;
	int phase;
	struct clk_duty duty;
	struct hlist_head children;
	struct hlist_node child_node;
	struct hlist_head clks;
	unsigned int notifier_count;
	struct dentry *dentry;
	struct hlist_node debug_node;
	struct kref ref;
};

struct clk_onecell_data {
	struct clk **clks;
	unsigned int clk_num;
};

struct clk_hw_onecell_data {
	unsigned int num;
	struct clk_hw___2 *hws[0];
};

typedef void (*dr_release_t___16)(struct device *, void *);

typedef int (*dr_match_t___15)(struct device *, void *, void *);

struct clk_parent_map {
	const struct clk_hw___2 *hw;
	struct clk_core *core;
	const char *fw_name;
	const char *name;
	int index;
};

struct trace_event_raw_clk {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_clk_rate {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int rate;
	char __data[0];
};

struct trace_event_raw_clk_rate_range {
	struct trace_entry ent;
	u32 __data_loc_name;
	long unsigned int min;
	long unsigned int max;
	char __data[0];
};

struct trace_event_raw_clk_parent {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_pname;
	char __data[0];
};

struct trace_event_raw_clk_phase {
	struct trace_entry ent;
	u32 __data_loc_name;
	int phase;
	char __data[0];
};

struct trace_event_raw_clk_duty_cycle {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int num;
	unsigned int den;
	char __data[0];
};

struct trace_event_data_offsets_clk {
	u32 name;
};

struct trace_event_data_offsets_clk_rate {
	u32 name;
};

struct trace_event_data_offsets_clk_rate_range {
	u32 name;
};

struct trace_event_data_offsets_clk_parent {
	u32 name;
	u32 pname;
};

struct trace_event_data_offsets_clk_phase {
	u32 name;
};

struct trace_event_data_offsets_clk_duty_cycle {
	u32 name;
};

typedef void (*btf_trace_clk_enable)(void *, struct clk_core *);

typedef void (*btf_trace_clk_enable_complete)(void *, struct clk_core *);

typedef void (*btf_trace_clk_disable)(void *, struct clk_core *);

typedef void (*btf_trace_clk_disable_complete)(void *, struct clk_core *);

typedef void (*btf_trace_clk_prepare)(void *, struct clk_core *);

typedef void (*btf_trace_clk_prepare_complete)(void *, struct clk_core *);

typedef void (*btf_trace_clk_unprepare)(void *, struct clk_core *);

typedef void (*btf_trace_clk_unprepare_complete)(void *, struct clk_core *);

typedef void (*btf_trace_clk_set_rate)(void *, struct clk_core *, long unsigned int);

typedef void (*btf_trace_clk_set_rate_complete)(void *, struct clk_core *, long unsigned int);

typedef void (*btf_trace_clk_set_min_rate)(void *, struct clk_core *, long unsigned int);

typedef void (*btf_trace_clk_set_max_rate)(void *, struct clk_core *, long unsigned int);

typedef void (*btf_trace_clk_set_rate_range)(void *, struct clk_core *, long unsigned int, long unsigned int);

typedef void (*btf_trace_clk_set_parent)(void *, struct clk_core *, struct clk_core *);

typedef void (*btf_trace_clk_set_parent_complete)(void *, struct clk_core *, struct clk_core *);

typedef void (*btf_trace_clk_set_phase)(void *, struct clk_core *, int);

typedef void (*btf_trace_clk_set_phase_complete)(void *, struct clk_core *, int);

typedef void (*btf_trace_clk_set_duty_cycle)(void *, struct clk_core *, struct clk_duty *);

typedef void (*btf_trace_clk_set_duty_cycle_complete)(void *, struct clk_core *, struct clk_duty *);

struct clk_notifier_devres {
	struct clk *clk;
	struct notifier_block *nb;
};

struct of_clk_provider {
	struct list_head link;
	struct device_node *node;
	struct clk * (*get)(struct of_phandle_args___22 *, void *);
	struct clk_hw___2 * (*get_hw)(struct of_phandle_args___22 *, void *);
	void *data;
};

struct clock_provider {
	void (*clk_init_cb)(struct device_node *);
	struct device_node *np;
	struct list_head node;
};

struct clk_div_table {
	unsigned int val;
	unsigned int div;
};

struct clk_divider {
	struct clk_hw hw;
	void *reg;
	u8 shift;
	u8 width;
	u8 flags;
	const struct clk_div_table *table;
	spinlock_t *lock;
};

typedef void (*of_init_fn_1)(struct device_node___60 *);

struct clk_fixed_factor {
	struct clk_hw hw;
	unsigned int mult;
	unsigned int div;
};

struct clk_fixed_rate {
	struct clk_hw hw;
	long unsigned int fixed_rate;
	long unsigned int fixed_accuracy;
	long unsigned int flags;
};

struct clk_hw___3;

struct clk_rate_request___3 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___3 *best_parent_hw;
};

struct clk_init_data___3;

struct clk_hw___3 {
	struct clk_core___2 *core;
	struct clk *clk;
	const struct clk_init_data___3 *init;
};

struct clk_ops___3 {
	int (*prepare)(struct clk_hw___3 *);
	void (*unprepare)(struct clk_hw___3 *);
	int (*is_prepared)(struct clk_hw___3 *);
	void (*unprepare_unused)(struct clk_hw___3 *);
	int (*enable)(struct clk_hw___3 *);
	void (*disable)(struct clk_hw___3 *);
	int (*is_enabled)(struct clk_hw___3 *);
	void (*disable_unused)(struct clk_hw___3 *);
	int (*save_context)(struct clk_hw___3 *);
	void (*restore_context)(struct clk_hw___3 *);
	long unsigned int (*recalc_rate)(struct clk_hw___3 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___3 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___3 *, struct clk_rate_request___3 *);
	int (*set_parent)(struct clk_hw___3 *, u8);
	u8 (*get_parent)(struct clk_hw___3 *);
	int (*set_rate)(struct clk_hw___3 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___3 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___3 *, long unsigned int);
	int (*get_phase)(struct clk_hw___3 *);
	int (*set_phase)(struct clk_hw___3 *, int);
	int (*get_duty_cycle)(struct clk_hw___3 *, struct clk_duty *);
	int (*set_duty_cycle)(struct clk_hw___3 *, struct clk_duty *);
	int (*init)(struct clk_hw___3 *);
	void (*terminate)(struct clk_hw___3 *);
	void (*debug_init)(struct clk_hw___3 *, struct dentry___182 *);
};

struct clk_parent_data___3 {
	const struct clk_hw___3 *hw;
	const char *fw_name;
	const char *name;
	int index;
};

struct clk_init_data___3 {
	const char *name;
	const struct clk_ops___3 *ops;
	const char * const *parent_names;
	const struct clk_parent_data___3 *parent_data;
	const struct clk_hw___3 **parent_hws;
	u8 num_parents;
	long unsigned int flags;
};

struct clk_gate {
	struct clk_hw___3 hw;
	void *reg;
	u8 bit_idx;
	u8 flags;
	spinlock_t *lock;
};

struct clk_multiplier {
	struct clk_hw___3 hw;
	void *reg;
	u8 shift;
	u8 width;
	u8 flags;
	spinlock_t *lock;
};

struct clk_mux {
	struct clk_hw hw;
	void *reg;
	u32 *table;
	u32 mask;
	u8 shift;
	u8 flags;
	spinlock_t *lock;
};

struct clk_composite {
	struct clk_hw___3 hw;
	struct clk_ops___3 ops;
	struct clk_hw___3 *mux_hw;
	struct clk_hw___3 *rate_hw;
	struct clk_hw___3 *gate_hw;
	const struct clk_ops___3 *mux_ops;
	const struct clk_ops___3 *rate_ops;
	const struct clk_ops___3 *gate_ops;
};

struct clk_fractional_divider {
	struct clk_hw hw;
	void *reg;
	u8 mshift;
	u8 mwidth;
	u32 mmask;
	u8 nshift;
	u8 nwidth;
	u32 nmask;
	u8 flags;
	void (*approximation)(struct clk_hw *, long unsigned int, long unsigned int *, long unsigned int *, long unsigned int *);
	spinlock_t *lock;
};

struct of_phandle_args___23 {
	struct device_node___23 *np;
	int args_count;
	uint32_t args[16];
};

struct clk_gpio {
	struct clk_hw___3 hw;
	struct gpio_desc *gpiod;
};

struct clk_gate___2 {
	struct clk_hw hw;
	void *reg;
	u8 bit_idx;
	u8 flags;
	spinlock_t *lock;
};

struct clk_hw_onecell_data___2 {
	unsigned int num;
	struct clk_hw *hws[0];
};

struct bm1880_clock_data {
	void *pll_base;
	void *sys_base;
	struct clk_hw_onecell_data___2 hw_data;
};

struct bm1880_gate_clock {
	unsigned int id;
	const char *name;
	const char *parent;
	u32 gate_reg;
	s8 gate_shift;
	long unsigned int flags;
};

struct bm1880_mux_clock {
	unsigned int id;
	const char *name;
	const char * const *parents;
	s8 num_parents;
	u32 reg;
	s8 shift;
	long unsigned int flags;
};

struct bm1880_div_clock {
	unsigned int id;
	const char *name;
	u32 reg;
	u8 shift;
	u8 width;
	u32 initval;
	const struct clk_div_table *table;
	long unsigned int flags;
};

struct bm1880_div_hw_clock {
	struct bm1880_div_clock div;
	void *base;
	spinlock_t *lock;
	struct clk_hw hw;
	struct clk_init_data init;
};

struct bm1880_composite_clock {
	unsigned int id;
	const char *name;
	const char *parent;
	const char * const *parents;
	unsigned int num_parents;
	long unsigned int flags;
	u32 gate_reg;
	u32 mux_reg;
	u32 div_reg;
	s8 gate_shift;
	s8 mux_shift;
	s8 div_shift;
	s8 div_width;
	s16 div_initval;
	const struct clk_div_table *table;
};

struct bm1880_pll_clock {
	unsigned int id;
	const char *name;
	u32 reg;
	long unsigned int flags;
};

struct bm1880_pll_hw_clock {
	struct bm1880_pll_clock pll;
	void *base;
	struct clk_hw hw;
	struct clk_init_data init;
};

struct s5_hw_clk {
	struct clk_hw hw;
	void *reg;
};

struct s5_clk_data {
	void *base;
	struct s5_hw_clk s5_hw[9];
};

struct s5_pll_conf {
	long unsigned int freq;
	u8 div;
	bool rot_ena;
	u8 rot_sel;
	u8 rot_dir;
	u8 pre_div;
};

struct fsl_sai_clk {
	struct clk_divider div;
	struct clk_gate___2 gate;
	spinlock_t lock;
};

typedef void (*of_init_fn_1___2)(struct device_node___61 *);

struct clk_hw___4;

struct clk_rate_request___4 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___4 *best_parent_hw;
};

struct clk_init_data___4;

struct clk_hw___4 {
	struct clk_core___2 *core;
	struct clk *clk;
	const struct clk_init_data___4 *init;
};

struct clk_ops___4 {
	int (*prepare)(struct clk_hw___4 *);
	void (*unprepare)(struct clk_hw___4 *);
	int (*is_prepared)(struct clk_hw___4 *);
	void (*unprepare_unused)(struct clk_hw___4 *);
	int (*enable)(struct clk_hw___4 *);
	void (*disable)(struct clk_hw___4 *);
	int (*is_enabled)(struct clk_hw___4 *);
	void (*disable_unused)(struct clk_hw___4 *);
	int (*save_context)(struct clk_hw___4 *);
	void (*restore_context)(struct clk_hw___4 *);
	long unsigned int (*recalc_rate)(struct clk_hw___4 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___4 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___4 *, struct clk_rate_request___4 *);
	int (*set_parent)(struct clk_hw___4 *, u8);
	u8 (*get_parent)(struct clk_hw___4 *);
	int (*set_rate)(struct clk_hw___4 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___4 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___4 *, long unsigned int);
	int (*get_phase)(struct clk_hw___4 *);
	int (*set_phase)(struct clk_hw___4 *, int);
	int (*get_duty_cycle)(struct clk_hw___4 *, struct clk_duty *);
	int (*set_duty_cycle)(struct clk_hw___4 *, struct clk_duty *);
	int (*init)(struct clk_hw___4 *);
	void (*terminate)(struct clk_hw___4 *);
	void (*debug_init)(struct clk_hw___4 *, struct dentry___195 *);
};

struct clk_parent_data___4 {
	const struct clk_hw___4 *hw;
	const char *fw_name;
	const char *name;
	int index;
};

struct clk_init_data___4 {
	const char *name;
	const struct clk_ops___4 *ops;
	const char * const *parent_names;
	const struct clk_parent_data___4 *parent_data;
	const struct clk_hw___4 **parent_hws;
	u8 num_parents;
	long unsigned int flags;
};

struct ccsr_guts {
	u32 porpllsr;
	u32 porbmsr;
	u32 porimpscr;
	u32 pordevsr;
	u32 pordbgmsr;
	u32 pordevsr2;
	u8 res018[8];
	u32 porcir;
	u8 res024[12];
	u32 gpiocr;
	u8 res034[12];
	u32 gpoutdr;
	u8 res044[12];
	u32 gpindr;
	u8 res054[12];
	u32 pmuxcr;
	u32 pmuxcr2;
	u32 dmuxcr;
	u8 res06c[4];
	u32 devdisr;
	u32 devdisr2;
	u8 res078[4];
	u32 pmjcr;
	u32 powmgtcsr;
	u32 pmrccr;
	u32 pmpdccr;
	u32 pmcdr;
	u32 mcpsumr;
	u32 rstrscr;
	u32 ectrstcr;
	u32 autorstsr;
	u32 pvr;
	u32 svr;
	u8 res0a8[8];
	u32 rstcr;
	u8 res0b4[12];
	u32 iovselsr;
	u8 res0c4[60];
	u32 rcwsr[16];
	u8 res140[228];
	u32 iodelay1;
	u32 iodelay2;
	u8 res22c[984];
	u32 pamubypenr;
	u8 res608[504];
	u32 clkdvdr;
	u8 res804[252];
	u32 ircr;
	u8 res904[4];
	u32 dmacr;
	u8 res90c[8];
	u32 elbccr;
	u8 res918[520];
	u32 ddr1clkdr;
	u32 ddr2clkdr;
	u32 ddrclkdr;
	u8 resb2c[724];
	u32 clkocr;
	u8 rese04[12];
	u32 ddrdllcr;
	u8 rese14[12];
	u32 lbcdllcr;
	u32 cpfor;
	u8 rese28[220];
	u32 srds1cr0;
	u32 srds1cr1;
	u8 resf0c[32];
	u32 itcr;
	u8 resf30[16];
	u32 srds2cr0;
	u32 srds2cr1;
};

struct clockgen_pll_div {
	struct clk *clk;
	char name[32];
};

struct clockgen_pll {
	struct clockgen_pll_div div[32];
};

struct clockgen_sourceinfo {
	u32 flags;
	int pll;
	int div;
};

struct clockgen_muxinfo {
	struct clockgen_sourceinfo clksel[16];
};

struct clockgen;

struct clockgen_chipinfo {
	const char *compat;
	const char *guts_compat;
	const struct clockgen_muxinfo *cmux_groups[2];
	const struct clockgen_muxinfo *hwaccel[5];
	void (*init_periph)(struct clockgen *);
	int cmux_to_group[9];
	u32 pll_mask;
	u32 flags;
};

struct clockgen {
	struct device_node___61 *node;
	void *regs;
	struct clockgen_chipinfo info;
	struct clk *sysclk;
	struct clk *coreclk;
	struct clockgen_pll pll[6];
	struct clk *cmux[8];
	struct clk *hwaccel[5];
	struct clk *fman[2];
	struct ccsr_guts *guts;
};

struct mux_hwclock {
	struct clk_hw___4 hw;
	struct clockgen *cg;
	const struct clockgen_muxinfo *info;
	u32 *reg;
	u8 parent_to_clksel[16];
	s8 clksel_to_parent[16];
	int num_parents;
};

struct property___48 {
	char *name;
	int length;
	void *value;
	struct property___48 *next;
	long unsigned int _flags;
	struct bin_attribute___155 attr;
};

struct device_node___62 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___158 fwnode;
	struct property___48 *properties;
	struct property___48 *deadprops;
	struct device_node___62 *parent;
	struct device_node___62 *child;
	struct device_node___62 *sibling;
	struct kobject___155 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___24 {
	struct device_node___62 *np;
	int args_count;
	uint32_t args[16];
};

typedef void (*of_init_fn_1___3)(struct device_node___62 *);

struct clk_init_data___5;

struct clk_hw___5 {
	struct clk_core___2 *core;
	struct clk *clk;
	const struct clk_init_data___5 *init;
};

struct clk_rate_request___5 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___5 *best_parent_hw;
};

struct clk_ops___5 {
	int (*prepare)(struct clk_hw___5 *);
	void (*unprepare)(struct clk_hw___5 *);
	int (*is_prepared)(struct clk_hw___5 *);
	void (*unprepare_unused)(struct clk_hw___5 *);
	int (*enable)(struct clk_hw___5 *);
	void (*disable)(struct clk_hw___5 *);
	int (*is_enabled)(struct clk_hw___5 *);
	void (*disable_unused)(struct clk_hw___5 *);
	int (*save_context)(struct clk_hw___5 *);
	void (*restore_context)(struct clk_hw___5 *);
	long unsigned int (*recalc_rate)(struct clk_hw___5 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___5 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___5 *, struct clk_rate_request___5 *);
	int (*set_parent)(struct clk_hw___5 *, u8);
	u8 (*get_parent)(struct clk_hw___5 *);
	int (*set_rate)(struct clk_hw___5 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___5 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___5 *, long unsigned int);
	int (*get_phase)(struct clk_hw___5 *);
	int (*set_phase)(struct clk_hw___5 *, int);
	int (*get_duty_cycle)(struct clk_hw___5 *, struct clk_duty *);
	int (*set_duty_cycle)(struct clk_hw___5 *, struct clk_duty *);
	int (*init)(struct clk_hw___5 *);
	void (*terminate)(struct clk_hw___5 *);
	void (*debug_init)(struct clk_hw___5 *, struct dentry___168 *);
};

struct clk_parent_data___5 {
	const struct clk_hw___5 *hw;
	const char *fw_name;
	const char *name;
	int index;
};

struct clk_init_data___5 {
	const char *name;
	const struct clk_ops___5 *ops;
	const char * const *parent_names;
	const struct clk_parent_data___5 *parent_data;
	const struct clk_hw___5 **parent_hws;
	u8 num_parents;
	long unsigned int flags;
};

enum xgene_pll_type {
	PLL_TYPE_PCP = 0,
	PLL_TYPE_SOC = 1,
};

struct xgene_clk_pll {
	struct clk_hw___5 hw;
	void *reg;
	spinlock_t *lock;
	u32 pll_offset;
	enum xgene_pll_type type;
	int version;
};

struct xgene_clk_pmd {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u32 mask;
	u64 denom;
	u32 flags;
	spinlock_t *lock;
};

struct xgene_dev_parameters {
	void *csr_reg;
	u32 reg_clk_offset;
	u32 reg_clk_mask;
	u32 reg_csr_offset;
	u32 reg_csr_mask;
	void *divider_reg;
	u32 reg_divider_offset;
	u32 reg_divider_shift;
	u32 reg_divider_width;
};

struct xgene_clk {
	struct clk_hw___5 hw;
	spinlock_t *lock;
	struct xgene_dev_parameters param;
};

struct owl_clk_common {
	struct regmap *regmap;
	struct clk_hw___5 hw;
};

struct owl_reset_map;

struct owl_clk_desc {
	struct owl_clk_common **clks;
	long unsigned int num_clks;
	struct clk_hw_onecell_data___2 *hw_clks;
	const struct owl_reset_map *resets;
	long unsigned int num_resets;
	struct regmap *regmap;
};

struct owl_reset_map {
	u32 reg;
	u32 bit;
};

struct owl_gate_hw {
	u32 reg;
	u8 bit_idx;
	u8 gate_flags;
};

struct owl_gate {
	struct owl_gate_hw gate_hw;
	struct owl_clk_common common;
};

struct owl_mux_hw {
	u32 reg;
	u8 shift;
	u8 width;
};

struct owl_mux {
	struct owl_mux_hw mux_hw;
	struct owl_clk_common common;
};

struct owl_divider_hw {
	u32 reg;
	u8 shift;
	u8 width;
	u8 div_flags;
	struct clk_div_table *table;
};

struct owl_divider {
	struct owl_divider_hw div_hw;
	struct owl_clk_common common;
};

struct clk_factor_table {
	unsigned int val;
	unsigned int mul;
	unsigned int div;
};

struct owl_factor_hw {
	u32 reg;
	u8 shift;
	u8 width;
	u8 fct_flags;
	struct clk_factor_table *table;
};

struct owl_factor {
	struct owl_factor_hw factor_hw;
	struct owl_clk_common common;
};

union owl_rate {
	struct owl_divider_hw div_hw;
	struct owl_factor_hw factor_hw;
	struct clk_fixed_factor fix_fact_hw;
};

struct owl_composite {
	struct owl_mux_hw mux_hw;
	struct owl_gate_hw gate_hw;
	union owl_rate rate;
	const struct clk_ops___5 *fix_fact_ops;
	struct owl_clk_common common;
};

struct clk_pll_table {
	unsigned int val;
	long unsigned int rate;
};

struct owl_pll_hw {
	u32 reg;
	u32 bfreq;
	u8 bit_idx;
	u8 shift;
	u8 width;
	u8 min_mul;
	u8 max_mul;
	u8 delay;
	const struct clk_pll_table *table;
};

struct owl_pll {
	struct owl_pll_hw pll_hw;
	struct owl_clk_common common;
};

struct reset_controller_dev;

struct reset_control_ops {
	int (*reset)(struct reset_controller_dev *, long unsigned int);
	int (*assert)(struct reset_controller_dev *, long unsigned int);
	int (*deassert)(struct reset_controller_dev *, long unsigned int);
	int (*status)(struct reset_controller_dev *, long unsigned int);
};

struct of_phandle_args___25;

struct reset_controller_dev {
	const struct reset_control_ops *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___9 *dev;
	struct device_node___2 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev *, const struct of_phandle_args___25 *);
	unsigned int nr_resets;
};

struct of_phandle_args___25 {
	struct device_node___24 *np;
	int args_count;
	uint32_t args[16];
};

struct owl_reset {
	struct reset_controller_dev rcdev;
	const struct owl_reset_map *reset_map;
	struct regmap *regmap;
};

struct reset_controller_dev___2;

struct reset_control_ops___2 {
	int (*reset)(struct reset_controller_dev___2 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___2 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___2 *, long unsigned int);
	int (*status)(struct reset_controller_dev___2 *, long unsigned int);
};

struct reset_controller_dev___2 {
	const struct reset_control_ops___2 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___139 *dev;
	struct device_node___41 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___2 *, const struct of_phandle_args___18 *);
	unsigned int nr_resets;
};

struct owl_reset___2 {
	struct reset_controller_dev___2 rcdev;
	const struct owl_reset_map *reset_map;
	struct regmap *regmap;
};

enum iproc_arm_pll_fid {
	ARM_PLL_FID_CRYSTAL_CLK = 0,
	ARM_PLL_FID_SYS_CLK = 2,
	ARM_PLL_FID_CH0_SLOW_CLK = 6,
	ARM_PLL_FID_CH1_FAST_CLK = 7,
};

struct iproc_arm_pll {
	struct clk_hw___5 hw;
	void *base;
	long unsigned int rate;
};

struct iproc_pll_vco_param {
	long unsigned int rate;
	unsigned int ndiv_int;
	unsigned int ndiv_frac;
	unsigned int pdiv;
};

struct iproc_clk_reg_op {
	unsigned int offset;
	unsigned int shift;
	unsigned int width;
};

struct iproc_asiu_gate {
	unsigned int offset;
	unsigned int en_shift;
};

struct iproc_pll_aon_pwr_ctrl {
	unsigned int offset;
	unsigned int pwr_width;
	unsigned int pwr_shift;
	unsigned int iso_shift;
};

struct iproc_pll_reset_ctrl {
	unsigned int offset;
	unsigned int reset_shift;
	unsigned int p_reset_shift;
};

struct iproc_pll_dig_filter_ctrl {
	unsigned int offset;
	unsigned int ki_shift;
	unsigned int ki_width;
	unsigned int kp_shift;
	unsigned int kp_width;
	unsigned int ka_shift;
	unsigned int ka_width;
};

struct iproc_pll_sw_ctrl {
	unsigned int offset;
	unsigned int shift;
};

struct iproc_pll_vco_ctrl {
	unsigned int u_offset;
	unsigned int l_offset;
};

struct iproc_pll_ctrl {
	long unsigned int flags;
	struct iproc_pll_aon_pwr_ctrl aon;
	struct iproc_asiu_gate asiu;
	struct iproc_pll_reset_ctrl reset;
	struct iproc_pll_dig_filter_ctrl dig_filter;
	struct iproc_pll_sw_ctrl sw_ctrl;
	struct iproc_clk_reg_op ndiv_int;
	struct iproc_clk_reg_op ndiv_frac;
	struct iproc_clk_reg_op pdiv;
	struct iproc_pll_vco_ctrl vco_ctrl;
	struct iproc_clk_reg_op status;
	struct iproc_clk_reg_op macro_mode;
};

struct iproc_clk_enable_ctrl {
	unsigned int offset;
	unsigned int enable_shift;
	unsigned int hold_shift;
	unsigned int bypass_shift;
};

struct iproc_clk_ctrl {
	unsigned int channel;
	long unsigned int flags;
	struct iproc_clk_enable_ctrl enable;
	struct iproc_clk_reg_op mdiv;
};

enum kp_band {
	KP_BAND_MID = 0,
	KP_BAND_HIGH = 1,
	KP_BAND_HIGH_HIGH = 2,
};

enum vco_freq_range {
	VCO_LOW = 700000000,
	VCO_MID = 1200000000,
	VCO_HIGH = 2200000000,
	VCO_HIGH_HIGH = 3100000000,
	VCO_MAX = 4000000000,
};

struct iproc_pll {
	void *status_base;
	void *control_base;
	void *pwr_base;
	void *asiu_base;
	const struct iproc_pll_ctrl *ctrl;
	const struct iproc_pll_vco_param *vco_param;
	unsigned int num_vco_entries;
};

struct iproc_clk {
	struct clk_hw___5 hw;
	struct iproc_pll *pll;
	const struct iproc_clk_ctrl *ctrl;
};

struct iproc_asiu_div {
	unsigned int offset;
	unsigned int en_shift;
	unsigned int high_shift;
	unsigned int high_width;
	unsigned int low_shift;
	unsigned int low_width;
};

struct iproc_asiu;

struct iproc_asiu_clk {
	struct clk_hw___5 hw;
	const char *name;
	struct iproc_asiu *asiu;
	long unsigned int rate;
	struct iproc_asiu_div div;
	struct iproc_asiu_gate gate;
};

struct iproc_asiu {
	void *div_base;
	void *gate_base;
	struct clk_hw_onecell_data___2 *clk_data;
	struct iproc_asiu_clk *clks;
};

struct bcm2835_cprman {
	struct device___157 *dev;
	void *regs;
	spinlock_t regs_lock;
	unsigned int soc;
	const char *real_parent_names[7];
	struct clk_hw_onecell_data___2 onecell;
};

struct cprman_plat_data {
	unsigned int soc;
};

struct bcm2835_pll_ana_bits;

struct bcm2835_pll_data {
	const char *name;
	u32 cm_ctrl_reg;
	u32 a2w_ctrl_reg;
	u32 frac_reg;
	u32 ana_reg_base;
	u32 reference_enable_mask;
	u32 lock_mask;
	u32 flags;
	const struct bcm2835_pll_ana_bits *ana;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int max_fb_rate;
};

struct bcm2835_pll_ana_bits {
	u32 mask0;
	u32 set0;
	u32 mask1;
	u32 set1;
	u32 mask3;
	u32 set3;
	u32 fb_prediv_mask;
};

struct bcm2835_pll_divider_data {
	const char *name;
	const char *source_pll;
	u32 cm_reg;
	u32 a2w_reg;
	u32 load_mask;
	u32 hold_mask;
	u32 fixed_divider;
	u32 flags;
};

struct bcm2835_clock_data {
	const char *name;
	const char * const *parents;
	int num_mux_parents;
	unsigned int set_rate_parent;
	u32 ctl_reg;
	u32 div_reg;
	u32 int_bits;
	u32 frac_bits;
	u32 flags;
	bool is_vpu_clock;
	bool is_mash_clock;
	bool low_jitter;
	u32 tcnt_mux;
};

struct bcm2835_gate_data {
	const char *name;
	const char *parent;
	u32 ctl_reg;
};

struct bcm2835_pll {
	struct clk_hw hw;
	struct bcm2835_cprman *cprman;
	const struct bcm2835_pll_data *data;
};

struct bcm2835_pll_divider {
	struct clk_divider div;
	struct bcm2835_cprman *cprman;
	const struct bcm2835_pll_divider_data *data;
};

struct bcm2835_clock {
	struct clk_hw hw;
	struct bcm2835_cprman *cprman;
	const struct bcm2835_clock_data *data;
};

struct bcm2835_clk_desc {
	struct clk_hw * (*clk_register)(struct bcm2835_cprman *, const void *);
	unsigned int supported;
	const void *data;
};

typedef void (*of_init_fn_1___4)(struct device_node___41 *);

struct berlin2_avpll_vco {
	struct clk_hw___5 hw;
	void *base;
	u8 flags;
};

struct berlin2_avpll_channel {
	struct clk_hw___5 hw;
	void *base;
	u8 flags;
	u8 index;
};

struct berlin2_pll_map {
	const u8 vcodiv[16];
	u8 mult;
	u8 fbdiv_shift;
	u8 rfdiv_shift;
	u8 divsel_shift;
};

struct berlin2_pll {
	struct clk_hw___5 hw;
	void *base;
	struct berlin2_pll_map map;
};

struct berlin2_div_map {
	u16 pll_select_offs;
	u16 pll_switch_offs;
	u16 div_select_offs;
	u16 div_switch_offs;
	u16 div3_switch_offs;
	u16 gate_offs;
	u8 pll_select_shift;
	u8 pll_switch_shift;
	u8 div_select_shift;
	u8 div_switch_shift;
	u8 div3_switch_shift;
	u8 gate_shift;
};

struct berlin2_div {
	struct clk_hw___5 hw;
	void *base;
	struct berlin2_div_map map;
	spinlock_t *lock;
};

struct hisi_clock_data {
	struct clk_onecell_data clk_data;
	void *base;
};

struct hisi_fixed_rate_clock {
	unsigned int id;
	char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int fixed_rate;
};

struct hisi_fixed_factor_clock {
	unsigned int id;
	char *name;
	const char *parent_name;
	long unsigned int mult;
	long unsigned int div;
	long unsigned int flags;
};

struct hisi_mux_clock {
	unsigned int id;
	const char *name;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u8 mux_flags;
	const u32 *table;
	const char *alias;
};

struct hisi_phase_clock {
	unsigned int id;
	const char *name;
	const char *parent_names;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u32 *phase_degrees;
	u32 *phase_regvals;
	u8 phase_num;
};

struct hisi_divider_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u8 div_flags;
	struct clk_div_table *table;
	const char *alias;
};

struct hi6220_divider_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int offset;
	u8 shift;
	u8 width;
	u32 mask_bit;
	const char *alias;
};

struct hisi_gate_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	long unsigned int offset;
	u8 bit_idx;
	u8 gate_flags;
	const char *alias;
};

struct clkgate_separated {
	struct clk_hw___5 hw;
	void *enable;
	u8 bit_idx;
	u8 flags;
	spinlock_t *lock;
};

struct hi6220_clk_divider {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u8 width;
	u32 mask;
	const struct clk_div_table *table;
	spinlock_t *lock;
};

struct clk_hisi_phase {
	struct clk_hw hw;
	void *reg;
	u32 *phase_degrees;
	u32 *phase_regvals;
	u8 phase_num;
	u32 mask;
	u8 shift;
	u8 flags;
	spinlock_t *lock;
};

struct hisi_crg_funcs {
	struct hisi_clock_data * (*register_clks)(struct platform_device___20 *);
	void (*unregister_clks)(struct platform_device___20 *);
};

struct hisi_reset_controller;

struct hisi_crg_dev {
	struct hisi_clock_data *clk_data;
	struct hisi_reset_controller *rstc;
	const struct hisi_crg_funcs *funcs;
};

struct hi3559av100_pll_clock {
	u32 id;
	const char *name;
	const char *parent_name;
	const u32 ctrl_reg1;
	const u8 frac_shift;
	const u8 frac_width;
	const u8 postdiv1_shift;
	const u8 postdiv1_width;
	const u8 postdiv2_shift;
	const u8 postdiv2_width;
	const u32 ctrl_reg2;
	const u8 fbdiv_shift;
	const u8 fbdiv_width;
	const u8 refdiv_shift;
	const u8 refdiv_width;
};

struct hi3559av100_clk_pll {
	struct clk_hw hw;
	u32 id;
	void *ctrl_reg1;
	u8 frac_shift;
	u8 frac_width;
	u8 postdiv1_shift;
	u8 postdiv1_width;
	u8 postdiv2_shift;
	u8 postdiv2_width;
	void *ctrl_reg2;
	u8 fbdiv_shift;
	u8 fbdiv_width;
	u8 refdiv_shift;
	u8 refdiv_width;
};

struct hisi_reset_controller___2 {
	spinlock_t lock;
	void *membase;
	struct reset_controller_dev___2 rcdev;
};

struct mbox_client___2 {
	struct device___39 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___2 *, void *);
	void (*tx_prepare)(struct mbox_client___2 *, void *);
	void (*tx_done)(struct mbox_client___2 *, void *, int);
};

struct mbox_chan___2;

struct hi6220_stub_clk {
	u32 id;
	struct device___39 *dev;
	struct clk_hw___5 hw;
	struct regmap *dfs_map;
	struct mbox_client___2 cl;
	struct mbox_chan___2 *mbox;
};

struct hi6220_mbox_msg {
	unsigned char type;
	unsigned char cmd;
	unsigned char obj;
	unsigned char src;
	unsigned char para[4];
};

union hi6220_mbox_data {
	unsigned int data[8];
	struct hi6220_mbox_msg msg;
};

struct hi3660_stub_clk_chan {
	struct mbox_client cl;
	struct mbox_chan___2 *mbox;
};

struct hi3660_stub_clk {
	unsigned int id;
	struct clk_hw___4 hw;
	unsigned int cmd;
	unsigned int msg[8];
	unsigned int rate;
};

struct of_phandle_args___26 {
	struct device_node___5 *np;
	int args_count;
	uint32_t args[16];
};

struct clk_divider___2 {
	struct clk_hw___5 hw;
	void *reg;
	u8 shift;
	u8 width;
	u8 flags;
	const struct clk_div_table *table;
	spinlock_t___2 *lock;
};

struct clk_mux___2 {
	struct clk_hw___5 hw;
	void *reg;
	u32 *table;
	u32 mask;
	u8 shift;
	u8 flags;
	spinlock_t___2 *lock;
};

struct clk_busy_divider {
	struct clk_divider___2 div;
	const struct clk_ops___5 *div_ops;
	void *reg;
	u8 shift;
};

struct clk_busy_mux {
	struct clk_mux___2 mux;
	const struct clk_ops___5 *mux_ops;
	void *reg;
	u8 shift;
};

struct clk_gate___3 {
	struct clk_hw___5 hw;
	void *reg;
	u8 bit_idx;
	u8 flags;
	spinlock_t___2 *lock;
};

struct clk_fractional_divider___2 {
	struct clk_hw___5 hw;
	void *reg;
	u8 mshift;
	u8 mwidth;
	u32 mmask;
	u8 nshift;
	u8 nwidth;
	u32 nmask;
	u8 flags;
	void (*approximation)(struct clk_hw___5 *, long unsigned int, long unsigned int *, long unsigned int *, long unsigned int *);
	spinlock_t___2 *lock;
};

struct clk_cpu {
	struct clk_hw___5 hw;
	struct clk *div;
	struct clk *mux;
	struct clk *pll;
	struct clk *step;
};

struct clk_divider_gate {
	struct clk_divider divider;
	u32 cached_val;
};

struct clk_fixup_div {
	struct clk_divider divider;
	const struct clk_ops___5 *ops;
	void (*fixup)(u32 *);
};

struct clk_fixup_mux {
	struct clk_mux mux;
	const struct clk_ops___5 *ops;
	void (*fixup)(u32 *);
};

struct clk_frac_pll {
	struct clk_hw___5 hw;
	void *base;
};

struct clk_gate2 {
	struct clk_hw___3 hw;
	void *reg;
	u8 bit_idx;
	u8 cgr_val;
	u8 cgr_mask;
	u8 flags;
	spinlock_t *lock;
	unsigned int *share_count;
};

struct clk_gate_exclusive {
	struct clk_gate___3 gate;
	u32 exclusive_mask;
};

struct clk_pfd {
	struct clk_hw___5 hw;
	void *reg;
	u8 idx;
};

struct clk_pfdv2 {
	struct clk_hw___5 hw;
	void *reg;
	u8 gate_bit;
	u8 vld_bit;
	u8 frac_off;
};

enum imx_pllv1_type {
	IMX_PLLV1_IMX1 = 0,
	IMX_PLLV1_IMX21 = 1,
	IMX_PLLV1_IMX25 = 2,
	IMX_PLLV1_IMX27 = 3,
	IMX_PLLV1_IMX31 = 4,
	IMX_PLLV1_IMX35 = 5,
};

struct clk_pllv1 {
	struct clk_hw___5 hw;
	void *base;
	enum imx_pllv1_type type;
};

struct clk_pllv2 {
	struct clk_hw___5 hw;
	void *base;
};

enum imx_pllv3_type {
	IMX_PLLV3_GENERIC = 0,
	IMX_PLLV3_SYS = 1,
	IMX_PLLV3_USB = 2,
	IMX_PLLV3_USB_VF610 = 3,
	IMX_PLLV3_AV = 4,
	IMX_PLLV3_ENET = 5,
	IMX_PLLV3_ENET_IMX7 = 6,
	IMX_PLLV3_SYS_VF610 = 7,
	IMX_PLLV3_DDR_IMX7 = 8,
	IMX_PLLV3_AV_IMX7 = 9,
};

struct clk_pllv3 {
	struct clk_hw___5 hw;
	void *base;
	u32 power_bit;
	bool powerup_set;
	u32 div_mask;
	u32 div_shift;
	long unsigned int ref_clock;
	u32 num_offset;
	u32 denom_offset;
};

struct clk_pllv3_vf610_mf {
	u32 mfi;
	u32 mfn;
	u32 mfd;
};

struct clk_pllv4 {
	struct clk_hw___5 hw;
	void *base;
};

enum imx_pll14xx_type {
	PLL_1416X = 0,
	PLL_1443X = 1,
};

struct imx_pll14xx_rate_table {
	unsigned int rate;
	unsigned int pdiv;
	unsigned int mdiv;
	unsigned int sdiv;
	unsigned int kdiv;
};

struct imx_pll14xx_clk {
	enum imx_pll14xx_type type;
	const struct imx_pll14xx_rate_table *rate_table;
	int rate_count;
	int flags;
};

struct clk_pll14xx {
	struct clk_hw___5 hw;
	void *base;
	enum imx_pll14xx_type type;
	const struct imx_pll14xx_rate_table *rate_table;
	int rate_count;
};

struct clk_sscg_pll_setup {
	int divr1;
	int divf1;
	int divr2;
	int divf2;
	int divq;
	int bypass;
	uint64_t vco1;
	uint64_t vco2;
	uint64_t fout;
	uint64_t ref;
	uint64_t ref_div1;
	uint64_t ref_div2;
	uint64_t fout_request;
	int fout_error;
};

struct clk_sscg_pll {
	struct clk_hw___5 hw;
	const struct clk_ops___5 ops;
	void *base;
	struct clk_sscg_pll_setup setup;
	u8 parent;
	u8 bypass1;
	u8 bypass2;
};

struct arm_smccc_quirk {
	int id;
	union {
		long unsigned int a6;
	} state;
};

struct fwnode_operations___159;

struct device___159;

struct fwnode_handle___159 {
	struct fwnode_handle___159 *secondary;
	const struct fwnode_operations___159 *ops;
	struct device___159 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___159;

struct fwnode_endpoint___159;

struct fwnode_operations___159 {
	struct fwnode_handle___159 * (*get)(struct fwnode_handle___159 *);
	void (*put)(struct fwnode_handle___159 *);
	bool (*device_is_available)(const struct fwnode_handle___159 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___159 *, const struct device___159 *);
	bool (*property_present)(const struct fwnode_handle___159 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___159 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___159 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___159 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*get_parent)(const struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*get_next_child_node)(const struct fwnode_handle___159 *, struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*get_named_child_node)(const struct fwnode_handle___159 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___159 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___159 *);
	struct fwnode_handle___159 * (*graph_get_next_endpoint)(const struct fwnode_handle___159 *, struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*graph_get_remote_endpoint)(const struct fwnode_handle___159 *);
	struct fwnode_handle___159 * (*graph_get_port_parent)(struct fwnode_handle___159 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___159 *, struct fwnode_endpoint___159 *);
	int (*add_links)(struct fwnode_handle___159 *);
};

struct wakeup_source___159;

struct pm_subsys_data___4;

struct dev_pm_info___159 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___159 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___4 *subsys_data;
	void (*set_latency_tolerance)(struct device___159 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___159;

struct bus_type___159;

struct device_driver___159;

struct dev_pm_domain___159;

struct device_node___63;

struct class___159;

struct device___159 {
	struct kobject___42 kobj;
	struct device___159 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___159 *type;
	struct bus_type___159 *bus;
	struct device_driver___159 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___159 power;
	struct dev_pm_domain___159 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___63 *of_node;
	struct fwnode_handle___159 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___159 *class;
	const struct attribute_group___42 **groups;
	void (*release)(struct device___159 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___159 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___159 *local_fwnode;
};

struct fwnode_reference_args___159 {
	struct fwnode_handle___159 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___63 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___159 fwnode;
	struct property___20 *properties;
	struct property___20 *deadprops;
	struct device_node___63 *parent;
	struct device_node___63 *child;
	struct device_node___63 *sibling;
	struct kobject___42 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___27 {
	struct device_node___63 *np;
	int args_count;
	uint32_t args[16];
};

struct dev_pm_ops___159 {
	int (*prepare)(struct device___159 *);
	void (*complete)(struct device___159 *);
	int (*suspend)(struct device___159 *);
	int (*resume)(struct device___159 *);
	int (*freeze)(struct device___159 *);
	int (*thaw)(struct device___159 *);
	int (*poweroff)(struct device___159 *);
	int (*restore)(struct device___159 *);
	int (*suspend_late)(struct device___159 *);
	int (*resume_early)(struct device___159 *);
	int (*freeze_late)(struct device___159 *);
	int (*thaw_early)(struct device___159 *);
	int (*poweroff_late)(struct device___159 *);
	int (*restore_early)(struct device___159 *);
	int (*suspend_noirq)(struct device___159 *);
	int (*resume_noirq)(struct device___159 *);
	int (*freeze_noirq)(struct device___159 *);
	int (*thaw_noirq)(struct device___159 *);
	int (*poweroff_noirq)(struct device___159 *);
	int (*restore_noirq)(struct device___159 *);
	int (*runtime_suspend)(struct device___159 *);
	int (*runtime_resume)(struct device___159 *);
	int (*runtime_idle)(struct device___159 *);
};

struct pm_domain_data___4;

struct pm_subsys_data___4 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___4 *domain_data;
};

struct pm_domain_data___4 {
	struct list_head list_node;
	struct device___159 *dev;
};

struct wakeup_source___159 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___159 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___159 {
	struct dev_pm_ops___159 ops;
	int (*start)(struct device___159 *);
	void (*detach)(struct device___159 *, bool);
	int (*activate)(struct device___159 *);
	void (*sync)(struct device___159 *);
	void (*dismiss)(struct device___159 *);
};

struct bus_type___159 {
	const char *name;
	const char *dev_name;
	struct device___159 *dev_root;
	const struct attribute_group___42 **bus_groups;
	const struct attribute_group___42 **dev_groups;
	const struct attribute_group___42 **drv_groups;
	int (*match)(struct device___159 *, struct device_driver___159 *);
	int (*uevent)(struct device___159 *, struct kobj_uevent_env *);
	int (*probe)(struct device___159 *);
	void (*sync_state)(struct device___159 *);
	void (*remove)(struct device___159 *);
	void (*shutdown)(struct device___159 *);
	int (*online)(struct device___159 *);
	int (*offline)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	int (*num_vf)(struct device___159 *);
	int (*dma_configure)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___159 {
	const char *name;
	struct bus_type___159 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___159 *);
	void (*sync_state)(struct device___159 *);
	int (*remove)(struct device___159 *);
	void (*shutdown)(struct device___159 *);
	int (*suspend)(struct device___159 *, pm_message_t);
	int (*resume)(struct device___159 *);
	const struct attribute_group___42 **groups;
	const struct attribute_group___42 **dev_groups;
	const struct dev_pm_ops___159 *pm;
	void (*coredump)(struct device___159 *);
	struct driver_private *p;
};

struct device_type___159 {
	const char *name;
	const struct attribute_group___42 **groups;
	int (*uevent)(struct device___159 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___159 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___159 *);
	const struct dev_pm_ops___159 *pm;
};

struct class___159 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___42 **class_groups;
	const struct attribute_group___42 **dev_groups;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___159 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___159 *, umode_t *);
	void (*class_release)(struct class___159 *);
	void (*dev_release)(struct device___159 *);
	int (*shutdown_pre)(struct device___159 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___159 *);
	void (*get_ownership)(struct device___159 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___159 *pm;
	struct subsys_private *p;
};

struct platform_device___21 {
	const char *name;
	int id;
	bool id_auto;
	struct device___159 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___18 {
	int (*probe)(struct platform_device___21 *);
	int (*remove)(struct platform_device___21 *);
	void (*shutdown)(struct platform_device___21 *);
	int (*suspend)(struct platform_device___21 *, pm_message_t);
	int (*resume)(struct platform_device___21 *);
	struct device_driver___159 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum imx_sc_pm_func {
	IMX_SC_PM_FUNC_UNKNOWN = 0,
	IMX_SC_PM_FUNC_SET_SYS_POWER_MODE = 19,
	IMX_SC_PM_FUNC_SET_PARTITION_POWER_MODE = 1,
	IMX_SC_PM_FUNC_GET_SYS_POWER_MODE = 2,
	IMX_SC_PM_FUNC_SET_RESOURCE_POWER_MODE = 3,
	IMX_SC_PM_FUNC_GET_RESOURCE_POWER_MODE = 4,
	IMX_SC_PM_FUNC_REQ_LOW_POWER_MODE = 16,
	IMX_SC_PM_FUNC_SET_CPU_RESUME_ADDR = 17,
	IMX_SC_PM_FUNC_REQ_SYS_IF_POWER_MODE = 18,
	IMX_SC_PM_FUNC_SET_CLOCK_RATE = 5,
	IMX_SC_PM_FUNC_GET_CLOCK_RATE = 6,
	IMX_SC_PM_FUNC_CLOCK_ENABLE = 7,
	IMX_SC_PM_FUNC_SET_CLOCK_PARENT = 14,
	IMX_SC_PM_FUNC_GET_CLOCK_PARENT = 15,
	IMX_SC_PM_FUNC_RESET = 13,
	IMX_SC_PM_FUNC_RESET_REASON = 10,
	IMX_SC_PM_FUNC_BOOT = 8,
	IMX_SC_PM_FUNC_REBOOT = 9,
	IMX_SC_PM_FUNC_REBOOT_PARTITION = 12,
	IMX_SC_PM_FUNC_CPU_START = 11,
};

struct imx_clk_scu_rsrc_table {
	const u32 *rsrc;
	u8 num;
};

struct imx_scu_clk_node {
	const char *name;
	u32 rsrc;
	u8 clk_type;
	const char * const *parents;
	int num_parents;
	struct clk_hw___5 *hw;
	struct list_head node;
};

struct clk_scu {
	struct clk_hw___5 hw;
	u16 rsrc_id;
	u8 clk_type;
	struct clk_hw___5 *parent;
	u8 parent_index;
	bool is_enabled;
	u32 rate;
};

struct clk_gpr_scu {
	struct clk_hw___5 hw;
	u16 rsrc_id;
	u8 gpr_id;
	u8 flags;
	bool gate_invert;
};

struct imx_sc_msg_req_set_clock_rate {
	struct imx_sc_rpc_msg hdr;
	__le32 rate;
	__le16 resource;
	u8 clk;
};

struct req_get_clock_rate {
	__le16 resource;
	u8 clk;
};

struct resp_get_clock_rate {
	__le32 rate;
};

struct imx_sc_msg_get_clock_rate {
	struct imx_sc_rpc_msg hdr;
	union {
		struct req_get_clock_rate req;
		struct resp_get_clock_rate resp;
	} data;
};

struct req_get_clock_parent {
	__le16 resource;
	u8 clk;
};

struct resp_get_clock_parent {
	u8 parent;
};

struct imx_sc_msg_get_clock_parent {
	struct imx_sc_rpc_msg hdr;
	union {
		struct req_get_clock_parent req;
		struct resp_get_clock_parent resp;
	} data;
};

struct imx_sc_msg_set_clock_parent {
	struct imx_sc_rpc_msg hdr;
	__le16 resource;
	u8 clk;
	u8 parent;
};

struct imx_sc_msg_req_clock_enable {
	struct imx_sc_rpc_msg hdr;
	__le16 resource;
	u8 clk;
	u8 enable;
	u8 autog;
	int: 24;
};

struct clk_lpcg_scu {
	struct clk_hw___5 hw;
	void *reg;
	u8 bit_idx;
	bool hw_gate;
	u32 state;
};

struct imx8qxp_lpcg_data {
	int id;
	char *name;
	char *parent;
	long unsigned int flags;
	u32 offset;
	u8 bit_idx;
	bool hw_gate;
};

struct imx8qxp_ss_lpcg {
	const struct imx8qxp_lpcg_data *lpcg;
	u8 num_lpcg;
	u8 num_max;
};

struct ti_syscon_gate_clk_priv {
	struct clk_hw hw;
	struct regmap *regmap;
	u32 reg;
	u32 idx;
};

struct ti_syscon_gate_clk_data {
	char *name;
	u32 offset;
	u32 bit_idx;
};

struct mtk_fixed_clk {
	int id;
	const char *name;
	const char *parent;
	long unsigned int rate;
};

struct mtk_fixed_factor {
	int id;
	const char *name;
	const char *parent_name;
	int mult;
	int div;
};

struct mtk_composite {
	int id;
	const char *name;
	const char * const *parent_names;
	const char *parent;
	unsigned int flags;
	uint32_t mux_reg;
	uint32_t divider_reg;
	uint32_t gate_reg;
	signed char mux_shift;
	signed char mux_width;
	signed char gate_shift;
	signed char divider_shift;
	signed char divider_width;
	u8 mux_flags;
	signed char num_parents;
};

struct mtk_gate_regs {
	u32 sta_ofs;
	u32 clr_ofs;
	u32 set_ofs;
};

struct mtk_gate {
	int id;
	const char *name;
	const char *parent_name;
	const struct mtk_gate_regs *regs;
	int shift;
	const struct clk_ops___5 *ops;
	long unsigned int flags;
};

struct mtk_clk_divider {
	int id;
	const char *name;
	const char *parent_name;
	long unsigned int flags;
	u32 div_reg;
	unsigned char div_shift;
	unsigned char div_width;
	unsigned char clk_divider_flags;
	const struct clk_div_table *clk_div_table;
};

struct mtk_clk_desc {
	const struct mtk_gate *clks;
	size_t num_clks;
};

struct mtk_pll_div_table {
	u32 div;
	long unsigned int freq;
};

struct mtk_pll_data {
	int id;
	const char *name;
	u32 reg;
	u32 pwr_reg;
	u32 en_mask;
	u32 pd_reg;
	u32 tuner_reg;
	u32 tuner_en_reg;
	u8 tuner_en_bit;
	int pd_shift;
	unsigned int flags;
	const struct clk_ops___5 *ops;
	u32 rst_bar_mask;
	long unsigned int fmin;
	long unsigned int fmax;
	int pcwbits;
	int pcwibits;
	u32 pcw_reg;
	int pcw_shift;
	u32 pcw_chg_reg;
	const struct mtk_pll_div_table *div_table;
	const char *parent_name;
	u32 en_reg;
	u8 pll_en_bit;
};

struct mtk_clk_pll {
	struct clk_hw___5 hw;
	void *base_addr;
	void *pd_addr;
	void *pwr_addr;
	void *tuner_addr;
	void *tuner_en_addr;
	void *pcw_addr;
	void *pcw_chg_addr;
	void *en_addr;
	const struct mtk_pll_data *data;
};

struct mtk_clk_gate {
	struct clk_hw___5 hw;
	struct regmap *regmap;
	int set_ofs;
	int clr_ofs;
	int sta_ofs;
	u8 bit;
};

struct mtk_ref2usb_tx {
	struct clk_hw___5 hw;
	void *base_addr;
};

struct mtk_clk_cpumux {
	struct clk_hw___5 hw;
	struct regmap *regmap;
	u32 reg;
	u32 mask;
	u8 shift;
};

struct reset_controller_dev___3;

struct reset_control_ops___3 {
	int (*reset)(struct reset_controller_dev___3 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___3 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___3 *, long unsigned int);
	int (*status)(struct reset_controller_dev___3 *, long unsigned int);
};

struct reset_controller_dev___3 {
	const struct reset_control_ops___3 *ops;
	struct module___180 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___157 *dev;
	struct device_node___60 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___3 *, const struct of_phandle_args___21 *);
	unsigned int nr_resets;
};

struct mtk_reset {
	struct regmap *regmap;
	int regofs;
	struct reset_controller_dev___3 rcdev;
};

struct mtk_mux;

struct mtk_clk_mux {
	struct clk_hw___5 hw;
	struct regmap *regmap;
	const struct mtk_mux *data;
	spinlock_t *lock;
	bool reparent;
};

struct mtk_mux {
	int id;
	const char *name;
	const char * const *parent_names;
	unsigned int flags;
	u32 mux_ofs;
	u32 set_ofs;
	u32 clr_ofs;
	u32 upd_ofs;
	u8 mux_shift;
	u8 mux_width;
	u8 gate_shift;
	s8 upd_shift;
	const struct clk_ops___5 *ops;
	signed char num_parents;
};

struct clk_mt8167_mm_driver_data {
	const struct mtk_gate *gates_clk;
	int gates_num;
};

struct mtk_clk_usb {
	int id;
	const char *name;
	const char *parent;
	u32 reg_ofs;
};

struct clk_mt8173_mm_driver_data {
	const struct mtk_gate *gates_clk;
	int gates_num;
};

struct clk_regmap {
	struct clk_hw hw;
	struct regmap *map;
	void *data;
};

struct meson_aoclk_data {
	const unsigned int reset_reg;
	const int num_reset;
	const unsigned int *reset;
	const int num_clks;
	struct clk_regmap **clks;
	const struct clk_hw_onecell_data___2 *hw_data;
};

struct meson_aoclk_reset_controller {
	struct reset_controller_dev___3 reset;
	const struct meson_aoclk_data *data;
	struct regmap *regmap;
};

struct clk_regmap___2 {
	struct clk_hw___3 hw;
	struct regmap *map;
	void *data;
};

struct parm {
	u16 reg_off;
	u8 shift;
	u8 width;
};

struct meson_clk_cpu_dyndiv_data {
	struct parm div;
	struct parm dyn;
};

struct meson_clk_dualdiv_param {
	unsigned int n1;
	unsigned int n2;
	unsigned int m1;
	unsigned int m2;
	unsigned int dual;
};

struct meson_clk_dualdiv_data {
	struct parm n1;
	struct parm n2;
	struct parm m1;
	struct parm m2;
	struct parm dual;
	const struct meson_clk_dualdiv_param *table;
};

struct reg_sequence {
	unsigned int reg;
	unsigned int def;
	unsigned int delay_us;
};

struct meson_eeclkc_data {
	struct clk_regmap * const *regmap_clks;
	unsigned int regmap_clk_num;
	const struct reg_sequence *init_regs;
	unsigned int init_count;
	struct clk_hw_onecell_data___2 *hw_onecell_data;
};

struct meson_clk_mpll_data {
	struct parm sdm;
	struct parm sdm_en;
	struct parm n2;
	struct parm ssen;
	struct parm misc;
	const struct reg_sequence *init_regs;
	unsigned int init_count;
	spinlock_t *lock;
	u8 flags;
};

struct pll_params_table {
	unsigned int m;
	unsigned int n;
};

struct pll_mult_range {
	unsigned int min;
	unsigned int max;
};

struct meson_clk_pll_data {
	struct parm en;
	struct parm m;
	struct parm n;
	struct parm frac;
	struct parm l;
	struct parm rst;
	const struct reg_sequence *init_regs;
	unsigned int init_count;
	const struct pll_params_table *table;
	const struct pll_mult_range *range;
	u8 flags;
};

struct clk_regmap_gate_data {
	unsigned int offset;
	u8 bit_idx;
	u8 flags;
};

struct clk_regmap_div_data {
	unsigned int offset;
	u8 shift;
	u8 width;
	u8 flags;
	const struct clk_div_table *table;
};

struct clk_regmap_mux_data {
	unsigned int offset;
	u32 *table;
	u32 mask;
	u8 shift;
	u8 flags;
};

struct clk_regmap___3 {
	struct clk_hw___5 hw;
	struct regmap *map;
	void *data;
};

struct meson_vid_pll_div_data {
	struct parm val;
	struct parm sel;
};

struct vid_pll_div {
	unsigned int shift_val;
	unsigned int shift_sel;
	unsigned int divider;
	unsigned int multiplier;
};

struct g12a_cpu_clk_postmux_nb_data {
	struct notifier_block nb;
	struct clk_hw *xtal;
	struct clk_hw *cpu_clk_dyn;
	struct clk_hw *cpu_clk_postmux0;
	struct clk_hw *cpu_clk_postmux1;
	struct clk_hw *cpu_clk_premux1;
};

struct g12a_sys_pll_nb_data {
	struct notifier_block nb;
	struct clk_hw *sys_pll;
	struct clk_hw *cpu_clk;
	struct clk_hw *cpu_clk_dyn;
};

struct meson_g12a_data {
	const struct meson_eeclkc_data eeclkc_data;
	int (*dvfs_setup)(struct platform_device___20 *);
};

struct tbg_def {
	char *name;
	u32 refdiv_offset;
	u32 fbdiv_offset;
	u32 vcodiv_reg;
	u32 vcodiv_offset;
};

struct clk_periph_driver_data {
	struct clk_hw_onecell_data___2 *hw_data;
	spinlock_t lock;
	void *reg;
	u32 tbg_sel;
	u32 div_sel0;
	u32 div_sel1;
	u32 div_sel2;
	u32 clk_sel;
	u32 clk_dis;
};

struct clk_double_div {
	struct clk_hw___5 hw;
	void *reg1;
	u8 shift1;
	void *reg2;
	u8 shift2;
};

struct clk_pm_cpu {
	struct clk_hw___5 hw;
	void *reg_mux;
	u8 shift_mux;
	u32 mask_mux;
	void *reg_div;
	u8 shift_div;
	struct regmap *nb_pm_base;
	long unsigned int l1_expiration;
};

struct clk_periph_data {
	const char *name;
	const char * const *parent_names;
	int num_parents;
	struct clk_hw___5 *mux_hw;
	struct clk_hw___5 *rate_hw;
	struct clk_hw___5 *gate_hw;
	struct clk_hw___5 *muxrate_hw;
	bool is_double_div;
};

struct cpu_dfs_regs {
	unsigned int divider_reg;
	unsigned int force_reg;
	unsigned int ratio_reg;
	unsigned int ratio_state_reg;
	unsigned int divider_mask;
	unsigned int cluster_offset;
	unsigned int force_mask;
	int divider_offset;
	int divider_ratio;
	int ratio_offset;
	int ratio_state_offset;
	int ratio_state_cluster_offset;
};

struct ap_cpu_clk {
	unsigned int cluster;
	const char *clk_name;
	struct device___139 *dev;
	struct clk_hw___5 hw;
	struct regmap *pll_cr_base;
	const struct cpu_dfs_regs *pll_regs;
};

enum {
	CP110_CLK_TYPE_CORE = 0,
	CP110_CLK_TYPE_GATABLE = 1,
};

struct cp110_gate_clk {
	struct clk_hw___5 hw;
	struct regmap *regmap;
	u8 bit_idx;
};

struct cpg_core_clk {
	const char *name;
	unsigned int id;
	unsigned int type;
	unsigned int parent;
	unsigned int div;
	unsigned int mult;
	unsigned int offset;
};

enum clk_types {
	CLK_TYPE_IN = 0,
	CLK_TYPE_FF = 1,
	CLK_TYPE_DIV6P1 = 2,
	CLK_TYPE_DIV6_RO = 3,
	CLK_TYPE_FR = 4,
	CLK_TYPE_CUSTOM = 5,
};

struct mssr_mod_clk {
	const char *name;
	unsigned int id;
	unsigned int parent;
};

enum clk_reg_layout {
	CLK_REG_LAYOUT_RCAR_GEN2_AND_GEN3 = 0,
	CLK_REG_LAYOUT_RZ_A = 1,
	CLK_REG_LAYOUT_RCAR_V3U = 2,
};

struct cpg_mssr_info {
	const struct cpg_core_clk *early_core_clks;
	unsigned int num_early_core_clks;
	const struct mssr_mod_clk *early_mod_clks;
	unsigned int num_early_mod_clks;
	const struct cpg_core_clk *core_clks;
	unsigned int num_core_clks;
	unsigned int last_dt_core_clk;
	unsigned int num_total_core_clks;
	enum clk_reg_layout reg_layout;
	const struct mssr_mod_clk *mod_clks;
	unsigned int num_mod_clks;
	unsigned int num_hw_mod_clks;
	const unsigned int *crit_mod_clks;
	unsigned int num_crit_mod_clks;
	const unsigned int *core_pm_clks;
	unsigned int num_core_pm_clks;
	int (*init)(struct device___139 *);
	struct clk * (*cpg_clk_register)(struct device___139 *, const struct cpg_core_clk *, const struct cpg_mssr_info *, struct clk **, void *, struct raw_notifier_head *);
};

enum rcar_gen3_clk_types {
	CLK_TYPE_GEN3_MAIN = 5,
	CLK_TYPE_GEN3_PLL0 = 6,
	CLK_TYPE_GEN3_PLL1 = 7,
	CLK_TYPE_GEN3_PLL2 = 8,
	CLK_TYPE_GEN3_PLL3 = 9,
	CLK_TYPE_GEN3_PLL4 = 10,
	CLK_TYPE_GEN3_SD = 11,
	CLK_TYPE_GEN3_R = 12,
	CLK_TYPE_GEN3_MDSEL = 13,
	CLK_TYPE_GEN3_Z = 14,
	CLK_TYPE_GEN3_OSC = 15,
	CLK_TYPE_GEN3_RCKSEL = 16,
	CLK_TYPE_GEN3_RPCSRC = 17,
	CLK_TYPE_GEN3_E3_RPCSRC = 18,
	CLK_TYPE_GEN3_RPC = 19,
	CLK_TYPE_GEN3_RPCD2 = 20,
	CLK_TYPE_GEN3_SOC_BASE = 21,
};

struct rcar_gen3_cpg_pll_config {
	u8 extal_div;
	u8 pll1_mult;
	u8 pll1_div;
	u8 pll3_mult;
	u8 pll3_div;
	u8 osc_prediv;
};

enum clk_ids {
	LAST_DT_CORE_CLK = 46,
	CLK_EXTAL = 47,
	CLK_EXTALR = 48,
	CLK_MAIN = 49,
	CLK_PLL0 = 50,
	CLK_PLL1 = 51,
	CLK_PLL2 = 52,
	CLK_PLL3 = 53,
	CLK_PLL4 = 54,
	CLK_PLL1_DIV2 = 55,
	CLK_PLL1_DIV4 = 56,
	CLK_S0 = 57,
	CLK_S1 = 58,
	CLK_S2 = 59,
	CLK_S3 = 60,
	CLK_SDSRC = 61,
	CLK_RPCSRC = 62,
	CLK_RINT = 63,
	MOD_CLK_BASE = 64,
};

enum clk_ids___2 {
	LAST_DT_CORE_CLK___2 = 44,
	CLK_EXTAL___2 = 45,
	CLK_EXTALR___2 = 46,
	CLK_MAIN___2 = 47,
	CLK_PLL0___2 = 48,
	CLK_PLL1___2 = 49,
	CLK_PLL3___2 = 50,
	CLK_PLL4___2 = 51,
	CLK_PLL1_DIV2___2 = 52,
	CLK_PLL1_DIV4___2 = 53,
	CLK_S0___2 = 54,
	CLK_S1___2 = 55,
	CLK_S2___2 = 56,
	CLK_S3___2 = 57,
	CLK_SDSRC___2 = 58,
	CLK_RPCSRC___2 = 59,
	CLK_RINT___2 = 60,
	MOD_CLK_BASE___2 = 61,
};

enum clk_ids___3 {
	LAST_DT_CORE_CLK___3 = 48,
	CLK_EXTAL___3 = 49,
	CLK_MAIN___3 = 50,
	CLK_PLL0___3 = 51,
	CLK_PLL1___3 = 52,
	CLK_PLL3___3 = 53,
	CLK_PLL0D4 = 54,
	CLK_PLL0D6 = 55,
	CLK_PLL0D8 = 56,
	CLK_PLL0D20 = 57,
	CLK_PLL0D24 = 58,
	CLK_PLL1D2 = 59,
	CLK_PE = 60,
	CLK_S0___3 = 61,
	CLK_S1___3 = 62,
	CLK_S2___3 = 63,
	CLK_S3___3 = 64,
	CLK_SDSRC___3 = 65,
	CLK_RPCSRC___3 = 66,
	CLK_RINT___3 = 67,
	CLK_OCO = 68,
	MOD_CLK_BASE___3 = 69,
};

struct soc_device_attribute___2 {
	const char *machine;
	const char *family;
	const char *revision;
	const char *serial_number;
	const char *soc_id;
	const void *data;
	const struct attribute_group___41 *custom_attr_group;
};

struct mssr_mod_reparent {
	unsigned int clk;
	unsigned int parent;
};

enum clk_ids___4 {
	LAST_DT_CORE_CLK___4 = 51,
	CLK_EXTAL___4 = 52,
	CLK_EXTALR___3 = 53,
	CLK_MAIN___4 = 54,
	CLK_PLL0___4 = 55,
	CLK_PLL1___4 = 56,
	CLK_PLL2___2 = 57,
	CLK_PLL3___4 = 58,
	CLK_PLL4___3 = 59,
	CLK_PLL1_DIV2___3 = 60,
	CLK_PLL1_DIV4___3 = 61,
	CLK_S0___4 = 62,
	CLK_S1___4 = 63,
	CLK_S2___4 = 64,
	CLK_S3___4 = 65,
	CLK_SDSRC___4 = 66,
	CLK_SSPSRC = 67,
	CLK_RPCSRC___4 = 68,
	CLK_RINT___4 = 69,
	MOD_CLK_BASE___4 = 70,
};

enum clk_ids___5 {
	LAST_DT_CORE_CLK___5 = 52,
	CLK_EXTAL___5 = 53,
	CLK_EXTALR___4 = 54,
	CLK_MAIN___5 = 55,
	CLK_PLL0___5 = 56,
	CLK_PLL1___5 = 57,
	CLK_PLL2___3 = 58,
	CLK_PLL3___5 = 59,
	CLK_PLL4___4 = 60,
	CLK_PLL1_DIV2___4 = 61,
	CLK_PLL1_DIV4___4 = 62,
	CLK_S0___5 = 63,
	CLK_S1___5 = 64,
	CLK_S2___5 = 65,
	CLK_S3___5 = 66,
	CLK_SDSRC___5 = 67,
	CLK_SSPSRC___2 = 68,
	CLK_RPCSRC___5 = 69,
	CLK_RINT___5 = 70,
	MOD_CLK_BASE___5 = 71,
};

enum clk_ids___6 {
	LAST_DT_CORE_CLK___6 = 49,
	CLK_EXTAL___6 = 50,
	CLK_EXTALR___5 = 51,
	CLK_MAIN___6 = 52,
	CLK_PLL0___6 = 53,
	CLK_PLL1___6 = 54,
	CLK_PLL3___6 = 55,
	CLK_PLL4___5 = 56,
	CLK_PLL1_DIV2___5 = 57,
	CLK_PLL1_DIV4___5 = 58,
	CLK_S0___6 = 59,
	CLK_S1___6 = 60,
	CLK_S2___6 = 61,
	CLK_S3___6 = 62,
	CLK_SDSRC___6 = 63,
	CLK_SSPSRC___3 = 64,
	CLK_RPCSRC___6 = 65,
	CLK_RINT___6 = 66,
	MOD_CLK_BASE___6 = 67,
};

enum r8a77970_clk_types {
	CLK_TYPE_R8A77970_SD0H = 21,
	CLK_TYPE_R8A77970_SD0 = 22,
};

enum clk_ids___7 {
	LAST_DT_CORE_CLK___7 = 30,
	CLK_EXTAL___7 = 31,
	CLK_EXTALR___6 = 32,
	CLK_MAIN___7 = 33,
	CLK_PLL0___7 = 34,
	CLK_PLL1___7 = 35,
	CLK_PLL3___7 = 36,
	CLK_PLL1_DIV2___6 = 37,
	CLK_PLL1_DIV4___6 = 38,
	MOD_CLK_BASE___7 = 39,
};

enum clk_ids___8 {
	LAST_DT_CORE_CLK___8 = 37,
	CLK_EXTAL___8 = 38,
	CLK_EXTALR___7 = 39,
	CLK_MAIN___8 = 40,
	CLK_PLL1___8 = 41,
	CLK_PLL2___4 = 42,
	CLK_PLL3___8 = 43,
	CLK_PLL1_DIV2___7 = 44,
	CLK_PLL1_DIV4___7 = 45,
	CLK_S0___7 = 46,
	CLK_S1___7 = 47,
	CLK_S2___7 = 48,
	CLK_S3___7 = 49,
	CLK_SDSRC___7 = 50,
	CLK_RPCSRC___7 = 51,
	CLK_OCO___2 = 52,
	MOD_CLK_BASE___8 = 53,
};

enum clk_ids___9 {
	LAST_DT_CORE_CLK___9 = 49,
	CLK_EXTAL___9 = 50,
	CLK_MAIN___9 = 51,
	CLK_PLL0___8 = 52,
	CLK_PLL1___9 = 53,
	CLK_PLL3___9 = 54,
	CLK_PLL0D4___2 = 55,
	CLK_PLL0D6___2 = 56,
	CLK_PLL0D8___2 = 57,
	CLK_PLL0D20___2 = 58,
	CLK_PLL0D24___2 = 59,
	CLK_PLL1D2___2 = 60,
	CLK_PE___2 = 61,
	CLK_S0___8 = 62,
	CLK_S1___8 = 63,
	CLK_S2___8 = 64,
	CLK_S3___8 = 65,
	CLK_SDSRC___8 = 66,
	CLK_RINT___7 = 67,
	CLK_OCO___3 = 68,
	MOD_CLK_BASE___9 = 69,
};

enum clk_ids___10 {
	LAST_DT_CORE_CLK___10 = 41,
	CLK_EXTAL___10 = 42,
	CLK_MAIN___10 = 43,
	CLK_PLL0___9 = 44,
	CLK_PLL1___10 = 45,
	CLK_PLL3___10 = 46,
	CLK_PLL0D2 = 47,
	CLK_PLL0D3 = 48,
	CLK_PLL0D5 = 49,
	CLK_PLL1D2___3 = 50,
	CLK_PE___3 = 51,
	CLK_S0___9 = 52,
	CLK_S1___9 = 53,
	CLK_S2___9 = 54,
	CLK_S3___9 = 55,
	CLK_SDSRC___9 = 56,
	CLK_RINT___8 = 57,
	CLK_OCO___4 = 58,
	MOD_CLK_BASE___10 = 59,
};

enum rcar_r8a779a0_clk_types {
	CLK_TYPE_R8A779A0_MAIN = 5,
	CLK_TYPE_R8A779A0_PLL1 = 6,
	CLK_TYPE_R8A779A0_PLL2X_3X = 7,
	CLK_TYPE_R8A779A0_PLL5 = 8,
	CLK_TYPE_R8A779A0_SD = 9,
	CLK_TYPE_R8A779A0_MDSEL = 10,
	CLK_TYPE_R8A779A0_OSC = 11,
};

struct rcar_r8a779a0_cpg_pll_config {
	u8 extal_div;
	u8 pll1_mult;
	u8 pll1_div;
	u8 pll5_mult;
	u8 pll5_div;
	u8 osc_prediv;
};

enum clk_ids___11 {
	LAST_DT_CORE_CLK___11 = 42,
	CLK_EXTAL___11 = 43,
	CLK_EXTALR___8 = 44,
	CLK_MAIN___11 = 45,
	CLK_PLL1___11 = 46,
	CLK_PLL20 = 47,
	CLK_PLL21 = 48,
	CLK_PLL30 = 49,
	CLK_PLL31 = 50,
	CLK_PLL5 = 51,
	CLK_PLL1_DIV2___8 = 52,
	CLK_PLL20_DIV2 = 53,
	CLK_PLL21_DIV2 = 54,
	CLK_PLL30_DIV2 = 55,
	CLK_PLL31_DIV2 = 56,
	CLK_PLL5_DIV2 = 57,
	CLK_PLL5_DIV4 = 58,
	CLK_S1___10 = 59,
	CLK_S3___10 = 60,
	CLK_SDSRC___10 = 61,
	CLK_RPCSRC___8 = 62,
	CLK_OCO___5 = 63,
	MOD_CLK_BASE___11 = 64,
};

struct cpg_core_clk___2 {
	const char *name;
	unsigned int id;
	unsigned int parent;
	unsigned int div;
	unsigned int mult;
	unsigned int type;
	unsigned int conf;
	const struct clk_div_table *dtable;
	const char * const *parent_names;
	int flag;
	int num_parents;
};

enum clk_types___2 {
	CLK_TYPE_IN___2 = 0,
	CLK_TYPE_FF___2 = 1,
	CLK_TYPE_SAM_PLL = 2,
	CLK_TYPE_DIV = 3,
};

struct rzg2l_mod_clk {
	const char *name;
	unsigned int id;
	unsigned int parent;
	u16 off;
	u8 bit;
};

struct rzg2l_reset {
	u16 off;
	u8 bit;
};

struct rzg2l_cpg_info {
	const struct cpg_core_clk___2 *core_clks;
	unsigned int num_core_clks;
	unsigned int last_dt_core_clk;
	unsigned int num_total_core_clks;
	const struct rzg2l_mod_clk *mod_clks;
	unsigned int num_mod_clks;
	unsigned int num_hw_mod_clks;
	const struct rzg2l_reset *resets;
	unsigned int num_resets;
	const unsigned int *crit_mod_clks;
	unsigned int num_crit_mod_clks;
};

enum clk_ids___12 {
	LAST_DT_CORE_CLK___12 = 22,
	CLK_EXTAL___12 = 23,
	CLK_OSC_DIV1000 = 24,
	CLK_PLL1___12 = 25,
	CLK_PLL2___5 = 26,
	CLK_PLL2_DIV2 = 27,
	CLK_PLL2_DIV16 = 28,
	CLK_PLL2_DIV20 = 29,
	CLK_PLL3___11 = 30,
	CLK_PLL3_DIV2 = 31,
	CLK_PLL3_DIV2_4 = 32,
	CLK_PLL3_DIV2_4_2 = 33,
	CLK_PLL3_DIV4 = 34,
	CLK_PLL4___6 = 35,
	CLK_PLL5___2 = 36,
	CLK_PLL5_DIV2___2 = 37,
	CLK_PLL6 = 38,
	CLK_P1_DIV2 = 39,
	MOD_CLK_BASE___12 = 40,
};

struct cpg_simple_notifier {
	struct notifier_block nb;
	void *reg;
	u32 saved;
};

struct sd_div_table {
	u32 val;
	unsigned int div;
};

struct sd_clock {
	struct clk_hw___5 hw;
	const struct sd_div_table *div_table;
	struct cpg_simple_notifier csn;
	unsigned int div_num;
	unsigned int cur_div_idx;
};

struct cpg_mssr_info___2 {
	const struct cpg_core_clk *early_core_clks;
	unsigned int num_early_core_clks;
	const struct mssr_mod_clk *early_mod_clks;
	unsigned int num_early_mod_clks;
	const struct cpg_core_clk *core_clks;
	unsigned int num_core_clks;
	unsigned int last_dt_core_clk;
	unsigned int num_total_core_clks;
	enum clk_reg_layout reg_layout;
	const struct mssr_mod_clk *mod_clks;
	unsigned int num_mod_clks;
	unsigned int num_hw_mod_clks;
	const unsigned int *crit_mod_clks;
	unsigned int num_crit_mod_clks;
	const unsigned int *core_pm_clks;
	unsigned int num_core_pm_clks;
	int (*init)(struct device___159 *);
	struct clk * (*cpg_clk_register)(struct device___159 *, const struct cpg_core_clk *, const struct cpg_mssr_info___2 *, struct clk **, void *, struct raw_notifier_head *);
};

struct cpg_pll_clk {
	struct clk_hw___5 hw;
	void *pllcr_reg;
	void *pllecr_reg;
	unsigned int fixed_mult;
	u32 pllecr_pllst_mask;
};

struct cpg_z_clk {
	struct clk_hw___5 hw;
	void *reg;
	void *kick_reg;
	long unsigned int max_rate;
	unsigned int fixed_div;
	u32 mask;
};

struct rpc_clock {
	struct clk_divider div;
	struct clk_gate___2 gate;
	struct cpg_simple_notifier csn;
};

struct rpcd2_clock {
	struct clk_fixed_factor fixed;
	struct clk_gate___2 gate;
};

struct usb2_clock_sel_priv {
	void *base;
	struct clk_hw___4 hw;
	struct clk_bulk_data clks[2];
	struct reset_control *rsts;
	bool extal;
	bool xtal;
};

enum gpd_status {
	GENPD_STATE_ON = 0,
	GENPD_STATE_OFF = 1,
};

struct dev_power_governor {
	bool (*power_down_ok)(struct dev_pm_domain___151 *);
	bool (*suspend_ok)(struct device___158 *);
};

struct gpd_dev_ops {
	int (*start)(struct device___158 *);
	int (*stop)(struct device___158 *);
};

struct genpd_power_state {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___158 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct opp_table;

struct dev_pm_opp;

struct genpd_lock_ops;

struct generic_pm_domain {
	struct device___158 dev;
	struct dev_pm_domain___151 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___158 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain *);
	int (*power_on)(struct generic_pm_domain *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain *, unsigned int);
	struct gpd_dev_ops dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain *, struct device___158 *);
	void (*detach_dev)(struct generic_pm_domain *, struct device___158 *);
	unsigned int flags;
	struct genpd_power_state *states;
	void (*free_states)(struct genpd_power_state *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

struct generic_pm_domain___2;

struct genpd_lock_ops {
	void (*lock)(struct generic_pm_domain___2 *);
	void (*lock_nested)(struct generic_pm_domain___2 *, int);
	int (*lock_interruptible)(struct generic_pm_domain___2 *);
	void (*unlock)(struct generic_pm_domain___2 *);
};

struct reset_controller_dev___4;

struct reset_control_ops___4 {
	int (*reset)(struct reset_controller_dev___4 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___4 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___4 *, long unsigned int);
	int (*status)(struct reset_controller_dev___4 *, long unsigned int);
};

struct reset_controller_dev___4 {
	const struct reset_control_ops___4 *ops;
	struct module___179 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___158 *dev;
	struct device_node___53 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___4 *, const struct of_phandle_args___20 *);
	unsigned int nr_resets;
};

struct rzg2l_cpg_priv {
	struct reset_controller_dev___4 rcdev;
	struct device___158 *dev;
	void *base;
	spinlock_t rmw_lock;
	struct clk **clks;
	unsigned int num_core_clks;
	unsigned int num_mod_clks;
	unsigned int num_resets;
	unsigned int last_dt_core_clk;
	struct raw_notifier_head notifiers;
	const struct rzg2l_cpg_info *info;
};

struct pll_clk {
	struct clk_hw___4 hw;
	unsigned int conf;
	unsigned int type;
	void *base;
	struct rzg2l_cpg_priv *priv;
};

struct mstp_clock {
	struct clk_hw___4 hw;
	u16 off;
	u8 bit;
	struct rzg2l_cpg_priv *priv;
};

struct cpg_mssr_info___3 {
	const struct cpg_core_clk *early_core_clks;
	unsigned int num_early_core_clks;
	const struct mssr_mod_clk *early_mod_clks;
	unsigned int num_early_mod_clks;
	const struct cpg_core_clk *core_clks;
	unsigned int num_core_clks;
	unsigned int last_dt_core_clk;
	unsigned int num_total_core_clks;
	enum clk_reg_layout reg_layout;
	const struct mssr_mod_clk *mod_clks;
	unsigned int num_mod_clks;
	unsigned int num_hw_mod_clks;
	const unsigned int *crit_mod_clks;
	unsigned int num_crit_mod_clks;
	const unsigned int *core_pm_clks;
	unsigned int num_core_pm_clks;
	int (*init)(struct device___158 *);
	struct clk * (*cpg_clk_register)(struct device___158 *, const struct cpg_core_clk *, const struct cpg_mssr_info___3 *, struct clk **, void *, struct raw_notifier_head *);
};

struct cpg_mssr_priv {
	struct reset_controller_dev___4 rcdev;
	struct device___158 *dev;
	void *base;
	enum clk_reg_layout reg_layout;
	spinlock_t rmw_lock;
	struct device_node___53 *np;
	unsigned int num_core_clks;
	unsigned int num_mod_clks;
	unsigned int last_dt_core_clk;
	struct raw_notifier_head notifiers;
	const u16 *status_regs;
	const u16 *control_regs;
	const u16 *reset_regs;
	const u16 *reset_clear_regs;
	struct {
		u32 mask;
		u32 val;
	} smstpcr_saved[15];
	struct clk *clks[0];
};

struct mstp_clock___2 {
	struct clk_hw___4 hw;
	u32 index;
	struct cpg_mssr_priv *priv;
};

struct cpg_mssr_clk_domain {
	struct generic_pm_domain genpd;
	unsigned int num_core_pm_clks;
	unsigned int core_pm_clks[0];
};

typedef void (*of_init_fn_1___5)(struct device_node___24 *);

struct div6_clock {
	struct clk_hw___5 hw;
	void *reg;
	unsigned int div;
	u32 src_mask;
	struct notifier_block nb;
	u8 parents[0];
};

struct of_phandle_args___28 {
	struct device_node___56 *np;
	int args_count;
	uint32_t args[16];
};

enum rockchip_pll_type {
	pll_rk3036 = 0,
	pll_rk3066 = 1,
	pll_rk3328 = 2,
	pll_rk3399 = 3,
};

struct rockchip_clk_provider {
	void *reg_base;
	struct clk_onecell_data clk_data;
	struct device_node___56 *cru_node;
	struct regmap *grf;
	spinlock_t lock;
};

struct rockchip_pll_rate_table {
	long unsigned int rate;
	union {
		struct {
			unsigned int nr;
			unsigned int nf;
			unsigned int no;
			unsigned int nb;
		};
		struct {
			unsigned int fbdiv;
			unsigned int postdiv1;
			unsigned int refdiv;
			unsigned int postdiv2;
			unsigned int dsmpd;
			unsigned int frac;
		};
	};
};

struct rockchip_pll_clock {
	unsigned int id;
	const char *name;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
	int con_offset;
	int mode_offset;
	int mode_shift;
	int lock_shift;
	enum rockchip_pll_type type;
	u8 pll_flags;
	struct rockchip_pll_rate_table *rate_table;
};

struct rockchip_cpuclk_clksel {
	int reg;
	u32 val;
};

struct rockchip_cpuclk_rate_table {
	long unsigned int prate;
	struct rockchip_cpuclk_clksel divs[5];
};

struct rockchip_cpuclk_reg_data {
	int core_reg[4];
	u8 div_core_shift[4];
	u32 div_core_mask[4];
	int num_cores;
	u8 mux_core_alt;
	u8 mux_core_main;
	u8 mux_core_shift;
	u32 mux_core_mask;
};

enum rockchip_clk_branch_type {
	branch_composite = 0,
	branch_mux = 1,
	branch_muxgrf = 2,
	branch_divider = 3,
	branch_fraction_divider = 4,
	branch_gate = 5,
	branch_mmc = 6,
	branch_inverter = 7,
	branch_factor = 8,
	branch_ddrclk = 9,
	branch_half_divider = 10,
};

struct rockchip_clk_branch {
	unsigned int id;
	enum rockchip_clk_branch_type branch_type;
	const char *name;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
	int muxdiv_offset;
	u8 mux_shift;
	u8 mux_width;
	u8 mux_flags;
	int div_offset;
	u8 div_shift;
	u8 div_width;
	u8 div_flags;
	struct clk_div_table *div_table;
	int gate_offset;
	u8 gate_shift;
	u8 gate_flags;
	struct rockchip_clk_branch *child;
};

struct rockchip_clk_frac {
	struct notifier_block clk_nb;
	struct clk_fractional_divider div;
	struct clk_gate___2 gate;
	struct clk_mux mux;
	const struct clk_ops___5 *mux_ops;
	int mux_frac_idx;
	bool rate_change_remuxed;
	int rate_change_idx;
};

struct rockchip_clk_pll {
	struct clk_hw___5 hw;
	struct clk_mux pll_mux;
	const struct clk_ops___5 *pll_mux_ops;
	struct notifier_block clk_nb;
	void *reg_base;
	int lock_offset;
	unsigned int lock_shift;
	enum rockchip_pll_type type;
	u8 flags;
	const struct rockchip_pll_rate_table *rate_table;
	unsigned int rate_count;
	spinlock_t *lock;
	struct rockchip_clk_provider *ctx;
};

struct rockchip_cpuclk {
	struct clk_hw___5 hw;
	struct clk *alt_parent;
	void *reg_base;
	struct notifier_block clk_nb;
	unsigned int rate_count;
	struct rockchip_cpuclk_rate_table *rate_table;
	const struct rockchip_cpuclk_reg_data *reg_data;
	spinlock_t *lock;
};

struct rockchip_inv_clock {
	struct clk_hw___5 hw;
	void *reg;
	int shift;
	int flags;
	spinlock_t *lock;
};

struct rockchip_mmc_clock {
	struct clk_hw___5 hw;
	void *reg;
	int id;
	int shift;
	int cached_phase;
	struct notifier_block clk_rate_change_nb;
};

struct rockchip_muxgrf_clock {
	struct clk_hw___5 hw;
	struct regmap *regmap;
	u32 reg;
	u32 shift;
	u32 width;
	int flags;
};

struct rockchip_ddrclk {
	struct clk_hw___5 hw;
	void *reg_base;
	int mux_offset;
	int mux_shift;
	int mux_width;
	int div_shift;
	int div_width;
	int ddr_flag;
	spinlock_t *lock;
};

struct reset_controller_dev___5;

struct reset_control_ops___5 {
	int (*reset)(struct reset_controller_dev___5 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___5 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___5 *, long unsigned int);
	int (*status)(struct reset_controller_dev___5 *, long unsigned int);
};

struct reset_controller_dev___5 {
	const struct reset_control_ops___5 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___9 *dev;
	struct device_node___24 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___5 *, const struct of_phandle_args___25 *);
	unsigned int nr_resets;
};

struct rockchip_softrst {
	struct reset_controller_dev___5 rcdev;
	void *reg_base;
	int num_regs;
	int num_per_reg;
	u8 flags;
	spinlock_t lock;
};

struct rockchip_clk_provider___2 {
	void *reg_base;
	struct clk_onecell_data clk_data;
	struct device_node___24 *cru_node;
	struct regmap *grf;
	spinlock_t lock;
};

enum px30_plls {
	apll = 0,
	dpll = 1,
	cpll = 2,
	npll = 3,
	apll_b_h = 4,
	apll_b_l = 5,
};

enum px30_pmu_plls {
	gpll = 0,
};

enum rk3308_plls {
	apll___2 = 0,
	dpll___2 = 1,
	vpll0 = 2,
	vpll1 = 3,
};

enum rk3328_plls {
	apll___3 = 0,
	dpll___3 = 1,
	cpll___2 = 2,
	gpll___2 = 3,
	npll___2 = 4,
};

struct rockchip_clk_provider___3 {
	void *reg_base;
	struct clk_onecell_data clk_data;
	struct device_node___41 *cru_node;
	struct regmap *grf;
	spinlock_t lock;
};

enum rk3368_plls {
	apllb = 0,
	aplll = 1,
	dpll___4 = 2,
	cpll___3 = 3,
	gpll___3 = 4,
	npll___3 = 5,
};

struct rockchip_clk_provider___4 {
	void *reg_base;
	struct clk_onecell_data clk_data;
	struct device_node___60 *cru_node;
	struct regmap *grf;
	spinlock_t lock;
};

enum rk3399_plls {
	lpll = 0,
	bpll = 1,
	dpll___5 = 2,
	cpll___4 = 3,
	gpll___4 = 4,
	npll___4 = 5,
	vpll = 6,
};

enum rk3399_pmu_plls {
	ppll = 0,
};

struct clk_rk3399_inits {
	void (*inits)(struct device_node___60 *);
};

struct stratix10_clock_data {
	struct clk_hw_onecell_data___2 clk_data;
	void *base;
};

struct stratix10_pll_clock {
	unsigned int id;
	const char *name;
	const struct clk_parent_data___5 *parent_data;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int offset;
};

struct stratix10_perip_c_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	const struct clk_parent_data___5 *parent_data;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int offset;
};

struct stratix10_perip_cnt_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	const struct clk_parent_data___5 *parent_data;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int offset;
	u8 fixed_divider;
	long unsigned int bypass_reg;
	long unsigned int bypass_shift;
};

struct stratix10_gate_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	const struct clk_parent_data___5 *parent_data;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int gate_reg;
	u8 gate_idx;
	long unsigned int div_reg;
	u8 div_offset;
	u8 div_width;
	long unsigned int bypass_reg;
	u8 bypass_shift;
	u8 fixed_div;
};

struct socfpga_pll {
	struct clk_gate___3 hw;
};

struct n5x_perip_c_clock {
	unsigned int id;
	const char *name;
	const char *parent_name;
	const char * const *parent_names;
	u8 num_parents;
	long unsigned int flags;
	long unsigned int offset;
	long unsigned int shift;
};

struct socfpga_periph_clk {
	struct clk_gate___3 hw;
	char *parent_name;
	u32 fixed_div;
	void *div_reg;
	void *bypass_reg;
	u32 width;
	u32 shift;
	u32 bypass_shift;
};

struct socfpga_gate_clk {
	struct clk_gate___3 hw;
	char *parent_name;
	u32 fixed_div;
	void *div_reg;
	void *bypass_reg;
	struct regmap *sys_mgr_base_addr;
	u32 width;
	u32 shift;
	u32 bypass_shift;
	u32 clk_phase[2];
};

struct clk_factors_config {
	u8 nshift;
	u8 nwidth;
	u8 kshift;
	u8 kwidth;
	u8 mshift;
	u8 mwidth;
	u8 pshift;
	u8 pwidth;
	u8 n_start;
};

struct factors_request {
	long unsigned int rate;
	long unsigned int parent_rate;
	u8 parent_index;
	u8 n;
	u8 k;
	u8 m;
	u8 p;
};

struct factors_data {
	int enable;
	int mux;
	int muxmask;
	const struct clk_factors_config *table;
	void (*getter)(struct factors_request *);
	void (*recalc)(struct factors_request *);
	const char *name;
};

struct clk_factors {
	struct clk_hw___5 hw;
	void *reg;
	const struct clk_factors_config *config;
	void (*get_factors)(struct factors_request *);
	void (*recalc)(struct factors_request *);
	spinlock_t *lock;
	struct clk_mux *mux;
	struct clk_gate___2 *gate;
};

struct mux_data {
	u8 shift;
};

struct div_data {
	u8 shift;
	u8 pow;
	u8 width;
	const struct clk_div_table *table;
};

struct divs_data {
	const struct factors_data *factors;
	int ndivs;
	struct {
		u8 self;
		u8 fixed;
		struct clk_div_table *table;
		u8 shift;
		u8 pow;
		u8 gate;
		bool critical;
	} div[4];
};

struct ve_reset_data {
	void *reg;
	spinlock_t *lock;
	struct reset_controller_dev___5 rcdev;
};

struct mmc_phase {
	struct clk_hw___5 hw;
	u8 offset;
	void *reg;
	spinlock_t *lock;
};

struct sun4i_a10_display_clk_data {
	bool has_div;
	u8 num_rst;
	u8 parents;
	u8 offset_en;
	u8 offset_div;
	u8 offset_mux;
	u8 offset_rst;
	u8 width_div;
	u8 width_mux;
	u32 flags;
};

struct reset_data {
	void *reg;
	spinlock_t *lock;
	struct reset_controller_dev___5 rcdev;
	u8 offset;
};

struct tcon_ch1_clk {
	struct clk_hw___5 hw;
	spinlock_t lock;
	void *reg;
};

enum {
	AHB1 = 0,
	AHB2 = 1,
	APB1 = 2,
	APB2 = 3,
	PARENT_MAX = 4,
};

struct sun9i_mmc_clk_data {
	spinlock_t lock;
	void *membase;
	struct clk *clk;
	struct reset_control *reset;
	struct clk_onecell_data clk_data;
	struct reset_controller_dev___2 rcdev;
};

struct usb_reset_data {
	void *reg;
	spinlock_t *lock;
	struct clk *clk;
	struct reset_controller_dev___5 rcdev;
};

struct usb_clk_data {
	u32 clk_mask;
	u32 reset_mask;
	bool reset_needs_clk;
};

struct sun9i_a80_cpus_clk {
	struct clk_hw___5 hw;
	void *reg;
};

struct gates_data {
	long unsigned int mask[1];
};

struct ccu_common {
	void *base;
	u16 reg;
	u16 lock_reg;
	u32 prediv;
	long unsigned int features;
	spinlock_t *lock;
	struct clk_hw___5 hw;
};

struct ccu_reset_map;

struct sunxi_ccu_desc {
	struct ccu_common **ccu_clks;
	long unsigned int num_ccu_clks;
	struct clk_hw_onecell_data___2 *hw_clks;
	struct ccu_reset_map *resets;
	long unsigned int num_resets;
};

struct ccu_reset_map {
	u16 reg;
	u32 bit;
};

struct ccu_pll_nb {
	struct notifier_block clk_nb;
	struct ccu_common *common;
	u32 enable;
	u32 lock;
};

struct ccu_reset {
	void *base;
	struct ccu_reset_map *reset_map;
	spinlock_t *lock;
	struct reset_controller_dev___2 rcdev;
};

struct sunxi_ccu {
	const struct sunxi_ccu_desc *desc;
	struct ccu_reset reset;
};

struct ccu_mux_fixed_prediv {
	u8 index;
	u16 div;
};

struct ccu_mux_var_prediv {
	u8 index;
	u8 shift;
	u8 width;
};

struct ccu_mux_internal {
	u8 shift;
	u8 width;
	const u8 *table;
	const struct ccu_mux_fixed_prediv *fixed_predivs;
	u8 n_predivs;
	const struct ccu_mux_var_prediv *var_predivs;
	u8 n_var_predivs;
};

struct ccu_div_internal {
	u8 shift;
	u8 width;
	u32 max;
	u32 offset;
	u32 flags;
	struct clk_div_table *table;
};

struct ccu_div {
	u32 enable;
	struct ccu_div_internal div;
	struct ccu_mux_internal mux;
	struct ccu_common common;
	unsigned int fixed_post_div;
};

struct ccu_frac_internal {
	u32 enable;
	u32 select;
	long unsigned int rates[2];
};

struct ccu_gate {
	u32 enable;
	struct ccu_common common;
};

struct ccu_mux {
	u16 reg;
	u32 enable;
	struct ccu_mux_internal mux;
	struct ccu_common common;
};

struct ccu_mux_nb {
	struct notifier_block clk_nb;
	struct ccu_common *common;
	struct ccu_mux_internal *cm;
	u32 delay_us;
	u8 bypass_index;
	u8 original_index;
};

struct ccu_mult_internal {
	u8 offset;
	u8 shift;
	u8 width;
	u8 min;
	u8 max;
};

struct ccu_mult {
	u32 enable;
	u32 lock;
	struct ccu_frac_internal frac;
	struct ccu_mult_internal mult;
	struct ccu_mux_internal mux;
	struct ccu_common common;
};

struct _ccu_mult {
	long unsigned int mult;
	long unsigned int min;
	long unsigned int max;
};

struct ccu_phase {
	u8 shift;
	u8 width;
	struct ccu_common common;
};

struct ccu_sdm_setting {
	long unsigned int rate;
	u32 pattern;
	u32 m;
	u32 n;
};

struct ccu_sdm_internal {
	struct ccu_sdm_setting *table;
	u32 table_size;
	u32 enable;
	u32 tuning_enable;
	u16 tuning_reg;
};

struct ccu_nk {
	u16 reg;
	u32 enable;
	u32 lock;
	struct ccu_mult_internal n;
	struct ccu_mult_internal k;
	unsigned int fixed_post_div;
	struct ccu_common common;
};

struct _ccu_nk {
	long unsigned int n;
	long unsigned int min_n;
	long unsigned int max_n;
	long unsigned int k;
	long unsigned int min_k;
	long unsigned int max_k;
};

struct ccu_nkm {
	u32 enable;
	u32 lock;
	struct ccu_mult_internal n;
	struct ccu_mult_internal k;
	struct ccu_div_internal m;
	struct ccu_mux_internal mux;
	unsigned int fixed_post_div;
	struct ccu_common common;
};

struct _ccu_nkm {
	long unsigned int n;
	long unsigned int min_n;
	long unsigned int max_n;
	long unsigned int k;
	long unsigned int min_k;
	long unsigned int max_k;
	long unsigned int m;
	long unsigned int min_m;
	long unsigned int max_m;
};

struct ccu_nkmp {
	u32 enable;
	u32 lock;
	struct ccu_mult_internal n;
	struct ccu_mult_internal k;
	struct ccu_div_internal m;
	struct ccu_div_internal p;
	unsigned int fixed_post_div;
	unsigned int max_rate;
	struct ccu_common common;
};

struct _ccu_nkmp {
	long unsigned int n;
	long unsigned int min_n;
	long unsigned int max_n;
	long unsigned int k;
	long unsigned int min_k;
	long unsigned int max_k;
	long unsigned int m;
	long unsigned int min_m;
	long unsigned int max_m;
	long unsigned int p;
	long unsigned int min_p;
	long unsigned int max_p;
};

struct ccu_nm {
	u32 enable;
	u32 lock;
	struct ccu_mult_internal n;
	struct ccu_div_internal m;
	struct ccu_frac_internal frac;
	struct ccu_sdm_internal sdm;
	unsigned int fixed_post_div;
	unsigned int min_rate;
	unsigned int max_rate;
	struct ccu_common common;
};

struct _ccu_nm {
	long unsigned int n;
	long unsigned int min_n;
	long unsigned int max_n;
	long unsigned int m;
	long unsigned int min_m;
	long unsigned int max_m;
};

struct ccu_mp {
	u32 enable;
	struct ccu_div_internal m;
	struct ccu_div_internal p;
	struct ccu_mux_internal mux;
	unsigned int fixed_post_div;
	struct ccu_common common;
};

struct ccu_common___2 {
	void *base;
	u16 reg;
	u16 lock_reg;
	u32 prediv;
	long unsigned int features;
	spinlock_t *lock;
	struct clk_hw hw;
};

struct sunxi_ccu_desc___2 {
	struct ccu_common___2 **ccu_clks;
	long unsigned int num_ccu_clks;
	struct clk_hw_onecell_data___2 *hw_clks;
	struct ccu_reset_map *resets;
	long unsigned int num_resets;
};

struct ccu_pll_nb___2 {
	struct notifier_block clk_nb;
	struct ccu_common___2 *common;
	u32 enable;
	u32 lock;
};

struct ccu_mux___2 {
	u16 reg;
	u32 enable;
	struct ccu_mux_internal mux;
	struct ccu_common___2 common;
};

struct ccu_mux_nb___2 {
	struct notifier_block clk_nb;
	struct ccu_common___2 *common;
	struct ccu_mux_internal *cm;
	u32 delay_us;
	u8 bypass_index;
	u8 original_index;
};

struct ccu_div___2 {
	u32 enable;
	struct ccu_div_internal div;
	struct ccu_mux_internal mux;
	struct ccu_common___2 common;
	unsigned int fixed_post_div;
};

struct ccu_gate___2 {
	u32 enable;
	struct ccu_common___2 common;
};

struct ccu_mult___2 {
	u32 enable;
	u32 lock;
	struct ccu_frac_internal frac;
	struct ccu_mult_internal mult;
	struct ccu_mux_internal mux;
	struct ccu_common___2 common;
};

struct ccu_mp___2 {
	u32 enable;
	struct ccu_div_internal m;
	struct ccu_div_internal p;
	struct ccu_mux_internal mux;
	unsigned int fixed_post_div;
	struct ccu_common___2 common;
};

struct ccu_nkmp___2 {
	u32 enable;
	u32 lock;
	struct ccu_mult_internal n;
	struct ccu_mult_internal k;
	struct ccu_div_internal m;
	struct ccu_div_internal p;
	unsigned int fixed_post_div;
	unsigned int max_rate;
	struct ccu_common___2 common;
};

struct ccu_nm___2 {
	u32 enable;
	u32 lock;
	struct ccu_mult_internal n;
	struct ccu_div_internal m;
	struct ccu_frac_internal frac;
	struct ccu_sdm_internal sdm;
	unsigned int fixed_post_div;
	unsigned int min_rate;
	unsigned int max_rate;
	struct ccu_common___2 common;
};

struct tegra_cpu_car_ops {
	void (*wait_for_reset)(u32);
	void (*put_in_reset)(u32);
	void (*out_of_reset)(u32);
	void (*enable_clock)(u32);
	void (*disable_clock)(u32);
	bool (*rail_off_ready)();
	void (*suspend)();
	void (*resume)();
};

struct tegra_clk_periph_regs {
	u32 enb_reg;
	u32 enb_set_reg;
	u32 enb_clr_reg;
	u32 rst_reg;
	u32 rst_set_reg;
	u32 rst_clr_reg;
};

struct tegra_clk_init_table {
	unsigned int clk_id;
	unsigned int parent_id;
	long unsigned int rate;
	int state;
};

struct tegra_clk_duplicate {
	int clk_id;
	struct clk_lookup lookup;
};

struct tegra_clk {
	int dt_id;
	bool present;
};

struct tegra_devclk {
	int dt_id;
	char *dev_id;
	char *con_id;
};

typedef void (*tegra_clk_apply_init_table_func)();

struct tegra_clk_sync_source {
	struct clk_hw___5 hw;
	long unsigned int rate;
	long unsigned int max_rate;
};

struct rail_alignment {
	int offset_uv;
	int step_uv;
};

struct cvb_coefficients {
	int c0;
	int c1;
	int c2;
};

struct cvb_table_freq_entry {
	long unsigned int freq;
	struct cvb_coefficients coefficients;
};

struct cvb_cpu_dfll_data {
	u32 tune0_low;
	u32 tune0_high;
	u32 tune1;
	unsigned int tune_high_min_millivolts;
};

struct cvb_table {
	int speedo_id;
	int process_id;
	int min_millivolts;
	int max_millivolts;
	int speedo_scale;
	int voltage_scale;
	struct cvb_table_freq_entry entries[40];
	struct cvb_cpu_dfll_data cpu_dfll_data;
};

struct tegra_dfll_soc_data {
	struct device___156 *dev;
	long unsigned int max_freq;
	const struct cvb_table *cvb;
	struct rail_alignment alignment;
	void (*init_clock_trimmers)();
	void (*set_clock_trimmers_high)();
	void (*set_clock_trimmers_low)();
};

enum dfll_ctrl_mode {
	DFLL_UNINITIALIZED = 0,
	DFLL_DISABLED = 1,
	DFLL_OPEN_LOOP = 2,
	DFLL_CLOSED_LOOP = 3,
};

enum dfll_tune_range {
	DFLL_TUNE_UNINITIALIZED = 0,
	DFLL_TUNE_LOW = 1,
};

enum tegra_dfll_pmu_if {
	TEGRA_DFLL_PMU_I2C = 0,
	TEGRA_DFLL_PMU_PWM = 1,
};

struct dfll_rate_req {
	long unsigned int rate;
	long unsigned int dvco_target_rate;
	int lut_index;
	u8 mult_bits;
	u8 scale_bits;
};

struct tegra_dfll {
	struct device___156 *dev;
	struct tegra_dfll_soc_data *soc;
	void *base;
	void *i2c_base;
	void *i2c_controller_base;
	void *lut_base;
	struct regulator *vdd_reg;
	struct clk *soc_clk;
	struct clk *ref_clk;
	struct clk *i2c_clk;
	struct clk *dfll_clk;
	struct reset_control *dvco_rst;
	long unsigned int ref_rate;
	long unsigned int i2c_clk_rate;
	long unsigned int dvco_rate_min;
	enum dfll_ctrl_mode mode;
	enum dfll_tune_range tune_range;
	struct dentry___196 *debugfs_dir;
	struct clk_hw dfll_clk_hw;
	const char *output_clock_name;
	struct dfll_rate_req last_req;
	long unsigned int last_unrounded_rate;
	u32 droop_ctrl;
	u32 sample_rate;
	u32 force_mode;
	u32 cf;
	u32 ci;
	u32 cg;
	bool cg_scale;
	u32 i2c_fs_rate;
	u32 i2c_reg;
	u32 i2c_slave_addr;
	unsigned int lut[33];
	long unsigned int lut_uv[33];
	int lut_size;
	u8 lut_bottom;
	u8 lut_min;
	u8 lut_max;
	u8 lut_safe;
	enum tegra_dfll_pmu_if pmu_if;
	long unsigned int pwm_rate;
	struct pinctrl___3 *pwm_pin;
	struct pinctrl_state *pwm_enable_state;
	struct pinctrl_state *pwm_disable_state;
	u32 reg_init_uV;
};

struct tegra_clk_frac_div {
	struct clk_hw___5 hw;
	void *reg;
	u8 flags;
	u8 shift;
	u8 width;
	u8 frac_width;
	spinlock_t *lock;
};

struct tegra_clk_frac_div___2 {
	struct clk_hw___5 hw;
	void *reg;
	u8 flags;
	u8 shift;
	u8 width;
	u8 frac_width;
	spinlock_t___2 *lock;
};

struct tegra_clk_periph_gate {
	u32 magic;
	struct clk_hw___5 hw;
	void *clk_base;
	u8 flags;
	int clk_num;
	int *enable_refcnt;
	const struct tegra_clk_periph_regs *regs;
};

struct tegra_clk_periph {
	u32 magic;
	struct clk_hw___5 hw;
	struct clk_mux___2 mux;
	struct tegra_clk_frac_div___2 divider;
	struct tegra_clk_periph_gate gate;
	const struct clk_ops___5 *mux_ops;
	const struct clk_ops___5 *div_ops;
	const struct clk_ops___5 *gate_ops;
};

struct tegra_periph_init_data {
	const char *name;
	int clk_id;
	union {
		const char * const *parent_names;
		const char *parent_name;
	} p;
	int num_parents;
	struct tegra_clk_periph periph;
	u32 offset;
	const char *con_id;
	const char *dev_id;
	long unsigned int flags;
};

struct tegra_clk_periph_fixed {
	struct clk_hw___5 hw;
	void *base;
	const struct tegra_clk_periph_regs *regs;
	unsigned int mul;
	unsigned int div;
	unsigned int num;
};

struct tegra_clk_pll_freq_table {
	long unsigned int input_rate;
	long unsigned int output_rate;
	u32 n;
	u32 m;
	u8 p;
	u8 cpcon;
	u16 sdm_data;
};

struct pdiv_map {
	u8 pdiv;
	u8 hw_val;
};

struct div_nmp {
	u8 divn_shift;
	u8 divn_width;
	u8 divm_shift;
	u8 divm_width;
	u8 divp_shift;
	u8 divp_width;
	u8 override_divn_shift;
	u8 override_divm_shift;
	u8 override_divp_shift;
};

struct tegra_clk_pll;

struct tegra_clk_pll_params {
	long unsigned int input_min;
	long unsigned int input_max;
	long unsigned int cf_min;
	long unsigned int cf_max;
	long unsigned int vco_min;
	long unsigned int vco_max;
	u32 base_reg;
	u32 misc_reg;
	u32 lock_reg;
	u32 lock_mask;
	u32 lock_enable_bit_idx;
	u32 iddq_reg;
	u32 iddq_bit_idx;
	u32 reset_reg;
	u32 reset_bit_idx;
	u32 sdm_din_reg;
	u32 sdm_din_mask;
	u32 sdm_ctrl_reg;
	u32 sdm_ctrl_en_mask;
	u32 ssc_ctrl_reg;
	u32 ssc_ctrl_en_mask;
	u32 aux_reg;
	u32 dyn_ramp_reg;
	u32 ext_misc_reg[6];
	u32 pmc_divnm_reg;
	u32 pmc_divp_reg;
	u32 flags;
	int stepa_shift;
	int stepb_shift;
	int lock_delay;
	int max_p;
	bool defaults_set;
	const struct pdiv_map *pdiv_tohw;
	struct div_nmp *div_nmp;
	struct tegra_clk_pll_freq_table *freq_table;
	long unsigned int fixed_rate;
	u16 mdiv_default;
	u32 (*round_p_to_pdiv)(u32, u32 *);
	void (*set_gain)(struct tegra_clk_pll_freq_table *);
	int (*calc_rate)(struct clk_hw___5 *, struct tegra_clk_pll_freq_table *, long unsigned int, long unsigned int);
	long unsigned int (*adjust_vco)(struct tegra_clk_pll_params *, long unsigned int);
	void (*set_defaults)(struct tegra_clk_pll *);
	int (*dyn_ramp)(struct tegra_clk_pll *, struct tegra_clk_pll_freq_table *);
	int (*pre_rate_change)();
	void (*post_rate_change)();
};

struct tegra_clk_pll {
	struct clk_hw___5 hw;
	void *clk_base;
	void *pmc;
	spinlock_t *lock;
	struct tegra_clk_pll_params *params;
};

struct utmi_clk_param {
	u32 osc_frequency;
	u8 enable_delay_count;
	u8 stable_count;
	u8 active_delay_count;
	u8 xtal_freq_count;
};

struct tegra_clk_pll_out {
	struct clk_hw___5 hw;
	void *reg;
	u8 enb_bit_idx;
	u8 rst_bit_idx;
	spinlock_t *lock;
	u8 flags;
};

struct tegra_sdmmc_mux {
	struct clk_hw___5 hw;
	void *reg;
	spinlock_t *lock;
	const struct clk_ops___5 *gate_ops;
	struct tegra_clk_periph_gate gate;
	u8 div_flags;
};

struct tegra_clk_super_mux {
	struct clk_hw___5 hw;
	void *reg;
	struct tegra_clk_frac_div frac_div;
	const struct clk_ops___5 *div_ops;
	u8 width;
	u8 flags;
	u8 div2_index;
	u8 pllx_index;
	spinlock_t *lock;
};

struct tegra_clk_pll___2;

struct tegra_clk_pll_params___2 {
	long unsigned int input_min;
	long unsigned int input_max;
	long unsigned int cf_min;
	long unsigned int cf_max;
	long unsigned int vco_min;
	long unsigned int vco_max;
	u32 base_reg;
	u32 misc_reg;
	u32 lock_reg;
	u32 lock_mask;
	u32 lock_enable_bit_idx;
	u32 iddq_reg;
	u32 iddq_bit_idx;
	u32 reset_reg;
	u32 reset_bit_idx;
	u32 sdm_din_reg;
	u32 sdm_din_mask;
	u32 sdm_ctrl_reg;
	u32 sdm_ctrl_en_mask;
	u32 ssc_ctrl_reg;
	u32 ssc_ctrl_en_mask;
	u32 aux_reg;
	u32 dyn_ramp_reg;
	u32 ext_misc_reg[6];
	u32 pmc_divnm_reg;
	u32 pmc_divp_reg;
	u32 flags;
	int stepa_shift;
	int stepb_shift;
	int lock_delay;
	int max_p;
	bool defaults_set;
	const struct pdiv_map *pdiv_tohw;
	struct div_nmp *div_nmp;
	struct tegra_clk_pll_freq_table *freq_table;
	long unsigned int fixed_rate;
	u16 mdiv_default;
	u32 (*round_p_to_pdiv)(u32, u32 *);
	void (*set_gain)(struct tegra_clk_pll_freq_table *);
	int (*calc_rate)(struct clk_hw___5 *, struct tegra_clk_pll_freq_table *, long unsigned int, long unsigned int);
	long unsigned int (*adjust_vco)(struct tegra_clk_pll_params___2 *, long unsigned int);
	void (*set_defaults)(struct tegra_clk_pll___2 *);
	int (*dyn_ramp)(struct tegra_clk_pll___2 *, struct tegra_clk_pll_freq_table *);
	int (*pre_rate_change)();
	void (*post_rate_change)();
};

struct tegra_clk_pll___2 {
	struct clk_hw___5 hw;
	void *clk_base;
	void *pmc;
	spinlock_t___2 *lock;
	struct tegra_clk_pll_params___2 *params;
};

struct tegra_audio_clk_info {
	char *name;
	struct tegra_clk_pll_params___2 *pll_params;
	int clk_id;
	char *parent;
};

enum clk_id {
	tegra_clk_actmon = 0,
	tegra_clk_adx = 1,
	tegra_clk_adx1 = 2,
	tegra_clk_afi = 3,
	tegra_clk_amx = 4,
	tegra_clk_amx1 = 5,
	tegra_clk_apb2ape = 6,
	tegra_clk_ahbdma = 7,
	tegra_clk_apbdma = 8,
	tegra_clk_apbif = 9,
	tegra_clk_ape = 10,
	tegra_clk_audio0 = 11,
	tegra_clk_audio0_2x = 12,
	tegra_clk_audio0_mux = 13,
	tegra_clk_audio1 = 14,
	tegra_clk_audio1_2x = 15,
	tegra_clk_audio1_mux = 16,
	tegra_clk_audio2 = 17,
	tegra_clk_audio2_2x = 18,
	tegra_clk_audio2_mux = 19,
	tegra_clk_audio3 = 20,
	tegra_clk_audio3_2x = 21,
	tegra_clk_audio3_mux = 22,
	tegra_clk_audio4 = 23,
	tegra_clk_audio4_2x = 24,
	tegra_clk_audio4_mux = 25,
	tegra_clk_bsea = 26,
	tegra_clk_bsev = 27,
	tegra_clk_cclk_g = 28,
	tegra_clk_cclk_lp = 29,
	tegra_clk_cilab = 30,
	tegra_clk_cilcd = 31,
	tegra_clk_cile = 32,
	tegra_clk_clk_32k = 33,
	tegra_clk_clk72Mhz = 34,
	tegra_clk_clk72Mhz_8 = 35,
	tegra_clk_clk_m = 36,
	tegra_clk_osc = 37,
	tegra_clk_osc_div2 = 38,
	tegra_clk_osc_div4 = 39,
	tegra_clk_cml0 = 40,
	tegra_clk_cml1 = 41,
	tegra_clk_csi = 42,
	tegra_clk_csite = 43,
	tegra_clk_csite_8 = 44,
	tegra_clk_csus = 45,
	tegra_clk_cve = 46,
	tegra_clk_dam0 = 47,
	tegra_clk_dam1 = 48,
	tegra_clk_dam2 = 49,
	tegra_clk_d_audio = 50,
	tegra_clk_dbgapb = 51,
	tegra_clk_dds = 52,
	tegra_clk_dfll_ref = 53,
	tegra_clk_dfll_soc = 54,
	tegra_clk_disp1 = 55,
	tegra_clk_disp1_8 = 56,
	tegra_clk_disp2 = 57,
	tegra_clk_disp2_8 = 58,
	tegra_clk_dp2 = 59,
	tegra_clk_dpaux = 60,
	tegra_clk_dpaux1 = 61,
	tegra_clk_dsialp = 62,
	tegra_clk_dsia_mux = 63,
	tegra_clk_dsiblp = 64,
	tegra_clk_dsib_mux = 65,
	tegra_clk_dtv = 66,
	tegra_clk_emc = 67,
	tegra_clk_entropy = 68,
	tegra_clk_entropy_8 = 69,
	tegra_clk_epp = 70,
	tegra_clk_epp_8 = 71,
	tegra_clk_extern1 = 72,
	tegra_clk_extern2 = 73,
	tegra_clk_extern3 = 74,
	tegra_clk_fuse = 75,
	tegra_clk_fuse_burn = 76,
	tegra_clk_gpu = 77,
	tegra_clk_gr2d = 78,
	tegra_clk_gr2d_8 = 79,
	tegra_clk_gr3d = 80,
	tegra_clk_gr3d_8 = 81,
	tegra_clk_hclk = 82,
	tegra_clk_hda = 83,
	tegra_clk_hda_8 = 84,
	tegra_clk_hda2codec_2x = 85,
	tegra_clk_hda2codec_2x_8 = 86,
	tegra_clk_hda2hdmi = 87,
	tegra_clk_hdmi = 88,
	tegra_clk_hdmi_audio = 89,
	tegra_clk_host1x = 90,
	tegra_clk_host1x_8 = 91,
	tegra_clk_host1x_9 = 92,
	tegra_clk_hsic_trk = 93,
	tegra_clk_i2c1 = 94,
	tegra_clk_i2c2 = 95,
	tegra_clk_i2c3 = 96,
	tegra_clk_i2c4 = 97,
	tegra_clk_i2c5 = 98,
	tegra_clk_i2c6 = 99,
	tegra_clk_i2cslow = 100,
	tegra_clk_i2s0 = 101,
	tegra_clk_i2s0_sync = 102,
	tegra_clk_i2s1 = 103,
	tegra_clk_i2s1_sync = 104,
	tegra_clk_i2s2 = 105,
	tegra_clk_i2s2_sync = 106,
	tegra_clk_i2s3 = 107,
	tegra_clk_i2s3_sync = 108,
	tegra_clk_i2s4 = 109,
	tegra_clk_i2s4_sync = 110,
	tegra_clk_isp = 111,
	tegra_clk_isp_8 = 112,
	tegra_clk_isp_9 = 113,
	tegra_clk_ispb = 114,
	tegra_clk_kbc = 115,
	tegra_clk_kfuse = 116,
	tegra_clk_la = 117,
	tegra_clk_maud = 118,
	tegra_clk_mipi = 119,
	tegra_clk_mipibif = 120,
	tegra_clk_mipi_cal = 121,
	tegra_clk_mpe = 122,
	tegra_clk_mselect = 123,
	tegra_clk_msenc = 124,
	tegra_clk_ndflash = 125,
	tegra_clk_ndflash_8 = 126,
	tegra_clk_ndspeed = 127,
	tegra_clk_ndspeed_8 = 128,
	tegra_clk_nor = 129,
	tegra_clk_nvdec = 130,
	tegra_clk_nvenc = 131,
	tegra_clk_nvjpg = 132,
	tegra_clk_owr = 133,
	tegra_clk_owr_8 = 134,
	tegra_clk_pcie = 135,
	tegra_clk_pclk = 136,
	tegra_clk_pll_a = 137,
	tegra_clk_pll_a_out0 = 138,
	tegra_clk_pll_a1 = 139,
	tegra_clk_pll_c = 140,
	tegra_clk_pll_c2 = 141,
	tegra_clk_pll_c3 = 142,
	tegra_clk_pll_c4 = 143,
	tegra_clk_pll_c4_out0 = 144,
	tegra_clk_pll_c4_out1 = 145,
	tegra_clk_pll_c4_out2 = 146,
	tegra_clk_pll_c4_out3 = 147,
	tegra_clk_pll_c_out1 = 148,
	tegra_clk_pll_d = 149,
	tegra_clk_pll_d2 = 150,
	tegra_clk_pll_d2_out0 = 151,
	tegra_clk_pll_d_out0 = 152,
	tegra_clk_pll_dp = 153,
	tegra_clk_pll_e_out0 = 154,
	tegra_clk_pll_g_ref = 155,
	tegra_clk_pll_m = 156,
	tegra_clk_pll_m_out1 = 157,
	tegra_clk_pll_mb = 158,
	tegra_clk_pll_p = 159,
	tegra_clk_pll_p_out1 = 160,
	tegra_clk_pll_p_out2 = 161,
	tegra_clk_pll_p_out2_int = 162,
	tegra_clk_pll_p_out3 = 163,
	tegra_clk_pll_p_out4 = 164,
	tegra_clk_pll_p_out4_cpu = 165,
	tegra_clk_pll_p_out5 = 166,
	tegra_clk_pll_p_out_hsio = 167,
	tegra_clk_pll_p_out_xusb = 168,
	tegra_clk_pll_p_out_cpu = 169,
	tegra_clk_pll_p_out_adsp = 170,
	tegra_clk_pll_ref = 171,
	tegra_clk_pll_re_out = 172,
	tegra_clk_pll_re_vco = 173,
	tegra_clk_pll_u = 174,
	tegra_clk_pll_u_out = 175,
	tegra_clk_pll_u_out1 = 176,
	tegra_clk_pll_u_out2 = 177,
	tegra_clk_pll_u_12m = 178,
	tegra_clk_pll_u_480m = 179,
	tegra_clk_pll_u_48m = 180,
	tegra_clk_pll_u_60m = 181,
	tegra_clk_pll_x = 182,
	tegra_clk_pll_x_out0 = 183,
	tegra_clk_pwm = 184,
	tegra_clk_qspi = 185,
	tegra_clk_rtc = 186,
	tegra_clk_sata = 187,
	tegra_clk_sata_8 = 188,
	tegra_clk_sata_cold = 189,
	tegra_clk_sata_oob = 190,
	tegra_clk_sata_oob_8 = 191,
	tegra_clk_sbc1 = 192,
	tegra_clk_sbc1_8 = 193,
	tegra_clk_sbc1_9 = 194,
	tegra_clk_sbc2 = 195,
	tegra_clk_sbc2_8 = 196,
	tegra_clk_sbc2_9 = 197,
	tegra_clk_sbc3 = 198,
	tegra_clk_sbc3_8 = 199,
	tegra_clk_sbc3_9 = 200,
	tegra_clk_sbc4 = 201,
	tegra_clk_sbc4_8 = 202,
	tegra_clk_sbc4_9 = 203,
	tegra_clk_sbc5 = 204,
	tegra_clk_sbc5_8 = 205,
	tegra_clk_sbc6 = 206,
	tegra_clk_sbc6_8 = 207,
	tegra_clk_sclk = 208,
	tegra_clk_sdmmc_legacy = 209,
	tegra_clk_sdmmc1 = 210,
	tegra_clk_sdmmc1_8 = 211,
	tegra_clk_sdmmc1_9 = 212,
	tegra_clk_sdmmc2 = 213,
	tegra_clk_sdmmc2_8 = 214,
	tegra_clk_sdmmc3 = 215,
	tegra_clk_sdmmc3_8 = 216,
	tegra_clk_sdmmc3_9 = 217,
	tegra_clk_sdmmc4 = 218,
	tegra_clk_sdmmc4_8 = 219,
	tegra_clk_se = 220,
	tegra_clk_se_10 = 221,
	tegra_clk_soc_therm = 222,
	tegra_clk_soc_therm_8 = 223,
	tegra_clk_sor0 = 224,
	tegra_clk_sor0_out = 225,
	tegra_clk_sor1 = 226,
	tegra_clk_sor1_out = 227,
	tegra_clk_spdif = 228,
	tegra_clk_spdif_2x = 229,
	tegra_clk_spdif_in = 230,
	tegra_clk_spdif_in_8 = 231,
	tegra_clk_spdif_in_sync = 232,
	tegra_clk_spdif_mux = 233,
	tegra_clk_spdif_out = 234,
	tegra_clk_timer = 235,
	tegra_clk_trace = 236,
	tegra_clk_tsec = 237,
	tegra_clk_tsec_8 = 238,
	tegra_clk_tsecb = 239,
	tegra_clk_tsensor = 240,
	tegra_clk_tvdac = 241,
	tegra_clk_tvo = 242,
	tegra_clk_uarta = 243,
	tegra_clk_uarta_8 = 244,
	tegra_clk_uartb = 245,
	tegra_clk_uartb_8 = 246,
	tegra_clk_uartc = 247,
	tegra_clk_uartc_8 = 248,
	tegra_clk_uartd = 249,
	tegra_clk_uartd_8 = 250,
	tegra_clk_uarte = 251,
	tegra_clk_uarte_8 = 252,
	tegra_clk_uartape = 253,
	tegra_clk_usb2 = 254,
	tegra_clk_usb2_hsic_trk = 255,
	tegra_clk_usb2_trk = 256,
	tegra_clk_usb3 = 257,
	tegra_clk_usbd = 258,
	tegra_clk_vcp = 259,
	tegra_clk_vde = 260,
	tegra_clk_vde_8 = 261,
	tegra_clk_vfir = 262,
	tegra_clk_vi = 263,
	tegra_clk_vi_8 = 264,
	tegra_clk_vi_9 = 265,
	tegra_clk_vi_10 = 266,
	tegra_clk_vi_i2c = 267,
	tegra_clk_vic03 = 268,
	tegra_clk_vic03_8 = 269,
	tegra_clk_vim2_clk = 270,
	tegra_clk_vimclk_sync = 271,
	tegra_clk_vi_sensor = 272,
	tegra_clk_vi_sensor_8 = 273,
	tegra_clk_vi_sensor_9 = 274,
	tegra_clk_vi_sensor2 = 275,
	tegra_clk_vi_sensor2_8 = 276,
	tegra_clk_xusb_dev = 277,
	tegra_clk_xusb_dev_src = 278,
	tegra_clk_xusb_dev_src_8 = 279,
	tegra_clk_xusb_falcon_src = 280,
	tegra_clk_xusb_falcon_src_8 = 281,
	tegra_clk_xusb_fs_src = 282,
	tegra_clk_xusb_gate = 283,
	tegra_clk_xusb_host = 284,
	tegra_clk_xusb_host_src = 285,
	tegra_clk_xusb_host_src_8 = 286,
	tegra_clk_xusb_hs_src = 287,
	tegra_clk_xusb_hs_src_4 = 288,
	tegra_clk_xusb_ss = 289,
	tegra_clk_xusb_ss_src = 290,
	tegra_clk_xusb_ss_src_8 = 291,
	tegra_clk_xusb_ss_div2 = 292,
	tegra_clk_xusb_ssp_src = 293,
	tegra_clk_sclk_mux = 294,
	tegra_clk_sor_safe = 295,
	tegra_clk_cec = 296,
	tegra_clk_ispa = 297,
	tegra_clk_dmic1 = 298,
	tegra_clk_dmic2 = 299,
	tegra_clk_dmic3 = 300,
	tegra_clk_dmic1_sync_clk = 301,
	tegra_clk_dmic2_sync_clk = 302,
	tegra_clk_dmic3_sync_clk = 303,
	tegra_clk_dmic1_sync_clk_mux = 304,
	tegra_clk_dmic2_sync_clk_mux = 305,
	tegra_clk_dmic3_sync_clk_mux = 306,
	tegra_clk_iqc1 = 307,
	tegra_clk_iqc2 = 308,
	tegra_clk_pll_a_out_adsp = 309,
	tegra_clk_pll_a_out0_out_adsp = 310,
	tegra_clk_adsp = 311,
	tegra_clk_adsp_neon = 312,
	tegra_clk_max = 313,
};

struct tegra_sync_source_initdata {
	char *name;
	long unsigned int rate;
	long unsigned int max_rate;
	int clk_id;
};

struct tegra_audio_clk_initdata {
	char *gate_name;
	char *mux_name;
	u32 offset;
	int gate_clk_id;
	int mux_clk_id;
};

struct tegra_audio2x_clk_initdata {
	char *parent;
	char *gate_name;
	char *name_2x;
	char *div_name;
	int clk_id;
	int clk_num;
	u8 div_offset;
};

struct pll_out_data {
	char *div_name;
	char *pll_out_name;
	u32 offset;
	int clk_id;
	u8 div_shift;
	u8 div_flags;
	u8 rst_shift;
	spinlock_t___2 *lock;
};

struct tegra_clk_super_mux___2 {
	struct clk_hw___5 hw;
	void *reg;
	struct tegra_clk_frac_div___2 frac_div;
	const struct clk_ops___5 *div_ops;
	u8 width;
	u8 flags;
	u8 div2_index;
	u8 pllx_index;
	spinlock_t___2 *lock;
};

enum tegra_super_gen {
	gen4 = 4,
	gen5 = 5,
};

struct tegra_super_gen_info {
	enum tegra_super_gen gen;
	const char **sclk_parents;
	const char **cclk_g_parents;
	const char **cclk_lp_parents;
	int num_sclk_parents;
	int num_cclk_g_parents;
	int num_cclk_lp_parents;
};

enum tegra_revision {
	TEGRA_REVISION_UNKNOWN = 0,
	TEGRA_REVISION_A01 = 1,
	TEGRA_REVISION_A02 = 2,
	TEGRA_REVISION_A03 = 3,
	TEGRA_REVISION_A03p = 4,
	TEGRA_REVISION_A04 = 5,
	TEGRA_REVISION_MAX = 6,
};

struct tegra_sku_info {
	int sku_id;
	int cpu_process_id;
	int cpu_speedo_id;
	int cpu_speedo_value;
	int cpu_iddq_value;
	int soc_process_id;
	int soc_speedo_id;
	int soc_speedo_value;
	int gpu_process_id;
	int gpu_speedo_id;
	int gpu_speedo_value;
	enum tegra_revision revision;
};

struct dfll_fcpu_data {
	const long unsigned int *cpu_max_freq_table;
	unsigned int cpu_max_freq_table_size;
	const struct cvb_table *cpu_cvb_tables;
	unsigned int cpu_cvb_tables_size;
};

struct tegra_audio_clk_info___2 {
	char *name;
	struct tegra_clk_pll_params *pll_params;
	int clk_id;
	char *parent;
};

struct tegra_clk_periph___2 {
	u32 magic;
	struct clk_hw___5 hw;
	struct clk_mux mux;
	struct tegra_clk_frac_div divider;
	struct tegra_clk_periph_gate gate;
	const struct clk_ops___5 *mux_ops;
	const struct clk_ops___5 *div_ops;
	const struct clk_ops___5 *gate_ops;
};

struct tegra_periph_init_data___2 {
	const char *name;
	int clk_id;
	union {
		const char * const *parent_names;
		const char *parent_name;
	} p;
	int num_parents;
	struct tegra_clk_periph___2 periph;
	u32 offset;
	const char *con_id;
	const char *dev_id;
	long unsigned int flags;
};

struct cpu_clk_suspend_context {
	u32 clk_csite_src;
	u32 cclkg_burst;
	u32 cclkg_divider;
};

enum {
	DOWN___2 = 0,
	UP___2 = 1,
};

typedef void (*of_init_fn_1___6)(struct device_node___56 *);

struct cpu_clk_suspend_context___2 {
	u32 clk_csite_src;
};

struct tegra210_domain_mbist_war {
	void (*handle_lvl2_ovr)(struct tegra210_domain_mbist_war *);
	const u32 lvl2_offset;
	const u32 lvl2_mask;
	const unsigned int num_clks;
	const unsigned int *clk_init_data;
	struct clk_bulk_data *clks;
};

struct utmi_clk_param___2 {
	u32 osc_frequency;
	u8 enable_delay_count;
	u16 stable_count;
	u8 active_delay_count;
	u16 xtal_freq_count;
};

struct tegra210_clk_emc_config {
	long unsigned int rate;
	bool same_freq;
	u32 value;
	long unsigned int parent_rate;
	u8 parent;
};

struct tegra210_clk_emc_provider {
	struct module___180 *owner;
	struct device___157 *dev;
	struct tegra210_clk_emc_config *configs;
	unsigned int num_configs;
	int (*set_rate)(struct device___157 *, const struct tegra210_clk_emc_config *);
};

struct tegra210_clk_emc {
	struct clk_hw hw;
	void *regs;
	struct tegra210_clk_emc_provider *provider;
	struct clk *parents[8];
};

typedef struct generic_pm_domain * (*genpd_xlate_t)(struct of_phandle_args___20 *, void *);

struct genpd_onecell_data {
	struct generic_pm_domain **domains;
	unsigned int num_domains;
	genpd_xlate_t xlate;
};

enum {
	CMD_CLK_GET_RATE = 1,
	CMD_CLK_SET_RATE = 2,
	CMD_CLK_ROUND_RATE = 3,
	CMD_CLK_GET_PARENT = 4,
	CMD_CLK_SET_PARENT = 5,
	CMD_CLK_IS_ENABLED = 6,
	CMD_CLK_ENABLE = 7,
	CMD_CLK_DISABLE = 8,
	CMD_CLK_GET_ALL_INFO = 14,
	CMD_CLK_GET_MAX_CLK_ID = 15,
	CMD_CLK_GET_FMAX_AT_VMIN = 16,
	CMD_CLK_MAX = 17,
};

struct cmd_clk_get_rate_request {};

struct cmd_clk_get_rate_response {
	int64_t rate;
};

struct cmd_clk_set_rate_request {
	int32_t unused;
	int64_t rate;
} __attribute__((packed));

struct cmd_clk_set_rate_response {
	int64_t rate;
};

struct cmd_clk_round_rate_request {
	int32_t unused;
	int64_t rate;
} __attribute__((packed));

struct cmd_clk_round_rate_response {
	int64_t rate;
};

struct cmd_clk_get_parent_request {};

struct cmd_clk_get_parent_response {
	uint32_t parent_id;
};

struct cmd_clk_set_parent_request {
	uint32_t parent_id;
};

struct cmd_clk_set_parent_response {
	uint32_t parent_id;
};

struct cmd_clk_is_enabled_request {};

struct cmd_clk_is_enabled_response {
	int32_t state;
};

struct cmd_clk_enable_request {};

struct cmd_clk_disable_request {};

struct cmd_clk_get_all_info_request {};

struct cmd_clk_get_all_info_response {
	uint32_t flags;
	uint32_t parent;
	uint32_t parents[16];
	uint8_t num_parents;
	uint8_t name[40];
} __attribute__((packed));

struct cmd_clk_get_max_clk_id_request {};

struct cmd_clk_get_max_clk_id_response {
	uint32_t max_id;
};

struct cmd_clk_get_fmax_at_vmin_request {};

struct mrq_clk_request {
	uint32_t cmd_and_id;
	union {
		struct cmd_clk_get_rate_request clk_get_rate;
		struct cmd_clk_set_rate_request clk_set_rate;
		struct cmd_clk_round_rate_request clk_round_rate;
		struct cmd_clk_get_parent_request clk_get_parent;
		struct cmd_clk_set_parent_request clk_set_parent;
		struct cmd_clk_enable_request clk_enable;
		struct cmd_clk_disable_request clk_disable;
		struct cmd_clk_is_enabled_request clk_is_enabled;
		struct cmd_clk_get_all_info_request clk_get_all_info;
		struct cmd_clk_get_max_clk_id_request clk_get_max_clk_id;
		struct cmd_clk_get_fmax_at_vmin_request clk_get_fmax_at_vmin;
	};
} __attribute__((packed));

struct tegra_bpmp_ops;

struct tegra_bpmp_soc {
	struct {
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} cpu_tx;
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} thread;
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} cpu_rx;
	} channels;
	const struct tegra_bpmp_ops *ops;
	unsigned int num_resets;
};

struct tegra_bpmp;

struct tegra_bpmp_channel;

struct tegra_bpmp_ops {
	int (*init)(struct tegra_bpmp *);
	void (*deinit)(struct tegra_bpmp *);
	bool (*is_response_ready)(struct tegra_bpmp_channel *);
	bool (*is_request_ready)(struct tegra_bpmp_channel *);
	int (*ack_response)(struct tegra_bpmp_channel *);
	int (*ack_request)(struct tegra_bpmp_channel *);
	bool (*is_response_channel_free)(struct tegra_bpmp_channel *);
	bool (*is_request_channel_free)(struct tegra_bpmp_channel *);
	int (*post_response)(struct tegra_bpmp_channel *);
	int (*post_request)(struct tegra_bpmp_channel *);
	int (*ring_doorbell)(struct tegra_bpmp *);
	int (*resume)(struct tegra_bpmp *);
};

struct tegra_bpmp_mb_data {
	u32 code;
	u32 flags;
	u8 data[120];
};

struct tegra_bpmp___2;

struct tegra_ivc;

struct tegra_bpmp_channel___2 {
	struct tegra_bpmp___2 *bpmp;
	struct tegra_bpmp_mb_data *ib;
	struct tegra_bpmp_mb_data *ob;
	struct completion completion;
	struct tegra_ivc *ivc;
	unsigned int index;
};

struct tegra_bpmp_clk;

struct tegra_bpmp___2 {
	const struct tegra_bpmp_soc *soc;
	struct device___158 *dev;
	void *priv;
	struct {
		struct mbox_client client;
		struct mbox_chan___2 *channel;
	} mbox;
	spinlock_t atomic_tx_lock;
	struct tegra_bpmp_channel___2 *tx_channel;
	struct tegra_bpmp_channel___2 *rx_channel;
	struct tegra_bpmp_channel___2 *threaded_channels;
	struct {
		long unsigned int *allocated;
		long unsigned int *busy;
		unsigned int count;
		struct semaphore lock;
	} threaded;
	struct list_head mrqs;
	spinlock_t lock;
	struct tegra_bpmp_clk **clocks;
	unsigned int num_clocks;
	struct reset_controller_dev___4 rstc;
	struct genpd_onecell_data genpd;
	struct dentry___195 *debugfs_mirror;
};

struct tegra_bpmp_clk {
	struct clk_hw___4 hw;
	struct tegra_bpmp___2 *bpmp;
	unsigned int id;
	unsigned int num_parents;
	unsigned int *parents;
};

struct tegra_bpmp_message {
	unsigned int mrq;
	struct {
		const void *data;
		size_t size;
	} tx;
	struct {
		void *data;
		size_t size;
		int ret;
	} rx;
};

struct tegra_bpmp_clk_info {
	unsigned int id;
	char name[40];
	unsigned int parents[16];
	unsigned int num_parents;
	long unsigned int flags;
};

struct tegra_bpmp_clk_message {
	unsigned int cmd;
	unsigned int id;
	struct {
		const void *data;
		size_t size;
	} tx;
	struct {
		void *data;
		size_t size;
		int ret;
	} rx;
};

struct icst_params {
	long unsigned int ref;
	long unsigned int vco_max;
	long unsigned int vco_min;
	short unsigned int vd_min;
	short unsigned int vd_max;
	unsigned char rd_min;
	unsigned char rd_max;
	const unsigned char *s2div;
	const unsigned char *idx2s;
};

struct icst_vco {
	short unsigned int v;
	unsigned char r;
	unsigned char s;
};

enum icst_control_type {
	ICST_VERSATILE = 0,
	ICST_INTEGRATOR_AP_CM = 1,
	ICST_INTEGRATOR_AP_SYS = 2,
	ICST_INTEGRATOR_AP_PCI = 3,
	ICST_INTEGRATOR_CP_CM_CORE = 4,
	ICST_INTEGRATOR_CP_CM_MEM = 5,
	ICST_INTEGRATOR_IM_PD1 = 6,
};

struct clk_icst_desc {
	const struct icst_params *params;
	u32 vco_offset;
	u32 lock_offset;
};

struct clk_icst {
	struct clk_hw___5 hw;
	struct regmap *map;
	u32 vcoreg_off;
	u32 lockreg_off;
	struct icst_params *params;
	long unsigned int rate;
	enum icst_control_type ctype;
};

struct clk_sp810;

struct clk_sp810_timerclken {
	struct clk_hw___5 hw;
	struct clk *clk;
	struct clk_sp810 *sp810;
	int channel;
};

struct clk_sp810 {
	struct device_node___24 *node;
	void *base;
	spinlock_t lock;
	struct clk_sp810_timerclken timerclken[4];
};

struct vexpress_osc {
	struct regmap *reg;
	struct clk_hw___4 hw;
	long unsigned int rate_min;
	long unsigned int rate_max;
};

struct clock_topology {
	u32 type;
	u32 flag;
	u32 type_flag;
	u8 custom_type_flag;
};

struct zynqmp_pll {
	struct clk_hw___5 hw;
	u32 clk_id;
	bool set_pll_mode;
};

enum pll_mode {
	PLL_MODE_INT = 0,
	PLL_MODE_FRAC = 1,
	PLL_MODE_ERROR = 2,
};

struct zynqmp_clk_gate {
	struct clk_hw___5 hw;
	u8 flags;
	u32 clk_id;
};

enum pm_query_id {
	PM_QID_INVALID = 0,
	PM_QID_CLOCK_GET_NAME = 1,
	PM_QID_CLOCK_GET_TOPOLOGY = 2,
	PM_QID_CLOCK_GET_FIXEDFACTOR_PARAMS = 3,
	PM_QID_CLOCK_GET_PARENTS = 4,
	PM_QID_CLOCK_GET_ATTRIBUTES = 5,
	PM_QID_PINCTRL_GET_NUM_PINS = 6,
	PM_QID_PINCTRL_GET_NUM_FUNCTIONS = 7,
	PM_QID_PINCTRL_GET_NUM_FUNCTION_GROUPS = 8,
	PM_QID_PINCTRL_GET_FUNCTION_NAME = 9,
	PM_QID_PINCTRL_GET_FUNCTION_GROUPS = 10,
	PM_QID_PINCTRL_GET_PIN_GROUPS = 11,
	PM_QID_CLOCK_GET_NUM_CLOCKS = 12,
	PM_QID_CLOCK_GET_MAX_DIVISOR = 13,
};

struct zynqmp_pm_query_data {
	u32 qid;
	u32 arg1;
	u32 arg2;
	u32 arg3;
};

enum topology_type {
	TYPE_INVALID = 0,
	TYPE_MUX = 1,
	TYPE_PLL = 2,
	TYPE_FIXEDFACTOR = 3,
	TYPE_DIV1 = 4,
	TYPE_DIV2 = 5,
	TYPE_GATE = 6,
};

struct zynqmp_clk_divider {
	struct clk_hw___5 hw;
	u8 flags;
	bool is_frac;
	u32 clk_id;
	u32 div_type;
	u16 max_div;
};

struct zynqmp_clk_mux {
	struct clk_hw___5 hw;
	u8 flags;
	u32 clk_id;
};

enum clk_type {
	CLK_TYPE_OUTPUT = 0,
	CLK_TYPE_EXTERNAL = 1,
};

struct clock_parent {
	char name[50];
	int id;
	u32 flag;
};

struct zynqmp_clock {
	char clk_name[50];
	u32 valid;
	enum clk_type type;
	struct clock_topology node[6];
	u32 num_nodes;
	struct clock_parent parent[100];
	u32 num_parents;
	u32 clk_id;
};

struct name_resp {
	char name[16];
};

struct topology_resp {
	u32 topology[3];
};

struct parents_resp {
	u32 parents[3];
};

struct attr_resp {
	u32 attr[1];
};

typedef void (*dr_release_t___17)(struct device___158 *, void *);

struct dma_chan_tbl_ent {
	struct dma_chan___3 *chan;
};

struct dmaengine_unmap_pool {
	struct kmem_cache *cache;
	const char *name;
	mempool_t *pool;
	size_t size;
};

struct dmaengine_desc_callback {
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
};

struct virt_dma_desc {
	struct dma_async_tx_descriptor___3 tx;
	struct dmaengine_result tx_result;
	struct list_head node;
};

struct virt_dma_chan {
	struct dma_chan___3 chan;
	struct tasklet_struct task;
	void (*desc_free)(struct virt_dma_desc *);
	spinlock_t lock;
	struct list_head desc_allocated;
	struct list_head desc_submitted;
	struct list_head desc_issued;
	struct list_head desc_completed;
	struct list_head desc_terminated;
	struct virt_dma_desc *cyclic;
};

typedef int (*dr_match_t___16)(struct device___158 *, void *, void *);

struct acpi_table_csrt {
	struct acpi_table_header header;
};

struct acpi_csrt_group {
	u32 length;
	u32 vendor_id;
	u32 subvendor_id;
	u16 device_id;
	u16 subdevice_id;
	u16 revision;
	u16 reserved;
	u32 shared_info_length;
};

struct acpi_csrt_shared_info {
	u16 major_version;
	u16 minor_version;
	u32 mmio_base_low;
	u32 mmio_base_high;
	u32 gsi_interrupt;
	u8 interrupt_polarity;
	u8 interrupt_mode;
	u8 num_channels;
	u8 dma_address_width;
	u16 base_request_line;
	u16 num_handshake_signals;
	u32 max_block_size;
};

struct acpi_dma_spec {
	int chan_id;
	int slave_id;
	struct device___158 *dev;
};

struct acpi_dma {
	struct list_head dma_controllers;
	struct device___158 *dev;
	struct dma_chan___3 * (*acpi_dma_xlate)(struct acpi_dma_spec *, struct acpi_dma *);
	void *data;
	short unsigned int base_request_line;
	short unsigned int end_request_line;
};

struct acpi_dma_filter_info {
	dma_cap_mask_t dma_cap;
	dma_filter_fn___3 filter_fn;
};

struct acpi_dma_parser_data {
	struct acpi_dma_spec dma_spec;
	size_t index;
	size_t n;
};

struct of_dma {
	struct list_head of_dma_controllers;
	struct device_node___61 *of_node;
	struct dma_chan___3 * (*of_dma_xlate)(struct of_phandle_args___20 *, struct of_dma *);
	void * (*of_dma_route_allocate)(struct of_phandle_args___20 *, struct of_dma *);
	struct dma_router___3 *dma_router;
	void *of_dma_data;
};

struct of_dma_filter_info {
	dma_cap_mask_t dma_cap;
	dma_filter_fn___3 filter_fn;
};

enum {
	PL08X_AHB1 = 1,
	PL08X_AHB2 = 2,
};

struct pl08x_channel_data {
	const char *bus_id;
	int min_signal;
	int max_signal;
	u32 muxval;
	dma_addr_t addr;
	bool single;
	u8 periph_buses;
};

enum pl08x_burst_size {
	PL08X_BURST_SZ_1 = 0,
	PL08X_BURST_SZ_4 = 1,
	PL08X_BURST_SZ_8 = 2,
	PL08X_BURST_SZ_16 = 3,
	PL08X_BURST_SZ_32 = 4,
	PL08X_BURST_SZ_64 = 5,
	PL08X_BURST_SZ_128 = 6,
	PL08X_BURST_SZ_256 = 7,
};

enum pl08x_bus_width {
	PL08X_BUS_WIDTH_8_BITS = 0,
	PL08X_BUS_WIDTH_16_BITS = 1,
	PL08X_BUS_WIDTH_32_BITS = 2,
};

struct pl08x_platform_data {
	struct pl08x_channel_data *slave_channels;
	unsigned int num_slave_channels;
	enum pl08x_burst_size memcpy_burst_size;
	enum pl08x_bus_width memcpy_bus_width;
	bool memcpy_prot_buff;
	bool memcpy_prot_cache;
	int (*get_xfer_signal)(const struct pl08x_channel_data *);
	void (*put_xfer_signal)(const struct pl08x_channel_data *, int);
	u8 lli_buses;
	u8 mem_buses;
	const struct dma_slave_map *slave_map;
	int slave_map_len;
};

struct vendor_data {
	u8 config_offset;
	u8 channels;
	u8 signals;
	bool dualmaster;
	bool nomadik;
	bool pl080s;
	bool ftdmac020;
	u32 max_transfer_size;
};

struct pl08x_bus_data {
	dma_addr_t addr;
	u8 maxwidth;
	u8 buswidth;
};

struct pl08x_dma_chan;

struct pl08x_phy_chan {
	unsigned int id;
	void *base;
	void *reg_config;
	void *reg_control;
	void *reg_src;
	void *reg_dst;
	void *reg_lli;
	void *reg_busy;
	spinlock_t lock;
	struct pl08x_dma_chan *serving;
	bool locked;
	bool ftdmac020;
	bool pl080s;
};

enum pl08x_dma_chan_state {
	PL08X_CHAN_IDLE = 0,
	PL08X_CHAN_RUNNING = 1,
	PL08X_CHAN_PAUSED = 2,
	PL08X_CHAN_WAITING = 3,
};

struct pl08x_txd;

struct pl08x_driver_data;

struct pl08x_dma_chan {
	struct virt_dma_chan vc;
	struct pl08x_phy_chan *phychan;
	const char *name;
	struct pl08x_channel_data *cd;
	struct dma_slave_config cfg;
	struct pl08x_txd *at;
	struct pl08x_driver_data *host;
	enum pl08x_dma_chan_state state;
	bool slave;
	int signal;
	unsigned int mux_use;
	long unsigned int waiting_at;
};

struct pl08x_sg {
	dma_addr_t src_addr;
	dma_addr_t dst_addr;
	size_t len;
	struct list_head node;
};

struct pl08x_txd {
	struct virt_dma_desc vd;
	struct list_head dsg_list;
	dma_addr_t llis_bus;
	u32 *llis_va;
	u32 cctl;
	u32 ccfg;
	bool done;
	bool cyclic;
};

struct dma_pool___2;

struct pl08x_driver_data {
	struct dma_device___3 slave;
	struct dma_device___3 memcpy;
	bool has_slave;
	void *base;
	struct amba_device *adev;
	const struct vendor_data *vd;
	struct pl08x_platform_data *pd;
	struct pl08x_phy_chan *phy_chans;
	struct dma_pool___2 *pool;
	u8 lli_buses;
	u8 mem_buses;
	u8 lli_words;
};

struct pl08x_lli_build_data {
	struct pl08x_txd *txd;
	struct pl08x_bus_data srcbus;
	struct pl08x_bus_data dstbus;
	size_t remainder;
	u32 lli_bus;
};

struct burst_table {
	u32 burstwords;
	u32 reg;
};

struct bcm2835_dmadev {
	struct dma_device___3 ddev;
	void *base;
	dma_addr_t zero_page;
};

struct bcm2835_dma_cb {
	uint32_t info;
	uint32_t src;
	uint32_t dst;
	uint32_t length;
	uint32_t stride;
	uint32_t next;
	uint32_t pad[2];
};

struct bcm2835_cb_entry {
	struct bcm2835_dma_cb *cb;
	dma_addr_t paddr;
};

struct bcm2835_desc;

struct bcm2835_chan {
	struct virt_dma_chan vc;
	struct dma_slave_config cfg;
	unsigned int dreq;
	int ch;
	struct bcm2835_desc *desc;
	struct dma_pool___2 *cb_pool;
	void *chan_base;
	int irq_number;
	unsigned int irq_flags;
	bool is_lite_channel;
};

struct bcm2835_desc {
	struct bcm2835_chan *c;
	struct virt_dma_desc vd;
	enum dma_transfer_direction dir;
	unsigned int frames;
	size_t size;
	bool cyclic;
	struct bcm2835_cb_entry cb_list[0];
};

struct mbus_dram_window {
	u8 cs_index;
	u8 mbus_attr;
	u64 base;
	u64 size;
};

struct mbus_dram_target_info {
	u8 mbus_dram_target_id;
	int num_cs;
	struct mbus_dram_window cs[4];
};

struct mv_xor_channel_data {
	dma_cap_mask_t cap_mask;
};

struct mv_xor_platform_data {
	struct mv_xor_channel_data *channels;
};

struct mv_xor_chan;

struct mv_xor_device {
	void *xor_base;
	void *xor_high_base;
	struct clk *clk;
	struct mv_xor_chan *channels[2];
	int xor_type;
	u32 win_start[8];
	u32 win_end[8];
};

struct mv_xor_chan {
	int pending;
	spinlock_t lock;
	void *mmr_base;
	void *mmr_high_base;
	unsigned int idx;
	int irq;
	struct list_head chain;
	struct list_head free_slots;
	struct list_head allocated_slots;
	struct list_head completed_slots;
	dma_addr_t dma_desc_pool;
	void *dma_desc_pool_virt;
	size_t pool_size;
	struct dma_device___3 dmadev;
	struct dma_chan___3 dmachan;
	int slots_allocated;
	struct tasklet_struct irq_tasklet;
	int op_in_desc;
	char dummy_src[128];
	char dummy_dst[128];
	dma_addr_t dummy_src_addr;
	dma_addr_t dummy_dst_addr;
	u32 saved_config_reg;
	u32 saved_int_mask_reg;
	struct mv_xor_device *xordev;
};

struct mv_xor_desc_slot {
	struct list_head node;
	struct list_head sg_tx_list;
	enum dma_transaction_type type;
	void *hw_desc;
	u16 idx;
	struct dma_async_tx_descriptor___3 async_tx;
};

struct mv_xor_desc {
	u32 status;
	u32 crc32_result;
	u32 desc_command;
	u32 phy_next_desc;
	u32 byte_count;
	u32 phy_dest_addr;
	u32 phy_src_addr[8];
	u32 reserved0;
	u32 reserved1;
};

enum mv_xor_type {
	XOR_ORION = 0,
	XOR_ARMADA_38X = 1,
	XOR_ARMADA_37XX = 2,
};

enum mv_xor_mode {
	XOR_MODE_IN_REG = 0,
	XOR_MODE_IN_DESC = 1,
};

typedef void (*irq_write_msi_msg_t___2)(struct msi_desc *, struct msi_msg *);

struct mv_xor_v2_descriptor {
	u16 desc_id;
	u16 flags;
	u32 crc32_result;
	u32 desc_ctrl;
	u32 buff_size;
	u32 fill_pattern_src_addr[4];
	u32 data_buff_addr[12];
	u32 reserved[12];
};

struct mv_xor_v2_sw_desc;

struct mv_xor_v2_device {
	spinlock_t lock;
	void *dma_base;
	void *glob_base;
	struct clk *clk;
	struct clk *reg_clk;
	struct tasklet_struct irq_tasklet;
	struct list_head free_sw_desc;
	struct dma_device___3 dmadev;
	struct dma_chan___3 dmachan;
	dma_addr_t hw_desq;
	struct mv_xor_v2_descriptor *hw_desq_virt;
	struct mv_xor_v2_sw_desc *sw_desq;
	int desc_size;
	unsigned int npendings;
	unsigned int hw_queue_idx;
	struct msi_desc *msi_desc;
};

struct mv_xor_v2_sw_desc {
	int idx;
	struct dma_async_tx_descriptor___3 async_tx;
	struct mv_xor_v2_descriptor hw_desc;
	struct list_head free_list;
};

struct mxs_dma_ccw {
	u32 next;
	u16 bits;
	u16 xfer_bytes;
	u32 bufaddr;
	u32 pio_words[16];
};

struct mxs_dma_engine;

struct mxs_dma_chan {
	struct mxs_dma_engine *mxs_dma;
	struct dma_chan___3 chan;
	struct dma_async_tx_descriptor___3 desc;
	struct tasklet_struct tasklet;
	unsigned int chan_irq;
	struct mxs_dma_ccw *ccw;
	dma_addr_t ccw_phys;
	int desc_count;
	enum dma_status status;
	unsigned int flags;
	bool reset;
};

enum mxs_dma_id {
	IMX23_DMA = 0,
	IMX28_DMA = 1,
};

enum mxs_dma_devtype {
	MXS_DMA_APBH = 0,
	MXS_DMA_APBX = 1,
};

struct mxs_dma_engine {
	enum mxs_dma_id dev_id;
	enum mxs_dma_devtype type;
	void *base;
	struct clk *clk;
	struct dma_device___3 dma_device;
	struct mxs_dma_chan mxs_chans[16];
	struct platform_device___17 *pdev;
	unsigned int nr_channels;
};

struct mxs_dma_type {
	enum mxs_dma_id id;
	enum mxs_dma_devtype type;
};

struct mxs_dma_filter_param {
	unsigned int chan_id;
};

struct idmac {
	struct dma_device___3 dma;
};

struct ipu {
	void *reg_ipu;
	void *reg_ic;
	unsigned int irq_fn;
	unsigned int irq_err;
	unsigned int irq_base;
	long unsigned int channel_init_mask;
	spinlock_t lock;
	struct clk *ipu_clk;
	struct device___158 *dev;
	struct idmac idmac;
	struct idmac_channel channel[32];
	struct tasklet_struct tasklet;
};

struct ipu_irq_bank {
	unsigned int control;
	unsigned int status;
	struct ipu *ipu;
};

struct ipu_irq_map {
	unsigned int irq;
	int source;
	struct ipu_irq_bank *bank;
	struct ipu *ipu;
};

enum ipu_color_space {
	IPU_COLORSPACE_RGB = 0,
	IPU_COLORSPACE_YCBCR = 1,
	IPU_COLORSPACE_YUV = 2,
};

enum ipu_rotate_mode {
	IPU_ROTATE_NONE = 0,
	IPU_ROTATE_VERT_FLIP = 1,
	IPU_ROTATE_HORIZ_FLIP = 2,
	IPU_ROTATE_180 = 3,
	IPU_ROTATE_90_RIGHT = 4,
	IPU_ROTATE_90_RIGHT_VFLIP = 5,
	IPU_ROTATE_90_RIGHT_HFLIP = 6,
	IPU_ROTATE_90_LEFT = 7,
};

struct chan_param_mem_planar {
	u32 xv: 10;
	u32 yv: 10;
	u32 xb: 12;
	u32 yb: 12;
	u32 res1: 2;
	u32 nsb: 1;
	u32 lnpb: 6;
	u32 ubo_l: 11;
	u32 ubo_h: 15;
	u32 vbo_l: 17;
	u32 vbo_h: 9;
	u32 res2: 3;
	u32 fw: 12;
	u32 fh_l: 8;
	u32 fh_h: 4;
	u32 res3: 28;
	long: 4;
	long: 64;
	long: 64;
	u32 eba0;
	u32 eba1;
	u32 bpp: 3;
	u32 sl: 14;
	u32 pfs: 3;
	u32 bam: 3;
	u32 res4: 2;
	u32 npb: 6;
	u32 res5: 1;
	u32 sat: 2;
	u32 res6: 30;
	long: 2;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct chan_param_mem_interleaved {
	u32 xv: 10;
	u32 yv: 10;
	u32 xb: 12;
	u32 yb: 12;
	u32 sce: 1;
	u32 res1: 1;
	u32 nsb: 1;
	u32 lnpb: 6;
	u32 sx: 10;
	u32 sy_l: 1;
	u32 sy_h: 9;
	u32 ns: 10;
	u32 sm: 10;
	u32 sdx_l: 3;
	u32 sdx_h: 2;
	u32 sdy: 5;
	u32 sdrx: 1;
	u32 sdry: 1;
	u32 sdr1: 1;
	u32 res2: 2;
	u32 fw: 12;
	u32 fh_l: 8;
	u32 fh_h: 4;
	u32 res3: 28;
	long: 4;
	long: 64;
	long: 64;
	u32 eba0;
	u32 eba1;
	u32 bpp: 3;
	u32 sl: 14;
	u32 pfs: 3;
	u32 bam: 3;
	u32 res4: 2;
	u32 npb: 6;
	u32 res5: 1;
	u32 sat: 2;
	u32 scc: 1;
	u32 ofs0: 5;
	u32 ofs1: 5;
	u32 ofs2: 5;
	u32 ofs3: 5;
	u32 wid0: 3;
	u32 wid1: 3;
	u32 wid2: 3;
	u32 wid3: 3;
	u32 dec_sel: 1;
	u32 res6: 28;
	long: 36;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union chan_param_mem {
	struct chan_param_mem_planar pp;
	struct chan_param_mem_interleaved ip;
};

struct dma_router___4 {
	struct device___22 *dev;
	void (*route_free)(struct device___22 *, void *);
};

struct dma_device___4;

struct dma_chan_dev___4;

struct dma_chan___4 {
	struct dma_device___4 *device;
	struct device___22 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___4 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___4 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___4)(struct dma_chan___4 *, void *);

struct dma_filter___4 {
	dma_filter_fn___4 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___4;

struct dma_device___4 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___4 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___22 *dev;
	struct module___26 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___4 *);
	int (*device_router_config)(struct dma_chan___4 *);
	void (*device_free_chan_resources)(struct dma_chan___4 *);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memcpy)(struct dma_chan___4 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_xor)(struct dma_chan___4 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_xor_val)(struct dma_chan___4 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_pq)(struct dma_chan___4 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_pq_val)(struct dma_chan___4 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memset)(struct dma_chan___4 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_memset_sg)(struct dma_chan___4 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_interrupt)(struct dma_chan___4 *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_slave_sg)(struct dma_chan___4 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_cyclic)(struct dma_chan___4 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_interleaved_dma)(struct dma_chan___4 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___4 * (*device_prep_dma_imm_data)(struct dma_chan___4 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___4 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___4 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___4 *);
	int (*device_resume)(struct dma_chan___4 *);
	int (*device_terminate_all)(struct dma_chan___4 *);
	void (*device_synchronize)(struct dma_chan___4 *);
	enum dma_status (*device_tx_status)(struct dma_chan___4 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___4 *);
	void (*device_release)(struct dma_device___4 *);
	void (*dbg_summary_show)(struct seq_file___25 *, struct dma_device___4 *);
	struct dentry___25 *dbg_dev_root;
};

struct dma_chan_dev___4 {
	struct dma_chan___4 *chan;
	struct device___22 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___4 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___22 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___4 {
	int (*attach)(struct dma_async_tx_descriptor___4 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___4 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___4 *, size_t);
};

struct dma_async_tx_descriptor___4 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___4 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___4 *);
	int (*desc_free)(struct dma_async_tx_descriptor___4 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___4 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___4 *metadata_ops;
	struct dma_async_tx_descriptor___4 *next;
	struct dma_async_tx_descriptor___4 *parent;
	spinlock_t lock;
};

struct of_dma___2 {
	struct list_head of_dma_controllers;
	struct device_node___15 *of_node;
	struct dma_chan___4 * (*of_dma_xlate)(struct of_phandle_args___14 *, struct of_dma___2 *);
	void * (*of_dma_route_allocate)(struct of_phandle_args___14 *, struct of_dma___2 *);
	struct dma_router___4 *dma_router;
	void *of_dma_data;
};

struct trace_event_raw_tegra_dma_tx_status {
	struct trace_entry ent;
	u32 __data_loc_chan;
	dma_cookie_t cookie;
	__u32 residue;
	char __data[0];
};

struct trace_event_raw_tegra_dma_complete_cb {
	struct trace_entry ent;
	u32 __data_loc_chan;
	int count;
	void *ptr;
	char __data[0];
};

struct trace_event_raw_tegra_dma_isr {
	struct trace_entry ent;
	u32 __data_loc_chan;
	int irq;
	char __data[0];
};

struct trace_event_data_offsets_tegra_dma_tx_status {
	u32 chan;
};

struct trace_event_data_offsets_tegra_dma_complete_cb {
	u32 chan;
};

struct trace_event_data_offsets_tegra_dma_isr {
	u32 chan;
};

typedef void (*btf_trace_tegra_dma_tx_status)(void *, struct dma_chan___4 *, dma_cookie_t, struct dma_tx_state *);

typedef void (*btf_trace_tegra_dma_complete_cb)(void *, struct dma_chan___4 *, int, void *);

typedef void (*btf_trace_tegra_dma_isr)(void *, struct dma_chan___4 *, int);

struct tegra_dma_chip_data {
	unsigned int nr_channels;
	unsigned int channel_reg_size;
	unsigned int max_dma_count;
	bool support_channel_pause;
	bool support_separate_wcount_reg;
};

struct tegra_dma_channel_regs {
	u32 csr;
	u32 ahb_ptr;
	u32 apb_ptr;
	u32 ahb_seq;
	u32 apb_seq;
	u32 wcount;
};

struct tegra_dma_desc;

struct tegra_dma_sg_req {
	struct tegra_dma_channel_regs ch_regs;
	unsigned int req_len;
	bool configured;
	bool last_sg;
	struct list_head node;
	struct tegra_dma_desc *dma_desc;
	unsigned int words_xferred;
};

struct tegra_dma_desc {
	struct dma_async_tx_descriptor___4 txd;
	unsigned int bytes_requested;
	unsigned int bytes_transferred;
	enum dma_status dma_status;
	struct list_head node;
	struct list_head tx_list;
	struct list_head cb_node;
	unsigned int cb_count;
};

struct tegra_dma_channel;

typedef void (*dma_isr_handler)(struct tegra_dma_channel *, bool);

struct tegra_dma;

struct tegra_dma_channel {
	struct dma_chan___4 dma_chan;
	char name[12];
	bool config_init;
	unsigned int id;
	void *chan_addr;
	spinlock_t lock;
	bool busy;
	struct tegra_dma *tdma;
	bool cyclic;
	struct list_head free_sg_req;
	struct list_head pending_sg_req;
	struct list_head free_dma_desc;
	struct list_head cb_desc;
	dma_isr_handler isr_handler;
	struct tasklet_struct tasklet;
	unsigned int slave_id;
	struct dma_slave_config dma_sconfig;
	struct tegra_dma_channel_regs channel_reg;
	struct wait_queue_head wq;
};

struct tegra_dma {
	struct dma_device___4 dma_dev;
	struct device___22 *dev;
	struct clk *dma_clk;
	struct reset_control *rst;
	spinlock_t global_lock;
	void *base_addr;
	const struct tegra_dma_chip_data *chip_data;
	u32 global_pause_count;
	struct tegra_dma_channel channels[0];
};

struct soc_device_attribute___3 {
	const char *machine;
	const char *family;
	const char *revision;
	const char *serial_number;
	const char *soc_id;
	const void *data;
	const struct attribute_group___183 *custom_attr_group;
};

enum k3_ring_mode {
	K3_RINGACC_RING_MODE_RING = 0,
	K3_RINGACC_RING_MODE_MESSAGE = 1,
	K3_RINGACC_RING_MODE_CREDENTIALS = 2,
	K3_RINGACC_RING_MODE_INVALID = 3,
};

enum k3_ring_size {
	K3_RINGACC_RING_ELSIZE_4 = 0,
	K3_RINGACC_RING_ELSIZE_8 = 1,
	K3_RINGACC_RING_ELSIZE_16 = 2,
	K3_RINGACC_RING_ELSIZE_32 = 3,
	K3_RINGACC_RING_ELSIZE_64 = 4,
	K3_RINGACC_RING_ELSIZE_128 = 5,
	K3_RINGACC_RING_ELSIZE_256 = 6,
	K3_RINGACC_RING_ELSIZE_INVALID = 7,
};

struct k3_ring_cfg {
	u32 size;
	enum k3_ring_size elm_size;
	enum k3_ring_mode mode;
	u32 flags;
	struct device___158 *dma_dev;
	u32 asel;
};

struct k3_ringacc_init_data {
	const struct ti_sci_handle *tisci;
	u32 tisci_dev_id;
	u32 num_rings;
};

struct k3_event_route_data {
	void *priv;
	int (*set_event)(void *, u32);
};

struct cppi5_desc_hdr_t {
	u32 pkt_info0;
	u32 pkt_info1;
	u32 pkt_info2;
	u32 src_dst_tag;
};

struct cppi5_host_desc_t {
	struct cppi5_desc_hdr_t hdr;
	u64 next_desc;
	u64 buf_ptr;
	u32 buf_info1;
	u32 org_buf_len;
	u64 org_buf_ptr;
	u32 epib[0];
};

enum cppi5_tr_types {
	CPPI5_TR_TYPE0 = 0,
	CPPI5_TR_TYPE1 = 1,
	CPPI5_TR_TYPE2 = 2,
	CPPI5_TR_TYPE3 = 3,
	CPPI5_TR_TYPE4 = 4,
	CPPI5_TR_TYPE5 = 5,
	CPPI5_TR_TYPE8 = 8,
	CPPI5_TR_TYPE9 = 9,
	CPPI5_TR_TYPE10 = 10,
	CPPI5_TR_TYPE11 = 11,
	CPPI5_TR_TYPE15 = 15,
	CPPI5_TR_TYPE_MAX = 16,
};

enum cppi5_tr_event_size {
	CPPI5_TR_EVENT_SIZE_COMPLETION = 0,
	CPPI5_TR_EVENT_SIZE_ICNT1_DEC = 1,
	CPPI5_TR_EVENT_SIZE_ICNT2_DEC = 2,
	CPPI5_TR_EVENT_SIZE_ICNT3_DEC = 3,
	CPPI5_TR_EVENT_SIZE_MAX = 4,
};

enum cppi5_tr_trigger {
	CPPI5_TR_TRIGGER_NONE = 0,
	CPPI5_TR_TRIGGER_GLOBAL0 = 1,
	CPPI5_TR_TRIGGER_GLOBAL1 = 2,
	CPPI5_TR_TRIGGER_LOCAL_EVENT = 3,
	CPPI5_TR_TRIGGER_MAX = 4,
};

enum cppi5_tr_trigger_type {
	CPPI5_TR_TRIGGER_TYPE_ICNT1_DEC = 0,
	CPPI5_TR_TRIGGER_TYPE_ICNT2_DEC = 1,
	CPPI5_TR_TRIGGER_TYPE_ICNT3_DEC = 2,
	CPPI5_TR_TRIGGER_TYPE_ALL = 3,
	CPPI5_TR_TRIGGER_TYPE_MAX = 4,
};

typedef u32 cppi5_tr_flags_t;

struct cppi5_tr_type1_t {
	cppi5_tr_flags_t flags;
	u16 icnt0;
	u16 icnt1;
	u64 addr;
	s32 dim1;
	long: 32;
	long: 64;
};

struct cppi5_tr_type15_t {
	cppi5_tr_flags_t flags;
	u16 icnt0;
	u16 icnt1;
	u64 addr;
	s32 dim1;
	u16 icnt2;
	u16 icnt3;
	s32 dim2;
	s32 dim3;
	u32 _reserved;
	s32 ddim1;
	u64 daddr;
	s32 ddim2;
	s32 ddim3;
	u16 dicnt0;
	u16 dicnt1;
	u16 dicnt2;
	u16 dicnt3;
};

struct cppi5_tr_resp_t {
	u8 status;
	u8 _reserved;
	u8 cmd_id;
	u8 flags;
};

enum udma_rm_range {
	RM_RANGE_BCHAN = 0,
	RM_RANGE_TCHAN = 1,
	RM_RANGE_RCHAN = 2,
	RM_RANGE_RFLOW = 3,
	RM_RANGE_TFLOW = 4,
	RM_RANGE_LAST = 5,
};

struct udma_tisci_rm {
	const struct ti_sci_handle *tisci;
	const struct ti_sci_rm_udmap_ops *tisci_udmap_ops;
	u32 tisci_dev_id;
	const struct ti_sci_rm_psil_ops *tisci_psil_ops;
	u32 tisci_navss_dev_id;
	struct ti_sci_resource *rm_ranges[5];
};

enum udma_tp_level {
	UDMA_TP_NORMAL = 0,
	UDMA_TP_HIGH = 1,
	UDMA_TP_ULTRAHIGH = 2,
	UDMA_TP_LAST = 3,
};

enum psil_endpoint_type {
	PSIL_EP_NATIVE = 0,
	PSIL_EP_PDMA_XY = 1,
	PSIL_EP_PDMA_MCAN = 2,
	PSIL_EP_PDMA_AASRC = 3,
};

struct psil_endpoint_config {
	enum psil_endpoint_type ep_type;
	enum udma_tp_level channel_tpl;
	unsigned int pkt_mode: 1;
	unsigned int notdpkt: 1;
	unsigned int needs_epib: 1;
	unsigned int pdma_acc32: 1;
	unsigned int pdma_burst: 1;
	long: 31;
	long: 64;
	u32 psd_size;
	s16 mapped_channel_id;
	u16 flow_start;
	u16 flow_num;
	s16 default_flow_id;
};

struct udma_static_tr {
	u8 elsize;
	u16 elcnt;
	u16 bstcnt;
};

enum k3_dma_type {
	DMA_TYPE_UDMA = 0,
	DMA_TYPE_BCDMA = 1,
	DMA_TYPE_PKTDMA = 2,
};

enum udma_mmr {
	MMR_GCFG = 0,
	MMR_BCHANRT = 1,
	MMR_RCHANRT = 2,
	MMR_TCHANRT = 3,
	MMR_LAST = 4,
};

struct k3_ring;

struct udma_tchan {
	void *reg_rt;
	int id;
	struct k3_ring *t_ring;
	struct k3_ring *tc_ring;
	int tflow_id;
};

struct udma_rflow {
	int id;
	struct k3_ring *fd_ring;
	struct k3_ring *r_ring;
};

struct udma_rchan {
	void *reg_rt;
	int id;
};

struct udma_oes_offsets {
	u32 udma_rchan;
	u32 bcdma_bchan_data;
	u32 bcdma_bchan_ring;
	u32 bcdma_tchan_data;
	u32 bcdma_tchan_ring;
	u32 bcdma_rchan_data;
	u32 bcdma_rchan_ring;
	u32 pktdma_tchan_flow;
	u32 pktdma_rchan_flow;
};

struct udma_match_data {
	enum k3_dma_type type;
	u32 psil_base;
	bool enable_memcpy_support;
	u32 flags;
	u32 statictr_z_mask;
	u8 burst_size[3];
};

struct udma_soc_data {
	struct udma_oes_offsets oes;
	u32 bcdma_trigger_event_offset;
};

struct udma_hwdesc {
	size_t cppi5_desc_size;
	void *cppi5_desc_vaddr;
	dma_addr_t cppi5_desc_paddr;
	void *tr_req_base;
	struct cppi5_tr_resp_t *tr_resp_base;
};

struct udma_rx_flush {
	struct udma_hwdesc hwdescs[2];
	size_t buffer_size;
	void *buffer_vaddr;
	dma_addr_t buffer_paddr;
};

struct udma_tpl {
	u8 levels;
	u32 start_idx[3];
};

struct k3_ringacc;

struct udma_chan;

struct udma_dev {
	struct dma_device___3 ddev;
	struct device___158 *dev;
	void *mmrs[4];
	const struct udma_match_data *match_data;
	const struct udma_soc_data *soc_data;
	struct udma_tpl bchan_tpl;
	struct udma_tpl tchan_tpl;
	struct udma_tpl rchan_tpl;
	size_t desc_align;
	struct udma_tisci_rm tisci_rm;
	struct k3_ringacc *ringacc;
	struct work_struct purge_work;
	struct list_head desc_to_purge;
	spinlock_t lock;
	struct udma_rx_flush rx_flush;
	int bchan_cnt;
	int tchan_cnt;
	int echan_cnt;
	int rchan_cnt;
	int rflow_cnt;
	int tflow_cnt;
	long unsigned int *bchan_map;
	long unsigned int *tchan_map;
	long unsigned int *rchan_map;
	long unsigned int *rflow_gp_map;
	long unsigned int *rflow_gp_map_allocated;
	long unsigned int *rflow_in_use;
	long unsigned int *tflow_map;
	struct udma_tchan *bchans;
	struct udma_tchan *tchans;
	struct udma_rchan *rchans;
	struct udma_rflow *rflows;
	struct udma_chan *channels;
	u32 psil_base;
	u32 atype;
	u32 asel;
};

enum udma_chan_state {
	UDMA_CHAN_IS_IDLE = 0,
	UDMA_CHAN_IS_ACTIVE = 1,
	UDMA_CHAN_IS_TERMINATING = 2,
};

struct udma_tx_drain {
	struct delayed_work work;
	ktime_t tstamp;
	u32 residue;
};

struct udma_chan_config {
	bool pkt_mode;
	bool needs_epib;
	u32 psd_size;
	u32 metadata_size;
	u32 hdesc_size;
	bool notdpkt;
	int remote_thread_id;
	u32 atype;
	u32 asel;
	u32 src_thread;
	u32 dst_thread;
	enum psil_endpoint_type ep_type;
	bool enable_acc32;
	bool enable_burst;
	enum udma_tp_level channel_tpl;
	u32 tr_trigger_type;
	int mapped_channel_id;
	int default_flow_id;
	enum dma_transfer_direction dir;
};

struct udma_desc;

struct udma_chan {
	struct virt_dma_chan vc;
	struct dma_slave_config cfg;
	struct udma_dev *ud;
	struct device___158 *dma_dev;
	struct udma_desc *desc;
	struct udma_desc *terminated_desc;
	struct udma_static_tr static_tr;
	char *name;
	struct udma_tchan *bchan;
	struct udma_tchan *tchan;
	struct udma_rchan *rchan;
	struct udma_rflow *rflow;
	bool psil_paired;
	int irq_num_ring;
	int irq_num_udma;
	bool cyclic;
	bool paused;
	enum udma_chan_state state;
	struct completion teardown_completed;
	struct udma_tx_drain tx_drain;
	u32 bcnt;
	struct udma_chan_config config;
	bool use_dma_pool;
	struct dma_pool___2 *hdesc_pool;
	u32 id;
};

struct udma_desc {
	struct virt_dma_desc vd;
	bool terminated;
	enum dma_transfer_direction dir;
	struct udma_static_tr static_tr;
	u32 residue;
	unsigned int sglen;
	unsigned int desc_idx;
	unsigned int tr_idx;
	u32 metadata_size;
	void *metadata;
	unsigned int hwdesc_count;
	struct udma_hwdesc hwdesc[0];
};

struct udma_filter_param {
	int remote_thread_id;
	u32 atype;
	u32 asel;
	u32 tr_trigger_type;
};

struct k3_udma_glue_tx_channel_cfg {
	struct k3_ring_cfg tx_cfg;
	struct k3_ring_cfg txcq_cfg;
	bool tx_pause_on_err;
	bool tx_filt_einfo;
	bool tx_filt_pswords;
	bool tx_supr_tdpkt;
	u32 swdata_size;
};

struct k3_udma_glue_rx_flow_cfg {
	struct k3_ring_cfg rx_cfg;
	struct k3_ring_cfg rxfdq_cfg;
	int ring_rxq_id;
	int ring_rxfdq0_id;
	bool rx_error_handling;
	int src_tag_lo_sel;
};

struct k3_udma_glue_rx_channel_cfg {
	u32 swdata_size;
	int flow_id_base;
	int flow_id_num;
	bool flow_id_use_rxchan_id;
	bool remote;
	struct k3_udma_glue_rx_flow_cfg *def_flow_cfg;
};

struct udma_dev___2;

struct k3_udma_glue_common {
	struct device___158 *dev;
	struct device___158 chan_dev;
	struct udma_dev___2 *udmax;
	const struct udma_tisci_rm *tisci_rm;
	struct k3_ringacc *ringacc;
	u32 src_thread;
	u32 dst_thread;
	u32 hdesc_size;
	bool epib;
	u32 psdata_size;
	u32 swdata_size;
	u32 atype_asel;
	struct psil_endpoint_config *ep_config;
};

struct udma_tchan___2;

struct k3_udma_glue_tx_channel {
	struct k3_udma_glue_common common;
	struct udma_tchan___2 *udma_tchanx;
	int udma_tchan_id;
	struct k3_ring *ringtx;
	struct k3_ring *ringtxcq;
	bool psil_paired;
	int virq;
	atomic_t free_pkts;
	bool tx_pause_on_err;
	bool tx_filt_einfo;
	bool tx_filt_pswords;
	bool tx_supr_tdpkt;
	int udma_tflow_id;
};

struct udma_rflow___2;

struct k3_udma_glue_rx_flow {
	struct udma_rflow___2 *udma_rflow;
	int udma_rflow_id;
	struct k3_ring *ringrx;
	struct k3_ring *ringrxfdq;
	int virq;
};

struct udma_rchan___2;

struct k3_udma_glue_rx_channel {
	struct k3_udma_glue_common common;
	struct udma_rchan___2 *udma_rchanx;
	int udma_rchan_id;
	bool remote;
	bool psil_paired;
	u32 swdata_size;
	int flow_id_base;
	struct k3_udma_glue_rx_flow *flows;
	u32 flow_num;
	u32 flows_ready;
};

struct psil_ep {
	u32 thread_id;
	struct psil_endpoint_config ep_config;
};

struct psil_ep_map {
	char *name;
	struct psil_ep *src;
	int src_count;
	struct psil_ep *dst;
	int dst_count;
};

struct psil_endpoint_config___2 {
	enum psil_endpoint_type ep_type;
	enum udma_tp_level channel_tpl;
	unsigned int pkt_mode;
	unsigned int notdpkt;
	unsigned int needs_epib;
	unsigned int pdma_acc32;
	unsigned int pdma_burst;
	long: 64;
	u32 psd_size;
	s16 mapped_channel_id;
	u16 flow_start;
	u16 flow_num;
	s16 default_flow_id;
};

struct psil_ep___2 {
	u32 thread_id;
	struct psil_endpoint_config___2 ep_config;
};

struct psil_ep_map___2 {
	char *name;
	struct psil_ep___2 *src;
	int src_count;
	struct psil_ep___2 *dst;
	int dst_count;
};

struct dev_power_governor___2 {
	bool (*power_down_ok)(struct dev_pm_domain___159 *);
	bool (*suspend_ok)(struct device___159 *);
};

struct gpd_dev_ops___2 {
	int (*start)(struct device___159 *);
	int (*stop)(struct device___159 *);
};

struct genpd_power_state___2 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___159 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct generic_pm_domain___3 {
	struct device___159 dev;
	struct dev_pm_domain___159 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor___2 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___159 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain___3 *);
	int (*power_on)(struct generic_pm_domain___3 *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___3 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___3 *, unsigned int);
	struct gpd_dev_ops___2 dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain___3 *, struct device___159 *);
	void (*detach_dev)(struct generic_pm_domain___3 *, struct device___159 *);
	unsigned int flags;
	struct genpd_power_state___2 *states;
	void (*free_states)(struct genpd_power_state___2 *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

typedef struct generic_pm_domain___3 * (*genpd_xlate_t___2)(struct of_phandle_args___27 *, void *);

struct genpd_onecell_data___2 {
	struct generic_pm_domain___3 **domains;
	unsigned int num_domains;
	genpd_xlate_t___2 xlate;
};

struct owl_sps_domain_info {
	const char *name;
	int pwr_bit;
	int ack_bit;
	unsigned int genpd_flags;
};

struct owl_sps_info {
	unsigned int num_domains;
	const struct owl_sps_domain_info *domains;
};

struct owl_sps {
	struct device___159 *dev;
	const struct owl_sps_info *info;
	void *base;
	struct genpd_onecell_data___2 genpd_data;
	struct generic_pm_domain___3 *domains[0];
};

struct owl_sps_domain {
	struct generic_pm_domain___3 genpd;
	const struct owl_sps_domain_info *info;
	struct owl_sps *sps;
};

struct bcm2835_pm {
	struct device___156 *dev;
	void *base;
	void *asb;
};

struct platform_driver___19 {
	int (*probe)(struct platform_device___19 *);
	int (*remove)(struct platform_device___19 *);
	void (*shutdown)(struct platform_device___19 *);
	int (*suspend)(struct platform_device___19 *, pm_message_t);
	int (*resume)(struct platform_device___19 *);
	struct device_driver___156 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct dev_power_governor___3 {
	bool (*power_down_ok)(struct dev_pm_domain___156 *);
	bool (*suspend_ok)(struct device___156 *);
};

struct gpd_dev_ops___3 {
	int (*start)(struct device___156 *);
	int (*stop)(struct device___156 *);
};

struct genpd_power_state___3 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___156 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct generic_pm_domain___4 {
	struct device___156 dev;
	struct dev_pm_domain___156 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor___3 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___156 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain___4 *);
	int (*power_on)(struct generic_pm_domain___4 *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___4 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___4 *, unsigned int);
	struct gpd_dev_ops___3 dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain___4 *, struct device___156 *);
	void (*detach_dev)(struct generic_pm_domain___4 *, struct device___156 *);
	unsigned int flags;
	struct genpd_power_state___3 *states;
	void (*free_states)(struct genpd_power_state___3 *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

typedef struct generic_pm_domain___4 * (*genpd_xlate_t___3)(struct of_phandle_args___21 *, void *);

struct genpd_onecell_data___3 {
	struct generic_pm_domain___4 **domains;
	unsigned int num_domains;
	genpd_xlate_t___3 xlate;
};

struct bcm2835_power;

struct bcm2835_power_domain {
	struct generic_pm_domain___4 base;
	struct bcm2835_power *power;
	u32 domain;
	struct clk *clk;
};

struct bcm2835_power {
	struct device___156 *dev;
	void *base;
	void *asb;
	struct genpd_onecell_data___3 pd_xlate;
	struct bcm2835_power_domain domains[13];
	struct reset_controller_dev___3 reset;
};

enum rpi_firmware_property_tag {
	RPI_FIRMWARE_PROPERTY_END = 0,
	RPI_FIRMWARE_GET_FIRMWARE_REVISION = 1,
	RPI_FIRMWARE_SET_CURSOR_INFO = 32784,
	RPI_FIRMWARE_SET_CURSOR_STATE = 32785,
	RPI_FIRMWARE_GET_BOARD_MODEL = 65537,
	RPI_FIRMWARE_GET_BOARD_REVISION = 65538,
	RPI_FIRMWARE_GET_BOARD_MAC_ADDRESS = 65539,
	RPI_FIRMWARE_GET_BOARD_SERIAL = 65540,
	RPI_FIRMWARE_GET_ARM_MEMORY = 65541,
	RPI_FIRMWARE_GET_VC_MEMORY = 65542,
	RPI_FIRMWARE_GET_CLOCKS = 65543,
	RPI_FIRMWARE_GET_POWER_STATE = 131073,
	RPI_FIRMWARE_GET_TIMING = 131074,
	RPI_FIRMWARE_SET_POWER_STATE = 163841,
	RPI_FIRMWARE_GET_CLOCK_STATE = 196609,
	RPI_FIRMWARE_GET_CLOCK_RATE = 196610,
	RPI_FIRMWARE_GET_VOLTAGE = 196611,
	RPI_FIRMWARE_GET_MAX_CLOCK_RATE = 196612,
	RPI_FIRMWARE_GET_MAX_VOLTAGE = 196613,
	RPI_FIRMWARE_GET_TEMPERATURE = 196614,
	RPI_FIRMWARE_GET_MIN_CLOCK_RATE = 196615,
	RPI_FIRMWARE_GET_MIN_VOLTAGE = 196616,
	RPI_FIRMWARE_GET_TURBO = 196617,
	RPI_FIRMWARE_GET_MAX_TEMPERATURE = 196618,
	RPI_FIRMWARE_GET_STC = 196619,
	RPI_FIRMWARE_ALLOCATE_MEMORY = 196620,
	RPI_FIRMWARE_LOCK_MEMORY = 196621,
	RPI_FIRMWARE_UNLOCK_MEMORY = 196622,
	RPI_FIRMWARE_RELEASE_MEMORY = 196623,
	RPI_FIRMWARE_EXECUTE_CODE = 196624,
	RPI_FIRMWARE_EXECUTE_QPU = 196625,
	RPI_FIRMWARE_SET_ENABLE_QPU = 196626,
	RPI_FIRMWARE_GET_DISPMANX_RESOURCE_MEM_HANDLE = 196628,
	RPI_FIRMWARE_GET_EDID_BLOCK = 196640,
	RPI_FIRMWARE_GET_CUSTOMER_OTP = 196641,
	RPI_FIRMWARE_GET_DOMAIN_STATE = 196656,
	RPI_FIRMWARE_GET_THROTTLED = 196678,
	RPI_FIRMWARE_GET_CLOCK_MEASURED = 196679,
	RPI_FIRMWARE_NOTIFY_REBOOT = 196680,
	RPI_FIRMWARE_SET_CLOCK_STATE = 229377,
	RPI_FIRMWARE_SET_CLOCK_RATE = 229378,
	RPI_FIRMWARE_SET_VOLTAGE = 229379,
	RPI_FIRMWARE_SET_TURBO = 229385,
	RPI_FIRMWARE_SET_CUSTOMER_OTP = 229409,
	RPI_FIRMWARE_SET_DOMAIN_STATE = 229424,
	RPI_FIRMWARE_GET_GPIO_STATE = 196673,
	RPI_FIRMWARE_SET_GPIO_STATE = 229441,
	RPI_FIRMWARE_SET_SDHOST_CLOCK = 229442,
	RPI_FIRMWARE_GET_GPIO_CONFIG = 196675,
	RPI_FIRMWARE_SET_GPIO_CONFIG = 229443,
	RPI_FIRMWARE_GET_PERIPH_REG = 196677,
	RPI_FIRMWARE_SET_PERIPH_REG = 229445,
	RPI_FIRMWARE_GET_POE_HAT_VAL = 196681,
	RPI_FIRMWARE_SET_POE_HAT_VAL = 196688,
	RPI_FIRMWARE_NOTIFY_XHCI_RESET = 196696,
	RPI_FIRMWARE_FRAMEBUFFER_ALLOCATE = 262145,
	RPI_FIRMWARE_FRAMEBUFFER_BLANK = 262146,
	RPI_FIRMWARE_FRAMEBUFFER_GET_PHYSICAL_WIDTH_HEIGHT = 262147,
	RPI_FIRMWARE_FRAMEBUFFER_GET_VIRTUAL_WIDTH_HEIGHT = 262148,
	RPI_FIRMWARE_FRAMEBUFFER_GET_DEPTH = 262149,
	RPI_FIRMWARE_FRAMEBUFFER_GET_PIXEL_ORDER = 262150,
	RPI_FIRMWARE_FRAMEBUFFER_GET_ALPHA_MODE = 262151,
	RPI_FIRMWARE_FRAMEBUFFER_GET_PITCH = 262152,
	RPI_FIRMWARE_FRAMEBUFFER_GET_VIRTUAL_OFFSET = 262153,
	RPI_FIRMWARE_FRAMEBUFFER_GET_OVERSCAN = 262154,
	RPI_FIRMWARE_FRAMEBUFFER_GET_PALETTE = 262155,
	RPI_FIRMWARE_FRAMEBUFFER_GET_TOUCHBUF = 262159,
	RPI_FIRMWARE_FRAMEBUFFER_GET_GPIOVIRTBUF = 262160,
	RPI_FIRMWARE_FRAMEBUFFER_RELEASE = 294913,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_PHYSICAL_WIDTH_HEIGHT = 278531,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_VIRTUAL_WIDTH_HEIGHT = 278532,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_DEPTH = 278533,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_PIXEL_ORDER = 278534,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_ALPHA_MODE = 278535,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_VIRTUAL_OFFSET = 278537,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_OVERSCAN = 278538,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_PALETTE = 278539,
	RPI_FIRMWARE_FRAMEBUFFER_TEST_VSYNC = 278542,
	RPI_FIRMWARE_FRAMEBUFFER_SET_PHYSICAL_WIDTH_HEIGHT = 294915,
	RPI_FIRMWARE_FRAMEBUFFER_SET_VIRTUAL_WIDTH_HEIGHT = 294916,
	RPI_FIRMWARE_FRAMEBUFFER_SET_DEPTH = 294917,
	RPI_FIRMWARE_FRAMEBUFFER_SET_PIXEL_ORDER = 294918,
	RPI_FIRMWARE_FRAMEBUFFER_SET_ALPHA_MODE = 294919,
	RPI_FIRMWARE_FRAMEBUFFER_SET_VIRTUAL_OFFSET = 294921,
	RPI_FIRMWARE_FRAMEBUFFER_SET_OVERSCAN = 294922,
	RPI_FIRMWARE_FRAMEBUFFER_SET_PALETTE = 294923,
	RPI_FIRMWARE_FRAMEBUFFER_SET_TOUCHBUF = 294943,
	RPI_FIRMWARE_FRAMEBUFFER_SET_GPIOVIRTBUF = 294944,
	RPI_FIRMWARE_FRAMEBUFFER_SET_VSYNC = 294926,
	RPI_FIRMWARE_FRAMEBUFFER_SET_BACKLIGHT = 294927,
	RPI_FIRMWARE_VCHIQ_INIT = 294928,
	RPI_FIRMWARE_GET_COMMAND_LINE = 327681,
	RPI_FIRMWARE_GET_DMA_CHANNELS = 393217,
};

struct rpi_firmware;

struct rpi_power_domain {
	u32 domain;
	bool enabled;
	bool old_interface;
	struct generic_pm_domain___4 base;
	struct rpi_firmware *fw;
};

struct rpi_power_domains {
	bool has_new_interface;
	struct genpd_onecell_data___3 xlate;
	struct rpi_firmware *fw;
	struct rpi_power_domain domains[23];
};

struct rpi_power_domain_packet {
	u32 domain;
	u32 on;
};

struct bcm_pmb {
	struct device___156 *dev;
	void *base;
	spinlock_t lock;
	bool little_endian;
	struct genpd_onecell_data___3 genpd_onecell_data;
};

struct bcm_pmb_pd_data {
	const char * const name;
	int id;
	u8 bus;
	u8 device;
};

struct bcm_pmb_pm_domain {
	struct bcm_pmb *pmb;
	const struct bcm_pmb_pd_data *data;
	struct generic_pm_domain___4 genpd;
};

struct soc_device;

enum cpubiuctrl_regs {
	CPU_CREDIT_REG = 0,
	CPU_MCP_FLOW_REG = 1,
	CPU_WRITEBACK_CTRL_REG = 2,
	RAC_CONFIG0_REG = 3,
	RAC_CONFIG1_REG = 4,
	NUM_CPU_BIUCTRL_REGS = 5,
};

struct reserved_mem_ops___4;

struct reserved_mem___4 {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops___4 *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops___4 {
	int (*device_init)(struct reserved_mem___4 *, struct device___158 *);
	void (*device_release)(struct reserved_mem___4 *, struct device___158 *);
};

typedef int (*reservedmem_of_init_fn___4)(struct reserved_mem___4 *);

struct bman_hwerr_txt {
	u32 mask;
	const char *txt;
};

struct platform_device___22 {
	const char *name;
	int id;
	bool id_auto;
	struct device___155 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___20 {
	int (*probe)(struct platform_device___22 *);
	int (*remove)(struct platform_device___22 *);
	void (*shutdown)(struct platform_device___22 *);
	int (*suspend)(struct platform_device___22 *, pm_message_t);
	int (*resume)(struct platform_device___22 *);
	struct device_driver___155 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum qm_wq_class {
	qm_wq_portal = 0,
	qm_wq_pool = 1,
	qm_wq_fman0 = 2,
	qm_wq_fman1 = 3,
	qm_wq_caam = 4,
	qm_wq_pme = 5,
	qm_wq_first = 0,
	qm_wq_last = 5,
};

enum qm_memory {
	qm_memory_fqd = 0,
	qm_memory_pfdr = 1,
};

struct qm_ecir {
	u32 info;
};

struct qm_ecir2 {
	u32 info;
};

struct qm_eadr {
	u32 info;
};

struct qman_hwerr_txt {
	u32 mask;
	const char *txt;
};

struct qman_error_info_mdata {
	u16 addr_mask;
	u16 bits;
	const char *txt;
};

enum qm_dc_portal {
	qm_dc_portal_fman0 = 0,
	qm_dc_portal_fman1 = 1,
};

struct bm_portal_config {
	void *addr_virt_ce;
	void *addr_virt_ci;
	struct list_head list;
	struct device___157 *dev;
	int cpu;
	int irq;
};

struct bman_portal;

struct qman_portal;

struct __qm_mcr_querycongestion {
	u32 state[8];
};

struct qman_cgrs {
	struct __qm_mcr_querycongestion q;
};

struct qm_portal_config {
	void *addr_virt_ce;
	void *addr_virt_ci;
	struct device___157 *dev;
	struct iommu_domain___7 *iommu_domain;
	struct list_head list;
	int cpu;
	int irq;
	u16 channel;
	u32 pools;
};

struct bm_buffer {
	union {
		struct {
			__be16 bpid;
			__be16 hi;
			__be32 lo;
		};
		__be64 data;
	};
};

struct bm_portal_config___2 {
	void *addr_virt_ce;
	void *addr_virt_ci;
	struct list_head list;
	struct device___158 *dev;
	int cpu;
	int irq;
};

enum bm_rcr_pmode {
	bm_rcr_pci = 0,
	bm_rcr_pce = 1,
	bm_rcr_pvb = 2,
};

enum bm_rcr_cmode {
	bm_rcr_cci = 0,
	bm_rcr_cce = 1,
};

struct bm_rcr_entry {
	union {
		struct {
			u8 _ncw_verb;
			u8 bpid;
			u8 __reserved1[62];
		};
		struct bm_buffer bufs[8];
	};
};

struct bm_rcr {
	struct bm_rcr_entry *ring;
	struct bm_rcr_entry *cursor;
	u8 ci;
	u8 available;
	u8 ithresh;
	u8 vbit;
	u32 busy;
	enum bm_rcr_pmode pmode;
	enum bm_rcr_cmode cmode;
};

struct bm_mc_command {
	u8 _ncw_verb;
	u8 bpid;
	u8 __reserved[62];
};

union bm_mc_result {
	struct {
		u8 verb;
		u8 bpid;
		u8 __reserved[62];
	};
	struct bm_buffer bufs[8];
};

struct bm_mc {
	struct bm_mc_command *cr;
	union bm_mc_result *rr;
	u8 rridx;
	u8 vbit;
	enum {
		mc_idle = 0,
		mc_user = 1,
		mc_hw = 2,
	} state;
};

struct bm_addr {
	void *ce;
	__be32 *ce_be;
	void *ci;
};

struct bm_portal {
	struct bm_addr addr;
	struct bm_rcr rcr;
	struct bm_mc mc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bman_portal___2 {
	struct bm_portal p;
	long unsigned int irq_sources;
	const struct bm_portal_config___2 *config;
	char irqname[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bman_pool {
	u32 bpid;
	struct bman_portal___2 *portal;
	struct bman_pool *next;
};

struct device_link___13 {
	struct device___155 *supplier;
	struct list_head s_node;
	struct device___155 *consumer;
	struct list_head c_node;
	struct device___155 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct qm_fd {
	union {
		struct {
			u8 cfg8b_w1;
			u8 bpid;
			u8 cfg8b_w3;
			u8 addr_hi;
			__be32 addr_lo;
		};
		__be64 data;
	};
	__be32 cfg;
	union {
		__be32 cmd;
		__be32 status;
	};
};

struct qm_dqrr_entry {
	u8 verb;
	u8 stat;
	__be16 seqnum;
	u8 tok;
	u8 __reserved2[3];
	__be32 fqid;
	__be32 context_b;
	struct qm_fd fd;
	u8 __reserved4[32];
};

union qm_mr_entry {
	struct {
		u8 verb;
		u8 __reserved[63];
	};
	struct {
		u8 verb;
		u8 dca;
		__be16 seqnum;
		u8 rc;
		u8 __reserved[3];
		__be32 fqid;
		__be32 tag;
		struct qm_fd fd;
		u8 __reserved1[32];
	} ern;
	struct {
		u8 verb;
		u8 fqs;
		u8 __reserved1[6];
		__be32 fqid;
		__be32 context_b;
		u8 __reserved2[48];
	} fq;
};

struct qm_fqd_stashing {
	u8 exclusive;
	u8 cl;
};

struct qm_fqd_oac {
	u8 oac;
	s8 oal;
};

struct qm_fqd {
	u8 orpc;
	u8 cgid;
	__be16 fq_ctrl;
	__be16 dest_wq;
	__be16 ics_cred;
	union {
		__be16 td;
		struct qm_fqd_oac oac_init;
	};
	__be32 context_b;
	union {
		__be64 opaque;
		struct {
			__be32 hi;
			__be32 lo;
		};
		struct {
			struct qm_fqd_stashing stashing;
			__be16 context_hi;
			__be32 context_lo;
		};
	} context_a;
	struct qm_fqd_oac oac_query;
} __attribute__((packed));

struct qm_cgr_wr_parm {
	__be32 word;
};

struct qm_cgr_cs_thres {
	__be16 word;
};

struct __qm_mc_cgr {
	struct qm_cgr_wr_parm wr_parm_g;
	struct qm_cgr_wr_parm wr_parm_y;
	struct qm_cgr_wr_parm wr_parm_r;
	u8 wr_en_g;
	u8 wr_en_y;
	u8 wr_en_r;
	u8 cscn_en;
	union {
		struct {
			__be16 cscn_targ_upd_ctrl;
			__be16 cscn_targ_dcp_low;
		};
		__be32 cscn_targ;
	};
	u8 cstd_en;
	u8 cs;
	struct qm_cgr_cs_thres cs_thres;
	u8 mode;
} __attribute__((packed));

struct qm_mcc_initfq {
	u8 __reserved1[2];
	__be16 we_mask;
	__be32 fqid;
	__be16 count;
	struct qm_fqd fqd;
	u8 __reserved2[30];
} __attribute__((packed));

struct qm_mcc_initcgr {
	u8 __reserve1[2];
	__be16 we_mask;
	struct __qm_mc_cgr cgr;
	u8 __reserved2[2];
	u8 cgid;
	u8 __reserved3[32];
};

enum qman_cb_dqrr_result {
	qman_cb_dqrr_consume = 0,
	qman_cb_dqrr_park = 1,
	qman_cb_dqrr_defer = 2,
	qman_cb_dqrr_stop = 3,
	qman_cb_dqrr_consume_stop = 4,
};

struct qman_portal___2;

struct qman_fq;

typedef enum qman_cb_dqrr_result (*qman_cb_dqrr)(struct qman_portal___2 *, struct qman_fq *, const struct qm_dqrr_entry *, bool);

struct qm_addr {
	void *ce;
	__be32 *ce_be;
	void *ci;
};

enum qm_eqcr_pmode {
	qm_eqcr_pci = 0,
	qm_eqcr_pce = 1,
	qm_eqcr_pvb = 2,
};

struct qm_eqcr_entry;

struct qm_eqcr {
	struct qm_eqcr_entry *ring;
	struct qm_eqcr_entry *cursor;
	u8 ci;
	u8 available;
	u8 ithresh;
	u8 vbit;
	u32 busy;
	enum qm_eqcr_pmode pmode;
};

enum qm_dqrr_dmode {
	qm_dqrr_dpush = 0,
	qm_dqrr_dpull = 1,
};

enum qm_dqrr_pmode {
	qm_dqrr_pci = 0,
	qm_dqrr_pce = 1,
	qm_dqrr_pvb = 2,
};

enum qm_dqrr_cmode {
	qm_dqrr_cci = 0,
	qm_dqrr_cce = 1,
	qm_dqrr_cdc = 2,
};

struct qm_dqrr {
	const struct qm_dqrr_entry *ring;
	const struct qm_dqrr_entry *cursor;
	u8 pi;
	u8 ci;
	u8 fill;
	u8 ithresh;
	u8 vbit;
	enum qm_dqrr_dmode dmode;
	enum qm_dqrr_pmode pmode;
	enum qm_dqrr_cmode cmode;
};

enum qm_mr_pmode {
	qm_mr_pci = 0,
	qm_mr_pce = 1,
	qm_mr_pvb = 2,
};

enum qm_mr_cmode {
	qm_mr_cci = 0,
	qm_mr_cce = 1,
};

struct qm_mr {
	union qm_mr_entry *ring;
	union qm_mr_entry *cursor;
	u8 pi;
	u8 ci;
	u8 fill;
	u8 ithresh;
	u8 vbit;
	enum qm_mr_pmode pmode;
	enum qm_mr_cmode cmode;
};

union qm_mc_command;

union qm_mc_result;

struct qm_mc {
	union qm_mc_command *cr;
	union qm_mc_result *rr;
	u8 rridx;
	u8 vbit;
	enum {
		qman_mc_idle = 0,
		qman_mc_user = 1,
		qman_mc_hw = 2,
	} state;
};

struct qm_portal {
	struct qm_addr addr;
	struct qm_eqcr eqcr;
	struct qm_dqrr dqrr;
	struct qm_mr mr;
	struct qm_mc mc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct qm_portal_config___2;

struct qman_portal___2 {
	struct qm_portal p;
	long unsigned int bits;
	long unsigned int irq_sources;
	u32 use_eqcr_ci_stashing;
	struct qman_fq *vdqcr_owned;
	u32 sdqcr;
	const struct qm_portal_config___2 *config;
	struct qman_cgrs *cgrs;
	struct list_head cgr_cbs;
	spinlock_t cgr_lock;
	struct work_struct congestion_work;
	struct work_struct mr_work;
	char irqname[16];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*qman_cb_mr)(struct qman_portal___2 *, struct qman_fq *, const union qm_mr_entry *);

struct qman_fq_cb {
	qman_cb_dqrr dqrr;
	qman_cb_mr ern;
	qman_cb_mr fqs;
};

enum qman_fq_state {
	qman_fq_state_oos = 0,
	qman_fq_state_parked = 1,
	qman_fq_state_sched = 2,
	qman_fq_state_retired = 3,
};

struct qman_fq {
	struct qman_fq_cb cb;
	u32 fqid;
	u32 idx;
	long unsigned int flags;
	enum qman_fq_state state;
	int cgr_groupid;
};

struct qman_cgr;

typedef void (*qman_cb_cgr)(struct qman_portal___2 *, struct qman_cgr *, int);

struct qman_cgr {
	u32 cgrid;
	qman_cb_cgr cb;
	u16 chan;
	struct list_head node;
};

struct qm_mcr_queryfq_np {
	u8 verb;
	u8 result;
	u8 __reserved1;
	u8 state;
	u32 fqd_link;
	u16 odp_seq;
	u16 orp_nesn;
	u16 orp_ea_hseq;
	u16 orp_ea_tseq;
	u32 orp_ea_hptr;
	u32 orp_ea_tptr;
	u32 pfdr_hptr;
	u32 pfdr_tptr;
	u8 __reserved2[5];
	u8 is;
	u16 ics_surp;
	u32 byte_cnt;
	u32 frm_cnt;
	u32 __reserved3;
	u16 ra1_sfdr;
	u16 ra2_sfdr;
	u16 __reserved4;
	u16 od1_sfdr;
	u16 od2_sfdr;
	u16 od3_sfdr;
};

struct qm_mcr_querywq {
	u8 verb;
	u8 result;
	u16 channel_wq;
	u8 __reserved[28];
	u32 wq_len[8];
};

struct qm_mcr_querycongestion {
	u8 verb;
	u8 result;
	u8 __reserved[30];
	struct __qm_mcr_querycongestion state;
};

struct qm_mcr_querycgr {
	u8 verb;
	u8 result;
	u16 __reserved1;
	struct __qm_mc_cgr cgr;
	u8 __reserved2[6];
	u8 i_bcnt_hi;
	__be32 i_bcnt_lo;
	u8 __reserved3[3];
	u8 a_bcnt_hi;
	__be32 a_bcnt_lo;
	__be32 cscn_targ_swp[4];
};

struct qm_portal_config___2 {
	void *addr_virt_ce;
	void *addr_virt_ci;
	struct device___155 *dev;
	struct iommu_domain___6 *iommu_domain;
	struct list_head list;
	int cpu;
	int irq;
	u16 channel;
	u32 pools;
};

struct qm_eqcr_entry {
	u8 _ncw_verb;
	u8 dca;
	__be16 seqnum;
	u8 __reserved[4];
	__be32 fqid;
	__be32 tag;
	struct qm_fd fd;
	u8 __reserved3[32];
};

struct qm_mcc_fq {
	u8 _ncw_verb;
	u8 __reserved1[3];
	__be32 fqid;
	u8 __reserved2[56];
};

struct qm_mcc_cgr {
	u8 _ncw_verb;
	u8 __reserved1[30];
	u8 cgid;
	u8 __reserved2[32];
};

union qm_mc_command {
	struct {
		u8 _ncw_verb;
		u8 __reserved[63];
	};
	struct qm_mcc_initfq initfq;
	struct qm_mcc_initcgr initcgr;
	struct qm_mcc_fq fq;
	struct qm_mcc_cgr cgr;
};

struct qm_mcr_queryfq {
	u8 verb;
	u8 result;
	u8 __reserved1[8];
	struct qm_fqd fqd;
	u8 __reserved2[30];
} __attribute__((packed));

struct qm_mcr_alterfq {
	u8 verb;
	u8 result;
	u8 fqs;
	u8 __reserved1[61];
};

union qm_mc_result {
	struct {
		u8 verb;
		u8 result;
		u8 __reserved1[62];
	};
	struct qm_mcr_queryfq queryfq;
	struct qm_mcr_alterfq alterfq;
	struct qm_mcr_querycgr querycgr;
	struct qm_mcr_querycongestion querycongestion;
	struct qm_mcr_querywq querywq;
	struct qm_mcr_queryfq_np queryfq_np;
};

struct qe_iram {
	__be32 iadd;
	__be32 idata;
	u8 res0[4];
	__be32 iready;
	u8 res1[112];
};

struct qe_ic_regs {
	__be32 qicr;
	__be32 qivec;
	__be32 qripnr;
	__be32 qipnr;
	__be32 qipxcc;
	__be32 qipycc;
	__be32 qipwcc;
	__be32 qipzcc;
	__be32 qimr;
	__be32 qrimr;
	__be32 qicnr;
	u8 res0[4];
	__be32 qiprta;
	__be32 qiprtb;
	u8 res1[4];
	__be32 qricr;
	u8 res2[32];
	__be32 qhivec;
	u8 res3[28];
};

struct cp_qe {
	__be32 cecr;
	__be32 ceccr;
	__be32 cecdr;
	u8 res0[10];
	__be16 ceter;
	u8 res1[2];
	__be16 cetmr;
	__be32 cetscr;
	__be32 cetsr1;
	__be32 cetsr2;
	u8 res2[8];
	__be32 cevter;
	__be32 cevtmr;
	__be16 cercr;
	u8 res3[2];
	u8 res4[36];
	__be16 ceexe1;
	u8 res5[2];
	__be16 ceexm1;
	u8 res6[2];
	__be16 ceexe2;
	u8 res7[2];
	__be16 ceexm2;
	u8 res8[2];
	__be16 ceexe3;
	u8 res9[2];
	__be16 ceexm3;
	u8 res10[2];
	__be16 ceexe4;
	u8 res11[2];
	__be16 ceexm4;
	u8 res12[58];
	__be32 ceurnr;
	u8 res13[580];
};

struct qe_mux {
	__be32 cmxgcr;
	__be32 cmxsi1cr_l;
	__be32 cmxsi1cr_h;
	__be32 cmxsi1syr;
	__be32 cmxucr[4];
	__be32 cmxupcr;
	u8 res0[28];
};

struct qe_timers {
	u8 gtcfr1;
	u8 res0[3];
	u8 gtcfr2;
	u8 res1[11];
	__be16 gtmdr1;
	__be16 gtmdr2;
	__be16 gtrfr1;
	__be16 gtrfr2;
	__be16 gtcpr1;
	__be16 gtcpr2;
	__be16 gtcnr1;
	__be16 gtcnr2;
	__be16 gtmdr3;
	__be16 gtmdr4;
	__be16 gtrfr3;
	__be16 gtrfr4;
	__be16 gtcpr3;
	__be16 gtcpr4;
	__be16 gtcnr3;
	__be16 gtcnr4;
	__be16 gtevr1;
	__be16 gtevr2;
	__be16 gtevr3;
	__be16 gtevr4;
	__be16 gtps;
	u8 res2[70];
};

struct qe_brg {
	__be32 brgc[16];
	u8 res0[64];
};

struct spi {
	u8 res0[32];
	__be32 spmode;
	u8 res1[2];
	u8 spie;
	u8 res2[1];
	u8 res3[2];
	u8 spim;
	u8 res4[1];
	u8 res5[1];
	u8 spcom;
	u8 res6[2];
	__be32 spitd;
	__be32 spird;
	u8 res7[8];
};

struct si1 {
	__be16 sixmr1[4];
	u8 siglmr1_h;
	u8 res0[1];
	u8 sicmdr1_h;
	u8 res2[1];
	u8 sistr1_h;
	u8 res3[1];
	__be16 sirsr1_h;
	u8 sitarc1;
	u8 sitbrc1;
	u8 sitcrc1;
	u8 sitdrc1;
	u8 sirarc1;
	u8 sirbrc1;
	u8 sircrc1;
	u8 sirdrc1;
	u8 res4[8];
	__be16 siemr1;
	__be16 sifmr1;
	__be16 sigmr1;
	__be16 sihmr1;
	u8 siglmg1_l;
	u8 res5[1];
	u8 sicmdr1_l;
	u8 res6[1];
	u8 sistr1_l;
	u8 res7[1];
	__be16 sirsr1_l;
	u8 siterc1;
	u8 sitfrc1;
	u8 sitgrc1;
	u8 sithrc1;
	u8 sirerc1;
	u8 sirfrc1;
	u8 sirgrc1;
	u8 sirhrc1;
	u8 res8[8];
	__be32 siml1;
	u8 siedm1;
	u8 res9[187];
};

struct sir {
	u8 tx[1024];
	u8 rx[1024];
	u8 res0[2048];
};

struct qe_usb_ctlr {
	u8 usb_usmod;
	u8 usb_usadr;
	u8 usb_uscom;
	u8 res1[1];
	__be16 usb_usep[4];
	u8 res2[4];
	__be16 usb_usber;
	u8 res3[2];
	__be16 usb_usbmr;
	u8 res4[1];
	u8 usb_usbs;
	__be16 usb_ussft;
	u8 res5[2];
	__be16 usb_usfrn;
	u8 res6[34];
};

struct qe_mcc {
	__be32 mcce;
	__be32 mccm;
	__be32 mccf;
	__be32 merl;
	u8 res0[240];
};

struct ucc_slow {
	__be32 gumr_l;
	__be32 gumr_h;
	__be16 upsmr;
	u8 res0[2];
	__be16 utodr;
	__be16 udsr;
	__be16 ucce;
	u8 res1[2];
	__be16 uccm;
	u8 res2[1];
	u8 uccs;
	u8 res3[36];
	__be16 utpt;
	u8 res4[82];
	u8 guemr;
} __attribute__((packed));

struct ucc_fast {
	__be32 gumr;
	__be32 upsmr;
	__be16 utodr;
	u8 res0[2];
	__be16 udsr;
	u8 res1[2];
	__be32 ucce;
	__be32 uccm;
	u8 uccs;
	u8 res2[7];
	__be32 urfb;
	__be16 urfs;
	u8 res3[2];
	__be16 urfet;
	__be16 urfset;
	__be32 utfb;
	__be16 utfs;
	u8 res4[2];
	__be16 utfet;
	u8 res5[2];
	__be16 utftt;
	u8 res6[2];
	__be16 utpt;
	u8 res7[2];
	__be32 urtry;
	u8 res8[76];
	u8 guemr;
} __attribute__((packed));

struct ucc {
	union {
		struct ucc_slow slow;
		struct ucc_fast fast;
		u8 res[512];
	};
};

struct upc {
	__be32 upgcr;
	__be32 uplpa;
	__be32 uphec;
	__be32 upuc;
	__be32 updc1;
	__be32 updc2;
	__be32 updc3;
	__be32 updc4;
	__be32 upstpa;
	u8 res0[12];
	__be32 updrs1_h;
	__be32 updrs1_l;
	__be32 updrs2_h;
	__be32 updrs2_l;
	__be32 updrs3_h;
	__be32 updrs3_l;
	__be32 updrs4_h;
	__be32 updrs4_l;
	__be32 updrp1;
	__be32 updrp2;
	__be32 updrp3;
	__be32 updrp4;
	__be32 upde1;
	__be32 upde2;
	__be32 upde3;
	__be32 upde4;
	__be16 uprp1;
	__be16 uprp2;
	__be16 uprp3;
	__be16 uprp4;
	u8 res1[8];
	__be16 uptirr1_0;
	__be16 uptirr1_1;
	__be16 uptirr1_2;
	__be16 uptirr1_3;
	__be16 uptirr2_0;
	__be16 uptirr2_1;
	__be16 uptirr2_2;
	__be16 uptirr2_3;
	__be16 uptirr3_0;
	__be16 uptirr3_1;
	__be16 uptirr3_2;
	__be16 uptirr3_3;
	__be16 uptirr4_0;
	__be16 uptirr4_1;
	__be16 uptirr4_2;
	__be16 uptirr4_3;
	__be32 uper1;
	__be32 uper2;
	__be32 uper3;
	__be32 uper4;
	u8 res2[336];
};

struct sdma {
	__be32 sdsr;
	__be32 sdmr;
	__be32 sdtr1;
	__be32 sdtr2;
	__be32 sdhy1;
	__be32 sdhy2;
	__be32 sdta1;
	__be32 sdta2;
	__be32 sdtm1;
	__be32 sdtm2;
	u8 res0[16];
	__be32 sdaqr;
	__be32 sdaqmr;
	u8 res1[4];
	__be32 sdebcr;
	u8 res2[56];
};

struct dbg {
	__be32 bpdcr;
	__be32 bpdsr;
	__be32 bpdmr;
	__be32 bprmrr0;
	__be32 bprmrr1;
	u8 res0[8];
	__be32 bprmtr0;
	__be32 bprmtr1;
	u8 res1[8];
	__be32 bprmir;
	__be32 bprmsr;
	__be32 bpemr;
	u8 res2[72];
};

struct rsp {
	__be32 tibcr[16];
	u8 res0[64];
	__be32 ibcr0;
	__be32 ibs0;
	__be32 ibcnr0;
	u8 res1[4];
	__be32 ibcr1;
	__be32 ibs1;
	__be32 ibcnr1;
	__be32 npcr;
	__be32 dbcr;
	__be32 dbar;
	__be32 dbamr;
	__be32 dbsr;
	__be32 dbcnr;
	u8 res2[12];
	__be32 dbdr_h;
	__be32 dbdr_l;
	__be32 dbdmr_h;
	__be32 dbdmr_l;
	__be32 bsr;
	__be32 bor;
	__be32 bior;
	u8 res3[4];
	__be32 iatr[4];
	__be32 eccr;
	__be32 eicr;
	u8 res4[8];
};

struct qe_immap {
	struct qe_iram iram;
	struct qe_ic_regs ic;
	struct cp_qe cp;
	struct qe_mux qmx;
	struct qe_timers qet;
	struct spi spi[2];
	struct qe_mcc mcc;
	struct qe_brg brg;
	struct qe_usb_ctlr usb;
	struct si1 si1;
	u8 res11[2048];
	struct sir sir;
	struct ucc ucc1;
	struct ucc ucc3;
	struct ucc ucc5;
	struct ucc ucc7;
	u8 res12[1536];
	struct upc upc1;
	struct ucc ucc2;
	struct ucc ucc4;
	struct ucc ucc6;
	struct ucc ucc8;
	u8 res13[1536];
	struct upc upc2;
	struct sdma sdma;
	struct dbg dbg;
	struct rsp rsp[2];
	u8 res14[768];
	u8 res15[14848];
	u8 res16[32768];
	u8 muram[49152];
	u8 res17[147456];
	u8 res18[786432];
};

enum qe_clock {
	QE_CLK_NONE = 0,
	QE_BRG1 = 1,
	QE_BRG2 = 2,
	QE_BRG3 = 3,
	QE_BRG4 = 4,
	QE_BRG5 = 5,
	QE_BRG6 = 6,
	QE_BRG7 = 7,
	QE_BRG8 = 8,
	QE_BRG9 = 9,
	QE_BRG10 = 10,
	QE_BRG11 = 11,
	QE_BRG12 = 12,
	QE_BRG13 = 13,
	QE_BRG14 = 14,
	QE_BRG15 = 15,
	QE_BRG16 = 16,
	QE_CLK1 = 17,
	QE_CLK2 = 18,
	QE_CLK3 = 19,
	QE_CLK4 = 20,
	QE_CLK5 = 21,
	QE_CLK6 = 22,
	QE_CLK7 = 23,
	QE_CLK8 = 24,
	QE_CLK9 = 25,
	QE_CLK10 = 26,
	QE_CLK11 = 27,
	QE_CLK12 = 28,
	QE_CLK13 = 29,
	QE_CLK14 = 30,
	QE_CLK15 = 31,
	QE_CLK16 = 32,
	QE_CLK17 = 33,
	QE_CLK18 = 34,
	QE_CLK19 = 35,
	QE_CLK20 = 36,
	QE_CLK21 = 37,
	QE_CLK22 = 38,
	QE_CLK23 = 39,
	QE_CLK24 = 40,
	QE_RSYNC_PIN = 41,
	QE_TSYNC_PIN = 42,
	QE_CLK_DUMMY = 43,
};

struct qe_header {
	__be32 length;
	u8 magic[3];
	u8 version;
};

struct qe_microcode {
	u8 id[32];
	__be32 traps[16];
	__be32 eccr;
	__be32 iram_offset;
	__be32 count;
	__be32 code_offset;
	u8 major;
	u8 minor;
	u8 revision;
	u8 padding;
	u8 reserved[4];
};

struct qe_firmware {
	struct qe_header header;
	u8 id[62];
	u8 split;
	u8 count;
	struct {
		__be16 model;
		u8 major;
		u8 minor;
	} soc;
	u8 padding[4];
	__be64 extended_modes;
	__be32 vtraps[8];
	u8 reserved[4];
	struct qe_microcode microcode[0];
} __attribute__((packed));

struct qe_firmware_info {
	char id[64];
	u32 vtraps[8];
	u64 extended_modes;
};

enum qe_fltr_tbl_lookup_key_size {
	QE_FLTR_TABLE_LOOKUP_KEY_SIZE_8_BYTES = 63,
	QE_FLTR_TABLE_LOOKUP_KEY_SIZE_16_BYTES = 95,
};

struct muram_block {
	struct list_head head;
	s32 start;
	int size;
};

struct qe_ic {
	__be32 *regs;
	struct irq_domain___22 *irqhost;
	struct irq_chip___23 hc_irq;
	int virq_high;
	int virq_low;
};

struct qe_ic_info {
	u32 mask;
	u32 mask_reg;
	u8 pri_code;
	u32 pri_reg;
};

struct qe_pio_regs {
	__be32 cpodr;
	__be32 cpdata;
	__be32 cpdir1;
	__be32 cpdir2;
	__be32 cppar1;
	__be32 cppar2;
};

enum comm_dir {
	COMM_DIR_NONE = 0,
	COMM_DIR_RX = 1,
	COMM_DIR_TX = 2,
	COMM_DIR_RX_AND_TX = 3,
};

enum ucc_speed_type {
	UCC_SPEED_TYPE_FAST = 3,
	UCC_SPEED_TYPE_SLOW = 0,
};

struct qe_bd {
	__be16 status;
	__be16 length;
	__be32 buf;
};

struct ucc_slow_pram {
	__be16 rbase;
	__be16 tbase;
	u8 rbmr;
	u8 tbmr;
	__be16 mrblr;
	__be32 rstate;
	__be32 rptr;
	__be16 rbptr;
	__be16 rcount;
	__be32 rtemp;
	__be32 tstate;
	__be32 tptr;
	__be16 tbptr;
	__be16 tcount;
	__be32 ttemp;
	__be32 rcrc;
	__be32 tcrc;
};

enum ucc_slow_channel_protocol_mode {
	UCC_SLOW_CHANNEL_PROTOCOL_MODE_QMC = 2,
	UCC_SLOW_CHANNEL_PROTOCOL_MODE_UART = 4,
	UCC_SLOW_CHANNEL_PROTOCOL_MODE_BISYNC = 8,
};

enum ucc_slow_transparent_tcrc {
	UCC_SLOW_TRANSPARENT_TCRC_CCITT_CRC16 = 0,
	UCC_SLOW_TRANSPARENT_TCRC_CRC16 = 16384,
	UCC_SLOW_TRANSPARENT_TCRC_CCITT_CRC32 = 32768,
};

enum ucc_slow_tx_oversampling_rate {
	UCC_SLOW_OVERSAMPLING_RATE_TX_TDCR_1 = 0,
	UCC_SLOW_OVERSAMPLING_RATE_TX_TDCR_8 = 65536,
	UCC_SLOW_OVERSAMPLING_RATE_TX_TDCR_16 = 131072,
	UCC_SLOW_OVERSAMPLING_RATE_TX_TDCR_32 = 196608,
};

enum ucc_slow_rx_oversampling_rate {
	UCC_SLOW_OVERSAMPLING_RATE_RX_RDCR_1 = 0,
	UCC_SLOW_OVERSAMPLING_RATE_RX_RDCR_8 = 16384,
	UCC_SLOW_OVERSAMPLING_RATE_RX_RDCR_16 = 32768,
	UCC_SLOW_OVERSAMPLING_RATE_RX_RDCR_32 = 49152,
};

enum ucc_slow_tx_encoding_method {
	UCC_SLOW_TRANSMITTER_ENCODING_METHOD_TENC_NRZ = 0,
	UCC_SLOW_TRANSMITTER_ENCODING_METHOD_TENC_NRZI = 256,
};

enum ucc_slow_rx_decoding_method {
	UCC_SLOW_RECEIVER_DECODING_METHOD_RENC_NRZ = 0,
	UCC_SLOW_RECEIVER_DECODING_METHOD_RENC_NRZI = 2048,
};

enum ucc_slow_diag_mode {
	UCC_SLOW_DIAG_MODE_NORMAL = 0,
	UCC_SLOW_DIAG_MODE_LOOPBACK = 64,
	UCC_SLOW_DIAG_MODE_ECHO = 128,
	UCC_SLOW_DIAG_MODE_LOOPBACK_ECHO = 192,
};

struct ucc_slow_info {
	int ucc_num;
	int protocol;
	enum qe_clock rx_clock;
	enum qe_clock tx_clock;
	phys_addr_t regs;
	int irq;
	u16 uccm_mask;
	int data_mem_part;
	int init_tx;
	int init_rx;
	u32 tx_bd_ring_len;
	u32 rx_bd_ring_len;
	int rx_interrupts;
	int brkpt_support;
	int grant_support;
	int tsa;
	int cdp;
	int cds;
	int ctsp;
	int ctss;
	int rinv;
	int tinv;
	int rtsm;
	int rfw;
	int tci;
	int tend;
	int tfl;
	int txsy;
	u16 max_rx_buf_length;
	enum ucc_slow_transparent_tcrc tcrc;
	enum ucc_slow_channel_protocol_mode mode;
	enum ucc_slow_diag_mode diag;
	enum ucc_slow_tx_oversampling_rate tdcr;
	enum ucc_slow_rx_oversampling_rate rdcr;
	enum ucc_slow_tx_encoding_method tenc;
	enum ucc_slow_rx_decoding_method renc;
};

struct ucc_slow_private {
	struct ucc_slow_info *us_info;
	struct ucc_slow *us_regs;
	struct ucc_slow_pram *us_pram;
	s32 us_pram_offset;
	int enabled_tx;
	int enabled_rx;
	int stopped_tx;
	int stopped_rx;
	struct list_head confQ;
	u32 first_tx_bd_mask;
	s32 tx_base_offset;
	s32 rx_base_offset;
	struct qe_bd *confBd;
	struct qe_bd *tx_bd;
	struct qe_bd *rx_bd;
	void *p_rx_frame;
	__be16 *p_ucce;
	__be16 *p_uccm;
	u16 saved_uccm;
	u32 tx_frames;
	u32 rx_frames;
	u32 rx_discarded;
};

enum ucc_fast_channel_protocol_mode {
	UCC_FAST_PROTOCOL_MODE_HDLC = 0,
	UCC_FAST_PROTOCOL_MODE_RESERVED01 = 1,
	UCC_FAST_PROTOCOL_MODE_RESERVED_QMC = 2,
	UCC_FAST_PROTOCOL_MODE_RESERVED02 = 3,
	UCC_FAST_PROTOCOL_MODE_RESERVED_UART = 4,
	UCC_FAST_PROTOCOL_MODE_RESERVED03 = 5,
	UCC_FAST_PROTOCOL_MODE_RESERVED_EX_MAC_1 = 6,
	UCC_FAST_PROTOCOL_MODE_RESERVED_EX_MAC_2 = 7,
	UCC_FAST_PROTOCOL_MODE_RESERVED_BISYNC = 8,
	UCC_FAST_PROTOCOL_MODE_RESERVED04 = 9,
	UCC_FAST_PROTOCOL_MODE_ATM = 10,
	UCC_FAST_PROTOCOL_MODE_RESERVED05 = 11,
	UCC_FAST_PROTOCOL_MODE_ETHERNET = 12,
	UCC_FAST_PROTOCOL_MODE_RESERVED06 = 13,
	UCC_FAST_PROTOCOL_MODE_POS = 14,
	UCC_FAST_PROTOCOL_MODE_RESERVED07 = 15,
};

enum ucc_fast_transparent_txrx {
	UCC_FAST_GUMR_TRANSPARENT_TTX_TRX_NORMAL = 0,
	UCC_FAST_GUMR_TRANSPARENT_TTX_TRX_TRANSPARENT = 402653184,
};

enum ucc_fast_sync_len {
	UCC_FAST_SYNC_LEN_NOT_USED = 0,
	UCC_FAST_SYNC_LEN_AUTOMATIC = 16384,
	UCC_FAST_SYNC_LEN_8_BIT = 32768,
	UCC_FAST_SYNC_LEN_16_BIT = 49152,
};

enum ucc_fast_rx_decoding_method {
	UCC_FAST_RX_ENCODING_NRZ = 0,
	UCC_FAST_RX_ENCODING_NRZI = 2048,
	UCC_FAST_RX_ENCODING_RESERVED0 = 4096,
	UCC_FAST_RX_ENCODING_RESERVED1 = 6144,
};

enum ucc_fast_tx_encoding_method {
	UCC_FAST_TX_ENCODING_NRZ = 0,
	UCC_FAST_TX_ENCODING_NRZI = 256,
	UCC_FAST_TX_ENCODING_RESERVED0 = 512,
	UCC_FAST_TX_ENCODING_RESERVED1 = 768,
};

enum ucc_fast_transparent_tcrc {
	UCC_FAST_16_BIT_CRC = 0,
	UCC_FAST_CRC_RESERVED0 = 64,
	UCC_FAST_32_BIT_CRC = 128,
	UCC_FAST_CRC_RESERVED1 = 192,
};

struct ucc_fast_info {
	int ucc_num;
	int tdm_num;
	enum qe_clock rx_clock;
	enum qe_clock tx_clock;
	enum qe_clock rx_sync;
	enum qe_clock tx_sync;
	resource_size_t regs;
	int irq;
	u32 uccm_mask;
	int brkpt_support;
	int grant_support;
	int tsa;
	int cdp;
	int cds;
	int ctsp;
	int ctss;
	int tci;
	int txsy;
	int rtsm;
	int revd;
	int rsyn;
	u16 max_rx_buf_length;
	u16 urfs;
	u16 urfet;
	u16 urfset;
	u16 utfs;
	u16 utfet;
	u16 utftt;
	u16 ufpt;
	enum ucc_fast_channel_protocol_mode mode;
	enum ucc_fast_transparent_txrx ttx_trx;
	enum ucc_fast_tx_encoding_method tenc;
	enum ucc_fast_rx_decoding_method renc;
	enum ucc_fast_transparent_tcrc tcrc;
	enum ucc_fast_sync_len synl;
};

struct ucc_fast_private {
	struct ucc_fast_info *uf_info;
	struct ucc_fast *uf_regs;
	__be32 *p_ucce;
	__be32 *p_uccm;
	int enabled_tx;
	int enabled_rx;
	int stopped_tx;
	int stopped_rx;
	s32 ucc_fast_tx_virtual_fifo_base_offset;
	s32 ucc_fast_rx_virtual_fifo_base_offset;
	u32 tx_frames;
	u32 rx_frames;
	u32 tx_discarded;
	u32 rx_discarded;
	u16 mrblr;
};

enum tdm_framer_t {
	TDM_FRAMER_T1 = 0,
	TDM_FRAMER_E1 = 1,
};

enum tdm_mode_t {
	TDM_INTERNAL_LOOPBACK = 0,
	TDM_NORMAL = 1,
};

struct si_mode_info {
	u8 simr_rfsd;
	u8 simr_tfsd;
	u8 simr_crt;
	u8 simr_sl;
	u8 simr_ce;
	u8 simr_fe;
	u8 simr_gm;
};

struct ucc_tdm_info {
	struct ucc_fast_info uf_info;
	struct si_mode_info si_info;
};

struct ucc_tdm {
	u16 tdm_port;
	u32 siram_entry_id;
	u16 *siram;
	struct si1 *si_regs;
	enum tdm_framer_t tdm_framer_type;
	enum tdm_mode_t tdm_mode;
	u8 num_of_ts;
	u32 tx_ts_mask;
	u32 rx_ts_mask;
};

struct rcpm {
	unsigned int wakeup_cells;
	void *ippdexpcr_base;
	bool little_endian;
};

struct soc_device_attribute___4 {
	const char *machine;
	const char *family;
	const char *revision;
	const char *serial_number;
	const char *soc_id;
	const void *data;
	const struct attribute_group___184 *custom_attr_group;
};

struct guts {
	struct ccsr_guts *regs;
	bool little_endian;
};

struct fsl_soc_die_attr {
	char *die;
	u32 svr;
	u32 mask;
};

struct regmap_config___7 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___156 *, unsigned int);
	bool (*readable_reg)(struct device___156 *, unsigned int);
	bool (*volatile_reg)(struct device___156 *, unsigned int);
	bool (*precious_reg)(struct device___156 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___156 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___156 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct imx_pgc_domain {
	struct generic_pm_domain___4 genpd;
	struct regmap *regmap;
	struct regulator *regulator;
	struct reset_control *reset;
	struct clk_bulk_data *clks;
	int num_clks;
	unsigned int pgc;
	const struct {
		u32 pxx;
		u32 map;
		u32 hskreq;
		u32 hskack;
	} bits;
	const int voltage;
	struct device___156 *dev;
};

struct imx_pgc_domain_data {
	const struct imx_pgc_domain *domains;
	size_t domains_num;
	const struct regmap_access_table *reg_access_table;
};

struct arm_smccc_quirk___2 {
	int id;
	union {
		long unsigned int a6;
	} state;
	long: 64;
};

struct property_entry___2 {
	const char *name;
	size_t length;
	bool is_inline;
	enum dev_prop_type type;
	union {
		const void *pointer;
		union {
			u8 u8_data[8];
			u16 u16_data[4];
			u32 u32_data[2];
			u64 u64_data[1];
			const char *str[1];
		} value;
	};
	long: 64;
};

struct platform_device_info___3 {
	struct device___139 *parent;
	struct fwnode_handle___139 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry___2 *properties;
};

struct imx8_soc_data {
	char *name;
	u32 (*soc_revision)();
};

enum clk_id___2 {
	CLK_NONE = 0,
	CLK_MM = 1,
	CLK_MFG = 2,
	CLK_VENC = 3,
	CLK_VENC_LT = 4,
	CLK_ETHIF = 5,
	CLK_VDEC = 6,
	CLK_HIFSEL = 7,
	CLK_JPGDEC = 8,
	CLK_AUDIO = 9,
	CLK_MAX = 10,
};

struct scp_domain_data {
	const char *name;
	u32 sta_mask;
	int ctl_offs;
	u32 sram_pdn_bits;
	u32 sram_pdn_ack_bits;
	u32 bus_prot_mask;
	enum clk_id___2 clk_id[3];
	u8 caps;
};

struct scp;

struct scp_domain {
	struct generic_pm_domain___4 genpd;
	struct scp *scp;
	struct clk *clk[3];
	const struct scp_domain_data *data;
	struct regulator *supply;
};

struct scp_ctrl_reg {
	int pwr_sta_offs;
	int pwr_sta2nd_offs;
};

struct scp {
	struct scp_domain *domains;
	struct genpd_onecell_data___3 pd_data;
	struct device___156 *dev;
	void *base;
	struct regmap *infracfg;
	struct scp_ctrl_reg ctrl_reg;
	bool bus_prot_reg_update;
};

struct scp_subdomain {
	int origin;
	int subdomain;
};

struct scp_soc_data {
	const struct scp_domain_data *domains;
	int num_domains;
	const struct scp_subdomain *subdomains;
	int num_subdomains;
	const struct scp_ctrl_reg regs;
	bool bus_prot_reg_update;
};

struct scpsys_bus_prot_data {
	u32 bus_prot_mask;
	u32 bus_prot_set;
	u32 bus_prot_clr;
	u32 bus_prot_sta;
	bool bus_prot_reg_update;
	bool ignore_clr_ack;
};

struct scpsys_domain_data {
	const char *name;
	u32 sta_mask;
	int ctl_offs;
	u32 sram_pdn_bits;
	u32 sram_pdn_ack_bits;
	u8 caps;
	const struct scpsys_bus_prot_data bp_infracfg[5];
	const struct scpsys_bus_prot_data bp_smi[5];
};

struct scpsys_soc_data {
	const struct scpsys_domain_data *domains_data;
	int num_domains;
	int pwr_sta_offs;
	int pwr_sta2nd_offs;
};

struct scpsys;

struct scpsys_domain {
	struct generic_pm_domain genpd;
	const struct scpsys_domain_data *data;
	struct scpsys *scpsys;
	int num_clks;
	struct clk_bulk_data *clks;
	int num_subsys_clks;
	struct clk_bulk_data *subsys_clks;
	struct regmap *infracfg;
	struct regmap *smi;
	struct regulator *supply;
};

struct scpsys {
	struct device___154 *dev;
	struct regmap *base;
	const struct scpsys_soc_data *soc_data;
	struct genpd_onecell_data pd_data;
	struct generic_pm_domain *domains[0];
};

enum mtk_ddp_comp_id {
	DDP_COMPONENT_AAL0 = 0,
	DDP_COMPONENT_AAL1 = 1,
	DDP_COMPONENT_BLS = 2,
	DDP_COMPONENT_CCORR = 3,
	DDP_COMPONENT_COLOR0 = 4,
	DDP_COMPONENT_COLOR1 = 5,
	DDP_COMPONENT_DITHER = 6,
	DDP_COMPONENT_DPI0 = 7,
	DDP_COMPONENT_DPI1 = 8,
	DDP_COMPONENT_DSI0 = 9,
	DDP_COMPONENT_DSI1 = 10,
	DDP_COMPONENT_DSI2 = 11,
	DDP_COMPONENT_DSI3 = 12,
	DDP_COMPONENT_GAMMA = 13,
	DDP_COMPONENT_OD0 = 14,
	DDP_COMPONENT_OD1 = 15,
	DDP_COMPONENT_OVL0 = 16,
	DDP_COMPONENT_OVL_2L0 = 17,
	DDP_COMPONENT_OVL_2L1 = 18,
	DDP_COMPONENT_OVL1 = 19,
	DDP_COMPONENT_PWM0 = 20,
	DDP_COMPONENT_PWM1 = 21,
	DDP_COMPONENT_PWM2 = 22,
	DDP_COMPONENT_RDMA0 = 23,
	DDP_COMPONENT_RDMA1 = 24,
	DDP_COMPONENT_RDMA2 = 25,
	DDP_COMPONENT_UFOE = 26,
	DDP_COMPONENT_WDMA0 = 27,
	DDP_COMPONENT_WDMA1 = 28,
	DDP_COMPONENT_ID_MAX = 29,
};

struct mtk_mmsys_routes {
	u32 from_comp;
	u32 to_comp;
	u32 addr;
	u32 mask;
	u32 val;
};

struct mtk_mmsys_driver_data {
	const char *clk_driver;
	const struct mtk_mmsys_routes *routes;
	const unsigned int num_routes;
};

struct mtk_mmsys {
	void *regs;
	const struct mtk_mmsys_driver_data *data;
};

struct mtk_mutex {
	int id;
	bool claimed;
};

enum mtk_mutex_sof_id {
	MUTEX_SOF_SINGLE_MODE = 0,
	MUTEX_SOF_DSI0 = 1,
	MUTEX_SOF_DSI1 = 2,
	MUTEX_SOF_DPI0 = 3,
	MUTEX_SOF_DPI1 = 4,
	MUTEX_SOF_DSI2 = 5,
	MUTEX_SOF_DSI3 = 6,
};

struct mtk_mutex_data {
	const unsigned int *mutex_mod;
	const unsigned int *mutex_sof;
	const unsigned int mutex_mod_reg;
	const unsigned int mutex_sof_reg;
	const bool no_clk;
};

struct mtk_mutex_ctx {
	struct device___157 *dev;
	struct clk *clk;
	void *regs;
	struct mtk_mutex mutex[10];
	const struct mtk_mutex_data *data;
};

struct meson_msr;

struct meson_msr_id {
	struct meson_msr *priv;
	unsigned int id;
	const char *name;
};

struct meson_msr {
	struct regmap *regmap;
	struct meson_msr_id msr_table[128];
};

struct meson_gx_soc_id {
	const char *name;
	unsigned int id;
};

struct meson_gx_package_id {
	const char *name;
	unsigned int major_id;
	unsigned int pack_id;
	unsigned int pack_mask;
};

struct meson_gx_pwrc_vpu {
	struct generic_pm_domain___4 genpd;
	struct regmap *regmap_ao;
	struct regmap *regmap_hhi;
	struct reset_control *rstc;
	struct clk *vpu_clk;
	struct clk *vapb_clk;
};

struct meson_ee_pwrc_mem_domain {
	unsigned int reg;
	unsigned int mask;
};

struct meson_ee_pwrc_top_domain {
	unsigned int sleep_reg;
	unsigned int sleep_mask;
	unsigned int iso_reg;
	unsigned int iso_mask;
};

struct meson_ee_pwrc_domain;

struct meson_ee_pwrc_domain_desc {
	char *name;
	unsigned int reset_names_count;
	unsigned int clk_names_count;
	struct meson_ee_pwrc_top_domain *top_pd;
	unsigned int mem_pd_count;
	struct meson_ee_pwrc_mem_domain *mem_pd;
	bool (*is_powered_off)(struct meson_ee_pwrc_domain *);
};

struct meson_ee_pwrc;

struct meson_ee_pwrc_domain {
	struct generic_pm_domain___4 base;
	bool enabled;
	struct meson_ee_pwrc *pwrc;
	struct meson_ee_pwrc_domain_desc desc;
	struct clk_bulk_data *clks;
	int num_clks;
	struct reset_control *rstc;
	int num_rstc;
};

struct meson_ee_pwrc_domain_data {
	unsigned int count;
	struct meson_ee_pwrc_domain_desc *domains;
};

struct meson_ee_pwrc {
	struct regmap *regmap_ao;
	struct regmap *regmap_hhi;
	struct meson_ee_pwrc_domain *domains;
	struct genpd_onecell_data___3 xlate;
};

enum {
	SM_EFUSE_READ = 0,
	SM_EFUSE_WRITE = 1,
	SM_EFUSE_USER_MAX = 2,
	SM_GET_CHIP_ID = 3,
	SM_A1_PWRC_SET = 4,
	SM_A1_PWRC_GET = 5,
};

struct meson_secure_pwrc;

struct meson_secure_pwrc_domain {
	struct generic_pm_domain___4 base;
	unsigned int index;
	struct meson_secure_pwrc *pwrc;
};

struct meson_sm_firmware;

struct meson_secure_pwrc {
	struct meson_secure_pwrc_domain *domains;
	struct genpd_onecell_data___3 xlate;
	struct meson_sm_firmware *fw;
};

struct meson_secure_pwrc_domain_desc {
	unsigned int index;
	unsigned int flags;
	char *name;
	bool (*is_off)(struct meson_secure_pwrc_domain *);
};

struct meson_secure_pwrc_domain_data {
	unsigned int count;
	struct meson_secure_pwrc_domain_desc *domains;
};

enum cmd_db_hw_type {
	CMD_DB_HW_INVALID = 0,
	CMD_DB_HW_MIN = 3,
	CMD_DB_HW_ARC = 3,
	CMD_DB_HW_VRM = 4,
	CMD_DB_HW_BCM = 5,
	CMD_DB_HW_MAX = 5,
	CMD_DB_HW_ALL = 255,
};

struct entry_header {
	u8 id[8];
	__le32 priority[2];
	__le32 addr;
	__le16 len;
	__le16 offset;
};

struct rsc_hdr {
	__le16 slv_id;
	__le16 header_offset;
	__le16 data_offset;
	__le16 cnt;
	__le16 version;
	__le16 reserved[3];
};

struct cmd_db_header {
	__le32 version;
	u8 magic[4];
	struct rsc_hdr header[8];
	__le32 checksum;
	__le32 reserved;
	u8 data[0];
};

struct platform_device___23 {
	const char *name;
	int id;
	bool id_auto;
	struct device___148 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___21 {
	int (*probe)(struct platform_device___23 *);
	int (*remove)(struct platform_device___23 *);
	void (*shutdown)(struct platform_device___23 *);
	int (*suspend)(struct platform_device___23 *, pm_message_t);
	int (*resume)(struct platform_device___23 *);
	struct device_driver___148 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum rpmh_state {
	RPMH_SLEEP_STATE = 0,
	RPMH_WAKE_ONLY_STATE = 1,
	RPMH_ACTIVE_ONLY_STATE = 2,
};

struct tcs_cmd {
	u32 addr;
	u32 data;
	u32 wait;
};

struct tcs_request {
	enum rpmh_state state;
	u32 wait_for_compl;
	u32 num_cmds;
	struct tcs_cmd *cmds;
};

struct rsc_drv;

struct tcs_group {
	struct rsc_drv *drv;
	int type;
	u32 mask;
	u32 offset;
	int num_tcs;
	int ncpt;
	const struct tcs_request *req[3];
	long unsigned int slots[1];
};

struct rpmh_ctrlr {
	struct list_head cache;
	spinlock_t cache_lock;
	bool dirty;
	struct list_head batch_cache;
};

struct rsc_drv {
	const char *name;
	void *tcs_base;
	int id;
	int num_tcs;
	struct notifier_block rsc_pm;
	atomic_t cpus_in_pm;
	struct tcs_group tcs[4];
	long unsigned int tcs_in_use[1];
	spinlock_t lock;
	wait_queue_head_t tcs_wait;
	struct rpmh_ctrlr client;
};

struct trace_event_raw_rpmh_tx_done {
	struct trace_entry ent;
	u32 __data_loc_name;
	int m;
	u32 addr;
	u32 data;
	int err;
	char __data[0];
};

struct trace_event_raw_rpmh_send_msg {
	struct trace_entry ent;
	u32 __data_loc_name;
	int m;
	int n;
	u32 hdr;
	u32 addr;
	u32 data;
	bool wait;
	char __data[0];
};

struct trace_event_data_offsets_rpmh_tx_done {
	u32 name;
};

struct trace_event_data_offsets_rpmh_send_msg {
	u32 name;
};

typedef void (*btf_trace_rpmh_tx_done)(void *, struct rsc_drv *, int, const struct tcs_request *, int);

typedef void (*btf_trace_rpmh_send_msg)(void *, struct rsc_drv *, int, int, u32, const struct tcs_cmd *);

struct tcs_type_config {
	u32 type;
	u32 n;
};

struct rpmh_request {
	struct tcs_request msg;
	struct tcs_cmd cmd[16];
	struct completion *completion;
	const struct device___158 *dev;
	int err;
	bool needs_free;
};

struct cache_req___2 {
	u32 addr;
	u32 sleep_val;
	u32 wake_val;
	struct list_head list;
};

struct batch_cache_req {
	struct list_head list;
	int count;
	struct rpmh_request rpm_msgs[0];
};

struct qcom_smem_state_ops {
	int (*update_bits)(void *, u32, u32);
};

struct qcom_smem_state {
	struct kref refcount;
	bool orphan;
	struct list_head list;
	struct device_node___60 *of_node;
	void *priv;
	struct qcom_smem_state_ops ops;
};

struct rpmhpd {
	struct device___158 *dev;
	struct generic_pm_domain pd;
	struct generic_pm_domain *parent;
	struct rpmhpd *peer;
	const bool active_only;
	unsigned int corner;
	unsigned int active_corner;
	unsigned int enable_corner;
	u32 level[16];
	size_t level_count;
	bool enabled;
	const char *res_name;
	u32 addr;
};

struct rpmhpd_desc {
	struct rpmhpd **rpmhpds;
	size_t num_pds;
};

struct renesas_family {
	const char name[16];
	u32 reg;
};

struct renesas_soc {
	const struct renesas_family *family;
	u32 id;
};

struct rcar_sysc_area {
	const char *name;
	u16 chan_offs;
	u8 chan_bit;
	u8 isr_bit;
	int parent;
	unsigned int flags;
};

struct rcar_sysc_info {
	int (*init)();
	const struct rcar_sysc_area *areas;
	unsigned int num_areas;
	u32 extmask_offs;
	u32 extmask_val;
};

struct soc_device_attribute___5 {
	const char *machine;
	const char *family;
	const char *revision;
	const char *serial_number;
	const char *soc_id;
	const void *data;
	const struct attribute_group___43 *custom_attr_group;
};

struct r8a779a0_sysc_area {
	const char *name;
	u8 pdr;
	int parent;
	unsigned int flags;
};

struct r8a779a0_sysc_info {
	const struct r8a779a0_sysc_area *areas;
	unsigned int num_areas;
};

struct r8a779a0_sysc_pd {
	struct generic_pm_domain genpd;
	u8 pdr;
	unsigned int flags;
	char name[0];
};

struct r8a779a0_pm_domains {
	struct genpd_onecell_data onecell_data;
	struct generic_pm_domain *domains[65];
};

struct rst_config {
	unsigned int modemr;
	int (*configure)(void *);
};

struct rcar_sysc_ch {
	u16 chan_offs;
	u8 chan_bit;
	u8 isr_bit;
};

struct rcar_sysc_pd {
	struct generic_pm_domain genpd;
	struct rcar_sysc_ch ch;
	unsigned int flags;
	char name[0];
};

struct rcar_pm_domains {
	struct genpd_onecell_data onecell_data;
	struct generic_pm_domain *domains[33];
};

struct rockchip_grf_value {
	const char *desc;
	u32 reg;
	u32 val;
};

struct rockchip_grf_info {
	const struct rockchip_grf_value *values;
	int num_values;
};

struct rockchip_domain_info {
	const char *name;
	int pwr_mask;
	int status_mask;
	int req_mask;
	int idle_mask;
	int ack_mask;
	bool active_wakeup;
	int pwr_w_mask;
	int req_w_mask;
};

struct rockchip_pmu_info {
	u32 pwr_offset;
	u32 status_offset;
	u32 req_offset;
	u32 idle_offset;
	u32 ack_offset;
	u32 core_pwrcnt_offset;
	u32 gpu_pwrcnt_offset;
	unsigned int core_power_transition_time;
	unsigned int gpu_power_transition_time;
	int num_domains;
	const struct rockchip_domain_info *domain_info;
};

struct rockchip_pmu;

struct rockchip_pm_domain {
	struct generic_pm_domain___3 genpd;
	const struct rockchip_domain_info *info;
	struct rockchip_pmu *pmu;
	int num_qos;
	struct regmap **qos_regmap;
	u32 *qos_save_regs[5];
	int num_clks;
	struct clk_bulk_data *clks;
};

struct rockchip_pmu {
	struct device___159 *dev;
	struct regmap *regmap;
	const struct rockchip_pmu_info *info;
	struct mutex mutex;
	struct genpd_onecell_data___2 genpd_data;
	struct generic_pm_domain___3 *domains[0];
};

struct sunxi_sram_func {
	char *func;
	u8 val;
	u32 reg_val;
};

struct sunxi_sram_data {
	char *name;
	u8 reg;
	u8 offset;
	u8 width;
	struct sunxi_sram_func *func;
	struct list_head list;
};

struct sunxi_sram_desc {
	struct sunxi_sram_data data;
	bool claimed;
};

struct sunxi_sramc_variant {
	int num_emac_clocks;
};

struct nvmem_cell_info {
	const char *name;
	unsigned int offset;
	unsigned int bytes;
	unsigned int bit_offset;
	unsigned int nbits;
};

struct nvmem_cell_lookup {
	const char *nvmem_name;
	const char *cell_name;
	const char *dev_id;
	const char *con_id;
	struct list_head node;
};

typedef int (*nvmem_reg_read_t)(void *, unsigned int, void *, size_t);

typedef int (*nvmem_reg_write_t)(void *, unsigned int, void *, size_t);

enum nvmem_type {
	NVMEM_TYPE_UNKNOWN = 0,
	NVMEM_TYPE_EEPROM = 1,
	NVMEM_TYPE_OTP = 2,
	NVMEM_TYPE_BATTERY_BACKED = 3,
	NVMEM_TYPE_FRAM = 4,
};

struct nvmem_keepout {
	unsigned int start;
	unsigned int end;
	unsigned char value;
};

struct nvmem_config {
	struct device___158 *dev;
	const char *name;
	int id;
	struct module___8 *owner;
	struct gpio_desc *wp_gpio;
	const struct nvmem_cell_info *cells;
	int ncells;
	const struct nvmem_keepout *keepout;
	unsigned int nkeepout;
	enum nvmem_type type;
	bool read_only;
	bool root_only;
	bool ignore_wp;
	struct device_node___61 *of_node;
	bool no_of_node;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	int size;
	int word_size;
	int stride;
	void *priv;
	bool compat;
	struct device___158 *base_dev;
};

struct tegra_fuse;

struct tegra_fuse_info {
	u32 (*read)(struct tegra_fuse *, unsigned int);
	unsigned int size;
	unsigned int spare;
};

struct nvmem_device;

struct tegra_fuse_soc;

struct tegra_fuse {
	struct device___158 *dev;
	void *base;
	phys_addr_t phys;
	struct clk *clk;
	u32 (*read_early)(struct tegra_fuse *, unsigned int);
	u32 (*read)(struct tegra_fuse *, unsigned int);
	const struct tegra_fuse_soc *soc;
	struct {
		struct mutex lock;
		struct completion wait;
		struct dma_chan___4 *chan;
		struct dma_slave_config config;
		dma_addr_t phys;
		u32 *virt;
	} apbdma;
	struct nvmem_device *nvmem;
	struct nvmem_cell_lookup *lookups;
};

struct tegra_fuse_soc {
	void (*init)(struct tegra_fuse *);
	void (*speedo_init)(struct tegra_sku_info *);
	int (*probe)(struct tegra_fuse *);
	const struct tegra_fuse_info *info;
	const struct nvmem_cell_lookup *lookups;
	unsigned int num_lookups;
	const struct attribute_group___183 *soc_attr_group;
	bool clk_suspend_on;
};

struct tegra_fuse___2;

struct tegra_fuse_info___2 {
	u32 (*read)(struct tegra_fuse___2 *, unsigned int);
	unsigned int size;
	unsigned int spare;
};

struct tegra_fuse_soc___2;

struct tegra_fuse___2 {
	struct device___157 *dev;
	void *base;
	phys_addr_t phys;
	struct clk *clk;
	u32 (*read_early)(struct tegra_fuse___2 *, unsigned int);
	u32 (*read)(struct tegra_fuse___2 *, unsigned int);
	const struct tegra_fuse_soc___2 *soc;
	struct {
		struct mutex lock;
		struct completion wait;
		struct dma_chan___2 *chan;
		struct dma_slave_config config;
		dma_addr_t phys;
		u32 *virt;
	} apbdma;
	struct nvmem_device *nvmem;
	struct nvmem_cell_lookup *lookups;
};

struct tegra_fuse_soc___2 {
	void (*init)(struct tegra_fuse___2 *);
	void (*speedo_init)(struct tegra_sku_info *);
	int (*probe)(struct tegra_fuse___2 *);
	const struct tegra_fuse_info___2 *info;
	const struct nvmem_cell_lookup *lookups;
	unsigned int num_lookups;
	const struct attribute_group___184 *soc_attr_group;
	bool clk_suspend_on;
};

enum {
	THRESHOLD_INDEX_0 = 0,
	THRESHOLD_INDEX_1 = 1,
	THRESHOLD_INDEX_COUNT = 2,
};

struct tegra_core_opp_params {
	bool init_state;
};

enum tegra_suspend_mode {
	TEGRA_SUSPEND_NONE = 0,
	TEGRA_SUSPEND_LP2 = 1,
	TEGRA_SUSPEND_LP1 = 2,
	TEGRA_SUSPEND_LP0 = 3,
	TEGRA_MAX_SUSPEND_MODE = 4,
	TEGRA_SUSPEND_NOT_READY = 5,
};

enum tegra_io_pad {
	TEGRA_IO_PAD_AUDIO = 0,
	TEGRA_IO_PAD_AUDIO_HV = 1,
	TEGRA_IO_PAD_BB = 2,
	TEGRA_IO_PAD_CAM = 3,
	TEGRA_IO_PAD_COMP = 4,
	TEGRA_IO_PAD_CONN = 5,
	TEGRA_IO_PAD_CSIA = 6,
	TEGRA_IO_PAD_CSIB = 7,
	TEGRA_IO_PAD_CSIC = 8,
	TEGRA_IO_PAD_CSID = 9,
	TEGRA_IO_PAD_CSIE = 10,
	TEGRA_IO_PAD_CSIF = 11,
	TEGRA_IO_PAD_CSIG = 12,
	TEGRA_IO_PAD_CSIH = 13,
	TEGRA_IO_PAD_DAP3 = 14,
	TEGRA_IO_PAD_DAP5 = 15,
	TEGRA_IO_PAD_DBG = 16,
	TEGRA_IO_PAD_DEBUG_NONAO = 17,
	TEGRA_IO_PAD_DMIC = 18,
	TEGRA_IO_PAD_DMIC_HV = 19,
	TEGRA_IO_PAD_DP = 20,
	TEGRA_IO_PAD_DSI = 21,
	TEGRA_IO_PAD_DSIB = 22,
	TEGRA_IO_PAD_DSIC = 23,
	TEGRA_IO_PAD_DSID = 24,
	TEGRA_IO_PAD_EDP = 25,
	TEGRA_IO_PAD_EMMC = 26,
	TEGRA_IO_PAD_EMMC2 = 27,
	TEGRA_IO_PAD_EQOS = 28,
	TEGRA_IO_PAD_GPIO = 29,
	TEGRA_IO_PAD_GP_PWM2 = 30,
	TEGRA_IO_PAD_GP_PWM3 = 31,
	TEGRA_IO_PAD_HDMI = 32,
	TEGRA_IO_PAD_HDMI_DP0 = 33,
	TEGRA_IO_PAD_HDMI_DP1 = 34,
	TEGRA_IO_PAD_HDMI_DP2 = 35,
	TEGRA_IO_PAD_HDMI_DP3 = 36,
	TEGRA_IO_PAD_HSIC = 37,
	TEGRA_IO_PAD_HV = 38,
	TEGRA_IO_PAD_LVDS = 39,
	TEGRA_IO_PAD_MIPI_BIAS = 40,
	TEGRA_IO_PAD_NAND = 41,
	TEGRA_IO_PAD_PEX_BIAS = 42,
	TEGRA_IO_PAD_PEX_CLK_BIAS = 43,
	TEGRA_IO_PAD_PEX_CLK1 = 44,
	TEGRA_IO_PAD_PEX_CLK2 = 45,
	TEGRA_IO_PAD_PEX_CLK3 = 46,
	TEGRA_IO_PAD_PEX_CLK_2_BIAS = 47,
	TEGRA_IO_PAD_PEX_CLK_2 = 48,
	TEGRA_IO_PAD_PEX_CNTRL = 49,
	TEGRA_IO_PAD_PEX_CTL2 = 50,
	TEGRA_IO_PAD_PEX_L0_RST_N = 51,
	TEGRA_IO_PAD_PEX_L1_RST_N = 52,
	TEGRA_IO_PAD_PEX_L5_RST_N = 53,
	TEGRA_IO_PAD_PWR_CTL = 54,
	TEGRA_IO_PAD_SDMMC1 = 55,
	TEGRA_IO_PAD_SDMMC1_HV = 56,
	TEGRA_IO_PAD_SDMMC2 = 57,
	TEGRA_IO_PAD_SDMMC2_HV = 58,
	TEGRA_IO_PAD_SDMMC3 = 59,
	TEGRA_IO_PAD_SDMMC3_HV = 60,
	TEGRA_IO_PAD_SDMMC4 = 61,
	TEGRA_IO_PAD_SOC_GPIO10 = 62,
	TEGRA_IO_PAD_SOC_GPIO12 = 63,
	TEGRA_IO_PAD_SOC_GPIO13 = 64,
	TEGRA_IO_PAD_SOC_GPIO53 = 65,
	TEGRA_IO_PAD_SPI = 66,
	TEGRA_IO_PAD_SPI_HV = 67,
	TEGRA_IO_PAD_SYS_DDC = 68,
	TEGRA_IO_PAD_UART = 69,
	TEGRA_IO_PAD_UART4 = 70,
	TEGRA_IO_PAD_UART5 = 71,
	TEGRA_IO_PAD_UFS = 72,
	TEGRA_IO_PAD_USB0 = 73,
	TEGRA_IO_PAD_USB1 = 74,
	TEGRA_IO_PAD_USB2 = 75,
	TEGRA_IO_PAD_USB3 = 76,
	TEGRA_IO_PAD_USB_BIAS = 77,
	TEGRA_IO_PAD_AO_HV = 78,
};

struct pmc_clk {
	struct clk_hw___4 hw;
	long unsigned int offs;
	u32 mux_shift;
	u32 force_en_shift;
};

struct pmc_clk_gate {
	struct clk_hw___4 hw;
	long unsigned int offs;
	u32 shift;
};

struct pmc_clk_init_data {
	char *name;
	const char * const *parents;
	int num_parents;
	int clk_id;
	u8 mux_shift;
	u8 force_en_shift;
};

struct tegra_pmc;

struct tegra_powergate {
	struct generic_pm_domain genpd;
	struct tegra_pmc *pmc;
	unsigned int id;
	struct clk **clks;
	unsigned int num_clks;
	long unsigned int *clk_rates;
	struct reset_control *reset;
};

struct tegra_pmc_soc;

struct tegra_pmc {
	struct device___158 *dev;
	void *base;
	void *wake;
	void *aotag;
	void *scratch;
	struct clk *clk;
	struct dentry___195 *debugfs;
	const struct tegra_pmc_soc *soc;
	bool tz_only;
	long unsigned int rate;
	enum tegra_suspend_mode suspend_mode;
	u32 cpu_good_time;
	u32 cpu_off_time;
	u32 core_osc_time;
	u32 core_pmu_time;
	u32 core_off_time;
	bool corereq_high;
	bool sysclkreq_high;
	bool combined_req;
	bool cpu_pwr_good_en;
	u32 lp0_vec_phys;
	u32 lp0_vec_size;
	long unsigned int powergates_available[1];
	struct mutex powergates_lock;
	struct pinctrl_dev___4 *pctl_dev;
	struct irq_domain___32 *domain;
	struct irq_chip___33 irq;
	struct notifier_block clk_nb;
	bool core_domain_state_synced;
	bool core_domain_registered;
};

struct tegra_io_pad_soc {
	enum tegra_io_pad id;
	unsigned int dpd;
	unsigned int voltage;
	const char *name;
};

struct tegra_pmc_regs {
	unsigned int scratch0;
	unsigned int dpd_req;
	unsigned int dpd_status;
	unsigned int dpd2_req;
	unsigned int dpd2_status;
	unsigned int rst_status;
	unsigned int rst_source_shift;
	unsigned int rst_source_mask;
	unsigned int rst_level_shift;
	unsigned int rst_level_mask;
};

struct tegra_wake_event {
	const char *name;
	unsigned int id;
	unsigned int irq;
	struct {
		unsigned int instance;
		unsigned int pin;
	} gpio;
};

struct tegra_pmc_soc {
	unsigned int num_powergates;
	const char * const *powergates;
	unsigned int num_cpu_powergates;
	const u8 *cpu_powergates;
	bool has_tsense_reset;
	bool has_gpu_clamps;
	bool needs_mbist_war;
	bool has_impl_33v_pwr;
	bool maybe_tz_only;
	const struct tegra_io_pad_soc *io_pads;
	unsigned int num_io_pads;
	const struct pinctrl_pin_desc *pin_descs;
	unsigned int num_pin_descs;
	const struct tegra_pmc_regs *regs;
	void (*init)(struct tegra_pmc *);
	void (*setup_irq_polarity)(struct tegra_pmc *, struct device_node___53 *, bool);
	int (*irq_set_wake)(struct irq_data___33 *, unsigned int);
	int (*irq_set_type)(struct irq_data___33 *, unsigned int);
	int (*powergate_set)(struct tegra_pmc *, unsigned int, bool);
	const char * const *reset_sources;
	unsigned int num_reset_sources;
	const char * const *reset_levels;
	unsigned int num_reset_levels;
	const struct tegra_wake_event *wake_events;
	unsigned int num_wake_events;
	const struct pmc_clk_init_data *pmc_clks_data;
	unsigned int num_pmc_clks;
	bool has_blink_output;
	bool has_usb_sleepwalk;
};

struct mbox_client___3 {
	struct device___159 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___3 *, void *);
	void (*tx_prepare)(struct mbox_client___3 *, void *);
	void (*tx_done)(struct mbox_client___3 *, void *, int);
};

struct reset_controller_dev___6;

struct reset_control_ops___6 {
	int (*reset)(struct reset_controller_dev___6 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___6 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___6 *, long unsigned int);
	int (*status)(struct reset_controller_dev___6 *, long unsigned int);
};

struct reset_controller_dev___6 {
	const struct reset_control_ops___6 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___159 *dev;
	struct device_node___63 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___6 *, const struct of_phandle_args___27 *);
	unsigned int nr_resets;
};

enum mrq_pg_cmd {
	CMD_PG_QUERY_ABI = 0,
	CMD_PG_SET_STATE = 1,
	CMD_PG_GET_STATE = 2,
	CMD_PG_GET_NAME = 3,
	CMD_PG_GET_MAX_ID = 4,
};

enum pg_states {
	PG_STATE_OFF = 0,
	PG_STATE_ON = 1,
	PG_STATE_RUNNING = 2,
};

struct cmd_pg_query_abi_request {
	uint32_t type;
};

struct cmd_pg_set_state_request {
	uint32_t state;
};

struct cmd_pg_get_state_response {
	uint32_t state;
};

struct cmd_pg_get_name_response {
	uint8_t name[40];
};

struct cmd_pg_get_max_id_response {
	uint32_t max_id;
};

struct mrq_pg_request {
	uint32_t cmd;
	uint32_t id;
	union {
		struct cmd_pg_query_abi_request query_abi;
		struct cmd_pg_set_state_request set_state;
	};
};

struct mrq_pg_response {
	union {
		struct cmd_pg_get_state_response get_state;
		struct cmd_pg_get_name_response get_name;
		struct cmd_pg_get_max_id_response get_max_id;
	};
};

struct tegra_bpmp___3;

struct tegra_bpmp_channel___3 {
	struct tegra_bpmp___3 *bpmp;
	struct tegra_bpmp_mb_data *ib;
	struct tegra_bpmp_mb_data *ob;
	struct completion completion;
	struct tegra_ivc *ivc;
	unsigned int index;
};

struct tegra_bpmp_clk___2;

struct tegra_bpmp___3 {
	const struct tegra_bpmp_soc *soc;
	struct device___159 *dev;
	void *priv;
	struct {
		struct mbox_client___3 client;
		struct mbox_chan___2 *channel;
	} mbox;
	spinlock_t atomic_tx_lock;
	struct tegra_bpmp_channel___3 *tx_channel;
	struct tegra_bpmp_channel___3 *rx_channel;
	struct tegra_bpmp_channel___3 *threaded_channels;
	struct {
		long unsigned int *allocated;
		long unsigned int *busy;
		unsigned int count;
		struct semaphore lock;
	} threaded;
	struct list_head mrqs;
	spinlock_t lock;
	struct tegra_bpmp_clk___2 **clocks;
	unsigned int num_clocks;
	struct reset_controller_dev___6 rstc;
	struct genpd_onecell_data___2 genpd;
	struct dentry___182 *debugfs_mirror;
};

struct tegra_powergate_info {
	unsigned int id;
	char *name;
};

struct tegra_powergate___2 {
	struct generic_pm_domain___3 genpd;
	struct tegra_bpmp___3 *bpmp;
	unsigned int id;
};

struct k3_ring_rt_regs {
	u32 resv_16[4];
	u32 db;
	u32 resv_4[1];
	u32 occ;
	u32 indx;
	u32 hwocc;
	u32 hwindx;
};

struct k3_ring_fifo_regs {
	u32 head_data[128];
	u32 tail_data[128];
	u32 peek_head_data[128];
	u32 peek_tail_data[128];
};

struct k3_ringacc_proxy_gcfg_regs {
	u32 revision;
	u32 config;
};

struct k3_ringacc_proxy_target_regs {
	u32 control;
	u32 status;
	u8 resv_512[504];
	u32 data[128];
};

enum k3_ringacc_proxy_access_mode {
	PROXY_ACCESS_MODE_HEAD = 0,
	PROXY_ACCESS_MODE_TAIL = 1,
	PROXY_ACCESS_MODE_PEEK_HEAD = 2,
	PROXY_ACCESS_MODE_PEEK_TAIL = 3,
};

struct k3_ring___2;

struct k3_ring_ops {
	int (*push_tail)(struct k3_ring___2 *, void *);
	int (*push_head)(struct k3_ring___2 *, void *);
	int (*pop_tail)(struct k3_ring___2 *, void *);
	int (*pop_head)(struct k3_ring___2 *, void *);
};

struct k3_ring_state {
	u32 free;
	u32 occ;
	u32 windex;
	u32 rindex;
	u32 tdown_complete: 1;
	long: 31;
	long: 64;
	long: 64;
};

struct k3_ringacc___2;

struct k3_ring___2 {
	struct k3_ring_rt_regs *rt;
	struct k3_ring_fifo_regs *fifos;
	struct k3_ringacc_proxy_target_regs *proxy;
	dma_addr_t ring_mem_dma;
	void *ring_mem_virt;
	struct k3_ring_ops *ops;
	u32 size;
	enum k3_ring_size elm_size;
	enum k3_ring_mode mode;
	u32 flags;
	struct k3_ring_state state;
	u32 ring_id;
	struct k3_ringacc___2 *parent;
	u32 use_count;
	int proxy_id;
	struct device___158 *dma_dev;
	u32 asel;
};

struct k3_ringacc_ops;

struct k3_ringacc___2 {
	struct device___158 *dev;
	struct k3_ringacc_proxy_gcfg_regs *proxy_gcfg;
	void *proxy_target_base;
	u32 num_rings;
	long unsigned int *rings_inuse;
	struct ti_sci_resource *rm_gp_range;
	bool dma_ring_reset_quirk;
	u32 num_proxies;
	long unsigned int *proxy_inuse;
	struct k3_ring___2 *rings;
	struct list_head list;
	struct mutex req_lock;
	const struct ti_sci_handle *tisci;
	const struct ti_sci_rm_ringacc_ops *tisci_ring_ops;
	u32 tisci_dev_id;
	const struct k3_ringacc_ops *ops;
	bool dma_rings;
};

struct k3_ringacc_ops {
	int (*init)(struct platform_device___17 *, struct k3_ringacc___2 *);
};

struct k3_ringacc_soc_data {
	unsigned int dma_ring_reset_quirk: 1;
};

enum k3_ringacc_access_mode {
	K3_RINGACC_ACCESS_MODE_PUSH_HEAD = 0,
	K3_RINGACC_ACCESS_MODE_POP_HEAD = 1,
	K3_RINGACC_ACCESS_MODE_PUSH_TAIL = 2,
	K3_RINGACC_ACCESS_MODE_POP_TAIL = 3,
	K3_RINGACC_ACCESS_MODE_PEEK_HEAD = 4,
	K3_RINGACC_ACCESS_MODE_PEEK_TAIL = 5,
};

struct ringacc_match_data {
	struct k3_ringacc_ops ops;
};

struct k3_soc_id {
	unsigned int id;
	const char *family_name;
};

struct mbox_client___4 {
	struct device___156 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___4 *, void *);
	void (*tx_prepare)(struct mbox_client___4 *, void *);
	void (*tx_done)(struct mbox_client___4 *, void *, int);
};

enum zynqmp_pm_suspend_reason {
	SUSPEND_POWER_REQUEST = 201,
	SUSPEND_ALERT = 202,
	SUSPEND_SYSTEM_SHUTDOWN = 203,
};

struct zynqmp_ipi_message {
	size_t len;
	u8 data[0];
};

struct zynqmp_pm_work_struct {
	struct work_struct callback_work;
	u32 args[4];
};

enum pm_suspend_mode {
	PM_SUSPEND_MODE_FIRST = 0,
	PM_SUSPEND_MODE_STD = 0,
	PM_SUSPEND_MODE_POWER_OFF = 1,
};

enum pm_api_cb_id {
	PM_INIT_SUSPEND_CB = 30,
	PM_ACKNOWLEDGE_CB = 31,
	PM_NOTIFY_CB = 32,
};

enum zynqmp_pm_request_ack {
	ZYNQMP_PM_REQUEST_ACK_NO = 1,
	ZYNQMP_PM_REQUEST_ACK_BLOCKING = 2,
	ZYNQMP_PM_REQUEST_ACK_NON_BLOCKING = 3,
};

struct zynqmp_pm_domain {
	struct generic_pm_domain gpd;
	u32 node_id;
	u8 flags;
};

struct virtio_driver {
	struct device_driver___157 driver;
	const struct virtio_device_id *id_table;
	const unsigned int *feature_table;
	unsigned int feature_table_size;
	const unsigned int *feature_table_legacy;
	unsigned int feature_table_size_legacy;
	int (*validate)(struct virtio_device *);
	int (*probe)(struct virtio_device *);
	void (*scan)(struct virtio_device *);
	void (*remove)(struct virtio_device *);
	void (*config_changed)(struct virtio_device *);
	int (*freeze)(struct virtio_device *);
	int (*restore)(struct virtio_device *);
};

struct virtio_device___2;

struct virtqueue___2 {
	struct list_head list;
	void (*callback)(struct virtqueue___2 *);
	const char *name;
	struct virtio_device___2 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct virtio_config_ops___2;

struct virtio_device___2 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___158 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___2 *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t___2(struct virtqueue___2 *);

struct virtio_config_ops___2 {
	void (*get)(struct virtio_device___2 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___2 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___2 *);
	u8 (*get_status)(struct virtio_device___2 *);
	void (*set_status)(struct virtio_device___2 *, u8);
	void (*reset)(struct virtio_device___2 *);
	int (*find_vqs)(struct virtio_device___2 *, unsigned int, struct virtqueue___2 **, vq_callback_t___2 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___2 *);
	u64 (*get_features)(struct virtio_device___2 *);
	int (*finalize_features)(struct virtio_device___2 *);
	const char * (*bus_name)(struct virtio_device___2 *);
	int (*set_vq_affinity)(struct virtqueue___2 *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___2 *, int);
	bool (*get_shm_region)(struct virtio_device___2 *, struct virtio_shm_region *, u8);
};

typedef __u16 __virtio16;

typedef __u32 __virtio32;

typedef __u64 __virtio64;

struct vring_desc {
	__virtio64 addr;
	__virtio32 len;
	__virtio16 flags;
	__virtio16 next;
};

struct vring_avail {
	__virtio16 flags;
	__virtio16 idx;
	__virtio16 ring[0];
};

struct vring_used_elem {
	__virtio32 id;
	__virtio32 len;
};

typedef struct vring_used_elem vring_used_elem_t;

struct vring_used {
	__virtio16 flags;
	__virtio16 idx;
	vring_used_elem_t ring[0];
};

typedef struct vring_desc vring_desc_t;

typedef struct vring_avail vring_avail_t;

typedef struct vring_used vring_used_t;

struct vring {
	unsigned int num;
	vring_desc_t *desc;
	vring_avail_t *avail;
	vring_used_t *used;
};

struct vring_packed_desc_event {
	__le16 off_wrap;
	__le16 flags;
};

struct vring_packed_desc {
	__le64 addr;
	__le32 len;
	__le16 id;
	__le16 flags;
};

struct vring_desc_state_split {
	void *data;
	struct vring_desc *indir_desc;
};

struct vring_desc_state_packed {
	void *data;
	struct vring_packed_desc *indir_desc;
	u16 num;
	u16 last;
};

struct vring_desc_extra {
	dma_addr_t addr;
	u32 len;
	u16 flags;
	u16 next;
};

struct vring_virtqueue {
	struct virtqueue___2 vq;
	bool packed_ring;
	bool use_dma_api;
	bool weak_barriers;
	bool broken;
	bool indirect;
	bool event;
	unsigned int free_head;
	unsigned int num_added;
	u16 last_used_idx;
	bool event_triggered;
	union {
		struct {
			struct vring vring;
			u16 avail_flags_shadow;
			u16 avail_idx_shadow;
			struct vring_desc_state_split *desc_state;
			struct vring_desc_extra *desc_extra;
			dma_addr_t queue_dma_addr;
			size_t queue_size_in_bytes;
		} split;
		struct {
			struct {
				unsigned int num;
				struct vring_packed_desc *desc;
				struct vring_packed_desc_event *driver;
				struct vring_packed_desc_event *device;
			} vring;
			bool avail_wrap_counter;
			bool used_wrap_counter;
			u16 avail_used_flags;
			u16 next_avail_idx;
			u16 event_flags_shadow;
			struct vring_desc_state_packed *desc_state;
			struct vring_desc_extra *desc_extra;
			dma_addr_t ring_dma_addr;
			dma_addr_t driver_event_dma_addr;
			dma_addr_t device_event_dma_addr;
			size_t ring_size_in_bytes;
			size_t event_size_in_bytes;
		} packed;
	};
	bool (*notify)(struct virtqueue___2 *);
	bool we_own_ring;
};

struct virtio_pci_common_cfg {
	__le32 device_feature_select;
	__le32 device_feature;
	__le32 guest_feature_select;
	__le32 guest_feature;
	__le16 msix_config;
	__le16 num_queues;
	__u8 device_status;
	__u8 config_generation;
	__le16 queue_select;
	__le16 queue_size;
	__le16 queue_msix_vector;
	__le16 queue_enable;
	__le16 queue_notify_off;
	__le32 queue_desc_lo;
	__le32 queue_desc_hi;
	__le32 queue_avail_lo;
	__le32 queue_avail_hi;
	__le32 queue_used_lo;
	__le32 queue_used_hi;
};

struct virtio_pci_modern_device {
	struct pci_dev___12 *pci_dev;
	struct virtio_pci_common_cfg *common;
	void *device;
	void *notify_base;
	resource_size_t notify_pa;
	u8 *isr;
	size_t notify_len;
	size_t device_len;
	int notify_map_cap;
	u32 notify_offset_multiplier;
	int modern_bars;
	struct virtio_device_id id;
};

struct module_version_attribute___5 {
	struct module_attribute___180 mattr;
	const char *module_name;
	const char *version;
};

struct platform_device_info___4 {
	struct device___156 *parent;
	struct fwnode_handle___156 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct virtio_device___3;

struct virtqueue___3 {
	struct list_head list;
	void (*callback)(struct virtqueue___3 *);
	const char *name;
	struct virtio_device___3 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct virtio_config_ops___3;

struct virtio_device___3 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___156 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___3 *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t___3(struct virtqueue___3 *);

struct virtio_config_ops___3 {
	void (*get)(struct virtio_device___3 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___3 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___3 *);
	u8 (*get_status)(struct virtio_device___3 *);
	void (*set_status)(struct virtio_device___3 *, u8);
	void (*reset)(struct virtio_device___3 *);
	int (*find_vqs)(struct virtio_device___3 *, unsigned int, struct virtqueue___3 **, vq_callback_t___3 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___3 *);
	u64 (*get_features)(struct virtio_device___3 *);
	int (*finalize_features)(struct virtio_device___3 *);
	const char * (*bus_name)(struct virtio_device___3 *);
	int (*set_vq_affinity)(struct virtqueue___3 *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___3 *, int);
	bool (*get_shm_region)(struct virtio_device___3 *, struct virtio_shm_region *, u8);
};

struct virtio_mmio_device {
	struct virtio_device___3 vdev;
	struct platform_device___19 *pdev;
	void *base;
	long unsigned int version;
	spinlock_t lock;
	struct list_head virtqueues;
};

struct virtio_mmio_vq_info {
	struct virtqueue___3 *vq;
	struct list_head node;
};

struct virtio_pci_vq_info {
	struct virtqueue___3 *vq;
	struct list_head node;
	unsigned int msix_vector;
};

struct virtio_pci_device {
	struct virtio_device___3 vdev;
	struct pci_dev___12 *pci_dev;
	struct virtio_pci_modern_device mdev;
	u8 *isr;
	void *ioaddr;
	spinlock_t lock;
	struct list_head virtqueues;
	struct virtio_pci_vq_info **vqs;
	int msix_enabled;
	int intx_enabled;
	cpumask_var_t *msix_affinity_masks;
	char (*msix_names)[256];
	unsigned int msix_vectors;
	unsigned int msix_used_vectors;
	bool per_vq_vectors;
	struct virtqueue___3 * (*setup_vq)(struct virtio_pci_device *, struct virtio_pci_vq_info *, unsigned int, void (*)(struct virtqueue___3 *), const char *, bool, u16);
	void (*del_vq)(struct virtio_pci_vq_info *);
	u16 (*config_vector)(struct virtio_pci_device *, u16);
};

enum {
	VP_MSIX_CONFIG_VECTOR = 0,
	VP_MSIX_VQ_VECTOR = 1,
};

typedef struct pglist_data___76 pg_data_t___13;

struct virtio_device___4;

struct virtqueue___4 {
	struct list_head list;
	void (*callback)(struct virtqueue___4 *);
	const char *name;
	struct virtio_device___4 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct virtio_config_ops___4;

struct virtio_device___4 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___126 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___4 *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t___4(struct virtqueue___4 *);

struct virtio_config_ops___4 {
	void (*get)(struct virtio_device___4 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___4 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___4 *);
	u8 (*get_status)(struct virtio_device___4 *);
	void (*set_status)(struct virtio_device___4 *, u8);
	void (*reset)(struct virtio_device___4 *);
	int (*find_vqs)(struct virtio_device___4 *, unsigned int, struct virtqueue___4 **, vq_callback_t___4 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___4 *);
	u64 (*get_features)(struct virtio_device___4 *);
	int (*finalize_features)(struct virtio_device___4 *);
	const char * (*bus_name)(struct virtio_device___4 *);
	int (*set_vq_affinity)(struct virtqueue___4 *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___4 *, int);
	bool (*get_shm_region)(struct virtio_device___4 *, struct virtio_shm_region *, u8);
};

struct virtio_driver___2 {
	struct device_driver___126 driver;
	const struct virtio_device_id *id_table;
	const unsigned int *feature_table;
	unsigned int feature_table_size;
	const unsigned int *feature_table_legacy;
	unsigned int feature_table_size_legacy;
	int (*validate)(struct virtio_device___4 *);
	int (*probe)(struct virtio_device___4 *);
	void (*scan)(struct virtio_device___4 *);
	void (*remove)(struct virtio_device___4 *);
	void (*config_changed)(struct virtio_device___4 *);
	int (*freeze)(struct virtio_device___4 *);
	int (*restore)(struct virtio_device___4 *);
};

struct virtio_balloon_config {
	__le32 num_pages;
	__le32 actual;
	union {
		__le32 free_page_hint_cmd_id;
		__le32 free_page_report_cmd_id;
	};
	__le32 poison_val;
};

struct virtio_balloon_stat {
	__virtio16 tag;
	__virtio64 val;
} __attribute__((packed));

struct balloon_dev_info___2 {
	long unsigned int isolated_pages;
	spinlock_t pages_lock;
	struct list_head pages;
	int (*migratepage)(struct balloon_dev_info___2 *, struct page___179 *, struct page___179 *, enum migrate_mode);
	struct inode___173 *inode;
};

enum virtio_balloon_vq {
	VIRTIO_BALLOON_VQ_INFLATE = 0,
	VIRTIO_BALLOON_VQ_DEFLATE = 1,
	VIRTIO_BALLOON_VQ_STATS = 2,
	VIRTIO_BALLOON_VQ_FREE_PAGE = 3,
	VIRTIO_BALLOON_VQ_REPORTING = 4,
	VIRTIO_BALLOON_VQ_MAX = 5,
};

enum virtio_balloon_config_read {
	VIRTIO_BALLOON_CONFIG_READ_CMD_ID = 0,
};

struct virtio_balloon {
	struct virtio_device___4 *vdev;
	struct virtqueue___4 *inflate_vq;
	struct virtqueue___4 *deflate_vq;
	struct virtqueue___4 *stats_vq;
	struct virtqueue___4 *free_page_vq;
	struct workqueue_struct *balloon_wq;
	struct work_struct report_free_page_work;
	struct work_struct update_balloon_stats_work;
	struct work_struct update_balloon_size_work;
	spinlock_t stop_update_lock;
	bool stop_update;
	int: 24;
	long unsigned int config_read_bitmap;
	struct list_head free_page_list;
	spinlock_t free_page_list_lock;
	int: 32;
	long unsigned int num_free_page_blocks;
	u32 cmd_id_received_cache;
	__virtio32 cmd_id_active;
	__virtio32 cmd_id_stop;
	int: 32;
	wait_queue_head_t acked;
	unsigned int num_pages;
	int: 32;
	struct balloon_dev_info___2 vb_dev_info;
	struct mutex balloon_lock;
	unsigned int num_pfns;
	__virtio32 pfns[256];
	struct virtio_balloon_stat stats[10];
	struct shrinker___69 shrinker;
	struct notifier_block oom_nb;
	struct virtqueue___4 *reporting_vq;
	struct page_reporting_dev_info pr_dev_info;
} __attribute__((packed));

struct xenbus_watch {
	struct list_head list;
	const char *node;
	unsigned int nr_pending;
	bool (*will_handle)(struct xenbus_watch *, const char *, const char *);
	void (*callback)(struct xenbus_watch *, const char *, const char *);
};

struct xenbus_transaction {
	u32 id;
};

typedef struct {
	union {
		xen_pfn_t *p;
		uint64_t q;
	};
} __guest_handle_xen_pfn_t;

struct grant_entry_v1 {
	uint16_t flags;
	domid_t domid;
	uint32_t frame;
};

struct grant_entry_header {
	uint16_t flags;
	domid_t domid;
};

union grant_entry_v2 {
	struct grant_entry_header hdr;
	struct {
		struct grant_entry_header hdr;
		uint32_t pad0;
		uint64_t frame;
	} full_page;
	struct {
		struct grant_entry_header hdr;
		uint16_t page_off;
		uint16_t length;
		uint64_t frame;
	} sub_page;
	struct {
		struct grant_entry_header hdr;
		domid_t trans_domid;
		uint16_t pad0;
		grant_ref_t gref;
	} transitive;
	uint32_t __spacer[4];
};

struct gnttab_setup_table {
	domid_t dom;
	uint32_t nr_frames;
	int16_t status;
	__guest_handle_xen_pfn_t frame_list;
};

struct gnttab_copy {
	struct {
		union {
			grant_ref_t ref;
			xen_pfn_t gmfn;
		} u;
		domid_t domid;
		uint16_t offset;
	} source;
	struct {
		union {
			grant_ref_t ref;
			xen_pfn_t gmfn;
		} u;
		domid_t domid;
		uint16_t offset;
	} dest;
	uint16_t len;
	uint16_t flags;
	int16_t status;
};

struct gnttab_query_size {
	domid_t dom;
	uint32_t nr_frames;
	uint32_t max_nr_frames;
	int16_t status;
};

struct gnttab_set_version {
	uint32_t version;
};

struct gnttab_get_status_frames {
	uint32_t nr_frames;
	domid_t dom;
	int16_t status;
	__guest_handle_uint64_t frame_list;
};

struct gnttab_free_callback {
	struct gnttab_free_callback *next;
	void (*fn)(void *);
	void *arg;
	u16 count;
};

struct gntab_unmap_queue_data;

typedef void (*gnttab_unmap_refs_done)(int, struct gntab_unmap_queue_data *);

struct gntab_unmap_queue_data {
	struct delayed_work gnttab_work;
	void *data;
	gnttab_unmap_refs_done done;
	struct gnttab_unmap_grant_ref *unmap_ops;
	struct gnttab_unmap_grant_ref *kunmap_ops;
	struct page___200 **pages;
	unsigned int count;
	unsigned int age;
};

struct gnttab_page_cache {
	spinlock_t lock;
	struct list_head pages;
	unsigned int num_pages;
};

struct gnttab_dma_alloc_args {
	struct device___158 *dev;
	bool coherent;
	int nr_pages;
	struct page___200 **pages;
	xen_pfn_t *frames;
	void *vaddr;
	dma_addr_t dev_bus_addr;
};

struct xen_page_foreign {
	domid_t domid;
	grant_ref_t gref;
};

typedef void (*xen_grant_fn_t)(long unsigned int, unsigned int, unsigned int, void *);

struct gnttab_ops {
	unsigned int version;
	unsigned int grefs_per_grant_frame;
	int (*map_frames)(xen_pfn_t *, unsigned int);
	void (*unmap_frames)();
	void (*update_entry)(grant_ref_t, domid_t, long unsigned int, unsigned int);
	int (*end_foreign_access_ref)(grant_ref_t, int);
	long unsigned int (*end_foreign_transfer_ref)(grant_ref_t);
	long unsigned int (*read_frame)(grant_ref_t);
};

struct unmap_refs_callback_data {
	struct completion completion;
	int result;
};

struct deferred_entry {
	struct list_head list;
	grant_ref_t ref;
	bool ro;
	uint16_t warn_delay;
	struct page___200 *page;
};

struct xen_feature_info {
	unsigned int submap_idx;
	uint32_t submap;
};

typedef struct pglist_data___90 pg_data_t___14;

typedef void (*online_page_callback_t___2)(struct page___200 *, unsigned int);

struct balloon_stats {
	long unsigned int current_pages;
	long unsigned int target_pages;
	long unsigned int target_unpopulated;
	long unsigned int balloon_low;
	long unsigned int balloon_high;
	long unsigned int total_pages;
	long unsigned int schedule_delay;
	long unsigned int max_schedule_delay;
	long unsigned int retry_count;
	long unsigned int max_retry_count;
};

enum bp_state {
	BP_DONE = 0,
	BP_WAIT = 1,
	BP_EAGAIN = 2,
	BP_ECANCELED = 3,
};

enum shutdown_state {
	SHUTDOWN_INVALID = 4294967295,
	SHUTDOWN_POWEROFF = 0,
	SHUTDOWN_SUSPEND = 2,
	SHUTDOWN_HALT = 4,
};

struct shutdown_handler {
	const char command[11];
	bool flag;
	void (*cb)();
};

struct vcpu_runstate_info {
	int state;
	uint64_t state_entry_time;
	uint64_t time[4];
};

typedef struct {
	union {
		struct vcpu_runstate_info *p;
		uint64_t q;
	};
	long: 64;
} __guest_handle_vcpu_runstate_info;

struct vcpu_register_runstate_memory_area {
	union {
		__guest_handle_vcpu_runstate_info h;
		struct vcpu_runstate_info *v;
		uint64_t p;
	} addr;
	long: 64;
};

struct xen_memory_reservation {
	__guest_handle_xen_pfn_t extent_start;
	xen_ulong_t nr_extents;
	unsigned int extent_order;
	unsigned int address_bits;
	domid_t domid;
};

typedef uint32_t evtchn_port_t;

typedef struct {
	union {
		evtchn_port_t *p;
		uint64_t q;
	};
} __guest_handle_evtchn_port_t;

struct evtchn_bind_interdomain {
	domid_t remote_dom;
	evtchn_port_t remote_port;
	evtchn_port_t local_port;
};

struct evtchn_bind_virq {
	uint32_t virq;
	uint32_t vcpu;
	evtchn_port_t port;
};

struct evtchn_bind_pirq {
	uint32_t pirq;
	uint32_t flags;
	evtchn_port_t port;
};

struct evtchn_bind_ipi {
	uint32_t vcpu;
	evtchn_port_t port;
};

struct evtchn_close {
	evtchn_port_t port;
};

struct evtchn_send {
	evtchn_port_t port;
};

struct evtchn_status {
	domid_t dom;
	evtchn_port_t port;
	uint32_t status;
	uint32_t vcpu;
	union {
		struct {
			domid_t dom;
		} unbound;
		struct {
			domid_t dom;
			evtchn_port_t port;
		} interdomain;
		uint32_t pirq;
		uint32_t virq;
	} u;
};

struct evtchn_bind_vcpu {
	evtchn_port_t port;
	uint32_t vcpu;
};

struct evtchn_set_priority {
	evtchn_port_t port;
	uint32_t priority;
};

struct sched_poll {
	__guest_handle_evtchn_port_t ports;
	unsigned int nr_ports;
	uint64_t timeout;
};

enum ipi_vector {
	XEN_PLACEHOLDER_VECTOR = 0,
	XEN_NR_IPIS = 1,
};

struct physdev_eoi {
	uint32_t irq;
};

struct physdev_irq_status_query {
	uint32_t irq;
	uint32_t flags;
};

struct physdev_irq {
	uint32_t irq;
	uint32_t vector;
};

struct physdev_map_pirq {
	domid_t domid;
	int type;
	int index;
	int pirq;
	int bus;
	int devfn;
	int entry_nr;
	uint64_t table_base;
};

struct physdev_unmap_pirq {
	domid_t domid;
	int pirq;
};

struct physdev_get_free_pirq {
	int type;
	uint32_t pirq;
};

enum xenbus_state {
	XenbusStateUnknown = 0,
	XenbusStateInitialising = 1,
	XenbusStateInitWait = 2,
	XenbusStateInitialised = 3,
	XenbusStateConnected = 4,
	XenbusStateClosing = 5,
	XenbusStateClosed = 6,
	XenbusStateReconfiguring = 7,
	XenbusStateReconfigured = 8,
};

struct xenbus_device {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___136 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
	struct semaphore reclaim_sem;
	atomic_t event_channels;
	atomic_t events;
	atomic_t spurious_events;
	atomic_t jiffies_eoi_delayed;
	unsigned int spurious_threshold;
};

struct evtchn_loop_ctrl;

struct evtchn_ops {
	unsigned int (*max_channels)();
	unsigned int (*nr_channels)();
	int (*setup)(evtchn_port_t);
	void (*remove)(evtchn_port_t, unsigned int);
	void (*bind_to_cpu)(evtchn_port_t, unsigned int, unsigned int);
	void (*clear_pending)(evtchn_port_t);
	void (*set_pending)(evtchn_port_t);
	bool (*is_pending)(evtchn_port_t);
	void (*mask)(evtchn_port_t);
	void (*unmask)(evtchn_port_t);
	void (*handle_events)(unsigned int, struct evtchn_loop_ctrl *);
	void (*resume)();
	int (*percpu_init)(unsigned int);
	int (*percpu_deinit)(unsigned int);
};

struct evtchn_loop_ctrl {
	ktime_t timeout;
	unsigned int count;
	bool defer_eoi;
};

enum xen_irq_type {
	IRQT_UNBOUND = 0,
	IRQT_PIRQ = 1,
	IRQT_VIRQ = 2,
	IRQT_IPI = 3,
	IRQT_EVTCHN = 4,
};

struct irq_info {
	struct list_head list;
	struct list_head eoi_list;
	short int refcnt;
	u8 spurious_cnt;
	u8 is_accounted;
	short int type;
	u8 mask_reason;
	u8 is_active;
	unsigned int irq;
	evtchn_port_t evtchn;
	short unsigned int cpu;
	short unsigned int eoi_cpu;
	unsigned int irq_epoch;
	u64 eoi_time;
	raw_spinlock_t lock;
	union {
		short unsigned int virq;
		enum ipi_vector ipi;
		struct {
			short unsigned int pirq;
			short unsigned int gsi;
			unsigned char vector;
			unsigned char flags;
			uint16_t domid;
		} pirq;
		struct xenbus_device *interdomain;
	} u;
};

struct lateeoi_work {
	struct delayed_work delayed;
	spinlock_t eoi_list_lock;
	struct list_head eoi_list;
};

struct evtchn_unmask {
	evtchn_port_t port;
};

struct evtchn_init_control {
	uint64_t control_gfn;
	uint32_t offset;
	uint32_t vcpu;
	uint8_t link_bits;
	uint8_t _pad[7];
};

struct evtchn_expand_array {
	uint64_t array_gfn;
};

typedef uint32_t event_word_t;

struct evtchn_fifo_control_block {
	uint32_t ready;
	uint32_t _rsvd;
	event_word_t head[16];
};

struct evtchn_fifo_queue {
	uint32_t head[16];
};

struct evtchn_alloc_unbound {
	domid_t dom;
	domid_t remote_dom;
	evtchn_port_t port;
};

struct xenbus_map_node {
	struct list_head next;
	union {
		struct {
			struct vm_struct___179 *area;
		} pv;
		struct {
			struct page___201 *pages[16];
			long unsigned int addrs[16];
			void *addr;
		} hvm;
	};
	grant_handle_t handles[16];
	unsigned int nr_handles;
};

struct map_ring_valloc {
	struct xenbus_map_node *node;
	long unsigned int addrs[16];
	phys_addr_t phys_addrs[16];
	struct gnttab_map_grant_ref map[16];
	struct gnttab_unmap_grant_ref unmap[16];
	unsigned int idx;
};

struct xenbus_ring_ops {
	int (*map)(struct xenbus_device *, struct map_ring_valloc *, grant_ref_t *, unsigned int, void **);
	int (*unmap)(struct xenbus_device *, void *);
};

struct unmap_ring_hvm {
	unsigned int idx;
	long unsigned int addrs[16];
};

enum xsd_sockmsg_type {
	XS_DEBUG = 0,
	XS_DIRECTORY = 1,
	XS_READ = 2,
	XS_GET_PERMS = 3,
	XS_WATCH = 4,
	XS_UNWATCH = 5,
	XS_TRANSACTION_START = 6,
	XS_TRANSACTION_END = 7,
	XS_INTRODUCE = 8,
	XS_RELEASE = 9,
	XS_GET_DOMAIN_PATH = 10,
	XS_WRITE = 11,
	XS_MKDIR = 12,
	XS_RM = 13,
	XS_SET_PERMS = 14,
	XS_WATCH_EVENT = 15,
	XS_ERROR = 16,
	XS_IS_DOMAIN_INTRODUCED = 17,
	XS_RESUME = 18,
	XS_SET_TARGET = 19,
	XS_RESTRICT = 20,
	XS_RESET_WATCHES = 21,
};

struct xsd_sockmsg {
	uint32_t type;
	uint32_t req_id;
	uint32_t tx_id;
	uint32_t len;
};

typedef uint32_t XENSTORE_RING_IDX;

struct xenstore_domain_interface {
	char req[1024];
	char rsp[1024];
	XENSTORE_RING_IDX req_cons;
	XENSTORE_RING_IDX req_prod;
	XENSTORE_RING_IDX rsp_cons;
	XENSTORE_RING_IDX rsp_prod;
};

struct xs_watch_event {
	struct list_head list;
	unsigned int len;
	struct xenbus_watch *handle;
	const char *path;
	const char *token;
	char body[0];
};

enum xb_req_state {
	xb_req_state_queued = 0,
	xb_req_state_wait_reply = 1,
	xb_req_state_got_reply = 2,
	xb_req_state_aborted = 3,
};

struct xb_req_data {
	struct list_head list;
	wait_queue_head_t wq;
	struct xsd_sockmsg msg;
	uint32_t caller_req_id;
	enum xsd_sockmsg_type type;
	char *body;
	const struct kvec *vec;
	int num_vecs;
	int err;
	enum xb_req_state state;
	bool user_req;
	void (*cb)(struct xb_req_data *);
	void *par;
};

enum xenstore_init {
	XS_UNKNOWN = 0,
	XS_PV = 1,
	XS_HVM = 2,
	XS_LOCAL = 3,
};

struct xenbus_device___2 {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___158 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
	struct semaphore reclaim_sem;
	atomic_t event_channels;
	atomic_t events;
	atomic_t spurious_events;
	atomic_t jiffies_eoi_delayed;
	unsigned int spurious_threshold;
};

struct xenbus_device_id {
	char devicetype[32];
};

struct xenbus_driver {
	const char *name;
	const struct xenbus_device_id *ids;
	bool allow_rebind;
	int (*probe)(struct xenbus_device___2 *, const struct xenbus_device_id *);
	void (*otherend_changed)(struct xenbus_device___2 *, enum xenbus_state);
	int (*remove)(struct xenbus_device___2 *);
	int (*suspend)(struct xenbus_device___2 *);
	int (*resume)(struct xenbus_device___2 *);
	int (*uevent)(struct xenbus_device___2 *, struct kobj_uevent_env *);
	struct device_driver___158 driver;
	int (*read_otherend_details)(struct xenbus_device___2 *);
	int (*is_ready)(struct xenbus_device___2 *);
	void (*reclaim_memory)(struct xenbus_device___2 *);
};

struct xen_bus_type {
	char *root;
	unsigned int levels;
	int (*get_bus_id)(char *, const char *);
	int (*probe)(struct xen_bus_type *, const char *, const char *);
	bool (*otherend_will_handle)(struct xenbus_watch *, const char *, const char *);
	void (*otherend_changed)(struct xenbus_watch *, const char *, const char *);
	struct bus_type___158 bus;
};

struct xb_find_info {
	struct xenbus_device___2 *dev;
	const char *nodename;
};

typedef struct poll_table_struct___128 poll_table___32;

struct xenbus_transaction_holder {
	struct list_head list;
	struct xenbus_transaction handle;
	unsigned int generation_id;
};

struct read_buffer {
	struct list_head list;
	unsigned int cons;
	unsigned int len;
	char msg[0];
};

struct xenbus_file_priv {
	struct mutex msgbuffer_mutex;
	struct list_head transactions;
	struct list_head watches;
	unsigned int len;
	union {
		struct xsd_sockmsg msg;
		char buffer[4096];
	} u;
	struct mutex reply_mutex;
	struct list_head read_buffers;
	wait_queue_head_t read_waitq;
	struct kref kref;
	struct work_struct wq;
};

struct watch_adapter {
	struct list_head list;
	struct xenbus_watch watch;
	struct xenbus_file_priv *dev_data;
	char *token;
};

typedef struct {
	union {
		int *p;
		uint64_t q;
	};
} __guest_handle_int;

typedef struct {
	union {
		xen_ulong_t *p;
		uint64_t q;
	};
} __guest_handle_xen_ulong_t;

struct xen_add_to_physmap_range {
	domid_t domid;
	uint16_t space;
	uint16_t size;
	domid_t foreign_domid;
	__guest_handle_xen_ulong_t idxs;
	__guest_handle_xen_pfn_t gpfns;
	__guest_handle_int errs;
};

struct xen_remove_from_physmap {
	domid_t domid;
	xen_pfn_t gpfn;
};

struct physdev_manage_pci {
	uint8_t bus;
	uint8_t devfn;
};

struct physdev_manage_pci_ext {
	uint8_t bus;
	uint8_t devfn;
	unsigned int is_extfn;
	unsigned int is_virtfn;
	struct {
		uint8_t bus;
		uint8_t devfn;
	} physfn;
};

struct physdev_pci_device_add {
	uint16_t seg;
	uint8_t bus;
	uint8_t devfn;
	uint32_t flags;
	struct {
		uint8_t bus;
		uint8_t devfn;
	} physfn;
	uint32_t optarr[0];
};

struct physdev_pci_device {
	uint16_t seg;
	uint8_t bus;
	uint8_t devfn;
};

struct usb_device_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdUSB;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bMaxPacketSize0;
	__le16 idVendor;
	__le16 idProduct;
	__le16 bcdDevice;
	__u8 iManufacturer;
	__u8 iProduct;
	__u8 iSerialNumber;
	__u8 bNumConfigurations;
};

struct usb_config_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wTotalLength;
	__u8 bNumInterfaces;
	__u8 bConfigurationValue;
	__u8 iConfiguration;
	__u8 bmAttributes;
	__u8 bMaxPower;
} __attribute__((packed));

struct usb_interface_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bInterfaceNumber;
	__u8 bAlternateSetting;
	__u8 bNumEndpoints;
	__u8 bInterfaceClass;
	__u8 bInterfaceSubClass;
	__u8 bInterfaceProtocol;
	__u8 iInterface;
};

struct usb_endpoint_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bEndpointAddress;
	__u8 bmAttributes;
	__le16 wMaxPacketSize;
	__u8 bInterval;
	__u8 bRefresh;
	__u8 bSynchAddress;
} __attribute__((packed));

struct usb_ssp_isoc_ep_comp_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wReseved;
	__le32 dwBytesPerInterval;
};

struct usb_ss_ep_comp_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bMaxBurst;
	__u8 bmAttributes;
	__le16 wBytesPerInterval;
};

struct usb_interface_assoc_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bFirstInterface;
	__u8 bInterfaceCount;
	__u8 bFunctionClass;
	__u8 bFunctionSubClass;
	__u8 bFunctionProtocol;
	__u8 iFunction;
};

struct usb_bos_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wTotalLength;
	__u8 bNumDeviceCaps;
} __attribute__((packed));

struct usb_ext_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__le32 bmAttributes;
} __attribute__((packed));

struct usb_ss_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bmAttributes;
	__le16 wSpeedSupported;
	__u8 bFunctionalitySupport;
	__u8 bU1devExitLat;
	__le16 bU2DevExitLat;
};

struct usb_ss_container_id_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bReserved;
	__u8 ContainerID[16];
};

struct usb_ssp_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
	__u8 bReserved;
	__le32 bmAttributes;
	__le16 wFunctionalitySupport;
	__le16 wReserved;
	__le32 bmSublinkSpeedAttr[1];
};

struct usb_ptm_cap_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
};

enum usb_device_speed {
	USB_SPEED_UNKNOWN = 0,
	USB_SPEED_LOW = 1,
	USB_SPEED_FULL = 2,
	USB_SPEED_HIGH = 3,
	USB_SPEED_WIRELESS = 4,
	USB_SPEED_SUPER = 5,
	USB_SPEED_SUPER_PLUS = 6,
};

enum usb_device_state {
	USB_STATE_NOTATTACHED = 0,
	USB_STATE_ATTACHED = 1,
	USB_STATE_POWERED = 2,
	USB_STATE_RECONNECTING = 3,
	USB_STATE_UNAUTHENTICATED = 4,
	USB_STATE_DEFAULT = 5,
	USB_STATE_ADDRESS = 6,
	USB_STATE_CONFIGURED = 7,
	USB_STATE_SUSPENDED = 8,
};

enum usb3_link_state {
	USB3_LPM_U0 = 0,
	USB3_LPM_U1 = 1,
	USB3_LPM_U2 = 2,
	USB3_LPM_U3 = 3,
};

enum usb_ssp_rate {
	USB_SSP_GEN_UNKNOWN = 0,
	USB_SSP_GEN_2x1 = 1,
	USB_SSP_GEN_1x2 = 2,
	USB_SSP_GEN_2x2 = 3,
};

struct ep_device;

struct usb_host_endpoint {
	struct usb_endpoint_descriptor desc;
	struct usb_ss_ep_comp_descriptor ss_ep_comp;
	struct usb_ssp_isoc_ep_comp_descriptor ssp_isoc_ep_comp;
	char: 8;
	struct list_head urb_list;
	void *hcpriv;
	struct ep_device *ep_dev;
	unsigned char *extra;
	int extralen;
	int enabled;
	int streams;
	int: 32;
} __attribute__((packed));

struct usb_host_interface {
	struct usb_interface_descriptor desc;
	int extralen;
	unsigned char *extra;
	struct usb_host_endpoint *endpoint;
	char *string;
};

enum usb_interface_condition {
	USB_INTERFACE_UNBOUND = 0,
	USB_INTERFACE_BINDING = 1,
	USB_INTERFACE_BOUND = 2,
	USB_INTERFACE_UNBINDING = 3,
};

struct usb_interface {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created;
	unsigned int ep_devs_created;
	unsigned int unregistering;
	unsigned int needs_remote_wakeup;
	unsigned int needs_altsetting0;
	unsigned int needs_binding;
	unsigned int resetting_device;
	unsigned int authorized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct device___157 dev;
	struct device___157 *usb_dev;
	struct work_struct reset_ws;
};

struct usb_interface_cache {
	unsigned int num_altsetting;
	struct kref ref;
	struct usb_host_interface altsetting[0];
};

struct usb_host_config {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_host_bos {
	struct usb_bos_descriptor *desc;
	struct usb_ext_cap_descriptor *ext_cap;
	struct usb_ss_cap_descriptor *ss_cap;
	struct usb_ssp_cap_descriptor *ssp_cap;
	struct usb_ss_container_id_descriptor *ss_id;
	struct usb_ptm_cap_descriptor *ptm_cap;
};

struct usb_devmap {
	long unsigned int devicemap[2];
};

struct mon_bus;

struct usb_device;

struct usb_bus {
	struct device___157 *controller;
	struct device___157 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device *root_hub;
	struct usb_bus *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct wusb_dev;

struct usb2_lpm_parameters {
	unsigned int besl;
	int timeout;
};

struct usb3_lpm_parameters {
	unsigned int mel;
	unsigned int pel;
	unsigned int sel;
	int timeout;
};

struct usb_tt;

struct usb_device {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	enum usb_ssp_rate ssp_rate;
	struct usb_tt *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device *parent;
	struct usb_bus *bus;
	struct usb_host_endpoint ep0;
	struct device___157 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config *config;
	struct usb_host_config *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	u8 devaddr;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct wusb_dev *wusb_dev;
	int slot_id;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
	unsigned int use_generic_driver: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_tt {
	struct usb_device *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usb_iso_packet_descriptor {
	unsigned int offset;
	unsigned int length;
	unsigned int actual_length;
	int status;
};

struct usb_anchor {
	struct list_head urb_list;
	wait_queue_head_t wait;
	spinlock_t lock;
	atomic_t suspend_wakeups;
	unsigned int poisoned: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct urb;

typedef void (*usb_complete_t)(struct urb *);

struct urb {
	struct kref kref;
	int unlinked;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct giveback_urb_bh {
	bool running;
	spinlock_t lock;
	struct list_head head;
	struct tasklet_struct bh;
	struct usb_host_endpoint *completing_ep;
};

enum usb_dev_authorize_policy {
	USB_DEVICE_AUTHORIZE_NONE = 0,
	USB_DEVICE_AUTHORIZE_ALL = 1,
	USB_DEVICE_AUTHORIZE_INTERNAL = 2,
};

struct usb_phy_roothub;

struct hc_driver;

struct usb_phy;

struct usb_hcd {
	struct usb_bus self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb *status_urb;
	struct work_struct wakeup_work;
	struct work_struct died_work;
	const struct hc_driver *driver;
	struct usb_phy *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	enum usb_dev_authorize_policy dev_policy;
	unsigned int rh_registered;
	unsigned int rh_pollable;
	unsigned int msix_enabled;
	unsigned int msi_enabled;
	unsigned int skip_phy_initialization;
	unsigned int uses_new_polling;
	unsigned int wireless;
	unsigned int has_tt;
	unsigned int amd_resume_bug;
	unsigned int can_do_streams;
	unsigned int tpl_support;
	unsigned int cant_recv_wakeups;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd *shared_hcd;
	struct usb_hcd *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	struct gen_pool *localmem_pool;
	long unsigned int hcd_priv[0];
};

struct hc_driver {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd *);
	int flags;
	int (*reset)(struct usb_hcd *);
	int (*start)(struct usb_hcd *);
	int (*pci_suspend)(struct usb_hcd *, bool);
	int (*pci_resume)(struct usb_hcd *, bool);
	void (*stop)(struct usb_hcd *);
	void (*shutdown)(struct usb_hcd *);
	int (*get_frame_number)(struct usb_hcd *);
	int (*urb_enqueue)(struct usb_hcd *, struct urb *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd *, struct urb *, int);
	int (*map_urb_for_dma)(struct usb_hcd *, struct urb *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd *, struct urb *);
	void (*endpoint_disable)(struct usb_hcd *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd *, char *);
	int (*hub_control)(struct usb_hcd *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd *);
	int (*bus_resume)(struct usb_hcd *);
	int (*start_port_reset)(struct usb_hcd *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd *);
	void (*relinquish_port)(struct usb_hcd *, int);
	int (*port_handed_over)(struct usb_hcd *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd *, struct usb_device *);
	void (*free_dev)(struct usb_hcd *, struct usb_device *);
	int (*alloc_streams)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd *, struct usb_device *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd *, struct usb_device *);
	void (*reset_bandwidth)(struct usb_hcd *, struct usb_device *);
	int (*address_device)(struct usb_hcd *, struct usb_device *);
	int (*enable_device)(struct usb_hcd *, struct usb_device *);
	int (*update_hub_device)(struct usb_hcd *, struct usb_device *, struct usb_tt *, gfp_t);
	int (*reset_device)(struct usb_hcd *, struct usb_device *);
	int (*update_device)(struct usb_hcd *, struct usb_device *);
	int (*set_usb2_hw_lpm)(struct usb_hcd *, struct usb_device *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd *, struct usb_device *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd *, struct usb_device *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd *, int);
	int (*port_power)(struct usb_hcd *, int, bool);
	int (*submit_single_step_set_feature)(struct usb_hcd *, struct urb *, int);
};

struct physdev_dbgp_op {
	uint8_t op;
	uint8_t bus;
	union {
		struct physdev_pci_device pci;
	} u;
};

struct dev_ext_attribute {
	struct device_attribute___15 attr;
	void *var;
};

typedef uint8_t xen_domain_handle_t[16];

struct xen_compile_info {
	char compiler[64];
	char compile_by[16];
	char compile_domain[32];
	char compile_date[32];
};

struct xen_platform_parameters {
	xen_ulong_t virt_start;
};

struct xen_build_id {
	uint32_t len;
	unsigned char buf[0];
};

struct hyp_sysfs_attr {
	struct attribute attr;
	ssize_t (*show)(struct hyp_sysfs_attr *, char *);
	ssize_t (*store)(struct hyp_sysfs_attr *, const char *, size_t);
	void *hyp_attr_data;
};

enum xen_swiotlb_err {
	XEN_SWIOTLB_UNKNOWN = 0,
	XEN_SWIOTLB_ENOMEM = 1,
	XEN_SWIOTLB_EFIXUP = 2,
};

struct xen_processor_flags___2 {
	uint32_t bm_control;
	uint32_t bm_check;
	uint32_t has_cst;
	uint32_t power_setup_done;
	uint32_t bm_rld_set;
};

struct xen_processor_power___2 {
	uint32_t count;
	struct xen_processor_flags___2 flags;
	__guest_handle_xen_processor_cx states;
};

struct xenpf_set_processor_pminfo___2 {
	uint32_t id;
	uint32_t type;
	union {
		struct xen_processor_power___2 power;
		struct xen_processor_performance perf;
		__guest_handle_uint32_t pdc;
	};
};

struct xen_platform_op___2 {
	uint32_t cmd;
	uint32_t interface_version;
	union {
		struct xenpf_settime32 settime32;
		struct xenpf_settime64 settime64;
		struct xenpf_add_memtype add_memtype;
		struct xenpf_del_memtype del_memtype;
		struct xenpf_read_memtype read_memtype;
		struct xenpf_microcode_update microcode;
		struct xenpf_platform_quirk platform_quirk;
		struct xenpf_efi_runtime_call efi_runtime_call;
		struct xenpf_firmware_info firmware_info;
		struct xenpf_enter_acpi_sleep enter_acpi_sleep;
		struct xenpf_change_freq change_freq;
		struct xenpf_getidletime getidletime;
		struct xenpf_set_processor_pminfo___2 set_pminfo;
		struct xenpf_pcpuinfo pcpu_info;
		struct xenpf_cpu_ol cpu_ol;
		struct xenpf_cpu_hotadd cpu_add;
		struct xenpf_mem_hotadd mem_add;
		struct xenpf_core_parking core_parking;
		struct xenpf_symdata symdata;
		uint8_t pad[128];
	} u;
};

typedef void (*xen_gfn_fn_t)(long unsigned int, void *);

struct xen_remap_gfn_info;

struct remap_data {
	xen_pfn_t *fgfn;
	int nr_fgfn;
	pgprot_t prot;
	domid_t domid;
	struct vm_area_struct___176 *vma;
	int index;
	struct page___177 **pages;
	struct xen_remap_gfn_info *info;
	int *err_ptr;
	int mapped;
	int h_errs[1];
	xen_ulong_t h_idxs[1];
	xen_pfn_t h_gpfns[1];
	int h_iter;
};

struct map_balloon_pages {
	xen_pfn_t *pfns;
	unsigned int idx;
};

struct remap_pfn {
	struct mm_struct___177 *mm;
	struct page___177 **pages;
	pgprot_t prot;
	long unsigned int i;
};

struct ww_class {
	atomic_long_t stamp;
	struct lock_class_key acquire_key;
	struct lock_class_key mutex_key;
	const char *acquire_name;
	const char *mutex_name;
	unsigned int is_wait_die;
};

struct ww_acquire_ctx___6;

struct ww_mutex___4 {
	struct mutex base;
	struct ww_acquire_ctx___6 *ctx;
};

struct ww_acquire_ctx___6 {
	struct task_struct___26 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct device_link___14 {
	struct device___22 *supplier;
	struct list_head s_node;
	struct device___22 *consumer;
	struct list_head c_node;
	struct device___22 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct regulation_constraints___2 {
	const char *name;
	int min_uV;
	int max_uV;
	int uV_offset;
	int min_uA;
	int max_uA;
	int ilim_uA;
	int system_load;
	u32 *max_spread;
	int max_uV_step;
	unsigned int valid_modes_mask;
	unsigned int valid_ops_mask;
	int input_uV;
	struct regulator_state state_disk;
	struct regulator_state state_mem;
	struct regulator_state state_standby;
	struct notification_limit over_curr_limits;
	struct notification_limit over_voltage_limits;
	struct notification_limit under_voltage_limits;
	struct notification_limit temp_limits;
	suspend_state_t initial_state;
	unsigned int initial_mode;
	unsigned int ramp_delay;
	unsigned int settling_time;
	unsigned int settling_time_up;
	unsigned int settling_time_down;
	unsigned int enable_time;
	unsigned int active_discharge;
	unsigned int always_on: 1;
	unsigned int boot_on: 1;
	unsigned int apply_uV: 1;
	unsigned int ramp_disable: 1;
	unsigned int soft_start: 1;
	unsigned int pull_down: 1;
	unsigned int over_current_protection: 1;
	unsigned int over_current_detection: 1;
	unsigned int over_voltage_detection: 1;
	unsigned int under_voltage_detection: 1;
	unsigned int over_temp_detection: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct regulator_init_data___2 {
	const char *supply_regulator;
	struct regulation_constraints___2 constraints;
	int num_consumer_supplies;
	struct regulator_consumer_supply *consumer_supplies;
	int (*regulator_init)(void *);
	void *driver_data;
};

struct regulator_config___3;

struct regulator_ops___3;

struct regulator_desc___3 {
	const char *name;
	const char *supply_name;
	const char *of_match;
	bool of_match_full_name;
	const char *regulators_node;
	int (*of_parse_cb)(struct device_node___15 *, const struct regulator_desc___3 *, struct regulator_config___3 *);
	int id;
	unsigned int continuous_voltage_range: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int n_voltages;
	unsigned int n_current_limits;
	const struct regulator_ops___3 *ops;
	int irq;
	enum regulator_type type;
	struct module___26 *owner;
	unsigned int min_uV;
	unsigned int uV_step;
	unsigned int linear_min_sel;
	int fixed_uV;
	unsigned int ramp_delay;
	int min_dropout_uV;
	const struct linear_range *linear_ranges;
	const unsigned int *linear_range_selectors;
	int n_linear_ranges;
	const unsigned int *volt_table;
	const unsigned int *curr_table;
	unsigned int vsel_range_reg;
	unsigned int vsel_range_mask;
	unsigned int vsel_reg;
	unsigned int vsel_mask;
	unsigned int vsel_step;
	unsigned int csel_reg;
	unsigned int csel_mask;
	unsigned int apply_reg;
	unsigned int apply_bit;
	unsigned int enable_reg;
	unsigned int enable_mask;
	unsigned int enable_val;
	unsigned int disable_val;
	bool enable_is_inverted;
	unsigned int bypass_reg;
	unsigned int bypass_mask;
	unsigned int bypass_val_on;
	unsigned int bypass_val_off;
	unsigned int active_discharge_on;
	unsigned int active_discharge_off;
	unsigned int active_discharge_mask;
	unsigned int active_discharge_reg;
	unsigned int soft_start_reg;
	unsigned int soft_start_mask;
	unsigned int soft_start_val_on;
	unsigned int pull_down_reg;
	unsigned int pull_down_mask;
	unsigned int pull_down_val_on;
	unsigned int ramp_reg;
	unsigned int ramp_mask;
	const unsigned int *ramp_delay_table;
	unsigned int n_ramp_values;
	unsigned int enable_time;
	unsigned int off_on_delay;
	unsigned int poll_enabled_time;
	unsigned int (*of_map_mode)(unsigned int);
};

struct pre_voltage_change_data {
	long unsigned int old_uV;
	long unsigned int min_uV;
	long unsigned int max_uV;
};

struct regulator_voltage {
	int min_uV;
	int max_uV;
};

struct regulator_dev___3;

struct regulator {
	struct device___22 *dev;
	struct list_head list;
	unsigned int always_on: 1;
	unsigned int bypass: 1;
	unsigned int device_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	int uA_load;
	unsigned int enable_count;
	unsigned int deferred_disables;
	struct regulator_voltage voltage[5];
	const char *supply_name;
	struct device_attribute___4 dev_attr;
	struct regulator_dev___3 *rdev;
	struct dentry___25 *debugfs;
};

struct regulator_coupler {
	struct list_head list;
	int (*attach_regulator)(struct regulator_coupler *, struct regulator_dev___3 *);
	int (*detach_regulator)(struct regulator_coupler *, struct regulator_dev___3 *);
	int (*balance_voltage)(struct regulator_coupler *, struct regulator_dev___3 *, suspend_state_t);
};

struct coupling_desc___3 {
	struct regulator_dev___3 **coupled_rdevs;
	struct regulator_coupler *coupler;
	int n_resolved;
	int n_coupled;
};

struct regulator_dev___3 {
	const struct regulator_desc___3 *desc;
	int exclusive;
	u32 use_count;
	u32 open_count;
	u32 bypass_count;
	struct list_head list;
	struct list_head consumer_list;
	struct coupling_desc___3 coupling_desc;
	struct blocking_notifier_head notifier;
	struct ww_mutex___4 mutex;
	struct task_struct___26 *mutex_owner;
	int ref_cnt;
	struct module___26 *owner;
	struct device___22 dev;
	struct regulation_constraints___2 *constraints;
	struct regulator *supply;
	const char *supply_name;
	struct regmap *regmap;
	struct delayed_work disable_work;
	void *reg_data;
	struct dentry___25 *debugfs;
	struct regulator_enable_gpio *ena_pin;
	unsigned int ena_gpio_state: 1;
	unsigned int is_switch: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	ktime_t last_off;
	int cached_err;
	bool use_cached_err;
	spinlock_t err_lock;
};

enum regulator_status {
	REGULATOR_STATUS_OFF = 0,
	REGULATOR_STATUS_ON = 1,
	REGULATOR_STATUS_ERROR = 2,
	REGULATOR_STATUS_FAST = 3,
	REGULATOR_STATUS_NORMAL = 4,
	REGULATOR_STATUS_IDLE = 5,
	REGULATOR_STATUS_STANDBY = 6,
	REGULATOR_STATUS_BYPASS = 7,
	REGULATOR_STATUS_UNDEFINED = 8,
};

enum regulator_detection_severity {
	REGULATOR_SEVERITY_PROT = 0,
	REGULATOR_SEVERITY_ERR = 1,
	REGULATOR_SEVERITY_WARN = 2,
};

struct regulator_ops___3 {
	int (*list_voltage)(struct regulator_dev___3 *, unsigned int);
	int (*set_voltage)(struct regulator_dev___3 *, int, int, unsigned int *);
	int (*map_voltage)(struct regulator_dev___3 *, int, int);
	int (*set_voltage_sel)(struct regulator_dev___3 *, unsigned int);
	int (*get_voltage)(struct regulator_dev___3 *);
	int (*get_voltage_sel)(struct regulator_dev___3 *);
	int (*set_current_limit)(struct regulator_dev___3 *, int, int);
	int (*get_current_limit)(struct regulator_dev___3 *);
	int (*set_input_current_limit)(struct regulator_dev___3 *, int);
	int (*set_over_current_protection)(struct regulator_dev___3 *, int, int, bool);
	int (*set_over_voltage_protection)(struct regulator_dev___3 *, int, int, bool);
	int (*set_under_voltage_protection)(struct regulator_dev___3 *, int, int, bool);
	int (*set_thermal_protection)(struct regulator_dev___3 *, int, int, bool);
	int (*set_active_discharge)(struct regulator_dev___3 *, bool);
	int (*enable)(struct regulator_dev___3 *);
	int (*disable)(struct regulator_dev___3 *);
	int (*is_enabled)(struct regulator_dev___3 *);
	int (*set_mode)(struct regulator_dev___3 *, unsigned int);
	unsigned int (*get_mode)(struct regulator_dev___3 *);
	int (*get_error_flags)(struct regulator_dev___3 *, unsigned int *);
	int (*enable_time)(struct regulator_dev___3 *);
	int (*set_ramp_delay)(struct regulator_dev___3 *, int);
	int (*set_voltage_time)(struct regulator_dev___3 *, int, int);
	int (*set_voltage_time_sel)(struct regulator_dev___3 *, unsigned int, unsigned int);
	int (*set_soft_start)(struct regulator_dev___3 *);
	int (*get_status)(struct regulator_dev___3 *);
	unsigned int (*get_optimum_mode)(struct regulator_dev___3 *, int, int, int);
	int (*set_load)(struct regulator_dev___3 *, int);
	int (*set_bypass)(struct regulator_dev___3 *, bool);
	int (*get_bypass)(struct regulator_dev___3 *, bool *);
	int (*set_suspend_voltage)(struct regulator_dev___3 *, int);
	int (*set_suspend_enable)(struct regulator_dev___3 *);
	int (*set_suspend_disable)(struct regulator_dev___3 *);
	int (*set_suspend_mode)(struct regulator_dev___3 *, unsigned int);
	int (*resume)(struct regulator_dev___3 *);
	int (*set_pull_down)(struct regulator_dev___3 *);
};

struct regulator_config___3 {
	struct device___22 *dev;
	const struct regulator_init_data___2 *init_data;
	void *driver_data;
	struct device_node___15 *of_node;
	struct regmap *regmap;
	struct gpio_desc *ena_gpiod;
};

struct regulator_enable_gpio {
	struct list_head list;
	struct gpio_desc *gpiod;
	u32 enable_count;
	u32 request_count;
};

enum regulator_active_discharge {
	REGULATOR_ACTIVE_DISCHARGE_DEFAULT = 0,
	REGULATOR_ACTIVE_DISCHARGE_DISABLE = 1,
	REGULATOR_ACTIVE_DISCHARGE_ENABLE = 2,
};

struct regulator_consumer_supply {
	const char *dev_name;
	const char *supply;
};

struct trace_event_raw_regulator_basic {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_regulator_range {
	struct trace_entry ent;
	u32 __data_loc_name;
	int min;
	int max;
	char __data[0];
};

struct trace_event_raw_regulator_value {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int val;
	char __data[0];
};

struct trace_event_data_offsets_regulator_basic {
	u32 name;
};

struct trace_event_data_offsets_regulator_range {
	u32 name;
};

struct trace_event_data_offsets_regulator_value {
	u32 name;
};

typedef void (*btf_trace_regulator_enable)(void *, const char *);

typedef void (*btf_trace_regulator_enable_delay)(void *, const char *);

typedef void (*btf_trace_regulator_enable_complete)(void *, const char *);

typedef void (*btf_trace_regulator_disable)(void *, const char *);

typedef void (*btf_trace_regulator_disable_complete)(void *, const char *);

typedef void (*btf_trace_regulator_bypass_enable)(void *, const char *);

typedef void (*btf_trace_regulator_bypass_enable_complete)(void *, const char *);

typedef void (*btf_trace_regulator_bypass_disable)(void *, const char *);

typedef void (*btf_trace_regulator_bypass_disable_complete)(void *, const char *);

typedef void (*btf_trace_regulator_set_voltage)(void *, const char *, int, int);

typedef void (*btf_trace_regulator_set_voltage_complete)(void *, const char *, unsigned int);

enum regulator_get_type {
	NORMAL_GET = 0,
	EXCLUSIVE_GET = 1,
	OPTIONAL_GET = 2,
	MAX_GET_TYPE = 3,
};

struct regulator_map {
	struct list_head list;
	const char *dev_name;
	const char *supply;
	struct regulator_dev___3 *regulator;
};

struct regulator_supply_alias {
	struct list_head list;
	struct device___22 *src_dev;
	const char *src_supply;
	struct device___22 *alias_dev;
	const char *alias_supply;
};

struct summary_data {
	struct seq_file___25 *s;
	struct regulator_dev___3 *parent;
	int level;
};

struct summary_lock_data {
	struct ww_acquire_ctx___6 *ww_ctx;
	struct regulator_dev___3 **new_contended_rdev;
	struct regulator_dev___3 **old_contended_rdev;
};

struct fixed_voltage_config {
	const char *supply_name;
	const char *input_supply;
	int microvolts;
	unsigned int startup_delay;
	unsigned int off_on_delay;
	unsigned int enabled_at_boot: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	struct regulator_init_data *init_data;
};

struct fixed_regulator_data {
	struct fixed_voltage_config cfg;
	struct regulator_init_data init_data;
	struct platform_device___19 pdev;
};

struct regulator___2;

struct regulator_bulk_data___2 {
	const char *supply;
	struct regulator___2 *consumer;
	int ret;
};

struct regulator_dev___4;

struct regulator___2 {
	struct device___156 *dev;
	struct list_head list;
	unsigned int always_on: 1;
	unsigned int bypass: 1;
	unsigned int device_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	int uA_load;
	unsigned int enable_count;
	unsigned int deferred_disables;
	struct regulator_voltage voltage[5];
	const char *supply_name;
	struct device_attribute___15 dev_attr;
	struct regulator_dev___4 *rdev;
	struct dentry___196 *debugfs;
};

struct regulator_ops___4 {
	int (*list_voltage)(struct regulator_dev___4 *, unsigned int);
	int (*set_voltage)(struct regulator_dev___4 *, int, int, unsigned int *);
	int (*map_voltage)(struct regulator_dev___4 *, int, int);
	int (*set_voltage_sel)(struct regulator_dev___4 *, unsigned int);
	int (*get_voltage)(struct regulator_dev___4 *);
	int (*get_voltage_sel)(struct regulator_dev___4 *);
	int (*set_current_limit)(struct regulator_dev___4 *, int, int);
	int (*get_current_limit)(struct regulator_dev___4 *);
	int (*set_input_current_limit)(struct regulator_dev___4 *, int);
	int (*set_over_current_protection)(struct regulator_dev___4 *, int, int, bool);
	int (*set_over_voltage_protection)(struct regulator_dev___4 *, int, int, bool);
	int (*set_under_voltage_protection)(struct regulator_dev___4 *, int, int, bool);
	int (*set_thermal_protection)(struct regulator_dev___4 *, int, int, bool);
	int (*set_active_discharge)(struct regulator_dev___4 *, bool);
	int (*enable)(struct regulator_dev___4 *);
	int (*disable)(struct regulator_dev___4 *);
	int (*is_enabled)(struct regulator_dev___4 *);
	int (*set_mode)(struct regulator_dev___4 *, unsigned int);
	unsigned int (*get_mode)(struct regulator_dev___4 *);
	int (*get_error_flags)(struct regulator_dev___4 *, unsigned int *);
	int (*enable_time)(struct regulator_dev___4 *);
	int (*set_ramp_delay)(struct regulator_dev___4 *, int);
	int (*set_voltage_time)(struct regulator_dev___4 *, int, int);
	int (*set_voltage_time_sel)(struct regulator_dev___4 *, unsigned int, unsigned int);
	int (*set_soft_start)(struct regulator_dev___4 *);
	int (*get_status)(struct regulator_dev___4 *);
	unsigned int (*get_optimum_mode)(struct regulator_dev___4 *, int, int, int);
	int (*set_load)(struct regulator_dev___4 *, int);
	int (*set_bypass)(struct regulator_dev___4 *, bool);
	int (*get_bypass)(struct regulator_dev___4 *, bool *);
	int (*set_suspend_voltage)(struct regulator_dev___4 *, int);
	int (*set_suspend_enable)(struct regulator_dev___4 *);
	int (*set_suspend_disable)(struct regulator_dev___4 *);
	int (*set_suspend_mode)(struct regulator_dev___4 *, unsigned int);
	int (*resume)(struct regulator_dev___4 *);
	int (*set_pull_down)(struct regulator_dev___4 *);
};

struct coupling_desc___4 {
	struct regulator_dev___4 **coupled_rdevs;
	struct regulator_coupler *coupler;
	int n_resolved;
	int n_coupled;
};

struct regulator_desc___4;

struct regulator_dev___4 {
	const struct regulator_desc___4 *desc;
	int exclusive;
	u32 use_count;
	u32 open_count;
	u32 bypass_count;
	struct list_head list;
	struct list_head consumer_list;
	struct coupling_desc___4 coupling_desc;
	struct blocking_notifier_head notifier;
	struct ww_mutex___3 mutex;
	struct task_struct___203 *mutex_owner;
	int ref_cnt;
	struct module___180 *owner;
	struct device___156 dev;
	struct regulation_constraints *constraints;
	struct regulator___2 *supply;
	const char *supply_name;
	struct regmap *regmap;
	struct delayed_work disable_work;
	void *reg_data;
	struct dentry___196 *debugfs;
	struct regulator_enable_gpio *ena_pin;
	unsigned int ena_gpio_state: 1;
	unsigned int is_switch: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	ktime_t last_off;
	int cached_err;
	bool use_cached_err;
	spinlock_t err_lock;
};

struct regulator_desc___4 {
	const char *name;
	const char *supply_name;
	const char *of_match;
	bool of_match_full_name;
	const char *regulators_node;
	int (*of_parse_cb)(struct device_node___2 *, const struct regulator_desc___4 *, struct regulator_config___2 *);
	int id;
	unsigned int continuous_voltage_range: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int n_voltages;
	unsigned int n_current_limits;
	const struct regulator_ops___4 *ops;
	int irq;
	enum regulator_type type;
	struct module___180 *owner;
	unsigned int min_uV;
	unsigned int uV_step;
	unsigned int linear_min_sel;
	int fixed_uV;
	unsigned int ramp_delay;
	int min_dropout_uV;
	const struct linear_range *linear_ranges;
	const unsigned int *linear_range_selectors;
	int n_linear_ranges;
	const unsigned int *volt_table;
	const unsigned int *curr_table;
	unsigned int vsel_range_reg;
	unsigned int vsel_range_mask;
	unsigned int vsel_reg;
	unsigned int vsel_mask;
	unsigned int vsel_step;
	unsigned int csel_reg;
	unsigned int csel_mask;
	unsigned int apply_reg;
	unsigned int apply_bit;
	unsigned int enable_reg;
	unsigned int enable_mask;
	unsigned int enable_val;
	unsigned int disable_val;
	bool enable_is_inverted;
	unsigned int bypass_reg;
	unsigned int bypass_mask;
	unsigned int bypass_val_on;
	unsigned int bypass_val_off;
	unsigned int active_discharge_on;
	unsigned int active_discharge_off;
	unsigned int active_discharge_mask;
	unsigned int active_discharge_reg;
	unsigned int soft_start_reg;
	unsigned int soft_start_mask;
	unsigned int soft_start_val_on;
	unsigned int pull_down_reg;
	unsigned int pull_down_mask;
	unsigned int pull_down_val_on;
	unsigned int ramp_reg;
	unsigned int ramp_mask;
	const unsigned int *ramp_delay_table;
	unsigned int n_ramp_values;
	unsigned int enable_time;
	unsigned int off_on_delay;
	unsigned int poll_enabled_time;
	unsigned int (*of_map_mode)(unsigned int);
};

typedef void (*dr_release_t___18)(struct device___156 *, void *);

typedef int (*dr_match_t___17)(struct device___156 *, void *, void *);

struct regulator_err_state {
	struct regulator_dev___4 *rdev;
	long unsigned int notifs;
	long unsigned int errors;
	int possible_errs;
};

struct regulator_irq_data {
	struct regulator_err_state *states;
	int num_states;
	void *data;
	long int opaque;
};

struct regulator_irq_desc {
	const char *name;
	int irq_flags;
	int fatal_cnt;
	int reread_ms;
	int irq_off_ms;
	bool skip_off;
	bool high_prio;
	void *data;
	int (*die)(struct regulator_irq_data *);
	int (*map_event)(int, struct regulator_irq_data *, long unsigned int *);
	int (*renable)(struct regulator_irq_data *);
};

struct regulator_bulk_devres {
	struct regulator_bulk_data___2 *consumers;
	int num_consumers;
};

struct regulator_supply_alias_match {
	struct device___156 *dev;
	const char *id;
};

struct regulator_notifier_match {
	struct regulator___2 *regulator;
	struct notifier_block *nb;
};

struct regulator_err_state___2 {
	struct regulator_dev___3 *rdev;
	long unsigned int notifs;
	long unsigned int errors;
	int possible_errs;
};

struct regulator_irq_data___2 {
	struct regulator_err_state___2 *states;
	int num_states;
	void *data;
	long int opaque;
};

struct regulator_irq_desc___2 {
	const char *name;
	int irq_flags;
	int fatal_cnt;
	int reread_ms;
	int irq_off_ms;
	bool skip_off;
	bool high_prio;
	void *data;
	int (*die)(struct regulator_irq_data___2 *);
	int (*map_event)(int, struct regulator_irq_data___2 *, long unsigned int *);
	int (*renable)(struct regulator_irq_data___2 *);
};

enum {
	REGULATOR_ERROR_CLEARED = 0,
	REGULATOR_FAILED_RETRY = 1,
	REGULATOR_ERROR_ON = 2,
};

struct regulator_irq {
	struct regulator_irq_data___2 rdata;
	struct regulator_irq_desc___2 desc;
	int irq;
	int retry_cnt;
	struct delayed_work isr_work;
};

typedef void (*dr_release_t___19)(struct device___154 *, void *);

struct of_regulator_match___2 {
	const char *name;
	void *driver_data;
	struct regulator_init_data___2 *init_data;
	struct device_node___57 *of_node;
	const struct regulator_desc___3 *desc;
};

struct devm_of_regulator_matches {
	struct of_regulator_match___2 *matches;
	unsigned int num_matches;
};

struct reset_control___2;

struct reset_control_bulk_data {
	const char *id;
	struct reset_control___2 *rstc;
};

struct reset_control___2 {
	struct reset_controller_dev___3 *rcdev;
	struct list_head list;
	unsigned int id;
	struct kref refcnt;
	bool acquired;
	bool shared;
	bool array;
	atomic_t deassert_count;
	atomic_t triggered_count;
};

struct reset_control_lookup {
	struct list_head list;
	const char *provider;
	unsigned int index;
	const char *dev_id;
	const char *con_id;
};

struct reset_control_array {
	struct reset_control___2 base;
	unsigned int num_rstcs;
	struct reset_control___2 *rstc[0];
};

struct reset_control_bulk_devres {
	int num_rstcs;
	struct reset_control_bulk_data *rstcs;
};

struct reset_controller_dev___7;

struct reset_control_ops___7 {
	int (*reset)(struct reset_controller_dev___7 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___7 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___7 *, long unsigned int);
	int (*status)(struct reset_controller_dev___7 *, long unsigned int);
};

struct device___160;

struct device_node___64;

struct of_phandle_args___29;

struct reset_controller_dev___7 {
	const struct reset_control_ops___7 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___160 *dev;
	struct device_node___64 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___7 *, const struct of_phandle_args___29 *);
	unsigned int nr_resets;
};

struct wakeup_source___160;

struct pm_subsys_data___5;

struct dev_pm_info___160 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___160 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___160 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___160;

struct bus_type___160;

struct device_driver___160;

struct dev_pm_domain___160;

struct fwnode_handle___160;

struct class___160;

struct device___160 {
	struct kobject___41 kobj;
	struct device___160 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___160 *type;
	struct bus_type___160 *bus;
	struct device_driver___160 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___160 power;
	struct dev_pm_domain___160 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___64 *of_node;
	struct fwnode_handle___160 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___160 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___160 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___160;

struct fwnode_handle___160 {
	struct fwnode_handle___160 *secondary;
	const struct fwnode_operations___160 *ops;
	struct device___160 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___64 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___160 fwnode;
	struct property___19 *properties;
	struct property___19 *deadprops;
	struct device_node___64 *parent;
	struct device_node___64 *child;
	struct device_node___64 *sibling;
	struct kobject___41 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___29 {
	struct device_node___64 *np;
	int args_count;
	uint32_t args[16];
};

struct fwnode_reference_args___160;

struct fwnode_endpoint___160;

struct fwnode_operations___160 {
	struct fwnode_handle___160 * (*get)(struct fwnode_handle___160 *);
	void (*put)(struct fwnode_handle___160 *);
	bool (*device_is_available)(const struct fwnode_handle___160 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___160 *, const struct device___160 *);
	bool (*property_present)(const struct fwnode_handle___160 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___160 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___160 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___160 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*get_parent)(const struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*get_next_child_node)(const struct fwnode_handle___160 *, struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*get_named_child_node)(const struct fwnode_handle___160 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___160 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___160 *);
	struct fwnode_handle___160 * (*graph_get_next_endpoint)(const struct fwnode_handle___160 *, struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*graph_get_remote_endpoint)(const struct fwnode_handle___160 *);
	struct fwnode_handle___160 * (*graph_get_port_parent)(struct fwnode_handle___160 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___160 *, struct fwnode_endpoint___160 *);
	int (*add_links)(struct fwnode_handle___160 *);
};

struct fwnode_endpoint___160 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___160 *local_fwnode;
};

struct fwnode_reference_args___160 {
	struct fwnode_handle___160 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___160 {
	int (*prepare)(struct device___160 *);
	void (*complete)(struct device___160 *);
	int (*suspend)(struct device___160 *);
	int (*resume)(struct device___160 *);
	int (*freeze)(struct device___160 *);
	int (*thaw)(struct device___160 *);
	int (*poweroff)(struct device___160 *);
	int (*restore)(struct device___160 *);
	int (*suspend_late)(struct device___160 *);
	int (*resume_early)(struct device___160 *);
	int (*freeze_late)(struct device___160 *);
	int (*thaw_early)(struct device___160 *);
	int (*poweroff_late)(struct device___160 *);
	int (*restore_early)(struct device___160 *);
	int (*suspend_noirq)(struct device___160 *);
	int (*resume_noirq)(struct device___160 *);
	int (*freeze_noirq)(struct device___160 *);
	int (*thaw_noirq)(struct device___160 *);
	int (*poweroff_noirq)(struct device___160 *);
	int (*restore_noirq)(struct device___160 *);
	int (*runtime_suspend)(struct device___160 *);
	int (*runtime_resume)(struct device___160 *);
	int (*runtime_idle)(struct device___160 *);
};

struct pm_domain_data___5;

struct pm_subsys_data___5 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___5 *domain_data;
};

struct pm_domain_data___5 {
	struct list_head list_node;
	struct device___160 *dev;
};

struct wakeup_source___160 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___160 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___160 {
	struct dev_pm_ops___160 ops;
	int (*start)(struct device___160 *);
	void (*detach)(struct device___160 *, bool);
	int (*activate)(struct device___160 *);
	void (*sync)(struct device___160 *);
	void (*dismiss)(struct device___160 *);
};

struct bus_type___160 {
	const char *name;
	const char *dev_name;
	struct device___160 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___160 *, struct device_driver___160 *);
	int (*uevent)(struct device___160 *, struct kobj_uevent_env *);
	int (*probe)(struct device___160 *);
	void (*sync_state)(struct device___160 *);
	void (*remove)(struct device___160 *);
	void (*shutdown)(struct device___160 *);
	int (*online)(struct device___160 *);
	int (*offline)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	int (*num_vf)(struct device___160 *);
	int (*dma_configure)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___160 {
	const char *name;
	struct bus_type___160 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___160 *);
	void (*sync_state)(struct device___160 *);
	int (*remove)(struct device___160 *);
	void (*shutdown)(struct device___160 *);
	int (*suspend)(struct device___160 *, pm_message_t);
	int (*resume)(struct device___160 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___160 *pm;
	void (*coredump)(struct device___160 *);
	struct driver_private *p;
};

struct device_type___160 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___160 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___160 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___160 *);
	const struct dev_pm_ops___160 *pm;
};

struct class___160 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___160 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___160 *, umode_t *);
	void (*class_release)(struct class___160 *);
	void (*dev_release)(struct device___160 *);
	int (*shutdown_pre)(struct device___160 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___160 *);
	void (*get_ownership)(struct device___160 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___160 *pm;
	struct subsys_private *p;
};

struct mbox_client___5 {
	struct device___160 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___5 *, void *);
	void (*tx_prepare)(struct mbox_client___5 *, void *);
	void (*tx_done)(struct mbox_client___5 *, void *, int);
};

struct dev_power_governor___4 {
	bool (*power_down_ok)(struct dev_pm_domain___160 *);
	bool (*suspend_ok)(struct device___160 *);
};

struct gpd_dev_ops___4 {
	int (*start)(struct device___160 *);
	int (*stop)(struct device___160 *);
};

struct genpd_power_state___4 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___160 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct generic_pm_domain___5 {
	struct device___160 dev;
	struct dev_pm_domain___160 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor___4 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___160 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain___5 *);
	int (*power_on)(struct generic_pm_domain___5 *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___5 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___5 *, unsigned int);
	struct gpd_dev_ops___4 dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain___5 *, struct device___160 *);
	void (*detach_dev)(struct generic_pm_domain___5 *, struct device___160 *);
	unsigned int flags;
	struct genpd_power_state___4 *states;
	void (*free_states)(struct genpd_power_state___4 *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

typedef struct generic_pm_domain___5 * (*genpd_xlate_t___4)(struct of_phandle_args___29 *, void *);

struct genpd_onecell_data___4 {
	struct generic_pm_domain___5 **domains;
	unsigned int num_domains;
	genpd_xlate_t___4 xlate;
};

enum mrq_reset_commands {
	CMD_RESET_ASSERT = 1,
	CMD_RESET_DEASSERT = 2,
	CMD_RESET_MODULE = 3,
	CMD_RESET_GET_MAX_ID = 4,
	CMD_RESET_MAX = 5,
};

struct mrq_reset_request {
	uint32_t cmd;
	uint32_t reset_id;
};

struct tegra_bpmp___4;

struct tegra_bpmp_channel___4 {
	struct tegra_bpmp___4 *bpmp;
	struct tegra_bpmp_mb_data *ib;
	struct tegra_bpmp_mb_data *ob;
	struct completion completion;
	struct tegra_ivc *ivc;
	unsigned int index;
};

struct tegra_bpmp___4 {
	const struct tegra_bpmp_soc *soc;
	struct device___160 *dev;
	void *priv;
	struct {
		struct mbox_client___5 client;
		struct mbox_chan___2 *channel;
	} mbox;
	spinlock_t atomic_tx_lock;
	struct tegra_bpmp_channel___4 *tx_channel;
	struct tegra_bpmp_channel___4 *rx_channel;
	struct tegra_bpmp_channel___4 *threaded_channels;
	struct {
		long unsigned int *allocated;
		long unsigned int *busy;
		unsigned int count;
		struct semaphore lock;
	} threaded;
	struct list_head mrqs;
	spinlock_t lock;
	struct tegra_bpmp_clk___2 **clocks;
	unsigned int num_clocks;
	struct reset_controller_dev___7 rstc;
	struct genpd_onecell_data___4 genpd;
	struct dentry___182 *debugfs_mirror;
};

struct berlin_reset_priv {
	struct regmap *regmap;
	struct reset_controller_dev___3 rcdev;
};

struct brcm_rescal_reset {
	void *base;
	struct device___158 *dev;
	struct reset_controller_dev___4 rcdev;
};

struct imx7_src_signal {
	unsigned int offset;
	unsigned int bit;
};

struct imx7_src_variant {
	const struct imx7_src_signal *signals;
	unsigned int signals_num;
	struct reset_control_ops___3 ops;
};

struct imx7_src {
	struct reset_controller_dev___3 rcdev;
	struct regmap *regmap;
	const struct imx7_src_signal *signals;
};

enum imx7_src_registers {
	SRC_A7RCR0 = 4,
	SRC_M4RCR = 12,
	SRC_ERCR = 20,
	SRC_HSICPHY_RCR = 28,
	SRC_USBOPHY1_RCR = 32,
	SRC_USBOPHY2_RCR = 36,
	SRC_MIPIPHY_RCR = 40,
	SRC_PCIEPHY_RCR = 44,
	SRC_DDRC_RCR = 4096,
};

enum imx8mq_src_registers {
	SRC_A53RCR0 = 4,
	SRC_HDMI_RCR = 48,
	SRC_DISP_RCR = 52,
	SRC_GPU_RCR = 64,
	SRC_VPU_RCR = 68,
	SRC_PCIE2_RCR = 72,
	SRC_MIPIPHY1_RCR = 76,
	SRC_MIPIPHY2_RCR = 80,
	SRC_DDRC2_RCR = 4100,
};

enum imx8mp_src_registers {
	SRC_SUPERMIX_RCR = 24,
	SRC_AUDIOMIX_RCR = 28,
	SRC_MLMIX_RCR = 40,
	SRC_GPU2D_RCR = 56,
	SRC_GPU3D_RCR = 60,
	SRC_VPU_G1_RCR = 72,
	SRC_VPU_G2_RCR = 76,
	SRC_VPUVC8KE_RCR = 80,
	SRC_NOC_RCR = 84,
};

struct mchp_reset_context {
	struct regmap *cpu_ctrl;
	struct regmap *gcb_ctrl;
	struct reset_controller_dev___3 rcdev;
};

struct meson_reset_param {
	int reg_count;
	int level_offset;
};

struct meson_reset {
	void *reg_base;
	const struct meson_reset_param *param;
	struct reset_controller_dev___3 rcdev;
	spinlock_t lock;
};

struct qcom_aoss_reset_map {
	unsigned int reg;
};

struct qcom_aoss_desc {
	const struct qcom_aoss_reset_map *resets;
	size_t num_resets;
};

struct qcom_aoss_reset_data {
	struct reset_controller_dev___3 rcdev;
	void *base;
	const struct qcom_aoss_desc *desc;
};

struct reset_simple_data {
	spinlock_t lock;
	void *membase;
	struct reset_controller_dev___7 rcdev;
	bool active_low;
	bool status_active_low;
	unsigned int reset_us;
};

struct reset_simple_devdata {
	u32 reg_offset;
	u32 nr_resets;
	bool active_low;
	bool status_active_low;
};

enum zynqmp_pm_reset_action {
	PM_RESET_ACTION_RELEASE = 0,
	PM_RESET_ACTION_ASSERT = 1,
	PM_RESET_ACTION_PULSE = 2,
};

enum zynqmp_pm_reset {
	ZYNQMP_PM_RESET_START = 1000,
	ZYNQMP_PM_RESET_PCIE_CFG = 1000,
	ZYNQMP_PM_RESET_PCIE_BRIDGE = 1001,
	ZYNQMP_PM_RESET_PCIE_CTRL = 1002,
	ZYNQMP_PM_RESET_DP = 1003,
	ZYNQMP_PM_RESET_SWDT_CRF = 1004,
	ZYNQMP_PM_RESET_AFI_FM5 = 1005,
	ZYNQMP_PM_RESET_AFI_FM4 = 1006,
	ZYNQMP_PM_RESET_AFI_FM3 = 1007,
	ZYNQMP_PM_RESET_AFI_FM2 = 1008,
	ZYNQMP_PM_RESET_AFI_FM1 = 1009,
	ZYNQMP_PM_RESET_AFI_FM0 = 1010,
	ZYNQMP_PM_RESET_GDMA = 1011,
	ZYNQMP_PM_RESET_GPU_PP1 = 1012,
	ZYNQMP_PM_RESET_GPU_PP0 = 1013,
	ZYNQMP_PM_RESET_GPU = 1014,
	ZYNQMP_PM_RESET_GT = 1015,
	ZYNQMP_PM_RESET_SATA = 1016,
	ZYNQMP_PM_RESET_ACPU3_PWRON = 1017,
	ZYNQMP_PM_RESET_ACPU2_PWRON = 1018,
	ZYNQMP_PM_RESET_ACPU1_PWRON = 1019,
	ZYNQMP_PM_RESET_ACPU0_PWRON = 1020,
	ZYNQMP_PM_RESET_APU_L2 = 1021,
	ZYNQMP_PM_RESET_ACPU3 = 1022,
	ZYNQMP_PM_RESET_ACPU2 = 1023,
	ZYNQMP_PM_RESET_ACPU1 = 1024,
	ZYNQMP_PM_RESET_ACPU0 = 1025,
	ZYNQMP_PM_RESET_DDR = 1026,
	ZYNQMP_PM_RESET_APM_FPD = 1027,
	ZYNQMP_PM_RESET_SOFT = 1028,
	ZYNQMP_PM_RESET_GEM0 = 1029,
	ZYNQMP_PM_RESET_GEM1 = 1030,
	ZYNQMP_PM_RESET_GEM2 = 1031,
	ZYNQMP_PM_RESET_GEM3 = 1032,
	ZYNQMP_PM_RESET_QSPI = 1033,
	ZYNQMP_PM_RESET_UART0 = 1034,
	ZYNQMP_PM_RESET_UART1 = 1035,
	ZYNQMP_PM_RESET_SPI0 = 1036,
	ZYNQMP_PM_RESET_SPI1 = 1037,
	ZYNQMP_PM_RESET_SDIO0 = 1038,
	ZYNQMP_PM_RESET_SDIO1 = 1039,
	ZYNQMP_PM_RESET_CAN0 = 1040,
	ZYNQMP_PM_RESET_CAN1 = 1041,
	ZYNQMP_PM_RESET_I2C0 = 1042,
	ZYNQMP_PM_RESET_I2C1 = 1043,
	ZYNQMP_PM_RESET_TTC0 = 1044,
	ZYNQMP_PM_RESET_TTC1 = 1045,
	ZYNQMP_PM_RESET_TTC2 = 1046,
	ZYNQMP_PM_RESET_TTC3 = 1047,
	ZYNQMP_PM_RESET_SWDT_CRL = 1048,
	ZYNQMP_PM_RESET_NAND = 1049,
	ZYNQMP_PM_RESET_ADMA = 1050,
	ZYNQMP_PM_RESET_GPIO = 1051,
	ZYNQMP_PM_RESET_IOU_CC = 1052,
	ZYNQMP_PM_RESET_TIMESTAMP = 1053,
	ZYNQMP_PM_RESET_RPU_R50 = 1054,
	ZYNQMP_PM_RESET_RPU_R51 = 1055,
	ZYNQMP_PM_RESET_RPU_AMBA = 1056,
	ZYNQMP_PM_RESET_OCM = 1057,
	ZYNQMP_PM_RESET_RPU_PGE = 1058,
	ZYNQMP_PM_RESET_USB0_CORERESET = 1059,
	ZYNQMP_PM_RESET_USB1_CORERESET = 1060,
	ZYNQMP_PM_RESET_USB0_HIBERRESET = 1061,
	ZYNQMP_PM_RESET_USB1_HIBERRESET = 1062,
	ZYNQMP_PM_RESET_USB0_APB = 1063,
	ZYNQMP_PM_RESET_USB1_APB = 1064,
	ZYNQMP_PM_RESET_IPI = 1065,
	ZYNQMP_PM_RESET_APM_LPD = 1066,
	ZYNQMP_PM_RESET_RTC = 1067,
	ZYNQMP_PM_RESET_SYSMON = 1068,
	ZYNQMP_PM_RESET_AFI_FM6 = 1069,
	ZYNQMP_PM_RESET_LPD_SWDT = 1070,
	ZYNQMP_PM_RESET_FPD = 1071,
	ZYNQMP_PM_RESET_RPU_DBG1 = 1072,
	ZYNQMP_PM_RESET_RPU_DBG0 = 1073,
	ZYNQMP_PM_RESET_DBG_LPD = 1074,
	ZYNQMP_PM_RESET_DBG_FPD = 1075,
	ZYNQMP_PM_RESET_APLL = 1076,
	ZYNQMP_PM_RESET_DPLL = 1077,
	ZYNQMP_PM_RESET_VPLL = 1078,
	ZYNQMP_PM_RESET_IOPLL = 1079,
	ZYNQMP_PM_RESET_RPLL = 1080,
	ZYNQMP_PM_RESET_GPO3_PL_0 = 1081,
	ZYNQMP_PM_RESET_GPO3_PL_1 = 1082,
	ZYNQMP_PM_RESET_GPO3_PL_2 = 1083,
	ZYNQMP_PM_RESET_GPO3_PL_3 = 1084,
	ZYNQMP_PM_RESET_GPO3_PL_4 = 1085,
	ZYNQMP_PM_RESET_GPO3_PL_5 = 1086,
	ZYNQMP_PM_RESET_GPO3_PL_6 = 1087,
	ZYNQMP_PM_RESET_GPO3_PL_7 = 1088,
	ZYNQMP_PM_RESET_GPO3_PL_8 = 1089,
	ZYNQMP_PM_RESET_GPO3_PL_9 = 1090,
	ZYNQMP_PM_RESET_GPO3_PL_10 = 1091,
	ZYNQMP_PM_RESET_GPO3_PL_11 = 1092,
	ZYNQMP_PM_RESET_GPO3_PL_12 = 1093,
	ZYNQMP_PM_RESET_GPO3_PL_13 = 1094,
	ZYNQMP_PM_RESET_GPO3_PL_14 = 1095,
	ZYNQMP_PM_RESET_GPO3_PL_15 = 1096,
	ZYNQMP_PM_RESET_GPO3_PL_16 = 1097,
	ZYNQMP_PM_RESET_GPO3_PL_17 = 1098,
	ZYNQMP_PM_RESET_GPO3_PL_18 = 1099,
	ZYNQMP_PM_RESET_GPO3_PL_19 = 1100,
	ZYNQMP_PM_RESET_GPO3_PL_20 = 1101,
	ZYNQMP_PM_RESET_GPO3_PL_21 = 1102,
	ZYNQMP_PM_RESET_GPO3_PL_22 = 1103,
	ZYNQMP_PM_RESET_GPO3_PL_23 = 1104,
	ZYNQMP_PM_RESET_GPO3_PL_24 = 1105,
	ZYNQMP_PM_RESET_GPO3_PL_25 = 1106,
	ZYNQMP_PM_RESET_GPO3_PL_26 = 1107,
	ZYNQMP_PM_RESET_GPO3_PL_27 = 1108,
	ZYNQMP_PM_RESET_GPO3_PL_28 = 1109,
	ZYNQMP_PM_RESET_GPO3_PL_29 = 1110,
	ZYNQMP_PM_RESET_GPO3_PL_30 = 1111,
	ZYNQMP_PM_RESET_GPO3_PL_31 = 1112,
	ZYNQMP_PM_RESET_RPU_LS = 1113,
	ZYNQMP_PM_RESET_PS_ONLY = 1114,
	ZYNQMP_PM_RESET_PL = 1115,
	ZYNQMP_PM_RESET_PS_PL0 = 1116,
	ZYNQMP_PM_RESET_PS_PL1 = 1117,
	ZYNQMP_PM_RESET_PS_PL2 = 1118,
	ZYNQMP_PM_RESET_PS_PL3 = 1119,
	ZYNQMP_PM_RESET_END = 1119,
};

struct zynqmp_reset_soc_data {
	u32 reset_id;
	u32 num_resets;
};

struct zynqmp_reset_data {
	struct reset_controller_dev___7 rcdev;
	const struct zynqmp_reset_soc_data *data;
};

struct dentry___197;

struct super_block___197;

struct module___181;

struct file_system_type___197 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___197 * (*mount)(struct file_system_type___197 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___197 *);
	struct module___181 *owner;
	struct file_system_type___197 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___197;

struct kiocb___197;

struct poll_table_struct___129;

struct vm_area_struct___202;

struct inode___197;

struct file_lock___197;

struct page___202;

struct seq_file___173;

struct file_operations___198 {
	struct module___181 *owner;
	loff_t (*llseek)(struct file___197 *, loff_t, int);
	ssize_t (*read)(struct file___197 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___197 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___197 *, struct iov_iter___118 *);
	ssize_t (*write_iter)(struct kiocb___197 *, struct iov_iter___118 *);
	int (*iopoll)(struct kiocb___197 *, bool);
	int (*iterate)(struct file___197 *, struct dir_context *);
	int (*iterate_shared)(struct file___197 *, struct dir_context *);
	__poll_t (*poll)(struct file___197 *, struct poll_table_struct___129 *);
	long int (*unlocked_ioctl)(struct file___197 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___197 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___197 *, struct vm_area_struct___202 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___197 *, struct file___197 *);
	int (*flush)(struct file___197 *, fl_owner_t);
	int (*release)(struct inode___197 *, struct file___197 *);
	int (*fsync)(struct file___197 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___197 *, int);
	int (*lock)(struct file___197 *, int, struct file_lock___197 *);
	ssize_t (*sendpage)(struct file___197 *, struct page___202 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___197 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___197 *, long unsigned int);
	int (*flock)(struct file___197 *, int, struct file_lock___197 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___197 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___197 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___197 *, long int, struct file_lock___197 **, void **);
	long int (*fallocate)(struct file___197 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___173 *, struct file___197 *);
	ssize_t (*copy_file_range)(struct file___197 *, loff_t, struct file___197 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___197 *, loff_t, struct file___197 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___197 *, loff_t, loff_t, int);
};

struct vmacache___202 {
	u64 seqnum;
	struct vm_area_struct___202 *vmas[4];
};

struct page_frag___202 {
	struct page___202 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___203;

struct files_struct___21;

struct signal_struct___198;

struct vm_struct___180;

struct task_struct___204 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___204 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___203 *mm;
	struct mm_struct___203 *active_mm;
	struct vmacache___202 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___204 *real_parent;
	struct task_struct___204 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___204 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___174 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___21 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___183 *nsproxy;
	struct signal_struct___198 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___204 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___100 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___202 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___204 *oom_reaper_list;
	struct vm_struct___180 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___74 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___185;

struct kobj_type___185;

struct kernfs_node___185;

struct kobject___185 {
	const char *name;
	struct list_head entry;
	struct kobject___185 *parent;
	struct kset___185 *kset;
	struct kobj_type___185 *ktype;
	struct kernfs_node___185 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___181 {
	struct kobject___185 kobj;
	struct module___181 *mod;
	struct kobject___185 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___181 {
	struct module___181 *mod;
	struct latch_tree_node node;
};

struct module_layout___181 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___181 mtn;
};

struct module_attribute___181;

struct kernel_param___181;

struct module___181 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___181 mkobj;
	struct module_attribute___181 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___185 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___181 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___181 core_layout;
	struct module_layout___181 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___202 *pgtable_t___202;

struct address_space___197;

struct dev_pagemap___192;

struct page___202 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___197 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___202 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___202 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___203 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___192 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___192;

struct vm_area_struct___202 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___202 *vm_next;
	struct vm_area_struct___202 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___203 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___192 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___197 *vm_file;
	struct file___197 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___16;

struct signal_struct___198 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___204 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___204 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___174 *pids[4];
	struct pid___174 *tty_old_pgrp;
	int leader;
	struct tty_struct___16 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___203 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___202;

struct mm_struct___203 {
	struct {
		struct vm_area_struct___202 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___197 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___202 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___204 *owner;
		struct user_namespace *user_ns;
		struct file___197 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___21 {
	unsigned int max_fds;
	struct file___197 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___21 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___21 *fdt;
	struct fdtable___21 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___197 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vm_struct___180 {
	struct vm_struct___180 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___202 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___197;

struct address_space___197 {
	struct inode___197 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___197 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___192;

struct dev_pagemap___192 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___192 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___197;

struct path___197 {
	struct vfsmount___197 *mnt;
	struct dentry___197 *dentry;
};

struct file___197 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___197 f_path;
	struct inode___197 *f_inode;
	const struct file_operations___198 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___174 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___197 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___192;

struct vm_operations_struct___192 {
	void (*open)(struct vm_area_struct___202 *);
	void (*close)(struct vm_area_struct___202 *);
	int (*may_split)(struct vm_area_struct___202 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___202 *);
	int (*mprotect)(struct vm_area_struct___202 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___192 *);
	vm_fault_t (*huge_fault)(struct vm_fault___192 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___192 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___202 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___192 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___192 *);
	int (*access)(struct vm_area_struct___202 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___202 *);
	int (*set_policy)(struct vm_area_struct___202 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___202 *, long unsigned int);
	struct page___202 * (*find_special_page)(struct vm_area_struct___202 *, long unsigned int);
};

struct core_thread___202 {
	struct task_struct___204 *task;
	struct core_thread___202 *next;
};

struct core_state___202 {
	atomic_t nr_threads;
	struct core_thread___202 dumper;
	struct completion startup;
};

struct vm_fault___192 {
	const struct {
		struct vm_area_struct___202 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___202 *cow_page;
	struct page___202 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___202 prealloc_pte;
};

struct device___161;

struct tty_driver___17;

struct tty_operations___17;

struct tty_ldisc___16;

struct fasync_struct___197;

struct tty_port___17;

struct tty_struct___16 {
	int magic;
	struct kref kref;
	struct device___161 *dev;
	struct tty_driver___17 *driver;
	const struct tty_operations___17 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___16 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___172 *pgrp;
		struct pid___172 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___16 *link;
	struct fasync_struct___197 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___17 *port;
};

struct fwnode_operations___161;

struct fwnode_handle___161 {
	struct fwnode_handle___161 *secondary;
	const struct fwnode_operations___161 *ops;
	struct device___161 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___161;

struct fwnode_endpoint___161;

struct fwnode_operations___161 {
	struct fwnode_handle___161 * (*get)(struct fwnode_handle___161 *);
	void (*put)(struct fwnode_handle___161 *);
	bool (*device_is_available)(const struct fwnode_handle___161 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___161 *, const struct device___161 *);
	bool (*property_present)(const struct fwnode_handle___161 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___161 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___161 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___161 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*get_parent)(const struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*get_next_child_node)(const struct fwnode_handle___161 *, struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*get_named_child_node)(const struct fwnode_handle___161 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___161 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___161 *);
	struct fwnode_handle___161 * (*graph_get_next_endpoint)(const struct fwnode_handle___161 *, struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*graph_get_remote_endpoint)(const struct fwnode_handle___161 *);
	struct fwnode_handle___161 * (*graph_get_port_parent)(struct fwnode_handle___161 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___161 *, struct fwnode_endpoint___161 *);
	int (*add_links)(struct fwnode_handle___161 *);
};

struct wakeup_source___161;

struct dev_pm_info___161 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___161 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___161 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___161;

struct bus_type___161;

struct device_driver___161;

struct dev_pm_domain___161;

struct class___161;

struct attribute_group___185;

struct device___161 {
	struct kobject___185 kobj;
	struct device___161 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___161 *type;
	struct bus_type___161 *bus;
	struct device_driver___161 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___161 power;
	struct dev_pm_domain___161 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___161 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___161 *class;
	const struct attribute_group___185 **groups;
	void (*release)(struct device___161 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___161 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___161 *local_fwnode;
};

struct fwnode_reference_args___161 {
	struct fwnode_handle___161 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___173;

struct seq_file___173 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___173 *op;
	int poll_event;
	const struct file___197 *file;
	void *private;
};

struct kernfs_root___185;

struct kernfs_elem_dir___185 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___185 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___185;

struct kernfs_root___185 {
	struct kernfs_node___185 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___185 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___185 {
	struct kernfs_node___185 *target_kn;
};

struct kernfs_ops___185;

struct kernfs_elem_attr___185 {
	const struct kernfs_ops___185 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___185 *notify_next;
};

struct kernfs_node___185 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___185 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___185 dir;
		struct kernfs_elem_symlink___185 symlink;
		struct kernfs_elem_attr___185 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___185;

struct kernfs_ops___185 {
	int (*open)(struct kernfs_open_file___185 *);
	void (*release)(struct kernfs_open_file___185 *);
	int (*seq_show)(struct seq_file___173 *, void *);
	void * (*seq_start)(struct seq_file___173 *, loff_t *);
	void * (*seq_next)(struct seq_file___173 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___173 *, void *);
	ssize_t (*read)(struct kernfs_open_file___185 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___185 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___185 *, struct poll_table_struct___129 *);
	int (*mmap)(struct kernfs_open_file___185 *, struct vm_area_struct___202 *);
};

struct kernfs_syscall_ops___185 {
	int (*show_options)(struct seq_file___173 *, struct kernfs_root___185 *);
	int (*mkdir)(struct kernfs_node___185 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___185 *);
	int (*rename)(struct kernfs_node___185 *, struct kernfs_node___185 *, const char *);
	int (*show_path)(struct seq_file___173 *, struct kernfs_node___185 *, struct kernfs_root___185 *);
};

struct kernfs_open_file___185 {
	struct kernfs_node___185 *kn;
	struct file___197 *file;
	struct seq_file___173 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___192 *vm_ops;
};

typedef void (*poll_queue_proc___134)(struct file___197 *, wait_queue_head_t *, struct poll_table_struct___129 *);

struct poll_table_struct___129 {
	poll_queue_proc___134 _qproc;
	__poll_t _key;
};

struct bin_attribute___185;

struct attribute_group___185 {
	const char *name;
	umode_t (*is_visible)(struct kobject___185 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___185 *, struct bin_attribute___185 *, int);
	struct attribute **attrs;
	struct bin_attribute___185 **bin_attrs;
};

struct bin_attribute___185 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___197 * (*f_mapping)();
	ssize_t (*read)(struct file___197 *, struct kobject___185 *, struct bin_attribute___185 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___197 *, struct kobject___185 *, struct bin_attribute___185 *, char *, loff_t, size_t);
	int (*mmap)(struct file___197 *, struct kobject___185 *, struct bin_attribute___185 *, struct vm_area_struct___202 *);
};

struct sysfs_ops___185 {
	ssize_t (*show)(struct kobject___185 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___185 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___185;

struct kset___185 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___185 kobj;
	const struct kset_uevent_ops___185 *uevent_ops;
};

struct kobj_type___185 {
	void (*release)(struct kobject___185 *);
	const struct sysfs_ops___185 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___185 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___185 *);
	const void * (*namespace)(struct kobject___185 *);
	void (*get_ownership)(struct kobject___185 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___185 {
	int (* const filter)(struct kset___185 *, struct kobject___185 *);
	const char * (* const name)(struct kset___185 *, struct kobject___185 *);
	int (* const uevent)(struct kset___185 *, struct kobject___185 *, struct kobj_uevent_env *);
};

struct dentry_operations___197;

struct dentry___197 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___197 *d_parent;
	struct qstr d_name;
	struct inode___197 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___197 *d_op;
	struct super_block___197 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___197;

struct cdev___44;

struct inode___197 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___197 *i_op;
	struct super_block___197 *i_sb;
	struct address_space___197 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___198 *i_fop;
		void (*free_inode)(struct inode___197 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___197 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___44 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___197 {
	int (*d_revalidate)(struct dentry___197 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___197 *, unsigned int);
	int (*d_hash)(const struct dentry___197 *, struct qstr *);
	int (*d_compare)(const struct dentry___197 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___197 *);
	int (*d_init)(struct dentry___197 *);
	void (*d_release)(struct dentry___197 *);
	void (*d_prune)(struct dentry___197 *);
	void (*d_iput)(struct dentry___197 *, struct inode___197 *);
	char * (*d_dname)(struct dentry___197 *, char *, int);
	struct vfsmount___197 * (*d_automount)(struct path___197 *);
	int (*d_manage)(const struct path___197 *, bool);
	struct dentry___197 * (*d_real)(struct dentry___197 *, const struct inode___197 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___197;

struct mem_dqinfo___197 {
	struct quota_format_type___197 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___197;

struct quota_info___197 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___197 *files[3];
	struct mem_dqinfo___197 info[3];
	const struct quota_format_ops___197 *ops[3];
};

struct rcuwait___198 {
	struct task_struct___204 *task;
};

struct percpu_rw_semaphore___198 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___198 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___197 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___198 rw_sem[3];
};

struct super_operations___197;

struct dquot_operations___197;

struct quotactl_ops___197;

struct super_block___197 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___197 *s_type;
	const struct super_operations___197 *s_op;
	const struct dquot_operations___197 *dq_op;
	const struct quotactl_ops___197 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___197 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___197 s_dquot;
	struct sb_writers___197 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___197 *s_d_op;
	int cleancache_poolid;
	struct shrinker___84 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___197 {
	struct dentry___197 *mnt_root;
	struct super_block___197 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___197 {
	struct file___197 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___197 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___93 *ki_waitq;
	};
};

struct iattr___197 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___197 *ia_file;
};

struct dquot___197 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___197 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___197 {
	int qf_fmt_id;
	const struct quota_format_ops___197 *qf_ops;
	struct module___181 *qf_owner;
	struct quota_format_type___197 *qf_next;
};

struct quota_format_ops___197 {
	int (*check_quota_file)(struct super_block___197 *, int);
	int (*read_file_info)(struct super_block___197 *, int);
	int (*write_file_info)(struct super_block___197 *, int);
	int (*free_file_info)(struct super_block___197 *, int);
	int (*read_dqblk)(struct dquot___197 *);
	int (*commit_dqblk)(struct dquot___197 *);
	int (*release_dqblk)(struct dquot___197 *);
	int (*get_next_id)(struct super_block___197 *, struct kqid *);
};

struct dquot_operations___197 {
	int (*write_dquot)(struct dquot___197 *);
	struct dquot___197 * (*alloc_dquot)(struct super_block___197 *, int);
	void (*destroy_dquot)(struct dquot___197 *);
	int (*acquire_dquot)(struct dquot___197 *);
	int (*release_dquot)(struct dquot___197 *);
	int (*mark_dirty)(struct dquot___197 *);
	int (*write_info)(struct super_block___197 *, int);
	qsize_t * (*get_reserved_space)(struct inode___197 *);
	int (*get_projid)(struct inode___197 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___197 *, qsize_t *);
	int (*get_next_id)(struct super_block___197 *, struct kqid *);
};

struct quotactl_ops___197 {
	int (*quota_on)(struct super_block___197 *, int, int, const struct path___197 *);
	int (*quota_off)(struct super_block___197 *, int);
	int (*quota_enable)(struct super_block___197 *, unsigned int);
	int (*quota_disable)(struct super_block___197 *, unsigned int);
	int (*quota_sync)(struct super_block___197 *, int);
	int (*set_info)(struct super_block___197 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___197 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___197 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___197 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___197 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___197 *, unsigned int);
};

struct address_space_operations___197 {
	int (*writepage)(struct page___202 *, struct writeback_control___3 *);
	int (*readpage)(struct file___197 *, struct page___202 *);
	int (*writepages)(struct address_space___197 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___202 *);
	int (*readpages)(struct file___197 *, struct address_space___197 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___197 *, struct address_space___197 *, loff_t, unsigned int, unsigned int, struct page___202 **, void **);
	int (*write_end)(struct file___197 *, struct address_space___197 *, loff_t, unsigned int, unsigned int, struct page___202 *, void *);
	sector_t (*bmap)(struct address_space___197 *, sector_t);
	void (*invalidatepage)(struct page___202 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___202 *, gfp_t);
	void (*freepage)(struct page___202 *);
	ssize_t (*direct_IO)(struct kiocb___197 *, struct iov_iter___118 *);
	int (*migratepage)(struct address_space___197 *, struct page___202 *, struct page___202 *, enum migrate_mode);
	bool (*isolate_page)(struct page___202 *, isolate_mode_t);
	void (*putback_page)(struct page___202 *);
	int (*launder_page)(struct page___202 *);
	int (*is_partially_uptodate)(struct page___202 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___202 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___197 *, struct page___202 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___197 *, sector_t *);
	void (*swap_deactivate)(struct file___197 *);
};

struct cdev___44 {
	struct kobject___185 kobj;
	struct module___181 *owner;
	const struct file_operations___198 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___197 {
	struct dentry___197 * (*lookup)(struct inode___197 *, struct dentry___197 *, unsigned int);
	const char * (*get_link)(struct dentry___197 *, struct inode___197 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___197 *, int);
	struct posix_acl * (*get_acl)(struct inode___197 *, int, bool);
	int (*readlink)(struct dentry___197 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___197 *, struct dentry___197 *, umode_t, bool);
	int (*link)(struct dentry___197 *, struct inode___197 *, struct dentry___197 *);
	int (*unlink)(struct inode___197 *, struct dentry___197 *);
	int (*symlink)(struct user_namespace *, struct inode___197 *, struct dentry___197 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___197 *, struct dentry___197 *, umode_t);
	int (*rmdir)(struct inode___197 *, struct dentry___197 *);
	int (*mknod)(struct user_namespace *, struct inode___197 *, struct dentry___197 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___197 *, struct dentry___197 *, struct inode___197 *, struct dentry___197 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___197 *, struct iattr___197 *);
	int (*getattr)(struct user_namespace *, const struct path___197 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___197 *, char *, size_t);
	int (*fiemap)(struct inode___197 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___197 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___197 *, struct dentry___197 *, struct file___197 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___197 *, struct dentry___197 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___197 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___197 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___197 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___197 {
	void (*fl_copy_lock)(struct file_lock___197 *, struct file_lock___197 *);
	void (*fl_release_private)(struct file_lock___197 *);
};

struct lock_manager_operations___197;

struct file_lock___197 {
	struct file_lock___197 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___197 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___197 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___197 *fl_ops;
	const struct lock_manager_operations___197 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___197 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___197 *);
	int (*lm_grant)(struct file_lock___197 *, int);
	bool (*lm_break)(struct file_lock___197 *);
	int (*lm_change)(struct file_lock___197 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___197 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___197 *);
};

struct fasync_struct___197 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___197 *fa_next;
	struct file___197 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___197 {
	struct inode___197 * (*alloc_inode)(struct super_block___197 *);
	void (*destroy_inode)(struct inode___197 *);
	void (*free_inode)(struct inode___197 *);
	void (*dirty_inode)(struct inode___197 *, int);
	int (*write_inode)(struct inode___197 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___197 *);
	void (*evict_inode)(struct inode___197 *);
	void (*put_super)(struct super_block___197 *);
	int (*sync_fs)(struct super_block___197 *, int);
	int (*freeze_super)(struct super_block___197 *);
	int (*freeze_fs)(struct super_block___197 *);
	int (*thaw_super)(struct super_block___197 *);
	int (*unfreeze_fs)(struct super_block___197 *);
	int (*statfs)(struct dentry___197 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___197 *, int *, char *);
	void (*umount_begin)(struct super_block___197 *);
	int (*show_options)(struct seq_file___173 *, struct dentry___197 *);
	int (*show_devname)(struct seq_file___173 *, struct dentry___197 *);
	int (*show_path)(struct seq_file___173 *, struct dentry___197 *);
	int (*show_stats)(struct seq_file___173 *, struct dentry___197 *);
	ssize_t (*quota_read)(struct super_block___197 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___197 *, int, const char *, size_t, loff_t);
	struct dquot___197 ** (*get_dquots)(struct inode___197 *);
	long int (*nr_cached_objects)(struct super_block___197 *, struct shrink_control___84 *);
	long int (*free_cached_objects)(struct super_block___197 *, struct shrink_control___84 *);
	struct file___197 * (*real_loop)(struct file___197 *);
};

struct dev_pm_ops___161 {
	int (*prepare)(struct device___161 *);
	void (*complete)(struct device___161 *);
	int (*suspend)(struct device___161 *);
	int (*resume)(struct device___161 *);
	int (*freeze)(struct device___161 *);
	int (*thaw)(struct device___161 *);
	int (*poweroff)(struct device___161 *);
	int (*restore)(struct device___161 *);
	int (*suspend_late)(struct device___161 *);
	int (*resume_early)(struct device___161 *);
	int (*freeze_late)(struct device___161 *);
	int (*thaw_early)(struct device___161 *);
	int (*poweroff_late)(struct device___161 *);
	int (*restore_early)(struct device___161 *);
	int (*suspend_noirq)(struct device___161 *);
	int (*resume_noirq)(struct device___161 *);
	int (*freeze_noirq)(struct device___161 *);
	int (*thaw_noirq)(struct device___161 *);
	int (*poweroff_noirq)(struct device___161 *);
	int (*restore_noirq)(struct device___161 *);
	int (*runtime_suspend)(struct device___161 *);
	int (*runtime_resume)(struct device___161 *);
	int (*runtime_idle)(struct device___161 *);
};

struct wakeup_source___161 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___161 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___161 {
	struct dev_pm_ops___161 ops;
	int (*start)(struct device___161 *);
	void (*detach)(struct device___161 *, bool);
	int (*activate)(struct device___161 *);
	void (*sync)(struct device___161 *);
	void (*dismiss)(struct device___161 *);
};

struct bus_type___161 {
	const char *name;
	const char *dev_name;
	struct device___161 *dev_root;
	const struct attribute_group___185 **bus_groups;
	const struct attribute_group___185 **dev_groups;
	const struct attribute_group___185 **drv_groups;
	int (*match)(struct device___161 *, struct device_driver___161 *);
	int (*uevent)(struct device___161 *, struct kobj_uevent_env *);
	int (*probe)(struct device___161 *);
	void (*sync_state)(struct device___161 *);
	void (*remove)(struct device___161 *);
	void (*shutdown)(struct device___161 *);
	int (*online)(struct device___161 *);
	int (*offline)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	int (*num_vf)(struct device___161 *);
	int (*dma_configure)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___161 {
	const char *name;
	struct bus_type___161 *bus;
	struct module___181 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___161 *);
	void (*sync_state)(struct device___161 *);
	int (*remove)(struct device___161 *);
	void (*shutdown)(struct device___161 *);
	int (*suspend)(struct device___161 *, pm_message_t);
	int (*resume)(struct device___161 *);
	const struct attribute_group___185 **groups;
	const struct attribute_group___185 **dev_groups;
	const struct dev_pm_ops___161 *pm;
	void (*coredump)(struct device___161 *);
	struct driver_private *p;
};

struct device_type___161 {
	const char *name;
	const struct attribute_group___185 **groups;
	int (*uevent)(struct device___161 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___161 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___161 *);
	const struct dev_pm_ops___161 *pm;
};

struct class___161 {
	const char *name;
	struct module___181 *owner;
	const struct attribute_group___185 **class_groups;
	const struct attribute_group___185 **dev_groups;
	struct kobject___185 *dev_kobj;
	int (*dev_uevent)(struct device___161 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___161 *, umode_t *);
	void (*class_release)(struct class___161 *);
	void (*dev_release)(struct device___161 *);
	int (*shutdown_pre)(struct device___161 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___161 *);
	void (*get_ownership)(struct device___161 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___161 *pm;
	struct subsys_private *p;
};

struct device_attribute___16 {
	struct attribute attr;
	ssize_t (*show)(struct device___161 *, struct device_attribute___16 *, char *);
	ssize_t (*store)(struct device___161 *, struct device_attribute___16 *, const char *, size_t);
};

struct seq_operations___173 {
	void * (*start)(struct seq_file___173 *, loff_t *);
	void (*stop)(struct seq_file___173 *, void *);
	void * (*next)(struct seq_file___173 *, void *, loff_t *);
	int (*show)(struct seq_file___173 *, void *);
};

struct tty_operations___17 {
	struct tty_struct___16 * (*lookup)(struct tty_driver___17 *, struct file___197 *, int);
	int (*install)(struct tty_driver___17 *, struct tty_struct___16 *);
	void (*remove)(struct tty_driver___17 *, struct tty_struct___16 *);
	int (*open)(struct tty_struct___16 *, struct file___197 *);
	void (*close)(struct tty_struct___16 *, struct file___197 *);
	void (*shutdown)(struct tty_struct___16 *);
	void (*cleanup)(struct tty_struct___16 *);
	int (*write)(struct tty_struct___16 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___16 *, unsigned char);
	void (*flush_chars)(struct tty_struct___16 *);
	unsigned int (*write_room)(struct tty_struct___16 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___16 *);
	int (*ioctl)(struct tty_struct___16 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___16 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___16 *, struct ktermios *);
	void (*throttle)(struct tty_struct___16 *);
	void (*unthrottle)(struct tty_struct___16 *);
	void (*stop)(struct tty_struct___16 *);
	void (*start)(struct tty_struct___16 *);
	void (*hangup)(struct tty_struct___16 *);
	int (*break_ctl)(struct tty_struct___16 *, int);
	void (*flush_buffer)(struct tty_struct___16 *);
	void (*set_ldisc)(struct tty_struct___16 *);
	void (*wait_until_sent)(struct tty_struct___16 *, int);
	void (*send_xchar)(struct tty_struct___16 *, char);
	int (*tiocmget)(struct tty_struct___16 *);
	int (*tiocmset)(struct tty_struct___16 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___16 *, struct winsize *);
	int (*get_icount)(struct tty_struct___16 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___16 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___16 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___16 *, struct seq_file___173 *);
	int (*poll_init)(struct tty_driver___17 *, int, char *);
	int (*poll_get_char)(struct tty_driver___17 *, int);
	void (*poll_put_char)(struct tty_driver___17 *, int, char);
	int (*proc_show)(struct seq_file___173 *, void *);
};

struct tty_driver___17 {
	int magic;
	struct kref kref;
	struct cdev___44 **cdevs;
	struct module___181 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___17 *other;
	struct tty_struct___16 **ttys;
	struct tty_port___17 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___17 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___16;

struct tty_port_client_operations___16;

struct tty_port___17 {
	struct tty_bufhead buf;
	struct tty_struct___16 *tty;
	struct tty_struct___16 *itty;
	const struct tty_port_operations___16 *ops;
	const struct tty_port_client_operations___16 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___16 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___16 *);
	void (*close)(struct tty_struct___16 *);
	void (*flush_buffer)(struct tty_struct___16 *);
	ssize_t (*read)(struct tty_struct___16 *, struct file___197 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___16 *, struct file___197 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___16 *, struct file___197 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___16 *, struct file___197 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___16 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___16 *, struct file___197 *, struct poll_table_struct___129 *);
	int (*hangup)(struct tty_struct___16 *);
	void (*receive_buf)(struct tty_struct___16 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___16 *);
	void (*dcd_change)(struct tty_struct___16 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___16 *, const unsigned char *, const char *, int);
	struct module___181 *owner;
};

struct tty_ldisc___16 {
	struct tty_ldisc_ops___16 *ops;
	struct tty_struct___16 *tty;
};

struct tty_port_operations___16 {
	int (*carrier_raised)(struct tty_port___17 *);
	void (*dtr_rts)(struct tty_port___17 *, int);
	void (*shutdown)(struct tty_port___17 *);
	int (*activate)(struct tty_port___17 *, struct tty_struct___16 *);
	void (*destruct)(struct tty_port___17 *);
};

struct tty_port_client_operations___16 {
	int (*receive_buf)(struct tty_port___17 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___17 *);
};

struct tty_file_private___3 {
	struct tty_struct___16 *tty;
	struct file___197 *file;
	struct list_head list;
};

struct console___5 {
	char name[16];
	void (*write)(struct console___5 *, const char *, unsigned int);
	int (*read)(struct console___5 *, char *, unsigned int);
	struct tty_driver___17 * (*device)(struct console___5 *, int *);
	void (*unblank)();
	int (*setup)(struct console___5 *, char *);
	int (*exit)(struct console___5 *);
	int (*match)(struct console___5 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___5 *next;
};

struct dev_pagemap_ops___192 {
	void (*page_free)(struct page___202 *);
	void (*kill)(struct dev_pagemap___192 *);
	void (*cleanup)(struct dev_pagemap___192 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___192 *);
};

typedef struct poll_table_struct___129 poll_table___33;

struct kernel_param_ops___181 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___181 *);
	int (*get)(char *, const struct kernel_param___181 *);
	void (*free)(void *);
};

struct kparam_array___181;

struct kernel_param___181 {
	const char *name;
	struct module___181 *mod;
	const struct kernel_param_ops___181 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___181 *arr;
	};
};

struct kparam_array___181 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___181 *ops;
	void *elem;
};

struct module_attribute___181 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___181 *, struct module_kobject___181 *, char *);
	ssize_t (*store)(struct module_attribute___181 *, struct module_kobject___181 *, const char *, size_t);
	void (*setup)(struct module___181 *, const char *);
	int (*test)(struct module___181 *);
	void (*free)(struct module___181 *);
};

struct serial_struct32 {
	compat_int_t type;
	compat_int_t line;
	compat_uint_t port;
	compat_int_t irq;
	compat_int_t flags;
	compat_int_t xmit_fifo_size;
	compat_int_t custom_divisor;
	compat_int_t baud_base;
	short unsigned int close_delay;
	char io_type;
	char reserved_char;
	compat_int_t hub6;
	short unsigned int closing_wait;
	short unsigned int closing_wait2;
	compat_uint_t iomem_base;
	short unsigned int iomem_reg_shift;
	unsigned int port_high;
	compat_int_t reserved;
};

typedef void (*poll_queue_proc___135)(struct file___196 *, wait_queue_head_t *, struct poll_table_struct___10 *);

struct n_tty_data {
	size_t read_head;
	size_t commit_head;
	size_t canon_head;
	size_t echo_head;
	size_t echo_commit;
	size_t echo_mark;
	long unsigned int char_map[4];
	long unsigned int overrun_time;
	int num_overrun;
	bool no_room;
	unsigned char lnext;
	unsigned char erasing;
	unsigned char raw: 1;
	unsigned char real_raw;
	unsigned char icanon;
	unsigned char push;
	long: 40;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char read_buf[4096];
	long unsigned int read_flags[64];
	unsigned char echo_buf[4096];
	size_t read_tail;
	size_t line_start;
	unsigned int column;
	unsigned int canon_column;
	size_t echo_tail;
	struct mutex atomic_read_lock;
	struct mutex output_lock;
};

enum {
	ERASE = 0,
	WERASE = 1,
	KILL = 2,
};

struct termios {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
};

struct termios2 {
	tcflag_t c_iflag;
	tcflag_t c_oflag;
	tcflag_t c_cflag;
	tcflag_t c_lflag;
	cc_t c_line;
	cc_t c_cc[19];
	speed_t c_ispeed;
	speed_t c_ospeed;
};

struct termio {
	short unsigned int c_iflag;
	short unsigned int c_oflag;
	short unsigned int c_cflag;
	short unsigned int c_lflag;
	unsigned char c_line;
	unsigned char c_cc[8];
};

struct ldsem_waiter {
	struct list_head list;
	struct task_struct___203 *task;
};

struct pts_fs_info___2;

struct tty_audit_buf {
	struct mutex mutex;
	dev_t dev;
	unsigned int icanon;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	size_t valid;
	unsigned char *data;
};

struct dentry___198;

struct super_block___198;

struct module___182;

struct file_system_type___198 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___198 * (*mount)(struct file_system_type___198 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___198 *);
	struct module___182 *owner;
	struct file_system_type___198 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___198;

struct kiocb___198;

struct iov_iter___119;

struct poll_table_struct___130;

struct vm_area_struct___203;

struct inode___198;

struct file_lock___198;

struct page___203;

struct seq_file___174;

struct file_operations___199 {
	struct module___182 *owner;
	loff_t (*llseek)(struct file___198 *, loff_t, int);
	ssize_t (*read)(struct file___198 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___198 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___198 *, struct iov_iter___119 *);
	ssize_t (*write_iter)(struct kiocb___198 *, struct iov_iter___119 *);
	int (*iopoll)(struct kiocb___198 *, bool);
	int (*iterate)(struct file___198 *, struct dir_context *);
	int (*iterate_shared)(struct file___198 *, struct dir_context *);
	__poll_t (*poll)(struct file___198 *, struct poll_table_struct___130 *);
	long int (*unlocked_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___198 *, struct vm_area_struct___203 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___198 *, struct file___198 *);
	int (*flush)(struct file___198 *, fl_owner_t);
	int (*release)(struct inode___198 *, struct file___198 *);
	int (*fsync)(struct file___198 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___198 *, int);
	int (*lock)(struct file___198 *, int, struct file_lock___198 *);
	ssize_t (*sendpage)(struct file___198 *, struct page___203 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___198 *, long unsigned int);
	int (*flock)(struct file___198 *, int, struct file_lock___198 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___198 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___198 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___198 *, long int, struct file_lock___198 **, void **);
	long int (*fallocate)(struct file___198 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___174 *, struct file___198 *);
	ssize_t (*copy_file_range)(struct file___198 *, loff_t, struct file___198 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___198 *, loff_t, struct file___198 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___198 *, loff_t, loff_t, int);
};

struct vmacache___203 {
	u64 seqnum;
	struct vm_area_struct___203 *vmas[4];
};

struct page_frag___203 {
	struct page___203 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___75;

struct debug_info___75 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___75 *hbp_break[16];
	struct perf_event___75 *hbp_watch[16];
};

struct thread_struct___75 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___75 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___204;

struct pid___175;

struct nsproxy___184;

struct signal_struct___199;

struct bio_list___101;

struct backing_dev_info___94;

struct io_context___101;

struct css_set___136;

struct perf_event_context___75;

struct mem_cgroup___85;

struct request_queue___101;

struct vm_struct___181;

struct task_struct___205 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___205 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___204 *mm;
	struct mm_struct___204 *active_mm;
	struct vmacache___203 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___205 *real_parent;
	struct task_struct___205 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___205 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___175 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___184 *nsproxy;
	struct signal_struct___199 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___205 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___101 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___94 *backing_dev_info;
	struct io_context___101 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___136 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___75 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___203 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___85 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___85 *active_memcg;
	struct request_queue___101 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___205 *oom_reaper_list;
	struct vm_struct___181 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___186;

struct kobj_type___186;

struct kernfs_node___186;

struct kobject___186 {
	const char *name;
	struct list_head entry;
	struct kobject___186 *parent;
	struct kset___186 *kset;
	struct kobj_type___186 *ktype;
	struct kernfs_node___186 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___182 {
	struct kobject___186 kobj;
	struct module___182 *mod;
	struct kobject___186 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___182 {
	struct module___182 *mod;
	struct latch_tree_node node;
};

struct module_layout___182 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___182 mtn;
};

struct module_attribute___182;

struct kernel_param___182;

struct trace_event_call___69;

struct module___182 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___182 mkobj;
	struct module_attribute___182 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___186 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___182 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___182 core_layout;
	struct module_layout___182 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___69 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___75 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___205 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___75)(struct perf_event___75 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___75;

struct fasync_struct___198;

struct pid_namespace___175;

struct perf_cgroup___75;

struct perf_event___75 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___75 *group_leader;
	struct pmu___75 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___75 hw;
	struct perf_event_context___75 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___75 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___205 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___198 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___75 *aux_event;
	void (*destroy)(struct perf_event___75 *);
	struct callback_head callback_head;
	struct pid_namespace___175 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___75 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___75 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___69 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___75 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___175 {
	int nr;
	struct pid_namespace___175 *ns;
};

struct pid_namespace___175 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___205 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___175 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___175 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___175 numbers[1];
};

typedef struct page___203 *pgtable_t___203;

struct address_space___198;

struct dev_pagemap___193;

struct page___203 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___198 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___53 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___203 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___203 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___204 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___193 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___193;

struct vm_area_struct___203 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___203 *vm_next;
	struct vm_area_struct___203 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___204 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___193 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___198 *vm_file;
	struct file___198 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___17;

struct signal_struct___199 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___205 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___205 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___175 *pids[4];
	struct pid___175 *tty_old_pgrp;
	int leader;
	struct tty_struct___17 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___204 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___203;

struct mm_struct___204 {
	struct {
		struct vm_area_struct___203 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___203 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___205 *owner;
		struct user_namespace___25 *user_ns;
		struct file___198 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___136;

struct nsproxy___184 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___175 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___136 *cgroup_ns;
};

struct bio___101;

struct bio_list___101 {
	struct bio___101 *head;
	struct bio___101 *tail;
};

struct cgroup_subsys_state___136;

struct bdi_writeback___94 {
	struct backing_dev_info___94 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___136 *memcg_css;
	struct cgroup_subsys_state___136 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___162;

struct backing_dev_info___94 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___94 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___162 *dev;
	char dev_name[64];
	struct device___162 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___198 *debug_dir;
};

struct io_cq___101;

struct io_context___101 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___101 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___136;

struct css_set___136 {
	struct cgroup_subsys_state___136 *subsys[14];
	refcount_t refcount;
	struct css_set___136 *dom_cset;
	struct cgroup___136 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___136 *mg_src_cgrp;
	struct cgroup___136 *mg_dst_cgrp;
	struct css_set___136 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___75 {
	struct pmu___75 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___205 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___75 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___136;

struct cgroup_subsys_state___136 {
	struct cgroup___136 *cgroup;
	struct cgroup_subsys___136 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___136 *parent;
};

struct cgroup_file___136 {
	struct kernfs_node___186 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___85;

struct mem_cgroup_per_node___85;

struct mem_cgroup___85 {
	struct cgroup_subsys_state___136 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___136 events_file;
	struct cgroup_file___136 events_local_file;
	struct cgroup_file___136 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___85 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___205 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___85 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___101;

struct blk_integrity___101 {
	const struct blk_integrity_profile___101 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___101 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___101 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___101;

struct elevator_queue___101;

struct blk_mq_ops___98;

struct blk_mq_hw_ctx___98;

struct gendisk___102;

struct blkcg_gq___96;

struct blk_mq_tag_set___98;

struct request_queue___101 {
	struct request___101 *last_merge;
	struct elevator_queue___101 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___98 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___98 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___102 *disk;
	struct kobject___186 kobj;
	struct kobject___186 *mq_kobj;
	struct blk_integrity___101 integrity;
	struct device___162 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___96 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___98 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___101 bio_split;
	struct dentry___198 *debugfs_dir;
	struct dentry___198 *sched_debugfs_dir;
	struct dentry___198 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___181 {
	struct vm_struct___181 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___203 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___198;

struct address_space___198 {
	struct inode___198 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___198 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___193;

struct dev_pagemap___193 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___193 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___198;

struct path___198 {
	struct vfsmount___198 *mnt;
	struct dentry___198 *dentry;
};

struct fown_struct___175 {
	rwlock_t lock;
	struct pid___175 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___198 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___198 f_path;
	struct inode___198 *f_inode;
	const struct file_operations___199 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___175 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___198 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___193;

struct vm_operations_struct___193 {
	void (*open)(struct vm_area_struct___203 *);
	void (*close)(struct vm_area_struct___203 *);
	int (*may_split)(struct vm_area_struct___203 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___203 *);
	int (*mprotect)(struct vm_area_struct___203 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___193 *);
	vm_fault_t (*huge_fault)(struct vm_fault___193 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___193 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___203 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___193 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___193 *);
	int (*access)(struct vm_area_struct___203 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___203 *);
	int (*set_policy)(struct vm_area_struct___203 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___203 *, long unsigned int);
	struct page___203 * (*find_special_page)(struct vm_area_struct___203 *, long unsigned int);
};

struct core_thread___203 {
	struct task_struct___205 *task;
	struct core_thread___203 *next;
};

struct core_state___203 {
	atomic_t nr_threads;
	struct core_thread___203 dumper;
	struct completion startup;
};

struct vm_fault___193 {
	const struct {
		struct vm_area_struct___203 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___203 *cow_page;
	struct page___203 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___203 prealloc_pte;
};

struct psi_group___136 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___205 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___136;

struct cgroup_rstat_cpu___136;

struct cgroup___136 {
	struct cgroup_subsys_state___136 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___186 *kn;
	struct cgroup_file___136 procs_file;
	struct cgroup_file___136 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___136 *subsys[14];
	struct cgroup_root___136 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___136 *dom_cgrp;
	struct cgroup___136 *old_dom_cgrp;
	struct cgroup_rstat_cpu___136 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___136 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___92;

struct lruvec___92 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___92 *pgdat;
};

struct zone___92 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___92 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___92 {
	struct zone___92 *zone;
	int zone_idx;
};

struct zonelist___92 {
	struct zoneref___92 _zonerefs[321];
};

struct pglist_data___92 {
	struct zone___92 node_zones[5];
	struct zonelist___92 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___205 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___205 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___92 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___92 pg_data_t___15;

struct tty_driver___18;

struct tty_operations___18;

struct tty_ldisc___17;

struct tty_port___18;

struct tty_struct___17 {
	int magic;
	struct kref kref;
	struct device___162 *dev;
	struct tty_driver___18 *driver;
	const struct tty_operations___18 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___17 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___175 *pgrp;
		struct pid___175 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___17 *link;
	struct fasync_struct___198 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___18 *port;
};

struct fwnode_operations___162;

struct fwnode_handle___162 {
	struct fwnode_handle___162 *secondary;
	const struct fwnode_operations___162 *ops;
	struct device___162 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___162;

struct fwnode_endpoint___162;

struct fwnode_operations___162 {
	struct fwnode_handle___162 * (*get)(struct fwnode_handle___162 *);
	void (*put)(struct fwnode_handle___162 *);
	bool (*device_is_available)(const struct fwnode_handle___162 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___162 *, const struct device___162 *);
	bool (*property_present)(const struct fwnode_handle___162 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___162 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___162 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___162 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*get_parent)(const struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*get_next_child_node)(const struct fwnode_handle___162 *, struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*get_named_child_node)(const struct fwnode_handle___162 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___162 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___162 *);
	struct fwnode_handle___162 * (*graph_get_next_endpoint)(const struct fwnode_handle___162 *, struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*graph_get_remote_endpoint)(const struct fwnode_handle___162 *);
	struct fwnode_handle___162 * (*graph_get_port_parent)(struct fwnode_handle___162 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___162 *, struct fwnode_endpoint___162 *);
	int (*add_links)(struct fwnode_handle___162 *);
};

struct wakeup_source___162;

struct dev_pm_info___162 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___162 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___162 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___162;

struct bus_type___162;

struct device_driver___162;

struct dev_pm_domain___162;

struct device_node___65;

struct class___162;

struct attribute_group___186;

struct device___162 {
	struct kobject___186 kobj;
	struct device___162 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___162 *type;
	struct bus_type___162 *bus;
	struct device_driver___162 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___162 power;
	struct dev_pm_domain___162 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___65 *of_node;
	struct fwnode_handle___162 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___162 *class;
	const struct attribute_group___186 **groups;
	void (*release)(struct device___162 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___162 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___162 *local_fwnode;
};

struct fwnode_reference_args___162 {
	struct fwnode_handle___162 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct seq_operations___174;

struct seq_file___174 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___174 *op;
	int poll_event;
	const struct file___198 *file;
	void *private;
};

struct kernfs_root___186;

struct kernfs_elem_dir___186 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___186 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___186;

struct kernfs_root___186 {
	struct kernfs_node___186 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___186 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___186 {
	struct kernfs_node___186 *target_kn;
};

struct kernfs_ops___186;

struct kernfs_elem_attr___186 {
	const struct kernfs_ops___186 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___186 *notify_next;
};

struct kernfs_node___186 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___186 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___186 dir;
		struct kernfs_elem_symlink___186 symlink;
		struct kernfs_elem_attr___186 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___186;

struct kernfs_ops___186 {
	int (*open)(struct kernfs_open_file___186 *);
	void (*release)(struct kernfs_open_file___186 *);
	int (*seq_show)(struct seq_file___174 *, void *);
	void * (*seq_start)(struct seq_file___174 *, loff_t *);
	void * (*seq_next)(struct seq_file___174 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___174 *, void *);
	ssize_t (*read)(struct kernfs_open_file___186 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___186 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___186 *, struct poll_table_struct___130 *);
	int (*mmap)(struct kernfs_open_file___186 *, struct vm_area_struct___203 *);
};

struct kernfs_syscall_ops___186 {
	int (*show_options)(struct seq_file___174 *, struct kernfs_root___186 *);
	int (*mkdir)(struct kernfs_node___186 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___186 *);
	int (*rename)(struct kernfs_node___186 *, struct kernfs_node___186 *, const char *);
	int (*show_path)(struct seq_file___174 *, struct kernfs_node___186 *, struct kernfs_root___186 *);
};

struct kernfs_open_file___186 {
	struct kernfs_node___186 *kn;
	struct file___198 *file;
	struct seq_file___174 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___193 *vm_ops;
};

typedef void (*poll_queue_proc___136)(struct file___198 *, wait_queue_head_t *, struct poll_table_struct___130 *);

struct poll_table_struct___130 {
	poll_queue_proc___136 _qproc;
	__poll_t _key;
};

struct bin_attribute___186;

struct attribute_group___186 {
	const char *name;
	umode_t (*is_visible)(struct kobject___186 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___186 *, struct bin_attribute___186 *, int);
	struct attribute **attrs;
	struct bin_attribute___186 **bin_attrs;
};

struct bin_attribute___186 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___198 * (*f_mapping)();
	ssize_t (*read)(struct file___198 *, struct kobject___186 *, struct bin_attribute___186 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___198 *, struct kobject___186 *, struct bin_attribute___186 *, char *, loff_t, size_t);
	int (*mmap)(struct file___198 *, struct kobject___186 *, struct bin_attribute___186 *, struct vm_area_struct___203 *);
};

struct sysfs_ops___186 {
	ssize_t (*show)(struct kobject___186 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___186 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___186;

struct kset___186 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___186 kobj;
	const struct kset_uevent_ops___186 *uevent_ops;
};

struct kobj_type___186 {
	void (*release)(struct kobject___186 *);
	const struct sysfs_ops___186 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___186 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___186 *);
	const void * (*namespace)(struct kobject___186 *);
	void (*get_ownership)(struct kobject___186 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___186 {
	int (* const filter)(struct kset___186 *, struct kobject___186 *);
	const char * (* const name)(struct kset___186 *, struct kobject___186 *);
	int (* const uevent)(struct kset___186 *, struct kobject___186 *, struct kobj_uevent_env *);
};

struct shrink_control___85 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___85 *memcg;
};

struct shrinker___85 {
	long unsigned int (*count_objects)(struct shrinker___85 *, struct shrink_control___85 *);
	long unsigned int (*scan_objects)(struct shrinker___85 *, struct shrink_control___85 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___193 {
	void (*page_free)(struct page___203 *);
	void (*kill)(struct dev_pagemap___193 *);
	void (*cleanup)(struct dev_pagemap___193 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___193 *);
};

struct dentry_operations___198;

struct dentry___198 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___198 *d_parent;
	struct qstr d_name;
	struct inode___198 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___198 *d_op;
	struct super_block___198 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___198;

struct cdev___45;

struct inode___198 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___198 *i_op;
	struct super_block___198 *i_sb;
	struct address_space___198 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___94 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___199 *i_fop;
		void (*free_inode)(struct inode___198 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___198 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___45 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___198 {
	int (*d_revalidate)(struct dentry___198 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___198 *, unsigned int);
	int (*d_hash)(const struct dentry___198 *, struct qstr *);
	int (*d_compare)(const struct dentry___198 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___198 *);
	int (*d_init)(struct dentry___198 *);
	void (*d_release)(struct dentry___198 *);
	void (*d_prune)(struct dentry___198 *);
	void (*d_iput)(struct dentry___198 *, struct inode___198 *);
	char * (*d_dname)(struct dentry___198 *, char *, int);
	struct vfsmount___198 * (*d_automount)(struct path___198 *);
	int (*d_manage)(const struct path___198 *, bool);
	struct dentry___198 * (*d_real)(struct dentry___198 *, const struct inode___198 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___198;

struct mem_dqinfo___198 {
	struct quota_format_type___198 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___198;

struct quota_info___198 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___198 *files[3];
	struct mem_dqinfo___198 info[3];
	const struct quota_format_ops___198 *ops[3];
};

struct rcuwait___199 {
	struct task_struct___205 *task;
};

struct percpu_rw_semaphore___199 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___199 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___198 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___199 rw_sem[3];
};

struct super_operations___198;

struct dquot_operations___198;

struct quotactl_ops___198;

struct block_device___102;

struct super_block___198 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___198 *s_type;
	const struct super_operations___198 *s_op;
	const struct dquot_operations___198 *dq_op;
	const struct quotactl_ops___198 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___198 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___102 *s_bdev;
	struct backing_dev_info___94 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___198 s_dquot;
	struct sb_writers___198 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___198 *s_d_op;
	int cleancache_poolid;
	struct shrinker___85 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___198 {
	struct dentry___198 *mnt_root;
	struct super_block___198 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct io_cq___101 {
	struct request_queue___101 *q;
	struct io_context___101 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___94;

struct kiocb___198 {
	struct file___198 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___198 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___94 *ki_waitq;
	};
};

struct iattr___198 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___198 *ia_file;
};

struct dquot___198 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___198 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___198 {
	int qf_fmt_id;
	const struct quota_format_ops___198 *qf_ops;
	struct module___182 *qf_owner;
	struct quota_format_type___198 *qf_next;
};

struct quota_format_ops___198 {
	int (*check_quota_file)(struct super_block___198 *, int);
	int (*read_file_info)(struct super_block___198 *, int);
	int (*write_file_info)(struct super_block___198 *, int);
	int (*free_file_info)(struct super_block___198 *, int);
	int (*read_dqblk)(struct dquot___198 *);
	int (*commit_dqblk)(struct dquot___198 *);
	int (*release_dqblk)(struct dquot___198 *);
	int (*get_next_id)(struct super_block___198 *, struct kqid *);
};

struct dquot_operations___198 {
	int (*write_dquot)(struct dquot___198 *);
	struct dquot___198 * (*alloc_dquot)(struct super_block___198 *, int);
	void (*destroy_dquot)(struct dquot___198 *);
	int (*acquire_dquot)(struct dquot___198 *);
	int (*release_dquot)(struct dquot___198 *);
	int (*mark_dirty)(struct dquot___198 *);
	int (*write_info)(struct super_block___198 *, int);
	qsize_t * (*get_reserved_space)(struct inode___198 *);
	int (*get_projid)(struct inode___198 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___198 *, qsize_t *);
	int (*get_next_id)(struct super_block___198 *, struct kqid *);
};

struct quotactl_ops___198 {
	int (*quota_on)(struct super_block___198 *, int, int, const struct path___198 *);
	int (*quota_off)(struct super_block___198 *, int);
	int (*quota_enable)(struct super_block___198 *, unsigned int);
	int (*quota_disable)(struct super_block___198 *, unsigned int);
	int (*quota_sync)(struct super_block___198 *, int);
	int (*set_info)(struct super_block___198 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___198 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___198 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___198 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___198 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___198 *, unsigned int);
};

struct wait_page_queue___94 {
	struct page___203 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___94;

struct readahead_control___94;

struct swap_info_struct___53;

struct address_space_operations___198 {
	int (*writepage)(struct page___203 *, struct writeback_control___94 *);
	int (*readpage)(struct file___198 *, struct page___203 *);
	int (*writepages)(struct address_space___198 *, struct writeback_control___94 *);
	int (*set_page_dirty)(struct page___203 *);
	int (*readpages)(struct file___198 *, struct address_space___198 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___94 *);
	int (*write_begin)(struct file___198 *, struct address_space___198 *, loff_t, unsigned int, unsigned int, struct page___203 **, void **);
	int (*write_end)(struct file___198 *, struct address_space___198 *, loff_t, unsigned int, unsigned int, struct page___203 *, void *);
	sector_t (*bmap)(struct address_space___198 *, sector_t);
	void (*invalidatepage)(struct page___203 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___203 *, gfp_t);
	void (*freepage)(struct page___203 *);
	ssize_t (*direct_IO)(struct kiocb___198 *, struct iov_iter___119 *);
	int (*migratepage)(struct address_space___198 *, struct page___203 *, struct page___203 *, enum migrate_mode);
	bool (*isolate_page)(struct page___203 *, isolate_mode_t);
	void (*putback_page)(struct page___203 *);
	int (*launder_page)(struct page___203 *);
	int (*is_partially_uptodate)(struct page___203 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___203 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___198 *, struct page___203 *);
	int (*swap_activate)(struct swap_info_struct___53 *, struct file___198 *, sector_t *);
	void (*swap_deactivate)(struct file___198 *);
};

struct writeback_control___94 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___94 *wb;
	struct inode___198 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___94 {
	struct file___198 *file;
	struct address_space___198 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___117;

struct iov_iter___119 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___117 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___53 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___102 *bdev;
	struct file___198 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___45 {
	struct kobject___186 kobj;
	struct module___182 *owner;
	const struct file_operations___199 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___198 {
	struct dentry___198 * (*lookup)(struct inode___198 *, struct dentry___198 *, unsigned int);
	const char * (*get_link)(struct dentry___198 *, struct inode___198 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___198 *, int);
	struct posix_acl * (*get_acl)(struct inode___198 *, int, bool);
	int (*readlink)(struct dentry___198 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___198 *, struct dentry___198 *, umode_t, bool);
	int (*link)(struct dentry___198 *, struct inode___198 *, struct dentry___198 *);
	int (*unlink)(struct inode___198 *, struct dentry___198 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___198 *, struct dentry___198 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___198 *, struct dentry___198 *, umode_t);
	int (*rmdir)(struct inode___198 *, struct dentry___198 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___198 *, struct dentry___198 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___198 *, struct dentry___198 *, struct inode___198 *, struct dentry___198 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___198 *, struct iattr___198 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___198 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___198 *, char *, size_t);
	int (*fiemap)(struct inode___198 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___198 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___198 *, struct dentry___198 *, struct file___198 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___198 *, struct dentry___198 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___198 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___198 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___198 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___198 {
	void (*fl_copy_lock)(struct file_lock___198 *, struct file_lock___198 *);
	void (*fl_release_private)(struct file_lock___198 *);
};

struct lock_manager_operations___198;

struct file_lock___198 {
	struct file_lock___198 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___198 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___198 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___198 *fl_ops;
	const struct lock_manager_operations___198 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___198 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___198 *);
	int (*lm_grant)(struct file_lock___198 *, int);
	bool (*lm_break)(struct file_lock___198 *);
	int (*lm_change)(struct file_lock___198 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___198 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___198 *);
};

struct fasync_struct___198 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___198 *fa_next;
	struct file___198 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___198 {
	struct inode___198 * (*alloc_inode)(struct super_block___198 *);
	void (*destroy_inode)(struct inode___198 *);
	void (*free_inode)(struct inode___198 *);
	void (*dirty_inode)(struct inode___198 *, int);
	int (*write_inode)(struct inode___198 *, struct writeback_control___94 *);
	int (*drop_inode)(struct inode___198 *);
	void (*evict_inode)(struct inode___198 *);
	void (*put_super)(struct super_block___198 *);
	int (*sync_fs)(struct super_block___198 *, int);
	int (*freeze_super)(struct super_block___198 *);
	int (*freeze_fs)(struct super_block___198 *);
	int (*thaw_super)(struct super_block___198 *);
	int (*unfreeze_fs)(struct super_block___198 *);
	int (*statfs)(struct dentry___198 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___198 *, int *, char *);
	void (*umount_begin)(struct super_block___198 *);
	int (*show_options)(struct seq_file___174 *, struct dentry___198 *);
	int (*show_devname)(struct seq_file___174 *, struct dentry___198 *);
	int (*show_path)(struct seq_file___174 *, struct dentry___198 *);
	int (*show_stats)(struct seq_file___174 *, struct dentry___198 *);
	ssize_t (*quota_read)(struct super_block___198 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___198 *, int, const char *, size_t, loff_t);
	struct dquot___198 ** (*get_dquots)(struct inode___198 *);
	long int (*nr_cached_objects)(struct super_block___198 *, struct shrink_control___85 *);
	long int (*free_cached_objects)(struct super_block___198 *, struct shrink_control___85 *);
	struct file___198 * (*real_loop)(struct file___198 *);
};

struct block_device___102 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___198 *bd_inode;
	struct super_block___198 *bd_super;
	void *bd_claiming;
	struct device___162 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___186 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___102 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___198 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___101(struct bio___101 *);

struct bio_vec___117 {
	struct page___203 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___101;

struct bio___101 {
	struct bio___101 *bi_next;
	struct block_device___102 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___101 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___96 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___101 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___117 *bi_io_vec;
	struct bio_set___101 *bi_pool;
	struct bio_vec___117 bi_inline_vecs[0];
};

struct dev_pm_ops___162 {
	int (*prepare)(struct device___162 *);
	void (*complete)(struct device___162 *);
	int (*suspend)(struct device___162 *);
	int (*resume)(struct device___162 *);
	int (*freeze)(struct device___162 *);
	int (*thaw)(struct device___162 *);
	int (*poweroff)(struct device___162 *);
	int (*restore)(struct device___162 *);
	int (*suspend_late)(struct device___162 *);
	int (*resume_early)(struct device___162 *);
	int (*freeze_late)(struct device___162 *);
	int (*thaw_early)(struct device___162 *);
	int (*poweroff_late)(struct device___162 *);
	int (*restore_early)(struct device___162 *);
	int (*suspend_noirq)(struct device___162 *);
	int (*resume_noirq)(struct device___162 *);
	int (*freeze_noirq)(struct device___162 *);
	int (*thaw_noirq)(struct device___162 *);
	int (*poweroff_noirq)(struct device___162 *);
	int (*restore_noirq)(struct device___162 *);
	int (*runtime_suspend)(struct device___162 *);
	int (*runtime_resume)(struct device___162 *);
	int (*runtime_idle)(struct device___162 *);
};

struct wakeup_source___162 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___162 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___162 {
	struct dev_pm_ops___162 ops;
	int (*start)(struct device___162 *);
	void (*detach)(struct device___162 *, bool);
	int (*activate)(struct device___162 *);
	void (*sync)(struct device___162 *);
	void (*dismiss)(struct device___162 *);
};

struct bus_type___162 {
	const char *name;
	const char *dev_name;
	struct device___162 *dev_root;
	const struct attribute_group___186 **bus_groups;
	const struct attribute_group___186 **dev_groups;
	const struct attribute_group___186 **drv_groups;
	int (*match)(struct device___162 *, struct device_driver___162 *);
	int (*uevent)(struct device___162 *, struct kobj_uevent_env *);
	int (*probe)(struct device___162 *);
	void (*sync_state)(struct device___162 *);
	void (*remove)(struct device___162 *);
	void (*shutdown)(struct device___162 *);
	int (*online)(struct device___162 *);
	int (*offline)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	int (*num_vf)(struct device___162 *);
	int (*dma_configure)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___162 {
	const char *name;
	struct bus_type___162 *bus;
	struct module___182 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___162 *);
	void (*sync_state)(struct device___162 *);
	int (*remove)(struct device___162 *);
	void (*shutdown)(struct device___162 *);
	int (*suspend)(struct device___162 *, pm_message_t);
	int (*resume)(struct device___162 *);
	const struct attribute_group___186 **groups;
	const struct attribute_group___186 **dev_groups;
	const struct dev_pm_ops___162 *pm;
	void (*coredump)(struct device___162 *);
	struct driver_private *p;
};

struct device_type___162 {
	const char *name;
	const struct attribute_group___186 **groups;
	int (*uevent)(struct device___162 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___162 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___162 *);
	const struct dev_pm_ops___162 *pm;
};

struct class___162 {
	const char *name;
	struct module___182 *owner;
	const struct attribute_group___186 **class_groups;
	const struct attribute_group___186 **dev_groups;
	struct kobject___186 *dev_kobj;
	int (*dev_uevent)(struct device___162 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___162 *, umode_t *);
	void (*class_release)(struct class___162 *);
	void (*dev_release)(struct device___162 *);
	int (*shutdown_pre)(struct device___162 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___162 *);
	void (*get_ownership)(struct device___162 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___162 *pm;
	struct subsys_private *p;
};

struct property___49;

struct device_node___65 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___162 fwnode;
	struct property___49 *properties;
	struct property___49 *deadprops;
	struct device_node___65 *parent;
	struct device_node___65 *child;
	struct device_node___65 *sibling;
	struct kobject___186 kobj;
	long unsigned int _flags;
	void *data;
};

struct seq_operations___174 {
	void * (*start)(struct seq_file___174 *, loff_t *);
	void (*stop)(struct seq_file___174 *, void *);
	void * (*next)(struct seq_file___174 *, void *, loff_t *);
	int (*show)(struct seq_file___174 *, void *);
};

struct tty_operations___18 {
	struct tty_struct___17 * (*lookup)(struct tty_driver___18 *, struct file___198 *, int);
	int (*install)(struct tty_driver___18 *, struct tty_struct___17 *);
	void (*remove)(struct tty_driver___18 *, struct tty_struct___17 *);
	int (*open)(struct tty_struct___17 *, struct file___198 *);
	void (*close)(struct tty_struct___17 *, struct file___198 *);
	void (*shutdown)(struct tty_struct___17 *);
	void (*cleanup)(struct tty_struct___17 *);
	int (*write)(struct tty_struct___17 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___17 *, unsigned char);
	void (*flush_chars)(struct tty_struct___17 *);
	unsigned int (*write_room)(struct tty_struct___17 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___17 *);
	int (*ioctl)(struct tty_struct___17 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___17 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___17 *, struct ktermios *);
	void (*throttle)(struct tty_struct___17 *);
	void (*unthrottle)(struct tty_struct___17 *);
	void (*stop)(struct tty_struct___17 *);
	void (*start)(struct tty_struct___17 *);
	void (*hangup)(struct tty_struct___17 *);
	int (*break_ctl)(struct tty_struct___17 *, int);
	void (*flush_buffer)(struct tty_struct___17 *);
	void (*set_ldisc)(struct tty_struct___17 *);
	void (*wait_until_sent)(struct tty_struct___17 *, int);
	void (*send_xchar)(struct tty_struct___17 *, char);
	int (*tiocmget)(struct tty_struct___17 *);
	int (*tiocmset)(struct tty_struct___17 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___17 *, struct winsize *);
	int (*get_icount)(struct tty_struct___17 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___17 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___17 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___17 *, struct seq_file___174 *);
	int (*poll_init)(struct tty_driver___18 *, int, char *);
	int (*poll_get_char)(struct tty_driver___18 *, int);
	void (*poll_put_char)(struct tty_driver___18 *, int, char);
	int (*proc_show)(struct seq_file___174 *, void *);
};

struct tty_driver___18 {
	int magic;
	struct kref kref;
	struct cdev___45 **cdevs;
	struct module___182 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___18 *other;
	struct tty_struct___17 **ttys;
	struct tty_port___18 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___18 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___17;

struct tty_port_client_operations___17;

struct tty_port___18 {
	struct tty_bufhead buf;
	struct tty_struct___17 *tty;
	struct tty_struct___17 *itty;
	const struct tty_port_operations___17 *ops;
	const struct tty_port_client_operations___17 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___17 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___17 *);
	void (*close)(struct tty_struct___17 *);
	void (*flush_buffer)(struct tty_struct___17 *);
	ssize_t (*read)(struct tty_struct___17 *, struct file___198 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___17 *, struct file___198 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___17 *, struct file___198 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___17 *, struct file___198 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___17 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___17 *, struct file___198 *, struct poll_table_struct___130 *);
	int (*hangup)(struct tty_struct___17 *);
	void (*receive_buf)(struct tty_struct___17 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___17 *);
	void (*dcd_change)(struct tty_struct___17 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___17 *, const unsigned char *, const char *, int);
	struct module___182 *owner;
};

struct tty_ldisc___17 {
	struct tty_ldisc_ops___17 *ops;
	struct tty_struct___17 *tty;
};

struct tty_port_operations___17 {
	int (*carrier_raised)(struct tty_port___18 *);
	void (*dtr_rts)(struct tty_port___18 *, int);
	void (*shutdown)(struct tty_port___18 *);
	int (*activate)(struct tty_port___18 *, struct tty_struct___17 *);
	void (*destruct)(struct tty_port___18 *);
};

struct tty_port_client_operations___17 {
	int (*receive_buf)(struct tty_port___18 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___18 *);
};

struct vc_data___3 {
	struct tty_port___18 port;
	struct vc_state state;
	struct vc_state saved_state;
	short unsigned int vc_num;
	unsigned int vc_cols;
	unsigned int vc_rows;
	unsigned int vc_size_row;
	unsigned int vc_scan_lines;
	unsigned int vc_cell_height;
	long unsigned int vc_origin;
	long unsigned int vc_scr_end;
	long unsigned int vc_visible_origin;
	unsigned int vc_top;
	unsigned int vc_bottom;
	const struct consw___2 *vc_sw;
	short unsigned int *vc_screenbuf;
	unsigned int vc_screenbuf_size;
	unsigned char vc_mode;
	unsigned char vc_attr;
	unsigned char vc_def_color;
	unsigned char vc_ulcolor;
	unsigned char vc_itcolor;
	unsigned char vc_halfcolor;
	unsigned int vc_cursor_type;
	short unsigned int vc_complement_mask;
	short unsigned int vc_s_complement_mask;
	long unsigned int vc_pos;
	short unsigned int vc_hi_font_mask;
	struct console_font vc_font;
	short unsigned int vc_video_erase_char;
	unsigned int vc_state;
	unsigned int vc_npar;
	unsigned int vc_par[16];
	struct vt_mode vt_mode;
	struct pid___175 *vt_pid;
	int vt_newvt;
	wait_queue_head_t paste_wait;
	unsigned int vc_disp_ctrl: 1;
	unsigned int vc_toggle_meta: 1;
	unsigned int vc_decscnm: 1;
	unsigned int vc_decom: 1;
	unsigned int vc_decawm: 1;
	unsigned int vc_deccm: 1;
	unsigned int vc_decim: 1;
	unsigned int vc_priv: 3;
	unsigned int vc_need_wrap: 1;
	unsigned int vc_can_do_color: 1;
	unsigned int vc_report_mouse: 2;
	unsigned char vc_utf: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned char vc_utf_count;
	int vc_utf_char;
	long unsigned int vc_tab_stop[4];
	unsigned char vc_palette[48];
	short unsigned int *vc_translate;
	unsigned int vc_resize_user;
	unsigned int vc_bell_pitch;
	unsigned int vc_bell_duration;
	short unsigned int vc_cur_blink_ms;
	struct vc_data___3 **vc_display_fg;
	struct uni_pagedir *vc_uni_pagedir;
	struct uni_pagedir **vc_uni_pagedir_loc;
	struct uni_screen *vc_uni_screen;
};

struct proc_ops___21 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___198 *, struct file___198 *);
	ssize_t (*proc_read)(struct file___198 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___198 *, struct iov_iter___119 *);
	ssize_t (*proc_write)(struct file___198 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___198 *, loff_t, int);
	int (*proc_release)(struct inode___198 *, struct file___198 *);
	__poll_t (*proc_poll)(struct file___198 *, struct poll_table_struct___130 *);
	long int (*proc_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___198 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___198 *, struct vm_area_struct___203 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___198 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct cgroup_namespace___136 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___136 *root_cset;
};

struct kernel_param_ops___182 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___182 *);
	int (*get)(char *, const struct kernel_param___182 *);
	void (*free)(void *);
};

struct kparam_array___182;

struct kernel_param___182 {
	const char *name;
	struct module___182 *mod;
	const struct kernel_param_ops___182 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___182 *arr;
	};
};

struct kparam_array___182 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___182 *ops;
	void *elem;
};

struct module_attribute___182 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___182 *, struct module_kobject___182 *, char *);
	ssize_t (*store)(struct module_attribute___182 *, struct module_kobject___182 *, const char *, size_t);
	void (*setup)(struct module___182 *, const char *);
	int (*test)(struct module___182 *);
	void (*free)(struct module___182 *);
};

struct trace_event_class___69;

struct trace_event_call___69 {
	struct list_head list;
	struct trace_event_class___69 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___36 *prog_array;
	int (*perf_perm)(struct trace_event_call___69 *, struct perf_event___75 *);
};

struct cftype___136;

struct cgroup_subsys___136 {
	struct cgroup_subsys_state___136 * (*css_alloc)(struct cgroup_subsys_state___136 *);
	int (*css_online)(struct cgroup_subsys_state___136 *);
	void (*css_offline)(struct cgroup_subsys_state___136 *);
	void (*css_released)(struct cgroup_subsys_state___136 *);
	void (*css_free)(struct cgroup_subsys_state___136 *);
	void (*css_reset)(struct cgroup_subsys_state___136 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___136 *, int);
	int (*css_extra_stat_show)(struct seq_file___174 *, struct cgroup_subsys_state___136 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___205 *, struct css_set___136 *);
	void (*cancel_fork)(struct task_struct___205 *, struct css_set___136 *);
	void (*fork)(struct task_struct___205 *);
	void (*exit)(struct task_struct___205 *);
	void (*release)(struct task_struct___205 *);
	void (*bind)(struct cgroup_subsys_state___136 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___136 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___136 *dfl_cftypes;
	struct cftype___136 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___136 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___136 *updated_children;
	struct cgroup___136 *updated_next;
};

struct cgroup_root___136 {
	struct kernfs_root___186 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___136 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___136 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___136 *ss;
	struct list_head node;
	struct kernfs_ops___186 *kf_ops;
	int (*open)(struct kernfs_open_file___186 *);
	void (*release)(struct kernfs_open_file___186 *);
	u64 (*read_u64)(struct cgroup_subsys_state___136 *, struct cftype___136 *);
	s64 (*read_s64)(struct cgroup_subsys_state___136 *, struct cftype___136 *);
	int (*seq_show)(struct seq_file___174 *, void *);
	void * (*seq_start)(struct seq_file___174 *, loff_t *);
	void * (*seq_next)(struct seq_file___174 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___174 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___136 *, struct cftype___136 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___136 *, struct cftype___136 *, s64);
	ssize_t (*write)(struct kernfs_open_file___186 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___186 *, struct poll_table_struct___130 *);
};

struct perf_cpu_context___75;

struct perf_output_handle___75;

struct pmu___75 {
	struct list_head entry;
	struct module___182 *module;
	struct device___162 *dev;
	const struct attribute_group___186 **attr_groups;
	const struct attribute_group___186 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___75 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___75 *);
	void (*pmu_disable)(struct pmu___75 *);
	int (*event_init)(struct perf_event___75 *);
	void (*event_mapped)(struct perf_event___75 *, struct mm_struct___204 *);
	void (*event_unmapped)(struct perf_event___75 *, struct mm_struct___204 *);
	int (*add)(struct perf_event___75 *, int);
	void (*del)(struct perf_event___75 *, int);
	void (*start)(struct perf_event___75 *, int);
	void (*stop)(struct perf_event___75 *, int);
	void (*read)(struct perf_event___75 *);
	void (*start_txn)(struct pmu___75 *, unsigned int);
	int (*commit_txn)(struct pmu___75 *);
	void (*cancel_txn)(struct pmu___75 *);
	int (*event_idx)(struct perf_event___75 *);
	void (*sched_task)(struct perf_event_context___75 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___75 *, struct perf_event_context___75 *);
	void * (*setup_aux)(struct perf_event___75 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___75 *, struct perf_output_handle___75 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___75 *);
	int (*aux_output_match)(struct perf_event___75 *);
	int (*filter_match)(struct perf_event___75 *);
	int (*check_period)(struct perf_event___75 *, u64);
};

struct perf_cpu_context___75 {
	struct perf_event_context___75 ctx;
	struct perf_event_context___75 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___75 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___75 **heap;
	struct perf_event___75 *heap_default[2];
};

struct perf_output_handle___75 {
	struct perf_event___75 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___75 {
	struct cgroup_subsys_state___136 css;
	struct perf_cgroup_info *info;
};

struct block_device_operations___101;

struct gendisk___102 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___102 *part0;
	const struct block_device_operations___101 *fops;
	struct request_queue___101 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___94 *bdi;
	struct kobject___186 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___186 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___101 {
	struct bio___101 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___117 *bip_vec;
	struct bio_vec___117 bip_inline_vecs[0];
};

struct blkcg___96;

struct blkg_policy_data___96;

struct blkcg_gq___96 {
	struct request_queue___101 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___96 *blkcg;
	struct blkcg_gq___96 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___96 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___101 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___101(struct request___101 *);

typedef void integrity_complete_fn___101(struct request___101 *, unsigned int);

struct blk_integrity_profile___101 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___101 *prepare_fn;
	integrity_complete_fn___101 *complete_fn;
	const char *name;
};

struct block_device_operations___101 {
	blk_qc_t (*submit_bio)(struct bio___101 *);
	int (*open)(struct block_device___102 *, fmode_t);
	void (*release)(struct gendisk___102 *, fmode_t);
	int (*rw_page)(struct block_device___102 *, sector_t, struct page___203 *, unsigned int);
	int (*ioctl)(struct block_device___102 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___102 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___102 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___102 *);
	int (*getgeo)(struct block_device___102 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___102 *, bool);
	void (*swap_slot_free_notify)(struct block_device___102 *, long unsigned int);
	int (*report_zones)(struct gendisk___102 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___102 *, umode_t *);
	struct module___182 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___102 *, sector_t *);
};

typedef void rq_end_io_fn___101(struct request___101 *, blk_status_t);

struct request___101 {
	struct request_queue___101 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___98 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___101 *bio;
	struct bio___101 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___117 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___101 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___101 *saved_end_io;
		} flush;
	};
	struct gendisk___102 *rq_disk;
	struct block_device___102 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___101 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___98 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___101 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___186 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___198 *debugfs_dir;
	struct dentry___198 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___101;

struct elevator_mq_ops___101 {
	int (*init_sched)(struct request_queue___101 *, struct elevator_type___101 *);
	void (*exit_sched)(struct elevator_queue___101 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___98 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___98 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___98 *);
	bool (*allow_merge)(struct request_queue___101 *, struct request___101 *, struct bio___101 *);
	bool (*bio_merge)(struct request_queue___101 *, struct bio___101 *, unsigned int);
	int (*request_merge)(struct request_queue___101 *, struct request___101 **, struct bio___101 *);
	void (*request_merged)(struct request_queue___101 *, struct request___101 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___101 *, struct request___101 *, struct request___101 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___101 *);
	void (*finish_request)(struct request___101 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___98 *, struct list_head *, bool);
	struct request___101 * (*dispatch_request)(struct blk_mq_hw_ctx___98 *);
	bool (*has_work)(struct blk_mq_hw_ctx___98 *);
	void (*completed_request)(struct request___101 *, u64);
	void (*requeue_request)(struct request___101 *);
	struct request___101 * (*former_request)(struct request_queue___101 *, struct request___101 *);
	struct request___101 * (*next_request)(struct request_queue___101 *, struct request___101 *);
	void (*init_icq)(struct io_cq___101 *);
	void (*exit_icq)(struct io_cq___101 *);
};

struct elv_fs_entry___101;

struct elevator_type___101 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___101 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___101 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___182 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___101 {
	struct elevator_type___101 *type;
	void *elevator_data;
	struct kobject___186 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___101 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___101 *, char *);
	ssize_t (*store)(struct elevator_queue___101 *, const char *, size_t);
};

struct blk_mq_queue_data___98;

struct blk_mq_ops___98 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___98 *, const struct blk_mq_queue_data___98 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___98 *);
	int (*get_budget)(struct request_queue___101 *);
	void (*put_budget)(struct request_queue___101 *, int);
	void (*set_rq_budget_token)(struct request___101 *, int);
	int (*get_rq_budget_token)(struct request___101 *);
	enum blk_eh_timer_return (*timeout)(struct request___101 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___98 *);
	void (*complete)(struct request___101 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___98 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___98 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___98 *, struct request___101 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___98 *, struct request___101 *, unsigned int);
	void (*initialize_rq_fn)(struct request___101 *);
	void (*cleanup_rq)(struct request___101 *);
	bool (*busy)(struct request_queue___101 *);
	int (*map_queues)(struct blk_mq_tag_set___98 *);
	void (*show_rq)(struct seq_file___174 *, struct request___101 *);
};

struct blk_mq_tag_set___98 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___98 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___98 {
	struct request___101 *rq;
	bool last;
};

struct blkcg_policy_data___96;

struct blkcg___96 {
	struct cgroup_subsys_state___136 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___96 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___96 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___96 {
	struct blkcg___96 *blkcg;
	int plid;
};

struct blkg_policy_data___96 {
	struct blkcg_gq___96 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___85 {
	struct mem_cgroup___85 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___85 {
	struct lruvec___92 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___85 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___85 *memcg;
};

struct obj_cgroup___85 {
	struct percpu_ref refcnt;
	struct mem_cgroup___85 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct vc___2 {
	struct vc_data___3 *d;
	struct work_struct SAK_work;
};

struct oom_control___4 {
	struct zonelist___92 *zonelist;
	nodemask_t *nodemask;
	struct mem_cgroup___85 *memcg;
	const gfp_t gfp_mask;
	const int order;
	long unsigned int totalpages;
	struct task_struct___205 *chosen;
	long int chosen_points;
	enum oom_constraint constraint;
};

struct ff_device___2;

struct input_handle___2;

struct input_dev___2 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___2 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___2 *, struct input_keymap_entry *);
	struct ff_device___2 *ff;
	struct input_dev_poller *poller;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___2 *);
	void (*close)(struct input_dev___2 *);
	int (*flush)(struct input_dev___2 *, struct file___198 *);
	int (*event)(struct input_dev___2 *, unsigned int, unsigned int, int);
	struct input_handle___2 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___162 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
	ktime_t timestamp[3];
	bool inhibited;
};

struct ff_device___2 {
	int (*upload)(struct input_dev___2 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___2 *, int);
	int (*playback)(struct input_dev___2 *, int, int);
	void (*set_gain)(struct input_dev___2 *, u16);
	void (*set_autocenter)(struct input_dev___2 *, u16);
	void (*destroy)(struct ff_device___2 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___198 *effect_owners[0];
};

struct input_handler___2;

struct input_handle___2 {
	void *private;
	int open;
	const char *name;
	struct input_dev___2 *dev;
	struct input_handler___2 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___2 {
	void *private;
	void (*event)(struct input_handle___2 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___2 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___2 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___2 *, struct input_dev___2 *);
	int (*connect)(struct input_handler___2 *, struct input_dev___2 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___2 *);
	void (*start)(struct input_handle___2 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct trace_event_fields___69 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___69 *);
	};
};

struct trace_event_class___69 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___69 *, enum trace_reg, void *);
	struct trace_event_fields___69 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___69 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___69 *);
};

struct property___49 {
	char *name;
	int length;
	void *value;
	struct property___49 *next;
	long unsigned int _flags;
	struct bin_attribute___186 attr;
};

struct sysrq_state {
	struct input_handle___2 handle;
	struct work_struct reinject_work;
	long unsigned int key_down[12];
	unsigned int alt;
	unsigned int alt_use;
	unsigned int shift;
	unsigned int shift_use;
	bool active;
	bool need_reinject;
	bool reinjecting;
	bool reset_canceled;
	bool reset_requested;
	long unsigned int reset_keybit[12];
	int reset_seq_len;
	int reset_seq_cnt;
	int reset_seq_version;
	struct timer_list keyreset_timer;
};

struct unipair {
	short unsigned int unicode;
	short unsigned int fontpos;
};

struct unimapdesc {
	short unsigned int entry_ct;
	struct unipair *entries;
};

struct kbentry {
	unsigned char kb_table;
	unsigned char kb_index;
	short unsigned int kb_value;
};

struct kbsentry {
	unsigned char kb_func;
	unsigned char kb_string[512];
};

struct kbkeycode {
	unsigned int scancode;
	unsigned int keycode;
};

struct kbd_repeat {
	int delay;
	int period;
};

struct console_font_op {
	unsigned int op;
	unsigned int flags;
	unsigned int width;
	unsigned int height;
	unsigned int charcount;
	unsigned char *data;
};

struct vt_stat {
	short unsigned int v_active;
	short unsigned int v_signal;
	short unsigned int v_state;
};

struct vt_sizes {
	short unsigned int v_rows;
	short unsigned int v_cols;
	short unsigned int v_scrollsize;
};

struct vt_consize {
	short unsigned int v_rows;
	short unsigned int v_cols;
	short unsigned int v_vlin;
	short unsigned int v_clin;
	short unsigned int v_vcol;
	short unsigned int v_ccol;
};

struct vt_event {
	unsigned int event;
	unsigned int oldev;
	unsigned int newev;
	unsigned int pad[4];
};

struct vt_setactivate {
	unsigned int console;
	struct vt_mode mode;
};

struct vt_spawn_console {
	spinlock_t lock;
	struct pid___175 *pid;
	int sig;
};

struct vt_event_wait {
	struct list_head list;
	struct vt_event event;
	int done;
};

struct compat_console_font_op {
	compat_uint_t op;
	compat_uint_t flags;
	compat_uint_t width;
	compat_uint_t height;
	compat_uint_t charcount;
	compat_caddr_t data;
};

struct compat_unimapdesc {
	short unsigned int entry_ct;
	compat_caddr_t entries;
};

struct vt_notifier_param {
	struct vc_data___3 *vc;
	unsigned int c;
};

typedef struct poll_table_struct___130 poll_table___34;

struct vcs_poll_data {
	struct notifier_block notifier;
	unsigned int cons_num;
	int event;
	wait_queue_head_t waitq;
	struct fasync_struct___198 *fasync;
};

struct tiocl_selection {
	short unsigned int xs;
	short unsigned int ys;
	short unsigned int xe;
	short unsigned int ye;
	short unsigned int sel_mode;
};

struct vc_selection {
	struct mutex lock;
	struct vc_data___3 *cons;
	char *buffer;
	unsigned int buf_len;
	volatile int start;
	int end;
};

struct kbdiacr {
	unsigned char diacr;
	unsigned char base;
	unsigned char result;
};

struct kbdiacrs {
	unsigned int kb_cnt;
	struct kbdiacr kbdiacr[256];
};

struct kbdiacruc {
	unsigned int diacr;
	unsigned int base;
	unsigned int result;
};

struct kbdiacrsuc {
	unsigned int kb_cnt;
	struct kbdiacruc kbdiacruc[256];
};

struct keyboard_notifier_param {
	struct vc_data___3 *vc;
	int down;
	int shift;
	int ledstate;
	unsigned int value;
};

struct kbd_struct {
	unsigned char lockstate;
	unsigned char slockstate;
	unsigned char ledmode: 1;
	unsigned char ledflagstate: 4;
	unsigned char default_ledflagstate: 4;
	unsigned char kbdmode: 3;
	unsigned char modeflags: 5;
	long: 35;
};

struct led_trigger___2;

struct led_classdev___2 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___2 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___2 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___2 *);
	int (*blink_set)(struct led_classdev___2 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___2 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___2 *);
	struct device___162 *dev;
	const struct attribute_group___186 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___2 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___2 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___186 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___2 {
	const char *name;
	int (*activate)(struct led_classdev___2 *);
	void (*deactivate)(struct led_classdev___2 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___186 **groups;
};

typedef void k_handler_fn(struct vc_data___3 *, unsigned char, char);

typedef void fn_handler_fn(struct vc_data___3 *);

struct getset_keycode_data {
	struct input_keymap_entry ke;
	int error;
};

struct kbd_led_trigger {
	struct led_trigger___2 trigger;
	unsigned int mask;
};

struct uni_pagedir {
	u16 **uni_pgdir[32];
	long unsigned int refcount;
	long unsigned int sum;
	unsigned char *inverse_translations[4];
	u16 *inverse_trans_unicode;
};

typedef uint32_t char32_t;

struct uni_screen {
	char32_t *lines[0];
};

struct con_driver {
	const struct consw___2 *con;
	const char *desc;
	struct device___162 *dev;
	int node;
	int first;
	int last;
	int flag;
};

enum {
	blank_off = 0,
	blank_normal_wait = 1,
	blank_vesa_wait = 2,
};

enum {
	EPecma = 0,
	EPdec = 1,
	EPeq = 2,
	EPgt = 3,
	EPlt = 4,
};

struct rgb {
	u8 r;
	u8 g;
	u8 b;
};

enum {
	ESnormal = 0,
	ESesc = 1,
	ESsquare = 2,
	ESgetpars = 3,
	ESfunckey = 4,
	EShash = 5,
	ESsetG0 = 6,
	ESsetG1 = 7,
	ESpercent = 8,
	EScsiignore = 9,
	ESnonstd = 10,
	ESpalette = 11,
	ESosc = 12,
	ESapc = 13,
	ESpm = 14,
	ESdcs = 15,
};

struct interval {
	uint32_t first;
	uint32_t last;
};

struct vc_draw_region {
	long unsigned int from;
	long unsigned int to;
	int x;
};

struct hv_ops;

struct hvc_struct {
	struct tty_port___2 port;
	spinlock_t lock;
	int index;
	int do_wakeup;
	char *outbuf;
	int outbuf_size;
	int n_outbuf;
	uint32_t vtermno;
	const struct hv_ops *ops;
	int irq_requested;
	int data;
	struct winsize ws;
	struct work_struct tty_resize;
	struct list_head next;
	long unsigned int flags;
};

struct hv_ops {
	int (*get_chars)(uint32_t, char *, int);
	int (*put_chars)(uint32_t, const char *, int);
	int (*flush)(uint32_t, bool);
	int (*notifier_add)(struct hvc_struct *, int);
	void (*notifier_del)(struct hvc_struct *, int);
	void (*notifier_hangup)(struct hvc_struct *, int);
	int (*tiocmget)(struct hvc_struct *);
	int (*tiocmset)(struct hvc_struct *, unsigned int, unsigned int);
	void (*dtr_rts)(struct hvc_struct *, int);
};

struct uart_port___2;

struct uart_ops___2 {
	unsigned int (*tx_empty)(struct uart_port___2 *);
	void (*set_mctrl)(struct uart_port___2 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___2 *);
	void (*stop_tx)(struct uart_port___2 *);
	void (*start_tx)(struct uart_port___2 *);
	void (*throttle)(struct uart_port___2 *);
	void (*unthrottle)(struct uart_port___2 *);
	void (*send_xchar)(struct uart_port___2 *, char);
	void (*stop_rx)(struct uart_port___2 *);
	void (*enable_ms)(struct uart_port___2 *);
	void (*break_ctl)(struct uart_port___2 *, int);
	int (*startup)(struct uart_port___2 *);
	void (*shutdown)(struct uart_port___2 *);
	void (*flush_buffer)(struct uart_port___2 *);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___2 *, struct ktermios *);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___2 *);
	void (*release_port)(struct uart_port___2 *);
	int (*request_port)(struct uart_port___2 *);
	void (*config_port)(struct uart_port___2 *, int);
	int (*verify_port)(struct uart_port___2 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___2 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___2 *);
	void (*poll_put_char)(struct uart_port___2 *, unsigned char);
	int (*poll_get_char)(struct uart_port___2 *);
};

struct uart_state___2;

struct uart_port___2 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___2 *, int);
	void (*serial_out)(struct uart_port___2 *, int, int);
	void (*set_termios)(struct uart_port___2 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___2 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___2 *);
	void (*set_mctrl)(struct uart_port___2 *, unsigned int);
	unsigned int (*get_divisor)(struct uart_port___2 *, unsigned int, unsigned int *);
	void (*set_divisor)(struct uart_port___2 *, unsigned int, unsigned int, unsigned int);
	int (*startup)(struct uart_port___2 *);
	void (*shutdown)(struct uart_port___2 *);
	void (*throttle)(struct uart_port___2 *);
	void (*unthrottle)(struct uart_port___2 *);
	int (*handle_irq)(struct uart_port___2 *);
	void (*pm)(struct uart_port___2 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___2 *);
	int (*rs485_config)(struct uart_port___2 *, struct serial_rs485 *);
	int (*iso7816_config)(struct uart_port___2 *, struct serial_iso7816 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___2 *state;
	struct uart_icount icount;
	struct console___2 *cons;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___2 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___12 *dev;
	long unsigned int sysrq;
	unsigned int sysrq_ch;
	unsigned char has_sysrq;
	unsigned char sysrq_seq;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char console_reinit;
	const char *name;
	struct attribute_group___13 *attr_group;
	const struct attribute_group___13 **tty_groups;
	struct serial_rs485 rs485;
	struct gpio_desc *rs485_term_gpio;
	struct serial_iso7816 iso7816;
	void *private_data;
};

struct uart_state___2 {
	struct tty_port___2 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___2 *uart_port;
};

struct earlycon_device {
	struct console___2 *con;
	struct uart_port___2 port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device *, const char *);
};

typedef uint32_t XENCONS_RING_IDX;

struct xencons_interface {
	char in[1024];
	char out[2048];
	XENCONS_RING_IDX in_cons;
	XENCONS_RING_IDX in_prod;
	XENCONS_RING_IDX out_cons;
	XENCONS_RING_IDX out_prod;
};

struct xenbus_driver___2 {
	const char *name;
	const struct xenbus_device_id *ids;
	bool allow_rebind;
	int (*probe)(struct xenbus_device *, const struct xenbus_device_id *);
	void (*otherend_changed)(struct xenbus_device *, enum xenbus_state);
	int (*remove)(struct xenbus_device *);
	int (*suspend)(struct xenbus_device *);
	int (*resume)(struct xenbus_device *);
	int (*uevent)(struct xenbus_device *, struct kobj_uevent_env *);
	struct device_driver___12 driver;
	int (*read_otherend_details)(struct xenbus_device *);
	int (*is_ready)(struct xenbus_device *);
	void (*reclaim_memory)(struct xenbus_device *);
};

struct xencons_info {
	struct list_head list;
	struct xenbus_device *xbdev;
	struct xencons_interface *intf;
	unsigned int evtchn;
	XENCONS_RING_IDX out_cons;
	unsigned int out_cons_same;
	struct hvc_struct *hvc;
	int irq;
	int vtermno;
	grant_ref_t gntref;
};

struct uart_driver {
	struct module___182 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___4 *cons;
	struct uart_state *state;
	struct tty_driver___18 *tty_driver;
};

struct uart_match {
	struct uart_port *port;
	struct uart_driver *driver;
};

enum hwparam_type {
	hwparam_ioport = 0,
	hwparam_iomem = 1,
	hwparam_ioport_or_iomem = 2,
	hwparam_irq = 3,
	hwparam_dma = 4,
	hwparam_dma_addr = 5,
	hwparam_other = 6,
};

struct uart_driver___2 {
	struct module___178 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___4 *cons;
	struct uart_state *state;
	struct tty_driver___16 *tty_driver;
};

enum {
	PLAT8250_DEV_LEGACY = 4294967295,
	PLAT8250_DEV_PLATFORM = 0,
	PLAT8250_DEV_PLATFORM1 = 1,
	PLAT8250_DEV_PLATFORM2 = 2,
	PLAT8250_DEV_FOURPORT = 3,
	PLAT8250_DEV_ACCENT = 4,
	PLAT8250_DEV_BOCA = 5,
	PLAT8250_DEV_EXAR_ST16C554 = 6,
	PLAT8250_DEV_HUB6 = 7,
	PLAT8250_DEV_AU1X00 = 8,
	PLAT8250_DEV_SM501 = 9,
};

struct uart_8250_port;

struct uart_8250_ops {
	int (*setup_irq)(struct uart_8250_port *);
	void (*release_irq)(struct uart_8250_port *);
};

struct mctrl_gpios;

struct uart_8250_dma;

struct uart_8250_em485;

struct uart_8250_port {
	struct uart_port port;
	struct timer_list timer;
	struct list_head list;
	u32 capabilities;
	short unsigned int bugs;
	bool fifo_bug;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char fcr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned int rpm_tx_active;
	unsigned char canary;
	unsigned char probe;
	struct mctrl_gpios *gpios;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma *dma;
	const struct uart_8250_ops *ops;
	int (*dl_read)(struct uart_8250_port *);
	void (*dl_write)(struct uart_8250_port *, int);
	struct uart_8250_em485 *em485;
	void (*rs485_start_tx)(struct uart_8250_port *);
	void (*rs485_stop_tx)(struct uart_8250_port *);
	struct delayed_work overrun_backoff;
	u32 overrun_backoff_time_ms;
};

struct uart_8250_em485 {
	struct hrtimer start_tx_timer;
	struct hrtimer stop_tx_timer;
	struct hrtimer *active_timer;
	struct uart_8250_port *port;
	unsigned int tx_stopped: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uart_8250_dma {
	int (*tx_dma)(struct uart_8250_port *);
	int (*rx_dma)(struct uart_8250_port *);
	dma_filter_fn___3 fn;
	void *rx_param;
	void *tx_param;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___3 *rxchan;
	struct dma_chan___3 *txchan;
	phys_addr_t rx_dma_addr;
	phys_addr_t tx_dma_addr;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running;
	unsigned char tx_err;
	unsigned char rx_running;
};

struct old_serial_port {
	unsigned int uart;
	unsigned int baud_base;
	unsigned int port;
	unsigned int irq;
	upf_t flags;
	unsigned char io_type;
	unsigned char *iomem_base;
	short unsigned int iomem_reg_shift;
};

struct irq_info___2 {
	struct hlist_node node;
	int irq;
	spinlock_t lock;
	struct list_head *head;
};

struct pnp_protocol___4;

struct pnp_card___4 {
	struct device___162 dev;
	unsigned char number;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head devices;
	struct pnp_protocol___4 *protocol;
	struct pnp_id *id;
	char name[50];
	unsigned char pnpver;
	unsigned char productver;
	unsigned int serial;
	unsigned char checksum;
	struct proc_dir_entry *procdir;
};

struct pnp_dev___4;

struct pnp_protocol___4 {
	struct list_head protocol_list;
	char *name;
	int (*get)(struct pnp_dev___4 *);
	int (*set)(struct pnp_dev___4 *);
	int (*disable)(struct pnp_dev___4 *);
	bool (*can_wakeup)(struct pnp_dev___4 *);
	int (*suspend)(struct pnp_dev___4 *, pm_message_t);
	int (*resume)(struct pnp_dev___4 *);
	unsigned char number;
	struct device___162 dev;
	struct list_head cards;
	struct list_head devices;
};

struct pnp_card_driver___4;

struct pnp_card_link___4 {
	struct pnp_card___4 *card;
	struct pnp_card_driver___4 *driver;
	void *driver_data;
	pm_message_t pm_state;
};

struct pnp_driver___4 {
	const char *name;
	const struct pnp_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_dev___4 *, const struct pnp_device_id *);
	void (*remove)(struct pnp_dev___4 *);
	void (*shutdown)(struct pnp_dev___4 *);
	int (*suspend)(struct pnp_dev___4 *, pm_message_t);
	int (*resume)(struct pnp_dev___4 *);
	struct device_driver___162 driver;
};

struct pnp_card_driver___4 {
	struct list_head global_list;
	char *name;
	const struct pnp_card_device_id *id_table;
	unsigned int flags;
	int (*probe)(struct pnp_card_link___4 *, const struct pnp_card_device_id *);
	void (*remove)(struct pnp_card_link___4 *);
	int (*suspend)(struct pnp_card_link___4 *, pm_message_t);
	int (*resume)(struct pnp_card_link___4 *);
	struct pnp_driver___4 link;
};

struct pnp_dev___4 {
	struct device___162 dev;
	u64 dma_mask;
	unsigned int number;
	int status;
	struct list_head global_list;
	struct list_head protocol_list;
	struct list_head card_list;
	struct list_head rdev_list;
	struct pnp_protocol___4 *protocol;
	struct pnp_card___4 *card;
	struct pnp_driver___4 *driver;
	struct pnp_card_link___4 *card_link;
	struct pnp_id *id;
	int active;
	int capabilities;
	unsigned int num_dependent_sets;
	struct list_head resources;
	struct list_head options;
	char name[50];
	int flags;
	struct proc_dir_entry *procent;
	void *data;
};

struct serial8250_config {
	const char *name;
	short unsigned int fifo_size;
	short unsigned int tx_loadsz;
	unsigned char fcr;
	unsigned char rxtrig_bytes[4];
	unsigned int flags;
};

struct dw8250_port_data {
	int line;
	struct uart_8250_dma dma;
	u8 dlf_size;
};

struct uart_8250_port___2;

struct uart_8250_ops___2 {
	int (*setup_irq)(struct uart_8250_port___2 *);
	void (*release_irq)(struct uart_8250_port___2 *);
};

struct uart_8250_dma___2;

struct uart_8250_em485___2;

struct uart_8250_port___2 {
	struct uart_port___2 port;
	struct timer_list timer;
	struct list_head list;
	u32 capabilities;
	short unsigned int bugs;
	bool fifo_bug;
	unsigned int tx_loadsz;
	unsigned char acr;
	unsigned char fcr;
	unsigned char ier;
	unsigned char lcr;
	unsigned char mcr;
	unsigned char mcr_mask;
	unsigned char mcr_force;
	unsigned char cur_iotype;
	unsigned int rpm_tx_active;
	unsigned char canary;
	unsigned char probe;
	struct mctrl_gpios *gpios;
	unsigned char lsr_saved_flags;
	unsigned char msr_saved_flags;
	struct uart_8250_dma___2 *dma;
	const struct uart_8250_ops___2 *ops;
	int (*dl_read)(struct uart_8250_port___2 *);
	void (*dl_write)(struct uart_8250_port___2 *, int);
	struct uart_8250_em485___2 *em485;
	void (*rs485_start_tx)(struct uart_8250_port___2 *);
	void (*rs485_stop_tx)(struct uart_8250_port___2 *);
	struct delayed_work overrun_backoff;
	u32 overrun_backoff_time_ms;
};

struct uart_8250_em485___2 {
	struct hrtimer start_tx_timer;
	struct hrtimer stop_tx_timer;
	struct hrtimer *active_timer;
	struct uart_8250_port___2 *port;
	unsigned int tx_stopped;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_chan___5;

typedef bool (*dma_filter_fn___5)(struct dma_chan___5 *, void *);

struct uart_8250_dma___2 {
	int (*tx_dma)(struct uart_8250_port___2 *);
	int (*rx_dma)(struct uart_8250_port___2 *);
	dma_filter_fn___5 fn;
	void *rx_param;
	void *tx_param;
	struct dma_slave_config rxconf;
	struct dma_slave_config txconf;
	struct dma_chan___5 *rxchan;
	struct dma_chan___5 *txchan;
	phys_addr_t rx_dma_addr;
	phys_addr_t tx_dma_addr;
	dma_addr_t rx_addr;
	dma_addr_t tx_addr;
	dma_cookie_t rx_cookie;
	dma_cookie_t tx_cookie;
	void *rx_buf;
	size_t rx_size;
	size_t tx_size;
	unsigned char tx_running;
	unsigned char tx_err;
	unsigned char rx_running;
};

struct dma_router___5 {
	struct device___12 *dev;
	void (*route_free)(struct device___12 *, void *);
};

struct dma_device___5;

struct dma_chan_dev___5;

struct dma_chan___5 {
	struct dma_device___5 *device;
	struct device___12 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___5 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___5 *router;
	void *route_data;
	void *private;
};

struct dma_filter___5 {
	dma_filter_fn___5 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___5;

struct dma_device___5 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___5 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___12 *dev;
	struct module___180 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___5 *);
	int (*device_router_config)(struct dma_chan___5 *);
	void (*device_free_chan_resources)(struct dma_chan___5 *);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memcpy)(struct dma_chan___5 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_xor)(struct dma_chan___5 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_xor_val)(struct dma_chan___5 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_pq)(struct dma_chan___5 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_pq_val)(struct dma_chan___5 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memset)(struct dma_chan___5 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_memset_sg)(struct dma_chan___5 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_interrupt)(struct dma_chan___5 *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_slave_sg)(struct dma_chan___5 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_cyclic)(struct dma_chan___5 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_interleaved_dma)(struct dma_chan___5 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___5 * (*device_prep_dma_imm_data)(struct dma_chan___5 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___5 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___5 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___5 *);
	int (*device_resume)(struct dma_chan___5 *);
	int (*device_terminate_all)(struct dma_chan___5 *);
	void (*device_synchronize)(struct dma_chan___5 *);
	enum dma_status (*device_tx_status)(struct dma_chan___5 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___5 *);
	void (*device_release)(struct dma_device___5 *);
	void (*dbg_summary_show)(struct seq_file___172 *, struct dma_device___5 *);
	struct dentry___196 *dbg_dev_root;
};

struct dma_chan_dev___5 {
	struct dma_chan___5 *chan;
	struct device___12 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___5 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___12 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___5 {
	int (*attach)(struct dma_async_tx_descriptor___5 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___5 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___5 *, size_t);
};

struct dma_async_tx_descriptor___5 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___5 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___5 *);
	int (*desc_free)(struct dma_async_tx_descriptor___5 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___5 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___5 *metadata_ops;
	struct dma_async_tx_descriptor___5 *next;
	struct dma_async_tx_descriptor___5 *parent;
	spinlock_t lock;
};

struct fintek_8250 {
	u16 pid;
	u16 base_port;
	u8 index;
	u8 key;
};

struct pci_bus___13;

struct pci_slot___13 {
	struct pci_bus___13 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___186 kobj;
};

struct pci_dev___13;

struct pci_ops___13;

struct pci_bus___13 {
	struct list_head node;
	struct pci_bus___13 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___13 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___13 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___162 *bridge;
	struct device___162 dev;
	struct bin_attribute___186 *legacy_io;
	struct bin_attribute___186 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___13;

struct pci_dev___13 {
	struct list_head bus_list;
	struct pci_bus___13 *bus;
	struct pci_bus___13 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___13 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___13 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___13 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___162 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___186 *res_attr[17];
	struct bin_attribute___186 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___186 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___13 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___13;

struct pci_driver___13 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___13 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___13 *);
	int (*suspend)(struct pci_dev___13 *, pm_message_t);
	int (*resume)(struct pci_dev___13 *);
	void (*shutdown)(struct pci_dev___13 *);
	int (*sriov_configure)(struct pci_dev___13 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___13 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___13 *);
	const struct pci_error_handlers___13 *err_handler;
	const struct attribute_group___186 **groups;
	const struct attribute_group___186 **dev_groups;
	struct device_driver___162 driver;
	struct pci_dynids dynids;
};

struct pci_ops___13 {
	int (*add_bus)(struct pci_bus___13 *);
	void (*remove_bus)(struct pci_bus___13 *);
	void * (*map_bus)(struct pci_bus___13 *, unsigned int, int);
	int (*read)(struct pci_bus___13 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___13 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___13 {
	pci_ers_result_t (*error_detected)(struct pci_dev___13 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___13 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___13 *);
	void (*reset_prepare)(struct pci_dev___13 *);
	void (*reset_done)(struct pci_dev___13 *);
	void (*resume)(struct pci_dev___13 *);
};

struct pciserial_board {
	unsigned int flags;
	unsigned int num_ports;
	unsigned int base_baud;
	unsigned int uart_offset;
	unsigned int reg_shift;
	unsigned int first_offset;
};

struct serial_private;

struct pci_serial_quirk {
	u32 vendor;
	u32 device;
	u32 subvendor;
	u32 subdevice;
	int (*probe)(struct pci_dev___13 *);
	int (*init)(struct pci_dev___13 *);
	int (*setup)(struct serial_private *, const struct pciserial_board *, struct uart_8250_port *, int);
	void (*exit)(struct pci_dev___13 *);
};

struct serial_private {
	struct pci_dev___13 *dev;
	unsigned int nr;
	struct pci_serial_quirk *quirk;
	const struct pciserial_board *board;
	int line[0];
};

struct f815xxa_data {
	spinlock_t lock;
	int idx;
};

struct timedia_struct {
	int num;
	const short unsigned int *ids;
};

struct quatech_feature {
	u16 devid;
	bool amcc;
};

enum pci_board_num_t {
	pbn_default = 0,
	pbn_b0_1_115200 = 1,
	pbn_b0_2_115200 = 2,
	pbn_b0_4_115200 = 3,
	pbn_b0_5_115200 = 4,
	pbn_b0_8_115200 = 5,
	pbn_b0_1_921600 = 6,
	pbn_b0_2_921600 = 7,
	pbn_b0_4_921600 = 8,
	pbn_b0_2_1130000 = 9,
	pbn_b0_4_1152000 = 10,
	pbn_b0_4_1250000 = 11,
	pbn_b0_2_1843200 = 12,
	pbn_b0_4_1843200 = 13,
	pbn_b0_1_3906250 = 14,
	pbn_b0_bt_1_115200 = 15,
	pbn_b0_bt_2_115200 = 16,
	pbn_b0_bt_4_115200 = 17,
	pbn_b0_bt_8_115200 = 18,
	pbn_b0_bt_1_460800 = 19,
	pbn_b0_bt_2_460800 = 20,
	pbn_b0_bt_4_460800 = 21,
	pbn_b0_bt_1_921600 = 22,
	pbn_b0_bt_2_921600 = 23,
	pbn_b0_bt_4_921600 = 24,
	pbn_b0_bt_8_921600 = 25,
	pbn_b1_1_115200 = 26,
	pbn_b1_2_115200 = 27,
	pbn_b1_4_115200 = 28,
	pbn_b1_8_115200 = 29,
	pbn_b1_16_115200 = 30,
	pbn_b1_1_921600 = 31,
	pbn_b1_2_921600 = 32,
	pbn_b1_4_921600 = 33,
	pbn_b1_8_921600 = 34,
	pbn_b1_2_1250000 = 35,
	pbn_b1_bt_1_115200 = 36,
	pbn_b1_bt_2_115200 = 37,
	pbn_b1_bt_4_115200 = 38,
	pbn_b1_bt_2_921600 = 39,
	pbn_b1_1_1382400 = 40,
	pbn_b1_2_1382400 = 41,
	pbn_b1_4_1382400 = 42,
	pbn_b1_8_1382400 = 43,
	pbn_b2_1_115200 = 44,
	pbn_b2_2_115200 = 45,
	pbn_b2_4_115200 = 46,
	pbn_b2_8_115200 = 47,
	pbn_b2_1_460800 = 48,
	pbn_b2_4_460800 = 49,
	pbn_b2_8_460800 = 50,
	pbn_b2_16_460800 = 51,
	pbn_b2_1_921600 = 52,
	pbn_b2_4_921600 = 53,
	pbn_b2_8_921600 = 54,
	pbn_b2_8_1152000 = 55,
	pbn_b2_bt_1_115200 = 56,
	pbn_b2_bt_2_115200 = 57,
	pbn_b2_bt_4_115200 = 58,
	pbn_b2_bt_2_921600 = 59,
	pbn_b2_bt_4_921600 = 60,
	pbn_b3_2_115200 = 61,
	pbn_b3_4_115200 = 62,
	pbn_b3_8_115200 = 63,
	pbn_b4_bt_2_921600 = 64,
	pbn_b4_bt_4_921600 = 65,
	pbn_b4_bt_8_921600 = 66,
	pbn_panacom = 67,
	pbn_panacom2 = 68,
	pbn_panacom4 = 69,
	pbn_plx_romulus = 70,
	pbn_endrun_2_4000000 = 71,
	pbn_oxsemi = 72,
	pbn_oxsemi_1_3906250 = 73,
	pbn_oxsemi_2_3906250 = 74,
	pbn_oxsemi_4_3906250 = 75,
	pbn_oxsemi_8_3906250 = 76,
	pbn_intel_i960 = 77,
	pbn_sgi_ioc3 = 78,
	pbn_computone_4 = 79,
	pbn_computone_6 = 80,
	pbn_computone_8 = 81,
	pbn_sbsxrsio = 82,
	pbn_pasemi_1682M = 83,
	pbn_ni8430_2 = 84,
	pbn_ni8430_4 = 85,
	pbn_ni8430_8 = 86,
	pbn_ni8430_16 = 87,
	pbn_ADDIDATA_PCIe_1_3906250 = 88,
	pbn_ADDIDATA_PCIe_2_3906250 = 89,
	pbn_ADDIDATA_PCIe_4_3906250 = 90,
	pbn_ADDIDATA_PCIe_8_3906250 = 91,
	pbn_ce4100_1_115200 = 92,
	pbn_omegapci = 93,
	pbn_NETMOS9900_2s_115200 = 94,
	pbn_brcm_trumanage = 95,
	pbn_fintek_4 = 96,
	pbn_fintek_8 = 97,
	pbn_fintek_12 = 98,
	pbn_fintek_F81504A = 99,
	pbn_fintek_F81508A = 100,
	pbn_fintek_F81512A = 101,
	pbn_wch382_2 = 102,
	pbn_wch384_4 = 103,
	pbn_wch384_8 = 104,
	pbn_pericom_PI7C9X7951 = 105,
	pbn_pericom_PI7C9X7952 = 106,
	pbn_pericom_PI7C9X7954 = 107,
	pbn_pericom_PI7C9X7958 = 108,
	pbn_sunix_pci_1s = 109,
	pbn_sunix_pci_2s = 110,
	pbn_sunix_pci_4s = 111,
	pbn_sunix_pci_8s = 112,
	pbn_sunix_pci_16s = 113,
	pbn_titan_1_4000000 = 114,
	pbn_titan_2_4000000 = 115,
	pbn_titan_4_4000000 = 116,
	pbn_titan_8_4000000 = 117,
	pbn_moxa8250_2p = 118,
	pbn_moxa8250_4p = 119,
	pbn_moxa8250_8p = 120,
};

struct fsl8250_data {
	int line;
};

struct dw8250_port_data___2 {
	int line;
	struct uart_8250_dma___2 dma;
	u8 dlf_size;
};

struct dw8250_data {
	struct dw8250_port_data___2 data;
	u8 usr_reg;
	int msr_mask_on;
	int msr_mask_off;
	struct clk *clk;
	struct clk *pclk;
	struct notifier_block clk_notifier;
	struct work_struct clk_work;
	struct reset_control *rst;
	unsigned int skip_autocfg;
	unsigned int uart_16550_compatible;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum mctrl_gpio_idx {
	UART_GPIO_CTS = 0,
	UART_GPIO_DSR = 1,
	UART_GPIO_DCD = 2,
	UART_GPIO_RNG = 3,
	UART_GPIO_RI = 3,
	UART_GPIO_RTS = 4,
	UART_GPIO_DTR = 5,
	UART_GPIO_MAX = 6,
};

struct omap8250_priv {
	int line;
	u8 habit;
	u8 mdr1;
	u8 efr;
	u8 scr;
	u8 wer;
	u8 xon;
	u8 xoff;
	u8 delayed_restore;
	u16 quot;
	u8 tx_trigger;
	u8 rx_trigger;
	bool is_suspending;
	int wakeirq;
	int wakeups_enabled;
	u32 latency;
	u32 calc_latency;
	struct pm_qos_request pm_qos_request;
	struct work_struct qos_work;
	struct uart_8250_dma___2 omap8250_dma;
	spinlock_t rx_dma_lock;
	bool rx_dma_broken;
	bool throttled;
};

struct omap8250_dma_params {
	u32 rx_size;
	u8 rx_trigger;
	u8 tx_trigger;
};

struct omap8250_platdata {
	struct omap8250_dma_params *dma_params;
	u8 habit;
};

struct earlycon_device___2 {
	struct console___4 *con;
	struct uart_port port;
	char options[16];
	unsigned int baud;
};

struct earlycon_id___2 {
	char name[15];
	char name_term;
	char compatible[128];
	int (*setup)(struct earlycon_device___2 *, const char *);
};

enum dma_rx_status {
	DMA_RX_START = 0,
	DMA_RX_RUNNING = 1,
	DMA_RX_SHUTDOWN = 2,
};

struct mtk8250_data {
	int line;
	unsigned int rx_pos;
	unsigned int clk_count;
	struct clk *uart_clk;
	struct clk *bus_clk;
	struct uart_8250_dma *dma;
	enum dma_rx_status rx_status;
	int rx_wakeup_irq;
};

enum {
	MTK_UART_FC_NONE = 0,
	MTK_UART_FC_SW = 1,
	MTK_UART_FC_HW = 2,
};

struct tegra_uart {
	struct clk *clk;
	struct reset_control *rst;
	int line;
};

struct of_serial_info {
	struct clk *clk;
	struct reset_control *rst;
	int type;
	int line;
};

struct console___6 {
	char name[16];
	void (*write)(struct console___6 *, const char *, unsigned int);
	int (*read)(struct console___6 *, char *, unsigned int);
	struct tty_driver___16 * (*device)(struct console___6 *, int *);
	void (*unblank)();
	int (*setup)(struct console___6 *, char *);
	int (*exit)(struct console___6 *);
	int (*match)(struct console___6 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___6 *next;
};

struct uart_port___3;

struct uart_ops___3 {
	unsigned int (*tx_empty)(struct uart_port___3 *);
	void (*set_mctrl)(struct uart_port___3 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___3 *);
	void (*stop_tx)(struct uart_port___3 *);
	void (*start_tx)(struct uart_port___3 *);
	void (*throttle)(struct uart_port___3 *);
	void (*unthrottle)(struct uart_port___3 *);
	void (*send_xchar)(struct uart_port___3 *, char);
	void (*stop_rx)(struct uart_port___3 *);
	void (*enable_ms)(struct uart_port___3 *);
	void (*break_ctl)(struct uart_port___3 *, int);
	int (*startup)(struct uart_port___3 *);
	void (*shutdown)(struct uart_port___3 *);
	void (*flush_buffer)(struct uart_port___3 *);
	void (*set_termios)(struct uart_port___3 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___3 *, struct ktermios *);
	void (*pm)(struct uart_port___3 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___3 *);
	void (*release_port)(struct uart_port___3 *);
	int (*request_port)(struct uart_port___3 *);
	void (*config_port)(struct uart_port___3 *, int);
	int (*verify_port)(struct uart_port___3 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___3 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___3 *);
	void (*poll_put_char)(struct uart_port___3 *, unsigned char);
	int (*poll_get_char)(struct uart_port___3 *);
};

struct uart_state___3;

struct uart_port___3 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___3 *, int);
	void (*serial_out)(struct uart_port___3 *, int, int);
	void (*set_termios)(struct uart_port___3 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___3 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___3 *);
	void (*set_mctrl)(struct uart_port___3 *, unsigned int);
	unsigned int (*get_divisor)(struct uart_port___3 *, unsigned int, unsigned int *);
	void (*set_divisor)(struct uart_port___3 *, unsigned int, unsigned int, unsigned int);
	int (*startup)(struct uart_port___3 *);
	void (*shutdown)(struct uart_port___3 *);
	void (*throttle)(struct uart_port___3 *);
	void (*unthrottle)(struct uart_port___3 *);
	int (*handle_irq)(struct uart_port___3 *);
	void (*pm)(struct uart_port___3 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___3 *);
	int (*rs485_config)(struct uart_port___3 *, struct serial_rs485 *);
	int (*iso7816_config)(struct uart_port___3 *, struct serial_iso7816 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___3 *state;
	struct uart_icount icount;
	struct console___6 *cons;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___3 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___153 *dev;
	long unsigned int sysrq;
	unsigned int sysrq_ch;
	unsigned char has_sysrq;
	unsigned char sysrq_seq;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char console_reinit;
	const char *name;
	struct attribute_group___182 *attr_group;
	const struct attribute_group___182 **tty_groups;
	struct serial_rs485 rs485;
	struct gpio_desc *rs485_term_gpio;
	struct serial_iso7816 iso7816;
	void *private_data;
};

struct uart_state___3 {
	struct tty_port___16 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___3 *uart_port;
};

struct amba_device___3 {
	struct device___153 dev;
	struct resource res;
	struct clk *pclk;
	struct device_dma_parameters dma_parms;
	unsigned int periphid;
	unsigned int cid;
	struct amba_cs_uci_id uci;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver___3 {
	struct device_driver___153 drv;
	int (*probe)(struct amba_device___3 *, const struct amba_id *);
	void (*remove)(struct amba_device___3 *);
	void (*shutdown)(struct amba_device___3 *);
	const struct amba_id *id_table;
};

enum amba_vendor {
	AMBA_VENDOR_ARM = 65,
	AMBA_VENDOR_ST = 128,
	AMBA_VENDOR_QCOM = 81,
	AMBA_VENDOR_LSI = 182,
	AMBA_VENDOR_LINUX = 254,
};

struct amba_pl011_data {
	bool (*dma_filter)(struct dma_chan___3 *, void *);
	void *dma_rx_param;
	void *dma_tx_param;
	bool dma_rx_poll_enable;
	unsigned int dma_rx_poll_rate;
	unsigned int dma_rx_poll_timeout;
	void (*init)();
	void (*exit)();
};

struct platform_device___24 {
	const char *name;
	int id;
	bool id_auto;
	struct device___153 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___22 {
	int (*probe)(struct platform_device___24 *);
	int (*remove)(struct platform_device___24 *);
	void (*shutdown)(struct platform_device___24 *);
	int (*suspend)(struct platform_device___24 *, pm_message_t);
	int (*resume)(struct platform_device___24 *);
	struct device_driver___153 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum {
	REG_DR = 0,
	REG_ST_DMAWM = 1,
	REG_ST_TIMEOUT = 2,
	REG_FR = 3,
	REG_LCRH_RX = 4,
	REG_LCRH_TX = 5,
	REG_IBRD = 6,
	REG_FBRD = 7,
	REG_CR = 8,
	REG_IFLS = 9,
	REG_IMSC = 10,
	REG_RIS = 11,
	REG_MIS = 12,
	REG_ICR = 13,
	REG_DMACR = 14,
	REG_ST_XFCR = 15,
	REG_ST_XON1 = 16,
	REG_ST_XON2 = 17,
	REG_ST_XOFF1 = 18,
	REG_ST_XOFF2 = 19,
	REG_ST_ITCR = 20,
	REG_ST_ITIP = 21,
	REG_ST_ABCR = 22,
	REG_ST_ABIMSC = 23,
	REG_ARRAY_SIZE = 24,
};

struct vendor_data___2 {
	const u16 *reg_offset;
	unsigned int ifls;
	unsigned int fr_busy;
	unsigned int fr_dsr;
	unsigned int fr_cts;
	unsigned int fr_ri;
	unsigned int inv_fr;
	bool access_32b;
	bool oversampling;
	bool dma_threshold;
	bool cts_event_workaround;
	bool always_enabled;
	bool fixed_options;
	unsigned int (*get_fifosize)(struct amba_device___3 *);
};

struct pl011_sgbuf {
	struct scatterlist sg;
	char *buf;
};

struct pl011_dmarx_data {
	struct dma_chan___3 *chan;
	struct completion complete;
	bool use_buf_b;
	struct pl011_sgbuf sgbuf_a;
	struct pl011_sgbuf sgbuf_b;
	dma_cookie_t cookie;
	bool running;
	struct timer_list timer;
	unsigned int last_residue;
	long unsigned int last_jiffies;
	bool auto_poll_rate;
	unsigned int poll_rate;
	unsigned int poll_timeout;
};

struct pl011_dmatx_data {
	struct dma_chan___3 *chan;
	struct scatterlist sg;
	char *buf;
	bool queued;
};

struct uart_amba_port {
	struct uart_port___3 port;
	const u16 *reg_offset;
	struct clk *clk;
	const struct vendor_data___2 *vendor;
	unsigned int dmacr;
	unsigned int im;
	unsigned int old_status;
	unsigned int fifosize;
	unsigned int old_cr;
	unsigned int fixed_baud;
	char type[12];
	bool rs485_tx_started;
	unsigned int rs485_tx_drain_interval;
	bool using_tx_dma;
	bool using_rx_dma;
	struct pl011_dmarx_data dmarx;
	struct pl011_dmatx_data dmatx;
	bool dma_probed;
};

struct dentry___199;

struct super_block___199;

struct module___183;

struct file_system_type___199 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___199 * (*mount)(struct file_system_type___199 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___199 *);
	struct module___183 *owner;
	struct file_system_type___199 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___199;

struct kiocb___199;

struct iov_iter___120;

struct poll_table_struct___131;

struct vm_area_struct___204;

struct inode___199;

struct file_lock___199;

struct page___204;

struct pipe_inode_info___64;

struct seq_file___175;

struct file_operations___200 {
	struct module___183 *owner;
	loff_t (*llseek)(struct file___199 *, loff_t, int);
	ssize_t (*read)(struct file___199 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___199 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___199 *, struct iov_iter___120 *);
	ssize_t (*write_iter)(struct kiocb___199 *, struct iov_iter___120 *);
	int (*iopoll)(struct kiocb___199 *, bool);
	int (*iterate)(struct file___199 *, struct dir_context *);
	int (*iterate_shared)(struct file___199 *, struct dir_context *);
	__poll_t (*poll)(struct file___199 *, struct poll_table_struct___131 *);
	long int (*unlocked_ioctl)(struct file___199 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___199 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___199 *, struct vm_area_struct___204 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___199 *, struct file___199 *);
	int (*flush)(struct file___199 *, fl_owner_t);
	int (*release)(struct inode___199 *, struct file___199 *);
	int (*fsync)(struct file___199 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___199 *, int);
	int (*lock)(struct file___199 *, int, struct file_lock___199 *);
	ssize_t (*sendpage)(struct file___199 *, struct page___204 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___199 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___199 *, long unsigned int);
	int (*flock)(struct file___199 *, int, struct file_lock___199 *);
	ssize_t (*splice_write)(struct pipe_inode_info___64 *, struct file___199 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___199 *, loff_t *, struct pipe_inode_info___64 *, size_t, unsigned int);
	int (*setlease)(struct file___199 *, long int, struct file_lock___199 **, void **);
	long int (*fallocate)(struct file___199 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___175 *, struct file___199 *);
	ssize_t (*copy_file_range)(struct file___199 *, loff_t, struct file___199 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___199 *, loff_t, struct file___199 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___199 *, loff_t, loff_t, int);
};

struct vmacache___204 {
	u64 seqnum;
	struct vm_area_struct___204 *vmas[4];
};

struct page_frag___204 {
	struct page___204 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___205;

struct pid___176;

struct nsproxy___185;

struct signal_struct___200;

struct vm_struct___182;

struct task_struct___206 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___206 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___205 *mm;
	struct mm_struct___205 *active_mm;
	struct vmacache___204 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___206 *real_parent;
	struct task_struct___206 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___206 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___176 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___185 *nsproxy;
	struct signal_struct___200 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___206 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___101 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___64 *splice_pipe;
	struct page_frag___204 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___206 *oom_reaper_list;
	struct vm_struct___182 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___187;

struct kobj_type___187;

struct kernfs_node___187;

struct kobject___187 {
	const char *name;
	struct list_head entry;
	struct kobject___187 *parent;
	struct kset___187 *kset;
	struct kobj_type___187 *ktype;
	struct kernfs_node___187 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___183 {
	struct kobject___187 kobj;
	struct module___183 *mod;
	struct kobject___187 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___183 {
	struct module___183 *mod;
	struct latch_tree_node node;
};

struct module_layout___183 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___183 mtn;
};

struct module_attribute___183;

struct kernel_param___183;

struct module___183 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___183 mkobj;
	struct module_attribute___183 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___187 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___183 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___183 core_layout;
	struct module_layout___183 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___176;

struct upid___176 {
	int nr;
	struct pid_namespace___176 *ns;
};

struct pid_namespace___176 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___206 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___176 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___176 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___176 numbers[1];
};

typedef struct page___204 *pgtable_t___204;

struct address_space___199;

struct page_pool___54;

struct dev_pagemap___194;

struct page___204 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___199 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___54 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___204 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___204 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___205 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___194 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___194;

struct vm_area_struct___204 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___204 *vm_next;
	struct vm_area_struct___204 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___205 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___194 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___199 *vm_file;
	struct file___199 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___18;

struct signal_struct___200 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___206 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___206 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___176 *pids[4];
	struct pid___176 *tty_old_pgrp;
	int leader;
	struct tty_struct___18 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___205 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___204;

struct mm_struct___205 {
	struct {
		struct vm_area_struct___204 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___199 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___204 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___206 *owner;
		struct user_namespace *user_ns;
		struct file___199 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___185 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___176 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___199;

struct pipe_buffer___64;

struct pipe_inode_info___64 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___204 *tmp_page;
	struct fasync_struct___199 *fasync_readers;
	struct fasync_struct___199 *fasync_writers;
	struct pipe_buffer___64 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___182 {
	struct vm_struct___182 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___204 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___199;

struct address_space___199 {
	struct inode___199 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___199 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___163;

struct page_pool_params___54 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___163 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___54 {
	u32 count;
	struct page___204 *cache[128];
};

struct page_pool___54 {
	struct page_pool_params___54 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___204 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___54 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___194;

struct dev_pagemap___194 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___194 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___199;

struct path___199 {
	struct vfsmount___199 *mnt;
	struct dentry___199 *dentry;
};

struct fown_struct___176 {
	rwlock_t lock;
	struct pid___176 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___199 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___199 f_path;
	struct inode___199 *f_inode;
	const struct file_operations___200 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___176 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___199 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___194;

struct vm_operations_struct___194 {
	void (*open)(struct vm_area_struct___204 *);
	void (*close)(struct vm_area_struct___204 *);
	int (*may_split)(struct vm_area_struct___204 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___204 *);
	int (*mprotect)(struct vm_area_struct___204 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___194 *);
	vm_fault_t (*huge_fault)(struct vm_fault___194 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___194 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___204 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___194 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___194 *);
	int (*access)(struct vm_area_struct___204 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___204 *);
	int (*set_policy)(struct vm_area_struct___204 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___204 *, long unsigned int);
	struct page___204 * (*find_special_page)(struct vm_area_struct___204 *, long unsigned int);
};

struct core_thread___204 {
	struct task_struct___206 *task;
	struct core_thread___204 *next;
};

struct core_state___204 {
	atomic_t nr_threads;
	struct core_thread___204 dumper;
	struct completion startup;
};

struct vm_fault___194 {
	const struct {
		struct vm_area_struct___204 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___204 *cow_page;
	struct page___204 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___204 prealloc_pte;
};

struct kernfs_root___187;

struct kernfs_elem_dir___187 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___187 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___187;

struct kernfs_root___187 {
	struct kernfs_node___187 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___187 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___187 {
	struct kernfs_node___187 *target_kn;
};

struct kernfs_ops___187;

struct kernfs_elem_attr___187 {
	const struct kernfs_ops___187 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___187 *notify_next;
};

struct kernfs_node___187 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___187 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___187 dir;
		struct kernfs_elem_symlink___187 symlink;
		struct kernfs_elem_attr___187 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___187;

struct kernfs_ops___187 {
	int (*open)(struct kernfs_open_file___187 *);
	void (*release)(struct kernfs_open_file___187 *);
	int (*seq_show)(struct seq_file___175 *, void *);
	void * (*seq_start)(struct seq_file___175 *, loff_t *);
	void * (*seq_next)(struct seq_file___175 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___175 *, void *);
	ssize_t (*read)(struct kernfs_open_file___187 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___187 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___187 *, struct poll_table_struct___131 *);
	int (*mmap)(struct kernfs_open_file___187 *, struct vm_area_struct___204 *);
};

struct kernfs_syscall_ops___187 {
	int (*show_options)(struct seq_file___175 *, struct kernfs_root___187 *);
	int (*mkdir)(struct kernfs_node___187 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___187 *);
	int (*rename)(struct kernfs_node___187 *, struct kernfs_node___187 *, const char *);
	int (*show_path)(struct seq_file___175 *, struct kernfs_node___187 *, struct kernfs_root___187 *);
};

struct seq_operations___175;

struct seq_file___175 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___175 *op;
	int poll_event;
	const struct file___199 *file;
	void *private;
};

struct kernfs_open_file___187 {
	struct kernfs_node___187 *kn;
	struct file___199 *file;
	struct seq_file___175 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___194 *vm_ops;
};

typedef void (*poll_queue_proc___137)(struct file___199 *, wait_queue_head_t *, struct poll_table_struct___131 *);

struct poll_table_struct___131 {
	poll_queue_proc___137 _qproc;
	__poll_t _key;
};

struct bin_attribute___187;

struct attribute_group___187 {
	const char *name;
	umode_t (*is_visible)(struct kobject___187 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___187 *, struct bin_attribute___187 *, int);
	struct attribute **attrs;
	struct bin_attribute___187 **bin_attrs;
};

struct bin_attribute___187 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___199 * (*f_mapping)();
	ssize_t (*read)(struct file___199 *, struct kobject___187 *, struct bin_attribute___187 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___199 *, struct kobject___187 *, struct bin_attribute___187 *, char *, loff_t, size_t);
	int (*mmap)(struct file___199 *, struct kobject___187 *, struct bin_attribute___187 *, struct vm_area_struct___204 *);
};

struct sysfs_ops___187 {
	ssize_t (*show)(struct kobject___187 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___187 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___187;

struct kset___187 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___187 kobj;
	const struct kset_uevent_ops___187 *uevent_ops;
};

struct kobj_type___187 {
	void (*release)(struct kobject___187 *);
	const struct sysfs_ops___187 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___187 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___187 *);
	const void * (*namespace)(struct kobject___187 *);
	void (*get_ownership)(struct kobject___187 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___187 {
	int (* const filter)(struct kset___187 *, struct kobject___187 *);
	const char * (* const name)(struct kset___187 *, struct kobject___187 *);
	int (* const uevent)(struct kset___187 *, struct kobject___187 *, struct kobj_uevent_env *);
};

struct wakeup_source___163;

struct dev_pm_info___163 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___163 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___163 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___163;

struct bus_type___163;

struct device_driver___163;

struct dev_pm_domain___163;

struct irq_domain___40;

struct device_node___66;

struct fwnode_handle___163;

struct class___163;

struct device___163 {
	struct kobject___187 kobj;
	struct device___163 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___163 *type;
	struct bus_type___163 *bus;
	struct device_driver___163 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___163 power;
	struct dev_pm_domain___163 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___40 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___66 *of_node;
	struct fwnode_handle___163 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___163 *class;
	const struct attribute_group___187 **groups;
	void (*release)(struct device___163 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___163 {
	int (*prepare)(struct device___163 *);
	void (*complete)(struct device___163 *);
	int (*suspend)(struct device___163 *);
	int (*resume)(struct device___163 *);
	int (*freeze)(struct device___163 *);
	int (*thaw)(struct device___163 *);
	int (*poweroff)(struct device___163 *);
	int (*restore)(struct device___163 *);
	int (*suspend_late)(struct device___163 *);
	int (*resume_early)(struct device___163 *);
	int (*freeze_late)(struct device___163 *);
	int (*thaw_early)(struct device___163 *);
	int (*poweroff_late)(struct device___163 *);
	int (*restore_early)(struct device___163 *);
	int (*suspend_noirq)(struct device___163 *);
	int (*resume_noirq)(struct device___163 *);
	int (*freeze_noirq)(struct device___163 *);
	int (*thaw_noirq)(struct device___163 *);
	int (*poweroff_noirq)(struct device___163 *);
	int (*restore_noirq)(struct device___163 *);
	int (*runtime_suspend)(struct device___163 *);
	int (*runtime_resume)(struct device___163 *);
	int (*runtime_idle)(struct device___163 *);
};

struct wakeup_source___163 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___163 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___163 {
	struct dev_pm_ops___163 ops;
	int (*start)(struct device___163 *);
	void (*detach)(struct device___163 *, bool);
	int (*activate)(struct device___163 *);
	void (*sync)(struct device___163 *);
	void (*dismiss)(struct device___163 *);
};

struct bus_type___163 {
	const char *name;
	const char *dev_name;
	struct device___163 *dev_root;
	const struct attribute_group___187 **bus_groups;
	const struct attribute_group___187 **dev_groups;
	const struct attribute_group___187 **drv_groups;
	int (*match)(struct device___163 *, struct device_driver___163 *);
	int (*uevent)(struct device___163 *, struct kobj_uevent_env *);
	int (*probe)(struct device___163 *);
	void (*sync_state)(struct device___163 *);
	void (*remove)(struct device___163 *);
	void (*shutdown)(struct device___163 *);
	int (*online)(struct device___163 *);
	int (*offline)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	int (*num_vf)(struct device___163 *);
	int (*dma_configure)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___163 {
	const char *name;
	struct bus_type___163 *bus;
	struct module___183 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___163 *);
	void (*sync_state)(struct device___163 *);
	int (*remove)(struct device___163 *);
	void (*shutdown)(struct device___163 *);
	int (*suspend)(struct device___163 *, pm_message_t);
	int (*resume)(struct device___163 *);
	const struct attribute_group___187 **groups;
	const struct attribute_group___187 **dev_groups;
	const struct dev_pm_ops___163 *pm;
	void (*coredump)(struct device___163 *);
	struct driver_private *p;
};

struct device_type___163 {
	const char *name;
	const struct attribute_group___187 **groups;
	int (*uevent)(struct device___163 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___163 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___163 *);
	const struct dev_pm_ops___163 *pm;
};

struct class___163 {
	const char *name;
	struct module___183 *owner;
	const struct attribute_group___187 **class_groups;
	const struct attribute_group___187 **dev_groups;
	struct kobject___187 *dev_kobj;
	int (*dev_uevent)(struct device___163 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___163 *, umode_t *);
	void (*class_release)(struct class___163 *);
	void (*dev_release)(struct device___163 *);
	int (*shutdown_pre)(struct device___163 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___163 *);
	void (*get_ownership)(struct device___163 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___163 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___40;

struct irq_domain_chip_generic___40;

struct irq_data___41;

struct irq_domain___40 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___40 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___163 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___40 *gc;
	struct irq_domain___40 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___41 *revmap[0];
};

struct fwnode_operations___163;

struct fwnode_handle___163 {
	struct fwnode_handle___163 *secondary;
	const struct fwnode_operations___163 *ops;
	struct device___163 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___50;

struct device_node___66 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___163 fwnode;
	struct property___50 *properties;
	struct property___50 *deadprops;
	struct device_node___66 *parent;
	struct device_node___66 *child;
	struct device_node___66 *sibling;
	struct kobject___187 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___42;

typedef void (*irq_flow_handler_t___42)(struct irq_desc___42 *);

struct irq_chip___41;

struct irq_data___41 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___12 *common;
	struct irq_chip___41 *chip;
	struct irq_domain___40 *domain;
	struct irq_data___41 *parent_data;
	void *chip_data;
};

struct irqaction___28;

struct irq_desc___42 {
	struct irq_common_data___12 irq_common_data;
	struct irq_data___41 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___42 handle_irq;
	struct irqaction___28 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___187 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___183 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___163;

struct fwnode_endpoint___163;

struct fwnode_operations___163 {
	struct fwnode_handle___163 * (*get)(struct fwnode_handle___163 *);
	void (*put)(struct fwnode_handle___163 *);
	bool (*device_is_available)(const struct fwnode_handle___163 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___163 *, const struct device___163 *);
	bool (*property_present)(const struct fwnode_handle___163 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___163 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___163 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___163 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*get_parent)(const struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*get_next_child_node)(const struct fwnode_handle___163 *, struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*get_named_child_node)(const struct fwnode_handle___163 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___163 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___163 *);
	struct fwnode_handle___163 * (*graph_get_next_endpoint)(const struct fwnode_handle___163 *, struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*graph_get_remote_endpoint)(const struct fwnode_handle___163 *);
	struct fwnode_handle___163 * (*graph_get_port_parent)(struct fwnode_handle___163 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___163 *, struct fwnode_endpoint___163 *);
	int (*add_links)(struct fwnode_handle___163 *);
};

struct fwnode_endpoint___163 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___163 *local_fwnode;
};

struct fwnode_reference_args___163 {
	struct fwnode_handle___163 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___41 {
	struct device___163 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___41 *);
	void (*irq_shutdown)(struct irq_data___41 *);
	void (*irq_enable)(struct irq_data___41 *);
	void (*irq_disable)(struct irq_data___41 *);
	void (*irq_ack)(struct irq_data___41 *);
	void (*irq_mask)(struct irq_data___41 *);
	void (*irq_mask_ack)(struct irq_data___41 *);
	void (*irq_unmask)(struct irq_data___41 *);
	void (*irq_eoi)(struct irq_data___41 *);
	int (*irq_set_affinity)(struct irq_data___41 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___41 *);
	int (*irq_set_type)(struct irq_data___41 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___41 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___41 *);
	void (*irq_bus_sync_unlock)(struct irq_data___41 *);
	void (*irq_cpu_online)(struct irq_data___41 *);
	void (*irq_cpu_offline)(struct irq_data___41 *);
	void (*irq_suspend)(struct irq_data___41 *);
	void (*irq_resume)(struct irq_data___41 *);
	void (*irq_pm_shutdown)(struct irq_data___41 *);
	void (*irq_calc_mask)(struct irq_data___41 *);
	void (*irq_print_chip)(struct irq_data___41 *, struct seq_file___175 *);
	int (*irq_request_resources)(struct irq_data___41 *);
	void (*irq_release_resources)(struct irq_data___41 *);
	void (*irq_compose_msi_msg)(struct irq_data___41 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___41 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___41 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___41 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___41 *, void *);
	void (*ipi_send_single)(struct irq_data___41 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___41 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___41 *);
	void (*irq_nmi_teardown)(struct irq_data___41 *);
	long unsigned int flags;
};

struct irqaction___28 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___28 *next;
	irq_handler_t thread_fn;
	struct task_struct___206 *thread;
	struct irqaction___28 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___40 {
	struct irq_chip___41 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___42 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___40 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___40 *);
	void (*resume)(struct irq_chip_generic___40 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___40 *domain;
	struct list_head list;
	struct irq_chip_type___40 chip_types[0];
};

struct irq_domain_chip_generic___40 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___40 *gc[0];
};

struct spi_device_id {
	char name[32];
	kernel_ulong_t driver_data;
};

struct property___50 {
	char *name;
	int length;
	void *value;
	struct property___50 *next;
	long unsigned int _flags;
	struct bin_attribute___187 attr;
};

struct of_phandle_args___30 {
	struct device_node___66 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___38 {
	struct fwnode_handle___163 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___40 {
	int (*match)(struct irq_domain___40 *, struct device_node___66 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___40 *, struct irq_fwspec___38 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___40 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___40 *, unsigned int);
	int (*xlate)(struct irq_domain___40 *, struct device_node___66 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___40 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___40 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___40 *, struct irq_data___41 *, bool);
	void (*deactivate)(struct irq_domain___40 *, struct irq_data___41 *);
	int (*translate)(struct irq_domain___40 *, struct irq_fwspec___38 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___199;

struct dentry___199 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___199 *d_parent;
	struct qstr d_name;
	struct inode___199 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___199 *d_op;
	struct super_block___199 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___199;

struct cdev___46;

struct inode___199 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___199 *i_op;
	struct super_block___199 *i_sb;
	struct address_space___199 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___200 *i_fop;
		void (*free_inode)(struct inode___199 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___199 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___64 *i_pipe;
		struct cdev___46 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___199 {
	int (*d_revalidate)(struct dentry___199 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___199 *, unsigned int);
	int (*d_hash)(const struct dentry___199 *, struct qstr *);
	int (*d_compare)(const struct dentry___199 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___199 *);
	int (*d_init)(struct dentry___199 *);
	void (*d_release)(struct dentry___199 *);
	void (*d_prune)(struct dentry___199 *);
	void (*d_iput)(struct dentry___199 *, struct inode___199 *);
	char * (*d_dname)(struct dentry___199 *, char *, int);
	struct vfsmount___199 * (*d_automount)(struct path___199 *);
	int (*d_manage)(const struct path___199 *, bool);
	struct dentry___199 * (*d_real)(struct dentry___199 *, const struct inode___199 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___199;

struct mem_dqinfo___199 {
	struct quota_format_type___199 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___199;

struct quota_info___199 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___199 *files[3];
	struct mem_dqinfo___199 info[3];
	const struct quota_format_ops___199 *ops[3];
};

struct rcuwait___200 {
	struct task_struct___206 *task;
};

struct percpu_rw_semaphore___200 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___200 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___199 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___200 rw_sem[3];
};

struct super_operations___199;

struct dquot_operations___199;

struct quotactl_ops___199;

struct super_block___199 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___199 *s_type;
	const struct super_operations___199 *s_op;
	const struct dquot_operations___199 *dq_op;
	const struct quotactl_ops___199 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___199 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___199 s_dquot;
	struct sb_writers___199 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___199 *s_d_op;
	int cleancache_poolid;
	struct shrinker___85 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___199 {
	struct dentry___199 *mnt_root;
	struct super_block___199 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct tty_driver___19;

struct tty_operations___19;

struct tty_ldisc___18;

struct tty_port___19;

struct tty_struct___18 {
	int magic;
	struct kref kref;
	struct device___163 *dev;
	struct tty_driver___19 *driver;
	const struct tty_operations___19 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___18 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___176 *pgrp;
		struct pid___176 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___18 *link;
	struct fasync_struct___199 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___19 *port;
};

struct kiocb___199 {
	struct file___199 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___199 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___94 *ki_waitq;
	};
};

struct iattr___199 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___199 *ia_file;
};

struct dquot___199 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___199 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___199 {
	int qf_fmt_id;
	const struct quota_format_ops___199 *qf_ops;
	struct module___183 *qf_owner;
	struct quota_format_type___199 *qf_next;
};

struct quota_format_ops___199 {
	int (*check_quota_file)(struct super_block___199 *, int);
	int (*read_file_info)(struct super_block___199 *, int);
	int (*write_file_info)(struct super_block___199 *, int);
	int (*free_file_info)(struct super_block___199 *, int);
	int (*read_dqblk)(struct dquot___199 *);
	int (*commit_dqblk)(struct dquot___199 *);
	int (*release_dqblk)(struct dquot___199 *);
	int (*get_next_id)(struct super_block___199 *, struct kqid *);
};

struct dquot_operations___199 {
	int (*write_dquot)(struct dquot___199 *);
	struct dquot___199 * (*alloc_dquot)(struct super_block___199 *, int);
	void (*destroy_dquot)(struct dquot___199 *);
	int (*acquire_dquot)(struct dquot___199 *);
	int (*release_dquot)(struct dquot___199 *);
	int (*mark_dirty)(struct dquot___199 *);
	int (*write_info)(struct super_block___199 *, int);
	qsize_t * (*get_reserved_space)(struct inode___199 *);
	int (*get_projid)(struct inode___199 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___199 *, qsize_t *);
	int (*get_next_id)(struct super_block___199 *, struct kqid *);
};

struct quotactl_ops___199 {
	int (*quota_on)(struct super_block___199 *, int, int, const struct path___199 *);
	int (*quota_off)(struct super_block___199 *, int);
	int (*quota_enable)(struct super_block___199 *, unsigned int);
	int (*quota_disable)(struct super_block___199 *, unsigned int);
	int (*quota_sync)(struct super_block___199 *, int);
	int (*set_info)(struct super_block___199 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___199 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___199 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___199 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___199 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___199 *, unsigned int);
};

struct address_space_operations___199 {
	int (*writepage)(struct page___204 *, struct writeback_control___3 *);
	int (*readpage)(struct file___199 *, struct page___204 *);
	int (*writepages)(struct address_space___199 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___204 *);
	int (*readpages)(struct file___199 *, struct address_space___199 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___199 *, struct address_space___199 *, loff_t, unsigned int, unsigned int, struct page___204 **, void **);
	int (*write_end)(struct file___199 *, struct address_space___199 *, loff_t, unsigned int, unsigned int, struct page___204 *, void *);
	sector_t (*bmap)(struct address_space___199 *, sector_t);
	void (*invalidatepage)(struct page___204 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___204 *, gfp_t);
	void (*freepage)(struct page___204 *);
	ssize_t (*direct_IO)(struct kiocb___199 *, struct iov_iter___120 *);
	int (*migratepage)(struct address_space___199 *, struct page___204 *, struct page___204 *, enum migrate_mode);
	bool (*isolate_page)(struct page___204 *, isolate_mode_t);
	void (*putback_page)(struct page___204 *);
	int (*launder_page)(struct page___204 *);
	int (*is_partially_uptodate)(struct page___204 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___204 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___199 *, struct page___204 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___199 *, sector_t *);
	void (*swap_deactivate)(struct file___199 *);
};

struct bio_vec___118;

struct iov_iter___120 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___118 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___64 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___46 {
	struct kobject___187 kobj;
	struct module___183 *owner;
	const struct file_operations___200 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___199 {
	struct dentry___199 * (*lookup)(struct inode___199 *, struct dentry___199 *, unsigned int);
	const char * (*get_link)(struct dentry___199 *, struct inode___199 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___199 *, int);
	struct posix_acl * (*get_acl)(struct inode___199 *, int, bool);
	int (*readlink)(struct dentry___199 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___199 *, struct dentry___199 *, umode_t, bool);
	int (*link)(struct dentry___199 *, struct inode___199 *, struct dentry___199 *);
	int (*unlink)(struct inode___199 *, struct dentry___199 *);
	int (*symlink)(struct user_namespace *, struct inode___199 *, struct dentry___199 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___199 *, struct dentry___199 *, umode_t);
	int (*rmdir)(struct inode___199 *, struct dentry___199 *);
	int (*mknod)(struct user_namespace *, struct inode___199 *, struct dentry___199 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___199 *, struct dentry___199 *, struct inode___199 *, struct dentry___199 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___199 *, struct iattr___199 *);
	int (*getattr)(struct user_namespace *, const struct path___199 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___199 *, char *, size_t);
	int (*fiemap)(struct inode___199 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___199 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___199 *, struct dentry___199 *, struct file___199 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___199 *, struct dentry___199 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___199 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___199 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___199 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___199 {
	void (*fl_copy_lock)(struct file_lock___199 *, struct file_lock___199 *);
	void (*fl_release_private)(struct file_lock___199 *);
};

struct lock_manager_operations___199;

struct file_lock___199 {
	struct file_lock___199 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___199 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___199 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___199 *fl_ops;
	const struct lock_manager_operations___199 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___199 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___199 *);
	int (*lm_grant)(struct file_lock___199 *, int);
	bool (*lm_break)(struct file_lock___199 *);
	int (*lm_change)(struct file_lock___199 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___199 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___199 *);
};

struct fasync_struct___199 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___199 *fa_next;
	struct file___199 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___199 {
	struct inode___199 * (*alloc_inode)(struct super_block___199 *);
	void (*destroy_inode)(struct inode___199 *);
	void (*free_inode)(struct inode___199 *);
	void (*dirty_inode)(struct inode___199 *, int);
	int (*write_inode)(struct inode___199 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___199 *);
	void (*evict_inode)(struct inode___199 *);
	void (*put_super)(struct super_block___199 *);
	int (*sync_fs)(struct super_block___199 *, int);
	int (*freeze_super)(struct super_block___199 *);
	int (*freeze_fs)(struct super_block___199 *);
	int (*thaw_super)(struct super_block___199 *);
	int (*unfreeze_fs)(struct super_block___199 *);
	int (*statfs)(struct dentry___199 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___199 *, int *, char *);
	void (*umount_begin)(struct super_block___199 *);
	int (*show_options)(struct seq_file___175 *, struct dentry___199 *);
	int (*show_devname)(struct seq_file___175 *, struct dentry___199 *);
	int (*show_path)(struct seq_file___175 *, struct dentry___199 *);
	int (*show_stats)(struct seq_file___175 *, struct dentry___199 *);
	ssize_t (*quota_read)(struct super_block___199 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___199 *, int, const char *, size_t, loff_t);
	struct dquot___199 ** (*get_dquots)(struct inode___199 *);
	long int (*nr_cached_objects)(struct super_block___199 *, struct shrink_control___85 *);
	long int (*free_cached_objects)(struct super_block___199 *, struct shrink_control___85 *);
	struct file___199 * (*real_loop)(struct file___199 *);
};

struct seq_operations___175 {
	void * (*start)(struct seq_file___175 *, loff_t *);
	void (*stop)(struct seq_file___175 *, void *);
	void * (*next)(struct seq_file___175 *, void *, loff_t *);
	int (*show)(struct seq_file___175 *, void *);
};

struct gpio_chip___10;

struct gpio_irq_chip___10 {
	struct irq_chip___41 *chip;
	struct irq_domain___40 *domain;
	const struct irq_domain_ops___40 *domain_ops;
	struct fwnode_handle___163 *fwnode;
	struct irq_domain___40 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___10 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___10 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___10 *, unsigned int);
	struct irq_domain_ops___40 child_irq_domain_ops;
	irq_flow_handler_t___42 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___42 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___10 *);
	void (*init_valid_mask)(struct gpio_chip___10 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___41 *);
	void (*irq_disable)(struct irq_data___41 *);
	void (*irq_unmask)(struct irq_data___41 *);
	void (*irq_mask)(struct irq_data___41 *);
};

struct gpio_chip___10 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___163 *parent;
	struct module___183 *owner;
	int (*request)(struct gpio_chip___10 *, unsigned int);
	void (*free)(struct gpio_chip___10 *, unsigned int);
	int (*get_direction)(struct gpio_chip___10 *, unsigned int);
	int (*direction_input)(struct gpio_chip___10 *, unsigned int);
	int (*direction_output)(struct gpio_chip___10 *, unsigned int, int);
	int (*get)(struct gpio_chip___10 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___10 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___10 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___10 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___10 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___10 *, unsigned int);
	void (*dbg_show)(struct seq_file___175 *, struct gpio_chip___10 *);
	int (*init_valid_mask)(struct gpio_chip___10 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___10 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___10 irq;
	long unsigned int *valid_mask;
	struct device_node___66 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___10 *, const struct of_phandle_args___30 *, u32 *);
};

struct kernel_param_ops___183 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___183 *);
	int (*get)(char *, const struct kernel_param___183 *);
	void (*free)(void *);
};

struct kparam_array___183;

struct kernel_param___183 {
	const char *name;
	struct module___183 *mod;
	const struct kernel_param_ops___183 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___183 *arr;
	};
};

struct kparam_array___183 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___183 *ops;
	void *elem;
};

struct module_attribute___183 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___183 *, struct module_kobject___183 *, char *);
	ssize_t (*store)(struct module_attribute___183 *, struct module_kobject___183 *, const char *, size_t);
	void (*setup)(struct module___183 *, const char *);
	int (*test)(struct module___183 *);
	void (*free)(struct module___183 *);
};

struct regmap_config___8 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___163 *, unsigned int);
	bool (*readable_reg)(struct device___163 *, unsigned int);
	bool (*volatile_reg)(struct device___163 *, unsigned int);
	bool (*precious_reg)(struct device___163 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___163 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___163 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct console___7 {
	char name[16];
	void (*write)(struct console___7 *, const char *, unsigned int);
	int (*read)(struct console___7 *, char *, unsigned int);
	struct tty_driver___19 * (*device)(struct console___7 *, int *);
	void (*unblank)();
	int (*setup)(struct console___7 *, char *);
	int (*exit)(struct console___7 *);
	int (*match)(struct console___7 *, char *, int, char *);
	short int flags;
	short int index;
	int cflag;
	uint ispeed;
	uint ospeed;
	void *data;
	struct console___7 *next;
};

struct tty_driver___19 {
	int magic;
	struct kref kref;
	struct cdev___46 **cdevs;
	struct module___183 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___19 *other;
	struct tty_struct___18 **ttys;
	struct tty_port___19 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___19 *ops;
	struct list_head tty_drivers;
};

struct tty_operations___19 {
	struct tty_struct___18 * (*lookup)(struct tty_driver___19 *, struct file___199 *, int);
	int (*install)(struct tty_driver___19 *, struct tty_struct___18 *);
	void (*remove)(struct tty_driver___19 *, struct tty_struct___18 *);
	int (*open)(struct tty_struct___18 *, struct file___199 *);
	void (*close)(struct tty_struct___18 *, struct file___199 *);
	void (*shutdown)(struct tty_struct___18 *);
	void (*cleanup)(struct tty_struct___18 *);
	int (*write)(struct tty_struct___18 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___18 *, unsigned char);
	void (*flush_chars)(struct tty_struct___18 *);
	unsigned int (*write_room)(struct tty_struct___18 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___18 *);
	int (*ioctl)(struct tty_struct___18 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___18 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___18 *, struct ktermios *);
	void (*throttle)(struct tty_struct___18 *);
	void (*unthrottle)(struct tty_struct___18 *);
	void (*stop)(struct tty_struct___18 *);
	void (*start)(struct tty_struct___18 *);
	void (*hangup)(struct tty_struct___18 *);
	int (*break_ctl)(struct tty_struct___18 *, int);
	void (*flush_buffer)(struct tty_struct___18 *);
	void (*set_ldisc)(struct tty_struct___18 *);
	void (*wait_until_sent)(struct tty_struct___18 *, int);
	void (*send_xchar)(struct tty_struct___18 *, char);
	int (*tiocmget)(struct tty_struct___18 *);
	int (*tiocmset)(struct tty_struct___18 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___18 *, struct winsize *);
	int (*get_icount)(struct tty_struct___18 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___18 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___18 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___18 *, struct seq_file___175 *);
	int (*poll_init)(struct tty_driver___19 *, int, char *);
	int (*poll_get_char)(struct tty_driver___19 *, int);
	void (*poll_put_char)(struct tty_driver___19 *, int, char);
	int (*proc_show)(struct seq_file___175 *, void *);
};

struct tty_port_operations___18;

struct tty_port_client_operations___18;

struct tty_port___19 {
	struct tty_bufhead buf;
	struct tty_struct___18 *tty;
	struct tty_struct___18 *itty;
	const struct tty_port_operations___18 *ops;
	const struct tty_port_client_operations___18 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___18 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___18 *);
	void (*close)(struct tty_struct___18 *);
	void (*flush_buffer)(struct tty_struct___18 *);
	ssize_t (*read)(struct tty_struct___18 *, struct file___199 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___18 *, struct file___199 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___18 *, struct file___199 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___18 *, struct file___199 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___18 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___18 *, struct file___199 *, struct poll_table_struct___131 *);
	int (*hangup)(struct tty_struct___18 *);
	void (*receive_buf)(struct tty_struct___18 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___18 *);
	void (*dcd_change)(struct tty_struct___18 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___18 *, const unsigned char *, const char *, int);
	struct module___183 *owner;
};

struct tty_ldisc___18 {
	struct tty_ldisc_ops___18 *ops;
	struct tty_struct___18 *tty;
};

struct tty_port_operations___18 {
	int (*carrier_raised)(struct tty_port___19 *);
	void (*dtr_rts)(struct tty_port___19 *, int);
	void (*shutdown)(struct tty_port___19 *);
	int (*activate)(struct tty_port___19 *, struct tty_struct___18 *);
	void (*destruct)(struct tty_port___19 *);
};

struct tty_port_client_operations___18 {
	int (*receive_buf)(struct tty_port___19 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___19 *);
};

struct uart_port___4;

struct uart_ops___4 {
	unsigned int (*tx_empty)(struct uart_port___4 *);
	void (*set_mctrl)(struct uart_port___4 *, unsigned int);
	unsigned int (*get_mctrl)(struct uart_port___4 *);
	void (*stop_tx)(struct uart_port___4 *);
	void (*start_tx)(struct uart_port___4 *);
	void (*throttle)(struct uart_port___4 *);
	void (*unthrottle)(struct uart_port___4 *);
	void (*send_xchar)(struct uart_port___4 *, char);
	void (*stop_rx)(struct uart_port___4 *);
	void (*enable_ms)(struct uart_port___4 *);
	void (*break_ctl)(struct uart_port___4 *, int);
	int (*startup)(struct uart_port___4 *);
	void (*shutdown)(struct uart_port___4 *);
	void (*flush_buffer)(struct uart_port___4 *);
	void (*set_termios)(struct uart_port___4 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___4 *, struct ktermios *);
	void (*pm)(struct uart_port___4 *, unsigned int, unsigned int);
	const char * (*type)(struct uart_port___4 *);
	void (*release_port)(struct uart_port___4 *);
	int (*request_port)(struct uart_port___4 *);
	void (*config_port)(struct uart_port___4 *, int);
	int (*verify_port)(struct uart_port___4 *, struct serial_struct *);
	int (*ioctl)(struct uart_port___4 *, unsigned int, long unsigned int);
	int (*poll_init)(struct uart_port___4 *);
	void (*poll_put_char)(struct uart_port___4 *, unsigned char);
	int (*poll_get_char)(struct uart_port___4 *);
};

struct uart_state___4;

struct uart_port___4 {
	spinlock_t lock;
	long unsigned int iobase;
	unsigned char *membase;
	unsigned int (*serial_in)(struct uart_port___4 *, int);
	void (*serial_out)(struct uart_port___4 *, int, int);
	void (*set_termios)(struct uart_port___4 *, struct ktermios *, struct ktermios *);
	void (*set_ldisc)(struct uart_port___4 *, struct ktermios *);
	unsigned int (*get_mctrl)(struct uart_port___4 *);
	void (*set_mctrl)(struct uart_port___4 *, unsigned int);
	unsigned int (*get_divisor)(struct uart_port___4 *, unsigned int, unsigned int *);
	void (*set_divisor)(struct uart_port___4 *, unsigned int, unsigned int, unsigned int);
	int (*startup)(struct uart_port___4 *);
	void (*shutdown)(struct uart_port___4 *);
	void (*throttle)(struct uart_port___4 *);
	void (*unthrottle)(struct uart_port___4 *);
	int (*handle_irq)(struct uart_port___4 *);
	void (*pm)(struct uart_port___4 *, unsigned int, unsigned int);
	void (*handle_break)(struct uart_port___4 *);
	int (*rs485_config)(struct uart_port___4 *, struct serial_rs485 *);
	int (*iso7816_config)(struct uart_port___4 *, struct serial_iso7816 *);
	unsigned int irq;
	long unsigned int irqflags;
	unsigned int uartclk;
	unsigned int fifosize;
	unsigned char x_char;
	unsigned char regshift;
	unsigned char iotype;
	unsigned char quirks;
	unsigned int read_status_mask;
	unsigned int ignore_status_mask;
	struct uart_state___4 *state;
	struct uart_icount icount;
	struct console___7 *cons;
	upf_t flags;
	upstat_t status;
	int hw_stopped;
	unsigned int mctrl;
	unsigned int timeout;
	unsigned int type;
	const struct uart_ops___4 *ops;
	unsigned int custom_divisor;
	unsigned int line;
	unsigned int minor;
	resource_size_t mapbase;
	resource_size_t mapsize;
	struct device___163 *dev;
	long unsigned int sysrq;
	unsigned int sysrq_ch;
	unsigned char has_sysrq;
	unsigned char sysrq_seq;
	unsigned char hub6;
	unsigned char suspended;
	unsigned char console_reinit;
	const char *name;
	struct attribute_group___187 *attr_group;
	const struct attribute_group___187 **tty_groups;
	struct serial_rs485 rs485;
	struct gpio_desc *rs485_term_gpio;
	struct serial_iso7816 iso7816;
	void *private_data;
};

struct uart_state___4 {
	struct tty_port___19 port;
	enum uart_pm_state pm_state;
	struct circ_buf xmit;
	atomic_t refcount;
	wait_queue_head_t remove_wait;
	struct uart_port___4 *uart_port;
};

struct uart_driver___3 {
	struct module___183 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___7 *cons;
	struct uart_state___4 *state;
	struct tty_driver___19 *tty_driver;
};

struct kthread_work___4;

typedef void (*kthread_work_func_t___4)(struct kthread_work___4 *);

struct kthread_worker___4;

struct kthread_work___4 {
	struct list_head node;
	kthread_work_func_t___4 func;
	struct kthread_worker___4 *worker;
	int canceling;
};

struct kthread_worker___4 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___206 *task;
	struct kthread_work___4 *current_work;
};

struct dev_pagemap_ops___194 {
	void (*page_free)(struct page___204 *);
	void (*kill)(struct dev_pagemap___194 *);
	void (*cleanup)(struct dev_pagemap___194 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___194 *);
};

struct bio_vec___118 {
	struct page___204 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct pipe_buf_operations___64;

struct pipe_buffer___64 {
	struct page___204 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___64 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___64 {
	int (*confirm)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
	void (*release)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
	bool (*try_steal)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
	bool (*get)(struct pipe_inode_info___64 *, struct pipe_buffer___64 *);
};

struct ptp_system_timestamp {
	struct timespec64 pre_ts;
	struct timespec64 post_ts;
};

struct spi_statistics {
	spinlock_t lock;
	long unsigned int messages;
	long unsigned int transfers;
	long unsigned int errors;
	long unsigned int timedout;
	long unsigned int spi_sync;
	long unsigned int spi_sync_immediate;
	long unsigned int spi_async;
	long long unsigned int bytes;
	long long unsigned int bytes_rx;
	long long unsigned int bytes_tx;
	long unsigned int transfer_bytes_histo[17];
	long unsigned int transfers_split_maxsize;
};

struct spi_delay {
	u16 value;
	u8 unit;
};

struct spi_controller;

struct spi_device {
	struct device___163 dev;
	struct spi_controller *controller;
	struct spi_controller *master;
	u32 max_speed_hz;
	u8 chip_select;
	u8 bits_per_word;
	bool rt;
	u32 mode;
	int irq;
	void *controller_state;
	void *controller_data;
	char modalias[32];
	const char *driver_override;
	int cs_gpio;
	struct gpio_desc *cs_gpiod;
	struct spi_delay word_delay;
	struct spi_delay cs_setup;
	struct spi_delay cs_hold;
	struct spi_delay cs_inactive;
	struct spi_statistics statistics;
};

struct spi_message;

struct spi_transfer;

struct spi_controller_mem_ops;

struct dma_chan___6;

struct spi_controller {
	struct device___163 dev;
	struct list_head list;
	s16 bus_num;
	u16 num_chipselect;
	u16 dma_alignment;
	u32 mode_bits;
	u32 buswidth_override_bits;
	u32 bits_per_word_mask;
	u32 min_speed_hz;
	u32 max_speed_hz;
	u16 flags;
	bool devm_allocated;
	bool slave;
	size_t (*max_transfer_size)(struct spi_device *);
	size_t (*max_message_size)(struct spi_device *);
	struct mutex io_mutex;
	struct mutex add_lock;
	spinlock_t bus_lock_spinlock;
	struct mutex bus_lock_mutex;
	bool bus_lock_flag;
	int (*setup)(struct spi_device *);
	int (*set_cs_timing)(struct spi_device *);
	int (*transfer)(struct spi_device *, struct spi_message *);
	void (*cleanup)(struct spi_device *);
	bool (*can_dma)(struct spi_controller *, struct spi_device *, struct spi_transfer *);
	struct device___163 *dma_map_dev;
	bool queued;
	struct kthread_worker___4 *kworker;
	struct kthread_work___4 pump_messages;
	spinlock_t queue_lock;
	struct list_head queue;
	struct spi_message *cur_msg;
	bool idling;
	bool busy;
	bool running;
	bool rt;
	bool auto_runtime_pm;
	bool cur_msg_prepared;
	bool cur_msg_mapped;
	bool last_cs_enable;
	bool last_cs_mode_high;
	bool fallback;
	struct completion xfer_completion;
	size_t max_dma_len;
	int (*prepare_transfer_hardware)(struct spi_controller *);
	int (*transfer_one_message)(struct spi_controller *, struct spi_message *);
	int (*unprepare_transfer_hardware)(struct spi_controller *);
	int (*prepare_message)(struct spi_controller *, struct spi_message *);
	int (*unprepare_message)(struct spi_controller *, struct spi_message *);
	int (*slave_abort)(struct spi_controller *);
	void (*set_cs)(struct spi_device *, bool);
	int (*transfer_one)(struct spi_controller *, struct spi_device *, struct spi_transfer *);
	void (*handle_err)(struct spi_controller *, struct spi_message *);
	const struct spi_controller_mem_ops *mem_ops;
	int *cs_gpios;
	struct gpio_desc **cs_gpiods;
	bool use_gpio_descriptors;
	s8 unused_native_cs;
	s8 max_native_cs;
	struct spi_statistics statistics;
	struct dma_chan___6 *dma_tx;
	struct dma_chan___6 *dma_rx;
	void *dummy_rx;
	void *dummy_tx;
	int (*fw_translate_cs)(struct spi_controller *, unsigned int);
	bool ptp_sts_supported;
	long unsigned int irq_flags;
};

struct spi_driver {
	const struct spi_device_id *id_table;
	int (*probe)(struct spi_device *);
	int (*remove)(struct spi_device *);
	void (*shutdown)(struct spi_device *);
	struct device_driver___163 driver;
};

struct spi_message {
	struct list_head transfers;
	struct spi_device *spi;
	unsigned int is_dma_mapped: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	void (*complete)(void *);
	void *context;
	unsigned int frame_length;
	unsigned int actual_length;
	int status;
	struct list_head queue;
	void *state;
	struct list_head resources;
};

struct spi_transfer {
	const void *tx_buf;
	void *rx_buf;
	unsigned int len;
	dma_addr_t tx_dma;
	dma_addr_t rx_dma;
	struct sg_table tx_sg;
	struct sg_table rx_sg;
	unsigned int dummy_data: 1;
	unsigned int cs_change: 1;
	unsigned int tx_nbits: 3;
	unsigned int rx_nbits: 3;
	long: 5;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 bits_per_word;
	struct spi_delay delay;
	struct spi_delay cs_change_delay;
	struct spi_delay word_delay;
	u32 speed_hz;
	u32 effective_speed_hz;
	unsigned int ptp_sts_word_pre;
	unsigned int ptp_sts_word_post;
	struct ptp_system_timestamp *ptp_sts;
	bool timestamped;
	struct list_head transfer_list;
	u16 error;
};

struct spi_mem;

struct spi_mem_op;

struct spi_mem_dirmap_desc;

struct spi_controller_mem_ops {
	int (*adjust_op_size)(struct spi_mem *, struct spi_mem_op *);
	bool (*supports_op)(struct spi_mem *, const struct spi_mem_op *);
	int (*exec_op)(struct spi_mem *, const struct spi_mem_op *);
	const char * (*get_name)(struct spi_mem *);
	int (*dirmap_create)(struct spi_mem_dirmap_desc *);
	void (*dirmap_destroy)(struct spi_mem_dirmap_desc *);
	ssize_t (*dirmap_read)(struct spi_mem_dirmap_desc *, u64, size_t, void *);
	ssize_t (*dirmap_write)(struct spi_mem_dirmap_desc *, u64, size_t, const void *);
	int (*poll_status)(struct spi_mem *, const struct spi_mem_op *, u16, u16, long unsigned int, long unsigned int, long unsigned int);
};

struct max310x_devtype {
	char name[9];
	int nr;
	u8 mode1;
	int (*detect)(struct device___163 *);
	void (*power)(struct uart_port___4 *, int);
};

struct max310x_one {
	struct uart_port___4 port;
	struct work_struct tx_work;
	struct work_struct md_work;
	struct work_struct rs_work;
	u8 wr_header;
	u8 rd_header;
	u8 rx_buf[128];
};

struct max310x_port {
	const struct max310x_devtype *devtype;
	struct regmap *regmap;
	struct clk *clk;
	struct gpio_chip___10 gpio;
	struct max310x_one p[0];
};

struct dma_router___6 {
	struct device___163 *dev;
	void (*route_free)(struct device___163 *, void *);
};

struct dma_device___6;

struct dma_chan_dev___6;

struct dma_chan___7 {
	struct dma_device___6 *device;
	struct device___163 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___6 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___6 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___6)(struct dma_chan___7 *, void *);

struct dma_filter___6 {
	dma_filter_fn___6 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___6;

struct dma_device___6 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___6 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___163 *dev;
	struct module___183 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___7 *);
	int (*device_router_config)(struct dma_chan___7 *);
	void (*device_free_chan_resources)(struct dma_chan___7 *);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memcpy)(struct dma_chan___7 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_xor)(struct dma_chan___7 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_xor_val)(struct dma_chan___7 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_pq)(struct dma_chan___7 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_pq_val)(struct dma_chan___7 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memset)(struct dma_chan___7 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_memset_sg)(struct dma_chan___7 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_interrupt)(struct dma_chan___7 *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_slave_sg)(struct dma_chan___7 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_cyclic)(struct dma_chan___7 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_interleaved_dma)(struct dma_chan___7 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___6 * (*device_prep_dma_imm_data)(struct dma_chan___7 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___7 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___7 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___7 *);
	int (*device_resume)(struct dma_chan___7 *);
	int (*device_terminate_all)(struct dma_chan___7 *);
	void (*device_synchronize)(struct dma_chan___7 *);
	enum dma_status (*device_tx_status)(struct dma_chan___7 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___7 *);
	void (*device_release)(struct dma_device___6 *);
	void (*dbg_summary_show)(struct seq_file___175 *, struct dma_device___6 *);
	struct dentry___199 *dbg_dev_root;
};

struct dma_chan_dev___6 {
	struct dma_chan___7 *chan;
	struct device___163 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___6 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___163 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___6 {
	int (*attach)(struct dma_async_tx_descriptor___6 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___6 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___6 *, size_t);
};

struct dma_async_tx_descriptor___6 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___7 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___6 *);
	int (*desc_free)(struct dma_async_tx_descriptor___6 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___6 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___6 *metadata_ops;
	struct dma_async_tx_descriptor___6 *next;
	struct dma_async_tx_descriptor___6 *parent;
	spinlock_t lock;
};

enum imx_uart_type {
	IMX1_UART = 0,
	IMX21_UART = 1,
	IMX53_UART = 2,
	IMX6Q_UART = 3,
};

struct imx_uart_data {
	unsigned int uts_reg;
	enum imx_uart_type devtype;
};

enum imx_tx_state {
	OFF = 0,
	WAIT_AFTER_RTS = 1,
	SEND = 2,
	WAIT_AFTER_SEND = 3,
};

struct imx_port {
	struct uart_port___4 port;
	struct timer_list timer;
	unsigned int old_status;
	unsigned int have_rtscts: 1;
	unsigned int have_rtsgpio: 1;
	unsigned int dte_mode: 1;
	unsigned int inverted_tx: 1;
	unsigned int inverted_rx: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clk *clk_ipg;
	struct clk *clk_per;
	const struct imx_uart_data *devdata;
	struct mctrl_gpios *gpios;
	unsigned int ucr1;
	unsigned int ucr2;
	unsigned int ucr3;
	unsigned int ucr4;
	unsigned int ufcr;
	unsigned int dma_is_enabled: 1;
	unsigned int dma_is_rxing: 1;
	unsigned int dma_is_txing: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dma_chan___7 *dma_chan_rx;
	struct dma_chan___7 *dma_chan_tx;
	struct scatterlist rx_sgl;
	struct scatterlist tx_sgl[2];
	void *rx_buf;
	struct circ_buf rx_ring;
	unsigned int rx_buf_size;
	unsigned int rx_period_length;
	unsigned int rx_periods;
	dma_cookie_t rx_cookie;
	unsigned int tx_bytes;
	unsigned int dma_tx_nents;
	unsigned int saved_reg[10];
	bool context_saved;
	enum imx_tx_state tx_state;
	struct hrtimer trigger_start_tx;
	struct hrtimer trigger_stop_tx;
};

struct imx_port_ucrs {
	unsigned int ucr1;
	unsigned int ucr2;
	unsigned int ucr3;
};

struct uart_driver___4 {
	struct module___180 *owner;
	const char *driver_name;
	const char *dev_name;
	int major;
	int minor;
	int nr;
	struct console___2 *cons;
	struct uart_state___2 *state;
	struct tty_driver___2 *tty_driver;
};

struct sccnxp_pdata {
	const u8 reg_shift;
	const u32 mctrl_cfg[2];
	const unsigned int poll_time_us;
};

struct sccnxp_chip {
	const char *name;
	unsigned int nr;
	long unsigned int freq_min;
	long unsigned int freq_std;
	long unsigned int freq_max;
	unsigned int flags;
	unsigned int fifosize;
	unsigned int trwd;
};

struct sccnxp_port {
	struct uart_driver uart;
	struct uart_port___3 port[2];
	bool opened[2];
	int irq;
	u8 imr;
	struct sccnxp_chip *chip;
	struct console___6 console;
	spinlock_t lock;
	bool poll;
	struct timer_list timer;
	struct sccnxp_pdata pdata;
	struct regulator *regulator;
};

enum {
	UARTDM_1P1 = 1,
	UARTDM_1P2 = 2,
	UARTDM_1P3 = 3,
	UARTDM_1P4 = 4,
};

struct msm_dma {
	struct dma_chan___5 *chan;
	enum dma_data_direction dir;
	dma_addr_t phys;
	unsigned char *virt;
	dma_cookie_t cookie;
	u32 enable_bit;
	unsigned int count;
	struct dma_async_tx_descriptor___5 *desc;
};

struct msm_port {
	struct uart_port___2 uart;
	char name[16];
	struct clk *clk;
	struct clk *pclk;
	unsigned int imr;
	int is_uartdm;
	unsigned int old_snap_state;
	bool break_detected;
	struct msm_dma tx_dma;
	struct msm_dma rx_dma;
};

struct msm_baud_map {
	u16 divisor;
	u8 code;
	u8 rxstale;
};

struct tegra_tcu {
	struct uart_driver___4 driver;
	struct console___2 console;
	struct uart_port___2 port;
	struct mbox_client___4 tx_client;
	struct mbox_client___4 rx_client;
	struct mbox_chan___2 *tx;
	struct mbox_chan___2 *rx;
};

enum {
	UART_IRQ_SUM = 0,
	UART_RX_IRQ = 0,
	UART_TX_IRQ = 1,
	UART_IRQ_COUNT = 2,
};

struct uart_regs_layout {
	unsigned int rbr;
	unsigned int tsh;
	unsigned int ctrl;
	unsigned int intr;
};

struct uart_flags {
	unsigned int ctrl_tx_rdy_int;
	unsigned int ctrl_rx_rdy_int;
	unsigned int stat_tx_rdy;
	unsigned int stat_rx_rdy;
};

struct mvebu_uart_driver_data {
	bool is_ext;
	struct uart_regs_layout regs;
	struct uart_flags flags;
};

struct mvebu_uart_pm_regs {
	unsigned int rbr;
	unsigned int tsh;
	unsigned int ctrl;
	unsigned int intr;
	unsigned int stat;
	unsigned int brdv;
	unsigned int osamp;
};

struct mvebu_uart {
	struct uart_port___4 *port;
	struct clk *clk;
	int irq[2];
	struct mvebu_uart_driver_data *data;
	struct mvebu_uart_pm_regs pm_regs;
};

struct owl_uart_info {
	unsigned int tx_fifosize;
};

struct owl_uart_port {
	struct uart_port___2 port;
	struct clk *clk;
};

struct gpio_array___4;

struct mctrl_gpios___2 {
	struct uart_port___2 *port;
	struct gpio_desc *gpio[6];
	int irq[6];
	unsigned int mctrl_prev;
	bool mctrl_on;
};

typedef unsigned char unchar;

struct kgdb_nmi_tty_priv {
	struct tty_port___2 port;
	struct timer_list timer;
	struct {
		union {
			struct __kfifo kfifo;
			char *type;
			const char *const_type;
			char (*rectype)[0];
			char *ptr;
			const char *ptr_const;
		};
		char buf[64];
	} fifo;
};

struct kgdb_io___2 {
	const char *name;
	int (*read_char)();
	void (*write_char)(u8);
	void (*flush)();
	int (*init)();
	void (*deinit)();
	void (*pre_exception)();
	void (*post_exception)();
	struct console___7 *cons;
};

struct device_attribute___17 {
	struct attribute attr;
	ssize_t (*show)(struct device___154 *, struct device_attribute___17 *, char *);
	ssize_t (*store)(struct device___154 *, struct device_attribute___17 *, const char *, size_t);
};

struct serdev_device;

struct serdev_device_ops {
	int (*receive_buf)(struct serdev_device *, const unsigned char *, size_t);
	void (*write_wakeup)(struct serdev_device *);
};

struct serdev_controller;

struct serdev_device {
	struct device___154 dev;
	int nr;
	struct serdev_controller *ctrl;
	const struct serdev_device_ops *ops;
	struct completion write_comp;
	struct mutex write_lock;
};

struct serdev_controller_ops;

struct serdev_controller {
	struct device___154 dev;
	unsigned int nr;
	struct serdev_device *serdev;
	const struct serdev_controller_ops *ops;
};

struct serdev_device_driver {
	struct device_driver___154 driver;
	int (*probe)(struct serdev_device *);
	void (*remove)(struct serdev_device *);
};

enum serdev_parity {
	SERDEV_PARITY_NONE = 0,
	SERDEV_PARITY_EVEN = 1,
	SERDEV_PARITY_ODD = 2,
};

struct serdev_controller_ops {
	int (*write_buf)(struct serdev_controller *, const unsigned char *, size_t);
	void (*write_flush)(struct serdev_controller *);
	int (*write_room)(struct serdev_controller *);
	int (*open)(struct serdev_controller *);
	void (*close)(struct serdev_controller *);
	void (*set_flow_control)(struct serdev_controller *, bool);
	int (*set_parity)(struct serdev_controller *, enum serdev_parity);
	unsigned int (*set_baudrate)(struct serdev_controller *, unsigned int);
	void (*wait_until_sent)(struct serdev_controller *, long int);
	int (*get_tiocm)(struct serdev_controller *);
	int (*set_tiocm)(struct serdev_controller *, unsigned int, unsigned int);
};

struct acpi_serdev_lookup {
	acpi_handle device_handle;
	acpi_handle controller_handle;
	int n;
	int index;
};

struct serdev_device___2;

struct serdev_device_ops___2 {
	int (*receive_buf)(struct serdev_device___2 *, const unsigned char *, size_t);
	void (*write_wakeup)(struct serdev_device___2 *);
};

struct serdev_controller___2;

struct serdev_device___2 {
	struct device___12 dev;
	int nr;
	struct serdev_controller___2 *ctrl;
	const struct serdev_device_ops___2 *ops;
	struct completion write_comp;
	struct mutex write_lock;
};

struct serdev_controller_ops___2;

struct serdev_controller___2 {
	struct device___12 dev;
	unsigned int nr;
	struct serdev_device___2 *serdev;
	const struct serdev_controller_ops___2 *ops;
};

struct serdev_controller_ops___2 {
	int (*write_buf)(struct serdev_controller___2 *, const unsigned char *, size_t);
	void (*write_flush)(struct serdev_controller___2 *);
	int (*write_room)(struct serdev_controller___2 *);
	int (*open)(struct serdev_controller___2 *);
	void (*close)(struct serdev_controller___2 *);
	void (*set_flow_control)(struct serdev_controller___2 *, bool);
	int (*set_parity)(struct serdev_controller___2 *, enum serdev_parity);
	unsigned int (*set_baudrate)(struct serdev_controller___2 *, unsigned int);
	void (*wait_until_sent)(struct serdev_controller___2 *, long int);
	int (*get_tiocm)(struct serdev_controller___2 *);
	int (*set_tiocm)(struct serdev_controller___2 *, unsigned int, unsigned int);
};

struct serport {
	struct tty_port___2 *port;
	struct tty_struct *tty;
	struct tty_driver___2 *tty_drv;
	int tty_idx;
	long unsigned int flags;
};

struct fs_context___32;

struct fs_parameter_spec___21;

struct dentry___200;

struct super_block___200;

struct module___184;

struct file_system_type___200 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___32 *);
	const struct fs_parameter_spec___21 *parameters;
	struct dentry___200 * (*mount)(struct file_system_type___200 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___200 *);
	struct module___184 *owner;
	struct file_system_type___200 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___200;

struct kiocb___200;

struct iov_iter___121;

struct vm_area_struct___205;

struct inode___200;

struct file_lock___200;

struct page___205;

struct pipe_inode_info___65;

struct seq_file___176;

struct file_operations___201 {
	struct module___184 *owner;
	loff_t (*llseek)(struct file___200 *, loff_t, int);
	ssize_t (*read)(struct file___200 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___200 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___200 *, struct iov_iter___121 *);
	ssize_t (*write_iter)(struct kiocb___200 *, struct iov_iter___121 *);
	int (*iopoll)(struct kiocb___200 *, bool);
	int (*iterate)(struct file___200 *, struct dir_context *);
	int (*iterate_shared)(struct file___200 *, struct dir_context *);
	__poll_t (*poll)(struct file___200 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___200 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___200 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___200 *, struct vm_area_struct___205 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___200 *, struct file___200 *);
	int (*flush)(struct file___200 *, fl_owner_t);
	int (*release)(struct inode___200 *, struct file___200 *);
	int (*fsync)(struct file___200 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___200 *, int);
	int (*lock)(struct file___200 *, int, struct file_lock___200 *);
	ssize_t (*sendpage)(struct file___200 *, struct page___205 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___200 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___200 *, long unsigned int);
	int (*flock)(struct file___200 *, int, struct file_lock___200 *);
	ssize_t (*splice_write)(struct pipe_inode_info___65 *, struct file___200 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___200 *, loff_t *, struct pipe_inode_info___65 *, size_t, unsigned int);
	int (*setlease)(struct file___200 *, long int, struct file_lock___200 **, void **);
	long int (*fallocate)(struct file___200 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___176 *, struct file___200 *);
	ssize_t (*copy_file_range)(struct file___200 *, loff_t, struct file___200 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___200 *, loff_t, struct file___200 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___200 *, loff_t, loff_t, int);
};

struct vmacache___205 {
	u64 seqnum;
	struct vm_area_struct___205 *vmas[4];
};

struct page_frag___205 {
	struct page___205 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___206;

struct pid___177;

struct nsproxy___186;

struct signal_struct___201;

struct bio_list___102;

struct backing_dev_info___95;

struct io_context___102;

struct css_set___137;

struct mem_cgroup___86;

struct request_queue___102;

struct vm_struct___183;

struct task_struct___207 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___207 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___206 *mm;
	struct mm_struct___206 *active_mm;
	struct vmacache___205 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___207 *real_parent;
	struct task_struct___207 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___207 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___177 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___186 *nsproxy;
	struct signal_struct___201 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___207 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___102 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___95 *backing_dev_info;
	struct io_context___102 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___137 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___65 *splice_pipe;
	struct page_frag___205 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___86 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___86 *active_memcg;
	struct request_queue___102 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___207 *oom_reaper_list;
	struct vm_struct___183 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___188;

struct kobj_type___188;

struct kernfs_node___188;

struct kobject___188 {
	const char *name;
	struct list_head entry;
	struct kobject___188 *parent;
	struct kset___188 *kset;
	struct kobj_type___188 *ktype;
	struct kernfs_node___188 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___184 {
	struct kobject___188 kobj;
	struct module___184 *mod;
	struct kobject___188 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___184 {
	struct module___184 *mod;
	struct latch_tree_node node;
};

struct module_layout___184 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___184 mtn;
};

struct module_attribute___184;

struct kernel_param___184;

struct module___184 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___184 mkobj;
	struct module_attribute___184 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___188 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___184 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___184 core_layout;
	struct module_layout___184 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___205 *pgtable_t___205;

struct address_space___200;

struct dev_pagemap___195;

struct page___205 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___200 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___54 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___205 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___205 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___206 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___195 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___195;

struct vm_area_struct___205 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___205 *vm_next;
	struct vm_area_struct___205 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___206 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___195 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___200 *vm_file;
	struct file___200 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___205;

struct mm_struct___206 {
	struct {
		struct vm_area_struct___205 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___200 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___205 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___207 *owner;
		struct user_namespace___25 *user_ns;
		struct file___200 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___200;

struct address_space___200 {
	struct inode___200 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___200 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___195;

struct dev_pagemap___195 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___195 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___200;

struct path___200 {
	struct vfsmount___200 *mnt;
	struct dentry___200 *dentry;
};

struct fown_struct___177 {
	rwlock_t lock;
	struct pid___177 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___200 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___200 f_path;
	struct inode___200 *f_inode;
	const struct file_operations___201 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___177 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___200 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___195;

struct vm_operations_struct___195 {
	void (*open)(struct vm_area_struct___205 *);
	void (*close)(struct vm_area_struct___205 *);
	int (*may_split)(struct vm_area_struct___205 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___205 *);
	int (*mprotect)(struct vm_area_struct___205 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___195 *);
	vm_fault_t (*huge_fault)(struct vm_fault___195 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___195 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___205 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___195 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___195 *);
	int (*access)(struct vm_area_struct___205 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___205 *);
	int (*set_policy)(struct vm_area_struct___205 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___205 *, long unsigned int);
	struct page___205 * (*find_special_page)(struct vm_area_struct___205 *, long unsigned int);
};

struct core_thread___205 {
	struct task_struct___207 *task;
	struct core_thread___205 *next;
};

struct core_state___205 {
	atomic_t nr_threads;
	struct core_thread___205 dumper;
	struct completion startup;
};

struct vm_fault___195 {
	const struct {
		struct vm_area_struct___205 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___205 *cow_page;
	struct page___205 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___205 prealloc_pte;
};

struct pglist_data___93;

struct lruvec___93 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___93 *pgdat;
};

struct zone___93 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___93 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___93 {
	struct zone___93 *zone;
	int zone_idx;
};

struct zonelist___93 {
	struct zoneref___93 _zonerefs[321];
};

struct pglist_data___93 {
	struct zone___93 node_zones[5];
	struct zonelist___93 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___207 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___207 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___93 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___86 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___86 *memcg;
};

struct cgroup___137;

struct cgroup_subsys___137;

struct cgroup_subsys_state___137 {
	struct cgroup___137 *cgroup;
	struct cgroup_subsys___137 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___137 *parent;
};

struct cgroup_file___137 {
	struct kernfs_node___188 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___86;

struct mem_cgroup_per_node___86;

struct mem_cgroup___86 {
	struct cgroup_subsys_state___137 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___137 events_file;
	struct cgroup_file___137 events_local_file;
	struct cgroup_file___137 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___86 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___207 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___86 *nodeinfo[0];
	long: 64;
};

struct shrinker___86 {
	long unsigned int (*count_objects)(struct shrinker___86 *, struct shrink_control___86 *);
	long unsigned int (*scan_objects)(struct shrinker___86 *, struct shrink_control___86 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___195 {
	void (*page_free)(struct page___205 *);
	void (*kill)(struct dev_pagemap___195 *);
	void (*cleanup)(struct dev_pagemap___195 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___195 *);
};

struct pid_namespace___177;

struct upid___177 {
	int nr;
	struct pid_namespace___177 *ns;
};

struct pid_namespace___177 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___207 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___177 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___177 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___177 numbers[1];
};

struct tty_struct___19;

struct signal_struct___201 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___207 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___207 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___177 *pids[4];
	struct pid___177 *tty_old_pgrp;
	int leader;
	struct tty_struct___19 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___206 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___137;

struct nsproxy___186 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___177 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___137 *cgroup_ns;
};

struct bio___102;

struct bio_list___102 {
	struct bio___102 *head;
	struct bio___102 *tail;
};

struct bdi_writeback___95 {
	struct backing_dev_info___95 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___137 *memcg_css;
	struct cgroup_subsys_state___137 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___164;

struct backing_dev_info___95 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___95 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___164 *dev;
	char dev_name[64];
	struct device___164 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___200 *debug_dir;
};

struct io_cq___102;

struct io_context___102 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___102 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___137 {
	struct cgroup_subsys_state___137 *subsys[14];
	refcount_t refcount;
	struct css_set___137 *dom_cset;
	struct cgroup___137 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___137 *mg_src_cgrp;
	struct cgroup___137 *mg_dst_cgrp;
	struct css_set___137 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___200;

struct pipe_buffer___65;

struct pipe_inode_info___65 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___205 *tmp_page;
	struct fasync_struct___200 *fasync_readers;
	struct fasync_struct___200 *fasync_writers;
	struct pipe_buffer___65 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___102;

struct blk_integrity___102 {
	const struct blk_integrity_profile___102 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___102 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___102 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___102;

struct elevator_queue___102;

struct blk_mq_ops___99;

struct blk_mq_hw_ctx___99;

struct gendisk___103;

struct blkcg_gq___97;

struct blk_mq_tag_set___99;

struct request_queue___102 {
	struct request___102 *last_merge;
	struct elevator_queue___102 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___99 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___99 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___103 *disk;
	struct kobject___188 kobj;
	struct kobject___188 *mq_kobj;
	struct blk_integrity___102 integrity;
	struct device___164 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___97 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___99 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___102 bio_split;
	struct dentry___200 *debugfs_dir;
	struct dentry___200 *sched_debugfs_dir;
	struct dentry___200 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___183 {
	struct vm_struct___183 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___205 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___200;

struct dentry___200 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___200 *d_parent;
	struct qstr d_name;
	struct inode___200 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___200 *d_op;
	struct super_block___200 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___200;

struct cdev___47;

struct inode___200 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___200 *i_op;
	struct super_block___200 *i_sb;
	struct address_space___200 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___95 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___201 *i_fop;
		void (*free_inode)(struct inode___200 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___200 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___65 *i_pipe;
		struct cdev___47 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___200 {
	int (*d_revalidate)(struct dentry___200 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___200 *, unsigned int);
	int (*d_hash)(const struct dentry___200 *, struct qstr *);
	int (*d_compare)(const struct dentry___200 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___200 *);
	int (*d_init)(struct dentry___200 *);
	void (*d_release)(struct dentry___200 *);
	void (*d_prune)(struct dentry___200 *);
	void (*d_iput)(struct dentry___200 *, struct inode___200 *);
	char * (*d_dname)(struct dentry___200 *, char *, int);
	struct vfsmount___200 * (*d_automount)(struct path___200 *);
	int (*d_manage)(const struct path___200 *, bool);
	struct dentry___200 * (*d_real)(struct dentry___200 *, const struct inode___200 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___200;

struct mem_dqinfo___200 {
	struct quota_format_type___200 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___200;

struct quota_info___200 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___200 *files[3];
	struct mem_dqinfo___200 info[3];
	const struct quota_format_ops___200 *ops[3];
};

struct rcuwait___201 {
	struct task_struct___207 *task;
};

struct percpu_rw_semaphore___201 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___201 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___200 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___201 rw_sem[3];
};

struct super_operations___200;

struct dquot_operations___200;

struct quotactl_ops___200;

struct xattr_handler___24;

struct block_device___103;

struct super_block___200 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___200 *s_type;
	const struct super_operations___200 *s_op;
	const struct dquot_operations___200 *dq_op;
	const struct quotactl_ops___200 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___200 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___24 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___103 *s_bdev;
	struct backing_dev_info___95 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___200 s_dquot;
	struct sb_writers___200 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___200 *s_d_op;
	int cleancache_poolid;
	struct shrinker___86 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___200 {
	struct dentry___200 *mnt_root;
	struct super_block___200 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct psi_group___137 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___207 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___137;

struct cgroup_rstat_cpu___137;

struct cgroup___137 {
	struct cgroup_subsys_state___137 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___188 *kn;
	struct cgroup_file___137 procs_file;
	struct cgroup_file___137 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___137 *subsys[14];
	struct cgroup_root___137 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___137 *dom_cgrp;
	struct cgroup___137 *old_dom_cgrp;
	struct cgroup_rstat_cpu___137 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___137 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct tty_driver___20;

struct tty_operations___20;

struct tty_ldisc___19;

struct tty_port___20;

struct tty_struct___19 {
	int magic;
	struct kref kref;
	struct device___164 *dev;
	struct tty_driver___20 *driver;
	const struct tty_operations___20 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___19 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___177 *pgrp;
		struct pid___177 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___19 *link;
	struct fasync_struct___200 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___20 *port;
};

struct io_cq___102 {
	struct request_queue___102 *q;
	struct io_context___102 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___95;

struct kiocb___200 {
	struct file___200 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___200 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___95 *ki_waitq;
	};
};

struct iattr___200 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___200 *ia_file;
};

struct dquot___200 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___200 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___200 {
	int qf_fmt_id;
	const struct quota_format_ops___200 *qf_ops;
	struct module___184 *qf_owner;
	struct quota_format_type___200 *qf_next;
};

struct quota_format_ops___200 {
	int (*check_quota_file)(struct super_block___200 *, int);
	int (*read_file_info)(struct super_block___200 *, int);
	int (*write_file_info)(struct super_block___200 *, int);
	int (*free_file_info)(struct super_block___200 *, int);
	int (*read_dqblk)(struct dquot___200 *);
	int (*commit_dqblk)(struct dquot___200 *);
	int (*release_dqblk)(struct dquot___200 *);
	int (*get_next_id)(struct super_block___200 *, struct kqid *);
};

struct dquot_operations___200 {
	int (*write_dquot)(struct dquot___200 *);
	struct dquot___200 * (*alloc_dquot)(struct super_block___200 *, int);
	void (*destroy_dquot)(struct dquot___200 *);
	int (*acquire_dquot)(struct dquot___200 *);
	int (*release_dquot)(struct dquot___200 *);
	int (*mark_dirty)(struct dquot___200 *);
	int (*write_info)(struct super_block___200 *, int);
	qsize_t * (*get_reserved_space)(struct inode___200 *);
	int (*get_projid)(struct inode___200 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___200 *, qsize_t *);
	int (*get_next_id)(struct super_block___200 *, struct kqid *);
};

struct quotactl_ops___200 {
	int (*quota_on)(struct super_block___200 *, int, int, const struct path___200 *);
	int (*quota_off)(struct super_block___200 *, int);
	int (*quota_enable)(struct super_block___200 *, unsigned int);
	int (*quota_disable)(struct super_block___200 *, unsigned int);
	int (*quota_sync)(struct super_block___200 *, int);
	int (*set_info)(struct super_block___200 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___200 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___200 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___200 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___200 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___200 *, unsigned int);
};

struct wait_page_queue___95 {
	struct page___205 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___95;

struct readahead_control___95;

struct swap_info_struct___54;

struct address_space_operations___200 {
	int (*writepage)(struct page___205 *, struct writeback_control___95 *);
	int (*readpage)(struct file___200 *, struct page___205 *);
	int (*writepages)(struct address_space___200 *, struct writeback_control___95 *);
	int (*set_page_dirty)(struct page___205 *);
	int (*readpages)(struct file___200 *, struct address_space___200 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___95 *);
	int (*write_begin)(struct file___200 *, struct address_space___200 *, loff_t, unsigned int, unsigned int, struct page___205 **, void **);
	int (*write_end)(struct file___200 *, struct address_space___200 *, loff_t, unsigned int, unsigned int, struct page___205 *, void *);
	sector_t (*bmap)(struct address_space___200 *, sector_t);
	void (*invalidatepage)(struct page___205 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___205 *, gfp_t);
	void (*freepage)(struct page___205 *);
	ssize_t (*direct_IO)(struct kiocb___200 *, struct iov_iter___121 *);
	int (*migratepage)(struct address_space___200 *, struct page___205 *, struct page___205 *, enum migrate_mode);
	bool (*isolate_page)(struct page___205 *, isolate_mode_t);
	void (*putback_page)(struct page___205 *);
	int (*launder_page)(struct page___205 *);
	int (*is_partially_uptodate)(struct page___205 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___205 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___200 *, struct page___205 *);
	int (*swap_activate)(struct swap_info_struct___54 *, struct file___200 *, sector_t *);
	void (*swap_deactivate)(struct file___200 *);
};

struct writeback_control___95 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___95 *wb;
	struct inode___200 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___95 {
	struct file___200 *file;
	struct address_space___200 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___119;

struct iov_iter___121 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___119 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___65 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___54 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___103 *bdev;
	struct file___200 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___47 {
	struct kobject___188 kobj;
	struct module___184 *owner;
	const struct file_operations___201 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___200 {
	struct dentry___200 * (*lookup)(struct inode___200 *, struct dentry___200 *, unsigned int);
	const char * (*get_link)(struct dentry___200 *, struct inode___200 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___200 *, int);
	struct posix_acl * (*get_acl)(struct inode___200 *, int, bool);
	int (*readlink)(struct dentry___200 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___200 *, struct dentry___200 *, umode_t, bool);
	int (*link)(struct dentry___200 *, struct inode___200 *, struct dentry___200 *);
	int (*unlink)(struct inode___200 *, struct dentry___200 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___200 *, struct dentry___200 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___200 *, struct dentry___200 *, umode_t);
	int (*rmdir)(struct inode___200 *, struct dentry___200 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___200 *, struct dentry___200 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___200 *, struct dentry___200 *, struct inode___200 *, struct dentry___200 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___200 *, struct iattr___200 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___200 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___200 *, char *, size_t);
	int (*fiemap)(struct inode___200 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___200 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___200 *, struct dentry___200 *, struct file___200 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___200 *, struct dentry___200 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___200 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___200 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___200 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___200 {
	void (*fl_copy_lock)(struct file_lock___200 *, struct file_lock___200 *);
	void (*fl_release_private)(struct file_lock___200 *);
};

struct lock_manager_operations___200;

struct file_lock___200 {
	struct file_lock___200 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___200 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___200 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___200 *fl_ops;
	const struct lock_manager_operations___200 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___200 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___200 *);
	int (*lm_grant)(struct file_lock___200 *, int);
	bool (*lm_break)(struct file_lock___200 *);
	int (*lm_change)(struct file_lock___200 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___200 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___200 *);
};

struct fasync_struct___200 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___200 *fa_next;
	struct file___200 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___200 {
	struct inode___200 * (*alloc_inode)(struct super_block___200 *);
	void (*destroy_inode)(struct inode___200 *);
	void (*free_inode)(struct inode___200 *);
	void (*dirty_inode)(struct inode___200 *, int);
	int (*write_inode)(struct inode___200 *, struct writeback_control___95 *);
	int (*drop_inode)(struct inode___200 *);
	void (*evict_inode)(struct inode___200 *);
	void (*put_super)(struct super_block___200 *);
	int (*sync_fs)(struct super_block___200 *, int);
	int (*freeze_super)(struct super_block___200 *);
	int (*freeze_fs)(struct super_block___200 *);
	int (*thaw_super)(struct super_block___200 *);
	int (*unfreeze_fs)(struct super_block___200 *);
	int (*statfs)(struct dentry___200 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___200 *, int *, char *);
	void (*umount_begin)(struct super_block___200 *);
	int (*show_options)(struct seq_file___176 *, struct dentry___200 *);
	int (*show_devname)(struct seq_file___176 *, struct dentry___200 *);
	int (*show_path)(struct seq_file___176 *, struct dentry___200 *);
	int (*show_stats)(struct seq_file___176 *, struct dentry___200 *);
	ssize_t (*quota_read)(struct super_block___200 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___200 *, int, const char *, size_t, loff_t);
	struct dquot___200 ** (*get_dquots)(struct inode___200 *);
	long int (*nr_cached_objects)(struct super_block___200 *, struct shrink_control___86 *);
	long int (*free_cached_objects)(struct super_block___200 *, struct shrink_control___86 *);
	struct file___200 * (*real_loop)(struct file___200 *);
};

struct xattr_handler___24 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___200 *);
	int (*get)(const struct xattr_handler___24 *, struct dentry___200 *, struct inode___200 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___24 *, struct user_namespace___25 *, struct dentry___200 *, struct inode___200 *, const char *, const void *, size_t, int);
};

struct wakeup_source___164;

struct dev_pm_info___164 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___164 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___164 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___164;

struct bus_type___164;

struct device_driver___164;

struct dev_pm_domain___164;

struct fwnode_handle___164;

struct class___164;

struct attribute_group___188;

struct device___164 {
	struct kobject___188 kobj;
	struct device___164 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___164 *type;
	struct bus_type___164 *bus;
	struct device_driver___164 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___164 power;
	struct dev_pm_domain___164 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___164 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___164 *class;
	const struct attribute_group___188 **groups;
	void (*release)(struct device___164 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___103 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___200 *bd_inode;
	struct super_block___200 *bd_super;
	void *bd_claiming;
	struct device___164 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___188 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___103 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___200 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___176;

struct seq_file___176 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___176 *op;
	int poll_event;
	const struct file___200 *file;
	void *private;
};

struct fc_log___32;

struct p_log___32 {
	const char *prefix;
	struct fc_log___32 *log;
};

struct fs_context_operations___32;

struct fs_context___32 {
	const struct fs_context_operations___32 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___200 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___200 *root;
	struct user_namespace___25 *user_ns;
	struct net *net_ns;
	const struct cred___30 *cred;
	struct p_log___32 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___32;

typedef int fs_param_type___21(struct p_log___32 *, const struct fs_parameter_spec___21 *, struct fs_parameter___32 *, struct fs_parse_result *);

struct fs_parameter_spec___21 {
	const char *name;
	fs_param_type___21 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___102(struct bio___102 *);

struct bio_vec___119 {
	struct page___205 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___102;

struct bio___102 {
	struct bio___102 *bi_next;
	struct block_device___103 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___102 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___97 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___102 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___119 *bi_io_vec;
	struct bio_set___102 *bi_pool;
	struct bio_vec___119 bi_inline_vecs[0];
};

struct kernfs_root___188;

struct kernfs_elem_dir___188 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___188 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___188;

struct kernfs_root___188 {
	struct kernfs_node___188 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___188 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___188 {
	struct kernfs_node___188 *target_kn;
};

struct kernfs_ops___188;

struct kernfs_elem_attr___188 {
	const struct kernfs_ops___188 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___188 *notify_next;
};

struct kernfs_node___188 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___188 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___188 dir;
		struct kernfs_elem_symlink___188 symlink;
		struct kernfs_elem_attr___188 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___188;

struct kernfs_ops___188 {
	int (*open)(struct kernfs_open_file___188 *);
	void (*release)(struct kernfs_open_file___188 *);
	int (*seq_show)(struct seq_file___176 *, void *);
	void * (*seq_start)(struct seq_file___176 *, loff_t *);
	void * (*seq_next)(struct seq_file___176 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___176 *, void *);
	ssize_t (*read)(struct kernfs_open_file___188 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___188 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___188 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___188 *, struct vm_area_struct___205 *);
};

struct kernfs_syscall_ops___188 {
	int (*show_options)(struct seq_file___176 *, struct kernfs_root___188 *);
	int (*mkdir)(struct kernfs_node___188 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___188 *);
	int (*rename)(struct kernfs_node___188 *, struct kernfs_node___188 *, const char *);
	int (*show_path)(struct seq_file___176 *, struct kernfs_node___188 *, struct kernfs_root___188 *);
};

struct kernfs_open_file___188 {
	struct kernfs_node___188 *kn;
	struct file___200 *file;
	struct seq_file___176 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___195 *vm_ops;
};

struct bin_attribute___188;

struct attribute_group___188 {
	const char *name;
	umode_t (*is_visible)(struct kobject___188 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___188 *, struct bin_attribute___188 *, int);
	struct attribute **attrs;
	struct bin_attribute___188 **bin_attrs;
};

struct bin_attribute___188 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___200 * (*f_mapping)();
	ssize_t (*read)(struct file___200 *, struct kobject___188 *, struct bin_attribute___188 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___200 *, struct kobject___188 *, struct bin_attribute___188 *, char *, loff_t, size_t);
	int (*mmap)(struct file___200 *, struct kobject___188 *, struct bin_attribute___188 *, struct vm_area_struct___205 *);
};

struct sysfs_ops___188 {
	ssize_t (*show)(struct kobject___188 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___188 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___188;

struct kset___188 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___188 kobj;
	const struct kset_uevent_ops___188 *uevent_ops;
};

struct kobj_type___188 {
	void (*release)(struct kobject___188 *);
	const struct sysfs_ops___188 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___188 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___188 *);
	const void * (*namespace)(struct kobject___188 *);
	void (*get_ownership)(struct kobject___188 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___188 {
	int (* const filter)(struct kset___188 *, struct kobject___188 *);
	const char * (* const name)(struct kset___188 *, struct kobject___188 *);
	int (* const uevent)(struct kset___188 *, struct kobject___188 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___164 {
	int (*prepare)(struct device___164 *);
	void (*complete)(struct device___164 *);
	int (*suspend)(struct device___164 *);
	int (*resume)(struct device___164 *);
	int (*freeze)(struct device___164 *);
	int (*thaw)(struct device___164 *);
	int (*poweroff)(struct device___164 *);
	int (*restore)(struct device___164 *);
	int (*suspend_late)(struct device___164 *);
	int (*resume_early)(struct device___164 *);
	int (*freeze_late)(struct device___164 *);
	int (*thaw_early)(struct device___164 *);
	int (*poweroff_late)(struct device___164 *);
	int (*restore_early)(struct device___164 *);
	int (*suspend_noirq)(struct device___164 *);
	int (*resume_noirq)(struct device___164 *);
	int (*freeze_noirq)(struct device___164 *);
	int (*thaw_noirq)(struct device___164 *);
	int (*poweroff_noirq)(struct device___164 *);
	int (*restore_noirq)(struct device___164 *);
	int (*runtime_suspend)(struct device___164 *);
	int (*runtime_resume)(struct device___164 *);
	int (*runtime_idle)(struct device___164 *);
};

struct wakeup_source___164 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___164 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___164 {
	struct dev_pm_ops___164 ops;
	int (*start)(struct device___164 *);
	void (*detach)(struct device___164 *, bool);
	int (*activate)(struct device___164 *);
	void (*sync)(struct device___164 *);
	void (*dismiss)(struct device___164 *);
};

struct bus_type___164 {
	const char *name;
	const char *dev_name;
	struct device___164 *dev_root;
	const struct attribute_group___188 **bus_groups;
	const struct attribute_group___188 **dev_groups;
	const struct attribute_group___188 **drv_groups;
	int (*match)(struct device___164 *, struct device_driver___164 *);
	int (*uevent)(struct device___164 *, struct kobj_uevent_env *);
	int (*probe)(struct device___164 *);
	void (*sync_state)(struct device___164 *);
	void (*remove)(struct device___164 *);
	void (*shutdown)(struct device___164 *);
	int (*online)(struct device___164 *);
	int (*offline)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	int (*num_vf)(struct device___164 *);
	int (*dma_configure)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___164 {
	const char *name;
	struct bus_type___164 *bus;
	struct module___184 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___164 *);
	void (*sync_state)(struct device___164 *);
	int (*remove)(struct device___164 *);
	void (*shutdown)(struct device___164 *);
	int (*suspend)(struct device___164 *, pm_message_t);
	int (*resume)(struct device___164 *);
	const struct attribute_group___188 **groups;
	const struct attribute_group___188 **dev_groups;
	const struct dev_pm_ops___164 *pm;
	void (*coredump)(struct device___164 *);
	struct driver_private *p;
};

struct device_type___164 {
	const char *name;
	const struct attribute_group___188 **groups;
	int (*uevent)(struct device___164 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___164 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___164 *);
	const struct dev_pm_ops___164 *pm;
};

struct class___164 {
	const char *name;
	struct module___184 *owner;
	const struct attribute_group___188 **class_groups;
	const struct attribute_group___188 **dev_groups;
	struct kobject___188 *dev_kobj;
	int (*dev_uevent)(struct device___164 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___164 *, umode_t *);
	void (*class_release)(struct class___164 *);
	void (*dev_release)(struct device___164 *);
	int (*shutdown_pre)(struct device___164 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___164 *);
	void (*get_ownership)(struct device___164 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___164 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___164;

struct fwnode_handle___164 {
	struct fwnode_handle___164 *secondary;
	const struct fwnode_operations___164 *ops;
	struct device___164 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___176 {
	void * (*start)(struct seq_file___176 *, loff_t *);
	void (*stop)(struct seq_file___176 *, void *);
	void * (*next)(struct seq_file___176 *, void *, loff_t *);
	int (*show)(struct seq_file___176 *, void *);
};

struct tty_operations___20 {
	struct tty_struct___19 * (*lookup)(struct tty_driver___20 *, struct file___200 *, int);
	int (*install)(struct tty_driver___20 *, struct tty_struct___19 *);
	void (*remove)(struct tty_driver___20 *, struct tty_struct___19 *);
	int (*open)(struct tty_struct___19 *, struct file___200 *);
	void (*close)(struct tty_struct___19 *, struct file___200 *);
	void (*shutdown)(struct tty_struct___19 *);
	void (*cleanup)(struct tty_struct___19 *);
	int (*write)(struct tty_struct___19 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___19 *, unsigned char);
	void (*flush_chars)(struct tty_struct___19 *);
	unsigned int (*write_room)(struct tty_struct___19 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___19 *);
	int (*ioctl)(struct tty_struct___19 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___19 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___19 *, struct ktermios *);
	void (*throttle)(struct tty_struct___19 *);
	void (*unthrottle)(struct tty_struct___19 *);
	void (*stop)(struct tty_struct___19 *);
	void (*start)(struct tty_struct___19 *);
	void (*hangup)(struct tty_struct___19 *);
	int (*break_ctl)(struct tty_struct___19 *, int);
	void (*flush_buffer)(struct tty_struct___19 *);
	void (*set_ldisc)(struct tty_struct___19 *);
	void (*wait_until_sent)(struct tty_struct___19 *, int);
	void (*send_xchar)(struct tty_struct___19 *, char);
	int (*tiocmget)(struct tty_struct___19 *);
	int (*tiocmset)(struct tty_struct___19 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___19 *, struct winsize *);
	int (*get_icount)(struct tty_struct___19 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___19 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___19 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___19 *, struct seq_file___176 *);
	int (*poll_init)(struct tty_driver___20 *, int, char *);
	int (*poll_get_char)(struct tty_driver___20 *, int);
	void (*poll_put_char)(struct tty_driver___20 *, int, char);
	int (*proc_show)(struct seq_file___176 *, void *);
};

struct tty_driver___20 {
	int magic;
	struct kref kref;
	struct cdev___47 **cdevs;
	struct module___184 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___20 *other;
	struct tty_struct___19 **ttys;
	struct tty_port___20 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___20 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___19;

struct tty_port_client_operations___19;

struct tty_port___20 {
	struct tty_bufhead buf;
	struct tty_struct___19 *tty;
	struct tty_struct___19 *itty;
	const struct tty_port_operations___19 *ops;
	const struct tty_port_client_operations___19 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___19 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___19 *);
	void (*close)(struct tty_struct___19 *);
	void (*flush_buffer)(struct tty_struct___19 *);
	ssize_t (*read)(struct tty_struct___19 *, struct file___200 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___19 *, struct file___200 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___19 *, struct file___200 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___19 *, struct file___200 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___19 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___19 *, struct file___200 *, struct poll_table_struct___5 *);
	int (*hangup)(struct tty_struct___19 *);
	void (*receive_buf)(struct tty_struct___19 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___19 *);
	void (*dcd_change)(struct tty_struct___19 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___19 *, const unsigned char *, const char *, int);
	struct module___184 *owner;
};

struct tty_ldisc___19 {
	struct tty_ldisc_ops___19 *ops;
	struct tty_struct___19 *tty;
};

struct tty_port_operations___19 {
	int (*carrier_raised)(struct tty_port___20 *);
	void (*dtr_rts)(struct tty_port___20 *, int);
	void (*shutdown)(struct tty_port___20 *);
	int (*activate)(struct tty_port___20 *, struct tty_struct___19 *);
	void (*destruct)(struct tty_port___20 *);
};

struct tty_port_client_operations___19 {
	int (*receive_buf)(struct tty_port___20 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___20 *);
};

struct cgroup_namespace___137 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___137 *root_cset;
};

struct fwnode_reference_args___164;

struct fwnode_endpoint___164;

struct fwnode_operations___164 {
	struct fwnode_handle___164 * (*get)(struct fwnode_handle___164 *);
	void (*put)(struct fwnode_handle___164 *);
	bool (*device_is_available)(const struct fwnode_handle___164 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___164 *, const struct device___164 *);
	bool (*property_present)(const struct fwnode_handle___164 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___164 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___164 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___164 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*get_parent)(const struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*get_next_child_node)(const struct fwnode_handle___164 *, struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*get_named_child_node)(const struct fwnode_handle___164 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___164 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___164 *);
	struct fwnode_handle___164 * (*graph_get_next_endpoint)(const struct fwnode_handle___164 *, struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*graph_get_remote_endpoint)(const struct fwnode_handle___164 *);
	struct fwnode_handle___164 * (*graph_get_port_parent)(struct fwnode_handle___164 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___164 *, struct fwnode_endpoint___164 *);
	int (*add_links)(struct fwnode_handle___164 *);
};

struct fwnode_endpoint___164 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___164 *local_fwnode;
};

struct fwnode_reference_args___164 {
	struct fwnode_handle___164 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___184 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___184 *);
	int (*get)(char *, const struct kernel_param___184 *);
	void (*free)(void *);
};

struct kparam_array___184;

struct kernel_param___184 {
	const char *name;
	struct module___184 *mod;
	const struct kernel_param_ops___184 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___184 *arr;
	};
};

struct kparam_array___184 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___184 *ops;
	void *elem;
};

struct module_attribute___184 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___184 *, struct module_kobject___184 *, char *);
	ssize_t (*store)(struct module_attribute___184 *, struct module_kobject___184 *, const char *, size_t);
	void (*setup)(struct module___184 *, const char *);
	int (*test)(struct module___184 *);
	void (*free)(struct module___184 *);
};

struct block_device_operations___102;

struct gendisk___103 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___103 *part0;
	const struct block_device_operations___102 *fops;
	struct request_queue___102 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___95 *bdi;
	struct kobject___188 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___188 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___102 {
	struct bio___102 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___119 *bip_vec;
	struct bio_vec___119 bip_inline_vecs[0];
};

struct blkcg___97;

struct blkg_policy_data___97;

struct blkcg_gq___97 {
	struct request_queue___102 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___97 *blkcg;
	struct blkcg_gq___97 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___97 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___102 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___102(struct request___102 *);

typedef void integrity_complete_fn___102(struct request___102 *, unsigned int);

struct blk_integrity_profile___102 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___102 *prepare_fn;
	integrity_complete_fn___102 *complete_fn;
	const char *name;
};

struct block_device_operations___102 {
	blk_qc_t (*submit_bio)(struct bio___102 *);
	int (*open)(struct block_device___103 *, fmode_t);
	void (*release)(struct gendisk___103 *, fmode_t);
	int (*rw_page)(struct block_device___103 *, sector_t, struct page___205 *, unsigned int);
	int (*ioctl)(struct block_device___103 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___103 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___103 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___103 *);
	int (*getgeo)(struct block_device___103 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___103 *, bool);
	void (*swap_slot_free_notify)(struct block_device___103 *, long unsigned int);
	int (*report_zones)(struct gendisk___103 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___103 *, umode_t *);
	struct module___184 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___103 *, sector_t *);
};

typedef void rq_end_io_fn___102(struct request___102 *, blk_status_t);

struct request___102 {
	struct request_queue___102 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___99 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___102 *bio;
	struct bio___102 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___119 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___102 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___102 *saved_end_io;
		} flush;
	};
	struct gendisk___103 *rq_disk;
	struct block_device___103 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___102 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___99 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___102 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___188 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___200 *debugfs_dir;
	struct dentry___200 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___102;

struct elevator_mq_ops___102 {
	int (*init_sched)(struct request_queue___102 *, struct elevator_type___102 *);
	void (*exit_sched)(struct elevator_queue___102 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___99 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___99 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___99 *);
	bool (*allow_merge)(struct request_queue___102 *, struct request___102 *, struct bio___102 *);
	bool (*bio_merge)(struct request_queue___102 *, struct bio___102 *, unsigned int);
	int (*request_merge)(struct request_queue___102 *, struct request___102 **, struct bio___102 *);
	void (*request_merged)(struct request_queue___102 *, struct request___102 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___102 *, struct request___102 *, struct request___102 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___102 *);
	void (*finish_request)(struct request___102 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___99 *, struct list_head *, bool);
	struct request___102 * (*dispatch_request)(struct blk_mq_hw_ctx___99 *);
	bool (*has_work)(struct blk_mq_hw_ctx___99 *);
	void (*completed_request)(struct request___102 *, u64);
	void (*requeue_request)(struct request___102 *);
	struct request___102 * (*former_request)(struct request_queue___102 *, struct request___102 *);
	struct request___102 * (*next_request)(struct request_queue___102 *, struct request___102 *);
	void (*init_icq)(struct io_cq___102 *);
	void (*exit_icq)(struct io_cq___102 *);
};

struct elv_fs_entry___102;

struct elevator_type___102 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___102 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___102 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___184 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___102 {
	struct elevator_type___102 *type;
	void *elevator_data;
	struct kobject___188 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___102 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___102 *, char *);
	ssize_t (*store)(struct elevator_queue___102 *, const char *, size_t);
};

struct blk_mq_queue_data___99;

struct blk_mq_ops___99 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___99 *, const struct blk_mq_queue_data___99 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___99 *);
	int (*get_budget)(struct request_queue___102 *);
	void (*put_budget)(struct request_queue___102 *, int);
	void (*set_rq_budget_token)(struct request___102 *, int);
	int (*get_rq_budget_token)(struct request___102 *);
	enum blk_eh_timer_return (*timeout)(struct request___102 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___99 *);
	void (*complete)(struct request___102 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___99 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___99 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___99 *, struct request___102 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___99 *, struct request___102 *, unsigned int);
	void (*initialize_rq_fn)(struct request___102 *);
	void (*cleanup_rq)(struct request___102 *);
	bool (*busy)(struct request_queue___102 *);
	int (*map_queues)(struct blk_mq_tag_set___99 *);
	void (*show_rq)(struct seq_file___176 *, struct request___102 *);
};

struct blk_mq_tag_set___99 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___99 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct cftype___137;

struct cgroup_subsys___137 {
	struct cgroup_subsys_state___137 * (*css_alloc)(struct cgroup_subsys_state___137 *);
	int (*css_online)(struct cgroup_subsys_state___137 *);
	void (*css_offline)(struct cgroup_subsys_state___137 *);
	void (*css_released)(struct cgroup_subsys_state___137 *);
	void (*css_free)(struct cgroup_subsys_state___137 *);
	void (*css_reset)(struct cgroup_subsys_state___137 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___137 *, int);
	int (*css_extra_stat_show)(struct seq_file___176 *, struct cgroup_subsys_state___137 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___207 *, struct css_set___137 *);
	void (*cancel_fork)(struct task_struct___207 *, struct css_set___137 *);
	void (*fork)(struct task_struct___207 *);
	void (*exit)(struct task_struct___207 *);
	void (*release)(struct task_struct___207 *);
	void (*bind)(struct cgroup_subsys_state___137 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___137 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___137 *dfl_cftypes;
	struct cftype___137 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___137 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___137 *updated_children;
	struct cgroup___137 *updated_next;
};

struct cgroup_root___137 {
	struct kernfs_root___188 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___137 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___137 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___137 *ss;
	struct list_head node;
	struct kernfs_ops___188 *kf_ops;
	int (*open)(struct kernfs_open_file___188 *);
	void (*release)(struct kernfs_open_file___188 *);
	u64 (*read_u64)(struct cgroup_subsys_state___137 *, struct cftype___137 *);
	s64 (*read_s64)(struct cgroup_subsys_state___137 *, struct cftype___137 *);
	int (*seq_show)(struct seq_file___176 *, void *);
	void * (*seq_start)(struct seq_file___176 *, loff_t *);
	void * (*seq_next)(struct seq_file___176 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___176 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___137 *, struct cftype___137 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___137 *, struct cftype___137 *, s64);
	ssize_t (*write)(struct kernfs_open_file___188 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___188 *, struct poll_table_struct___5 *);
};

struct blk_mq_queue_data___99 {
	struct request___102 *rq;
	bool last;
};

struct blkcg_policy_data___97;

struct blkcg___97 {
	struct cgroup_subsys_state___137 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___97 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___97 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___97 {
	struct blkcg___97 *blkcg;
	int plid;
};

struct blkg_policy_data___97 {
	struct blkcg_gq___97 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___86 {
	struct mem_cgroup___86 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___86 {
	struct lruvec___93 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___86 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___86 *memcg;
};

struct obj_cgroup___86 {
	struct percpu_ref refcnt;
	struct mem_cgroup___86 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fs_parameter___32 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___200 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___32 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___184 *owner;
	char *buffer[8];
};

struct fs_context_operations___32 {
	void (*free)(struct fs_context___32 *);
	int (*dup)(struct fs_context___32 *, struct fs_context___32 *);
	int (*parse_param)(struct fs_context___32 *, struct fs_parameter___32 *);
	int (*parse_monolithic)(struct fs_context___32 *, void *);
	int (*get_tree)(struct fs_context___32 *);
	int (*reconfigure)(struct fs_context___32 *);
};

struct pipe_buf_operations___65;

struct pipe_buffer___65 {
	struct page___205 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___65 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___65 {
	int (*confirm)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
	void (*release)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
	bool (*try_steal)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
	bool (*get)(struct pipe_inode_info___65 *, struct pipe_buffer___65 *);
};

struct splice_desc___2 {
	size_t total_len;
	unsigned int len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___200 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

typedef int splice_actor___2(struct pipe_inode_info___65 *, struct pipe_buffer___65 *, struct splice_desc___2 *);

struct memdev {
	const char *name;
	umode_t mode;
	const struct file_operations___201 *fops;
	fmode_t fmode;
};

typedef void (*poll_queue_proc___138)(struct file___190 *, wait_queue_head_t *, struct poll_table_struct___5 *);

struct timer_rand_state {
	cycles_t last_time;
	long int last_delta;
	long int last_delta2;
};

struct trace_event_raw_add_device_randomness {
	struct trace_entry ent;
	int bytes;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_random__mix_pool_bytes {
	struct trace_entry ent;
	const char *pool_name;
	int bytes;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_credit_entropy_bits {
	struct trace_entry ent;
	const char *pool_name;
	int bits;
	int entropy_count;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_debit_entropy {
	struct trace_entry ent;
	const char *pool_name;
	int debit_bits;
	char __data[0];
};

struct trace_event_raw_add_input_randomness {
	struct trace_entry ent;
	int input_bits;
	char __data[0];
};

struct trace_event_raw_add_disk_randomness {
	struct trace_entry ent;
	dev_t dev;
	int input_bits;
	char __data[0];
};

struct trace_event_raw_random__get_random_bytes {
	struct trace_entry ent;
	int nbytes;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_random__extract_entropy {
	struct trace_entry ent;
	const char *pool_name;
	int nbytes;
	int entropy_count;
	long unsigned int IP;
	char __data[0];
};

struct trace_event_raw_urandom_read {
	struct trace_entry ent;
	int got_bits;
	int pool_left;
	int input_left;
	char __data[0];
};

struct trace_event_raw_prandom_u32 {
	struct trace_entry ent;
	unsigned int ret;
	char __data[0];
};

struct trace_event_data_offsets_add_device_randomness {};

struct trace_event_data_offsets_random__mix_pool_bytes {};

struct trace_event_data_offsets_credit_entropy_bits {};

struct trace_event_data_offsets_debit_entropy {};

struct trace_event_data_offsets_add_input_randomness {};

struct trace_event_data_offsets_add_disk_randomness {};

struct trace_event_data_offsets_random__get_random_bytes {};

struct trace_event_data_offsets_random__extract_entropy {};

struct trace_event_data_offsets_urandom_read {};

struct trace_event_data_offsets_prandom_u32 {};

typedef void (*btf_trace_add_device_randomness)(void *, int, long unsigned int);

typedef void (*btf_trace_mix_pool_bytes)(void *, const char *, int, long unsigned int);

typedef void (*btf_trace_mix_pool_bytes_nolock)(void *, const char *, int, long unsigned int);

typedef void (*btf_trace_credit_entropy_bits)(void *, const char *, int, int, long unsigned int);

typedef void (*btf_trace_debit_entropy)(void *, const char *, int);

typedef void (*btf_trace_add_input_randomness)(void *, int);

typedef void (*btf_trace_add_disk_randomness)(void *, dev_t, int);

typedef void (*btf_trace_get_random_bytes)(void *, int, long unsigned int);

typedef void (*btf_trace_get_random_bytes_arch)(void *, int, long unsigned int);

typedef void (*btf_trace_extract_entropy)(void *, const char *, int, int, long unsigned int);

typedef void (*btf_trace_urandom_read)(void *, int, int, int);

typedef void (*btf_trace_prandom_u32)(void *, unsigned int);

struct poolinfo {
	int poolbitshift;
	int poolwords;
	int poolbytes;
	int poolfracbits;
	int tap1;
	int tap2;
	int tap3;
	int tap4;
	int tap5;
};

struct crng_state {
	__u32 state[16];
	long unsigned int init_time;
	spinlock_t lock;
};

struct entropy_store {
	const struct poolinfo *poolinfo;
	__u32 *pool;
	const char *name;
	spinlock_t lock;
	short unsigned int add_ptr;
	short unsigned int input_rotate;
	int entropy_count;
	unsigned int last_data_init: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 last_data[10];
};

struct fast_pool {
	__u32 pool[4];
	long unsigned int last;
	short unsigned int reg_idx;
	unsigned char count;
};

struct batched_entropy {
	union {
		u64 entropy_u64[8];
		u32 entropy_u32[16];
	};
	unsigned int position;
	spinlock_t batch_lock;
};

struct ttyprintk_port {
	struct tty_port___2 port;
	spinlock_t spinlock;
};

struct dentry___201;

struct super_block___201;

struct module___185;

struct file_system_type___201 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___201 * (*mount)(struct file_system_type___201 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___201 *);
	struct module___185 *owner;
	struct file_system_type___201 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___201;

struct kiocb___201;

struct iov_iter___122;

struct poll_table_struct___132;

struct vm_area_struct___206;

struct inode___201;

struct file_lock___201;

struct page___206;

struct pipe_inode_info___66;

struct seq_file___177;

struct file_operations___202 {
	struct module___185 *owner;
	loff_t (*llseek)(struct file___201 *, loff_t, int);
	ssize_t (*read)(struct file___201 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___201 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___201 *, struct iov_iter___122 *);
	ssize_t (*write_iter)(struct kiocb___201 *, struct iov_iter___122 *);
	int (*iopoll)(struct kiocb___201 *, bool);
	int (*iterate)(struct file___201 *, struct dir_context *);
	int (*iterate_shared)(struct file___201 *, struct dir_context *);
	__poll_t (*poll)(struct file___201 *, struct poll_table_struct___132 *);
	long int (*unlocked_ioctl)(struct file___201 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___201 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___201 *, struct vm_area_struct___206 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___201 *, struct file___201 *);
	int (*flush)(struct file___201 *, fl_owner_t);
	int (*release)(struct inode___201 *, struct file___201 *);
	int (*fsync)(struct file___201 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___201 *, int);
	int (*lock)(struct file___201 *, int, struct file_lock___201 *);
	ssize_t (*sendpage)(struct file___201 *, struct page___206 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___201 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___201 *, long unsigned int);
	int (*flock)(struct file___201 *, int, struct file_lock___201 *);
	ssize_t (*splice_write)(struct pipe_inode_info___66 *, struct file___201 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___201 *, loff_t *, struct pipe_inode_info___66 *, size_t, unsigned int);
	int (*setlease)(struct file___201 *, long int, struct file_lock___201 **, void **);
	long int (*fallocate)(struct file___201 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___177 *, struct file___201 *);
	ssize_t (*copy_file_range)(struct file___201 *, loff_t, struct file___201 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___201 *, loff_t, struct file___201 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___201 *, loff_t, loff_t, int);
};

struct vmacache___206 {
	u64 seqnum;
	struct vm_area_struct___206 *vmas[4];
};

struct page_frag___206 {
	struct page___206 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___207;

struct pid___178;

struct nsproxy___187;

struct signal_struct___202;

struct vm_struct___184;

struct task_struct___208 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___208 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___207 *mm;
	struct mm_struct___207 *active_mm;
	struct vmacache___206 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___208 *real_parent;
	struct task_struct___208 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___208 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___178 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___187 *nsproxy;
	struct signal_struct___202 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___208 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___102 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___66 *splice_pipe;
	struct page_frag___206 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___208 *oom_reaper_list;
	struct vm_struct___184 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___189;

struct kobj_type___189;

struct kernfs_node___189;

struct kobject___189 {
	const char *name;
	struct list_head entry;
	struct kobject___189 *parent;
	struct kset___189 *kset;
	struct kobj_type___189 *ktype;
	struct kernfs_node___189 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___185 {
	struct kobject___189 kobj;
	struct module___185 *mod;
	struct kobject___189 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___185 {
	struct module___185 *mod;
	struct latch_tree_node node;
};

struct module_layout___185 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___185 mtn;
};

struct module_attribute___185;

struct kernel_param___185;

struct module___185 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___185 mkobj;
	struct module_attribute___185 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___189 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___185 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___185 core_layout;
	struct module_layout___185 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___206 *pgtable_t___206;

struct address_space___201;

struct dev_pagemap___196;

struct page___206 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___201 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___54 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___206 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___206 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___207 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___196 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___196;

struct vm_area_struct___206 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___206 *vm_next;
	struct vm_area_struct___206 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___207 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___196 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___201 *vm_file;
	struct file___201 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___206;

struct mm_struct___207 {
	struct {
		struct vm_area_struct___206 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___201 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___206 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___208 *owner;
		struct user_namespace *user_ns;
		struct file___201 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___201;

struct address_space___201 {
	struct inode___201 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___201 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___196;

struct dev_pagemap___196 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___196 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___201;

struct path___201 {
	struct vfsmount___201 *mnt;
	struct dentry___201 *dentry;
};

struct fown_struct___178 {
	rwlock_t lock;
	struct pid___178 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___201 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___201 f_path;
	struct inode___201 *f_inode;
	const struct file_operations___202 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___178 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___201 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___196;

struct vm_operations_struct___196 {
	void (*open)(struct vm_area_struct___206 *);
	void (*close)(struct vm_area_struct___206 *);
	int (*may_split)(struct vm_area_struct___206 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___206 *);
	int (*mprotect)(struct vm_area_struct___206 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___196 *);
	vm_fault_t (*huge_fault)(struct vm_fault___196 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___196 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___206 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___196 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___196 *);
	int (*access)(struct vm_area_struct___206 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___206 *);
	int (*set_policy)(struct vm_area_struct___206 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___206 *, long unsigned int);
	struct page___206 * (*find_special_page)(struct vm_area_struct___206 *, long unsigned int);
};

struct core_thread___206 {
	struct task_struct___208 *task;
	struct core_thread___206 *next;
};

struct core_state___206 {
	atomic_t nr_threads;
	struct core_thread___206 dumper;
	struct completion startup;
};

struct vm_fault___196 {
	const struct {
		struct vm_area_struct___206 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___206 *cow_page;
	struct page___206 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___206 prealloc_pte;
};

struct kernfs_root___189;

struct kernfs_elem_dir___189 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___189 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___189;

struct kernfs_root___189 {
	struct kernfs_node___189 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___189 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___189 {
	struct kernfs_node___189 *target_kn;
};

struct kernfs_ops___189;

struct kernfs_elem_attr___189 {
	const struct kernfs_ops___189 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___189 *notify_next;
};

struct kernfs_node___189 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___189 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___189 dir;
		struct kernfs_elem_symlink___189 symlink;
		struct kernfs_elem_attr___189 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___189;

struct kernfs_ops___189 {
	int (*open)(struct kernfs_open_file___189 *);
	void (*release)(struct kernfs_open_file___189 *);
	int (*seq_show)(struct seq_file___177 *, void *);
	void * (*seq_start)(struct seq_file___177 *, loff_t *);
	void * (*seq_next)(struct seq_file___177 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___177 *, void *);
	ssize_t (*read)(struct kernfs_open_file___189 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___189 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___189 *, struct poll_table_struct___132 *);
	int (*mmap)(struct kernfs_open_file___189 *, struct vm_area_struct___206 *);
};

struct kernfs_syscall_ops___189 {
	int (*show_options)(struct seq_file___177 *, struct kernfs_root___189 *);
	int (*mkdir)(struct kernfs_node___189 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___189 *);
	int (*rename)(struct kernfs_node___189 *, struct kernfs_node___189 *, const char *);
	int (*show_path)(struct seq_file___177 *, struct kernfs_node___189 *, struct kernfs_root___189 *);
};

struct seq_operations___177;

struct seq_file___177 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___177 *op;
	int poll_event;
	const struct file___201 *file;
	void *private;
};

struct kernfs_open_file___189 {
	struct kernfs_node___189 *kn;
	struct file___201 *file;
	struct seq_file___177 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___196 *vm_ops;
};

typedef void (*poll_queue_proc___139)(struct file___201 *, wait_queue_head_t *, struct poll_table_struct___132 *);

struct poll_table_struct___132 {
	poll_queue_proc___139 _qproc;
	__poll_t _key;
};

struct pid_namespace___178;

struct upid___178 {
	int nr;
	struct pid_namespace___178 *ns;
};

struct pid_namespace___178 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___208 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___178 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___178 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___178 numbers[1];
};

struct tty_struct___20;

struct signal_struct___202 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___208 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___208 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___178 *pids[4];
	struct pid___178 *tty_old_pgrp;
	int leader;
	struct tty_struct___20 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___207 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___187 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___178 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___201;

struct pipe_buffer___66;

struct pipe_inode_info___66 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___206 *tmp_page;
	struct fasync_struct___201 *fasync_readers;
	struct fasync_struct___201 *fasync_writers;
	struct pipe_buffer___66 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___184 {
	struct vm_struct___184 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___206 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___189;

struct attribute_group___189 {
	const char *name;
	umode_t (*is_visible)(struct kobject___189 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___189 *, struct bin_attribute___189 *, int);
	struct attribute **attrs;
	struct bin_attribute___189 **bin_attrs;
};

struct bin_attribute___189 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___201 * (*f_mapping)();
	ssize_t (*read)(struct file___201 *, struct kobject___189 *, struct bin_attribute___189 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___201 *, struct kobject___189 *, struct bin_attribute___189 *, char *, loff_t, size_t);
	int (*mmap)(struct file___201 *, struct kobject___189 *, struct bin_attribute___189 *, struct vm_area_struct___206 *);
};

struct sysfs_ops___189 {
	ssize_t (*show)(struct kobject___189 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___189 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___189;

struct kset___189 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___189 kobj;
	const struct kset_uevent_ops___189 *uevent_ops;
};

struct kobj_type___189 {
	void (*release)(struct kobject___189 *);
	const struct sysfs_ops___189 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___189 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___189 *);
	const void * (*namespace)(struct kobject___189 *);
	void (*get_ownership)(struct kobject___189 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___189 {
	int (* const filter)(struct kset___189 *, struct kobject___189 *);
	const char * (* const name)(struct kset___189 *, struct kobject___189 *);
	int (* const uevent)(struct kset___189 *, struct kobject___189 *, struct kobj_uevent_env *);
};

struct wakeup_source___165;

struct device___165;

struct dev_pm_info___165 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___165 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___165 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___165;

struct bus_type___165;

struct device_driver___165;

struct dev_pm_domain___165;

struct fwnode_handle___165;

struct class___165;

struct device___165 {
	struct kobject___189 kobj;
	struct device___165 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___165 *type;
	struct bus_type___165 *bus;
	struct device_driver___165 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___165 power;
	struct dev_pm_domain___165 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___165 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___165 *class;
	const struct attribute_group___189 **groups;
	void (*release)(struct device___165 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___165 {
	int (*prepare)(struct device___165 *);
	void (*complete)(struct device___165 *);
	int (*suspend)(struct device___165 *);
	int (*resume)(struct device___165 *);
	int (*freeze)(struct device___165 *);
	int (*thaw)(struct device___165 *);
	int (*poweroff)(struct device___165 *);
	int (*restore)(struct device___165 *);
	int (*suspend_late)(struct device___165 *);
	int (*resume_early)(struct device___165 *);
	int (*freeze_late)(struct device___165 *);
	int (*thaw_early)(struct device___165 *);
	int (*poweroff_late)(struct device___165 *);
	int (*restore_early)(struct device___165 *);
	int (*suspend_noirq)(struct device___165 *);
	int (*resume_noirq)(struct device___165 *);
	int (*freeze_noirq)(struct device___165 *);
	int (*thaw_noirq)(struct device___165 *);
	int (*poweroff_noirq)(struct device___165 *);
	int (*restore_noirq)(struct device___165 *);
	int (*runtime_suspend)(struct device___165 *);
	int (*runtime_resume)(struct device___165 *);
	int (*runtime_idle)(struct device___165 *);
};

struct wakeup_source___165 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___165 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___165 {
	struct dev_pm_ops___165 ops;
	int (*start)(struct device___165 *);
	void (*detach)(struct device___165 *, bool);
	int (*activate)(struct device___165 *);
	void (*sync)(struct device___165 *);
	void (*dismiss)(struct device___165 *);
};

struct bus_type___165 {
	const char *name;
	const char *dev_name;
	struct device___165 *dev_root;
	const struct attribute_group___189 **bus_groups;
	const struct attribute_group___189 **dev_groups;
	const struct attribute_group___189 **drv_groups;
	int (*match)(struct device___165 *, struct device_driver___165 *);
	int (*uevent)(struct device___165 *, struct kobj_uevent_env *);
	int (*probe)(struct device___165 *);
	void (*sync_state)(struct device___165 *);
	void (*remove)(struct device___165 *);
	void (*shutdown)(struct device___165 *);
	int (*online)(struct device___165 *);
	int (*offline)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	int (*num_vf)(struct device___165 *);
	int (*dma_configure)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___165 {
	const char *name;
	struct bus_type___165 *bus;
	struct module___185 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___165 *);
	void (*sync_state)(struct device___165 *);
	int (*remove)(struct device___165 *);
	void (*shutdown)(struct device___165 *);
	int (*suspend)(struct device___165 *, pm_message_t);
	int (*resume)(struct device___165 *);
	const struct attribute_group___189 **groups;
	const struct attribute_group___189 **dev_groups;
	const struct dev_pm_ops___165 *pm;
	void (*coredump)(struct device___165 *);
	struct driver_private *p;
};

struct device_type___165 {
	const char *name;
	const struct attribute_group___189 **groups;
	int (*uevent)(struct device___165 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___165 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___165 *);
	const struct dev_pm_ops___165 *pm;
};

struct class___165 {
	const char *name;
	struct module___185 *owner;
	const struct attribute_group___189 **class_groups;
	const struct attribute_group___189 **dev_groups;
	struct kobject___189 *dev_kobj;
	int (*dev_uevent)(struct device___165 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___165 *, umode_t *);
	void (*class_release)(struct class___165 *);
	void (*dev_release)(struct device___165 *);
	int (*shutdown_pre)(struct device___165 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___165 *);
	void (*get_ownership)(struct device___165 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___165 *pm;
	struct subsys_private *p;
};

struct device_attribute___18 {
	struct attribute attr;
	ssize_t (*show)(struct device___165 *, struct device_attribute___18 *, char *);
	ssize_t (*store)(struct device___165 *, struct device_attribute___18 *, const char *, size_t);
};

struct fwnode_operations___165;

struct fwnode_handle___165 {
	struct fwnode_handle___165 *secondary;
	const struct fwnode_operations___165 *ops;
	struct device___165 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct cdev___48 {
	struct kobject___189 kobj;
	struct module___185 *owner;
	const struct file_operations___202 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct dentry_operations___201;

struct dentry___201 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___201 *d_parent;
	struct qstr d_name;
	struct inode___201 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___201 *d_op;
	struct super_block___201 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___201;

struct inode___201 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___201 *i_op;
	struct super_block___201 *i_sb;
	struct address_space___201 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___202 *i_fop;
		void (*free_inode)(struct inode___201 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___201 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___66 *i_pipe;
		struct cdev___48 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___201 {
	int (*d_revalidate)(struct dentry___201 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___201 *, unsigned int);
	int (*d_hash)(const struct dentry___201 *, struct qstr *);
	int (*d_compare)(const struct dentry___201 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___201 *);
	int (*d_init)(struct dentry___201 *);
	void (*d_release)(struct dentry___201 *);
	void (*d_prune)(struct dentry___201 *);
	void (*d_iput)(struct dentry___201 *, struct inode___201 *);
	char * (*d_dname)(struct dentry___201 *, char *, int);
	struct vfsmount___201 * (*d_automount)(struct path___201 *);
	int (*d_manage)(const struct path___201 *, bool);
	struct dentry___201 * (*d_real)(struct dentry___201 *, const struct inode___201 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___201;

struct mem_dqinfo___201 {
	struct quota_format_type___201 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___201;

struct quota_info___201 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___201 *files[3];
	struct mem_dqinfo___201 info[3];
	const struct quota_format_ops___201 *ops[3];
};

struct rcuwait___202 {
	struct task_struct___208 *task;
};

struct percpu_rw_semaphore___202 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___202 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___201 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___202 rw_sem[3];
};

struct super_operations___201;

struct dquot_operations___201;

struct quotactl_ops___201;

struct super_block___201 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___201 *s_type;
	const struct super_operations___201 *s_op;
	const struct dquot_operations___201 *dq_op;
	const struct quotactl_ops___201 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___201 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___201 s_dquot;
	struct sb_writers___201 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___201 *s_d_op;
	int cleancache_poolid;
	struct shrinker___86 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___201 {
	struct dentry___201 *mnt_root;
	struct super_block___201 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct tty_driver___21;

struct tty_operations___21;

struct tty_ldisc___20;

struct tty_port___21;

struct tty_struct___20 {
	int magic;
	struct kref kref;
	struct device___165 *dev;
	struct tty_driver___21 *driver;
	const struct tty_operations___21 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___20 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___178 *pgrp;
		struct pid___178 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___20 *link;
	struct fasync_struct___201 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___21 *port;
};

struct wait_page_queue___96;

struct kiocb___201 {
	struct file___201 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___201 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___96 *ki_waitq;
	};
};

struct iattr___201 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___201 *ia_file;
};

struct dquot___201 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___201 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___201 {
	int qf_fmt_id;
	const struct quota_format_ops___201 *qf_ops;
	struct module___185 *qf_owner;
	struct quota_format_type___201 *qf_next;
};

struct quota_format_ops___201 {
	int (*check_quota_file)(struct super_block___201 *, int);
	int (*read_file_info)(struct super_block___201 *, int);
	int (*write_file_info)(struct super_block___201 *, int);
	int (*free_file_info)(struct super_block___201 *, int);
	int (*read_dqblk)(struct dquot___201 *);
	int (*commit_dqblk)(struct dquot___201 *);
	int (*release_dqblk)(struct dquot___201 *);
	int (*get_next_id)(struct super_block___201 *, struct kqid *);
};

struct dquot_operations___201 {
	int (*write_dquot)(struct dquot___201 *);
	struct dquot___201 * (*alloc_dquot)(struct super_block___201 *, int);
	void (*destroy_dquot)(struct dquot___201 *);
	int (*acquire_dquot)(struct dquot___201 *);
	int (*release_dquot)(struct dquot___201 *);
	int (*mark_dirty)(struct dquot___201 *);
	int (*write_info)(struct super_block___201 *, int);
	qsize_t * (*get_reserved_space)(struct inode___201 *);
	int (*get_projid)(struct inode___201 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___201 *, qsize_t *);
	int (*get_next_id)(struct super_block___201 *, struct kqid *);
};

struct quotactl_ops___201 {
	int (*quota_on)(struct super_block___201 *, int, int, const struct path___201 *);
	int (*quota_off)(struct super_block___201 *, int);
	int (*quota_enable)(struct super_block___201 *, unsigned int);
	int (*quota_disable)(struct super_block___201 *, unsigned int);
	int (*quota_sync)(struct super_block___201 *, int);
	int (*set_info)(struct super_block___201 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___201 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___201 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___201 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___201 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___201 *, unsigned int);
};

struct wait_page_queue___96 {
	struct page___206 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___96;

struct address_space_operations___201 {
	int (*writepage)(struct page___206 *, struct writeback_control___3 *);
	int (*readpage)(struct file___201 *, struct page___206 *);
	int (*writepages)(struct address_space___201 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___206 *);
	int (*readpages)(struct file___201 *, struct address_space___201 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___96 *);
	int (*write_begin)(struct file___201 *, struct address_space___201 *, loff_t, unsigned int, unsigned int, struct page___206 **, void **);
	int (*write_end)(struct file___201 *, struct address_space___201 *, loff_t, unsigned int, unsigned int, struct page___206 *, void *);
	sector_t (*bmap)(struct address_space___201 *, sector_t);
	void (*invalidatepage)(struct page___206 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___206 *, gfp_t);
	void (*freepage)(struct page___206 *);
	ssize_t (*direct_IO)(struct kiocb___201 *, struct iov_iter___122 *);
	int (*migratepage)(struct address_space___201 *, struct page___206 *, struct page___206 *, enum migrate_mode);
	bool (*isolate_page)(struct page___206 *, isolate_mode_t);
	void (*putback_page)(struct page___206 *);
	int (*launder_page)(struct page___206 *);
	int (*is_partially_uptodate)(struct page___206 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___206 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___201 *, struct page___206 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___201 *, sector_t *);
	void (*swap_deactivate)(struct file___201 *);
};

struct readahead_control___96 {
	struct file___201 *file;
	struct address_space___201 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct iov_iter___122 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___3 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___66 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___201 {
	struct dentry___201 * (*lookup)(struct inode___201 *, struct dentry___201 *, unsigned int);
	const char * (*get_link)(struct dentry___201 *, struct inode___201 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___201 *, int);
	struct posix_acl * (*get_acl)(struct inode___201 *, int, bool);
	int (*readlink)(struct dentry___201 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___201 *, struct dentry___201 *, umode_t, bool);
	int (*link)(struct dentry___201 *, struct inode___201 *, struct dentry___201 *);
	int (*unlink)(struct inode___201 *, struct dentry___201 *);
	int (*symlink)(struct user_namespace *, struct inode___201 *, struct dentry___201 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___201 *, struct dentry___201 *, umode_t);
	int (*rmdir)(struct inode___201 *, struct dentry___201 *);
	int (*mknod)(struct user_namespace *, struct inode___201 *, struct dentry___201 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___201 *, struct dentry___201 *, struct inode___201 *, struct dentry___201 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___201 *, struct iattr___201 *);
	int (*getattr)(struct user_namespace *, const struct path___201 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___201 *, char *, size_t);
	int (*fiemap)(struct inode___201 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___201 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___201 *, struct dentry___201 *, struct file___201 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___201 *, struct dentry___201 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___201 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___201 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___201 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___201 {
	void (*fl_copy_lock)(struct file_lock___201 *, struct file_lock___201 *);
	void (*fl_release_private)(struct file_lock___201 *);
};

struct lock_manager_operations___201;

struct file_lock___201 {
	struct file_lock___201 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___201 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___201 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___201 *fl_ops;
	const struct lock_manager_operations___201 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___201 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___201 *);
	int (*lm_grant)(struct file_lock___201 *, int);
	bool (*lm_break)(struct file_lock___201 *);
	int (*lm_change)(struct file_lock___201 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___201 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___201 *);
};

struct fasync_struct___201 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___201 *fa_next;
	struct file___201 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___201 {
	struct inode___201 * (*alloc_inode)(struct super_block___201 *);
	void (*destroy_inode)(struct inode___201 *);
	void (*free_inode)(struct inode___201 *);
	void (*dirty_inode)(struct inode___201 *, int);
	int (*write_inode)(struct inode___201 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___201 *);
	void (*evict_inode)(struct inode___201 *);
	void (*put_super)(struct super_block___201 *);
	int (*sync_fs)(struct super_block___201 *, int);
	int (*freeze_super)(struct super_block___201 *);
	int (*freeze_fs)(struct super_block___201 *);
	int (*thaw_super)(struct super_block___201 *);
	int (*unfreeze_fs)(struct super_block___201 *);
	int (*statfs)(struct dentry___201 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___201 *, int *, char *);
	void (*umount_begin)(struct super_block___201 *);
	int (*show_options)(struct seq_file___177 *, struct dentry___201 *);
	int (*show_devname)(struct seq_file___177 *, struct dentry___201 *);
	int (*show_path)(struct seq_file___177 *, struct dentry___201 *);
	int (*show_stats)(struct seq_file___177 *, struct dentry___201 *);
	ssize_t (*quota_read)(struct super_block___201 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___201 *, int, const char *, size_t, loff_t);
	struct dquot___201 ** (*get_dquots)(struct inode___201 *);
	long int (*nr_cached_objects)(struct super_block___201 *, struct shrink_control___86 *);
	long int (*free_cached_objects)(struct super_block___201 *, struct shrink_control___86 *);
	struct file___201 * (*real_loop)(struct file___201 *);
};

struct seq_operations___177 {
	void * (*start)(struct seq_file___177 *, loff_t *);
	void (*stop)(struct seq_file___177 *, void *);
	void * (*next)(struct seq_file___177 *, void *, loff_t *);
	int (*show)(struct seq_file___177 *, void *);
};

struct pipe_buf_operations___66;

struct pipe_buffer___66 {
	struct page___206 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___66 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___66 {
	int (*confirm)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
	void (*release)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
	bool (*try_steal)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
	bool (*get)(struct pipe_inode_info___66 *, struct pipe_buffer___66 *);
};

struct splice_desc___3 {
	size_t total_len;
	unsigned int len;
	unsigned int flags;
	union {
		void *userptr;
		struct file___201 *file;
		void *data;
	} u;
	loff_t pos;
	loff_t *opos;
	size_t num_spliced;
	bool need_wakeup;
};

typedef int splice_actor___3(struct pipe_inode_info___66 *, struct pipe_buffer___66 *, struct splice_desc___3 *);

struct dev_pagemap_ops___196 {
	void (*page_free)(struct page___206 *);
	void (*kill)(struct dev_pagemap___196 *);
	void (*cleanup)(struct dev_pagemap___196 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___196 *);
};

struct fwnode_reference_args___165;

struct fwnode_endpoint___165;

struct fwnode_operations___165 {
	struct fwnode_handle___165 * (*get)(struct fwnode_handle___165 *);
	void (*put)(struct fwnode_handle___165 *);
	bool (*device_is_available)(const struct fwnode_handle___165 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___165 *, const struct device___165 *);
	bool (*property_present)(const struct fwnode_handle___165 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___165 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___165 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___165 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*get_parent)(const struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*get_next_child_node)(const struct fwnode_handle___165 *, struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*get_named_child_node)(const struct fwnode_handle___165 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___165 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___165 *);
	struct fwnode_handle___165 * (*graph_get_next_endpoint)(const struct fwnode_handle___165 *, struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*graph_get_remote_endpoint)(const struct fwnode_handle___165 *);
	struct fwnode_handle___165 * (*graph_get_port_parent)(struct fwnode_handle___165 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___165 *, struct fwnode_endpoint___165 *);
	int (*add_links)(struct fwnode_handle___165 *);
};

struct fwnode_endpoint___165 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___165 *local_fwnode;
};

struct fwnode_reference_args___165 {
	struct fwnode_handle___165 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___185 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___185 *);
	int (*get)(char *, const struct kernel_param___185 *);
	void (*free)(void *);
};

struct kparam_array___185;

struct kernel_param___185 {
	const char *name;
	struct module___185 *mod;
	const struct kernel_param_ops___185 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___185 *arr;
	};
};

struct kparam_array___185 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___185 *ops;
	void *elem;
};

struct module_attribute___185 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___185 *, struct module_kobject___185 *, char *);
	ssize_t (*store)(struct module_attribute___185 *, struct module_kobject___185 *, const char *, size_t);
	void (*setup)(struct module___185 *, const char *);
	int (*test)(struct module___185 *);
	void (*free)(struct module___185 *);
};

struct hvc_struct___2;

struct console___8 {
	struct list_head list;
	struct hvc_struct___2 *hvc;
	struct winsize ws;
	u32 vtermno;
};

typedef struct poll_table_struct___132 poll_table___35;

struct virtio_device___5;

struct virtqueue___5 {
	struct list_head list;
	void (*callback)(struct virtqueue___5 *);
	const char *name;
	struct virtio_device___5 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct virtio_config_ops___5;

struct virtio_device___5 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___165 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___5 *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t___5(struct virtqueue___5 *);

struct virtio_config_ops___5 {
	void (*get)(struct virtio_device___5 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___5 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___5 *);
	u8 (*get_status)(struct virtio_device___5 *);
	void (*set_status)(struct virtio_device___5 *, u8);
	void (*reset)(struct virtio_device___5 *);
	int (*find_vqs)(struct virtio_device___5 *, unsigned int, struct virtqueue___5 **, vq_callback_t___5 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___5 *);
	u64 (*get_features)(struct virtio_device___5 *);
	int (*finalize_features)(struct virtio_device___5 *);
	const char * (*bus_name)(struct virtio_device___5 *);
	int (*set_vq_affinity)(struct virtqueue___5 *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___5 *, int);
	bool (*get_shm_region)(struct virtio_device___5 *, struct virtio_shm_region *, u8);
};

struct virtio_driver___3 {
	struct device_driver___165 driver;
	const struct virtio_device_id *id_table;
	const unsigned int *feature_table;
	unsigned int feature_table_size;
	const unsigned int *feature_table_legacy;
	unsigned int feature_table_size_legacy;
	int (*validate)(struct virtio_device___5 *);
	int (*probe)(struct virtio_device___5 *);
	void (*scan)(struct virtio_device___5 *);
	void (*remove)(struct virtio_device___5 *);
	void (*config_changed)(struct virtio_device___5 *);
	int (*freeze)(struct virtio_device___5 *);
	int (*restore)(struct virtio_device___5 *);
};

struct virtio_console_config {
	__virtio16 cols;
	__virtio16 rows;
	__virtio32 max_nr_ports;
	__virtio32 emerg_wr;
};

struct virtio_console_control {
	__virtio32 id;
	__virtio16 event;
	__virtio16 value;
};

struct tty_operations___21 {
	struct tty_struct___20 * (*lookup)(struct tty_driver___21 *, struct file___201 *, int);
	int (*install)(struct tty_driver___21 *, struct tty_struct___20 *);
	void (*remove)(struct tty_driver___21 *, struct tty_struct___20 *);
	int (*open)(struct tty_struct___20 *, struct file___201 *);
	void (*close)(struct tty_struct___20 *, struct file___201 *);
	void (*shutdown)(struct tty_struct___20 *);
	void (*cleanup)(struct tty_struct___20 *);
	int (*write)(struct tty_struct___20 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___20 *, unsigned char);
	void (*flush_chars)(struct tty_struct___20 *);
	unsigned int (*write_room)(struct tty_struct___20 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___20 *);
	int (*ioctl)(struct tty_struct___20 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___20 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___20 *, struct ktermios *);
	void (*throttle)(struct tty_struct___20 *);
	void (*unthrottle)(struct tty_struct___20 *);
	void (*stop)(struct tty_struct___20 *);
	void (*start)(struct tty_struct___20 *);
	void (*hangup)(struct tty_struct___20 *);
	int (*break_ctl)(struct tty_struct___20 *, int);
	void (*flush_buffer)(struct tty_struct___20 *);
	void (*set_ldisc)(struct tty_struct___20 *);
	void (*wait_until_sent)(struct tty_struct___20 *, int);
	void (*send_xchar)(struct tty_struct___20 *, char);
	int (*tiocmget)(struct tty_struct___20 *);
	int (*tiocmset)(struct tty_struct___20 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___20 *, struct winsize *);
	int (*get_icount)(struct tty_struct___20 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___20 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___20 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___20 *, struct seq_file___177 *);
	int (*poll_init)(struct tty_driver___21 *, int, char *);
	int (*poll_get_char)(struct tty_driver___21 *, int);
	void (*poll_put_char)(struct tty_driver___21 *, int, char);
	int (*proc_show)(struct seq_file___177 *, void *);
};

struct tty_driver___21 {
	int magic;
	struct kref kref;
	struct cdev___48 **cdevs;
	struct module___185 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___21 *other;
	struct tty_struct___20 **ttys;
	struct tty_port___21 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___21 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___20;

struct tty_port_client_operations___20;

struct tty_port___21 {
	struct tty_bufhead buf;
	struct tty_struct___20 *tty;
	struct tty_struct___20 *itty;
	const struct tty_port_operations___20 *ops;
	const struct tty_port_client_operations___20 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___20 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___20 *);
	void (*close)(struct tty_struct___20 *);
	void (*flush_buffer)(struct tty_struct___20 *);
	ssize_t (*read)(struct tty_struct___20 *, struct file___201 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___20 *, struct file___201 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___20 *, struct file___201 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___20 *, struct file___201 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___20 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___20 *, struct file___201 *, struct poll_table_struct___132 *);
	int (*hangup)(struct tty_struct___20 *);
	void (*receive_buf)(struct tty_struct___20 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___20 *);
	void (*dcd_change)(struct tty_struct___20 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___20 *, const unsigned char *, const char *, int);
	struct module___185 *owner;
};

struct tty_ldisc___20 {
	struct tty_ldisc_ops___20 *ops;
	struct tty_struct___20 *tty;
};

struct tty_port_operations___20 {
	int (*carrier_raised)(struct tty_port___21 *);
	void (*dtr_rts)(struct tty_port___21 *, int);
	void (*shutdown)(struct tty_port___21 *);
	int (*activate)(struct tty_port___21 *, struct tty_struct___20 *);
	void (*destruct)(struct tty_port___21 *);
};

struct tty_port_client_operations___20 {
	int (*receive_buf)(struct tty_port___21 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___21 *);
};

struct hv_ops___2;

struct hvc_struct___2 {
	struct tty_port___21 port;
	spinlock_t lock;
	int index;
	int do_wakeup;
	char *outbuf;
	int outbuf_size;
	int n_outbuf;
	uint32_t vtermno;
	const struct hv_ops___2 *ops;
	int irq_requested;
	int data;
	struct winsize ws;
	struct work_struct tty_resize;
	struct list_head next;
	long unsigned int flags;
};

struct hv_ops___2 {
	int (*get_chars)(uint32_t, char *, int);
	int (*put_chars)(uint32_t, const char *, int);
	int (*flush)(uint32_t, bool);
	int (*notifier_add)(struct hvc_struct___2 *, int);
	void (*notifier_del)(struct hvc_struct___2 *, int);
	void (*notifier_hangup)(struct hvc_struct___2 *, int);
	int (*tiocmget)(struct hvc_struct___2 *);
	int (*tiocmset)(struct hvc_struct___2 *, unsigned int, unsigned int);
	void (*dtr_rts)(struct hvc_struct___2 *, int);
};

struct ports_driver_data {
	struct class___165 *class;
	struct dentry___201 *debugfs_dir;
	struct list_head portdevs;
	unsigned int next_vtermno;
	struct list_head consoles;
};

struct port_buffer {
	char *buf;
	size_t size;
	size_t len;
	size_t offset;
	dma_addr_t dma;
	struct device___165 *dev;
	struct list_head list;
	unsigned int sgpages;
	struct scatterlist sg[0];
};

struct ports_device {
	struct list_head list;
	struct work_struct control_work;
	struct work_struct config_work;
	struct list_head ports;
	spinlock_t ports_lock;
	spinlock_t c_ivq_lock;
	spinlock_t c_ovq_lock;
	u32 max_nr_ports;
	struct virtio_device___5 *vdev;
	struct virtqueue___5 *c_ivq;
	struct virtqueue___5 *c_ovq;
	struct virtio_console_control cpkt;
	struct virtqueue___5 **in_vqs;
	struct virtqueue___5 **out_vqs;
	int chr_major;
};

struct port_stats {
	long unsigned int bytes_sent;
	long unsigned int bytes_received;
	long unsigned int bytes_discarded;
};

struct port {
	struct list_head list;
	struct ports_device *portdev;
	struct port_buffer *inbuf;
	spinlock_t inbuf_lock;
	spinlock_t outvq_lock;
	struct virtqueue___5 *in_vq;
	struct virtqueue___5 *out_vq;
	struct dentry___201 *debugfs_file;
	struct port_stats stats;
	struct console___8 cons;
	struct cdev___48 *cdev;
	struct device___165 *dev;
	struct kref kref;
	wait_queue_head_t waitqueue;
	char *name;
	struct fasync_struct___201 *async_queue;
	u32 id;
	bool outvq_full;
	bool host_connected;
	bool guest_connected;
};

struct sg_list {
	unsigned int n;
	unsigned int size;
	size_t len;
	struct scatterlist *sg;
};

enum tpm2_startup_types {
	TPM2_SU_CLEAR = 0,
	TPM2_SU_STATE = 1,
};

enum tpm_chip_flags {
	TPM_CHIP_FLAG_TPM2 = 2,
	TPM_CHIP_FLAG_IRQ = 4,
	TPM_CHIP_FLAG_VIRTUAL = 8,
	TPM_CHIP_FLAG_HAVE_TIMEOUTS = 16,
	TPM_CHIP_FLAG_ALWAYS_POWERED = 32,
	TPM_CHIP_FLAG_FIRMWARE_POWER_MANAGED = 64,
};

struct file_priv {
	struct tpm_chip *chip;
	struct tpm_space *space;
	struct mutex buffer_mutex;
	struct timer_list user_read_timer;
	struct work_struct timeout_work;
	struct work_struct async_work;
	wait_queue_head_t async_wait;
	ssize_t response_length;
	bool response_read;
	bool command_enqueued;
	u8 data_buffer[4096];
};

struct file_priv___2 {
	struct tpm_chip___3 *chip;
	struct tpm_space *space;
	struct mutex buffer_mutex;
	struct timer_list user_read_timer;
	struct work_struct timeout_work;
	struct work_struct async_work;
	wait_queue_head_t async_wait;
	ssize_t response_length;
	bool response_read;
	bool command_enqueued;
	u8 data_buffer[4096];
};

enum TPM_OPS_FLAGS {
	TPM_OPS_AUTO_STARTUP = 1,
};

struct tpm_chip___4;

struct tpm_class_ops___4 {
	unsigned int flags;
	const u8 req_complete_mask;
	const u8 req_complete_val;
	bool (*req_canceled)(struct tpm_chip___4 *, u8);
	int (*recv)(struct tpm_chip___4 *, u8 *, size_t);
	int (*send)(struct tpm_chip___4 *, u8 *, size_t);
	void (*cancel)(struct tpm_chip___4 *);
	u8 (*status)(struct tpm_chip___4 *);
	void (*update_timeouts)(struct tpm_chip___4 *, long unsigned int *);
	void (*update_durations)(struct tpm_chip___4 *, long unsigned int *);
	int (*go_idle)(struct tpm_chip___4 *);
	int (*cmd_ready)(struct tpm_chip___4 *);
	int (*request_locality)(struct tpm_chip___4 *, int);
	int (*relinquish_locality)(struct tpm_chip___4 *, int);
	void (*clk_enable)(struct tpm_chip___4 *, bool);
};

struct tpm_chip_seqops___4 {
	struct tpm_chip___4 *chip;
	const struct seq_operations___172 *seqops;
};

struct tpm_chip___4 {
	struct device___156 dev;
	struct device___156 devs;
	struct cdev___43 cdev;
	struct cdev___43 cdevs;
	struct rw_semaphore ops_sem;
	const struct tpm_class_ops___4 *ops;
	struct tpm_bios_log log;
	struct tpm_chip_seqops___4 bin_log_seqops;
	struct tpm_chip_seqops___4 ascii_log_seqops;
	unsigned int flags;
	int dev_num;
	long unsigned int is_open;
	char hwrng_name[64];
	struct hwrng hwrng;
	struct mutex tpm_mutex;
	long unsigned int timeout_a;
	long unsigned int timeout_b;
	long unsigned int timeout_c;
	long unsigned int timeout_d;
	bool timeout_adjusted;
	long unsigned int duration[4];
	bool duration_adjusted;
	struct dentry___196 *bios_dir[3];
	const struct attribute_group___184 *groups[8];
	unsigned int groups_cnt;
	u32 nr_allocated_banks;
	struct tpm_bank_info *allocated_banks;
	acpi_handle acpi_dev_handle;
	char ppi_version[4];
	struct tpm_space work_space;
	u32 last_cc;
	u32 nr_commands;
	u32 *cc_attrs_tbl;
	int locality;
};

enum tpm2_timeouts {
	TPM2_TIMEOUT_A = 750,
	TPM2_TIMEOUT_B = 2000,
	TPM2_TIMEOUT_C = 200,
	TPM2_TIMEOUT_D = 30,
	TPM2_DURATION_SHORT = 20,
	TPM2_DURATION_MEDIUM = 750,
	TPM2_DURATION_LONG = 2000,
	TPM2_DURATION_LONG_LONG = 300000,
	TPM2_DURATION_DEFAULT = 120000,
};

enum tpm_timeout {
	TPM_TIMEOUT = 5,
	TPM_TIMEOUT_RETRY = 100,
	TPM_TIMEOUT_RANGE_US = 300,
	TPM_TIMEOUT_POLL = 1,
	TPM_TIMEOUT_USECS_MIN = 100,
	TPM_TIMEOUT_USECS_MAX = 500,
};

struct stclear_flags_t {
	__be16 tag;
	u8 deactivated;
	u8 disableForceClear;
	u8 physicalPresence;
	u8 physicalPresenceLock;
	u8 bGlobalLock;
} __attribute__((packed));

struct tpm1_version {
	u8 major;
	u8 minor;
	u8 rev_major;
	u8 rev_minor;
};

struct tpm1_version2 {
	__be16 tag;
	struct tpm1_version version;
};

struct timeout_t {
	__be32 a;
	__be32 b;
	__be32 c;
	__be32 d;
};

struct duration_t {
	__be32 tpm_short;
	__be32 tpm_medium;
	__be32 tpm_long;
};

struct permanent_flags_t {
	__be16 tag;
	u8 disable;
	u8 ownership;
	u8 deactivated;
	u8 readPubek;
	u8 disableOwnerClear;
	u8 allowMaintenance;
	u8 physicalPresenceLifetimeLock;
	u8 physicalPresenceHWEnable;
	u8 physicalPresenceCMDEnable;
	u8 CEKPUsed;
	u8 TPMpost;
	u8 TPMpostLock;
	u8 FIPS;
	u8 operator;
	u8 enableRevokeEK;
	u8 nvLocked;
	u8 readSRKPub;
	u8 tpmEstablished;
	u8 maintenanceDone;
	u8 disableFullDALogicInfo;
};

typedef union {
	struct permanent_flags_t perm_flags;
	struct stclear_flags_t stclear_flags;
	__u8 owned;
	__be32 num_pcrs;
	struct tpm1_version version1;
	struct tpm1_version2 version2;
	__be32 manufacturer_id;
	struct timeout_t timeout;
	struct duration_t duration;
} cap_t;

enum tpm_capabilities {
	TPM_CAP_FLAG = 4,
	TPM_CAP_PROP = 5,
	TPM_CAP_VERSION_1_1 = 6,
	TPM_CAP_VERSION_1_2 = 26,
};

enum tpm_sub_capabilities {
	TPM_CAP_PROP_PCR = 257,
	TPM_CAP_PROP_MANUFACTURER = 259,
	TPM_CAP_FLAG_PERM = 264,
	TPM_CAP_FLAG_VOL = 265,
	TPM_CAP_PROP_OWNER = 273,
	TPM_CAP_PROP_TIS_TIMEOUT = 277,
	TPM_CAP_PROP_TIS_DURATION = 288,
};

struct tpm1_get_random_out {
	__be32 rng_data_len;
	u8 rng_data[128];
};

enum tpm2_const {
	TPM2_PLATFORM_PCR = 24,
	TPM2_PCR_SELECT_MIN = 3,
};

enum tpm2_capabilities {
	TPM2_CAP_HANDLES = 1,
	TPM2_CAP_COMMANDS = 2,
	TPM2_CAP_PCRS = 5,
	TPM2_CAP_TPM_PROPERTIES = 6,
};

enum tpm2_properties {
	TPM_PT_TOTAL_COMMANDS = 297,
};

enum tpm2_cc_attrs {
	TPM2_CC_ATTR_CHANDLES = 25,
	TPM2_CC_ATTR_RHANDLE = 28,
};

struct tpm2_pcr_read_out {
	__be32 update_cnt;
	__be32 pcr_selects_cnt;
	__be16 hash_alg;
	u8 pcr_select_size;
	u8 pcr_select[3];
	__be32 digests_cnt;
	__be16 digest_size;
	u8 digest[0];
} __attribute__((packed));

struct tpm2_null_auth_area {
	__be32 handle;
	__be16 nonce_size;
	u8 attributes;
	__be16 auth_size;
} __attribute__((packed));

struct tpm2_get_random_out {
	__be16 size;
	u8 buffer[128];
};

struct tpm2_get_cap_out {
	u8 more_data;
	__be32 subcap_id;
	__be32 property_cnt;
	__be32 property_id;
	__be32 value;
} __attribute__((packed));

struct tpm2_pcr_selection {
	__be16 hash_alg;
	u8 size_of_select;
	u8 pcr_select[3];
};

struct tpmrm_priv {
	struct file_priv priv;
	struct tpm_space space;
};

enum tpm2_handle_types {
	TPM2_HT_HMAC_SESSION = 33554432,
	TPM2_HT_POLICY_SESSION = 50331648,
	TPM2_HT_TRANSIENT = 2147483648,
};

struct tpm2_context {
	__be64 sequence;
	__be32 saved_handle;
	__be32 hierarchy;
	__be16 blob_size;
} __attribute__((packed));

struct tpm2_cap_handles {
	u8 more_data;
	__be32 capability;
	__be32 count;
	__be32 handles[0];
} __attribute__((packed));

struct tpm_readpubek_out {
	u8 algorithm[4];
	u8 encscheme[2];
	u8 sigscheme[2];
	__be32 paramsize;
	u8 parameters[12];
	__be32 keysize;
	u8 modulus[256];
	u8 checksum[20];
};

struct tpm_pcr_attr {
	int alg_id;
	int pcr;
	struct device_attribute___13 attr;
};

struct tcpa_event {
	u32 pcr_index;
	u32 event_type;
	u8 pcr_value[20];
	u32 event_size;
	u8 event_data[0];
};

enum tcpa_event_types {
	PREBOOT = 0,
	POST_CODE = 1,
	UNUSED = 2,
	NO_ACTION = 3,
	SEPARATOR = 4,
	ACTION = 5,
	EVENT_TAG = 6,
	SCRTM_CONTENTS = 7,
	SCRTM_VERSION = 8,
	CPU_MICROCODE = 9,
	PLATFORM_CONFIG_FLAGS = 10,
	TABLE_OF_DEVICES = 11,
	COMPACT_HASH = 12,
	IPL = 13,
	IPL_PARTITION_DATA = 14,
	NONHOST_CODE = 15,
	NONHOST_CONFIG = 16,
	NONHOST_INFO = 17,
};

struct tcpa_pc_event {
	u32 event_id;
	u32 event_size;
	u8 event_data[0];
};

enum tcpa_pc_event_ids {
	SMBIOS = 1,
	BIS_CERT = 2,
	POST_BIOS_ROM = 3,
	ESCD = 4,
	CMOS = 5,
	NVRAM = 6,
	OPTION_ROM_EXEC = 7,
	OPTION_ROM_CONFIG = 8,
	OPTION_ROM_MICROCODE = 10,
	S_CRTM_VERSION = 11,
	S_CRTM_CONTENTS = 12,
	POST_CONTENTS = 13,
	HOST_TABLE_OF_DEVICES = 14,
};

struct tcg_efi_specid_event_algs {
	u16 alg_id;
	u16 digest_size;
};

struct tcg_efi_specid_event_head {
	u8 signature[16];
	u32 platform_class;
	u8 spec_version_minor;
	u8 spec_version_major;
	u8 spec_errata;
	u8 uintnsize;
	u32 num_algs;
	struct tcg_efi_specid_event_algs digest_sizes[0];
};

struct tcg_pcr_event {
	u32 pcr_idx;
	u32 event_type;
	u8 digest[20];
	u32 event_size;
	u8 event[0];
};

struct tcg_event_field {
	u32 event_size;
	u8 event[0];
};

struct tcg_pcr_event2_head {
	u32 pcr_idx;
	u32 event_type;
	u32 count;
	struct tpm_digest digests[0];
};

struct acpi_table_tpm2 {
	struct acpi_table_header header;
	u16 platform_class;
	u16 reserved;
	u64 control_address;
	u32 start_method;
} __attribute__((packed));

struct acpi_tpm2_phy {
	u8 start_method_specific[12];
	u32 log_area_minimum_length;
	u64 log_area_start_address;
};

enum bios_platform_class {
	BIOS_CLIENT = 0,
	BIOS_SERVER = 1,
};

struct client_hdr {
	u32 log_max_len;
	u64 log_start_addr;
} __attribute__((packed));

struct server_hdr {
	u16 reserved;
	u64 log_max_len;
	u64 log_start_addr;
} __attribute__((packed));

struct acpi_tcpa {
	struct acpi_table_header hdr;
	u16 platform_class;
	union {
		struct client_hdr client;
		struct server_hdr server;
	};
} __attribute__((packed));

struct linux_efi_tpm_eventlog {
	u32 size;
	u32 final_events_preboot_size;
	u8 version;
	u8 log[0];
};

struct efi_tcg2_final_events_table {
	u64 version;
	u64 nr_events;
	u8 events[0];
};

struct module_version_attribute___6 {
	struct module_attribute___185 mattr;
	const char *module_name;
	const char *version;
};

enum tis_access {
	TPM_ACCESS_VALID = 128,
	TPM_ACCESS_ACTIVE_LOCALITY = 32,
	TPM_ACCESS_REQUEST_PENDING = 4,
	TPM_ACCESS_REQUEST_USE = 2,
};

enum tis_status {
	TPM_STS_VALID = 128,
	TPM_STS_COMMAND_READY = 64,
	TPM_STS_GO = 32,
	TPM_STS_DATA_AVAIL = 16,
	TPM_STS_DATA_EXPECT = 8,
	TPM_STS_READ_ZERO = 35,
};

enum tis_int_flags {
	TPM_GLOBAL_INT_ENABLE = 2147483648,
	TPM_INTF_BURST_COUNT_STATIC = 256,
	TPM_INTF_CMD_READY_INT = 128,
	TPM_INTF_INT_EDGE_FALLING = 64,
	TPM_INTF_INT_EDGE_RISING = 32,
	TPM_INTF_INT_LEVEL_LOW = 16,
	TPM_INTF_INT_LEVEL_HIGH = 8,
	TPM_INTF_LOCALITY_CHANGE_INT = 4,
	TPM_INTF_STS_VALID_INT = 2,
	TPM_INTF_DATA_AVAIL_INT = 1,
};

enum tis_defaults {
	TIS_MEM_LEN = 20480,
	TIS_SHORT_TIMEOUT = 750,
	TIS_LONG_TIMEOUT = 2000,
	TIS_TIMEOUT_MIN_ATML = 14700,
	TIS_TIMEOUT_MAX_ATML = 15000,
};

enum tpm_tis_flags {
	TPM_TIS_ITPM_WORKAROUND = 1,
	TPM_TIS_INVALID_STATUS = 2,
};

struct tpm_tis_phy_ops;

struct tpm_tis_data {
	u16 manufacturer_id;
	int locality;
	int irq;
	bool irq_tested;
	long unsigned int flags;
	void *ilb_base_addr;
	u16 clkrun_enabled;
	wait_queue_head_t int_queue;
	wait_queue_head_t read_queue;
	const struct tpm_tis_phy_ops *phy_ops;
	short unsigned int rng_quality;
	unsigned int timeout_min;
	unsigned int timeout_max;
};

struct tpm_tis_phy_ops {
	int (*read_bytes)(struct tpm_tis_data *, u32, u16, u8 *);
	int (*write_bytes)(struct tpm_tis_data *, u32, u16, const u8 *);
	int (*read16)(struct tpm_tis_data *, u32, u16 *);
	int (*read32)(struct tpm_tis_data *, u32, u32 *);
	int (*write32)(struct tpm_tis_data *, u32, u32);
};

struct tis_vendor_durations_override {
	u32 did_vid;
	struct tpm1_version version;
	long unsigned int durations[3];
};

struct tis_vendor_timeout_override {
	u32 did_vid;
	long unsigned int timeout_us[4];
};

struct tpm_info {
	struct resource res;
	int irq;
};

struct tpm_tis_tcg_phy {
	struct tpm_tis_data priv;
	void *iobase;
};

enum crb_defaults {
	CRB_ACPI_START_REVISION_ID = 1,
	CRB_ACPI_START_INDEX = 1,
};

enum crb_loc_ctrl {
	CRB_LOC_CTRL_REQUEST_ACCESS = 1,
	CRB_LOC_CTRL_RELINQUISH = 2,
};

enum crb_loc_state {
	CRB_LOC_STATE_LOC_ASSIGNED = 2,
	CRB_LOC_STATE_TPM_REG_VALID_STS = 128,
};

enum crb_ctrl_req {
	CRB_CTRL_REQ_CMD_READY = 1,
	CRB_CTRL_REQ_GO_IDLE = 2,
};

enum crb_ctrl_sts {
	CRB_CTRL_STS_ERROR = 1,
	CRB_CTRL_STS_TPM_IDLE = 2,
};

enum crb_start {
	CRB_START_INVOKE = 1,
};

enum crb_cancel {
	CRB_CANCEL_INVOKE = 1,
};

struct crb_regs_head {
	u32 loc_state;
	u32 reserved1;
	u32 loc_ctrl;
	u32 loc_sts;
	u8 reserved2[32];
	u64 intf_id;
	u64 ctrl_ext;
};

struct crb_regs_tail {
	u32 ctrl_req;
	u32 ctrl_sts;
	u32 ctrl_cancel;
	u32 ctrl_start;
	u32 ctrl_int_enable;
	u32 ctrl_int_sts;
	u32 ctrl_cmd_size;
	u32 ctrl_cmd_pa_low;
	u32 ctrl_cmd_pa_high;
	u32 ctrl_rsp_size;
	u64 ctrl_rsp_pa;
};

enum crb_status {
	CRB_DRV_STS_COMPLETE = 1,
};

struct crb_priv {
	u32 sm;
	const char *hid;
	struct crb_regs_head *regs_h;
	struct crb_regs_tail *regs_t;
	u8 *cmd;
	u8 *rsp;
	u32 cmd_size;
	u32 smc_func_id;
};

struct tpm2_crb_smc {
	u32 interrupt;
	u8 interrupt_flags;
	u8 op_flags;
	u16 reserved2;
	u32 smc_func_id;
};

enum io_pgtable_fmt {
	ARM_32_LPAE_S1 = 0,
	ARM_32_LPAE_S2 = 1,
	ARM_64_LPAE_S1 = 2,
	ARM_64_LPAE_S2 = 3,
	ARM_V7S = 4,
	ARM_MALI_LPAE = 5,
	AMD_IOMMU_V1 = 6,
	APPLE_DART = 7,
	IO_PGTABLE_NUM_FMTS = 8,
};

struct iommu_flush_ops {
	void (*tlb_flush_all)(void *);
	void (*tlb_flush_walk)(long unsigned int, size_t, size_t, void *);
	void (*tlb_add_page)(struct iommu_iotlb_gather___4 *, long unsigned int, size_t, void *);
};

struct io_pgtable_cfg {
	long unsigned int quirks;
	long unsigned int pgsize_bitmap;
	unsigned int ias;
	unsigned int oas;
	bool coherent_walk;
	const struct iommu_flush_ops *tlb;
	struct device___155 *iommu_dev;
	union {
		struct {
			u64 ttbr;
			struct {
				u32 ips: 3;
				u32 tg: 2;
				u32 sh: 2;
				u32 orgn: 2;
				u32 irgn: 2;
				u32 tsz: 6;
			} tcr;
			u64 mair;
		} arm_lpae_s1_cfg;
		struct {
			u64 vttbr;
			struct {
				u32 ps: 3;
				u32 tg: 2;
				u32 sh: 2;
				u32 orgn: 2;
				u32 irgn: 2;
				u32 sl: 2;
				u32 tsz: 6;
			} vtcr;
		} arm_lpae_s2_cfg;
		struct {
			u32 ttbr;
			u32 tcr;
			u32 nmrr;
			u32 prrr;
		} arm_v7s_cfg;
		struct {
			u64 transtab;
			u64 memattr;
		} arm_mali_lpae_cfg;
		struct {
			u64 ttbr[4];
			u32 n_ttbrs;
		} apple_dart_cfg;
	};
};

struct io_pgtable_ops {
	int (*map)(struct io_pgtable_ops *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct io_pgtable_ops *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct io_pgtable_ops *, long unsigned int, size_t, struct iommu_iotlb_gather___4 *);
	size_t (*unmap_pages)(struct io_pgtable_ops *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___4 *);
	phys_addr_t (*iova_to_phys)(struct io_pgtable_ops *, long unsigned int);
};

struct io_pgtable {
	enum io_pgtable_fmt fmt;
	void *cookie;
	struct io_pgtable_cfg cfg;
	struct io_pgtable_ops ops;
};

enum qcom_iommu_clk {
	CLK_IFACE = 0,
	CLK_BUS = 1,
	CLK_TBU = 2,
	CLK_NUM = 3,
};

struct qcom_iommu_ctx;

struct qcom_iommu_dev {
	struct iommu_device___6 iommu;
	struct device___155 *dev;
	struct clk_bulk_data clks[3];
	void *local_base;
	u32 sec_id;
	u8 num_ctxs;
	struct qcom_iommu_ctx *ctxs[0];
};

struct qcom_iommu_ctx {
	struct device___155 *dev;
	void *base;
	bool secure_init;
	u8 asid;
	struct iommu_domain___6 *domain;
};

struct qcom_iommu_domain {
	struct io_pgtable_ops *pgtbl_ops;
	spinlock_t pgtbl_lock;
	struct mutex init_mutex;
	struct iommu_domain___6 domain;
	struct qcom_iommu_dev *iommu;
	struct iommu_fwspec___6 *fwspec;
};

struct irq_desc___43;

typedef void (*irq_flow_handler_t___43)(struct irq_desc___43 *);

struct msi_desc___13;

struct irq_common_data___13 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___13 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___42;

struct irq_domain___41;

struct irq_data___42 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___13 *common;
	struct irq_chip___42 *chip;
	struct irq_domain___41 *domain;
	struct irq_data___42 *parent_data;
	void *chip_data;
};

struct kset___190;

struct kobj_type___190;

struct kernfs_node___190;

struct kobject___190 {
	const char *name;
	struct list_head entry;
	struct kobject___190 *parent;
	struct kset___190 *kset;
	struct kobj_type___190 *ktype;
	struct kernfs_node___190 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___29;

struct module___186;

struct irq_desc___43 {
	struct irq_common_data___13 irq_common_data;
	struct irq_data___42 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___43 handle_irq;
	struct irqaction___29 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___190 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___186 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___202;

struct super_block___202;

struct file_system_type___202 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___202 * (*mount)(struct file_system_type___202 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___202 *);
	struct module___186 *owner;
	struct file_system_type___202 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___202;

struct kiocb___202;

struct iov_iter___123;

struct poll_table_struct___133;

struct vm_area_struct___207;

struct inode___202;

struct file_lock___202;

struct page___207;

struct seq_file___178;

struct file_operations___203 {
	struct module___186 *owner;
	loff_t (*llseek)(struct file___202 *, loff_t, int);
	ssize_t (*read)(struct file___202 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___202 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___202 *, struct iov_iter___123 *);
	ssize_t (*write_iter)(struct kiocb___202 *, struct iov_iter___123 *);
	int (*iopoll)(struct kiocb___202 *, bool);
	int (*iterate)(struct file___202 *, struct dir_context *);
	int (*iterate_shared)(struct file___202 *, struct dir_context *);
	__poll_t (*poll)(struct file___202 *, struct poll_table_struct___133 *);
	long int (*unlocked_ioctl)(struct file___202 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___202 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___202 *, struct vm_area_struct___207 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___202 *, struct file___202 *);
	int (*flush)(struct file___202 *, fl_owner_t);
	int (*release)(struct inode___202 *, struct file___202 *);
	int (*fsync)(struct file___202 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___202 *, int);
	int (*lock)(struct file___202 *, int, struct file_lock___202 *);
	ssize_t (*sendpage)(struct file___202 *, struct page___207 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___202 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___202 *, long unsigned int);
	int (*flock)(struct file___202 *, int, struct file_lock___202 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___202 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___202 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___202 *, long int, struct file_lock___202 **, void **);
	long int (*fallocate)(struct file___202 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___178 *, struct file___202 *);
	ssize_t (*copy_file_range)(struct file___202 *, loff_t, struct file___202 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___202 *, loff_t, struct file___202 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___202 *, loff_t, loff_t, int);
};

struct vmacache___207 {
	u64 seqnum;
	struct vm_area_struct___207 *vmas[4];
};

struct page_frag___207 {
	struct page___207 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___208;

struct pid___179;

struct nsproxy___188;

struct signal_struct___203;

struct bio_list___103;

struct backing_dev_info___96;

struct io_context___103;

struct css_set___138;

struct mem_cgroup___87;

struct request_queue___103;

struct vm_struct___185;

struct task_struct___209 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___209 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___208 *mm;
	struct mm_struct___208 *active_mm;
	struct vmacache___207 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___209 *real_parent;
	struct task_struct___209 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___209 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___179 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___188 *nsproxy;
	struct signal_struct___203 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___209 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___103 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___96 *backing_dev_info;
	struct io_context___103 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___138 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___207 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___87 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___87 *active_memcg;
	struct request_queue___103 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___209 *oom_reaper_list;
	struct vm_struct___185 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___186 {
	struct kobject___190 kobj;
	struct module___186 *mod;
	struct kobject___190 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___186 {
	struct module___186 *mod;
	struct latch_tree_node node;
};

struct module_layout___186 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___186 mtn;
};

struct module_attribute___186;

struct kernel_param___186;

struct module___186 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___186 mkobj;
	struct module_attribute___186 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___190 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___186 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___186 core_layout;
	struct module_layout___186 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___207 *pgtable_t___207;

struct address_space___202;

struct dev_pagemap___197;

struct page___207 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___202 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___54 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___207 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___207 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___208 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___197 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___197;

struct vm_area_struct___207 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___207 *vm_next;
	struct vm_area_struct___207 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___208 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___197 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___202 *vm_file;
	struct file___202 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___207;

struct mm_struct___208 {
	struct {
		struct vm_area_struct___207 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___202 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___207 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___209 *owner;
		struct user_namespace___25 *user_ns;
		struct file___202 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___202;

struct address_space___202 {
	struct inode___202 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___202 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___197;

struct dev_pagemap___197 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___197 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___202;

struct path___202 {
	struct vfsmount___202 *mnt;
	struct dentry___202 *dentry;
};

struct fown_struct___179 {
	rwlock_t lock;
	struct pid___179 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___202 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___202 f_path;
	struct inode___202 *f_inode;
	const struct file_operations___203 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___179 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___202 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___197;

struct vm_operations_struct___197 {
	void (*open)(struct vm_area_struct___207 *);
	void (*close)(struct vm_area_struct___207 *);
	int (*may_split)(struct vm_area_struct___207 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___207 *);
	int (*mprotect)(struct vm_area_struct___207 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___197 *);
	vm_fault_t (*huge_fault)(struct vm_fault___197 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___197 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___207 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___197 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___197 *);
	int (*access)(struct vm_area_struct___207 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___207 *);
	int (*set_policy)(struct vm_area_struct___207 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___207 *, long unsigned int);
	struct page___207 * (*find_special_page)(struct vm_area_struct___207 *, long unsigned int);
};

struct core_thread___207 {
	struct task_struct___209 *task;
	struct core_thread___207 *next;
};

struct core_state___207 {
	atomic_t nr_threads;
	struct core_thread___207 dumper;
	struct completion startup;
};

struct vm_fault___197 {
	const struct {
		struct vm_area_struct___207 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___207 *cow_page;
	struct page___207 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___207 prealloc_pte;
};

struct pglist_data___94;

struct lruvec___94 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___94 *pgdat;
};

struct zone___94 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___94 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___94 {
	struct zone___94 *zone;
	int zone_idx;
};

struct zonelist___94 {
	struct zoneref___94 _zonerefs[321];
};

struct pglist_data___94 {
	struct zone___94 node_zones[5];
	struct zonelist___94 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___209 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___209 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___94 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___190;

struct kernfs_elem_dir___190 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___190 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___190;

struct kernfs_root___190 {
	struct kernfs_node___190 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___190 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___190 {
	struct kernfs_node___190 *target_kn;
};

struct kernfs_ops___190;

struct kernfs_elem_attr___190 {
	const struct kernfs_ops___190 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___190 *notify_next;
};

struct kernfs_node___190 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___190 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___190 dir;
		struct kernfs_elem_symlink___190 symlink;
		struct kernfs_elem_attr___190 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___190;

struct kernfs_ops___190 {
	int (*open)(struct kernfs_open_file___190 *);
	void (*release)(struct kernfs_open_file___190 *);
	int (*seq_show)(struct seq_file___178 *, void *);
	void * (*seq_start)(struct seq_file___178 *, loff_t *);
	void * (*seq_next)(struct seq_file___178 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___178 *, void *);
	ssize_t (*read)(struct kernfs_open_file___190 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___190 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___190 *, struct poll_table_struct___133 *);
	int (*mmap)(struct kernfs_open_file___190 *, struct vm_area_struct___207 *);
};

struct kernfs_syscall_ops___190 {
	int (*show_options)(struct seq_file___178 *, struct kernfs_root___190 *);
	int (*mkdir)(struct kernfs_node___190 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___190 *);
	int (*rename)(struct kernfs_node___190 *, struct kernfs_node___190 *, const char *);
	int (*show_path)(struct seq_file___178 *, struct kernfs_node___190 *, struct kernfs_root___190 *);
};

struct seq_operations___178;

struct seq_file___178 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___178 *op;
	int poll_event;
	const struct file___202 *file;
	void *private;
};

struct kernfs_open_file___190 {
	struct kernfs_node___190 *kn;
	struct file___202 *file;
	struct seq_file___178 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___197 *vm_ops;
};

typedef void (*poll_queue_proc___140)(struct file___202 *, wait_queue_head_t *, struct poll_table_struct___133 *);

struct poll_table_struct___133 {
	poll_queue_proc___140 _qproc;
	__poll_t _key;
};

struct pid_namespace___179;

struct upid___179 {
	int nr;
	struct pid_namespace___179 *ns;
};

struct pid_namespace___179 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___209 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___179 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___179 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___179 numbers[1];
};

struct signal_struct___203 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___209 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___209 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___179 *pids[4];
	struct pid___179 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___208 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___138;

struct nsproxy___188 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___179 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___138 *cgroup_ns;
};

struct bio___103;

struct bio_list___103 {
	struct bio___103 *head;
	struct bio___103 *tail;
};

struct cgroup_subsys_state___138;

struct bdi_writeback___96 {
	struct backing_dev_info___96 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___138 *memcg_css;
	struct cgroup_subsys_state___138 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___166;

struct backing_dev_info___96 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___96 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___166 *dev;
	char dev_name[64];
	struct device___166 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___202 *debug_dir;
};

struct io_cq___103;

struct io_context___103 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___103 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___138;

struct css_set___138 {
	struct cgroup_subsys_state___138 *subsys[14];
	refcount_t refcount;
	struct css_set___138 *dom_cset;
	struct cgroup___138 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___138 *mg_src_cgrp;
	struct cgroup___138 *mg_dst_cgrp;
	struct css_set___138 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___138;

struct cgroup_subsys_state___138 {
	struct cgroup___138 *cgroup;
	struct cgroup_subsys___138 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___138 *parent;
};

struct cgroup_file___138 {
	struct kernfs_node___190 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___87;

struct mem_cgroup_per_node___87;

struct mem_cgroup___87 {
	struct cgroup_subsys_state___138 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___138 events_file;
	struct cgroup_file___138 events_local_file;
	struct cgroup_file___138 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___87 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___209 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___87 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___103;

struct blk_integrity___103 {
	const struct blk_integrity_profile___103 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___103 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___103 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___103;

struct elevator_queue___103;

struct blk_mq_ops___100;

struct blk_mq_hw_ctx___100;

struct gendisk___104;

struct blkcg_gq___98;

struct blk_mq_tag_set___100;

struct request_queue___103 {
	struct request___103 *last_merge;
	struct elevator_queue___103 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___100 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___100 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___104 *disk;
	struct kobject___190 kobj;
	struct kobject___190 *mq_kobj;
	struct blk_integrity___103 integrity;
	struct device___166 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___98 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___100 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___103 bio_split;
	struct dentry___202 *debugfs_dir;
	struct dentry___202 *sched_debugfs_dir;
	struct dentry___202 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___185 {
	struct vm_struct___185 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___207 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___190;

struct attribute_group___190 {
	const char *name;
	umode_t (*is_visible)(struct kobject___190 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___190 *, struct bin_attribute___190 *, int);
	struct attribute **attrs;
	struct bin_attribute___190 **bin_attrs;
};

struct bin_attribute___190 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___202 * (*f_mapping)();
	ssize_t (*read)(struct file___202 *, struct kobject___190 *, struct bin_attribute___190 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___202 *, struct kobject___190 *, struct bin_attribute___190 *, char *, loff_t, size_t);
	int (*mmap)(struct file___202 *, struct kobject___190 *, struct bin_attribute___190 *, struct vm_area_struct___207 *);
};

struct sysfs_ops___190 {
	ssize_t (*show)(struct kobject___190 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___190 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___190;

struct kset___190 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___190 kobj;
	const struct kset_uevent_ops___190 *uevent_ops;
};

struct kobj_type___190 {
	void (*release)(struct kobject___190 *);
	const struct sysfs_ops___190 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___190 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___190 *);
	const void * (*namespace)(struct kobject___190 *);
	void (*get_ownership)(struct kobject___190 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___190 {
	int (* const filter)(struct kset___190 *, struct kobject___190 *);
	const char * (* const name)(struct kset___190 *, struct kobject___190 *);
	int (* const uevent)(struct kset___190 *, struct kobject___190 *, struct kobj_uevent_env *);
};

struct fwnode_operations___166;

struct fwnode_handle___166 {
	struct fwnode_handle___166 *secondary;
	const struct fwnode_operations___166 *ops;
	struct device___166 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___166;

struct fwnode_endpoint___166;

struct fwnode_operations___166 {
	struct fwnode_handle___166 * (*get)(struct fwnode_handle___166 *);
	void (*put)(struct fwnode_handle___166 *);
	bool (*device_is_available)(const struct fwnode_handle___166 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___166 *, const struct device___166 *);
	bool (*property_present)(const struct fwnode_handle___166 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___166 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___166 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___166 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*get_parent)(const struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*get_next_child_node)(const struct fwnode_handle___166 *, struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*get_named_child_node)(const struct fwnode_handle___166 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___166 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___166 *);
	struct fwnode_handle___166 * (*graph_get_next_endpoint)(const struct fwnode_handle___166 *, struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*graph_get_remote_endpoint)(const struct fwnode_handle___166 *);
	struct fwnode_handle___166 * (*graph_get_port_parent)(struct fwnode_handle___166 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___166 *, struct fwnode_endpoint___166 *);
	int (*add_links)(struct fwnode_handle___166 *);
};

struct wakeup_source___166;

struct dev_pm_info___166 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___166 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___166 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___166;

struct bus_type___166;

struct device_driver___166;

struct dev_pm_domain___166;

struct device_node___67;

struct class___166;

struct dev_iommu___8;

struct device___166 {
	struct kobject___190 kobj;
	struct device___166 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___166 *type;
	struct bus_type___166 *bus;
	struct device_driver___166 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___166 power;
	struct dev_pm_domain___166 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___41 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___67 *of_node;
	struct fwnode_handle___166 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___166 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___166 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___8 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___166 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___166 *local_fwnode;
};

struct fwnode_reference_args___166 {
	struct fwnode_handle___166 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___51 {
	char *name;
	int length;
	void *value;
	struct property___51 *next;
	long unsigned int _flags;
	struct bin_attribute___190 attr;
};

struct device_node___67 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___166 fwnode;
	struct property___51 *properties;
	struct property___51 *deadprops;
	struct device_node___67 *parent;
	struct device_node___67 *child;
	struct device_node___67 *sibling;
	struct kobject___190 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___31 {
	struct device_node___67 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___39 {
	struct fwnode_handle___166 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___41 {
	int (*match)(struct irq_domain___41 *, struct device_node___67 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___41 *, struct irq_fwspec___39 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___41 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___41 *, unsigned int);
	int (*xlate)(struct irq_domain___41 *, struct device_node___67 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___41 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___41 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___41 *, struct irq_data___42 *, bool);
	void (*deactivate)(struct irq_domain___41 *, struct irq_data___42 *);
	int (*translate)(struct irq_domain___41 *, struct irq_fwspec___39 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___41;

struct irq_domain___41 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___41 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___166 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___41 *gc;
	struct irq_domain___41 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___42 *revmap[0];
};

struct irq_chip_generic___41;

struct irq_domain_chip_generic___41 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___41 *gc[0];
};

struct dev_pm_ops___166 {
	int (*prepare)(struct device___166 *);
	void (*complete)(struct device___166 *);
	int (*suspend)(struct device___166 *);
	int (*resume)(struct device___166 *);
	int (*freeze)(struct device___166 *);
	int (*thaw)(struct device___166 *);
	int (*poweroff)(struct device___166 *);
	int (*restore)(struct device___166 *);
	int (*suspend_late)(struct device___166 *);
	int (*resume_early)(struct device___166 *);
	int (*freeze_late)(struct device___166 *);
	int (*thaw_early)(struct device___166 *);
	int (*poweroff_late)(struct device___166 *);
	int (*restore_early)(struct device___166 *);
	int (*suspend_noirq)(struct device___166 *);
	int (*resume_noirq)(struct device___166 *);
	int (*freeze_noirq)(struct device___166 *);
	int (*thaw_noirq)(struct device___166 *);
	int (*poweroff_noirq)(struct device___166 *);
	int (*restore_noirq)(struct device___166 *);
	int (*runtime_suspend)(struct device___166 *);
	int (*runtime_resume)(struct device___166 *);
	int (*runtime_idle)(struct device___166 *);
};

struct wakeup_source___166 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___166 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___166 {
	struct dev_pm_ops___166 ops;
	int (*start)(struct device___166 *);
	void (*detach)(struct device___166 *, bool);
	int (*activate)(struct device___166 *);
	void (*sync)(struct device___166 *);
	void (*dismiss)(struct device___166 *);
};

struct iommu_ops___8;

struct bus_type___166 {
	const char *name;
	const char *dev_name;
	struct device___166 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___166 *, struct device_driver___166 *);
	int (*uevent)(struct device___166 *, struct kobj_uevent_env *);
	int (*probe)(struct device___166 *);
	void (*sync_state)(struct device___166 *);
	void (*remove)(struct device___166 *);
	void (*shutdown)(struct device___166 *);
	int (*online)(struct device___166 *);
	int (*offline)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	int (*num_vf)(struct device___166 *);
	int (*dma_configure)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
	const struct iommu_ops___8 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___166 {
	const char *name;
	struct bus_type___166 *bus;
	struct module___186 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___166 *);
	void (*sync_state)(struct device___166 *);
	int (*remove)(struct device___166 *);
	void (*shutdown)(struct device___166 *);
	int (*suspend)(struct device___166 *, pm_message_t);
	int (*resume)(struct device___166 *);
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	const struct dev_pm_ops___166 *pm;
	void (*coredump)(struct device___166 *);
	struct driver_private *p;
};

struct iommu_domain___8;

struct iommu_iotlb_gather___5;

struct iommu_device___8;

struct iommu_sva___8;

struct iommu_ops___8 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___8 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___8 *);
	int (*attach_dev)(struct iommu_domain___8 *, struct device___166 *);
	void (*detach_dev)(struct iommu_domain___8 *, struct device___166 *);
	int (*map)(struct iommu_domain___8 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___8 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___8 *, long unsigned int, size_t, struct iommu_iotlb_gather___5 *);
	size_t (*unmap_pages)(struct iommu_domain___8 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___5 *);
	void (*flush_iotlb_all)(struct iommu_domain___8 *);
	void (*iotlb_sync_map)(struct iommu_domain___8 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___8 *, struct iommu_iotlb_gather___5 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___8 *, dma_addr_t);
	struct iommu_device___8 * (*probe_device)(struct device___166 *);
	void (*release_device)(struct device___166 *);
	void (*probe_finalize)(struct device___166 *);
	struct iommu_group * (*device_group)(struct device___166 *);
	int (*enable_nesting)(struct iommu_domain___8 *);
	int (*set_pgtable_quirks)(struct iommu_domain___8 *, long unsigned int);
	void (*get_resv_regions)(struct device___166 *, struct list_head *);
	void (*put_resv_regions)(struct device___166 *, struct list_head *);
	void (*apply_resv_region)(struct device___166 *, struct iommu_domain___8 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___166 *, struct of_phandle_args___31 *);
	bool (*is_attach_deferred)(struct iommu_domain___8 *, struct device___166 *);
	bool (*dev_has_feat)(struct device___166 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___166 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___166 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___166 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___8 *, struct device___166 *);
	void (*aux_detach_dev)(struct iommu_domain___8 *, struct device___166 *);
	int (*aux_get_pasid)(struct iommu_domain___8 *, struct device___166 *);
	struct iommu_sva___8 * (*sva_bind)(struct device___166 *, struct mm_struct___208 *, void *);
	void (*sva_unbind)(struct iommu_sva___8 *);
	u32 (*sva_get_pasid)(struct iommu_sva___8 *);
	int (*page_response)(struct device___166 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___8 *, struct device___166 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___8 *, struct device___166 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___166 *, u32);
	int (*def_domain_type)(struct device___166 *);
	long unsigned int pgsize_bitmap;
	struct module___186 *owner;
};

struct device_type___166 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___166 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___166 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___166 *);
	const struct dev_pm_ops___166 *pm;
};

struct class___166 {
	const char *name;
	struct module___186 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___166 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___166 *, umode_t *);
	void (*class_release)(struct class___166 *);
	void (*dev_release)(struct device___166 *);
	int (*shutdown_pre)(struct device___166 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___166 *);
	void (*get_ownership)(struct device___166 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___166 *pm;
	struct subsys_private *p;
};

struct iommu_fwspec___8;

struct dev_iommu___8 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___8 *fwspec;
	struct iommu_device___8 *iommu_dev;
	void *priv;
};

struct device_link___15 {
	struct device___166 *supplier;
	struct list_head s_node;
	struct device___166 *consumer;
	struct list_head c_node;
	struct device___166 link_dev;
	enum device_link_state status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct dentry_operations___202;

struct dentry___202 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___202 *d_parent;
	struct qstr d_name;
	struct inode___202 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___202 *d_op;
	struct super_block___202 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___202;

struct cdev___49;

struct inode___202 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___202 *i_op;
	struct super_block___202 *i_sb;
	struct address_space___202 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___96 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___203 *i_fop;
		void (*free_inode)(struct inode___202 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___202 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___49 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___202 {
	int (*d_revalidate)(struct dentry___202 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___202 *, unsigned int);
	int (*d_hash)(const struct dentry___202 *, struct qstr *);
	int (*d_compare)(const struct dentry___202 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___202 *);
	int (*d_init)(struct dentry___202 *);
	void (*d_release)(struct dentry___202 *);
	void (*d_prune)(struct dentry___202 *);
	void (*d_iput)(struct dentry___202 *, struct inode___202 *);
	char * (*d_dname)(struct dentry___202 *, char *, int);
	struct vfsmount___202 * (*d_automount)(struct path___202 *);
	int (*d_manage)(const struct path___202 *, bool);
	struct dentry___202 * (*d_real)(struct dentry___202 *, const struct inode___202 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___202;

struct mem_dqinfo___202 {
	struct quota_format_type___202 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___202;

struct quota_info___202 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___202 *files[3];
	struct mem_dqinfo___202 info[3];
	const struct quota_format_ops___202 *ops[3];
};

struct rcuwait___203 {
	struct task_struct___209 *task;
};

struct percpu_rw_semaphore___203 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___203 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___202 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___203 rw_sem[3];
};

struct shrink_control___87;

struct shrinker___87 {
	long unsigned int (*count_objects)(struct shrinker___87 *, struct shrink_control___87 *);
	long unsigned int (*scan_objects)(struct shrinker___87 *, struct shrink_control___87 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___202;

struct dquot_operations___202;

struct quotactl_ops___202;

struct block_device___104;

struct super_block___202 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___202 *s_type;
	const struct super_operations___202 *s_op;
	const struct dquot_operations___202 *dq_op;
	const struct quotactl_ops___202 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___202 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___104 *s_bdev;
	struct backing_dev_info___96 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___202 s_dquot;
	struct sb_writers___202 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___202 *s_d_op;
	int cleancache_poolid;
	struct shrinker___87 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___202 {
	struct dentry___202 *mnt_root;
	struct super_block___202 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___87 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___87 *memcg;
};

struct psi_group___138 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___209 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___138;

struct cgroup_rstat_cpu___138;

struct cgroup___138 {
	struct cgroup_subsys_state___138 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___190 *kn;
	struct cgroup_file___138 procs_file;
	struct cgroup_file___138 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___138 *subsys[14];
	struct cgroup_root___138 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___138 *dom_cgrp;
	struct cgroup___138 *old_dom_cgrp;
	struct cgroup_rstat_cpu___138 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___138 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___103 {
	struct request_queue___103 *q;
	struct io_context___103 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___97;

struct kiocb___202 {
	struct file___202 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___202 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___97 *ki_waitq;
	};
};

struct iattr___202 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___202 *ia_file;
};

struct dquot___202 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___202 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___202 {
	int qf_fmt_id;
	const struct quota_format_ops___202 *qf_ops;
	struct module___186 *qf_owner;
	struct quota_format_type___202 *qf_next;
};

struct quota_format_ops___202 {
	int (*check_quota_file)(struct super_block___202 *, int);
	int (*read_file_info)(struct super_block___202 *, int);
	int (*write_file_info)(struct super_block___202 *, int);
	int (*free_file_info)(struct super_block___202 *, int);
	int (*read_dqblk)(struct dquot___202 *);
	int (*commit_dqblk)(struct dquot___202 *);
	int (*release_dqblk)(struct dquot___202 *);
	int (*get_next_id)(struct super_block___202 *, struct kqid *);
};

struct dquot_operations___202 {
	int (*write_dquot)(struct dquot___202 *);
	struct dquot___202 * (*alloc_dquot)(struct super_block___202 *, int);
	void (*destroy_dquot)(struct dquot___202 *);
	int (*acquire_dquot)(struct dquot___202 *);
	int (*release_dquot)(struct dquot___202 *);
	int (*mark_dirty)(struct dquot___202 *);
	int (*write_info)(struct super_block___202 *, int);
	qsize_t * (*get_reserved_space)(struct inode___202 *);
	int (*get_projid)(struct inode___202 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___202 *, qsize_t *);
	int (*get_next_id)(struct super_block___202 *, struct kqid *);
};

struct quotactl_ops___202 {
	int (*quota_on)(struct super_block___202 *, int, int, const struct path___202 *);
	int (*quota_off)(struct super_block___202 *, int);
	int (*quota_enable)(struct super_block___202 *, unsigned int);
	int (*quota_disable)(struct super_block___202 *, unsigned int);
	int (*quota_sync)(struct super_block___202 *, int);
	int (*set_info)(struct super_block___202 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___202 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___202 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___202 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___202 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___202 *, unsigned int);
};

struct wait_page_queue___97 {
	struct page___207 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___96;

struct readahead_control___97;

struct swap_info_struct___55;

struct address_space_operations___202 {
	int (*writepage)(struct page___207 *, struct writeback_control___96 *);
	int (*readpage)(struct file___202 *, struct page___207 *);
	int (*writepages)(struct address_space___202 *, struct writeback_control___96 *);
	int (*set_page_dirty)(struct page___207 *);
	int (*readpages)(struct file___202 *, struct address_space___202 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___97 *);
	int (*write_begin)(struct file___202 *, struct address_space___202 *, loff_t, unsigned int, unsigned int, struct page___207 **, void **);
	int (*write_end)(struct file___202 *, struct address_space___202 *, loff_t, unsigned int, unsigned int, struct page___207 *, void *);
	sector_t (*bmap)(struct address_space___202 *, sector_t);
	void (*invalidatepage)(struct page___207 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___207 *, gfp_t);
	void (*freepage)(struct page___207 *);
	ssize_t (*direct_IO)(struct kiocb___202 *, struct iov_iter___123 *);
	int (*migratepage)(struct address_space___202 *, struct page___207 *, struct page___207 *, enum migrate_mode);
	bool (*isolate_page)(struct page___207 *, isolate_mode_t);
	void (*putback_page)(struct page___207 *);
	int (*launder_page)(struct page___207 *);
	int (*is_partially_uptodate)(struct page___207 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___207 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___202 *, struct page___207 *);
	int (*swap_activate)(struct swap_info_struct___55 *, struct file___202 *, sector_t *);
	void (*swap_deactivate)(struct file___202 *);
};

struct writeback_control___96 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___96 *wb;
	struct inode___202 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___97 {
	struct file___202 *file;
	struct address_space___202 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___120;

struct iov_iter___123 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___120 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___55 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___104 *bdev;
	struct file___202 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___49 {
	struct kobject___190 kobj;
	struct module___186 *owner;
	const struct file_operations___203 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___202 {
	struct dentry___202 * (*lookup)(struct inode___202 *, struct dentry___202 *, unsigned int);
	const char * (*get_link)(struct dentry___202 *, struct inode___202 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___202 *, int);
	struct posix_acl * (*get_acl)(struct inode___202 *, int, bool);
	int (*readlink)(struct dentry___202 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___202 *, struct dentry___202 *, umode_t, bool);
	int (*link)(struct dentry___202 *, struct inode___202 *, struct dentry___202 *);
	int (*unlink)(struct inode___202 *, struct dentry___202 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___202 *, struct dentry___202 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___202 *, struct dentry___202 *, umode_t);
	int (*rmdir)(struct inode___202 *, struct dentry___202 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___202 *, struct dentry___202 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___202 *, struct dentry___202 *, struct inode___202 *, struct dentry___202 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___202 *, struct iattr___202 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___202 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___202 *, char *, size_t);
	int (*fiemap)(struct inode___202 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___202 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___202 *, struct dentry___202 *, struct file___202 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___202 *, struct dentry___202 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___202 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___202 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___202 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___202 {
	void (*fl_copy_lock)(struct file_lock___202 *, struct file_lock___202 *);
	void (*fl_release_private)(struct file_lock___202 *);
};

struct fasync_struct___202;

struct lock_manager_operations___202;

struct file_lock___202 {
	struct file_lock___202 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___202 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___202 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___202 *fl_ops;
	const struct lock_manager_operations___202 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___202 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___202 *);
	int (*lm_grant)(struct file_lock___202 *, int);
	bool (*lm_break)(struct file_lock___202 *);
	int (*lm_change)(struct file_lock___202 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___202 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___202 *);
};

struct fasync_struct___202 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___202 *fa_next;
	struct file___202 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___202 {
	struct inode___202 * (*alloc_inode)(struct super_block___202 *);
	void (*destroy_inode)(struct inode___202 *);
	void (*free_inode)(struct inode___202 *);
	void (*dirty_inode)(struct inode___202 *, int);
	int (*write_inode)(struct inode___202 *, struct writeback_control___96 *);
	int (*drop_inode)(struct inode___202 *);
	void (*evict_inode)(struct inode___202 *);
	void (*put_super)(struct super_block___202 *);
	int (*sync_fs)(struct super_block___202 *, int);
	int (*freeze_super)(struct super_block___202 *);
	int (*freeze_fs)(struct super_block___202 *);
	int (*thaw_super)(struct super_block___202 *);
	int (*unfreeze_fs)(struct super_block___202 *);
	int (*statfs)(struct dentry___202 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___202 *, int *, char *);
	void (*umount_begin)(struct super_block___202 *);
	int (*show_options)(struct seq_file___178 *, struct dentry___202 *);
	int (*show_devname)(struct seq_file___178 *, struct dentry___202 *);
	int (*show_path)(struct seq_file___178 *, struct dentry___202 *);
	int (*show_stats)(struct seq_file___178 *, struct dentry___202 *);
	ssize_t (*quota_read)(struct super_block___202 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___202 *, int, const char *, size_t, loff_t);
	struct dquot___202 ** (*get_dquots)(struct inode___202 *);
	long int (*nr_cached_objects)(struct super_block___202 *, struct shrink_control___87 *);
	long int (*free_cached_objects)(struct super_block___202 *, struct shrink_control___87 *);
	struct file___202 * (*real_loop)(struct file___202 *);
};

struct block_device___104 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___202 *bd_inode;
	struct super_block___202 *bd_super;
	void *bd_claiming;
	struct device___166 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___190 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___104 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___202 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___103(struct bio___103 *);

struct bio_vec___120 {
	struct page___207 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___103;

struct bio___103 {
	struct bio___103 *bi_next;
	struct block_device___104 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___103 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___98 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___103 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___120 *bi_io_vec;
	struct bio_set___103 *bi_pool;
	struct bio_vec___120 bi_inline_vecs[0];
};

struct kernel_param_ops___186 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___186 *);
	int (*get)(char *, const struct kernel_param___186 *);
	void (*free)(void *);
};

struct kparam_array___186;

struct kernel_param___186 {
	const char *name;
	struct module___186 *mod;
	const struct kernel_param_ops___186 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___186 *arr;
	};
};

struct kparam_array___186 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___186 *ops;
	void *elem;
};

struct module_attribute___186 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___186 *, struct module_kobject___186 *, char *);
	ssize_t (*store)(struct module_attribute___186 *, struct module_kobject___186 *, const char *, size_t);
	void (*setup)(struct module___186 *, const char *);
	int (*test)(struct module___186 *);
	void (*free)(struct module___186 *);
};

struct msi_desc___13 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___166 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___13 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___42 {
	struct device___166 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___42 *);
	void (*irq_shutdown)(struct irq_data___42 *);
	void (*irq_enable)(struct irq_data___42 *);
	void (*irq_disable)(struct irq_data___42 *);
	void (*irq_ack)(struct irq_data___42 *);
	void (*irq_mask)(struct irq_data___42 *);
	void (*irq_mask_ack)(struct irq_data___42 *);
	void (*irq_unmask)(struct irq_data___42 *);
	void (*irq_eoi)(struct irq_data___42 *);
	int (*irq_set_affinity)(struct irq_data___42 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___42 *);
	int (*irq_set_type)(struct irq_data___42 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___42 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___42 *);
	void (*irq_bus_sync_unlock)(struct irq_data___42 *);
	void (*irq_cpu_online)(struct irq_data___42 *);
	void (*irq_cpu_offline)(struct irq_data___42 *);
	void (*irq_suspend)(struct irq_data___42 *);
	void (*irq_resume)(struct irq_data___42 *);
	void (*irq_pm_shutdown)(struct irq_data___42 *);
	void (*irq_calc_mask)(struct irq_data___42 *);
	void (*irq_print_chip)(struct irq_data___42 *, struct seq_file___178 *);
	int (*irq_request_resources)(struct irq_data___42 *);
	void (*irq_release_resources)(struct irq_data___42 *);
	void (*irq_compose_msi_msg)(struct irq_data___42 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___42 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___42 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___42 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___42 *, void *);
	void (*ipi_send_single)(struct irq_data___42 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___42 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___42 *);
	void (*irq_nmi_teardown)(struct irq_data___42 *);
	long unsigned int flags;
};

struct irqaction___29 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___29 *next;
	irq_handler_t thread_fn;
	struct task_struct___209 *thread;
	struct irqaction___29 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___41 {
	struct irq_chip___42 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___43 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___41 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___41 *);
	void (*resume)(struct irq_chip_generic___41 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___41 *domain;
	struct list_head list;
	struct irq_chip_type___41 chip_types[0];
};

struct seq_operations___178 {
	void * (*start)(struct seq_file___178 *, loff_t *);
	void (*stop)(struct seq_file___178 *, void *);
	void * (*next)(struct seq_file___178 *, void *, loff_t *);
	int (*show)(struct seq_file___178 *, void *);
};

struct dev_pagemap_ops___197 {
	void (*page_free)(struct page___207 *);
	void (*kill)(struct dev_pagemap___197 *);
	void (*cleanup)(struct dev_pagemap___197 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___197 *);
};

typedef int (*iommu_fault_handler_t___8)(struct iommu_domain___8 *, struct device___166 *, long unsigned int, int, void *);

struct iommu_domain___8 {
	unsigned int type;
	const struct iommu_ops___8 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___8 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___5 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___207 *freelist;
	bool queued;
};

struct iommu_device___8 {
	struct list_head list;
	const struct iommu_ops___8 *ops;
	struct fwnode_handle___166 *fwnode;
	struct device___166 *dev;
};

struct iommu_sva___8 {
	struct device___166 *dev;
};

struct iommu_fwspec___8 {
	const struct iommu_ops___8 *ops;
	struct fwnode_handle___166 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct platform_device___25 {
	const char *name;
	int id;
	bool id_auto;
	struct device___166 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___23 {
	int (*probe)(struct platform_device___25 *);
	int (*remove)(struct platform_device___25 *);
	void (*shutdown)(struct platform_device___25 *);
	int (*suspend)(struct platform_device___25 *, pm_message_t);
	int (*resume)(struct platform_device___25 *);
	struct device_driver___166 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct cgroup_namespace___138 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___138 *root_cset;
};

struct cftype___138;

struct cgroup_subsys___138 {
	struct cgroup_subsys_state___138 * (*css_alloc)(struct cgroup_subsys_state___138 *);
	int (*css_online)(struct cgroup_subsys_state___138 *);
	void (*css_offline)(struct cgroup_subsys_state___138 *);
	void (*css_released)(struct cgroup_subsys_state___138 *);
	void (*css_free)(struct cgroup_subsys_state___138 *);
	void (*css_reset)(struct cgroup_subsys_state___138 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___138 *, int);
	int (*css_extra_stat_show)(struct seq_file___178 *, struct cgroup_subsys_state___138 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___209 *, struct css_set___138 *);
	void (*cancel_fork)(struct task_struct___209 *, struct css_set___138 *);
	void (*fork)(struct task_struct___209 *);
	void (*exit)(struct task_struct___209 *);
	void (*release)(struct task_struct___209 *);
	void (*bind)(struct cgroup_subsys_state___138 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___138 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___138 *dfl_cftypes;
	struct cftype___138 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___138 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___138 *updated_children;
	struct cgroup___138 *updated_next;
};

struct cgroup_root___138 {
	struct kernfs_root___190 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___138 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___138 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___138 *ss;
	struct list_head node;
	struct kernfs_ops___190 *kf_ops;
	int (*open)(struct kernfs_open_file___190 *);
	void (*release)(struct kernfs_open_file___190 *);
	u64 (*read_u64)(struct cgroup_subsys_state___138 *, struct cftype___138 *);
	s64 (*read_s64)(struct cgroup_subsys_state___138 *, struct cftype___138 *);
	int (*seq_show)(struct seq_file___178 *, void *);
	void * (*seq_start)(struct seq_file___178 *, loff_t *);
	void * (*seq_next)(struct seq_file___178 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___178 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___138 *, struct cftype___138 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___138 *, struct cftype___138 *, s64);
	ssize_t (*write)(struct kernfs_open_file___190 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___190 *, struct poll_table_struct___133 *);
};

struct block_device_operations___103;

struct gendisk___104 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___104 *part0;
	const struct block_device_operations___103 *fops;
	struct request_queue___103 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___96 *bdi;
	struct kobject___190 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___190 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___103 {
	struct bio___103 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___120 *bip_vec;
	struct bio_vec___120 bip_inline_vecs[0];
};

struct blkcg___98;

struct blkg_policy_data___98;

struct blkcg_gq___98 {
	struct request_queue___103 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___98 *blkcg;
	struct blkcg_gq___98 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___98 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___103 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___103(struct request___103 *);

typedef void integrity_complete_fn___103(struct request___103 *, unsigned int);

struct blk_integrity_profile___103 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___103 *prepare_fn;
	integrity_complete_fn___103 *complete_fn;
	const char *name;
};

struct block_device_operations___103 {
	blk_qc_t (*submit_bio)(struct bio___103 *);
	int (*open)(struct block_device___104 *, fmode_t);
	void (*release)(struct gendisk___104 *, fmode_t);
	int (*rw_page)(struct block_device___104 *, sector_t, struct page___207 *, unsigned int);
	int (*ioctl)(struct block_device___104 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___104 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___104 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___104 *);
	int (*getgeo)(struct block_device___104 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___104 *, bool);
	void (*swap_slot_free_notify)(struct block_device___104 *, long unsigned int);
	int (*report_zones)(struct gendisk___104 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___104 *, umode_t *);
	struct module___186 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___104 *, sector_t *);
};

typedef void rq_end_io_fn___103(struct request___103 *, blk_status_t);

struct request___103 {
	struct request_queue___103 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___100 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___103 *bio;
	struct bio___103 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___120 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___103 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___103 *saved_end_io;
		} flush;
	};
	struct gendisk___104 *rq_disk;
	struct block_device___104 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___103 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___100 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___103 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___190 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___202 *debugfs_dir;
	struct dentry___202 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___103;

struct elevator_mq_ops___103 {
	int (*init_sched)(struct request_queue___103 *, struct elevator_type___103 *);
	void (*exit_sched)(struct elevator_queue___103 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___100 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___100 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___100 *);
	bool (*allow_merge)(struct request_queue___103 *, struct request___103 *, struct bio___103 *);
	bool (*bio_merge)(struct request_queue___103 *, struct bio___103 *, unsigned int);
	int (*request_merge)(struct request_queue___103 *, struct request___103 **, struct bio___103 *);
	void (*request_merged)(struct request_queue___103 *, struct request___103 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___103 *, struct request___103 *, struct request___103 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___103 *);
	void (*finish_request)(struct request___103 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___100 *, struct list_head *, bool);
	struct request___103 * (*dispatch_request)(struct blk_mq_hw_ctx___100 *);
	bool (*has_work)(struct blk_mq_hw_ctx___100 *);
	void (*completed_request)(struct request___103 *, u64);
	void (*requeue_request)(struct request___103 *);
	struct request___103 * (*former_request)(struct request_queue___103 *, struct request___103 *);
	struct request___103 * (*next_request)(struct request_queue___103 *, struct request___103 *);
	void (*init_icq)(struct io_cq___103 *);
	void (*exit_icq)(struct io_cq___103 *);
};

struct elv_fs_entry___103;

struct elevator_type___103 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___103 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___103 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___186 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___103 {
	struct elevator_type___103 *type;
	void *elevator_data;
	struct kobject___190 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___103 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___103 *, char *);
	ssize_t (*store)(struct elevator_queue___103 *, const char *, size_t);
};

struct blk_mq_queue_data___100;

struct blk_mq_ops___100 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___100 *, const struct blk_mq_queue_data___100 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___100 *);
	int (*get_budget)(struct request_queue___103 *);
	void (*put_budget)(struct request_queue___103 *, int);
	void (*set_rq_budget_token)(struct request___103 *, int);
	int (*get_rq_budget_token)(struct request___103 *);
	enum blk_eh_timer_return (*timeout)(struct request___103 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___100 *);
	void (*complete)(struct request___103 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___100 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___100 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___100 *, struct request___103 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___100 *, struct request___103 *, unsigned int);
	void (*initialize_rq_fn)(struct request___103 *);
	void (*cleanup_rq)(struct request___103 *);
	bool (*busy)(struct request_queue___103 *);
	int (*map_queues)(struct blk_mq_tag_set___100 *);
	void (*show_rq)(struct seq_file___178 *, struct request___103 *);
};

struct blk_mq_tag_set___100 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___100 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___100 {
	struct request___103 *rq;
	bool last;
};

struct blkcg_policy_data___98;

struct blkcg___98 {
	struct cgroup_subsys_state___138 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___98 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___98 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___98 {
	struct blkcg___98 *blkcg;
	int plid;
};

struct blkg_policy_data___98 {
	struct blkcg_gq___98 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___87 {
	struct mem_cgroup___87 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___87 {
	struct lruvec___94 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___87 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___87 *memcg;
};

struct obj_cgroup___87 {
	struct percpu_ref refcnt;
	struct mem_cgroup___87 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct iommu_flush_ops___2 {
	void (*tlb_flush_all)(void *);
	void (*tlb_flush_walk)(long unsigned int, size_t, size_t, void *);
	void (*tlb_add_page)(struct iommu_iotlb_gather___5 *, long unsigned int, size_t, void *);
};

struct io_pgtable_cfg___2 {
	long unsigned int quirks;
	long unsigned int pgsize_bitmap;
	unsigned int ias;
	unsigned int oas;
	bool coherent_walk;
	const struct iommu_flush_ops___2 *tlb;
	struct device___166 *iommu_dev;
	union {
		struct {
			u64 ttbr;
			struct {
				u32 ips: 3;
				u32 tg: 2;
				u32 sh: 2;
				u32 orgn: 2;
				u32 irgn: 2;
				u32 tsz: 6;
			} tcr;
			u64 mair;
		} arm_lpae_s1_cfg;
		struct {
			u64 vttbr;
			struct {
				u32 ps: 3;
				u32 tg: 2;
				u32 sh: 2;
				u32 orgn: 2;
				u32 irgn: 2;
				u32 sl: 2;
				u32 tsz: 6;
			} vtcr;
		} arm_lpae_s2_cfg;
		struct {
			u32 ttbr;
			u32 tcr;
			u32 nmrr;
			u32 prrr;
		} arm_v7s_cfg;
		struct {
			u64 transtab;
			u64 memattr;
		} arm_mali_lpae_cfg;
		struct {
			u64 ttbr[4];
			u32 n_ttbrs;
		} apple_dart_cfg;
	};
};

struct io_pgtable_ops___2 {
	int (*map)(struct io_pgtable_ops___2 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct io_pgtable_ops___2 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct io_pgtable_ops___2 *, long unsigned int, size_t, struct iommu_iotlb_gather___5 *);
	size_t (*unmap_pages)(struct io_pgtable_ops___2 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___5 *);
	phys_addr_t (*iova_to_phys)(struct io_pgtable_ops___2 *, long unsigned int);
};

enum arm_smmu_s2cr_privcfg {
	S2CR_PRIVCFG_DEFAULT = 0,
	S2CR_PRIVCFG_DIPAN = 1,
	S2CR_PRIVCFG_UNPRIV = 2,
	S2CR_PRIVCFG_PRIV = 3,
};

enum arm_smmu_s2cr_type {
	S2CR_TYPE_TRANS = 0,
	S2CR_TYPE_BYPASS = 1,
	S2CR_TYPE_FAULT = 2,
};

enum arm_smmu_cbar_type {
	CBAR_TYPE_S2_TRANS = 0,
	CBAR_TYPE_S1_TRANS_S2_BYPASS = 1,
	CBAR_TYPE_S1_TRANS_S2_FAULT = 2,
	CBAR_TYPE_S1_TRANS_S2_TRANS = 3,
};

enum arm_smmu_arch_version {
	ARM_SMMU_V1 = 0,
	ARM_SMMU_V1_64K = 1,
	ARM_SMMU_V2 = 2,
};

enum arm_smmu_implementation {
	GENERIC_SMMU = 0,
	ARM_MMU500 = 1,
	CAVIUM_SMMUV2 = 2,
	QCOM_SMMUV2 = 3,
};

struct arm_smmu_s2cr {
	struct iommu_group *group;
	int count;
	enum arm_smmu_s2cr_type type;
	enum arm_smmu_s2cr_privcfg privcfg;
	u8 cbndx;
};

struct arm_smmu_smr {
	u16 mask;
	u16 id;
	bool valid;
	bool pinned;
};

struct arm_smmu_impl;

struct arm_smmu_cb;

struct arm_smmu_device {
	struct device___166 *dev;
	void *base;
	unsigned int numpage;
	unsigned int pgshift;
	u32 features;
	enum arm_smmu_arch_version version;
	enum arm_smmu_implementation model;
	const struct arm_smmu_impl *impl;
	u32 num_context_banks;
	u32 num_s2_context_banks;
	long unsigned int context_map[2];
	struct arm_smmu_cb *cbs;
	atomic_t irptndx;
	u32 num_mapping_groups;
	u16 streamid_mask;
	u16 smr_mask_mask;
	struct arm_smmu_smr *smrs;
	struct arm_smmu_s2cr *s2crs;
	struct mutex stream_map_mutex;
	long unsigned int va_size;
	long unsigned int ipa_size;
	long unsigned int pa_size;
	long unsigned int pgsize_bitmap;
	u32 num_global_irqs;
	u32 num_context_irqs;
	unsigned int *irqs;
	struct clk_bulk_data *clks;
	int num_clks;
	spinlock_t global_sync_lock;
	struct iommu_device___8 iommu;
};

struct arm_smmu_domain;

struct arm_smmu_impl {
	u32 (*read_reg)(struct arm_smmu_device *, int, int);
	void (*write_reg)(struct arm_smmu_device *, int, int, u32);
	u64 (*read_reg64)(struct arm_smmu_device *, int, int);
	void (*write_reg64)(struct arm_smmu_device *, int, int, u64);
	int (*cfg_probe)(struct arm_smmu_device *);
	int (*reset)(struct arm_smmu_device *);
	int (*init_context)(struct arm_smmu_domain *, struct io_pgtable_cfg___2 *, struct device___166 *);
	void (*tlb_sync)(struct arm_smmu_device *, int, int, int);
	int (*def_domain_type)(struct device___166 *);
	irqreturn_t (*global_fault)(int, void *);
	irqreturn_t (*context_fault)(int, void *);
	int (*alloc_context_bank)(struct arm_smmu_domain *, struct arm_smmu_device *, struct device___166 *, int);
	void (*write_s2cr)(struct arm_smmu_device *, int);
	void (*write_sctlr)(struct arm_smmu_device *, int, u32);
	void (*probe_finalize)(struct arm_smmu_device *, struct device___166 *);
};

struct arm_smmu_cfg;

struct arm_smmu_cb {
	u64 ttbr[2];
	u32 tcr[2];
	u32 mair[2];
	struct arm_smmu_cfg *cfg;
};

enum arm_smmu_context_fmt {
	ARM_SMMU_CTX_FMT_NONE = 0,
	ARM_SMMU_CTX_FMT_AARCH64 = 1,
	ARM_SMMU_CTX_FMT_AARCH32_L = 2,
	ARM_SMMU_CTX_FMT_AARCH32_S = 3,
};

struct arm_smmu_cfg {
	u8 cbndx;
	u8 irptndx;
	union {
		u16 asid;
		u16 vmid;
	};
	enum arm_smmu_cbar_type cbar;
	enum arm_smmu_context_fmt fmt;
	bool flush_walk_prefer_tlbiasid;
};

enum arm_smmu_domain_stage {
	ARM_SMMU_DOMAIN_S1 = 0,
	ARM_SMMU_DOMAIN_S2 = 1,
	ARM_SMMU_DOMAIN_NESTED = 2,
	ARM_SMMU_DOMAIN_BYPASS = 3,
};

struct arm_smmu_domain {
	struct arm_smmu_device *smmu;
	struct io_pgtable_ops___2 *pgtbl_ops;
	long unsigned int pgtbl_quirks;
	const struct iommu_flush_ops___2 *flush_ops;
	struct arm_smmu_cfg cfg;
	enum arm_smmu_domain_stage stage;
	struct mutex init_mutex;
	spinlock_t cb_lock;
	struct iommu_domain___8 domain;
};

struct arm_smmu_master_cfg {
	struct arm_smmu_device *smmu;
	s16 smendx[0];
};

struct arm_smmu_match_data {
	enum arm_smmu_arch_version version;
	enum arm_smmu_implementation model;
};

struct cavium_smmu {
	struct arm_smmu_device smmu;
	u32 id_base;
};

struct icc_node;

struct icc_node_data {
	struct icc_node *node;
	u32 tag;
};

struct icc_provider;

struct icc_node {
	int id;
	const char *name;
	struct icc_node **links;
	size_t num_links;
	struct icc_provider *provider;
	struct list_head node_list;
	struct list_head search_list;
	struct icc_node *reverse;
	u8 is_traversed;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head req_list;
	u32 avg_bw;
	u32 peak_bw;
	u32 init_avg;
	u32 init_peak;
	void *data;
};

struct icc_provider {
	struct list_head provider_list;
	struct list_head nodes;
	int (*set)(struct icc_node *, struct icc_node *);
	int (*aggregate)(struct icc_node *, u32, u32, u32, u32 *, u32 *);
	void (*pre_aggregate)(struct icc_node *);
	int (*get_bw)(struct icc_node *, u32 *, u32 *);
	struct icc_node * (*xlate)(struct of_phandle_args___31 *, void *);
	struct icc_node_data * (*xlate_extended)(struct of_phandle_args___31 *, void *);
	struct device___166 *dev;
	int users;
	bool inter_set;
	void *data;
};

struct reset_controller_dev___8;

struct reset_control_ops___8 {
	int (*reset)(struct reset_controller_dev___8 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___8 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___8 *, long unsigned int);
	int (*status)(struct reset_controller_dev___8 *, long unsigned int);
};

struct reset_controller_dev___8 {
	const struct reset_control_ops___8 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___166 *dev;
	struct device_node___67 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___8 *, const struct of_phandle_args___31 *);
	unsigned int nr_resets;
};

struct tegra_mc_timing {
	long unsigned int rate;
	u32 *emem_data;
};

struct tegra_mc_client {
	unsigned int id;
	const char *name;
	union {
		unsigned int swgroup;
		unsigned int sid;
	};
	unsigned int fifo_size;
	struct {
		struct {
			unsigned int reg;
			unsigned int bit;
		} smmu;
		struct {
			unsigned int reg;
			unsigned int shift;
			unsigned int mask;
			unsigned int def;
		} la;
		struct {
			unsigned int override;
			unsigned int security;
		} sid;
	} regs;
};

struct tegra_smmu_swgroup {
	const char *name;
	unsigned int swgroup;
	unsigned int reg;
};

struct tegra_smmu_group_soc {
	const char *name;
	const unsigned int *swgroups;
	unsigned int num_swgroups;
};

struct tegra_smmu_soc {
	const struct tegra_mc_client *clients;
	unsigned int num_clients;
	const struct tegra_smmu_swgroup *swgroups;
	unsigned int num_swgroups;
	const struct tegra_smmu_group_soc *groups;
	unsigned int num_groups;
	bool supports_round_robin_arbitration;
	bool supports_request_limit;
	unsigned int num_tlb_lines;
	unsigned int num_asids;
};

struct tegra_mc_reset {
	const char *name;
	long unsigned int id;
	unsigned int control;
	unsigned int status;
	unsigned int reset;
	unsigned int bit;
};

struct tegra_mc;

struct tegra_mc_reset_ops {
	int (*hotreset_assert)(struct tegra_mc *, const struct tegra_mc_reset *);
	int (*hotreset_deassert)(struct tegra_mc *, const struct tegra_mc_reset *);
	int (*block_dma)(struct tegra_mc *, const struct tegra_mc_reset *);
	bool (*dma_idling)(struct tegra_mc *, const struct tegra_mc_reset *);
	int (*unblock_dma)(struct tegra_mc *, const struct tegra_mc_reset *);
	int (*reset_status)(struct tegra_mc *, const struct tegra_mc_reset *);
};

struct tegra_smmu;

struct gart_device;

struct tegra_mc_soc;

struct tegra_mc {
	struct device___166 *dev;
	struct tegra_smmu *smmu;
	struct gart_device *gart;
	void *regs;
	struct clk *clk;
	int irq;
	const struct tegra_mc_soc *soc;
	long unsigned int tick;
	struct tegra_mc_timing *timings;
	unsigned int num_timings;
	struct reset_controller_dev___8 reset;
	struct icc_provider provider;
	spinlock_t lock;
	struct {
		struct dentry___202 *root;
	} debugfs;
};

struct tegra_mc_icc_ops {
	int (*set)(struct icc_node *, struct icc_node *);
	int (*aggregate)(struct icc_node *, u32, u32, u32, u32 *, u32 *);
	struct icc_node_data * (*xlate_extended)(struct of_phandle_args___31 *, void *);
};

struct tegra_mc_ops {
	int (*probe)(struct tegra_mc *);
	void (*remove)(struct tegra_mc *);
	int (*suspend)(struct tegra_mc *);
	int (*resume)(struct tegra_mc *);
	irqreturn_t (*handle_irq)(int, void *);
	int (*probe_device)(struct tegra_mc *, struct device___166 *);
};

struct tegra_mc_soc {
	const struct tegra_mc_client *clients;
	unsigned int num_clients;
	const long unsigned int *emem_regs;
	unsigned int num_emem_regs;
	unsigned int num_address_bits;
	unsigned int atom_size;
	u8 client_id_mask;
	const struct tegra_smmu_soc *smmu;
	u32 intmask;
	const struct tegra_mc_reset_ops *reset_ops;
	const struct tegra_mc_reset *resets;
	unsigned int num_resets;
	const struct tegra_mc_icc_ops *icc_ops;
	const struct tegra_mc_ops *ops;
};

struct nvidia_smmu {
	struct arm_smmu_device smmu;
	void *bases[2];
	unsigned int num_instances;
	struct tegra_mc *mc;
};

struct io_pgtable___2 {
	enum io_pgtable_fmt fmt;
	void *cookie;
	struct io_pgtable_cfg___2 cfg;
	struct io_pgtable_ops___2 ops;
};

struct adreno_smmu_fault_info {
	u64 far;
	u64 ttbr0;
	u32 contextidr;
	u32 fsr;
	u32 fsynr0;
	u32 fsynr1;
	u32 cbfrsynra;
};

struct adreno_smmu_priv {
	const void *cookie;
	const struct io_pgtable_cfg___2 * (*get_ttbr1_cfg)(const void *);
	int (*set_ttbr0_cfg)(const void *, const struct io_pgtable_cfg___2 *);
	void (*get_fault_info)(const void *, struct adreno_smmu_fault_info *);
	void (*set_stall)(const void *, bool);
	void (*resume_translation)(const void *, bool);
};

struct qcom_smmu {
	struct arm_smmu_device smmu;
	bool bypass_quirk;
	u8 bypass_cbndx;
	u32 stall_enabled;
};

struct irq_desc___44;

typedef void (*irq_flow_handler_t___44)(struct irq_desc___44 *);

struct msi_desc___14;

struct irq_common_data___14 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___14 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___43;

struct irq_domain___42;

struct irq_data___43 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___14 *common;
	struct irq_chip___43 *chip;
	struct irq_domain___42 *domain;
	struct irq_data___43 *parent_data;
	void *chip_data;
};

struct kset___191;

struct kobj_type___191;

struct kernfs_node___191;

struct kobject___191 {
	const char *name;
	struct list_head entry;
	struct kobject___191 *parent;
	struct kset___191 *kset;
	struct kobj_type___191 *ktype;
	struct kernfs_node___191 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___30;

struct module___187;

struct irq_desc___44 {
	struct irq_common_data___14 irq_common_data;
	struct irq_data___43 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___44 handle_irq;
	struct irqaction___30 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___191 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___187 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___203;

struct super_block___203;

struct file_system_type___203 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___203 * (*mount)(struct file_system_type___203 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___203 *);
	struct module___187 *owner;
	struct file_system_type___203 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___203;

struct kiocb___203;

struct iov_iter___124;

struct poll_table_struct___134;

struct vm_area_struct___208;

struct inode___203;

struct file_lock___203;

struct page___208;

struct seq_file___179;

struct file_operations___204 {
	struct module___187 *owner;
	loff_t (*llseek)(struct file___203 *, loff_t, int);
	ssize_t (*read)(struct file___203 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___203 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___203 *, struct iov_iter___124 *);
	ssize_t (*write_iter)(struct kiocb___203 *, struct iov_iter___124 *);
	int (*iopoll)(struct kiocb___203 *, bool);
	int (*iterate)(struct file___203 *, struct dir_context *);
	int (*iterate_shared)(struct file___203 *, struct dir_context *);
	__poll_t (*poll)(struct file___203 *, struct poll_table_struct___134 *);
	long int (*unlocked_ioctl)(struct file___203 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___203 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___203 *, struct vm_area_struct___208 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___203 *, struct file___203 *);
	int (*flush)(struct file___203 *, fl_owner_t);
	int (*release)(struct inode___203 *, struct file___203 *);
	int (*fsync)(struct file___203 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___203 *, int);
	int (*lock)(struct file___203 *, int, struct file_lock___203 *);
	ssize_t (*sendpage)(struct file___203 *, struct page___208 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___203 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___203 *, long unsigned int);
	int (*flock)(struct file___203 *, int, struct file_lock___203 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___203 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___203 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___203 *, long int, struct file_lock___203 **, void **);
	long int (*fallocate)(struct file___203 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___179 *, struct file___203 *);
	ssize_t (*copy_file_range)(struct file___203 *, loff_t, struct file___203 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___203 *, loff_t, struct file___203 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___203 *, loff_t, loff_t, int);
};

struct vmacache___208 {
	u64 seqnum;
	struct vm_area_struct___208 *vmas[4];
};

struct page_frag___208 {
	struct page___208 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___209;

struct pid___180;

struct nsproxy___189;

struct signal_struct___204;

struct bio_list___104;

struct backing_dev_info___97;

struct io_context___104;

struct css_set___139;

struct mem_cgroup___88;

struct request_queue___104;

struct vm_struct___186;

struct task_struct___210 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___210 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___209 *mm;
	struct mm_struct___209 *active_mm;
	struct vmacache___208 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___210 *real_parent;
	struct task_struct___210 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___210 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___180 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___189 *nsproxy;
	struct signal_struct___204 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___210 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___104 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___97 *backing_dev_info;
	struct io_context___104 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___139 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___208 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___88 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___88 *active_memcg;
	struct request_queue___104 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___210 *oom_reaper_list;
	struct vm_struct___186 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___187 {
	struct kobject___191 kobj;
	struct module___187 *mod;
	struct kobject___191 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___187 {
	struct module___187 *mod;
	struct latch_tree_node node;
};

struct module_layout___187 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___187 mtn;
};

struct module_attribute___187;

struct kernel_param___187;

struct module___187 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___187 mkobj;
	struct module_attribute___187 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___191 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___187 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___187 core_layout;
	struct module_layout___187 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___208 *pgtable_t___208;

struct address_space___203;

struct dev_pagemap___198;

struct page___208 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___203 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___54 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___208 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___208 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___209 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___198 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___198;

struct vm_area_struct___208 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___208 *vm_next;
	struct vm_area_struct___208 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___209 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___198 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___203 *vm_file;
	struct file___203 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___208;

struct mm_struct___209 {
	struct {
		struct vm_area_struct___208 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___203 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___208 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___210 *owner;
		struct user_namespace___25 *user_ns;
		struct file___203 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___203;

struct address_space___203 {
	struct inode___203 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___203 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___198;

struct dev_pagemap___198 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___198 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___203;

struct path___203 {
	struct vfsmount___203 *mnt;
	struct dentry___203 *dentry;
};

struct fown_struct___180 {
	rwlock_t lock;
	struct pid___180 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___203 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___203 f_path;
	struct inode___203 *f_inode;
	const struct file_operations___204 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___180 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___203 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___198;

struct vm_operations_struct___198 {
	void (*open)(struct vm_area_struct___208 *);
	void (*close)(struct vm_area_struct___208 *);
	int (*may_split)(struct vm_area_struct___208 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___208 *);
	int (*mprotect)(struct vm_area_struct___208 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___198 *);
	vm_fault_t (*huge_fault)(struct vm_fault___198 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___198 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___208 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___198 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___198 *);
	int (*access)(struct vm_area_struct___208 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___208 *);
	int (*set_policy)(struct vm_area_struct___208 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___208 *, long unsigned int);
	struct page___208 * (*find_special_page)(struct vm_area_struct___208 *, long unsigned int);
};

struct core_thread___208 {
	struct task_struct___210 *task;
	struct core_thread___208 *next;
};

struct core_state___208 {
	atomic_t nr_threads;
	struct core_thread___208 dumper;
	struct completion startup;
};

struct vm_fault___198 {
	const struct {
		struct vm_area_struct___208 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___208 *cow_page;
	struct page___208 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___208 prealloc_pte;
};

struct pglist_data___95;

struct lruvec___95 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___95 *pgdat;
};

struct zone___95 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___95 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___95 {
	struct zone___95 *zone;
	int zone_idx;
};

struct zonelist___95 {
	struct zoneref___95 _zonerefs[321];
};

struct pglist_data___95 {
	struct zone___95 node_zones[5];
	struct zonelist___95 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___210 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___210 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___95 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___191;

struct kernfs_elem_dir___191 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___191 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___191;

struct kernfs_root___191 {
	struct kernfs_node___191 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___191 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___191 {
	struct kernfs_node___191 *target_kn;
};

struct kernfs_ops___191;

struct kernfs_elem_attr___191 {
	const struct kernfs_ops___191 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___191 *notify_next;
};

struct kernfs_node___191 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___191 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___191 dir;
		struct kernfs_elem_symlink___191 symlink;
		struct kernfs_elem_attr___191 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___191;

struct kernfs_ops___191 {
	int (*open)(struct kernfs_open_file___191 *);
	void (*release)(struct kernfs_open_file___191 *);
	int (*seq_show)(struct seq_file___179 *, void *);
	void * (*seq_start)(struct seq_file___179 *, loff_t *);
	void * (*seq_next)(struct seq_file___179 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___179 *, void *);
	ssize_t (*read)(struct kernfs_open_file___191 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___191 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___191 *, struct poll_table_struct___134 *);
	int (*mmap)(struct kernfs_open_file___191 *, struct vm_area_struct___208 *);
};

struct kernfs_syscall_ops___191 {
	int (*show_options)(struct seq_file___179 *, struct kernfs_root___191 *);
	int (*mkdir)(struct kernfs_node___191 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___191 *);
	int (*rename)(struct kernfs_node___191 *, struct kernfs_node___191 *, const char *);
	int (*show_path)(struct seq_file___179 *, struct kernfs_node___191 *, struct kernfs_root___191 *);
};

struct seq_operations___179;

struct seq_file___179 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___179 *op;
	int poll_event;
	const struct file___203 *file;
	void *private;
};

struct kernfs_open_file___191 {
	struct kernfs_node___191 *kn;
	struct file___203 *file;
	struct seq_file___179 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___198 *vm_ops;
};

typedef void (*poll_queue_proc___141)(struct file___203 *, wait_queue_head_t *, struct poll_table_struct___134 *);

struct poll_table_struct___134 {
	poll_queue_proc___141 _qproc;
	__poll_t _key;
};

struct pid_namespace___180;

struct upid___180 {
	int nr;
	struct pid_namespace___180 *ns;
};

struct pid_namespace___180 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___210 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___180 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___180 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___180 numbers[1];
};

struct signal_struct___204 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___210 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___210 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___180 *pids[4];
	struct pid___180 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___209 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___139;

struct nsproxy___189 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___180 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___139 *cgroup_ns;
};

struct bio___104;

struct bio_list___104 {
	struct bio___104 *head;
	struct bio___104 *tail;
};

struct cgroup_subsys_state___139;

struct bdi_writeback___97 {
	struct backing_dev_info___97 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___139 *memcg_css;
	struct cgroup_subsys_state___139 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___167;

struct backing_dev_info___97 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___97 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___167 *dev;
	char dev_name[64];
	struct device___167 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___203 *debug_dir;
};

struct io_cq___104;

struct io_context___104 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___104 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___139;

struct css_set___139 {
	struct cgroup_subsys_state___139 *subsys[14];
	refcount_t refcount;
	struct css_set___139 *dom_cset;
	struct cgroup___139 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___139 *mg_src_cgrp;
	struct cgroup___139 *mg_dst_cgrp;
	struct css_set___139 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___139;

struct cgroup_subsys_state___139 {
	struct cgroup___139 *cgroup;
	struct cgroup_subsys___139 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___139 *parent;
};

struct cgroup_file___139 {
	struct kernfs_node___191 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___88;

struct mem_cgroup_per_node___88;

struct mem_cgroup___88 {
	struct cgroup_subsys_state___139 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___139 events_file;
	struct cgroup_file___139 events_local_file;
	struct cgroup_file___139 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___88 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___210 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___88 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___104;

struct blk_integrity___104 {
	const struct blk_integrity_profile___104 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___104 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___104 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___104;

struct elevator_queue___104;

struct blk_mq_ops___101;

struct blk_mq_hw_ctx___101;

struct gendisk___105;

struct blkcg_gq___99;

struct blk_mq_tag_set___101;

struct request_queue___104 {
	struct request___104 *last_merge;
	struct elevator_queue___104 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___101 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___101 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___105 *disk;
	struct kobject___191 kobj;
	struct kobject___191 *mq_kobj;
	struct blk_integrity___104 integrity;
	struct device___167 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___99 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___101 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___104 bio_split;
	struct dentry___203 *debugfs_dir;
	struct dentry___203 *sched_debugfs_dir;
	struct dentry___203 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___186 {
	struct vm_struct___186 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___208 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___191;

struct attribute_group___191 {
	const char *name;
	umode_t (*is_visible)(struct kobject___191 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___191 *, struct bin_attribute___191 *, int);
	struct attribute **attrs;
	struct bin_attribute___191 **bin_attrs;
};

struct bin_attribute___191 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___203 * (*f_mapping)();
	ssize_t (*read)(struct file___203 *, struct kobject___191 *, struct bin_attribute___191 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___203 *, struct kobject___191 *, struct bin_attribute___191 *, char *, loff_t, size_t);
	int (*mmap)(struct file___203 *, struct kobject___191 *, struct bin_attribute___191 *, struct vm_area_struct___208 *);
};

struct sysfs_ops___191 {
	ssize_t (*show)(struct kobject___191 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___191 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___191;

struct kset___191 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___191 kobj;
	const struct kset_uevent_ops___191 *uevent_ops;
};

struct kobj_type___191 {
	void (*release)(struct kobject___191 *);
	const struct sysfs_ops___191 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___191 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___191 *);
	const void * (*namespace)(struct kobject___191 *);
	void (*get_ownership)(struct kobject___191 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___191 {
	int (* const filter)(struct kset___191 *, struct kobject___191 *);
	const char * (* const name)(struct kset___191 *, struct kobject___191 *);
	int (* const uevent)(struct kset___191 *, struct kobject___191 *, struct kobj_uevent_env *);
};

struct fwnode_operations___167;

struct fwnode_handle___167 {
	struct fwnode_handle___167 *secondary;
	const struct fwnode_operations___167 *ops;
	struct device___167 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___167;

struct fwnode_endpoint___167;

struct fwnode_operations___167 {
	struct fwnode_handle___167 * (*get)(struct fwnode_handle___167 *);
	void (*put)(struct fwnode_handle___167 *);
	bool (*device_is_available)(const struct fwnode_handle___167 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___167 *, const struct device___167 *);
	bool (*property_present)(const struct fwnode_handle___167 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___167 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___167 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___167 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*get_parent)(const struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*get_next_child_node)(const struct fwnode_handle___167 *, struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*get_named_child_node)(const struct fwnode_handle___167 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___167 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___167 *);
	struct fwnode_handle___167 * (*graph_get_next_endpoint)(const struct fwnode_handle___167 *, struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*graph_get_remote_endpoint)(const struct fwnode_handle___167 *);
	struct fwnode_handle___167 * (*graph_get_port_parent)(struct fwnode_handle___167 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___167 *, struct fwnode_endpoint___167 *);
	int (*add_links)(struct fwnode_handle___167 *);
};

struct wakeup_source___167;

struct dev_pm_info___167 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___167 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___167 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___167;

struct bus_type___167;

struct device_driver___167;

struct dev_pm_domain___167;

struct device_node___68;

struct class___167;

struct dev_iommu___9;

struct device___167 {
	struct kobject___191 kobj;
	struct device___167 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___167 *type;
	struct bus_type___167 *bus;
	struct device_driver___167 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___167 power;
	struct dev_pm_domain___167 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___42 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___68 *of_node;
	struct fwnode_handle___167 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___167 *class;
	const struct attribute_group___191 **groups;
	void (*release)(struct device___167 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___9 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___167 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___167 *local_fwnode;
};

struct fwnode_reference_args___167 {
	struct fwnode_handle___167 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___52 {
	char *name;
	int length;
	void *value;
	struct property___52 *next;
	long unsigned int _flags;
	struct bin_attribute___191 attr;
};

struct device_node___68 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___167 fwnode;
	struct property___52 *properties;
	struct property___52 *deadprops;
	struct device_node___68 *parent;
	struct device_node___68 *child;
	struct device_node___68 *sibling;
	struct kobject___191 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___32 {
	struct device_node___68 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___40 {
	struct fwnode_handle___167 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___42 {
	int (*match)(struct irq_domain___42 *, struct device_node___68 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___42 *, struct irq_fwspec___40 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___42 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___42 *, unsigned int);
	int (*xlate)(struct irq_domain___42 *, struct device_node___68 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___42 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___42 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___42 *, struct irq_data___43 *, bool);
	void (*deactivate)(struct irq_domain___42 *, struct irq_data___43 *);
	int (*translate)(struct irq_domain___42 *, struct irq_fwspec___40 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___42;

struct irq_domain___42 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___42 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___167 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___42 *gc;
	struct irq_domain___42 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___43 *revmap[0];
};

struct irq_chip_generic___42;

struct irq_domain_chip_generic___42 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___42 *gc[0];
};

struct dev_pm_ops___167 {
	int (*prepare)(struct device___167 *);
	void (*complete)(struct device___167 *);
	int (*suspend)(struct device___167 *);
	int (*resume)(struct device___167 *);
	int (*freeze)(struct device___167 *);
	int (*thaw)(struct device___167 *);
	int (*poweroff)(struct device___167 *);
	int (*restore)(struct device___167 *);
	int (*suspend_late)(struct device___167 *);
	int (*resume_early)(struct device___167 *);
	int (*freeze_late)(struct device___167 *);
	int (*thaw_early)(struct device___167 *);
	int (*poweroff_late)(struct device___167 *);
	int (*restore_early)(struct device___167 *);
	int (*suspend_noirq)(struct device___167 *);
	int (*resume_noirq)(struct device___167 *);
	int (*freeze_noirq)(struct device___167 *);
	int (*thaw_noirq)(struct device___167 *);
	int (*poweroff_noirq)(struct device___167 *);
	int (*restore_noirq)(struct device___167 *);
	int (*runtime_suspend)(struct device___167 *);
	int (*runtime_resume)(struct device___167 *);
	int (*runtime_idle)(struct device___167 *);
};

struct wakeup_source___167 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___167 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___167 {
	struct dev_pm_ops___167 ops;
	int (*start)(struct device___167 *);
	void (*detach)(struct device___167 *, bool);
	int (*activate)(struct device___167 *);
	void (*sync)(struct device___167 *);
	void (*dismiss)(struct device___167 *);
};

struct iommu_ops___9;

struct bus_type___167 {
	const char *name;
	const char *dev_name;
	struct device___167 *dev_root;
	const struct attribute_group___191 **bus_groups;
	const struct attribute_group___191 **dev_groups;
	const struct attribute_group___191 **drv_groups;
	int (*match)(struct device___167 *, struct device_driver___167 *);
	int (*uevent)(struct device___167 *, struct kobj_uevent_env *);
	int (*probe)(struct device___167 *);
	void (*sync_state)(struct device___167 *);
	void (*remove)(struct device___167 *);
	void (*shutdown)(struct device___167 *);
	int (*online)(struct device___167 *);
	int (*offline)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	int (*num_vf)(struct device___167 *);
	int (*dma_configure)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
	const struct iommu_ops___9 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___167 {
	const char *name;
	struct bus_type___167 *bus;
	struct module___187 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___167 *);
	void (*sync_state)(struct device___167 *);
	int (*remove)(struct device___167 *);
	void (*shutdown)(struct device___167 *);
	int (*suspend)(struct device___167 *, pm_message_t);
	int (*resume)(struct device___167 *);
	const struct attribute_group___191 **groups;
	const struct attribute_group___191 **dev_groups;
	const struct dev_pm_ops___167 *pm;
	void (*coredump)(struct device___167 *);
	struct driver_private *p;
};

struct iommu_domain___9;

struct iommu_iotlb_gather___6;

struct iommu_device___9;

struct iommu_sva___9;

struct iommu_ops___9 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___9 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___9 *);
	int (*attach_dev)(struct iommu_domain___9 *, struct device___167 *);
	void (*detach_dev)(struct iommu_domain___9 *, struct device___167 *);
	int (*map)(struct iommu_domain___9 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___9 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___9 *, long unsigned int, size_t, struct iommu_iotlb_gather___6 *);
	size_t (*unmap_pages)(struct iommu_domain___9 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___6 *);
	void (*flush_iotlb_all)(struct iommu_domain___9 *);
	void (*iotlb_sync_map)(struct iommu_domain___9 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___9 *, struct iommu_iotlb_gather___6 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___9 *, dma_addr_t);
	struct iommu_device___9 * (*probe_device)(struct device___167 *);
	void (*release_device)(struct device___167 *);
	void (*probe_finalize)(struct device___167 *);
	struct iommu_group * (*device_group)(struct device___167 *);
	int (*enable_nesting)(struct iommu_domain___9 *);
	int (*set_pgtable_quirks)(struct iommu_domain___9 *, long unsigned int);
	void (*get_resv_regions)(struct device___167 *, struct list_head *);
	void (*put_resv_regions)(struct device___167 *, struct list_head *);
	void (*apply_resv_region)(struct device___167 *, struct iommu_domain___9 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___167 *, struct of_phandle_args___32 *);
	bool (*is_attach_deferred)(struct iommu_domain___9 *, struct device___167 *);
	bool (*dev_has_feat)(struct device___167 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___167 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___167 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___167 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___9 *, struct device___167 *);
	void (*aux_detach_dev)(struct iommu_domain___9 *, struct device___167 *);
	int (*aux_get_pasid)(struct iommu_domain___9 *, struct device___167 *);
	struct iommu_sva___9 * (*sva_bind)(struct device___167 *, struct mm_struct___209 *, void *);
	void (*sva_unbind)(struct iommu_sva___9 *);
	u32 (*sva_get_pasid)(struct iommu_sva___9 *);
	int (*page_response)(struct device___167 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___9 *, struct device___167 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___9 *, struct device___167 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___167 *, u32);
	int (*def_domain_type)(struct device___167 *);
	long unsigned int pgsize_bitmap;
	struct module___187 *owner;
};

struct device_type___167 {
	const char *name;
	const struct attribute_group___191 **groups;
	int (*uevent)(struct device___167 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___167 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___167 *);
	const struct dev_pm_ops___167 *pm;
};

struct class___167 {
	const char *name;
	struct module___187 *owner;
	const struct attribute_group___191 **class_groups;
	const struct attribute_group___191 **dev_groups;
	struct kobject___191 *dev_kobj;
	int (*dev_uevent)(struct device___167 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___167 *, umode_t *);
	void (*class_release)(struct class___167 *);
	void (*dev_release)(struct device___167 *);
	int (*shutdown_pre)(struct device___167 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___167 *);
	void (*get_ownership)(struct device___167 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___167 *pm;
	struct subsys_private *p;
};

struct iommu_fwspec___9;

struct dev_iommu___9 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___9 *fwspec;
	struct iommu_device___9 *iommu_dev;
	void *priv;
};

struct dentry_operations___203;

struct dentry___203 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___203 *d_parent;
	struct qstr d_name;
	struct inode___203 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___203 *d_op;
	struct super_block___203 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___203;

struct cdev___50;

struct inode___203 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___203 *i_op;
	struct super_block___203 *i_sb;
	struct address_space___203 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___97 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___204 *i_fop;
		void (*free_inode)(struct inode___203 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___203 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___50 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___203 {
	int (*d_revalidate)(struct dentry___203 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___203 *, unsigned int);
	int (*d_hash)(const struct dentry___203 *, struct qstr *);
	int (*d_compare)(const struct dentry___203 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___203 *);
	int (*d_init)(struct dentry___203 *);
	void (*d_release)(struct dentry___203 *);
	void (*d_prune)(struct dentry___203 *);
	void (*d_iput)(struct dentry___203 *, struct inode___203 *);
	char * (*d_dname)(struct dentry___203 *, char *, int);
	struct vfsmount___203 * (*d_automount)(struct path___203 *);
	int (*d_manage)(const struct path___203 *, bool);
	struct dentry___203 * (*d_real)(struct dentry___203 *, const struct inode___203 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___203;

struct mem_dqinfo___203 {
	struct quota_format_type___203 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___203;

struct quota_info___203 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___203 *files[3];
	struct mem_dqinfo___203 info[3];
	const struct quota_format_ops___203 *ops[3];
};

struct rcuwait___204 {
	struct task_struct___210 *task;
};

struct percpu_rw_semaphore___204 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___204 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___203 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___204 rw_sem[3];
};

struct shrink_control___88;

struct shrinker___88 {
	long unsigned int (*count_objects)(struct shrinker___88 *, struct shrink_control___88 *);
	long unsigned int (*scan_objects)(struct shrinker___88 *, struct shrink_control___88 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___203;

struct dquot_operations___203;

struct quotactl_ops___203;

struct block_device___105;

struct super_block___203 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___203 *s_type;
	const struct super_operations___203 *s_op;
	const struct dquot_operations___203 *dq_op;
	const struct quotactl_ops___203 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___203 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___105 *s_bdev;
	struct backing_dev_info___97 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___203 s_dquot;
	struct sb_writers___203 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___203 *s_d_op;
	int cleancache_poolid;
	struct shrinker___88 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___203 {
	struct dentry___203 *mnt_root;
	struct super_block___203 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___88 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___88 *memcg;
};

struct psi_group___139 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___210 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___139;

struct cgroup_rstat_cpu___139;

struct cgroup___139 {
	struct cgroup_subsys_state___139 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___191 *kn;
	struct cgroup_file___139 procs_file;
	struct cgroup_file___139 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___139 *subsys[14];
	struct cgroup_root___139 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___139 *dom_cgrp;
	struct cgroup___139 *old_dom_cgrp;
	struct cgroup_rstat_cpu___139 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___139 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___104 {
	struct request_queue___104 *q;
	struct io_context___104 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___98;

struct kiocb___203 {
	struct file___203 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___203 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___98 *ki_waitq;
	};
};

struct iattr___203 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___203 *ia_file;
};

struct dquot___203 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___203 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___203 {
	int qf_fmt_id;
	const struct quota_format_ops___203 *qf_ops;
	struct module___187 *qf_owner;
	struct quota_format_type___203 *qf_next;
};

struct quota_format_ops___203 {
	int (*check_quota_file)(struct super_block___203 *, int);
	int (*read_file_info)(struct super_block___203 *, int);
	int (*write_file_info)(struct super_block___203 *, int);
	int (*free_file_info)(struct super_block___203 *, int);
	int (*read_dqblk)(struct dquot___203 *);
	int (*commit_dqblk)(struct dquot___203 *);
	int (*release_dqblk)(struct dquot___203 *);
	int (*get_next_id)(struct super_block___203 *, struct kqid *);
};

struct dquot_operations___203 {
	int (*write_dquot)(struct dquot___203 *);
	struct dquot___203 * (*alloc_dquot)(struct super_block___203 *, int);
	void (*destroy_dquot)(struct dquot___203 *);
	int (*acquire_dquot)(struct dquot___203 *);
	int (*release_dquot)(struct dquot___203 *);
	int (*mark_dirty)(struct dquot___203 *);
	int (*write_info)(struct super_block___203 *, int);
	qsize_t * (*get_reserved_space)(struct inode___203 *);
	int (*get_projid)(struct inode___203 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___203 *, qsize_t *);
	int (*get_next_id)(struct super_block___203 *, struct kqid *);
};

struct quotactl_ops___203 {
	int (*quota_on)(struct super_block___203 *, int, int, const struct path___203 *);
	int (*quota_off)(struct super_block___203 *, int);
	int (*quota_enable)(struct super_block___203 *, unsigned int);
	int (*quota_disable)(struct super_block___203 *, unsigned int);
	int (*quota_sync)(struct super_block___203 *, int);
	int (*set_info)(struct super_block___203 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___203 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___203 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___203 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___203 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___203 *, unsigned int);
};

struct wait_page_queue___98 {
	struct page___208 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___97;

struct readahead_control___98;

struct swap_info_struct___56;

struct address_space_operations___203 {
	int (*writepage)(struct page___208 *, struct writeback_control___97 *);
	int (*readpage)(struct file___203 *, struct page___208 *);
	int (*writepages)(struct address_space___203 *, struct writeback_control___97 *);
	int (*set_page_dirty)(struct page___208 *);
	int (*readpages)(struct file___203 *, struct address_space___203 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___98 *);
	int (*write_begin)(struct file___203 *, struct address_space___203 *, loff_t, unsigned int, unsigned int, struct page___208 **, void **);
	int (*write_end)(struct file___203 *, struct address_space___203 *, loff_t, unsigned int, unsigned int, struct page___208 *, void *);
	sector_t (*bmap)(struct address_space___203 *, sector_t);
	void (*invalidatepage)(struct page___208 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___208 *, gfp_t);
	void (*freepage)(struct page___208 *);
	ssize_t (*direct_IO)(struct kiocb___203 *, struct iov_iter___124 *);
	int (*migratepage)(struct address_space___203 *, struct page___208 *, struct page___208 *, enum migrate_mode);
	bool (*isolate_page)(struct page___208 *, isolate_mode_t);
	void (*putback_page)(struct page___208 *);
	int (*launder_page)(struct page___208 *);
	int (*is_partially_uptodate)(struct page___208 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___208 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___203 *, struct page___208 *);
	int (*swap_activate)(struct swap_info_struct___56 *, struct file___203 *, sector_t *);
	void (*swap_deactivate)(struct file___203 *);
};

struct writeback_control___97 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___97 *wb;
	struct inode___203 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___98 {
	struct file___203 *file;
	struct address_space___203 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___121;

struct iov_iter___124 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___121 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___56 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___105 *bdev;
	struct file___203 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___50 {
	struct kobject___191 kobj;
	struct module___187 *owner;
	const struct file_operations___204 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___203 {
	struct dentry___203 * (*lookup)(struct inode___203 *, struct dentry___203 *, unsigned int);
	const char * (*get_link)(struct dentry___203 *, struct inode___203 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___203 *, int);
	struct posix_acl * (*get_acl)(struct inode___203 *, int, bool);
	int (*readlink)(struct dentry___203 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___203 *, struct dentry___203 *, umode_t, bool);
	int (*link)(struct dentry___203 *, struct inode___203 *, struct dentry___203 *);
	int (*unlink)(struct inode___203 *, struct dentry___203 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___203 *, struct dentry___203 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___203 *, struct dentry___203 *, umode_t);
	int (*rmdir)(struct inode___203 *, struct dentry___203 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___203 *, struct dentry___203 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___203 *, struct dentry___203 *, struct inode___203 *, struct dentry___203 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___203 *, struct iattr___203 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___203 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___203 *, char *, size_t);
	int (*fiemap)(struct inode___203 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___203 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___203 *, struct dentry___203 *, struct file___203 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___203 *, struct dentry___203 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___203 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___203 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___203 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___203 {
	void (*fl_copy_lock)(struct file_lock___203 *, struct file_lock___203 *);
	void (*fl_release_private)(struct file_lock___203 *);
};

struct fasync_struct___203;

struct lock_manager_operations___203;

struct file_lock___203 {
	struct file_lock___203 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___203 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___203 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___203 *fl_ops;
	const struct lock_manager_operations___203 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___203 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___203 *);
	int (*lm_grant)(struct file_lock___203 *, int);
	bool (*lm_break)(struct file_lock___203 *);
	int (*lm_change)(struct file_lock___203 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___203 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___203 *);
};

struct fasync_struct___203 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___203 *fa_next;
	struct file___203 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___203 {
	struct inode___203 * (*alloc_inode)(struct super_block___203 *);
	void (*destroy_inode)(struct inode___203 *);
	void (*free_inode)(struct inode___203 *);
	void (*dirty_inode)(struct inode___203 *, int);
	int (*write_inode)(struct inode___203 *, struct writeback_control___97 *);
	int (*drop_inode)(struct inode___203 *);
	void (*evict_inode)(struct inode___203 *);
	void (*put_super)(struct super_block___203 *);
	int (*sync_fs)(struct super_block___203 *, int);
	int (*freeze_super)(struct super_block___203 *);
	int (*freeze_fs)(struct super_block___203 *);
	int (*thaw_super)(struct super_block___203 *);
	int (*unfreeze_fs)(struct super_block___203 *);
	int (*statfs)(struct dentry___203 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___203 *, int *, char *);
	void (*umount_begin)(struct super_block___203 *);
	int (*show_options)(struct seq_file___179 *, struct dentry___203 *);
	int (*show_devname)(struct seq_file___179 *, struct dentry___203 *);
	int (*show_path)(struct seq_file___179 *, struct dentry___203 *);
	int (*show_stats)(struct seq_file___179 *, struct dentry___203 *);
	ssize_t (*quota_read)(struct super_block___203 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___203 *, int, const char *, size_t, loff_t);
	struct dquot___203 ** (*get_dquots)(struct inode___203 *);
	long int (*nr_cached_objects)(struct super_block___203 *, struct shrink_control___88 *);
	long int (*free_cached_objects)(struct super_block___203 *, struct shrink_control___88 *);
	struct file___203 * (*real_loop)(struct file___203 *);
};

struct block_device___105 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___203 *bd_inode;
	struct super_block___203 *bd_super;
	void *bd_claiming;
	struct device___167 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___191 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___105 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___203 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___104(struct bio___104 *);

struct bio_vec___121 {
	struct page___208 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___104;

struct bio___104 {
	struct bio___104 *bi_next;
	struct block_device___105 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___104 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___99 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___104 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___121 *bi_io_vec;
	struct bio_set___104 *bi_pool;
	struct bio_vec___121 bi_inline_vecs[0];
};

struct kernel_param_ops___187 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___187 *);
	int (*get)(char *, const struct kernel_param___187 *);
	void (*free)(void *);
};

struct kparam_array___187;

struct kernel_param___187 {
	const char *name;
	struct module___187 *mod;
	const struct kernel_param_ops___187 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___187 *arr;
	};
};

struct kparam_array___187 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___187 *ops;
	void *elem;
};

struct module_attribute___187 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___187 *, struct module_kobject___187 *, char *);
	ssize_t (*store)(struct module_attribute___187 *, struct module_kobject___187 *, const char *, size_t);
	void (*setup)(struct module___187 *, const char *);
	int (*test)(struct module___187 *);
	void (*free)(struct module___187 *);
};

struct pci_dev___14;

struct pci_ops___14;

struct pci_bus___14 {
	struct list_head node;
	struct pci_bus___14 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___14 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___14 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___167 *bridge;
	struct device___167 dev;
	struct bin_attribute___191 *legacy_io;
	struct bin_attribute___191 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_desc___14 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___167 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___14 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___43 {
	struct device___167 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___43 *);
	void (*irq_shutdown)(struct irq_data___43 *);
	void (*irq_enable)(struct irq_data___43 *);
	void (*irq_disable)(struct irq_data___43 *);
	void (*irq_ack)(struct irq_data___43 *);
	void (*irq_mask)(struct irq_data___43 *);
	void (*irq_mask_ack)(struct irq_data___43 *);
	void (*irq_unmask)(struct irq_data___43 *);
	void (*irq_eoi)(struct irq_data___43 *);
	int (*irq_set_affinity)(struct irq_data___43 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___43 *);
	int (*irq_set_type)(struct irq_data___43 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___43 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___43 *);
	void (*irq_bus_sync_unlock)(struct irq_data___43 *);
	void (*irq_cpu_online)(struct irq_data___43 *);
	void (*irq_cpu_offline)(struct irq_data___43 *);
	void (*irq_suspend)(struct irq_data___43 *);
	void (*irq_resume)(struct irq_data___43 *);
	void (*irq_pm_shutdown)(struct irq_data___43 *);
	void (*irq_calc_mask)(struct irq_data___43 *);
	void (*irq_print_chip)(struct irq_data___43 *, struct seq_file___179 *);
	int (*irq_request_resources)(struct irq_data___43 *);
	void (*irq_release_resources)(struct irq_data___43 *);
	void (*irq_compose_msi_msg)(struct irq_data___43 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___43 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___43 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___43 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___43 *, void *);
	void (*ipi_send_single)(struct irq_data___43 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___43 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___43 *);
	void (*irq_nmi_teardown)(struct irq_data___43 *);
	long unsigned int flags;
};

struct irqaction___30 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___30 *next;
	irq_handler_t thread_fn;
	struct task_struct___210 *thread;
	struct irqaction___30 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___42 {
	struct irq_chip___43 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___44 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___42 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___42 *);
	void (*resume)(struct irq_chip_generic___42 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___42 *domain;
	struct list_head list;
	struct irq_chip_type___42 chip_types[0];
};

struct seq_operations___179 {
	void * (*start)(struct seq_file___179 *, loff_t *);
	void (*stop)(struct seq_file___179 *, void *);
	void * (*next)(struct seq_file___179 *, void *, loff_t *);
	int (*show)(struct seq_file___179 *, void *);
};

struct dev_pagemap_ops___198 {
	void (*page_free)(struct page___208 *);
	void (*kill)(struct dev_pagemap___198 *);
	void (*cleanup)(struct dev_pagemap___198 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___198 *);
};

struct cgroup_namespace___139 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___139 *root_cset;
};

enum iommu_fault_type {
	IOMMU_FAULT_DMA_UNRECOV = 1,
	IOMMU_FAULT_PAGE_REQ = 2,
};

enum iommu_fault_reason {
	IOMMU_FAULT_REASON_UNKNOWN = 0,
	IOMMU_FAULT_REASON_PASID_FETCH = 1,
	IOMMU_FAULT_REASON_BAD_PASID_ENTRY = 2,
	IOMMU_FAULT_REASON_PASID_INVALID = 3,
	IOMMU_FAULT_REASON_WALK_EABT = 4,
	IOMMU_FAULT_REASON_PTE_FETCH = 5,
	IOMMU_FAULT_REASON_PERMISSION = 6,
	IOMMU_FAULT_REASON_ACCESS = 7,
	IOMMU_FAULT_REASON_OOR_ADDRESS = 8,
};

enum iommu_page_response_code {
	IOMMU_PAGE_RESP_SUCCESS = 0,
	IOMMU_PAGE_RESP_INVALID = 1,
	IOMMU_PAGE_RESP_FAILURE = 2,
};

typedef int (*iommu_fault_handler_t___9)(struct iommu_domain___9 *, struct device___167 *, long unsigned int, int, void *);

struct iommu_domain___9 {
	unsigned int type;
	const struct iommu_ops___9 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___9 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___6 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___208 *freelist;
	bool queued;
};

struct iommu_device___9 {
	struct list_head list;
	const struct iommu_ops___9 *ops;
	struct fwnode_handle___167 *fwnode;
	struct device___167 *dev;
};

struct iommu_sva___9 {
	struct device___167 *dev;
};

struct iommu_fwspec___9 {
	const struct iommu_ops___9 *ops;
	struct fwnode_handle___167 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

typedef void (*irq_write_msi_msg_t___3)(struct msi_desc___14 *, struct msi_msg *);

struct iommu_flush_ops___3 {
	void (*tlb_flush_all)(void *);
	void (*tlb_flush_walk)(long unsigned int, size_t, size_t, void *);
	void (*tlb_add_page)(struct iommu_iotlb_gather___6 *, long unsigned int, size_t, void *);
};

struct io_pgtable_cfg___3 {
	long unsigned int quirks;
	long unsigned int pgsize_bitmap;
	unsigned int ias;
	unsigned int oas;
	bool coherent_walk;
	const struct iommu_flush_ops___3 *tlb;
	struct device___167 *iommu_dev;
	union {
		struct {
			u64 ttbr;
			struct {
				u32 ips: 3;
				u32 tg: 2;
				u32 sh: 2;
				u32 orgn: 2;
				u32 irgn: 2;
				u32 tsz: 6;
			} tcr;
			u64 mair;
		} arm_lpae_s1_cfg;
		struct {
			u64 vttbr;
			struct {
				u32 ps: 3;
				u32 tg: 2;
				u32 sh: 2;
				u32 orgn: 2;
				u32 irgn: 2;
				u32 sl: 2;
				u32 tsz: 6;
			} vtcr;
		} arm_lpae_s2_cfg;
		struct {
			u32 ttbr;
			u32 tcr;
			u32 nmrr;
			u32 prrr;
		} arm_v7s_cfg;
		struct {
			u64 transtab;
			u64 memattr;
		} arm_mali_lpae_cfg;
		struct {
			u64 ttbr[4];
			u32 n_ttbrs;
		} apple_dart_cfg;
	};
};

struct io_pgtable_ops___3 {
	int (*map)(struct io_pgtable_ops___3 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct io_pgtable_ops___3 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct io_pgtable_ops___3 *, long unsigned int, size_t, struct iommu_iotlb_gather___6 *);
	size_t (*unmap_pages)(struct io_pgtable_ops___3 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___6 *);
	phys_addr_t (*iova_to_phys)(struct io_pgtable_ops___3 *, long unsigned int);
};

struct platform_device___26 {
	const char *name;
	int id;
	bool id_auto;
	struct device___167 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___24 {
	int (*probe)(struct platform_device___26 *);
	int (*remove)(struct platform_device___26 *);
	void (*shutdown)(struct platform_device___26 *);
	int (*suspend)(struct platform_device___26 *, pm_message_t);
	int (*resume)(struct platform_device___26 *);
	struct device_driver___167 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct pci_slot___14 {
	struct pci_bus___14 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___191 kobj;
};

struct pci_driver___14;

struct pci_dev___14 {
	struct list_head bus_list;
	struct pci_bus___14 *bus;
	struct pci_bus___14 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___14 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___14 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___14 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___167 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___191 *res_attr[17];
	struct bin_attribute___191 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___191 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___14 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___14;

struct pci_driver___14 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___14 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___14 *);
	int (*suspend)(struct pci_dev___14 *, pm_message_t);
	int (*resume)(struct pci_dev___14 *);
	void (*shutdown)(struct pci_dev___14 *);
	int (*sriov_configure)(struct pci_dev___14 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___14 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___14 *);
	const struct pci_error_handlers___14 *err_handler;
	const struct attribute_group___191 **groups;
	const struct attribute_group___191 **dev_groups;
	struct device_driver___167 driver;
	struct pci_dynids dynids;
};

struct pci_ops___14 {
	int (*add_bus)(struct pci_bus___14 *);
	void (*remove_bus)(struct pci_bus___14 *);
	void * (*map_bus)(struct pci_bus___14 *, unsigned int, int);
	int (*read)(struct pci_bus___14 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___14 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___14 {
	pci_ers_result_t (*error_detected)(struct pci_dev___14 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___14 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___14 *);
	void (*reset_prepare)(struct pci_dev___14 *);
	void (*reset_done)(struct pci_dev___14 *);
	void (*resume)(struct pci_dev___14 *);
};

struct cftype___139;

struct cgroup_subsys___139 {
	struct cgroup_subsys_state___139 * (*css_alloc)(struct cgroup_subsys_state___139 *);
	int (*css_online)(struct cgroup_subsys_state___139 *);
	void (*css_offline)(struct cgroup_subsys_state___139 *);
	void (*css_released)(struct cgroup_subsys_state___139 *);
	void (*css_free)(struct cgroup_subsys_state___139 *);
	void (*css_reset)(struct cgroup_subsys_state___139 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___139 *, int);
	int (*css_extra_stat_show)(struct seq_file___179 *, struct cgroup_subsys_state___139 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___210 *, struct css_set___139 *);
	void (*cancel_fork)(struct task_struct___210 *, struct css_set___139 *);
	void (*fork)(struct task_struct___210 *);
	void (*exit)(struct task_struct___210 *);
	void (*release)(struct task_struct___210 *);
	void (*bind)(struct cgroup_subsys_state___139 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___139 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___139 *dfl_cftypes;
	struct cftype___139 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___139 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___139 *updated_children;
	struct cgroup___139 *updated_next;
};

struct cgroup_root___139 {
	struct kernfs_root___191 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___139 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___139 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___139 *ss;
	struct list_head node;
	struct kernfs_ops___191 *kf_ops;
	int (*open)(struct kernfs_open_file___191 *);
	void (*release)(struct kernfs_open_file___191 *);
	u64 (*read_u64)(struct cgroup_subsys_state___139 *, struct cftype___139 *);
	s64 (*read_s64)(struct cgroup_subsys_state___139 *, struct cftype___139 *);
	int (*seq_show)(struct seq_file___179 *, void *);
	void * (*seq_start)(struct seq_file___179 *, loff_t *);
	void * (*seq_next)(struct seq_file___179 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___179 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___139 *, struct cftype___139 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___139 *, struct cftype___139 *, s64);
	ssize_t (*write)(struct kernfs_open_file___191 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___191 *, struct poll_table_struct___134 *);
};

struct block_device_operations___104;

struct gendisk___105 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___105 *part0;
	const struct block_device_operations___104 *fops;
	struct request_queue___104 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___97 *bdi;
	struct kobject___191 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___191 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___104 {
	struct bio___104 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___121 *bip_vec;
	struct bio_vec___121 bip_inline_vecs[0];
};

struct blkcg___99;

struct blkg_policy_data___99;

struct blkcg_gq___99 {
	struct request_queue___104 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___99 *blkcg;
	struct blkcg_gq___99 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___99 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___104 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___104(struct request___104 *);

typedef void integrity_complete_fn___104(struct request___104 *, unsigned int);

struct blk_integrity_profile___104 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___104 *prepare_fn;
	integrity_complete_fn___104 *complete_fn;
	const char *name;
};

struct block_device_operations___104 {
	blk_qc_t (*submit_bio)(struct bio___104 *);
	int (*open)(struct block_device___105 *, fmode_t);
	void (*release)(struct gendisk___105 *, fmode_t);
	int (*rw_page)(struct block_device___105 *, sector_t, struct page___208 *, unsigned int);
	int (*ioctl)(struct block_device___105 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___105 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___105 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___105 *);
	int (*getgeo)(struct block_device___105 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___105 *, bool);
	void (*swap_slot_free_notify)(struct block_device___105 *, long unsigned int);
	int (*report_zones)(struct gendisk___105 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___105 *, umode_t *);
	struct module___187 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___105 *, sector_t *);
};

typedef void rq_end_io_fn___104(struct request___104 *, blk_status_t);

struct request___104 {
	struct request_queue___104 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___101 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___104 *bio;
	struct bio___104 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___121 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___104 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___104 *saved_end_io;
		} flush;
	};
	struct gendisk___105 *rq_disk;
	struct block_device___105 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___104 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___101 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___104 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___191 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___203 *debugfs_dir;
	struct dentry___203 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___104;

struct elevator_mq_ops___104 {
	int (*init_sched)(struct request_queue___104 *, struct elevator_type___104 *);
	void (*exit_sched)(struct elevator_queue___104 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___101 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___101 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___101 *);
	bool (*allow_merge)(struct request_queue___104 *, struct request___104 *, struct bio___104 *);
	bool (*bio_merge)(struct request_queue___104 *, struct bio___104 *, unsigned int);
	int (*request_merge)(struct request_queue___104 *, struct request___104 **, struct bio___104 *);
	void (*request_merged)(struct request_queue___104 *, struct request___104 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___104 *, struct request___104 *, struct request___104 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___104 *);
	void (*finish_request)(struct request___104 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___101 *, struct list_head *, bool);
	struct request___104 * (*dispatch_request)(struct blk_mq_hw_ctx___101 *);
	bool (*has_work)(struct blk_mq_hw_ctx___101 *);
	void (*completed_request)(struct request___104 *, u64);
	void (*requeue_request)(struct request___104 *);
	struct request___104 * (*former_request)(struct request_queue___104 *, struct request___104 *);
	struct request___104 * (*next_request)(struct request_queue___104 *, struct request___104 *);
	void (*init_icq)(struct io_cq___104 *);
	void (*exit_icq)(struct io_cq___104 *);
};

struct elv_fs_entry___104;

struct elevator_type___104 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___104 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___104 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___187 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___104 {
	struct elevator_type___104 *type;
	void *elevator_data;
	struct kobject___191 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___104 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___104 *, char *);
	ssize_t (*store)(struct elevator_queue___104 *, const char *, size_t);
};

struct blk_mq_queue_data___101;

struct blk_mq_ops___101 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___101 *, const struct blk_mq_queue_data___101 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___101 *);
	int (*get_budget)(struct request_queue___104 *);
	void (*put_budget)(struct request_queue___104 *, int);
	void (*set_rq_budget_token)(struct request___104 *, int);
	int (*get_rq_budget_token)(struct request___104 *);
	enum blk_eh_timer_return (*timeout)(struct request___104 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___101 *);
	void (*complete)(struct request___104 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___101 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___101 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___101 *, struct request___104 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___101 *, struct request___104 *, unsigned int);
	void (*initialize_rq_fn)(struct request___104 *);
	void (*cleanup_rq)(struct request___104 *);
	bool (*busy)(struct request_queue___104 *);
	int (*map_queues)(struct blk_mq_tag_set___101 *);
	void (*show_rq)(struct seq_file___179 *, struct request___104 *);
};

struct blk_mq_tag_set___101 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___101 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___101 {
	struct request___104 *rq;
	bool last;
};

struct blkcg_policy_data___99;

struct blkcg___99 {
	struct cgroup_subsys_state___139 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___99 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___99 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___99 {
	struct blkcg___99 *blkcg;
	int plid;
};

struct blkg_policy_data___99 {
	struct blkcg_gq___99 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___88 {
	struct mem_cgroup___88 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___88 {
	struct lruvec___95 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___88 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___88 *memcg;
};

struct obj_cgroup___88 {
	struct percpu_ref refcnt;
	struct mem_cgroup___88 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum pri_resp {
	PRI_RESP_DENY = 0,
	PRI_RESP_FAIL = 1,
	PRI_RESP_SUCC = 2,
};

struct arm_smmu_cmdq_ent {
	u8 opcode;
	bool substream_valid;
	union {
		struct {
			u32 sid;
		} prefetch;
		struct {
			u32 sid;
			u32 ssid;
			union {
				bool leaf;
				u8 span;
			};
		} cfgi;
		struct {
			u8 num;
			u8 scale;
			u16 asid;
			u16 vmid;
			bool leaf;
			u8 ttl;
			u8 tg;
			u64 addr;
		} tlbi;
		struct {
			u32 sid;
			u32 ssid;
			u64 addr;
			u8 size;
			bool global;
		} atc;
		struct {
			u32 sid;
			u32 ssid;
			u16 grpid;
			enum pri_resp resp;
		} pri;
		struct {
			u32 sid;
			u16 stag;
			u8 resp;
		} resume;
		struct {
			u64 msiaddr;
		} sync;
	};
};

struct arm_smmu_ll_queue {
	union {
		u64 val;
		struct {
			u32 prod;
			u32 cons;
		};
		struct {
			atomic_t prod;
			atomic_t cons;
		} atomic;
		u8 __pad[64];
	};
	u32 max_n_shift;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct arm_smmu_queue {
	struct arm_smmu_ll_queue llq;
	int irq;
	__le64 *base;
	dma_addr_t base_dma;
	u64 q_base;
	size_t ent_dwords;
	u32 *prod_reg;
	u32 *cons_reg;
	long: 64;
};

struct arm_smmu_queue_poll {
	ktime_t timeout;
	unsigned int delay;
	unsigned int spin_cnt;
	bool wfe;
};

struct arm_smmu_cmdq {
	struct arm_smmu_queue q;
	atomic_long_t *valid_map;
	atomic_t owner_prod;
	atomic_t lock;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct arm_smmu_cmdq_batch {
	u64 cmds[128];
	int num;
};

struct iopf_queue;

struct arm_smmu_evtq {
	struct arm_smmu_queue q;
	struct iopf_queue *iopf;
	u32 max_stalls;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct arm_smmu_priq {
	struct arm_smmu_queue q;
};

struct arm_smmu_strtab_l1_desc {
	u8 span;
	__le64 *l2ptr;
	dma_addr_t l2ptr_dma;
};

struct arm_smmu_ctx_desc {
	u16 asid;
	u64 ttbr;
	u64 tcr;
	u64 mair;
	refcount_t refs;
	struct mm_struct___209 *mm;
};

struct arm_smmu_l1_ctx_desc {
	__le64 *l2ptr;
	dma_addr_t l2ptr_dma;
};

struct arm_smmu_ctx_desc_cfg {
	__le64 *cdtab;
	dma_addr_t cdtab_dma;
	struct arm_smmu_l1_ctx_desc *l1_desc;
	unsigned int num_l1_ents;
};

struct arm_smmu_s1_cfg {
	struct arm_smmu_ctx_desc_cfg cdcfg;
	struct arm_smmu_ctx_desc cd;
	u8 s1fmt;
	u8 s1cdmax;
};

struct arm_smmu_s2_cfg {
	u16 vmid;
	u64 vttbr;
	u64 vtcr;
};

struct arm_smmu_strtab_cfg {
	__le64 *strtab;
	dma_addr_t strtab_dma;
	struct arm_smmu_strtab_l1_desc *l1_desc;
	unsigned int num_l1_ents;
	u64 strtab_base;
	u32 strtab_base_cfg;
};

struct arm_smmu_device___2 {
	struct device___167 *dev;
	void *base;
	void *page1;
	u32 features;
	u32 options;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct arm_smmu_cmdq cmdq;
	struct arm_smmu_evtq evtq;
	struct arm_smmu_priq priq;
	int gerr_irq;
	int combined_irq;
	long unsigned int ias;
	long unsigned int oas;
	long unsigned int pgsize_bitmap;
	unsigned int asid_bits;
	unsigned int vmid_bits;
	long unsigned int vmid_map[1024];
	unsigned int ssid_bits;
	unsigned int sid_bits;
	struct arm_smmu_strtab_cfg strtab_cfg;
	struct iommu_device___9 iommu;
	struct rb_root streams;
	struct mutex streams_mutex;
	long: 64;
	long: 64;
};

struct arm_smmu_master;

struct arm_smmu_stream {
	u32 id;
	struct arm_smmu_master *master;
	struct rb_node node;
};

struct arm_smmu_domain___2;

struct arm_smmu_master {
	struct arm_smmu_device___2 *smmu;
	struct device___167 *dev;
	struct arm_smmu_domain___2 *domain;
	struct list_head domain_head;
	struct arm_smmu_stream *streams;
	unsigned int num_streams;
	bool ats_enabled;
	bool stall_enabled;
	bool sva_enabled;
	bool iopf_enabled;
	struct list_head bonds;
	unsigned int ssid_bits;
};

struct arm_smmu_domain___2 {
	struct arm_smmu_device___2 *smmu;
	struct mutex init_mutex;
	struct io_pgtable_ops___3 *pgtbl_ops;
	bool stall_enabled;
	atomic_t nr_ats_masters;
	enum arm_smmu_domain_stage stage;
	union {
		struct arm_smmu_s1_cfg s1_cfg;
		struct arm_smmu_s2_cfg s2_cfg;
	};
	struct iommu_domain___9 domain;
	struct list_head devices;
	spinlock_t devices_lock;
	struct list_head mmu_notifiers;
};

enum arm_smmu_msi_index {
	EVTQ_MSI_INDEX = 0,
	GERROR_MSI_INDEX = 1,
	PRIQ_MSI_INDEX = 2,
	ARM_SMMU_MAX_MSIS = 3,
};

struct arm_smmu_option_prop {
	u32 opt;
	const char *prop;
};

struct fwnode_operations___168;

struct device___168;

struct fwnode_handle___168 {
	struct fwnode_handle___168 *secondary;
	const struct fwnode_operations___168 *ops;
	struct device___168 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___168;

struct fwnode_endpoint___168;

struct fwnode_operations___168 {
	struct fwnode_handle___168 * (*get)(struct fwnode_handle___168 *);
	void (*put)(struct fwnode_handle___168 *);
	bool (*device_is_available)(const struct fwnode_handle___168 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___168 *, const struct device___168 *);
	bool (*property_present)(const struct fwnode_handle___168 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___168 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___168 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___168 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*get_parent)(const struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*get_next_child_node)(const struct fwnode_handle___168 *, struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*get_named_child_node)(const struct fwnode_handle___168 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___168 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___168 *);
	struct fwnode_handle___168 * (*graph_get_next_endpoint)(const struct fwnode_handle___168 *, struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*graph_get_remote_endpoint)(const struct fwnode_handle___168 *);
	struct fwnode_handle___168 * (*graph_get_port_parent)(struct fwnode_handle___168 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___168 *, struct fwnode_endpoint___168 *);
	int (*add_links)(struct fwnode_handle___168 *);
};

struct wakeup_source___168;

struct dev_pm_info___168 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___168 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___168 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___168;

struct bus_type___168;

struct device_driver___168;

struct dev_pm_domain___168;

struct device_node___69;

struct class___168;

struct dev_iommu___10;

struct device___168 {
	struct kobject___152 kobj;
	struct device___168 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___168 *type;
	struct bus_type___168 *bus;
	struct device_driver___168 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___168 power;
	struct dev_pm_domain___168 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___69 *of_node;
	struct fwnode_handle___168 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___168 *class;
	const struct attribute_group___152 **groups;
	void (*release)(struct device___168 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___10 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___168 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___168 *local_fwnode;
};

struct fwnode_reference_args___168 {
	struct fwnode_handle___168 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct mmu_notifier___8;

struct mmu_notifier_range___12;

struct mmu_notifier_ops___8 {
	void (*release)(struct mmu_notifier___8 *, struct mm_struct___171 *);
	int (*clear_flush_young)(struct mmu_notifier___8 *, struct mm_struct___171 *, long unsigned int, long unsigned int);
	int (*clear_young)(struct mmu_notifier___8 *, struct mm_struct___171 *, long unsigned int, long unsigned int);
	int (*test_young)(struct mmu_notifier___8 *, struct mm_struct___171 *, long unsigned int);
	void (*change_pte)(struct mmu_notifier___8 *, struct mm_struct___171 *, long unsigned int, pte_t);
	int (*invalidate_range_start)(struct mmu_notifier___8 *, const struct mmu_notifier_range___12 *);
	void (*invalidate_range_end)(struct mmu_notifier___8 *, const struct mmu_notifier_range___12 *);
	void (*invalidate_range)(struct mmu_notifier___8 *, struct mm_struct___171 *, long unsigned int, long unsigned int);
	struct mmu_notifier___8 * (*alloc_notifier)(struct mm_struct___171 *);
	void (*free_notifier)(struct mmu_notifier___8 *);
};

struct mmu_notifier___8 {
	struct hlist_node hlist;
	const struct mmu_notifier_ops___8 *ops;
	struct mm_struct___171 *mm;
	struct callback_head rcu;
	unsigned int users;
};

struct mmu_notifier_range___12 {
	struct vm_area_struct___170 *vma;
	struct mm_struct___171 *mm;
	long unsigned int start;
	long unsigned int end;
	unsigned int flags;
	enum mmu_notifier_event event;
	void *owner;
};

struct dev_pm_ops___168 {
	int (*prepare)(struct device___168 *);
	void (*complete)(struct device___168 *);
	int (*suspend)(struct device___168 *);
	int (*resume)(struct device___168 *);
	int (*freeze)(struct device___168 *);
	int (*thaw)(struct device___168 *);
	int (*poweroff)(struct device___168 *);
	int (*restore)(struct device___168 *);
	int (*suspend_late)(struct device___168 *);
	int (*resume_early)(struct device___168 *);
	int (*freeze_late)(struct device___168 *);
	int (*thaw_early)(struct device___168 *);
	int (*poweroff_late)(struct device___168 *);
	int (*restore_early)(struct device___168 *);
	int (*suspend_noirq)(struct device___168 *);
	int (*resume_noirq)(struct device___168 *);
	int (*freeze_noirq)(struct device___168 *);
	int (*thaw_noirq)(struct device___168 *);
	int (*poweroff_noirq)(struct device___168 *);
	int (*restore_noirq)(struct device___168 *);
	int (*runtime_suspend)(struct device___168 *);
	int (*runtime_resume)(struct device___168 *);
	int (*runtime_idle)(struct device___168 *);
};

struct wakeup_source___168 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___168 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___168 {
	struct dev_pm_ops___168 ops;
	int (*start)(struct device___168 *);
	void (*detach)(struct device___168 *, bool);
	int (*activate)(struct device___168 *);
	void (*sync)(struct device___168 *);
	void (*dismiss)(struct device___168 *);
};

struct iommu_ops___10;

struct bus_type___168 {
	const char *name;
	const char *dev_name;
	struct device___168 *dev_root;
	const struct attribute_group___152 **bus_groups;
	const struct attribute_group___152 **dev_groups;
	const struct attribute_group___152 **drv_groups;
	int (*match)(struct device___168 *, struct device_driver___168 *);
	int (*uevent)(struct device___168 *, struct kobj_uevent_env *);
	int (*probe)(struct device___168 *);
	void (*sync_state)(struct device___168 *);
	void (*remove)(struct device___168 *);
	void (*shutdown)(struct device___168 *);
	int (*online)(struct device___168 *);
	int (*offline)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	int (*num_vf)(struct device___168 *);
	int (*dma_configure)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
	const struct iommu_ops___10 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___168 {
	const char *name;
	struct bus_type___168 *bus;
	struct module___149 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___168 *);
	void (*sync_state)(struct device___168 *);
	int (*remove)(struct device___168 *);
	void (*shutdown)(struct device___168 *);
	int (*suspend)(struct device___168 *, pm_message_t);
	int (*resume)(struct device___168 *);
	const struct attribute_group___152 **groups;
	const struct attribute_group___152 **dev_groups;
	const struct dev_pm_ops___168 *pm;
	void (*coredump)(struct device___168 *);
	struct driver_private *p;
};

struct iommu_domain___10;

struct iommu_iotlb_gather___7;

struct iommu_device___10;

struct of_phandle_args___33;

struct iommu_sva___10;

struct iommu_ops___10 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___10 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___10 *);
	int (*attach_dev)(struct iommu_domain___10 *, struct device___168 *);
	void (*detach_dev)(struct iommu_domain___10 *, struct device___168 *);
	int (*map)(struct iommu_domain___10 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___10 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___10 *, long unsigned int, size_t, struct iommu_iotlb_gather___7 *);
	size_t (*unmap_pages)(struct iommu_domain___10 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___7 *);
	void (*flush_iotlb_all)(struct iommu_domain___10 *);
	void (*iotlb_sync_map)(struct iommu_domain___10 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___10 *, struct iommu_iotlb_gather___7 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___10 *, dma_addr_t);
	struct iommu_device___10 * (*probe_device)(struct device___168 *);
	void (*release_device)(struct device___168 *);
	void (*probe_finalize)(struct device___168 *);
	struct iommu_group * (*device_group)(struct device___168 *);
	int (*enable_nesting)(struct iommu_domain___10 *);
	int (*set_pgtable_quirks)(struct iommu_domain___10 *, long unsigned int);
	void (*get_resv_regions)(struct device___168 *, struct list_head *);
	void (*put_resv_regions)(struct device___168 *, struct list_head *);
	void (*apply_resv_region)(struct device___168 *, struct iommu_domain___10 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___168 *, struct of_phandle_args___33 *);
	bool (*is_attach_deferred)(struct iommu_domain___10 *, struct device___168 *);
	bool (*dev_has_feat)(struct device___168 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___168 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___168 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___168 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___10 *, struct device___168 *);
	void (*aux_detach_dev)(struct iommu_domain___10 *, struct device___168 *);
	int (*aux_get_pasid)(struct iommu_domain___10 *, struct device___168 *);
	struct iommu_sva___10 * (*sva_bind)(struct device___168 *, struct mm_struct___171 *, void *);
	void (*sva_unbind)(struct iommu_sva___10 *);
	u32 (*sva_get_pasid)(struct iommu_sva___10 *);
	int (*page_response)(struct device___168 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___10 *, struct device___168 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___10 *, struct device___168 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___168 *, u32);
	int (*def_domain_type)(struct device___168 *);
	long unsigned int pgsize_bitmap;
	struct module___149 *owner;
};

struct device_type___168 {
	const char *name;
	const struct attribute_group___152 **groups;
	int (*uevent)(struct device___168 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___168 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___168 *);
	const struct dev_pm_ops___168 *pm;
};

struct class___168 {
	const char *name;
	struct module___149 *owner;
	const struct attribute_group___152 **class_groups;
	const struct attribute_group___152 **dev_groups;
	struct kobject___152 *dev_kobj;
	int (*dev_uevent)(struct device___168 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___168 *, umode_t *);
	void (*class_release)(struct class___168 *);
	void (*dev_release)(struct device___168 *);
	int (*shutdown_pre)(struct device___168 *);
	const struct kobj_ns_type_operations___26 *ns_type;
	const void * (*namespace)(struct device___168 *);
	void (*get_ownership)(struct device___168 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___168 *pm;
	struct subsys_private *p;
};

struct device_node___69 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___168 fwnode;
	struct property *properties;
	struct property *deadprops;
	struct device_node___69 *parent;
	struct device_node___69 *child;
	struct device_node___69 *sibling;
	struct kobject___152 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___10;

struct dev_iommu___10 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___10 *fwspec;
	struct iommu_device___10 *iommu_dev;
	void *priv;
};

struct of_phandle_args___33 {
	struct device_node___69 *np;
	int args_count;
	uint32_t args[16];
};

typedef unsigned int ioasid_t;

typedef int (*iommu_fault_handler_t___10)(struct iommu_domain___10 *, struct device___168 *, long unsigned int, int, void *);

struct iommu_domain___10 {
	unsigned int type;
	const struct iommu_ops___10 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___10 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___7 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___170 *freelist;
	bool queued;
};

struct iommu_device___10 {
	struct list_head list;
	const struct iommu_ops___10 *ops;
	struct fwnode_handle___168 *fwnode;
	struct device___168 *dev;
};

struct iommu_sva___10 {
	struct device___168 *dev;
};

struct iommu_fwspec___10 {
	const struct iommu_ops___10 *ops;
	struct fwnode_handle___168 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct arm_smmu_ctx_desc___2 {
	u16 asid;
	u64 ttbr;
	u64 tcr;
	u64 mair;
	refcount_t refs;
	struct mm_struct___171 *mm;
};

struct arm_smmu_s1_cfg___2 {
	struct arm_smmu_ctx_desc_cfg cdcfg;
	struct arm_smmu_ctx_desc___2 cd;
	u8 s1fmt;
	u8 s1cdmax;
};

struct arm_smmu_device___3 {
	struct device___168 *dev;
	void *base;
	void *page1;
	u32 features;
	u32 options;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct arm_smmu_cmdq cmdq;
	struct arm_smmu_evtq evtq;
	struct arm_smmu_priq priq;
	int gerr_irq;
	int combined_irq;
	long unsigned int ias;
	long unsigned int oas;
	long unsigned int pgsize_bitmap;
	unsigned int asid_bits;
	unsigned int vmid_bits;
	long unsigned int vmid_map[1024];
	unsigned int ssid_bits;
	unsigned int sid_bits;
	struct arm_smmu_strtab_cfg strtab_cfg;
	struct iommu_device___10 iommu;
	struct rb_root streams;
	struct mutex streams_mutex;
	long: 64;
	long: 64;
};

struct arm_smmu_master___2;

struct arm_smmu_stream___2 {
	u32 id;
	struct arm_smmu_master___2 *master;
	struct rb_node node;
};

struct arm_smmu_domain___3;

struct arm_smmu_master___2 {
	struct arm_smmu_device___3 *smmu;
	struct device___168 *dev;
	struct arm_smmu_domain___3 *domain;
	struct list_head domain_head;
	struct arm_smmu_stream___2 *streams;
	unsigned int num_streams;
	bool ats_enabled;
	bool stall_enabled;
	bool sva_enabled;
	bool iopf_enabled;
	struct list_head bonds;
	unsigned int ssid_bits;
};

struct io_pgtable_ops___4;

struct arm_smmu_domain___3 {
	struct arm_smmu_device___3 *smmu;
	struct mutex init_mutex;
	struct io_pgtable_ops___4 *pgtbl_ops;
	bool stall_enabled;
	atomic_t nr_ats_masters;
	enum arm_smmu_domain_stage stage;
	union {
		struct arm_smmu_s1_cfg___2 s1_cfg;
		struct arm_smmu_s2_cfg s2_cfg;
	};
	struct iommu_domain___10 domain;
	struct list_head devices;
	spinlock_t devices_lock;
	struct list_head mmu_notifiers;
};

struct arm_smmu_mmu_notifier {
	struct mmu_notifier___8 mn;
	struct arm_smmu_ctx_desc___2 *cd;
	bool cleared;
	refcount_t refs;
	struct list_head list;
	struct arm_smmu_domain___3 *domain;
};

struct arm_smmu_bond {
	struct iommu_sva___10 sva;
	struct mm_struct___171 *mm;
	struct arm_smmu_mmu_notifier *smmu_mn;
	struct list_head list;
	refcount_t refs;
};

struct iommu_group {
	struct kobject___189 kobj;
	struct kobject___189 *devices_kobj;
	struct list_head devices;
	struct mutex mutex;
	struct blocking_notifier_head notifier;
	void *iommu_data;
	void (*iommu_data_release)(void *);
	char *name;
	int id;
	struct iommu_domain___6 *default_domain;
	struct iommu_domain___6 *domain;
	struct list_head entry;
};

enum iommu_inv_granularity {
	IOMMU_INV_GRANU_DOMAIN = 0,
	IOMMU_INV_GRANU_PASID = 1,
	IOMMU_INV_GRANU_ADDR = 2,
	IOMMU_INV_GRANU_NR = 3,
};

struct pci_bus___15;

struct pci_slot___15 {
	struct pci_bus___15 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___189 kobj;
};

struct pci_dev___15;

struct pci_ops___15;

struct pci_bus___15 {
	struct list_head node;
	struct pci_bus___15 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___15 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___15 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___155 *bridge;
	struct device___155 dev;
	struct bin_attribute___189 *legacy_io;
	struct bin_attribute___189 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___15;

struct pci_dev___15 {
	struct list_head bus_list;
	struct pci_bus___15 *bus;
	struct pci_bus___15 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___15 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___15 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___15 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___155 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___189 *res_attr[17];
	struct bin_attribute___189 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___189 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___15 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___15;

struct pci_driver___15 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___15 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___15 *);
	int (*suspend)(struct pci_dev___15 *, pm_message_t);
	int (*resume)(struct pci_dev___15 *);
	void (*shutdown)(struct pci_dev___15 *);
	int (*sriov_configure)(struct pci_dev___15 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___15 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___15 *);
	const struct pci_error_handlers___15 *err_handler;
	const struct attribute_group___189 **groups;
	const struct attribute_group___189 **dev_groups;
	struct device_driver___155 driver;
	struct pci_dynids dynids;
};

struct pci_ops___15 {
	int (*add_bus)(struct pci_bus___15 *);
	void (*remove_bus)(struct pci_bus___15 *);
	void * (*map_bus)(struct pci_bus___15 *, unsigned int, int);
	int (*read)(struct pci_bus___15 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___15 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___15 {
	pci_ers_result_t (*error_detected)(struct pci_dev___15 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___15 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___15 *);
	void (*reset_prepare)(struct pci_dev___15 *);
	void (*reset_done)(struct pci_dev___15 *);
	void (*resume)(struct pci_dev___15 *);
};

struct group_device {
	struct list_head list;
	struct device___155 *dev;
	char *name;
};

struct iommu_group_attribute {
	struct attribute attr;
	ssize_t (*show)(struct iommu_group *, char *);
	ssize_t (*store)(struct iommu_group *, const char *, size_t);
};

struct group_for_pci_data {
	struct pci_dev___15 *pdev;
	struct iommu_group *group;
};

struct __group_domain_type {
	struct device___155 *dev;
	unsigned int type;
};

struct trace_event_raw_iommu_group_event {
	struct trace_entry ent;
	int gid;
	u32 __data_loc_device;
	char __data[0];
};

struct trace_event_raw_iommu_device_event {
	struct trace_entry ent;
	u32 __data_loc_device;
	char __data[0];
};

struct trace_event_raw_map {
	struct trace_entry ent;
	u64 iova;
	u64 paddr;
	size_t size;
	char __data[0];
};

struct trace_event_raw_unmap {
	struct trace_entry ent;
	u64 iova;
	size_t size;
	size_t unmapped_size;
	char __data[0];
};

struct trace_event_raw_iommu_error {
	struct trace_entry ent;
	u32 __data_loc_device;
	u32 __data_loc_driver;
	u64 iova;
	int flags;
	char __data[0];
};

struct trace_event_data_offsets_iommu_group_event {
	u32 device;
};

struct trace_event_data_offsets_iommu_device_event {
	u32 device;
};

struct trace_event_data_offsets_map {};

struct trace_event_data_offsets_unmap {};

struct trace_event_data_offsets_iommu_error {
	u32 device;
	u32 driver;
};

typedef void (*btf_trace_add_device_to_group)(void *, int, struct device___148 *);

typedef void (*btf_trace_remove_device_from_group)(void *, int, struct device___148 *);

typedef void (*btf_trace_attach_device_to_domain)(void *, struct device___148 *);

typedef void (*btf_trace_detach_device_from_domain)(void *, struct device___148 *);

typedef void (*btf_trace_map)(void *, long unsigned int, phys_addr_t, size_t);

typedef void (*btf_trace_unmap)(void *, long unsigned int, size_t, size_t);

typedef void (*btf_trace_io_page_fault)(void *, struct device___148 *, long unsigned int, int);

struct irq_desc___45;

typedef void (*irq_flow_handler_t___45)(struct irq_desc___45 *);

struct msi_desc___15;

struct irq_common_data___15 {
	unsigned int state_use_accessors;
	unsigned int node;
	void *handler_data;
	struct msi_desc___15 *msi_desc;
	cpumask_var_t affinity;
	cpumask_var_t effective_affinity;
	unsigned int ipi_offset;
};

struct irq_chip___44;

struct irq_domain___43;

struct irq_data___44 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___44 *chip;
	struct irq_domain___43 *domain;
	struct irq_data___44 *parent_data;
	void *chip_data;
};

struct irq_desc___45 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___44 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___45 handle_irq;
	struct irqaction___29 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___190 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___186 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___169;

struct device___169;

struct fwnode_handle___169 {
	struct fwnode_handle___169 *secondary;
	const struct fwnode_operations___169 *ops;
	struct device___169 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___169;

struct fwnode_endpoint___169;

struct fwnode_operations___169 {
	struct fwnode_handle___169 * (*get)(struct fwnode_handle___169 *);
	void (*put)(struct fwnode_handle___169 *);
	bool (*device_is_available)(const struct fwnode_handle___169 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___169 *, const struct device___169 *);
	bool (*property_present)(const struct fwnode_handle___169 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___169 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___169 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___169 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*get_parent)(const struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*get_next_child_node)(const struct fwnode_handle___169 *, struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*get_named_child_node)(const struct fwnode_handle___169 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___169 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___169 *);
	struct fwnode_handle___169 * (*graph_get_next_endpoint)(const struct fwnode_handle___169 *, struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*graph_get_remote_endpoint)(const struct fwnode_handle___169 *);
	struct fwnode_handle___169 * (*graph_get_port_parent)(struct fwnode_handle___169 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___169 *, struct fwnode_endpoint___169 *);
	int (*add_links)(struct fwnode_handle___169 *);
};

struct wakeup_source___169;

struct dev_pm_info___169 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___169 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___169 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___169;

struct bus_type___169;

struct device_driver___169;

struct dev_pm_domain___169;

struct dma_map_ops___9;

struct device_node___70;

struct class___169;

struct dev_iommu___11;

struct device___169 {
	struct kobject___190 kobj;
	struct device___169 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___169 *type;
	struct bus_type___169 *bus;
	struct device_driver___169 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___169 power;
	struct dev_pm_domain___169 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___43 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___9 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem___2 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___70 *of_node;
	struct fwnode_handle___169 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___169 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___169 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___11 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___169 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___169 *local_fwnode;
};

struct fwnode_reference_args___169 {
	struct fwnode_handle___169 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___70 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___169 fwnode;
	struct property___51 *properties;
	struct property___51 *deadprops;
	struct device_node___70 *parent;
	struct device_node___70 *child;
	struct device_node___70 *sibling;
	struct kobject___190 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___34 {
	struct device_node___70 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___41 {
	struct fwnode_handle___169 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___43 {
	int (*match)(struct irq_domain___43 *, struct device_node___70 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___43 *, struct irq_fwspec___41 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___43 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___43 *, unsigned int);
	int (*xlate)(struct irq_domain___43 *, struct device_node___70 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___43 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___43 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___43 *, struct irq_data___44 *, bool);
	void (*deactivate)(struct irq_domain___43 *, struct irq_data___44 *);
	int (*translate)(struct irq_domain___43 *, struct irq_fwspec___41 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___43;

struct irq_domain___43 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___43 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___169 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___43 *gc;
	struct irq_domain___43 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___44 *revmap[0];
};

struct irq_chip_generic___43;

struct irq_domain_chip_generic___43 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___43 *gc[0];
};

struct dev_pm_ops___169 {
	int (*prepare)(struct device___169 *);
	void (*complete)(struct device___169 *);
	int (*suspend)(struct device___169 *);
	int (*resume)(struct device___169 *);
	int (*freeze)(struct device___169 *);
	int (*thaw)(struct device___169 *);
	int (*poweroff)(struct device___169 *);
	int (*restore)(struct device___169 *);
	int (*suspend_late)(struct device___169 *);
	int (*resume_early)(struct device___169 *);
	int (*freeze_late)(struct device___169 *);
	int (*thaw_early)(struct device___169 *);
	int (*poweroff_late)(struct device___169 *);
	int (*restore_early)(struct device___169 *);
	int (*suspend_noirq)(struct device___169 *);
	int (*resume_noirq)(struct device___169 *);
	int (*freeze_noirq)(struct device___169 *);
	int (*thaw_noirq)(struct device___169 *);
	int (*poweroff_noirq)(struct device___169 *);
	int (*restore_noirq)(struct device___169 *);
	int (*runtime_suspend)(struct device___169 *);
	int (*runtime_resume)(struct device___169 *);
	int (*runtime_idle)(struct device___169 *);
};

struct wakeup_source___169 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___169 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___169 {
	struct dev_pm_ops___169 ops;
	int (*start)(struct device___169 *);
	void (*detach)(struct device___169 *, bool);
	int (*activate)(struct device___169 *);
	void (*sync)(struct device___169 *);
	void (*dismiss)(struct device___169 *);
};

struct iommu_ops___11;

struct bus_type___169 {
	const char *name;
	const char *dev_name;
	struct device___169 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___169 *, struct device_driver___169 *);
	int (*uevent)(struct device___169 *, struct kobj_uevent_env *);
	int (*probe)(struct device___169 *);
	void (*sync_state)(struct device___169 *);
	void (*remove)(struct device___169 *);
	void (*shutdown)(struct device___169 *);
	int (*online)(struct device___169 *);
	int (*offline)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	int (*num_vf)(struct device___169 *);
	int (*dma_configure)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
	const struct iommu_ops___11 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___169 {
	const char *name;
	struct bus_type___169 *bus;
	struct module___186 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___169 *);
	void (*sync_state)(struct device___169 *);
	int (*remove)(struct device___169 *);
	void (*shutdown)(struct device___169 *);
	int (*suspend)(struct device___169 *, pm_message_t);
	int (*resume)(struct device___169 *);
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	const struct dev_pm_ops___169 *pm;
	void (*coredump)(struct device___169 *);
	struct driver_private *p;
};

struct iommu_domain___11;

struct iommu_device___11;

struct iommu_sva___11;

struct iommu_ops___11 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___11 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___11 *);
	int (*attach_dev)(struct iommu_domain___11 *, struct device___169 *);
	void (*detach_dev)(struct iommu_domain___11 *, struct device___169 *);
	int (*map)(struct iommu_domain___11 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___11 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___11 *, long unsigned int, size_t, struct iommu_iotlb_gather___5 *);
	size_t (*unmap_pages)(struct iommu_domain___11 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___5 *);
	void (*flush_iotlb_all)(struct iommu_domain___11 *);
	void (*iotlb_sync_map)(struct iommu_domain___11 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___11 *, struct iommu_iotlb_gather___5 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___11 *, dma_addr_t);
	struct iommu_device___11 * (*probe_device)(struct device___169 *);
	void (*release_device)(struct device___169 *);
	void (*probe_finalize)(struct device___169 *);
	struct iommu_group * (*device_group)(struct device___169 *);
	int (*enable_nesting)(struct iommu_domain___11 *);
	int (*set_pgtable_quirks)(struct iommu_domain___11 *, long unsigned int);
	void (*get_resv_regions)(struct device___169 *, struct list_head *);
	void (*put_resv_regions)(struct device___169 *, struct list_head *);
	void (*apply_resv_region)(struct device___169 *, struct iommu_domain___11 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___169 *, struct of_phandle_args___34 *);
	bool (*is_attach_deferred)(struct iommu_domain___11 *, struct device___169 *);
	bool (*dev_has_feat)(struct device___169 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___169 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___169 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___169 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___11 *, struct device___169 *);
	void (*aux_detach_dev)(struct iommu_domain___11 *, struct device___169 *);
	int (*aux_get_pasid)(struct iommu_domain___11 *, struct device___169 *);
	struct iommu_sva___11 * (*sva_bind)(struct device___169 *, struct mm_struct___208 *, void *);
	void (*sva_unbind)(struct iommu_sva___11 *);
	u32 (*sva_get_pasid)(struct iommu_sva___11 *);
	int (*page_response)(struct device___169 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___11 *, struct device___169 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___11 *, struct device___169 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___169 *, u32);
	int (*def_domain_type)(struct device___169 *);
	long unsigned int pgsize_bitmap;
	struct module___186 *owner;
};

struct device_type___169 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___169 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___169 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___169 *);
	const struct dev_pm_ops___169 *pm;
};

struct class___169 {
	const char *name;
	struct module___186 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___169 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___169 *, umode_t *);
	void (*class_release)(struct class___169 *);
	void (*dev_release)(struct device___169 *);
	int (*shutdown_pre)(struct device___169 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___169 *);
	void (*get_ownership)(struct device___169 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___169 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___9 {
	void * (*alloc)(struct device___169 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___169 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___207 * (*alloc_pages)(struct device___169 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___169 *, size_t, struct page___207 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___169 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___169 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___169 *, struct vm_area_struct___207 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___169 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___169 *, struct page___207 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___169 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___169 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___169 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___169 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___169 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___169 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___169 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___169 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___169 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___169 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___169 *, u64);
	u64 (*get_required_mask)(struct device___169 *);
	size_t (*max_mapping_size)(struct device___169 *);
	long unsigned int (*get_merge_boundary)(struct device___169 *);
};

struct iommu_fwspec___11;

struct dev_iommu___11 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___11 *fwspec;
	struct iommu_device___11 *iommu_dev;
	void *priv;
};

struct pci_dev___16;

struct pci_ops___16;

struct pci_bus___16 {
	struct list_head node;
	struct pci_bus___16 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___16 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___16 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___169 *bridge;
	struct device___169 dev;
	struct bin_attribute___190 *legacy_io;
	struct bin_attribute___190 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct msi_desc___15 {
	struct list_head list;
	unsigned int irq;
	unsigned int nvec_used;
	struct device___169 *dev;
	struct msi_msg msg;
	struct irq_affinity_desc *affinity;
	const void *iommu_cookie;
	void (*write_msi_msg)(struct msi_desc___15 *, void *);
	void *write_msi_msg_data;
	union {
		struct {
			union {
				u32 msi_mask;
				u32 msix_ctrl;
			};
			struct {
				u8 is_msix: 1;
				u8 multiple: 3;
				u8 multi_cap: 3;
				u8 can_mask: 1;
				u8 is_64: 1;
				u8 is_virtual: 1;
				u16 entry_nr;
				unsigned int default_irq;
			} msi_attrib;
			union {
				u8 mask_pos;
				void *mask_base;
			};
		};
		struct platform_msi_desc platform;
		struct fsl_mc_msi_desc fsl_mc;
		struct ti_sci_inta_msi_desc inta;
	};
};

struct irq_chip___44 {
	struct device___169 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___44 *);
	void (*irq_shutdown)(struct irq_data___44 *);
	void (*irq_enable)(struct irq_data___44 *);
	void (*irq_disable)(struct irq_data___44 *);
	void (*irq_ack)(struct irq_data___44 *);
	void (*irq_mask)(struct irq_data___44 *);
	void (*irq_mask_ack)(struct irq_data___44 *);
	void (*irq_unmask)(struct irq_data___44 *);
	void (*irq_eoi)(struct irq_data___44 *);
	int (*irq_set_affinity)(struct irq_data___44 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___44 *);
	int (*irq_set_type)(struct irq_data___44 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___44 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___44 *);
	void (*irq_bus_sync_unlock)(struct irq_data___44 *);
	void (*irq_cpu_online)(struct irq_data___44 *);
	void (*irq_cpu_offline)(struct irq_data___44 *);
	void (*irq_suspend)(struct irq_data___44 *);
	void (*irq_resume)(struct irq_data___44 *);
	void (*irq_pm_shutdown)(struct irq_data___44 *);
	void (*irq_calc_mask)(struct irq_data___44 *);
	void (*irq_print_chip)(struct irq_data___44 *, struct seq_file___178 *);
	int (*irq_request_resources)(struct irq_data___44 *);
	void (*irq_release_resources)(struct irq_data___44 *);
	void (*irq_compose_msi_msg)(struct irq_data___44 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___44 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___44 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___44 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___44 *, void *);
	void (*ipi_send_single)(struct irq_data___44 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___44 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___44 *);
	void (*irq_nmi_teardown)(struct irq_data___44 *);
	long unsigned int flags;
};

struct irq_chip_type___43 {
	struct irq_chip___44 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___45 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___43 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___43 *);
	void (*resume)(struct irq_chip_generic___43 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___43 *domain;
	struct list_head list;
	struct irq_chip_type___43 chip_types[0];
};

struct dma_sgt_handle___2 {
	struct sg_table sgt;
	struct page___207 **pages;
};

typedef int (*iommu_fault_handler_t___11)(struct iommu_domain___11 *, struct device___169 *, long unsigned int, int, void *);

struct iommu_domain___11 {
	unsigned int type;
	const struct iommu_ops___11 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___11 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

enum iommu_dma_cookie_type {
	IOMMU_DMA_IOVA_COOKIE = 0,
	IOMMU_DMA_MSI_COOKIE = 1,
};

struct iova {
	struct rb_node node;
	long unsigned int pfn_hi;
	long unsigned int pfn_lo;
};

struct iova_magazine;

struct iova_cpu_rcache;

struct iova_rcache {
	spinlock_t lock;
	long unsigned int depot_size;
	struct iova_magazine *depot[32];
	struct iova_cpu_rcache *cpu_rcaches;
};

struct iova_domain;

typedef void (*iova_flush_cb)(struct iova_domain *);

typedef void (*iova_entry_dtor)(long unsigned int);

struct iova_fq;

struct iova_domain {
	spinlock_t iova_rbtree_lock;
	struct rb_root rbroot;
	struct rb_node *cached_node;
	struct rb_node *cached32_node;
	long unsigned int granule;
	long unsigned int start_pfn;
	long unsigned int dma_32bit_pfn;
	long unsigned int max32_alloc_size;
	struct iova_fq *fq;
	atomic64_t fq_flush_start_cnt;
	atomic64_t fq_flush_finish_cnt;
	struct iova anchor;
	struct iova_rcache rcaches[6];
	iova_flush_cb flush_cb;
	iova_entry_dtor entry_dtor;
	struct timer_list fq_timer;
	atomic_t fq_timer_on;
	struct hlist_node cpuhp_dead;
};

struct iommu_dma_cookie {
	enum iommu_dma_cookie_type type;
	union {
		struct iova_domain iovad;
		dma_addr_t msi_iova;
	};
	struct list_head msi_page_list;
	struct iommu_domain___11 *fq_domain;
};

struct iommu_device___11 {
	struct list_head list;
	const struct iommu_ops___11 *ops;
	struct fwnode_handle___169 *fwnode;
	struct device___169 *dev;
};

struct iommu_sva___11 {
	struct device___169 *dev;
};

struct iommu_fwspec___11 {
	const struct iommu_ops___11 *ops;
	struct fwnode_handle___169 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct iova_fq_entry {
	long unsigned int iova_pfn;
	long unsigned int pages;
	long unsigned int data;
	u64 counter;
};

struct iova_fq {
	struct iova_fq_entry entries[256];
	unsigned int head;
	unsigned int tail;
	spinlock_t lock;
};

struct pci_slot___16 {
	struct pci_bus___16 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___190 kobj;
};

struct pci_driver___16;

struct pci_dev___16 {
	struct list_head bus_list;
	struct pci_bus___16 *bus;
	struct pci_bus___16 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___16 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___16 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___16 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___169 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___190 *res_attr[17];
	struct bin_attribute___190 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___190 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___16 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___16;

struct pci_driver___16 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___16 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___16 *);
	int (*suspend)(struct pci_dev___16 *, pm_message_t);
	int (*resume)(struct pci_dev___16 *);
	void (*shutdown)(struct pci_dev___16 *);
	int (*sriov_configure)(struct pci_dev___16 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___16 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___16 *);
	const struct pci_error_handlers___16 *err_handler;
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	struct device_driver___169 driver;
	struct pci_dynids dynids;
};

struct pci_host_bridge___9 {
	struct device___169 dev;
	struct pci_bus___16 *bus;
	struct pci_ops___16 *ops;
	struct pci_ops___16 *child_ops;
	void *sysdata;
	int busnr;
	int domain_nr;
	struct list_head windows;
	struct list_head dma_ranges;
	u8 (*swizzle_irq)(struct pci_dev___16 *, u8 *);
	int (*map_irq)(const struct pci_dev___16 *, u8, u8);
	void (*release_fn)(struct pci_host_bridge___9 *);
	void *release_data;
	unsigned int ignore_reset_delay: 1;
	unsigned int no_ext_tags: 1;
	unsigned int native_aer: 1;
	unsigned int native_pcie_hotplug: 1;
	unsigned int native_shpc_hotplug: 1;
	unsigned int native_pme: 1;
	unsigned int native_ltr: 1;
	unsigned int native_dpc: 1;
	unsigned int preserve_config: 1;
	unsigned int size_windows: 1;
	unsigned int msi_domain: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	resource_size_t (*align_resource)(struct pci_dev___16 *, const struct resource *, resource_size_t, resource_size_t, resource_size_t);
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct pci_ops___16 {
	int (*add_bus)(struct pci_bus___16 *);
	void (*remove_bus)(struct pci_bus___16 *);
	void * (*map_bus)(struct pci_bus___16 *, unsigned int, int);
	int (*read)(struct pci_bus___16 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___16 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___16 {
	pci_ers_result_t (*error_detected)(struct pci_dev___16 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___16 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___16 *);
	void (*reset_prepare)(struct pci_dev___16 *);
	void (*reset_done)(struct pci_dev___16 *);
	void (*resume)(struct pci_dev___16 *);
};

struct iommu_dma_msi_page {
	struct list_head list;
	dma_addr_t iova;
	phys_addr_t phys;
};

struct io_pgtable_init_fns {
	struct io_pgtable___2 * (*alloc)(struct io_pgtable_cfg___2 *, void *);
	void (*free)(struct io_pgtable___2 *);
};

struct arm_lpae_io_pgtable {
	struct io_pgtable___2 iop;
	int pgd_bits;
	int start_level;
	int bits_per_level;
	void *pgd;
};

typedef u64 arm_lpae_iopte;

typedef ioasid_t (*ioasid_alloc_fn_t)(ioasid_t, ioasid_t, void *);

typedef void (*ioasid_free_fn_t)(ioasid_t, void *);

struct ioasid_set {
	int dummy;
};

struct ioasid_allocator_ops {
	ioasid_alloc_fn_t alloc;
	ioasid_free_fn_t free;
	struct list_head list;
	void *pdata;
};

struct xarray___3 {
	spinlock_t xa_lock;
	gfp_t xa_flags;
	void *xa_head;
};

struct ioasid_data {
	ioasid_t id;
	struct ioasid_set *set;
	void *private;
	struct callback_head rcu;
	refcount_t refs;
};

struct ioasid_allocator_data {
	struct ioasid_allocator_ops *ops;
	struct list_head list;
	struct list_head slist;
	long unsigned int flags;
	struct xarray___3 xa;
	long: 64;
	long: 64;
	struct callback_head rcu;
};

struct iova_magazine {
	long unsigned int size;
	long unsigned int pfns[128];
};

struct iova_cpu_rcache {
	spinlock_t lock;
	struct iova_magazine *loaded;
	struct iova_magazine *prev;
};

struct of_pci_iommu_alias_info {
	struct device___155 *dev;
	struct device_node___58 *np;
};

struct rk_iommu_domain {
	struct list_head iommus;
	u32 *dt;
	dma_addr_t dt_dma;
	spinlock_t iommus_lock;
	spinlock_t dt_lock;
	struct iommu_domain___6 domain;
};

struct rk_iommu_ops {
	phys_addr_t (*pt_address)(u32);
	u32 (*mk_dtentries)(dma_addr_t);
	u32 (*mk_ptentries)(phys_addr_t, int);
	phys_addr_t (*dte_addr_phys)(u32);
	u32 (*dma_addr_dte)(dma_addr_t);
	u64 dma_bit_mask;
};

struct rk_iommu {
	struct device___155 *dev;
	void **bases;
	int num_mmu;
	int num_irq;
	struct clk_bulk_data *clocks;
	int num_clocks;
	bool reset_disabled;
	struct iommu_device___6 iommu;
	struct list_head node;
	struct iommu_domain___6 *domain;
	struct iommu_group *group;
};

struct rk_iommudata {
	struct device_link___2 *link;
	struct rk_iommu *iommu;
};

struct sun50i_iommu {
	struct iommu_device___6 iommu;
	spinlock_t iommu_lock;
	struct device___155 *dev;
	void *base;
	struct reset_control *reset;
	struct clk *clk;
	struct iommu_domain___6 *domain;
	struct iommu_group *group;
	struct kmem_cache *pt_pool;
};

struct sun50i_iommu_domain {
	struct iommu_domain___6 domain;
	refcount_t refcnt;
	u32 *dt;
	dma_addr_t dt_dma;
	struct sun50i_iommu *iommu;
};

enum sun50i_iommu_aci {
	SUN50I_IOMMU_ACI_DO_NOT_USE = 0,
	SUN50I_IOMMU_ACI_NONE = 1,
	SUN50I_IOMMU_ACI_RD = 2,
	SUN50I_IOMMU_ACI_WR = 3,
	SUN50I_IOMMU_ACI_RD_WR = 4,
};

struct icc_node___2;

struct icc_node_data___2 {
	struct icc_node___2 *node;
	u32 tag;
};

struct icc_provider___2;

struct icc_node___2 {
	int id;
	const char *name;
	struct icc_node___2 **links;
	size_t num_links;
	struct icc_provider___2 *provider;
	struct list_head node_list;
	struct list_head search_list;
	struct icc_node___2 *reverse;
	u8 is_traversed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head req_list;
	u32 avg_bw;
	u32 peak_bw;
	u32 init_avg;
	u32 init_peak;
	void *data;
};

struct icc_provider___2 {
	struct list_head provider_list;
	struct list_head nodes;
	int (*set)(struct icc_node___2 *, struct icc_node___2 *);
	int (*aggregate)(struct icc_node___2 *, u32, u32, u32, u32 *, u32 *);
	void (*pre_aggregate)(struct icc_node___2 *);
	int (*get_bw)(struct icc_node___2 *, u32 *, u32 *);
	struct icc_node___2 * (*xlate)(struct of_phandle_args___19 *, void *);
	struct icc_node_data___2 * (*xlate_extended)(struct of_phandle_args___19 *, void *);
	struct device___155 *dev;
	int users;
	bool inter_set;
	void *data;
};

struct reset_controller_dev___9;

struct reset_control_ops___9 {
	int (*reset)(struct reset_controller_dev___9 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___9 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___9 *, long unsigned int);
	int (*status)(struct reset_controller_dev___9 *, long unsigned int);
};

struct reset_controller_dev___9 {
	const struct reset_control_ops___9 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___155 *dev;
	struct device_node___58 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___9 *, const struct of_phandle_args___19 *);
	unsigned int nr_resets;
};

struct tegra_mc___2;

struct tegra_mc_reset_ops___2 {
	int (*hotreset_assert)(struct tegra_mc___2 *, const struct tegra_mc_reset *);
	int (*hotreset_deassert)(struct tegra_mc___2 *, const struct tegra_mc_reset *);
	int (*block_dma)(struct tegra_mc___2 *, const struct tegra_mc_reset *);
	bool (*dma_idling)(struct tegra_mc___2 *, const struct tegra_mc_reset *);
	int (*unblock_dma)(struct tegra_mc___2 *, const struct tegra_mc_reset *);
	int (*reset_status)(struct tegra_mc___2 *, const struct tegra_mc_reset *);
};

struct tegra_smmu___2;

struct tegra_mc_soc___2;

struct tegra_mc___2 {
	struct device___155 *dev;
	struct tegra_smmu___2 *smmu;
	struct gart_device *gart;
	void *regs;
	struct clk *clk;
	int irq;
	const struct tegra_mc_soc___2 *soc;
	long unsigned int tick;
	struct tegra_mc_timing *timings;
	unsigned int num_timings;
	struct reset_controller_dev___9 reset;
	struct icc_provider___2 provider;
	spinlock_t lock;
	struct {
		struct dentry___201 *root;
	} debugfs;
};

struct tegra_mc_icc_ops___2 {
	int (*set)(struct icc_node___2 *, struct icc_node___2 *);
	int (*aggregate)(struct icc_node___2 *, u32, u32, u32, u32 *, u32 *);
	struct icc_node_data___2 * (*xlate_extended)(struct of_phandle_args___19 *, void *);
};

struct tegra_mc_ops___2 {
	int (*probe)(struct tegra_mc___2 *);
	void (*remove)(struct tegra_mc___2 *);
	int (*suspend)(struct tegra_mc___2 *);
	int (*resume)(struct tegra_mc___2 *);
	irqreturn_t (*handle_irq)(int, void *);
	int (*probe_device)(struct tegra_mc___2 *, struct device___155 *);
};

struct tegra_mc_soc___2 {
	const struct tegra_mc_client *clients;
	unsigned int num_clients;
	const long unsigned int *emem_regs;
	unsigned int num_emem_regs;
	unsigned int num_address_bits;
	unsigned int atom_size;
	u8 client_id_mask;
	const struct tegra_smmu_soc *smmu;
	u32 intmask;
	const struct tegra_mc_reset_ops___2 *reset_ops;
	const struct tegra_mc_reset *resets;
	unsigned int num_resets;
	const struct tegra_mc_icc_ops___2 *icc_ops;
	const struct tegra_mc_ops___2 *ops;
};

struct tegra_smmu___2 {
	void *regs;
	struct device___155 *dev;
	struct tegra_mc___2 *mc;
	const struct tegra_smmu_soc *soc;
	struct list_head groups;
	long unsigned int pfn_mask;
	long unsigned int tlb_mask;
	long unsigned int *asids;
	struct mutex lock;
	struct list_head list;
	struct dentry___201 *debugfs;
	struct iommu_device___6 iommu;
};

struct tegra_smmu_group {
	struct list_head list;
	struct tegra_smmu___2 *smmu;
	const struct tegra_smmu_group_soc *soc;
	struct iommu_group *group;
	unsigned int swgroup;
};

struct tegra_smmu_as {
	struct iommu_domain___6 domain;
	struct tegra_smmu___2 *smmu;
	unsigned int use_count;
	spinlock_t lock;
	u32 *count;
	struct page___206 **pts;
	struct page___206 *pd;
	dma_addr_t pd_dma;
	unsigned int id;
	u32 attr;
};

struct dentry___204;

struct super_block___204;

struct module___188;

struct file_system_type___204 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___204 * (*mount)(struct file_system_type___204 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___204 *);
	struct module___188 *owner;
	struct file_system_type___204 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___204;

struct kiocb___204;

struct iov_iter___125;

struct vm_area_struct___209;

struct inode___204;

struct file_lock___204;

struct page___209;

struct seq_file___180;

struct file_operations___205 {
	struct module___188 *owner;
	loff_t (*llseek)(struct file___204 *, loff_t, int);
	ssize_t (*read)(struct file___204 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___204 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___204 *, struct iov_iter___125 *);
	ssize_t (*write_iter)(struct kiocb___204 *, struct iov_iter___125 *);
	int (*iopoll)(struct kiocb___204 *, bool);
	int (*iterate)(struct file___204 *, struct dir_context *);
	int (*iterate_shared)(struct file___204 *, struct dir_context *);
	__poll_t (*poll)(struct file___204 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___204 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___204 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___204 *, struct vm_area_struct___209 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___204 *, struct file___204 *);
	int (*flush)(struct file___204 *, fl_owner_t);
	int (*release)(struct inode___204 *, struct file___204 *);
	int (*fsync)(struct file___204 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___204 *, int);
	int (*lock)(struct file___204 *, int, struct file_lock___204 *);
	ssize_t (*sendpage)(struct file___204 *, struct page___209 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___204 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___204 *, long unsigned int);
	int (*flock)(struct file___204 *, int, struct file_lock___204 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___204 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___204 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___204 *, long int, struct file_lock___204 **, void **);
	long int (*fallocate)(struct file___204 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___180 *, struct file___204 *);
	ssize_t (*copy_file_range)(struct file___204 *, loff_t, struct file___204 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___204 *, loff_t, struct file___204 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___204 *, loff_t, loff_t, int);
};

struct vmacache___209 {
	u64 seqnum;
	struct vm_area_struct___209 *vmas[4];
};

struct page_frag___209 {
	struct page___209 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___210;

struct pid___181;

struct nsproxy___190;

struct signal_struct___205;

struct bio_list___105;

struct backing_dev_info___98;

struct io_context___105;

struct css_set___140;

struct mem_cgroup___89;

struct request_queue___105;

struct vm_struct___187;

struct task_struct___211 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___211 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___210 *mm;
	struct mm_struct___210 *active_mm;
	struct vmacache___209 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___211 *real_parent;
	struct task_struct___211 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___211 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___181 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___190 *nsproxy;
	struct signal_struct___205 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___211 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___105 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___98 *backing_dev_info;
	struct io_context___105 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___140 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___209 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___89 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___89 *active_memcg;
	struct request_queue___105 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___211 *oom_reaper_list;
	struct vm_struct___187 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___192;

struct kobj_type___192;

struct kernfs_node___192;

struct kobject___192 {
	const char *name;
	struct list_head entry;
	struct kobject___192 *parent;
	struct kset___192 *kset;
	struct kobj_type___192 *ktype;
	struct kernfs_node___192 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___188 {
	struct kobject___192 kobj;
	struct module___188 *mod;
	struct kobject___192 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___188 {
	struct module___188 *mod;
	struct latch_tree_node node;
};

struct module_layout___188 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___188 mtn;
};

struct module_attribute___188;

struct kernel_param___188;

struct module___188 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___188 mkobj;
	struct module_attribute___188 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___192 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___188 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___188 core_layout;
	struct module_layout___188 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___181;

struct upid___181 {
	int nr;
	struct pid_namespace___181 *ns;
};

struct pid_namespace___181 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___211 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___181 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___181 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___181 numbers[1];
};

typedef struct page___209 *pgtable_t___209;

struct address_space___204;

struct dev_pagemap___199;

struct page___209 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___204 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___54 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___209 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___209 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___210 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___199 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___199;

struct vm_area_struct___209 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___209 *vm_next;
	struct vm_area_struct___209 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___210 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___199 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___204 *vm_file;
	struct file___204 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___205 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___211 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___211 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___181 *pids[4];
	struct pid___181 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___210 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___209;

struct mm_struct___210 {
	struct {
		struct vm_area_struct___209 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___204 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___209 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___211 *owner;
		struct user_namespace___25 *user_ns;
		struct file___204 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___140;

struct nsproxy___190 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___181 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___140 *cgroup_ns;
};

struct bio___105;

struct bio_list___105 {
	struct bio___105 *head;
	struct bio___105 *tail;
};

struct cgroup_subsys_state___140;

struct bdi_writeback___98 {
	struct backing_dev_info___98 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___140 *memcg_css;
	struct cgroup_subsys_state___140 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___170;

struct backing_dev_info___98 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___98 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___170 *dev;
	char dev_name[64];
	struct device___170 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___204 *debug_dir;
};

struct io_cq___105;

struct io_context___105 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___105 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___140;

struct css_set___140 {
	struct cgroup_subsys_state___140 *subsys[14];
	refcount_t refcount;
	struct css_set___140 *dom_cset;
	struct cgroup___140 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___140 *mg_src_cgrp;
	struct cgroup___140 *mg_dst_cgrp;
	struct css_set___140 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___140;

struct cgroup_subsys_state___140 {
	struct cgroup___140 *cgroup;
	struct cgroup_subsys___140 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___140 *parent;
};

struct cgroup_file___140 {
	struct kernfs_node___192 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___89;

struct mem_cgroup_per_node___89;

struct mem_cgroup___89 {
	struct cgroup_subsys_state___140 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___140 events_file;
	struct cgroup_file___140 events_local_file;
	struct cgroup_file___140 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___89 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___211 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___89 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___105;

struct blk_integrity___105 {
	const struct blk_integrity_profile___105 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___105 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___105 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___105;

struct elevator_queue___105;

struct blk_mq_ops___102;

struct blk_mq_hw_ctx___102;

struct gendisk___106;

struct blkcg_gq___100;

struct blk_mq_tag_set___102;

struct request_queue___105 {
	struct request___105 *last_merge;
	struct elevator_queue___105 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___102 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___102 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___106 *disk;
	struct kobject___192 kobj;
	struct kobject___192 *mq_kobj;
	struct blk_integrity___105 integrity;
	struct device___170 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___100 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___102 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___105 bio_split;
	struct dentry___204 *debugfs_dir;
	struct dentry___204 *sched_debugfs_dir;
	struct dentry___204 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___187 {
	struct vm_struct___187 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___209 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___204;

struct address_space___204 {
	struct inode___204 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___204 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___199;

struct dev_pagemap___199 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___199 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___204;

struct path___204 {
	struct vfsmount___204 *mnt;
	struct dentry___204 *dentry;
};

struct fown_struct___181 {
	rwlock_t lock;
	struct pid___181 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___204 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___204 f_path;
	struct inode___204 *f_inode;
	const struct file_operations___205 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___181 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___204 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___199;

struct vm_operations_struct___199 {
	void (*open)(struct vm_area_struct___209 *);
	void (*close)(struct vm_area_struct___209 *);
	int (*may_split)(struct vm_area_struct___209 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___209 *);
	int (*mprotect)(struct vm_area_struct___209 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___199 *);
	vm_fault_t (*huge_fault)(struct vm_fault___199 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___199 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___209 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___199 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___199 *);
	int (*access)(struct vm_area_struct___209 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___209 *);
	int (*set_policy)(struct vm_area_struct___209 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___209 *, long unsigned int);
	struct page___209 * (*find_special_page)(struct vm_area_struct___209 *, long unsigned int);
};

struct core_thread___209 {
	struct task_struct___211 *task;
	struct core_thread___209 *next;
};

struct core_state___209 {
	atomic_t nr_threads;
	struct core_thread___209 dumper;
	struct completion startup;
};

struct vm_fault___199 {
	const struct {
		struct vm_area_struct___209 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___209 *cow_page;
	struct page___209 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___209 prealloc_pte;
};

struct pglist_data___96;

struct lruvec___96 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___96 *pgdat;
};

struct zone___96 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___96 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___96 {
	struct zone___96 *zone;
	int zone_idx;
};

struct zonelist___96 {
	struct zoneref___96 _zonerefs[321];
};

struct pglist_data___96 {
	struct zone___96 node_zones[5];
	struct zonelist___96 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___211 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___211 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___96 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___192;

struct kernfs_elem_dir___192 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___192 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___192;

struct kernfs_root___192 {
	struct kernfs_node___192 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___192 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___192 {
	struct kernfs_node___192 *target_kn;
};

struct kernfs_ops___192;

struct kernfs_elem_attr___192 {
	const struct kernfs_ops___192 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___192 *notify_next;
};

struct kernfs_node___192 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___192 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___192 dir;
		struct kernfs_elem_symlink___192 symlink;
		struct kernfs_elem_attr___192 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___192;

struct kernfs_ops___192 {
	int (*open)(struct kernfs_open_file___192 *);
	void (*release)(struct kernfs_open_file___192 *);
	int (*seq_show)(struct seq_file___180 *, void *);
	void * (*seq_start)(struct seq_file___180 *, loff_t *);
	void * (*seq_next)(struct seq_file___180 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___180 *, void *);
	ssize_t (*read)(struct kernfs_open_file___192 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___192 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___192 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___192 *, struct vm_area_struct___209 *);
};

struct kernfs_syscall_ops___192 {
	int (*show_options)(struct seq_file___180 *, struct kernfs_root___192 *);
	int (*mkdir)(struct kernfs_node___192 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___192 *);
	int (*rename)(struct kernfs_node___192 *, struct kernfs_node___192 *, const char *);
	int (*show_path)(struct seq_file___180 *, struct kernfs_node___192 *, struct kernfs_root___192 *);
};

struct seq_operations___180;

struct seq_file___180 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___180 *op;
	int poll_event;
	const struct file___204 *file;
	void *private;
};

struct kernfs_open_file___192 {
	struct kernfs_node___192 *kn;
	struct file___204 *file;
	struct seq_file___180 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___199 *vm_ops;
};

struct bin_attribute___192;

struct attribute_group___192 {
	const char *name;
	umode_t (*is_visible)(struct kobject___192 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___192 *, struct bin_attribute___192 *, int);
	struct attribute **attrs;
	struct bin_attribute___192 **bin_attrs;
};

struct bin_attribute___192 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___204 * (*f_mapping)();
	ssize_t (*read)(struct file___204 *, struct kobject___192 *, struct bin_attribute___192 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___204 *, struct kobject___192 *, struct bin_attribute___192 *, char *, loff_t, size_t);
	int (*mmap)(struct file___204 *, struct kobject___192 *, struct bin_attribute___192 *, struct vm_area_struct___209 *);
};

struct sysfs_ops___192 {
	ssize_t (*show)(struct kobject___192 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___192 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___192;

struct kset___192 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___192 kobj;
	const struct kset_uevent_ops___192 *uevent_ops;
};

struct kobj_type___192 {
	void (*release)(struct kobject___192 *);
	const struct sysfs_ops___192 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___192 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___192 *);
	const void * (*namespace)(struct kobject___192 *);
	void (*get_ownership)(struct kobject___192 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___192 {
	int (* const filter)(struct kset___192 *, struct kobject___192 *);
	const char * (* const name)(struct kset___192 *, struct kobject___192 *);
	int (* const uevent)(struct kset___192 *, struct kobject___192 *, struct kobj_uevent_env *);
};

struct wakeup_source___170;

struct dev_pm_info___170 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___170 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___170 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___170;

struct bus_type___170;

struct device_driver___170;

struct dev_pm_domain___170;

struct dma_map_ops___10;

struct device_node___71;

struct fwnode_handle___170;

struct class___170;

struct dev_iommu___12;

struct device___170 {
	struct kobject___192 kobj;
	struct device___170 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___170 *type;
	struct bus_type___170 *bus;
	struct device_driver___170 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___170 power;
	struct dev_pm_domain___170 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___10 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___71 *of_node;
	struct fwnode_handle___170 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___170 *class;
	const struct attribute_group___192 **groups;
	void (*release)(struct device___170 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___12 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___170 {
	int (*prepare)(struct device___170 *);
	void (*complete)(struct device___170 *);
	int (*suspend)(struct device___170 *);
	int (*resume)(struct device___170 *);
	int (*freeze)(struct device___170 *);
	int (*thaw)(struct device___170 *);
	int (*poweroff)(struct device___170 *);
	int (*restore)(struct device___170 *);
	int (*suspend_late)(struct device___170 *);
	int (*resume_early)(struct device___170 *);
	int (*freeze_late)(struct device___170 *);
	int (*thaw_early)(struct device___170 *);
	int (*poweroff_late)(struct device___170 *);
	int (*restore_early)(struct device___170 *);
	int (*suspend_noirq)(struct device___170 *);
	int (*resume_noirq)(struct device___170 *);
	int (*freeze_noirq)(struct device___170 *);
	int (*thaw_noirq)(struct device___170 *);
	int (*poweroff_noirq)(struct device___170 *);
	int (*restore_noirq)(struct device___170 *);
	int (*runtime_suspend)(struct device___170 *);
	int (*runtime_resume)(struct device___170 *);
	int (*runtime_idle)(struct device___170 *);
};

struct wakeup_source___170 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___170 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___170 {
	struct dev_pm_ops___170 ops;
	int (*start)(struct device___170 *);
	void (*detach)(struct device___170 *, bool);
	int (*activate)(struct device___170 *);
	void (*sync)(struct device___170 *);
	void (*dismiss)(struct device___170 *);
};

struct iommu_ops___12;

struct bus_type___170 {
	const char *name;
	const char *dev_name;
	struct device___170 *dev_root;
	const struct attribute_group___192 **bus_groups;
	const struct attribute_group___192 **dev_groups;
	const struct attribute_group___192 **drv_groups;
	int (*match)(struct device___170 *, struct device_driver___170 *);
	int (*uevent)(struct device___170 *, struct kobj_uevent_env *);
	int (*probe)(struct device___170 *);
	void (*sync_state)(struct device___170 *);
	void (*remove)(struct device___170 *);
	void (*shutdown)(struct device___170 *);
	int (*online)(struct device___170 *);
	int (*offline)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	int (*num_vf)(struct device___170 *);
	int (*dma_configure)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
	const struct iommu_ops___12 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___170 {
	const char *name;
	struct bus_type___170 *bus;
	struct module___188 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___170 *);
	void (*sync_state)(struct device___170 *);
	int (*remove)(struct device___170 *);
	void (*shutdown)(struct device___170 *);
	int (*suspend)(struct device___170 *, pm_message_t);
	int (*resume)(struct device___170 *);
	const struct attribute_group___192 **groups;
	const struct attribute_group___192 **dev_groups;
	const struct dev_pm_ops___170 *pm;
	void (*coredump)(struct device___170 *);
	struct driver_private *p;
};

struct iommu_domain___12;

struct iommu_iotlb_gather___8;

struct iommu_device___12;

struct of_phandle_args___35;

struct iommu_sva___12;

struct iommu_ops___12 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___12 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___12 *);
	int (*attach_dev)(struct iommu_domain___12 *, struct device___170 *);
	void (*detach_dev)(struct iommu_domain___12 *, struct device___170 *);
	int (*map)(struct iommu_domain___12 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___12 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___12 *, long unsigned int, size_t, struct iommu_iotlb_gather___8 *);
	size_t (*unmap_pages)(struct iommu_domain___12 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___8 *);
	void (*flush_iotlb_all)(struct iommu_domain___12 *);
	void (*iotlb_sync_map)(struct iommu_domain___12 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___12 *, struct iommu_iotlb_gather___8 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___12 *, dma_addr_t);
	struct iommu_device___12 * (*probe_device)(struct device___170 *);
	void (*release_device)(struct device___170 *);
	void (*probe_finalize)(struct device___170 *);
	struct iommu_group * (*device_group)(struct device___170 *);
	int (*enable_nesting)(struct iommu_domain___12 *);
	int (*set_pgtable_quirks)(struct iommu_domain___12 *, long unsigned int);
	void (*get_resv_regions)(struct device___170 *, struct list_head *);
	void (*put_resv_regions)(struct device___170 *, struct list_head *);
	void (*apply_resv_region)(struct device___170 *, struct iommu_domain___12 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___170 *, struct of_phandle_args___35 *);
	bool (*is_attach_deferred)(struct iommu_domain___12 *, struct device___170 *);
	bool (*dev_has_feat)(struct device___170 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___170 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___170 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___170 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___12 *, struct device___170 *);
	void (*aux_detach_dev)(struct iommu_domain___12 *, struct device___170 *);
	int (*aux_get_pasid)(struct iommu_domain___12 *, struct device___170 *);
	struct iommu_sva___12 * (*sva_bind)(struct device___170 *, struct mm_struct___210 *, void *);
	void (*sva_unbind)(struct iommu_sva___12 *);
	u32 (*sva_get_pasid)(struct iommu_sva___12 *);
	int (*page_response)(struct device___170 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___12 *, struct device___170 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___12 *, struct device___170 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___170 *, u32);
	int (*def_domain_type)(struct device___170 *);
	long unsigned int pgsize_bitmap;
	struct module___188 *owner;
};

struct device_type___170 {
	const char *name;
	const struct attribute_group___192 **groups;
	int (*uevent)(struct device___170 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___170 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___170 *);
	const struct dev_pm_ops___170 *pm;
};

struct class___170 {
	const char *name;
	struct module___188 *owner;
	const struct attribute_group___192 **class_groups;
	const struct attribute_group___192 **dev_groups;
	struct kobject___192 *dev_kobj;
	int (*dev_uevent)(struct device___170 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___170 *, umode_t *);
	void (*class_release)(struct class___170 *);
	void (*dev_release)(struct device___170 *);
	int (*shutdown_pre)(struct device___170 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___170 *);
	void (*get_ownership)(struct device___170 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___170 *pm;
	struct subsys_private *p;
};

struct dma_map_ops___10 {
	void * (*alloc)(struct device___170 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___170 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___209 * (*alloc_pages)(struct device___170 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___170 *, size_t, struct page___209 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___170 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___170 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___170 *, struct vm_area_struct___209 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___170 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___170 *, struct page___209 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___170 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___170 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___170 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___170 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___170 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___170 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___170 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___170 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___170 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___170 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___170 *, u64);
	u64 (*get_required_mask)(struct device___170 *);
	size_t (*max_mapping_size)(struct device___170 *);
	long unsigned int (*get_merge_boundary)(struct device___170 *);
};

struct fwnode_operations___170;

struct fwnode_handle___170 {
	struct fwnode_handle___170 *secondary;
	const struct fwnode_operations___170 *ops;
	struct device___170 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___53;

struct device_node___71 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___170 fwnode;
	struct property___53 *properties;
	struct property___53 *deadprops;
	struct device_node___71 *parent;
	struct device_node___71 *child;
	struct device_node___71 *sibling;
	struct kobject___192 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___12;

struct dev_iommu___12 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___12 *fwspec;
	struct iommu_device___12 *iommu_dev;
	void *priv;
};

struct dentry_operations___204;

struct dentry___204 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___204 *d_parent;
	struct qstr d_name;
	struct inode___204 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___204 *d_op;
	struct super_block___204 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___204;

struct inode___204 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___204 *i_op;
	struct super_block___204 *i_sb;
	struct address_space___204 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___98 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___205 *i_fop;
		void (*free_inode)(struct inode___204 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___204 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___50 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___204 {
	int (*d_revalidate)(struct dentry___204 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___204 *, unsigned int);
	int (*d_hash)(const struct dentry___204 *, struct qstr *);
	int (*d_compare)(const struct dentry___204 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___204 *);
	int (*d_init)(struct dentry___204 *);
	void (*d_release)(struct dentry___204 *);
	void (*d_prune)(struct dentry___204 *);
	void (*d_iput)(struct dentry___204 *, struct inode___204 *);
	char * (*d_dname)(struct dentry___204 *, char *, int);
	struct vfsmount___204 * (*d_automount)(struct path___204 *);
	int (*d_manage)(const struct path___204 *, bool);
	struct dentry___204 * (*d_real)(struct dentry___204 *, const struct inode___204 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___204;

struct mem_dqinfo___204 {
	struct quota_format_type___204 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___204;

struct quota_info___204 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___204 *files[3];
	struct mem_dqinfo___204 info[3];
	const struct quota_format_ops___204 *ops[3];
};

struct rcuwait___205 {
	struct task_struct___211 *task;
};

struct percpu_rw_semaphore___205 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___205 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___204 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___205 rw_sem[3];
};

struct shrink_control___89;

struct shrinker___89 {
	long unsigned int (*count_objects)(struct shrinker___89 *, struct shrink_control___89 *);
	long unsigned int (*scan_objects)(struct shrinker___89 *, struct shrink_control___89 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___204;

struct dquot_operations___204;

struct quotactl_ops___204;

struct block_device___106;

struct super_block___204 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___204 *s_type;
	const struct super_operations___204 *s_op;
	const struct dquot_operations___204 *dq_op;
	const struct quotactl_ops___204 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___204 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___106 *s_bdev;
	struct backing_dev_info___98 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___204 s_dquot;
	struct sb_writers___204 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___204 *s_d_op;
	int cleancache_poolid;
	struct shrinker___89 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___204 {
	struct dentry___204 *mnt_root;
	struct super_block___204 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___89 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___89 *memcg;
};

struct psi_group___140 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___211 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___140;

struct cgroup_rstat_cpu___140;

struct cgroup___140 {
	struct cgroup_subsys_state___140 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___192 *kn;
	struct cgroup_file___140 procs_file;
	struct cgroup_file___140 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___140 *subsys[14];
	struct cgroup_root___140 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___140 *dom_cgrp;
	struct cgroup___140 *old_dom_cgrp;
	struct cgroup_rstat_cpu___140 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___140 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___105 {
	struct request_queue___105 *q;
	struct io_context___105 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___99;

struct kiocb___204 {
	struct file___204 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___204 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___99 *ki_waitq;
	};
};

struct iattr___204 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___204 *ia_file;
};

struct dquot___204 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___204 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___204 {
	int qf_fmt_id;
	const struct quota_format_ops___204 *qf_ops;
	struct module___188 *qf_owner;
	struct quota_format_type___204 *qf_next;
};

struct quota_format_ops___204 {
	int (*check_quota_file)(struct super_block___204 *, int);
	int (*read_file_info)(struct super_block___204 *, int);
	int (*write_file_info)(struct super_block___204 *, int);
	int (*free_file_info)(struct super_block___204 *, int);
	int (*read_dqblk)(struct dquot___204 *);
	int (*commit_dqblk)(struct dquot___204 *);
	int (*release_dqblk)(struct dquot___204 *);
	int (*get_next_id)(struct super_block___204 *, struct kqid *);
};

struct dquot_operations___204 {
	int (*write_dquot)(struct dquot___204 *);
	struct dquot___204 * (*alloc_dquot)(struct super_block___204 *, int);
	void (*destroy_dquot)(struct dquot___204 *);
	int (*acquire_dquot)(struct dquot___204 *);
	int (*release_dquot)(struct dquot___204 *);
	int (*mark_dirty)(struct dquot___204 *);
	int (*write_info)(struct super_block___204 *, int);
	qsize_t * (*get_reserved_space)(struct inode___204 *);
	int (*get_projid)(struct inode___204 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___204 *, qsize_t *);
	int (*get_next_id)(struct super_block___204 *, struct kqid *);
};

struct quotactl_ops___204 {
	int (*quota_on)(struct super_block___204 *, int, int, const struct path___204 *);
	int (*quota_off)(struct super_block___204 *, int);
	int (*quota_enable)(struct super_block___204 *, unsigned int);
	int (*quota_disable)(struct super_block___204 *, unsigned int);
	int (*quota_sync)(struct super_block___204 *, int);
	int (*set_info)(struct super_block___204 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___204 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___204 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___204 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___204 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___204 *, unsigned int);
};

struct wait_page_queue___99 {
	struct page___209 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___98;

struct readahead_control___99;

struct swap_info_struct___57;

struct address_space_operations___204 {
	int (*writepage)(struct page___209 *, struct writeback_control___98 *);
	int (*readpage)(struct file___204 *, struct page___209 *);
	int (*writepages)(struct address_space___204 *, struct writeback_control___98 *);
	int (*set_page_dirty)(struct page___209 *);
	int (*readpages)(struct file___204 *, struct address_space___204 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___99 *);
	int (*write_begin)(struct file___204 *, struct address_space___204 *, loff_t, unsigned int, unsigned int, struct page___209 **, void **);
	int (*write_end)(struct file___204 *, struct address_space___204 *, loff_t, unsigned int, unsigned int, struct page___209 *, void *);
	sector_t (*bmap)(struct address_space___204 *, sector_t);
	void (*invalidatepage)(struct page___209 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___209 *, gfp_t);
	void (*freepage)(struct page___209 *);
	ssize_t (*direct_IO)(struct kiocb___204 *, struct iov_iter___125 *);
	int (*migratepage)(struct address_space___204 *, struct page___209 *, struct page___209 *, enum migrate_mode);
	bool (*isolate_page)(struct page___209 *, isolate_mode_t);
	void (*putback_page)(struct page___209 *);
	int (*launder_page)(struct page___209 *);
	int (*is_partially_uptodate)(struct page___209 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___209 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___204 *, struct page___209 *);
	int (*swap_activate)(struct swap_info_struct___57 *, struct file___204 *, sector_t *);
	void (*swap_deactivate)(struct file___204 *);
};

struct writeback_control___98 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___98 *wb;
	struct inode___204 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___99 {
	struct file___204 *file;
	struct address_space___204 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___122;

struct iov_iter___125 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___122 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___57 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___106 *bdev;
	struct file___204 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___204 {
	struct dentry___204 * (*lookup)(struct inode___204 *, struct dentry___204 *, unsigned int);
	const char * (*get_link)(struct dentry___204 *, struct inode___204 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___204 *, int);
	struct posix_acl * (*get_acl)(struct inode___204 *, int, bool);
	int (*readlink)(struct dentry___204 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___204 *, struct dentry___204 *, umode_t, bool);
	int (*link)(struct dentry___204 *, struct inode___204 *, struct dentry___204 *);
	int (*unlink)(struct inode___204 *, struct dentry___204 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___204 *, struct dentry___204 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___204 *, struct dentry___204 *, umode_t);
	int (*rmdir)(struct inode___204 *, struct dentry___204 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___204 *, struct dentry___204 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___204 *, struct dentry___204 *, struct inode___204 *, struct dentry___204 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___204 *, struct iattr___204 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___204 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___204 *, char *, size_t);
	int (*fiemap)(struct inode___204 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___204 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___204 *, struct dentry___204 *, struct file___204 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___204 *, struct dentry___204 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___204 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___204 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___204 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___204 {
	void (*fl_copy_lock)(struct file_lock___204 *, struct file_lock___204 *);
	void (*fl_release_private)(struct file_lock___204 *);
};

struct fasync_struct___204;

struct lock_manager_operations___204;

struct file_lock___204 {
	struct file_lock___204 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___204 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___204 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___204 *fl_ops;
	const struct lock_manager_operations___204 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___204 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___204 *);
	int (*lm_grant)(struct file_lock___204 *, int);
	bool (*lm_break)(struct file_lock___204 *);
	int (*lm_change)(struct file_lock___204 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___204 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___204 *);
};

struct fasync_struct___204 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___204 *fa_next;
	struct file___204 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___204 {
	struct inode___204 * (*alloc_inode)(struct super_block___204 *);
	void (*destroy_inode)(struct inode___204 *);
	void (*free_inode)(struct inode___204 *);
	void (*dirty_inode)(struct inode___204 *, int);
	int (*write_inode)(struct inode___204 *, struct writeback_control___98 *);
	int (*drop_inode)(struct inode___204 *);
	void (*evict_inode)(struct inode___204 *);
	void (*put_super)(struct super_block___204 *);
	int (*sync_fs)(struct super_block___204 *, int);
	int (*freeze_super)(struct super_block___204 *);
	int (*freeze_fs)(struct super_block___204 *);
	int (*thaw_super)(struct super_block___204 *);
	int (*unfreeze_fs)(struct super_block___204 *);
	int (*statfs)(struct dentry___204 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___204 *, int *, char *);
	void (*umount_begin)(struct super_block___204 *);
	int (*show_options)(struct seq_file___180 *, struct dentry___204 *);
	int (*show_devname)(struct seq_file___180 *, struct dentry___204 *);
	int (*show_path)(struct seq_file___180 *, struct dentry___204 *);
	int (*show_stats)(struct seq_file___180 *, struct dentry___204 *);
	ssize_t (*quota_read)(struct super_block___204 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___204 *, int, const char *, size_t, loff_t);
	struct dquot___204 ** (*get_dquots)(struct inode___204 *);
	long int (*nr_cached_objects)(struct super_block___204 *, struct shrink_control___89 *);
	long int (*free_cached_objects)(struct super_block___204 *, struct shrink_control___89 *);
	struct file___204 * (*real_loop)(struct file___204 *);
};

struct block_device___106 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___204 *bd_inode;
	struct super_block___204 *bd_super;
	void *bd_claiming;
	struct device___170 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___192 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___106 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___204 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___105(struct bio___105 *);

struct bio_vec___122 {
	struct page___209 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___105;

struct bio___105 {
	struct bio___105 *bi_next;
	struct block_device___106 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___105 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___100 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___105 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___122 *bi_io_vec;
	struct bio_set___105 *bi_pool;
	struct bio_vec___122 bi_inline_vecs[0];
};

struct seq_operations___180 {
	void * (*start)(struct seq_file___180 *, loff_t *);
	void (*stop)(struct seq_file___180 *, void *);
	void * (*next)(struct seq_file___180 *, void *, loff_t *);
	int (*show)(struct seq_file___180 *, void *);
};

struct cgroup_namespace___140 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___140 *root_cset;
};

struct fwnode_reference_args___170;

struct fwnode_endpoint___170;

struct fwnode_operations___170 {
	struct fwnode_handle___170 * (*get)(struct fwnode_handle___170 *);
	void (*put)(struct fwnode_handle___170 *);
	bool (*device_is_available)(const struct fwnode_handle___170 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___170 *, const struct device___170 *);
	bool (*property_present)(const struct fwnode_handle___170 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___170 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___170 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___170 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*get_parent)(const struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*get_next_child_node)(const struct fwnode_handle___170 *, struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*get_named_child_node)(const struct fwnode_handle___170 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___170 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___170 *);
	struct fwnode_handle___170 * (*graph_get_next_endpoint)(const struct fwnode_handle___170 *, struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*graph_get_remote_endpoint)(const struct fwnode_handle___170 *);
	struct fwnode_handle___170 * (*graph_get_port_parent)(struct fwnode_handle___170 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___170 *, struct fwnode_endpoint___170 *);
	int (*add_links)(struct fwnode_handle___170 *);
};

struct fwnode_endpoint___170 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___170 *local_fwnode;
};

struct fwnode_reference_args___170 {
	struct fwnode_handle___170 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___188 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___188 *);
	int (*get)(char *, const struct kernel_param___188 *);
	void (*free)(void *);
};

struct kparam_array___188;

struct kernel_param___188 {
	const char *name;
	struct module___188 *mod;
	const struct kernel_param_ops___188 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___188 *arr;
	};
};

struct kparam_array___188 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___188 *ops;
	void *elem;
};

struct module_attribute___188 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___188 *, struct module_kobject___188 *, char *);
	ssize_t (*store)(struct module_attribute___188 *, struct module_kobject___188 *, const char *, size_t);
	void (*setup)(struct module___188 *, const char *);
	int (*test)(struct module___188 *);
	void (*free)(struct module___188 *);
};

struct dev_pagemap_ops___199 {
	void (*page_free)(struct page___209 *);
	void (*kill)(struct dev_pagemap___199 *);
	void (*cleanup)(struct dev_pagemap___199 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___199 *);
};

struct cftype___140;

struct cgroup_subsys___140 {
	struct cgroup_subsys_state___140 * (*css_alloc)(struct cgroup_subsys_state___140 *);
	int (*css_online)(struct cgroup_subsys_state___140 *);
	void (*css_offline)(struct cgroup_subsys_state___140 *);
	void (*css_released)(struct cgroup_subsys_state___140 *);
	void (*css_free)(struct cgroup_subsys_state___140 *);
	void (*css_reset)(struct cgroup_subsys_state___140 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___140 *, int);
	int (*css_extra_stat_show)(struct seq_file___180 *, struct cgroup_subsys_state___140 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___211 *, struct css_set___140 *);
	void (*cancel_fork)(struct task_struct___211 *, struct css_set___140 *);
	void (*fork)(struct task_struct___211 *);
	void (*exit)(struct task_struct___211 *);
	void (*release)(struct task_struct___211 *);
	void (*bind)(struct cgroup_subsys_state___140 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___140 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___140 *dfl_cftypes;
	struct cftype___140 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___140 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___140 *updated_children;
	struct cgroup___140 *updated_next;
};

struct cgroup_root___140 {
	struct kernfs_root___192 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___140 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___140 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___140 *ss;
	struct list_head node;
	struct kernfs_ops___192 *kf_ops;
	int (*open)(struct kernfs_open_file___192 *);
	void (*release)(struct kernfs_open_file___192 *);
	u64 (*read_u64)(struct cgroup_subsys_state___140 *, struct cftype___140 *);
	s64 (*read_s64)(struct cgroup_subsys_state___140 *, struct cftype___140 *);
	int (*seq_show)(struct seq_file___180 *, void *);
	void * (*seq_start)(struct seq_file___180 *, loff_t *);
	void * (*seq_next)(struct seq_file___180 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___180 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___140 *, struct cftype___140 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___140 *, struct cftype___140 *, s64);
	ssize_t (*write)(struct kernfs_open_file___192 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___192 *, struct poll_table_struct___5 *);
};

struct block_device_operations___105;

struct gendisk___106 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___106 *part0;
	const struct block_device_operations___105 *fops;
	struct request_queue___105 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___98 *bdi;
	struct kobject___192 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___192 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___105 {
	struct bio___105 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___122 *bip_vec;
	struct bio_vec___122 bip_inline_vecs[0];
};

struct blkcg___100;

struct blkg_policy_data___100;

struct blkcg_gq___100 {
	struct request_queue___105 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___100 *blkcg;
	struct blkcg_gq___100 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___100 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___105 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___105(struct request___105 *);

typedef void integrity_complete_fn___105(struct request___105 *, unsigned int);

struct blk_integrity_profile___105 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___105 *prepare_fn;
	integrity_complete_fn___105 *complete_fn;
	const char *name;
};

struct block_device_operations___105 {
	blk_qc_t (*submit_bio)(struct bio___105 *);
	int (*open)(struct block_device___106 *, fmode_t);
	void (*release)(struct gendisk___106 *, fmode_t);
	int (*rw_page)(struct block_device___106 *, sector_t, struct page___209 *, unsigned int);
	int (*ioctl)(struct block_device___106 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___106 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___106 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___106 *);
	int (*getgeo)(struct block_device___106 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___106 *, bool);
	void (*swap_slot_free_notify)(struct block_device___106 *, long unsigned int);
	int (*report_zones)(struct gendisk___106 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___106 *, umode_t *);
	struct module___188 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___106 *, sector_t *);
};

typedef void rq_end_io_fn___105(struct request___105 *, blk_status_t);

struct request___105 {
	struct request_queue___105 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___102 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___105 *bio;
	struct bio___105 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___122 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___105 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___105 *saved_end_io;
		} flush;
	};
	struct gendisk___106 *rq_disk;
	struct block_device___106 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___105 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___102 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___105 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___192 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___204 *debugfs_dir;
	struct dentry___204 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___105;

struct elevator_mq_ops___105 {
	int (*init_sched)(struct request_queue___105 *, struct elevator_type___105 *);
	void (*exit_sched)(struct elevator_queue___105 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___102 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___102 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___102 *);
	bool (*allow_merge)(struct request_queue___105 *, struct request___105 *, struct bio___105 *);
	bool (*bio_merge)(struct request_queue___105 *, struct bio___105 *, unsigned int);
	int (*request_merge)(struct request_queue___105 *, struct request___105 **, struct bio___105 *);
	void (*request_merged)(struct request_queue___105 *, struct request___105 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___105 *, struct request___105 *, struct request___105 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___105 *);
	void (*finish_request)(struct request___105 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___102 *, struct list_head *, bool);
	struct request___105 * (*dispatch_request)(struct blk_mq_hw_ctx___102 *);
	bool (*has_work)(struct blk_mq_hw_ctx___102 *);
	void (*completed_request)(struct request___105 *, u64);
	void (*requeue_request)(struct request___105 *);
	struct request___105 * (*former_request)(struct request_queue___105 *, struct request___105 *);
	struct request___105 * (*next_request)(struct request_queue___105 *, struct request___105 *);
	void (*init_icq)(struct io_cq___105 *);
	void (*exit_icq)(struct io_cq___105 *);
};

struct elv_fs_entry___105;

struct elevator_type___105 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___105 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___105 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___188 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___105 {
	struct elevator_type___105 *type;
	void *elevator_data;
	struct kobject___192 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___105 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___105 *, char *);
	ssize_t (*store)(struct elevator_queue___105 *, const char *, size_t);
};

struct blk_mq_queue_data___102;

struct blk_mq_ops___102 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___102 *, const struct blk_mq_queue_data___102 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___102 *);
	int (*get_budget)(struct request_queue___105 *);
	void (*put_budget)(struct request_queue___105 *, int);
	void (*set_rq_budget_token)(struct request___105 *, int);
	int (*get_rq_budget_token)(struct request___105 *);
	enum blk_eh_timer_return (*timeout)(struct request___105 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___102 *);
	void (*complete)(struct request___105 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___102 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___102 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___102 *, struct request___105 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___102 *, struct request___105 *, unsigned int);
	void (*initialize_rq_fn)(struct request___105 *);
	void (*cleanup_rq)(struct request___105 *);
	bool (*busy)(struct request_queue___105 *);
	int (*map_queues)(struct blk_mq_tag_set___102 *);
	void (*show_rq)(struct seq_file___180 *, struct request___105 *);
};

struct blk_mq_tag_set___102 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___102 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___102 {
	struct request___105 *rq;
	bool last;
};

struct blkcg_policy_data___100;

struct blkcg___100 {
	struct cgroup_subsys_state___140 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___100 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___100 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___100 {
	struct blkcg___100 *blkcg;
	int plid;
};

struct blkg_policy_data___100 {
	struct blkcg_gq___100 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___89 {
	struct mem_cgroup___89 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___89 {
	struct lruvec___96 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___89 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___89 *memcg;
};

struct obj_cgroup___89 {
	struct percpu_ref refcnt;
	struct mem_cgroup___89 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct property___53 {
	char *name;
	int length;
	void *value;
	struct property___53 *next;
	long unsigned int _flags;
	struct bin_attribute___192 attr;
};

struct of_phandle_args___35 {
	struct device_node___71 *np;
	int args_count;
	uint32_t args[16];
};

typedef int (*iommu_fault_handler_t___12)(struct iommu_domain___12 *, struct device___170 *, long unsigned int, int, void *);

struct iommu_domain___12 {
	unsigned int type;
	const struct iommu_ops___12 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___12 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct iommu_iotlb_gather___8 {
	long unsigned int start;
	long unsigned int end;
	size_t pgsize;
	struct page___209 *freelist;
	bool queued;
};

struct iommu_device___12 {
	struct list_head list;
	const struct iommu_ops___12 *ops;
	struct fwnode_handle___170 *fwnode;
	struct device___170 *dev;
};

struct iommu_sva___12 {
	struct device___170 *dev;
};

struct iommu_fwspec___12 {
	const struct iommu_ops___12 *ops;
	struct fwnode_handle___170 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct virtio_device___6;

struct virtqueue___6 {
	struct list_head list;
	void (*callback)(struct virtqueue___6 *);
	const char *name;
	struct virtio_device___6 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct virtio_config_ops___6;

struct virtio_device___6 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___170 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___6 *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t___6(struct virtqueue___6 *);

struct virtio_config_ops___6 {
	void (*get)(struct virtio_device___6 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___6 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___6 *);
	u8 (*get_status)(struct virtio_device___6 *);
	void (*set_status)(struct virtio_device___6 *, u8);
	void (*reset)(struct virtio_device___6 *);
	int (*find_vqs)(struct virtio_device___6 *, unsigned int, struct virtqueue___6 **, vq_callback_t___6 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___6 *);
	u64 (*get_features)(struct virtio_device___6 *);
	int (*finalize_features)(struct virtio_device___6 *);
	const char * (*bus_name)(struct virtio_device___6 *);
	int (*set_vq_affinity)(struct virtqueue___6 *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___6 *, int);
	bool (*get_shm_region)(struct virtio_device___6 *, struct virtio_shm_region *, u8);
};

struct virtio_driver___4 {
	struct device_driver___170 driver;
	const struct virtio_device_id *id_table;
	const unsigned int *feature_table;
	unsigned int feature_table_size;
	const unsigned int *feature_table_legacy;
	unsigned int feature_table_size_legacy;
	int (*validate)(struct virtio_device___6 *);
	int (*probe)(struct virtio_device___6 *);
	void (*scan)(struct virtio_device___6 *);
	void (*remove)(struct virtio_device___6 *);
	void (*config_changed)(struct virtio_device___6 *);
	int (*freeze)(struct virtio_device___6 *);
	int (*restore)(struct virtio_device___6 *);
};

struct virtio_iommu_range_64 {
	__le64 start;
	__le64 end;
};

struct virtio_iommu_range_32 {
	__le32 start;
	__le32 end;
};

struct virtio_iommu_config {
	__le64 page_size_mask;
	struct virtio_iommu_range_64 input_range;
	struct virtio_iommu_range_32 domain_range;
	__le32 probe_size;
};

struct virtio_iommu_req_head {
	__u8 type;
	__u8 reserved[3];
};

struct virtio_iommu_req_tail {
	__u8 status;
	__u8 reserved[3];
};

struct virtio_iommu_req_attach {
	struct virtio_iommu_req_head head;
	__le32 domain;
	__le32 endpoint;
	__u8 reserved[8];
	struct virtio_iommu_req_tail tail;
};

struct virtio_iommu_req_map {
	struct virtio_iommu_req_head head;
	__le32 domain;
	__le64 virt_start;
	__le64 virt_end;
	__le64 phys_start;
	__le32 flags;
	struct virtio_iommu_req_tail tail;
};

struct virtio_iommu_req_unmap {
	struct virtio_iommu_req_head head;
	__le32 domain;
	__le64 virt_start;
	__le64 virt_end;
	__u8 reserved[4];
	struct virtio_iommu_req_tail tail;
};

struct virtio_iommu_probe_property {
	__le16 type;
	__le16 length;
};

struct virtio_iommu_probe_resv_mem {
	struct virtio_iommu_probe_property head;
	__u8 subtype;
	__u8 reserved[3];
	__le64 start;
	__le64 end;
};

struct virtio_iommu_req_probe {
	struct virtio_iommu_req_head head;
	__le32 endpoint;
	__u8 reserved[64];
	__u8 properties[0];
};

struct virtio_iommu_fault {
	__u8 reason;
	__u8 reserved[3];
	__le32 flags;
	__le32 endpoint;
	__u8 reserved2[4];
	__le64 address;
};

struct viommu_dev {
	struct iommu_device___12 iommu;
	struct device___170 *dev;
	struct virtio_device___6 *vdev;
	struct ida domain_ids;
	struct virtqueue___6 *vqs[2];
	spinlock_t request_lock;
	struct list_head requests;
	void *evts;
	struct iommu_domain_geometry geometry;
	u64 pgsize_bitmap;
	u32 first_domain;
	u32 last_domain;
	u32 map_flags;
	u32 probe_size;
};

struct viommu_mapping {
	phys_addr_t paddr;
	struct interval_tree_node iova;
	u32 flags;
};

struct viommu_domain {
	struct iommu_domain___12 domain;
	struct viommu_dev *viommu;
	struct mutex mutex;
	unsigned int id;
	u32 map_flags;
	spinlock_t mappings_lock;
	struct rb_root_cached mappings;
	long unsigned int nr_endpoints;
};

struct viommu_endpoint {
	struct device___170 *dev;
	struct viommu_dev *viommu;
	struct viommu_domain *vdomain;
	struct list_head resv_regions;
};

struct viommu_request {
	struct list_head list;
	void *writeback;
	unsigned int write_offset;
	unsigned int len;
	char buf[0];
};

struct viommu_event {
	union {
		u32 head;
		struct virtio_iommu_fault fault;
	};
};

struct iopf_queue___2;

struct iopf_device_param {
	struct device___169 *dev;
	struct iopf_queue___2 *queue;
	struct list_head queue_list;
	struct list_head partial;
};

struct iopf_queue___2 {
	struct workqueue_struct *wq;
	struct list_head devices;
	struct mutex lock;
};

struct iopf_fault {
	struct iommu_fault fault;
	struct list_head list;
};

struct iopf_group {
	struct iopf_fault last_fault;
	struct list_head faults;
	struct work_struct work;
	struct device___169 *dev;
};

struct netlink_skb_parms___3 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___5 *sk;
	bool nsid_is_set;
	int nsid;
};

struct cb_id {
	__u32 idx;
	__u32 val;
};

struct cn_msg {
	struct cb_id id;
	__u32 seq;
	__u32 ack;
	__u16 len;
	__u16 flags;
	__u8 data[0];
};

struct cn_queue_dev {
	atomic_t refcnt;
	unsigned char name[32];
	struct list_head queue_list;
	spinlock_t queue_lock;
	struct sock___5 *nls;
};

struct cn_callback_id {
	unsigned char name[32];
	struct cb_id id;
};

struct cn_callback_entry {
	struct list_head callback_entry;
	refcount_t refcnt;
	struct cn_queue_dev *pdev;
	struct cn_callback_id id;
	void (*callback)(struct cn_msg *, struct netlink_skb_parms___3 *);
	u32 seq;
	u32 group;
};

struct netlink_skb_parms___4 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___30 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___3 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___37 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___41 *, int);
	void (*unbind)(struct net___41 *, int);
	bool (*compare)(struct net___41 *, struct sock___30 *);
};

struct cn_queue_dev___2 {
	atomic_t refcnt;
	unsigned char name[32];
	struct list_head queue_list;
	spinlock_t queue_lock;
	struct sock___30 *nls;
};

struct cn_callback_entry___2 {
	struct list_head callback_entry;
	refcount_t refcnt;
	struct cn_queue_dev___2 *pdev;
	struct cn_callback_id id;
	void (*callback)(struct cn_msg *, struct netlink_skb_parms___4 *);
	u32 seq;
	u32 group;
};

struct cn_dev {
	struct cb_id id;
	u32 seq;
	u32 groups;
	struct sock___30 *nls;
	struct cn_queue_dev___2 *cbdev;
};

enum proc_cn_mcast_op {
	PROC_CN_MCAST_LISTEN = 1,
	PROC_CN_MCAST_IGNORE = 2,
};

struct fork_proc_event {
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
	__kernel_pid_t child_pid;
	__kernel_pid_t child_tgid;
};

struct exec_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct id_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	union {
		__u32 ruid;
		__u32 rgid;
	} r;
	union {
		__u32 euid;
		__u32 egid;
	} e;
};

struct sid_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
};

struct ptrace_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__kernel_pid_t tracer_pid;
	__kernel_pid_t tracer_tgid;
};

struct comm_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	char comm[16];
};

struct coredump_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
};

struct exit_proc_event {
	__kernel_pid_t process_pid;
	__kernel_pid_t process_tgid;
	__u32 exit_code;
	__u32 exit_signal;
	__kernel_pid_t parent_pid;
	__kernel_pid_t parent_tgid;
};

struct proc_event {
	enum what what;
	__u32 cpu;
	__u64 timestamp_ns;
	union {
		struct {
			__u32 err;
		} ack;
		struct fork_proc_event fork;
		struct exec_proc_event exec;
		struct id_proc_event id;
		struct sid_proc_event sid;
		struct ptrace_proc_event ptrace;
		struct comm_proc_event comm;
		struct coredump_proc_event coredump;
		struct exit_proc_event exit;
	} event_data;
};

struct local_event {
	local_lock_t lock;
	__u32 count;
};

struct component_ops {
	int (*bind)(struct device___170 *, struct device___170 *, void *);
	void (*unbind)(struct device___170 *, struct device___170 *, void *);
};

struct component_master_ops {
	int (*bind)(struct device___170 *);
	void (*unbind)(struct device___170 *);
};

typedef void (*dr_release_t___20)(struct device___170 *, void *);

struct component;

struct component_match_array {
	void *data;
	int (*compare)(struct device___170 *, void *);
	int (*compare_typed)(struct device___170 *, int, void *);
	void (*release)(struct device___170 *, void *);
	struct component *component;
	bool duplicate;
};

struct master;

struct component {
	struct list_head node;
	struct master *master;
	bool bound;
	const struct component_ops *ops;
	int subcomponent;
	struct device___170 *dev;
};

struct component_match {
	size_t alloc;
	size_t num;
	struct component_match_array *compare;
};

struct master {
	struct list_head node;
	bool bound;
	const struct component_master_ops *ops;
	struct device___170 *parent;
	struct component_match *match;
};

struct irq_desc___46;

typedef void (*irq_flow_handler_t___46)(struct irq_desc___46 *);

struct irq_chip___45;

struct irq_domain___44;

struct irq_data___45 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___45 *chip;
	struct irq_domain___44 *domain;
	struct irq_data___45 *parent_data;
	void *chip_data;
};

struct kset___193;

struct kobj_type___193;

struct kernfs_node___193;

struct kobject___193 {
	const char *name;
	struct list_head entry;
	struct kobject___193 *parent;
	struct kset___193 *kset;
	struct kobj_type___193 *ktype;
	struct kernfs_node___193 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___31;

struct module___189;

struct irq_desc___46 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___45 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___46 handle_irq;
	struct irqaction___31 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___193 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___189 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___205;

struct super_block___205;

struct file_system_type___205 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___205 * (*mount)(struct file_system_type___205 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___205 *);
	struct module___189 *owner;
	struct file_system_type___205 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___205;

struct kiocb___205;

struct iov_iter___126;

struct poll_table_struct___135;

struct vm_area_struct___210;

struct inode___205;

struct file_lock___205;

struct page___210;

struct pipe_inode_info___67;

struct seq_file___181;

struct file_operations___206 {
	struct module___189 *owner;
	loff_t (*llseek)(struct file___205 *, loff_t, int);
	ssize_t (*read)(struct file___205 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___205 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___205 *, struct iov_iter___126 *);
	ssize_t (*write_iter)(struct kiocb___205 *, struct iov_iter___126 *);
	int (*iopoll)(struct kiocb___205 *, bool);
	int (*iterate)(struct file___205 *, struct dir_context *);
	int (*iterate_shared)(struct file___205 *, struct dir_context *);
	__poll_t (*poll)(struct file___205 *, struct poll_table_struct___135 *);
	long int (*unlocked_ioctl)(struct file___205 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___205 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___205 *, struct vm_area_struct___210 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___205 *, struct file___205 *);
	int (*flush)(struct file___205 *, fl_owner_t);
	int (*release)(struct inode___205 *, struct file___205 *);
	int (*fsync)(struct file___205 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___205 *, int);
	int (*lock)(struct file___205 *, int, struct file_lock___205 *);
	ssize_t (*sendpage)(struct file___205 *, struct page___210 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___205 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___205 *, long unsigned int);
	int (*flock)(struct file___205 *, int, struct file_lock___205 *);
	ssize_t (*splice_write)(struct pipe_inode_info___67 *, struct file___205 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___205 *, loff_t *, struct pipe_inode_info___67 *, size_t, unsigned int);
	int (*setlease)(struct file___205 *, long int, struct file_lock___205 **, void **);
	long int (*fallocate)(struct file___205 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___181 *, struct file___205 *);
	ssize_t (*copy_file_range)(struct file___205 *, loff_t, struct file___205 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___205 *, loff_t, struct file___205 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___205 *, loff_t, loff_t, int);
};

struct vmacache___210 {
	u64 seqnum;
	struct vm_area_struct___210 *vmas[4];
};

struct page_frag___210 {
	struct page___210 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___211;

struct pid___182;

struct nsproxy___191;

struct signal_struct___206;

struct css_set___141;

struct vm_struct___188;

struct task_struct___212 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___212 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___211 *mm;
	struct mm_struct___211 *active_mm;
	struct vmacache___210 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___212 *real_parent;
	struct task_struct___212 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___212 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___182 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___191 *nsproxy;
	struct signal_struct___206 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___212 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___105 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___141 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___67 *splice_pipe;
	struct page_frag___210 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___212 *oom_reaper_list;
	struct vm_struct___188 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___189 {
	struct kobject___193 kobj;
	struct module___189 *mod;
	struct kobject___193 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___189 {
	struct module___189 *mod;
	struct latch_tree_node node;
};

struct module_layout___189 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___189 mtn;
};

struct module_attribute___189;

struct kernel_param___189;

struct module___189 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___189 mkobj;
	struct module_attribute___189 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___193 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___189 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___189 core_layout;
	struct module_layout___189 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___210 *pgtable_t___210;

struct address_space___205;

struct page_pool___55;

struct dev_pagemap___200;

struct page___210 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___205 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___55 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___210 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___210 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___211 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___200 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___200;

struct vm_area_struct___210 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___210 *vm_next;
	struct vm_area_struct___210 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___211 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___200 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___205 *vm_file;
	struct file___205 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___210;

struct mm_struct___211 {
	struct {
		struct vm_area_struct___210 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___205 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___210 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___212 *owner;
		struct user_namespace___25 *user_ns;
		struct file___205 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___205;

struct address_space___205 {
	struct inode___205 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___205 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___171;

struct page_pool_params___55 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___171 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___55 {
	u32 count;
	struct page___210 *cache[128];
};

struct page_pool___55 {
	struct page_pool_params___55 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___210 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___55 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___200;

struct dev_pagemap___200 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___200 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___205;

struct path___205 {
	struct vfsmount___205 *mnt;
	struct dentry___205 *dentry;
};

struct fown_struct___182 {
	rwlock_t lock;
	struct pid___182 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___205 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___205 f_path;
	struct inode___205 *f_inode;
	const struct file_operations___206 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___182 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___205 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___200;

struct vm_operations_struct___200 {
	void (*open)(struct vm_area_struct___210 *);
	void (*close)(struct vm_area_struct___210 *);
	int (*may_split)(struct vm_area_struct___210 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___210 *);
	int (*mprotect)(struct vm_area_struct___210 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___200 *);
	vm_fault_t (*huge_fault)(struct vm_fault___200 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___200 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___210 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___200 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___200 *);
	int (*access)(struct vm_area_struct___210 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___210 *);
	int (*set_policy)(struct vm_area_struct___210 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___210 *, long unsigned int);
	struct page___210 * (*find_special_page)(struct vm_area_struct___210 *, long unsigned int);
};

struct core_thread___210 {
	struct task_struct___212 *task;
	struct core_thread___210 *next;
};

struct core_state___210 {
	atomic_t nr_threads;
	struct core_thread___210 dumper;
	struct completion startup;
};

struct vm_fault___200 {
	const struct {
		struct vm_area_struct___210 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___210 *cow_page;
	struct page___210 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___210 prealloc_pte;
};

struct kernfs_root___193;

struct kernfs_elem_dir___193 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___193 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___193;

struct kernfs_root___193 {
	struct kernfs_node___193 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___193 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___193 {
	struct kernfs_node___193 *target_kn;
};

struct kernfs_ops___193;

struct kernfs_elem_attr___193 {
	const struct kernfs_ops___193 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___193 *notify_next;
};

struct kernfs_node___193 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___193 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___193 dir;
		struct kernfs_elem_symlink___193 symlink;
		struct kernfs_elem_attr___193 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___193;

struct kernfs_ops___193 {
	int (*open)(struct kernfs_open_file___193 *);
	void (*release)(struct kernfs_open_file___193 *);
	int (*seq_show)(struct seq_file___181 *, void *);
	void * (*seq_start)(struct seq_file___181 *, loff_t *);
	void * (*seq_next)(struct seq_file___181 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___181 *, void *);
	ssize_t (*read)(struct kernfs_open_file___193 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___193 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___193 *, struct poll_table_struct___135 *);
	int (*mmap)(struct kernfs_open_file___193 *, struct vm_area_struct___210 *);
};

struct kernfs_syscall_ops___193 {
	int (*show_options)(struct seq_file___181 *, struct kernfs_root___193 *);
	int (*mkdir)(struct kernfs_node___193 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___193 *);
	int (*rename)(struct kernfs_node___193 *, struct kernfs_node___193 *, const char *);
	int (*show_path)(struct seq_file___181 *, struct kernfs_node___193 *, struct kernfs_root___193 *);
};

struct seq_operations___181;

struct seq_file___181 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___181 *op;
	int poll_event;
	const struct file___205 *file;
	void *private;
};

struct kernfs_open_file___193 {
	struct kernfs_node___193 *kn;
	struct file___205 *file;
	struct seq_file___181 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___200 *vm_ops;
};

typedef void (*poll_queue_proc___142)(struct file___205 *, wait_queue_head_t *, struct poll_table_struct___135 *);

struct poll_table_struct___135 {
	poll_queue_proc___142 _qproc;
	__poll_t _key;
};

struct pid_namespace___182;

struct upid___182 {
	int nr;
	struct pid_namespace___182 *ns;
};

struct pid_namespace___182 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___212 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___182 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___182 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___182 numbers[1];
};

struct signal_struct___206 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___212 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___212 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___182 *pids[4];
	struct pid___182 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___211 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___42;

struct cgroup_namespace___141;

struct nsproxy___191 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___182 *pid_ns_for_children;
	struct net___42 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___141 *cgroup_ns;
};

struct cgroup_subsys_state___141;

struct cgroup___141;

struct css_set___141 {
	struct cgroup_subsys_state___141 *subsys[14];
	refcount_t refcount;
	struct css_set___141 *dom_cset;
	struct cgroup___141 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___141 *mg_src_cgrp;
	struct cgroup___141 *mg_dst_cgrp;
	struct css_set___141 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___205;

struct pipe_buffer___67;

struct pipe_inode_info___67 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___210 *tmp_page;
	struct fasync_struct___205 *fasync_readers;
	struct fasync_struct___205 *fasync_writers;
	struct pipe_buffer___67 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___188 {
	struct vm_struct___188 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___210 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___193;

struct attribute_group___193 {
	const char *name;
	umode_t (*is_visible)(struct kobject___193 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___193 *, struct bin_attribute___193 *, int);
	struct attribute **attrs;
	struct bin_attribute___193 **bin_attrs;
};

struct bin_attribute___193 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___205 * (*f_mapping)();
	ssize_t (*read)(struct file___205 *, struct kobject___193 *, struct bin_attribute___193 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___205 *, struct kobject___193 *, struct bin_attribute___193 *, char *, loff_t, size_t);
	int (*mmap)(struct file___205 *, struct kobject___193 *, struct bin_attribute___193 *, struct vm_area_struct___210 *);
};

struct sysfs_ops___193 {
	ssize_t (*show)(struct kobject___193 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___193 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___193;

struct kset___193 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___193 kobj;
	const struct kset_uevent_ops___193 *uevent_ops;
};

struct kobj_type___193 {
	void (*release)(struct kobject___193 *);
	const struct sysfs_ops___193 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___193 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___193 *);
	const void * (*namespace)(struct kobject___193 *);
	void (*get_ownership)(struct kobject___193 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___193 {
	int (* const filter)(struct kset___193 *, struct kobject___193 *);
	const char * (* const name)(struct kset___193 *, struct kobject___193 *);
	int (* const uevent)(struct kset___193 *, struct kobject___193 *, struct kobj_uevent_env *);
};

struct fwnode_operations___171;

struct fwnode_handle___171 {
	struct fwnode_handle___171 *secondary;
	const struct fwnode_operations___171 *ops;
	struct device___171 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___171;

struct fwnode_endpoint___171;

struct fwnode_operations___171 {
	struct fwnode_handle___171 * (*get)(struct fwnode_handle___171 *);
	void (*put)(struct fwnode_handle___171 *);
	bool (*device_is_available)(const struct fwnode_handle___171 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___171 *, const struct device___171 *);
	bool (*property_present)(const struct fwnode_handle___171 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___171 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___171 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___171 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*get_parent)(const struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*get_next_child_node)(const struct fwnode_handle___171 *, struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*get_named_child_node)(const struct fwnode_handle___171 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___171 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___171 *);
	struct fwnode_handle___171 * (*graph_get_next_endpoint)(const struct fwnode_handle___171 *, struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*graph_get_remote_endpoint)(const struct fwnode_handle___171 *);
	struct fwnode_handle___171 * (*graph_get_port_parent)(struct fwnode_handle___171 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___171 *, struct fwnode_endpoint___171 *);
	int (*add_links)(struct fwnode_handle___171 *);
};

struct wakeup_source___171;

struct wake_irq___2;

struct dev_pm_qos___12;

struct dev_pm_info___171 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___171 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___2 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___171 *, s32);
	struct dev_pm_qos___12 *qos;
};

struct device_private___2;

struct device_type___171;

struct bus_type___171;

struct device_driver___171;

struct dev_pm_domain___171;

struct dma_map_ops___11;

struct io_tlb_mem___5;

struct device_node___72;

struct class___171;

struct device___171 {
	struct kobject___193 kobj;
	struct device___171 *parent;
	struct device_private___2 *p;
	const char *init_name;
	const struct device_type___171 *type;
	struct bus_type___171 *bus;
	struct device_driver___171 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___171 power;
	struct dev_pm_domain___171 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___44 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___11 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem___5 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___72 *of_node;
	struct fwnode_handle___171 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___171 *class;
	const struct attribute_group___193 **groups;
	void (*release)(struct device___171 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_link {
	struct fwnode_handle___171 *supplier;
	struct list_head s_hook;
	struct fwnode_handle___171 *consumer;
	struct list_head c_hook;
};

struct fwnode_endpoint___171 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___171 *local_fwnode;
};

struct fwnode_reference_args___171 {
	struct fwnode_handle___171 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___54 {
	char *name;
	int length;
	void *value;
	struct property___54 *next;
	long unsigned int _flags;
	struct bin_attribute___193 attr;
};

struct device_node___72 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___171 fwnode;
	struct property___54 *properties;
	struct property___54 *deadprops;
	struct device_node___72 *parent;
	struct device_node___72 *child;
	struct device_node___72 *sibling;
	struct kobject___193 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___42 {
	struct fwnode_handle___171 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___44 {
	int (*match)(struct irq_domain___44 *, struct device_node___72 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___44 *, struct irq_fwspec___42 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___44 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___44 *, unsigned int);
	int (*xlate)(struct irq_domain___44 *, struct device_node___72 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___44 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___44 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___44 *, struct irq_data___45 *, bool);
	void (*deactivate)(struct irq_domain___44 *, struct irq_data___45 *);
	int (*translate)(struct irq_domain___44 *, struct irq_fwspec___42 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___44;

struct irq_domain___44 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___44 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___171 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___44 *gc;
	struct irq_domain___44 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___45 *revmap[0];
};

struct irq_chip_generic___44;

struct irq_domain_chip_generic___44 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___44 *gc[0];
};

struct dev_pm_ops___171 {
	int (*prepare)(struct device___171 *);
	void (*complete)(struct device___171 *);
	int (*suspend)(struct device___171 *);
	int (*resume)(struct device___171 *);
	int (*freeze)(struct device___171 *);
	int (*thaw)(struct device___171 *);
	int (*poweroff)(struct device___171 *);
	int (*restore)(struct device___171 *);
	int (*suspend_late)(struct device___171 *);
	int (*resume_early)(struct device___171 *);
	int (*freeze_late)(struct device___171 *);
	int (*thaw_early)(struct device___171 *);
	int (*poweroff_late)(struct device___171 *);
	int (*restore_early)(struct device___171 *);
	int (*suspend_noirq)(struct device___171 *);
	int (*resume_noirq)(struct device___171 *);
	int (*freeze_noirq)(struct device___171 *);
	int (*thaw_noirq)(struct device___171 *);
	int (*poweroff_noirq)(struct device___171 *);
	int (*restore_noirq)(struct device___171 *);
	int (*runtime_suspend)(struct device___171 *);
	int (*runtime_resume)(struct device___171 *);
	int (*runtime_idle)(struct device___171 *);
};

struct wakeup_source___171 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___2 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___171 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___2 {
	struct device___171 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___12;

struct dev_pm_qos___12 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___12 *resume_latency_req;
	struct dev_pm_qos_request___12 *latency_tolerance_req;
	struct dev_pm_qos_request___12 *flags_req;
};

struct dev_pm_domain___171 {
	struct dev_pm_ops___171 ops;
	int (*start)(struct device___171 *);
	void (*detach)(struct device___171 *, bool);
	int (*activate)(struct device___171 *);
	void (*sync)(struct device___171 *);
	void (*dismiss)(struct device___171 *);
};

enum dpm_order {
	DPM_ORDER_NONE = 0,
	DPM_ORDER_DEV_AFTER_PARENT = 1,
	DPM_ORDER_PARENT_BEFORE_DEV = 2,
	DPM_ORDER_DEV_LAST = 3,
};

struct subsys_private___2;

struct bus_type___171 {
	const char *name;
	const char *dev_name;
	struct device___171 *dev_root;
	const struct attribute_group___193 **bus_groups;
	const struct attribute_group___193 **dev_groups;
	const struct attribute_group___193 **drv_groups;
	int (*match)(struct device___171 *, struct device_driver___171 *);
	int (*uevent)(struct device___171 *, struct kobj_uevent_env *);
	int (*probe)(struct device___171 *);
	void (*sync_state)(struct device___171 *);
	void (*remove)(struct device___171 *);
	void (*shutdown)(struct device___171 *);
	int (*online)(struct device___171 *);
	int (*offline)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	int (*num_vf)(struct device___171 *);
	int (*dma_configure)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___2 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___2;

struct device_driver___171 {
	const char *name;
	struct bus_type___171 *bus;
	struct module___189 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___171 *);
	void (*sync_state)(struct device___171 *);
	int (*remove)(struct device___171 *);
	void (*shutdown)(struct device___171 *);
	int (*suspend)(struct device___171 *, pm_message_t);
	int (*resume)(struct device___171 *);
	const struct attribute_group___193 **groups;
	const struct attribute_group___193 **dev_groups;
	const struct dev_pm_ops___171 *pm;
	void (*coredump)(struct device___171 *);
	struct driver_private___2 *p;
};

struct subsys_private___2 {
	struct kset___193 subsys;
	struct kset___193 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___193 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___171 *bus;
	struct kset___193 glue_dirs;
	struct class___171 *class;
};

struct device_type___171 {
	const char *name;
	const struct attribute_group___193 **groups;
	int (*uevent)(struct device___171 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___171 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___171 *);
	const struct dev_pm_ops___171 *pm;
};

struct class___171 {
	const char *name;
	struct module___189 *owner;
	const struct attribute_group___193 **class_groups;
	const struct attribute_group___193 **dev_groups;
	struct kobject___193 *dev_kobj;
	int (*dev_uevent)(struct device___171 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___171 *, umode_t *);
	void (*class_release)(struct class___171 *);
	void (*dev_release)(struct device___171 *);
	int (*shutdown_pre)(struct device___171 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___171 *);
	void (*get_ownership)(struct device___171 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___171 *pm;
	struct subsys_private___2 *p;
};

struct class_interface___2 {
	struct list_head node;
	struct class___171 *class;
	int (*add_dev)(struct device___171 *, struct class_interface___2 *);
	void (*remove_dev)(struct device___171 *, struct class_interface___2 *);
};

struct driver_private___2 {
	struct kobject___193 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___189 *mkobj;
	struct device_driver___171 *driver;
};

struct device_attribute___19 {
	struct attribute attr;
	ssize_t (*show)(struct device___171 *, struct device_attribute___19 *, char *);
	ssize_t (*store)(struct device___171 *, struct device_attribute___19 *, const char *, size_t);
};

struct dev_ext_attribute___2 {
	struct device_attribute___19 attr;
	void *var;
};

typedef void (*dr_release_t___21)(struct device___171 *, void *);

typedef int (*dr_match_t___18)(struct device___171 *, void *, void *);

struct device_private___2 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___171 *async_driver;
	char *deferred_probe_reason;
	struct device___171 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___11 {
	void * (*alloc)(struct device___171 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___171 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___210 * (*alloc_pages)(struct device___171 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___171 *, size_t, struct page___210 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___171 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___171 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___171 *, struct vm_area_struct___210 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___171 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___171 *, struct page___210 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___171 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___171 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___171 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___171 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___171 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___171 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___171 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___171 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___171 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___171 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___171 *, u64);
	u64 (*get_required_mask)(struct device___171 *);
	size_t (*max_mapping_size)(struct device___171 *);
	long unsigned int (*get_merge_boundary)(struct device___171 *);
};

struct io_tlb_mem___5 {
	phys_addr_t start;
	phys_addr_t end;
	long unsigned int nslabs;
	long unsigned int used;
	unsigned int index;
	spinlock_t lock;
	struct dentry___205 *debugfs;
	bool late_alloc;
	bool force_bounce;
	bool for_alloc;
	struct io_tlb_slot *slots;
};

struct device_link___16 {
	struct device___171 *supplier;
	struct list_head s_node;
	struct device___171 *consumer;
	struct list_head c_node;
	struct device___171 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct dentry_operations___205;

struct dentry___205 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___205 *d_parent;
	struct qstr d_name;
	struct inode___205 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___205 *d_op;
	struct super_block___205 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___205;

struct cdev___51;

struct inode___205 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___205 *i_op;
	struct super_block___205 *i_sb;
	struct address_space___205 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___206 *i_fop;
		void (*free_inode)(struct inode___205 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___205 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___67 *i_pipe;
		struct cdev___51 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___205 {
	int (*d_revalidate)(struct dentry___205 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___205 *, unsigned int);
	int (*d_hash)(const struct dentry___205 *, struct qstr *);
	int (*d_compare)(const struct dentry___205 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___205 *);
	int (*d_init)(struct dentry___205 *);
	void (*d_release)(struct dentry___205 *);
	void (*d_prune)(struct dentry___205 *);
	void (*d_iput)(struct dentry___205 *, struct inode___205 *);
	char * (*d_dname)(struct dentry___205 *, char *, int);
	struct vfsmount___205 * (*d_automount)(struct path___205 *);
	int (*d_manage)(const struct path___205 *, bool);
	struct dentry___205 * (*d_real)(struct dentry___205 *, const struct inode___205 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___205;

struct mem_dqinfo___205 {
	struct quota_format_type___205 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___205;

struct quota_info___205 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___205 *files[3];
	struct mem_dqinfo___205 info[3];
	const struct quota_format_ops___205 *ops[3];
};

struct rcuwait___206 {
	struct task_struct___212 *task;
};

struct percpu_rw_semaphore___206 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___206 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___205 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___206 rw_sem[3];
};

struct super_operations___205;

struct dquot_operations___205;

struct quotactl_ops___205;

struct block_device___107;

struct super_block___205 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___205 *s_type;
	const struct super_operations___205 *s_op;
	const struct dquot_operations___205 *dq_op;
	const struct quotactl_ops___205 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___205 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___107 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___205 s_dquot;
	struct sb_writers___205 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___205 *s_d_op;
	int cleancache_poolid;
	struct shrinker___89 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___205 {
	struct dentry___205 *mnt_root;
	struct super_block___205 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct cgroup_subsys___141;

struct cgroup_subsys_state___141 {
	struct cgroup___141 *cgroup;
	struct cgroup_subsys___141 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___141 *parent;
};

struct cgroup_file___141 {
	struct kernfs_node___193 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___141 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___212 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___141;

struct cgroup_rstat_cpu___141;

struct cgroup___141 {
	struct cgroup_subsys_state___141 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___193 *kn;
	struct cgroup_file___141 procs_file;
	struct cgroup_file___141 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___141 *subsys[14];
	struct cgroup_root___141 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___141 *dom_cgrp;
	struct cgroup___141 *old_dom_cgrp;
	struct cgroup_rstat_cpu___141 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___141 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___205 {
	struct file___205 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___205 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___99 *ki_waitq;
	};
};

struct iattr___205 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___205 *ia_file;
};

struct dquot___205 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___205 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___205 {
	int qf_fmt_id;
	const struct quota_format_ops___205 *qf_ops;
	struct module___189 *qf_owner;
	struct quota_format_type___205 *qf_next;
};

struct quota_format_ops___205 {
	int (*check_quota_file)(struct super_block___205 *, int);
	int (*read_file_info)(struct super_block___205 *, int);
	int (*write_file_info)(struct super_block___205 *, int);
	int (*free_file_info)(struct super_block___205 *, int);
	int (*read_dqblk)(struct dquot___205 *);
	int (*commit_dqblk)(struct dquot___205 *);
	int (*release_dqblk)(struct dquot___205 *);
	int (*get_next_id)(struct super_block___205 *, struct kqid *);
};

struct dquot_operations___205 {
	int (*write_dquot)(struct dquot___205 *);
	struct dquot___205 * (*alloc_dquot)(struct super_block___205 *, int);
	void (*destroy_dquot)(struct dquot___205 *);
	int (*acquire_dquot)(struct dquot___205 *);
	int (*release_dquot)(struct dquot___205 *);
	int (*mark_dirty)(struct dquot___205 *);
	int (*write_info)(struct super_block___205 *, int);
	qsize_t * (*get_reserved_space)(struct inode___205 *);
	int (*get_projid)(struct inode___205 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___205 *, qsize_t *);
	int (*get_next_id)(struct super_block___205 *, struct kqid *);
};

struct quotactl_ops___205 {
	int (*quota_on)(struct super_block___205 *, int, int, const struct path___205 *);
	int (*quota_off)(struct super_block___205 *, int);
	int (*quota_enable)(struct super_block___205 *, unsigned int);
	int (*quota_disable)(struct super_block___205 *, unsigned int);
	int (*quota_sync)(struct super_block___205 *, int);
	int (*set_info)(struct super_block___205 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___205 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___205 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___205 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___205 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___205 *, unsigned int);
};

struct address_space_operations___205 {
	int (*writepage)(struct page___210 *, struct writeback_control___3 *);
	int (*readpage)(struct file___205 *, struct page___210 *);
	int (*writepages)(struct address_space___205 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___210 *);
	int (*readpages)(struct file___205 *, struct address_space___205 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___205 *, struct address_space___205 *, loff_t, unsigned int, unsigned int, struct page___210 **, void **);
	int (*write_end)(struct file___205 *, struct address_space___205 *, loff_t, unsigned int, unsigned int, struct page___210 *, void *);
	sector_t (*bmap)(struct address_space___205 *, sector_t);
	void (*invalidatepage)(struct page___210 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___210 *, gfp_t);
	void (*freepage)(struct page___210 *);
	ssize_t (*direct_IO)(struct kiocb___205 *, struct iov_iter___126 *);
	int (*migratepage)(struct address_space___205 *, struct page___210 *, struct page___210 *, enum migrate_mode);
	bool (*isolate_page)(struct page___210 *, isolate_mode_t);
	void (*putback_page)(struct page___210 *);
	int (*launder_page)(struct page___210 *);
	int (*is_partially_uptodate)(struct page___210 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___210 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___205 *, struct page___210 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___205 *, sector_t *);
	void (*swap_deactivate)(struct file___205 *);
};

struct bio_vec___123;

struct iov_iter___126 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___123 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___67 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___51 {
	struct kobject___193 kobj;
	struct module___189 *owner;
	const struct file_operations___206 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___205 {
	struct dentry___205 * (*lookup)(struct inode___205 *, struct dentry___205 *, unsigned int);
	const char * (*get_link)(struct dentry___205 *, struct inode___205 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___205 *, int);
	struct posix_acl * (*get_acl)(struct inode___205 *, int, bool);
	int (*readlink)(struct dentry___205 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___205 *, struct dentry___205 *, umode_t, bool);
	int (*link)(struct dentry___205 *, struct inode___205 *, struct dentry___205 *);
	int (*unlink)(struct inode___205 *, struct dentry___205 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___205 *, struct dentry___205 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___205 *, struct dentry___205 *, umode_t);
	int (*rmdir)(struct inode___205 *, struct dentry___205 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___205 *, struct dentry___205 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___205 *, struct dentry___205 *, struct inode___205 *, struct dentry___205 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___205 *, struct iattr___205 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___205 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___205 *, char *, size_t);
	int (*fiemap)(struct inode___205 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___205 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___205 *, struct dentry___205 *, struct file___205 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___205 *, struct dentry___205 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___205 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___205 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___205 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___205 {
	void (*fl_copy_lock)(struct file_lock___205 *, struct file_lock___205 *);
	void (*fl_release_private)(struct file_lock___205 *);
};

struct lock_manager_operations___205;

struct file_lock___205 {
	struct file_lock___205 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___205 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___205 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___205 *fl_ops;
	const struct lock_manager_operations___205 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___205 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___205 *);
	int (*lm_grant)(struct file_lock___205 *, int);
	bool (*lm_break)(struct file_lock___205 *);
	int (*lm_change)(struct file_lock___205 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___205 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___205 *);
};

struct fasync_struct___205 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___205 *fa_next;
	struct file___205 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___205 {
	struct inode___205 * (*alloc_inode)(struct super_block___205 *);
	void (*destroy_inode)(struct inode___205 *);
	void (*free_inode)(struct inode___205 *);
	void (*dirty_inode)(struct inode___205 *, int);
	int (*write_inode)(struct inode___205 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___205 *);
	void (*evict_inode)(struct inode___205 *);
	void (*put_super)(struct super_block___205 *);
	int (*sync_fs)(struct super_block___205 *, int);
	int (*freeze_super)(struct super_block___205 *);
	int (*freeze_fs)(struct super_block___205 *);
	int (*thaw_super)(struct super_block___205 *);
	int (*unfreeze_fs)(struct super_block___205 *);
	int (*statfs)(struct dentry___205 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___205 *, int *, char *);
	void (*umount_begin)(struct super_block___205 *);
	int (*show_options)(struct seq_file___181 *, struct dentry___205 *);
	int (*show_devname)(struct seq_file___181 *, struct dentry___205 *);
	int (*show_path)(struct seq_file___181 *, struct dentry___205 *);
	int (*show_stats)(struct seq_file___181 *, struct dentry___205 *);
	ssize_t (*quota_read)(struct super_block___205 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___205 *, int, const char *, size_t, loff_t);
	struct dquot___205 ** (*get_dquots)(struct inode___205 *);
	long int (*nr_cached_objects)(struct super_block___205 *, struct shrink_control___89 *);
	long int (*free_cached_objects)(struct super_block___205 *, struct shrink_control___89 *);
	struct file___205 * (*real_loop)(struct file___205 *);
};

struct gendisk___107;

struct block_device___107 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___205 *bd_inode;
	struct super_block___205 *bd_super;
	void *bd_claiming;
	struct device___171 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___193 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___107 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___205 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct kernel_param_ops___189 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___189 *);
	int (*get)(char *, const struct kernel_param___189 *);
	void (*free)(void *);
};

struct kparam_array___189;

struct kernel_param___189 {
	const char *name;
	struct module___189 *mod;
	const struct kernel_param_ops___189 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___189 *arr;
	};
};

struct kparam_array___189 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___189 *ops;
	void *elem;
};

struct module_attribute___189 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___189 *, struct module_kobject___189 *, char *);
	ssize_t (*store)(struct module_attribute___189 *, struct module_kobject___189 *, const char *, size_t);
	void (*setup)(struct module___189 *, const char *);
	int (*test)(struct module___189 *);
	void (*free)(struct module___189 *);
};

struct acpi_device___12;

struct acpi_hotplug_profile___12 {
	struct kobject___193 kobj;
	int (*scan_dependent)(struct acpi_device___12 *);
	void (*notify_online)(struct acpi_device___12 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___12 {
	void (*func)(struct acpi_device_wakeup_context___12 *);
	struct device___171 *dev;
};

struct acpi_device_wakeup___12 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___12 context;
	struct wakeup_source___171 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___12;

struct acpi_hotplug_context___12;

struct acpi_driver___12;

struct acpi_device___12 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___171 fwnode;
	struct acpi_device___12 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___12 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___12 *handler;
	struct acpi_hotplug_context___12 *hp;
	struct acpi_driver___12 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___171 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___12 *);
};

struct acpi_scan_handler___12 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___12 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___12 *);
	void (*bind)(struct device___171 *);
	void (*unbind)(struct device___171 *);
	struct acpi_hotplug_profile___12 hotplug;
};

struct acpi_hotplug_context___12 {
	struct acpi_device___12 *self;
	int (*notify)(struct acpi_device___12 *, u32);
	void (*uevent)(struct acpi_device___12 *, u32);
	void (*fixup)(struct acpi_device___12 *);
};

typedef int (*acpi_op_add___12)(struct acpi_device___12 *);

typedef int (*acpi_op_remove___12)(struct acpi_device___12 *);

typedef void (*acpi_op_notify___12)(struct acpi_device___12 *, u32);

struct acpi_device_ops___12 {
	acpi_op_add___12 add;
	acpi_op_remove___12 remove;
	acpi_op_notify___12 notify;
};

struct acpi_driver___12 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___12 ops;
	struct device_driver___171 drv;
	struct module___189 *owner;
};

struct irq_chip___45 {
	struct device___171 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___45 *);
	void (*irq_shutdown)(struct irq_data___45 *);
	void (*irq_enable)(struct irq_data___45 *);
	void (*irq_disable)(struct irq_data___45 *);
	void (*irq_ack)(struct irq_data___45 *);
	void (*irq_mask)(struct irq_data___45 *);
	void (*irq_mask_ack)(struct irq_data___45 *);
	void (*irq_unmask)(struct irq_data___45 *);
	void (*irq_eoi)(struct irq_data___45 *);
	int (*irq_set_affinity)(struct irq_data___45 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___45 *);
	int (*irq_set_type)(struct irq_data___45 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___45 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___45 *);
	void (*irq_bus_sync_unlock)(struct irq_data___45 *);
	void (*irq_cpu_online)(struct irq_data___45 *);
	void (*irq_cpu_offline)(struct irq_data___45 *);
	void (*irq_suspend)(struct irq_data___45 *);
	void (*irq_resume)(struct irq_data___45 *);
	void (*irq_pm_shutdown)(struct irq_data___45 *);
	void (*irq_calc_mask)(struct irq_data___45 *);
	void (*irq_print_chip)(struct irq_data___45 *, struct seq_file___181 *);
	int (*irq_request_resources)(struct irq_data___45 *);
	void (*irq_release_resources)(struct irq_data___45 *);
	void (*irq_compose_msi_msg)(struct irq_data___45 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___45 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___45 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___45 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___45 *, void *);
	void (*ipi_send_single)(struct irq_data___45 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___45 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___45 *);
	void (*irq_nmi_teardown)(struct irq_data___45 *);
	long unsigned int flags;
};

struct irqaction___31 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___31 *next;
	irq_handler_t thread_fn;
	struct task_struct___212 *thread;
	struct irqaction___31 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___44 {
	struct irq_chip___45 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___46 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___44 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___44 *);
	void (*resume)(struct irq_chip_generic___44 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___44 *domain;
	struct list_head list;
	struct irq_chip_type___44 chip_types[0];
};

struct seq_operations___181 {
	void * (*start)(struct seq_file___181 *, loff_t *);
	void (*stop)(struct seq_file___181 *, void *);
	void * (*next)(struct seq_file___181 *, void *, loff_t *);
	int (*show)(struct seq_file___181 *, void *);
};

struct dev_pagemap_ops___200 {
	void (*page_free)(struct page___210 *);
	void (*kill)(struct dev_pagemap___200 *);
	void (*cleanup)(struct dev_pagemap___200 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___200 *);
};

struct dev_pm_qos_request___12 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___171 *dev;
};

struct fqdir___42;

struct netns_ipv4___42 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___42 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___39;

struct sk_buff___38;

struct dst_ops___42 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___42 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___39 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___38 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___38 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___38 *);
	int (*local_out)(struct net___42 *, struct sock *, struct sk_buff___38 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___38 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___42 {
	struct dst_ops___42 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___42 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___42 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___42 *fqdir;
};

struct sk_buff_head___37 {
	struct sk_buff___38 *next;
	struct sk_buff___38 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___42 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___42 xfrm4_dst_ops;
	struct dst_ops___42 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___42 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___39 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___42 ipv4;
	struct netns_ipv6___42 ipv6;
	struct netns_ieee802154_lowpan___42 ieee802154_lowpan;
	struct netns_sctp___29 sctp;
	struct netns_nf___3 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___37 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___36 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___42 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___141 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___141 *root_cset;
};

struct bio_vec___123 {
	struct page___210 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct gendisk___107 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___107 *part0;
	const struct block_device_operations___81 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___193 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___193 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct sk_buff___38 {
	union {
		struct {
			struct sk_buff___38 *next;
			struct sk_buff___38 *prev;
			union {
				struct net_device___39 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___38 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___42;

struct fqdir___42 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___42 *f;
	struct net___42 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___42;

struct inet_frags___42 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___42 *, const void *);
	void (*destructor)(struct inet_frag_queue___42 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___42 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___38 *fragments_tail;
	struct sk_buff___38 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___42 *fqdir;
	struct callback_head rcu;
};

typedef rx_handler_result_t rx_handler_func_t___37(struct sk_buff___38 **);

typedef struct {
	struct net___42 *net;
} possible_net_t___37;

struct netdev_name_node___37;

struct net_device_ops___37;

struct xfrmdev_ops___37;

struct header_ops___37;

struct netdev_rx_queue___37;

struct netdev_queue___37;

struct dcbnl_rtnl_ops___37;

struct net_device___39 {
	char name[16];
	struct netdev_name_node___37 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___37 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___37 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___37 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___193 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___37 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___37 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___37 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___37 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___37 = 0,
		NETREG_REGISTERED___37 = 1,
		NETREG_UNREGISTERING___37 = 2,
		NETREG_UNREGISTERED___37 = 3,
		NETREG_RELEASED___37 = 4,
		NETREG_DUMMY___37 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___37 = 0,
		RTNL_LINK_INITIALIZING___37 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___39 *);
	struct netpoll_info *npinfo;
	possible_net_t___37 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___171 dev;
	const struct attribute_group___193 *sysfs_groups[4];
	const struct attribute_group___193 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___37 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___36 xdp_state[3];
	long: 64;
};

struct pipe_buf_operations___67;

struct pipe_buffer___67 {
	struct page___210 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___67 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___67 {
	int (*confirm)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
	void (*release)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
	bool (*try_steal)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
	bool (*get)(struct pipe_inode_info___67 *, struct pipe_buffer___67 *);
};

struct dcbnl_rtnl_ops___37 {
	int (*ieee_getets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___39 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___39 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___39 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___39 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___39 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___39 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___39 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___39 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___39 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___39 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___39 *);
	u8 (*setstate)(struct net_device___39 *, u8);
	void (*getpermhwaddr)(struct net_device___39 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___39 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___39 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___39 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___39 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___39 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___39 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___39 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___39 *, int, u8 *);
	void (*setpfccfg)(struct net_device___39 *, int, u8);
	void (*getpfccfg)(struct net_device___39 *, int, u8 *);
	u8 (*setall)(struct net_device___39 *);
	u8 (*getcap)(struct net_device___39 *, int, u8 *);
	int (*getnumtcs)(struct net_device___39 *, int, u8 *);
	int (*setnumtcs)(struct net_device___39 *, int, u8);
	u8 (*getpfcstate)(struct net_device___39 *);
	void (*setpfcstate)(struct net_device___39 *, u8);
	void (*getbcncfg)(struct net_device___39 *, int, u32 *);
	void (*setbcncfg)(struct net_device___39 *, int, u32);
	void (*getbcnrp)(struct net_device___39 *, int, u8 *);
	void (*setbcnrp)(struct net_device___39 *, int, u8);
	int (*setapp)(struct net_device___39 *, u8, u16, u8);
	int (*getapp)(struct net_device___39 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___39 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___39 *, int, u8);
	u8 (*getdcbx)(struct net_device___39 *);
	u8 (*setdcbx)(struct net_device___39 *, u8);
	int (*peer_getappinfo)(struct net_device___39 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___39 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___39 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___39 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___39 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___39 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___40;

typedef int (*bpf_iter_init_seq_priv_t___39)(void *, struct bpf_iter_aux_info___40 *);

struct bpf_map___40;

struct bpf_iter_aux_info___40 {
	struct bpf_map___40 *map;
};

struct bpf_iter_seq_info___39 {
	const struct seq_operations___181 *seq_ops;
	bpf_iter_init_seq_priv_t___39 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___40;

struct bpf_map_ops___39 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___40 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___40 *, struct file___205 *);
	void (*map_free)(struct bpf_map___40 *);
	int (*map_get_next_key)(struct bpf_map___40 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___40 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___40 *, void *);
	int (*map_lookup_batch)(struct bpf_map___40 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___40 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___40 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___40 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___40 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___40 *, void *);
	int (*map_update_elem)(struct bpf_map___40 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___40 *, void *);
	int (*map_push_elem)(struct bpf_map___40 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___40 *, void *);
	int (*map_peek_elem)(struct bpf_map___40 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___40 *, struct file___205 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___40 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___40 *, void *, struct seq_file___181 *);
	int (*map_check_btf)(const struct bpf_map___40 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___40 *, struct bpf_prog_aux___40 *);
	void (*map_poke_untrack)(struct bpf_map___40 *, struct bpf_prog_aux___40 *);
	void (*map_poke_run)(struct bpf_map___40 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___40 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___40 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___40 *, struct vm_area_struct___210 *);
	__poll_t (*map_poll)(struct bpf_map___40 *, struct file___205 *, struct poll_table_struct___135 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___40 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___40 *, const struct bpf_map___40 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___40 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___39 *iter_seq_info;
};

struct bpf_map___40 {
	const struct bpf_map_ops___39 *ops;
	struct bpf_map___40 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___39;

struct bpf_jit_poke_descriptor___39;

struct btf_mod_pair___39;

struct bpf_prog_offload___37;

struct bpf_prog_aux___40 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___39 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___39 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___36 *ops;
	struct bpf_map___40 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___39 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___40 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___37 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___37;

struct bpf_map_dev_ops___37 {
	int (*map_get_next_key)(struct bpf_offloaded_map___37 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___37 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___37 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___37 *, void *);
};

struct bpf_offloaded_map___37 {
	struct bpf_map___40 map;
	struct net_device___39 *netdev;
	const struct bpf_map_dev_ops___37 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___37 {
	struct bpf_prog *prog;
	struct net_device___39 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___39 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___189 *mod;
};

struct bpf_jit_poke_descriptor___39 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___40 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___39 {
	struct btf *btf;
	struct module___189 *module;
};

struct cftype___141;

struct cgroup_subsys___141 {
	struct cgroup_subsys_state___141 * (*css_alloc)(struct cgroup_subsys_state___141 *);
	int (*css_online)(struct cgroup_subsys_state___141 *);
	void (*css_offline)(struct cgroup_subsys_state___141 *);
	void (*css_released)(struct cgroup_subsys_state___141 *);
	void (*css_free)(struct cgroup_subsys_state___141 *);
	void (*css_reset)(struct cgroup_subsys_state___141 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___141 *, int);
	int (*css_extra_stat_show)(struct seq_file___181 *, struct cgroup_subsys_state___141 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___212 *, struct css_set___141 *);
	void (*cancel_fork)(struct task_struct___212 *, struct css_set___141 *);
	void (*fork)(struct task_struct___212 *);
	void (*exit)(struct task_struct___212 *);
	void (*release)(struct task_struct___212 *);
	void (*bind)(struct cgroup_subsys_state___141 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___141 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___141 *dfl_cftypes;
	struct cftype___141 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___141 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___141 *updated_children;
	struct cgroup___141 *updated_next;
};

struct cgroup_root___141 {
	struct kernfs_root___193 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___141 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___141 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___141 *ss;
	struct list_head node;
	struct kernfs_ops___193 *kf_ops;
	int (*open)(struct kernfs_open_file___193 *);
	void (*release)(struct kernfs_open_file___193 *);
	u64 (*read_u64)(struct cgroup_subsys_state___141 *, struct cftype___141 *);
	s64 (*read_s64)(struct cgroup_subsys_state___141 *, struct cftype___141 *);
	int (*seq_show)(struct seq_file___181 *, void *);
	void * (*seq_start)(struct seq_file___181 *, loff_t *);
	void * (*seq_next)(struct seq_file___181 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___181 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___141 *, struct cftype___141 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___141 *, struct cftype___141 *, s64);
	ssize_t (*write)(struct kernfs_open_file___193 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___193 *, struct poll_table_struct___135 *);
};

struct xdp_rxq_info___37 {
	struct net_device___39 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___37 {
	struct net_device___39 *dev;
};

struct xdp_buff___37 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___37 *rxq;
	struct xdp_txq_info___37 *txq;
	u32 frame_sz;
};

struct xdp_frame___37 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___39 *dev_rx;
};

struct netlink_callback___37 {
	struct sk_buff___38 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___38 *, struct netlink_callback___37 *);
	int (*done)(struct netlink_callback___37 *);
	void *data;
	struct module___189 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___37 {
	int (*create)(struct sk_buff___38 *, struct net_device___39 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___38 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___39 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___38 *);
};

struct netdev_queue___37 {
	struct net_device___39 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___193 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___39 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___37 {
	struct xdp_rxq_info___37 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___193 kobj;
	struct net_device___39 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___37 {
	enum net_device_path_type type;
	const struct net_device___39 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___37 = 0,
				DEV_PATH_BR_VLAN_TAG___37 = 1,
				DEV_PATH_BR_VLAN_UNTAG___37 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___37 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___37 {
	const struct net_device___39 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___37 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___36 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___37 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___37 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___38 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___37 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___39 *dev;
	const char *name;
};

struct net_device_ops___37 {
	int (*ndo_init)(struct net_device___39 *);
	void (*ndo_uninit)(struct net_device___39 *);
	int (*ndo_open)(struct net_device___39 *);
	int (*ndo_stop)(struct net_device___39 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___38 *, struct net_device___39 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___38 *, struct net_device___39 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___39 *, struct sk_buff___38 *, struct net_device___39 *);
	void (*ndo_change_rx_flags)(struct net_device___39 *, int);
	void (*ndo_set_rx_mode)(struct net_device___39 *);
	int (*ndo_set_mac_address)(struct net_device___39 *, void *);
	int (*ndo_validate_addr)(struct net_device___39 *);
	int (*ndo_do_ioctl)(struct net_device___39 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___39 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___39 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___39 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___39 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___39 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___39 *, int);
	int (*ndo_neigh_setup)(struct net_device___39 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___39 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___39 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___39 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___39 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___39 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___39 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___39 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___39 *);
	int (*ndo_netpoll_setup)(struct net_device___39 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___39 *);
	int (*ndo_set_vf_mac)(struct net_device___39 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___39 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___39 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___39 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___39 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___39 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___39 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___39 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___39 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___39 *, int, struct sk_buff___38 *);
	int (*ndo_get_vf_guid)(struct net_device___39 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___39 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___39 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___39 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___39 *);
	int (*ndo_fcoe_disable)(struct net_device___39 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___39 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___39 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___39 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___39 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___39 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___39 *, const struct sk_buff___38 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___39 *, struct net_device___39 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___39 *, struct net_device___39 *);
	struct net_device___39 * (*ndo_get_xmit_slave)(struct net_device___39 *, struct sk_buff___38 *, bool);
	struct net_device___39 * (*ndo_sk_get_lower_dev)(struct net_device___39 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___39 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___39 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___39 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___39 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___38 *, struct netlink_callback___37 *, struct net_device___39 *, struct net_device___39 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___38 *, struct nlattr **, struct net_device___39 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___39 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___38 *, u32, u32, struct net_device___39 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___39 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___39 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___39 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___39 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___39 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___39 *, struct net_device___39 *);
	void (*ndo_dfwd_del_station)(struct net_device___39 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___39 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___39 *);
	int (*ndo_change_proto_down)(struct net_device___39 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___39 *, struct sk_buff___38 *);
	void (*ndo_set_rx_headroom)(struct net_device___39 *, int);
	int (*ndo_bpf)(struct net_device___39 *, struct netdev_bpf___37 *);
	int (*ndo_xdp_xmit)(struct net_device___39 *, int, struct xdp_frame___37 **, u32);
	struct net_device___39 * (*ndo_xdp_get_xmit_slave)(struct net_device___39 *, struct xdp_buff___37 *);
	int (*ndo_xsk_wakeup)(struct net_device___39 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___39 *);
	int (*ndo_tunnel_ctl)(struct net_device___39 *, struct ip_tunnel_parm *, int);
	struct net_device___39 * (*ndo_get_peer_dev)(struct net_device___39 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___37 *, struct net_device_path___37 *);
};

union device_attr_group_devres {
	const struct attribute_group___193 *group;
	const struct attribute_group___193 **groups;
};

struct class_dir {
	struct kobject___193 kobj;
	struct class___171 *class;
};

struct root_device {
	struct device___171 dev;
	struct module___189 *owner;
};

struct wake_irq {
	struct device___154 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct subsys_private {
	struct kset___192 subsys;
	struct kset___192 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___192 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___154 *bus;
	struct kset___192 glue_dirs;
	struct class___154 *class;
};

struct bus_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct bus_type___154 *, char *);
	ssize_t (*store)(struct bus_type___154 *, const char *, size_t);
};

struct subsys_dev_iter {
	struct klist_iter ki;
	const struct device_type___154 *type;
};

struct driver_private {
	struct kobject___192 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___188 *mkobj;
	struct device_driver___154 *driver;
};

struct driver_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___154 *, char *);
	ssize_t (*store)(struct device_driver___154 *, const char *, size_t);
};

struct subsys_interface {
	const char *name;
	struct bus_type___154 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___154 *, struct subsys_interface *);
	void (*remove_dev)(struct device___154 *, struct subsys_interface *);
};

struct device_private {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___154 *async_driver;
	char *deferred_probe_reason;
	struct device___154 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wakeup_source___172;

struct wake_irq___3;

struct device___172;

struct dev_pm_qos___13;

struct dev_pm_info___172 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___172 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___3 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___172 *, s32);
	struct dev_pm_qos___13 *qos;
};

struct device_private___3;

struct device_type___172;

struct bus_type___172;

struct device_driver___172;

struct dev_pm_domain___172;

struct dma_map_ops___12;

struct fwnode_handle___172;

struct class___172;

struct device___172 {
	struct kobject___192 kobj;
	struct device___172 *parent;
	struct device_private___3 *p;
	const char *init_name;
	const struct device_type___172 *type;
	struct bus_type___172 *bus;
	struct device_driver___172 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___172 power;
	struct dev_pm_domain___172 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info___5 *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___12 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___172 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___172 *class;
	const struct attribute_group___192 **groups;
	void (*release)(struct device___172 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___172 {
	int (*prepare)(struct device___172 *);
	void (*complete)(struct device___172 *);
	int (*suspend)(struct device___172 *);
	int (*resume)(struct device___172 *);
	int (*freeze)(struct device___172 *);
	int (*thaw)(struct device___172 *);
	int (*poweroff)(struct device___172 *);
	int (*restore)(struct device___172 *);
	int (*suspend_late)(struct device___172 *);
	int (*resume_early)(struct device___172 *);
	int (*freeze_late)(struct device___172 *);
	int (*thaw_early)(struct device___172 *);
	int (*poweroff_late)(struct device___172 *);
	int (*restore_early)(struct device___172 *);
	int (*suspend_noirq)(struct device___172 *);
	int (*resume_noirq)(struct device___172 *);
	int (*freeze_noirq)(struct device___172 *);
	int (*thaw_noirq)(struct device___172 *);
	int (*poweroff_noirq)(struct device___172 *);
	int (*restore_noirq)(struct device___172 *);
	int (*runtime_suspend)(struct device___172 *);
	int (*runtime_resume)(struct device___172 *);
	int (*runtime_idle)(struct device___172 *);
};

struct wakeup_source___172 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___3 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___172 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___3 {
	struct device___172 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___13;

struct dev_pm_qos___13 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___13 *resume_latency_req;
	struct dev_pm_qos_request___13 *latency_tolerance_req;
	struct dev_pm_qos_request___13 *flags_req;
};

struct dev_pm_domain___172 {
	struct dev_pm_ops___172 ops;
	int (*start)(struct device___172 *);
	void (*detach)(struct device___172 *, bool);
	int (*activate)(struct device___172 *);
	void (*sync)(struct device___172 *);
	void (*dismiss)(struct device___172 *);
};

struct subsys_private___3;

struct bus_type___172 {
	const char *name;
	const char *dev_name;
	struct device___172 *dev_root;
	const struct attribute_group___192 **bus_groups;
	const struct attribute_group___192 **dev_groups;
	const struct attribute_group___192 **drv_groups;
	int (*match)(struct device___172 *, struct device_driver___172 *);
	int (*uevent)(struct device___172 *, struct kobj_uevent_env *);
	int (*probe)(struct device___172 *);
	void (*sync_state)(struct device___172 *);
	void (*remove)(struct device___172 *);
	void (*shutdown)(struct device___172 *);
	int (*online)(struct device___172 *);
	int (*offline)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	int (*num_vf)(struct device___172 *);
	int (*dma_configure)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___3 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___3;

struct device_driver___172 {
	const char *name;
	struct bus_type___172 *bus;
	struct module___188 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___172 *);
	void (*sync_state)(struct device___172 *);
	int (*remove)(struct device___172 *);
	void (*shutdown)(struct device___172 *);
	int (*suspend)(struct device___172 *, pm_message_t);
	int (*resume)(struct device___172 *);
	const struct attribute_group___192 **groups;
	const struct attribute_group___192 **dev_groups;
	const struct dev_pm_ops___172 *pm;
	void (*coredump)(struct device___172 *);
	struct driver_private___3 *p;
};

struct subsys_private___3 {
	struct kset___192 subsys;
	struct kset___192 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___192 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___172 *bus;
	struct kset___192 glue_dirs;
	struct class___172 *class;
};

struct device_type___172 {
	const char *name;
	const struct attribute_group___192 **groups;
	int (*uevent)(struct device___172 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___172 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___172 *);
	const struct dev_pm_ops___172 *pm;
};

struct class___172 {
	const char *name;
	struct module___188 *owner;
	const struct attribute_group___192 **class_groups;
	const struct attribute_group___192 **dev_groups;
	struct kobject___192 *dev_kobj;
	int (*dev_uevent)(struct device___172 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___172 *, umode_t *);
	void (*class_release)(struct class___172 *);
	void (*dev_release)(struct device___172 *);
	int (*shutdown_pre)(struct device___172 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___172 *);
	void (*get_ownership)(struct device___172 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___172 *pm;
	struct subsys_private___3 *p;
};

struct driver_private___3 {
	struct kobject___192 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___188 *mkobj;
	struct device_driver___172 *driver;
};

struct device_attribute___20 {
	struct attribute attr;
	ssize_t (*show)(struct device___172 *, struct device_attribute___20 *, char *);
	ssize_t (*store)(struct device___172 *, struct device_attribute___20 *, const char *, size_t);
};

struct device_private___3 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___172 *async_driver;
	char *deferred_probe_reason;
	struct device___172 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dma_map_ops___12 {
	void * (*alloc)(struct device___172 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___172 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___209 * (*alloc_pages)(struct device___172 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___172 *, size_t, struct page___209 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___172 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___172 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___172 *, struct vm_area_struct___209 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___172 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___172 *, struct page___209 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___172 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___172 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___172 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___172 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___172 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___172 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___172 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___172 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___172 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___172 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___172 *, u64);
	u64 (*get_required_mask)(struct device___172 *);
	size_t (*max_mapping_size)(struct device___172 *);
	long unsigned int (*get_merge_boundary)(struct device___172 *);
};

struct fwnode_operations___172;

struct fwnode_handle___172 {
	struct fwnode_handle___172 *secondary;
	const struct fwnode_operations___172 *ops;
	struct device___172 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___172;

struct fwnode_endpoint___172;

struct fwnode_operations___172 {
	struct fwnode_handle___172 * (*get)(struct fwnode_handle___172 *);
	void (*put)(struct fwnode_handle___172 *);
	bool (*device_is_available)(const struct fwnode_handle___172 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___172 *, const struct device___172 *);
	bool (*property_present)(const struct fwnode_handle___172 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___172 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___172 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___172 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*get_parent)(const struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*get_next_child_node)(const struct fwnode_handle___172 *, struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*get_named_child_node)(const struct fwnode_handle___172 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___172 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___172 *);
	struct fwnode_handle___172 * (*graph_get_next_endpoint)(const struct fwnode_handle___172 *, struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*graph_get_remote_endpoint)(const struct fwnode_handle___172 *);
	struct fwnode_handle___172 * (*graph_get_port_parent)(struct fwnode_handle___172 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___172 *, struct fwnode_endpoint___172 *);
	int (*add_links)(struct fwnode_handle___172 *);
};

struct fwnode_endpoint___172 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___172 *local_fwnode;
};

struct fwnode_reference_args___172 {
	struct fwnode_handle___172 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_qos_request___13 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___172 *dev;
};

struct device_attach_data {
	struct device___172 *dev;
	bool check_async;
	bool want_async;
	bool have_async;
};

struct device___173;

struct dev_pm_ops___173 {
	int (*prepare)(struct device___173 *);
	void (*complete)(struct device___173 *);
	int (*suspend)(struct device___173 *);
	int (*resume)(struct device___173 *);
	int (*freeze)(struct device___173 *);
	int (*thaw)(struct device___173 *);
	int (*poweroff)(struct device___173 *);
	int (*restore)(struct device___173 *);
	int (*suspend_late)(struct device___173 *);
	int (*resume_early)(struct device___173 *);
	int (*freeze_late)(struct device___173 *);
	int (*thaw_early)(struct device___173 *);
	int (*poweroff_late)(struct device___173 *);
	int (*restore_early)(struct device___173 *);
	int (*suspend_noirq)(struct device___173 *);
	int (*resume_noirq)(struct device___173 *);
	int (*freeze_noirq)(struct device___173 *);
	int (*thaw_noirq)(struct device___173 *);
	int (*poweroff_noirq)(struct device___173 *);
	int (*restore_noirq)(struct device___173 *);
	int (*runtime_suspend)(struct device___173 *);
	int (*runtime_resume)(struct device___173 *);
	int (*runtime_idle)(struct device___173 *);
};

struct wakeup_source___173;

struct dev_pm_info___173 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___173 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___173 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___4;

struct device_type___173;

struct bus_type___173;

struct device_driver___173;

struct dev_pm_domain___173;

struct class___173;

struct device___173 {
	struct kobject___190 kobj;
	struct device___173 *parent;
	struct device_private___4 *p;
	const char *init_name;
	const struct device_type___173 *type;
	struct bus_type___173 *bus;
	struct device_driver___173 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___173 power;
	struct dev_pm_domain___173 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___7 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___173 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___173 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wakeup_source___173 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___173 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___173 {
	struct dev_pm_ops___173 ops;
	int (*start)(struct device___173 *);
	void (*detach)(struct device___173 *, bool);
	int (*activate)(struct device___173 *);
	void (*sync)(struct device___173 *);
	void (*dismiss)(struct device___173 *);
};

struct subsys_private___4;

struct bus_type___173 {
	const char *name;
	const char *dev_name;
	struct device___173 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___173 *, struct device_driver___173 *);
	int (*uevent)(struct device___173 *, struct kobj_uevent_env *);
	int (*probe)(struct device___173 *);
	void (*sync_state)(struct device___173 *);
	void (*remove)(struct device___173 *);
	void (*shutdown)(struct device___173 *);
	int (*online)(struct device___173 *);
	int (*offline)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	int (*num_vf)(struct device___173 *);
	int (*dma_configure)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___4 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___4;

struct device_driver___173 {
	const char *name;
	struct bus_type___173 *bus;
	struct module___186 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___173 *);
	void (*sync_state)(struct device___173 *);
	int (*remove)(struct device___173 *);
	void (*shutdown)(struct device___173 *);
	int (*suspend)(struct device___173 *, pm_message_t);
	int (*resume)(struct device___173 *);
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	const struct dev_pm_ops___173 *pm;
	void (*coredump)(struct device___173 *);
	struct driver_private___4 *p;
};

struct subsys_private___4 {
	struct kset___190 subsys;
	struct kset___190 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___190 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___173 *bus;
	struct kset___190 glue_dirs;
	struct class___173 *class;
};

struct device_type___173 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___173 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___173 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___173 *);
	const struct dev_pm_ops___173 *pm;
};

struct driver_private___4 {
	struct kobject___190 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___186 *mkobj;
	struct device_driver___173 *driver;
};

struct driver_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct device_driver___173 *, char *);
	ssize_t (*store)(struct device_driver___173 *, const char *, size_t);
};

struct class___173 {
	const char *name;
	struct module___186 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___173 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___173 *, umode_t *);
	void (*class_release)(struct class___173 *);
	void (*dev_release)(struct device___173 *);
	int (*shutdown_pre)(struct device___173 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___173 *);
	void (*get_ownership)(struct device___173 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___173 *pm;
	struct subsys_private___4 *p;
};

struct device_private___4 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___173 *async_driver;
	char *deferred_probe_reason;
	struct device___173 *device;
	u8 dead;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___206;

struct super_block___206;

struct module___190;

struct file_system_type___206 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___206 * (*mount)(struct file_system_type___206 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___206 *);
	struct module___190 *owner;
	struct file_system_type___206 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___206;

struct kiocb___206;

struct iov_iter___127;

struct vm_area_struct___211;

struct inode___206;

struct file_lock___206;

struct page___211;

struct file_operations___207 {
	struct module___190 *owner;
	loff_t (*llseek)(struct file___206 *, loff_t, int);
	ssize_t (*read)(struct file___206 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___206 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___206 *, struct iov_iter___127 *);
	ssize_t (*write_iter)(struct kiocb___206 *, struct iov_iter___127 *);
	int (*iopoll)(struct kiocb___206 *, bool);
	int (*iterate)(struct file___206 *, struct dir_context *);
	int (*iterate_shared)(struct file___206 *, struct dir_context *);
	__poll_t (*poll)(struct file___206 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___206 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___206 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___206 *, struct vm_area_struct___211 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___206 *, struct file___206 *);
	int (*flush)(struct file___206 *, fl_owner_t);
	int (*release)(struct inode___206 *, struct file___206 *);
	int (*fsync)(struct file___206 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___206 *, int);
	int (*lock)(struct file___206 *, int, struct file_lock___206 *);
	ssize_t (*sendpage)(struct file___206 *, struct page___211 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___206 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___206 *, long unsigned int);
	int (*flock)(struct file___206 *, int, struct file_lock___206 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___206 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___206 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___206 *, long int, struct file_lock___206 **, void **);
	long int (*fallocate)(struct file___206 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___9 *, struct file___206 *);
	ssize_t (*copy_file_range)(struct file___206 *, loff_t, struct file___206 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___206 *, loff_t, struct file___206 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___206 *, loff_t, loff_t, int);
};

struct vmacache___211 {
	u64 seqnum;
	struct vm_area_struct___211 *vmas[4];
};

struct page_frag___211 {
	struct page___211 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___212;

struct pid___183;

struct nsproxy___192;

struct signal_struct___207;

struct vm_struct___189;

struct task_struct___213 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___213 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___212 *mm;
	struct mm_struct___212 *active_mm;
	struct vmacache___211 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___213 *real_parent;
	struct task_struct___213 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___213 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___183 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___192 *nsproxy;
	struct signal_struct___207 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___213 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___105 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___211 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___213 *oom_reaper_list;
	struct vm_struct___189 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___194;

struct kobj_type___194;

struct kernfs_node___194;

struct kobject___194 {
	const char *name;
	struct list_head entry;
	struct kobject___194 *parent;
	struct kset___194 *kset;
	struct kobj_type___194 *ktype;
	struct kernfs_node___194 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___190 {
	struct kobject___194 kobj;
	struct module___190 *mod;
	struct kobject___194 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___190 {
	struct module___190 *mod;
	struct latch_tree_node node;
};

struct module_layout___190 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___190 mtn;
};

struct module_attribute___190;

struct kernel_param___190;

struct module___190 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___190 mkobj;
	struct module_attribute___190 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___194 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___190 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___190 core_layout;
	struct module_layout___190 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___211 *pgtable_t___211;

struct address_space___206;

struct dev_pagemap___201;

struct page___211 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___206 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___55 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___211 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___211 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___212 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___201 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___201;

struct vm_area_struct___211 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___211 *vm_next;
	struct vm_area_struct___211 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___212 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___201 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___206 *vm_file;
	struct file___206 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___211;

struct mm_struct___212 {
	struct {
		struct vm_area_struct___211 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___206 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___211 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___213 *owner;
		struct user_namespace *user_ns;
		struct file___206 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___206;

struct address_space___206 {
	struct inode___206 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___206 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___201;

struct dev_pagemap___201 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___201 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___206;

struct path___206 {
	struct vfsmount___206 *mnt;
	struct dentry___206 *dentry;
};

struct fown_struct___183 {
	rwlock_t lock;
	struct pid___183 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___206 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___206 f_path;
	struct inode___206 *f_inode;
	const struct file_operations___207 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___183 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___206 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___201;

struct vm_operations_struct___201 {
	void (*open)(struct vm_area_struct___211 *);
	void (*close)(struct vm_area_struct___211 *);
	int (*may_split)(struct vm_area_struct___211 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___211 *);
	int (*mprotect)(struct vm_area_struct___211 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___201 *);
	vm_fault_t (*huge_fault)(struct vm_fault___201 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___201 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___211 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___201 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___201 *);
	int (*access)(struct vm_area_struct___211 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___211 *);
	int (*set_policy)(struct vm_area_struct___211 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___211 *, long unsigned int);
	struct page___211 * (*find_special_page)(struct vm_area_struct___211 *, long unsigned int);
};

struct core_thread___211 {
	struct task_struct___213 *task;
	struct core_thread___211 *next;
};

struct core_state___211 {
	atomic_t nr_threads;
	struct core_thread___211 dumper;
	struct completion startup;
};

struct vm_fault___201 {
	const struct {
		struct vm_area_struct___211 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___211 *cow_page;
	struct page___211 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___211 prealloc_pte;
};

struct kernfs_root___194;

struct kernfs_elem_dir___194 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___194 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___194;

struct kernfs_root___194 {
	struct kernfs_node___194 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___194 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___194 {
	struct kernfs_node___194 *target_kn;
};

struct kernfs_ops___194;

struct kernfs_elem_attr___194 {
	const struct kernfs_ops___194 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___194 *notify_next;
};

struct kernfs_node___194 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___194 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___194 dir;
		struct kernfs_elem_symlink___194 symlink;
		struct kernfs_elem_attr___194 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___194;

struct kernfs_ops___194 {
	int (*open)(struct kernfs_open_file___194 *);
	void (*release)(struct kernfs_open_file___194 *);
	int (*seq_show)(struct seq_file___9 *, void *);
	void * (*seq_start)(struct seq_file___9 *, loff_t *);
	void * (*seq_next)(struct seq_file___9 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___9 *, void *);
	ssize_t (*read)(struct kernfs_open_file___194 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___194 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___194 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___194 *, struct vm_area_struct___211 *);
};

struct kernfs_syscall_ops___194 {
	int (*show_options)(struct seq_file___9 *, struct kernfs_root___194 *);
	int (*mkdir)(struct kernfs_node___194 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___194 *);
	int (*rename)(struct kernfs_node___194 *, struct kernfs_node___194 *, const char *);
	int (*show_path)(struct seq_file___9 *, struct kernfs_node___194 *, struct kernfs_root___194 *);
};

struct kernfs_open_file___194 {
	struct kernfs_node___194 *kn;
	struct file___206 *file;
	struct seq_file___9 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___201 *vm_ops;
};

struct pid_namespace___183;

struct upid___183 {
	int nr;
	struct pid_namespace___183 *ns;
};

struct pid_namespace___183 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___213 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___183 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___183 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___183 numbers[1];
};

struct signal_struct___207 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___213 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___213 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___183 *pids[4];
	struct pid___183 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___212 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct nsproxy___192 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___183 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct vm_struct___189 {
	struct vm_struct___189 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___211 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___194;

struct attribute_group___194 {
	const char *name;
	umode_t (*is_visible)(struct kobject___194 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___194 *, struct bin_attribute___194 *, int);
	struct attribute **attrs;
	struct bin_attribute___194 **bin_attrs;
};

struct bin_attribute___194 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___206 * (*f_mapping)();
	ssize_t (*read)(struct file___206 *, struct kobject___194 *, struct bin_attribute___194 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___206 *, struct kobject___194 *, struct bin_attribute___194 *, char *, loff_t, size_t);
	int (*mmap)(struct file___206 *, struct kobject___194 *, struct bin_attribute___194 *, struct vm_area_struct___211 *);
};

struct sysfs_ops___194 {
	ssize_t (*show)(struct kobject___194 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___194 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___194;

struct kset___194 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___194 kobj;
	const struct kset_uevent_ops___194 *uevent_ops;
};

struct kobj_type___194 {
	void (*release)(struct kobject___194 *);
	const struct sysfs_ops___194 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___194 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___194 *);
	const void * (*namespace)(struct kobject___194 *);
	void (*get_ownership)(struct kobject___194 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___194 {
	int (* const filter)(struct kset___194 *, struct kobject___194 *);
	const char * (* const name)(struct kset___194 *, struct kobject___194 *);
	int (* const uevent)(struct kset___194 *, struct kobject___194 *, struct kobj_uevent_env *);
};

struct device___174;

struct dev_pm_ops___174 {
	int (*prepare)(struct device___174 *);
	void (*complete)(struct device___174 *);
	int (*suspend)(struct device___174 *);
	int (*resume)(struct device___174 *);
	int (*freeze)(struct device___174 *);
	int (*thaw)(struct device___174 *);
	int (*poweroff)(struct device___174 *);
	int (*restore)(struct device___174 *);
	int (*suspend_late)(struct device___174 *);
	int (*resume_early)(struct device___174 *);
	int (*freeze_late)(struct device___174 *);
	int (*thaw_early)(struct device___174 *);
	int (*poweroff_late)(struct device___174 *);
	int (*restore_early)(struct device___174 *);
	int (*suspend_noirq)(struct device___174 *);
	int (*resume_noirq)(struct device___174 *);
	int (*freeze_noirq)(struct device___174 *);
	int (*thaw_noirq)(struct device___174 *);
	int (*poweroff_noirq)(struct device___174 *);
	int (*restore_noirq)(struct device___174 *);
	int (*runtime_suspend)(struct device___174 *);
	int (*runtime_resume)(struct device___174 *);
	int (*runtime_idle)(struct device___174 *);
};

struct wakeup_source___174;

struct dev_pm_info___174 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___174 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___5 *subsys_data;
	void (*set_latency_tolerance)(struct device___174 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___5;

struct device_type___174;

struct bus_type___174;

struct device_driver___174;

struct dev_pm_domain___174;

struct fwnode_handle___173;

struct class___174;

struct device___174 {
	struct kobject___194 kobj;
	struct device___174 *parent;
	struct device_private___5 *p;
	const char *init_name;
	const struct device_type___174 *type;
	struct bus_type___174 *bus;
	struct device_driver___174 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___174 power;
	struct dev_pm_domain___174 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___173 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___174 *class;
	const struct attribute_group___194 **groups;
	void (*release)(struct device___174 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wakeup_source___174 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___174 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___174 {
	struct dev_pm_ops___174 ops;
	int (*start)(struct device___174 *);
	void (*detach)(struct device___174 *, bool);
	int (*activate)(struct device___174 *);
	void (*sync)(struct device___174 *);
	void (*dismiss)(struct device___174 *);
};

struct subsys_private___5;

struct bus_type___174 {
	const char *name;
	const char *dev_name;
	struct device___174 *dev_root;
	const struct attribute_group___194 **bus_groups;
	const struct attribute_group___194 **dev_groups;
	const struct attribute_group___194 **drv_groups;
	int (*match)(struct device___174 *, struct device_driver___174 *);
	int (*uevent)(struct device___174 *, struct kobj_uevent_env *);
	int (*probe)(struct device___174 *);
	void (*sync_state)(struct device___174 *);
	void (*remove)(struct device___174 *);
	void (*shutdown)(struct device___174 *);
	int (*online)(struct device___174 *);
	int (*offline)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	int (*num_vf)(struct device___174 *);
	int (*dma_configure)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___5 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___5;

struct device_driver___174 {
	const char *name;
	struct bus_type___174 *bus;
	struct module___190 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___174 *);
	void (*sync_state)(struct device___174 *);
	int (*remove)(struct device___174 *);
	void (*shutdown)(struct device___174 *);
	int (*suspend)(struct device___174 *, pm_message_t);
	int (*resume)(struct device___174 *);
	const struct attribute_group___194 **groups;
	const struct attribute_group___194 **dev_groups;
	const struct dev_pm_ops___174 *pm;
	void (*coredump)(struct device___174 *);
	struct driver_private___5 *p;
};

struct subsys_private___5 {
	struct kset___194 subsys;
	struct kset___194 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___194 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___174 *bus;
	struct kset___194 glue_dirs;
	struct class___174 *class;
};

struct device_type___174 {
	const char *name;
	const struct attribute_group___194 **groups;
	int (*uevent)(struct device___174 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___174 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___174 *);
	const struct dev_pm_ops___174 *pm;
};

struct class___174 {
	const char *name;
	struct module___190 *owner;
	const struct attribute_group___194 **class_groups;
	const struct attribute_group___194 **dev_groups;
	struct kobject___194 *dev_kobj;
	int (*dev_uevent)(struct device___174 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___174 *, umode_t *);
	void (*class_release)(struct class___174 *);
	void (*dev_release)(struct device___174 *);
	int (*shutdown_pre)(struct device___174 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___174 *);
	void (*get_ownership)(struct device___174 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___174 *pm;
	struct subsys_private___5 *p;
};

struct class_dev_iter___3 {
	struct klist_iter ki;
	const struct device_type___174 *type;
};

struct class_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct class___174 *, struct class_attribute___2 *, char *);
	ssize_t (*store)(struct class___174 *, struct class_attribute___2 *, const char *, size_t);
};

struct class_attribute_string {
	struct class_attribute___2 attr;
	char *str;
};

struct class_interface___3 {
	struct list_head node;
	struct class___174 *class;
	int (*add_dev)(struct device___174 *, struct class_interface___3 *);
	void (*remove_dev)(struct device___174 *, struct class_interface___3 *);
};

struct driver_private___5 {
	struct kobject___194 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___190 *mkobj;
	struct device_driver___174 *driver;
};

struct device_private___5 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___174 *async_driver;
	char *deferred_probe_reason;
	struct device___174 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___173;

struct fwnode_handle___173 {
	struct fwnode_handle___173 *secondary;
	const struct fwnode_operations___173 *ops;
	struct device___174 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dentry_operations___206;

struct dentry___206 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___206 *d_parent;
	struct qstr d_name;
	struct inode___206 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___206 *d_op;
	struct super_block___206 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___206;

struct inode___206 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___206 *i_op;
	struct super_block___206 *i_sb;
	struct address_space___206 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___207 *i_fop;
		void (*free_inode)(struct inode___206 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___206 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___67 *i_pipe;
		struct cdev___51 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___206 {
	int (*d_revalidate)(struct dentry___206 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___206 *, unsigned int);
	int (*d_hash)(const struct dentry___206 *, struct qstr *);
	int (*d_compare)(const struct dentry___206 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___206 *);
	int (*d_init)(struct dentry___206 *);
	void (*d_release)(struct dentry___206 *);
	void (*d_prune)(struct dentry___206 *);
	void (*d_iput)(struct dentry___206 *, struct inode___206 *);
	char * (*d_dname)(struct dentry___206 *, char *, int);
	struct vfsmount___206 * (*d_automount)(struct path___206 *);
	int (*d_manage)(const struct path___206 *, bool);
	struct dentry___206 * (*d_real)(struct dentry___206 *, const struct inode___206 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___206;

struct mem_dqinfo___206 {
	struct quota_format_type___206 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___206;

struct quota_info___206 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___206 *files[3];
	struct mem_dqinfo___206 info[3];
	const struct quota_format_ops___206 *ops[3];
};

struct rcuwait___207 {
	struct task_struct___213 *task;
};

struct percpu_rw_semaphore___207 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___207 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___206 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___207 rw_sem[3];
};

struct super_operations___206;

struct dquot_operations___206;

struct quotactl_ops___206;

struct block_device___108;

struct super_block___206 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___206 *s_type;
	const struct super_operations___206 *s_op;
	const struct dquot_operations___206 *dq_op;
	const struct quotactl_ops___206 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___206 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___108 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___206 s_dquot;
	struct sb_writers___206 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___206 *s_d_op;
	int cleancache_poolid;
	struct shrinker___89 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___206 {
	struct dentry___206 *mnt_root;
	struct super_block___206 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___206 {
	struct file___206 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___206 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___99 *ki_waitq;
	};
};

struct iattr___206 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___206 *ia_file;
};

struct dquot___206 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___206 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___206 {
	int qf_fmt_id;
	const struct quota_format_ops___206 *qf_ops;
	struct module___190 *qf_owner;
	struct quota_format_type___206 *qf_next;
};

struct quota_format_ops___206 {
	int (*check_quota_file)(struct super_block___206 *, int);
	int (*read_file_info)(struct super_block___206 *, int);
	int (*write_file_info)(struct super_block___206 *, int);
	int (*free_file_info)(struct super_block___206 *, int);
	int (*read_dqblk)(struct dquot___206 *);
	int (*commit_dqblk)(struct dquot___206 *);
	int (*release_dqblk)(struct dquot___206 *);
	int (*get_next_id)(struct super_block___206 *, struct kqid *);
};

struct dquot_operations___206 {
	int (*write_dquot)(struct dquot___206 *);
	struct dquot___206 * (*alloc_dquot)(struct super_block___206 *, int);
	void (*destroy_dquot)(struct dquot___206 *);
	int (*acquire_dquot)(struct dquot___206 *);
	int (*release_dquot)(struct dquot___206 *);
	int (*mark_dirty)(struct dquot___206 *);
	int (*write_info)(struct super_block___206 *, int);
	qsize_t * (*get_reserved_space)(struct inode___206 *);
	int (*get_projid)(struct inode___206 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___206 *, qsize_t *);
	int (*get_next_id)(struct super_block___206 *, struct kqid *);
};

struct quotactl_ops___206 {
	int (*quota_on)(struct super_block___206 *, int, int, const struct path___206 *);
	int (*quota_off)(struct super_block___206 *, int);
	int (*quota_enable)(struct super_block___206 *, unsigned int);
	int (*quota_disable)(struct super_block___206 *, unsigned int);
	int (*quota_sync)(struct super_block___206 *, int);
	int (*set_info)(struct super_block___206 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___206 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___206 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___206 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___206 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___206 *, unsigned int);
};

struct address_space_operations___206 {
	int (*writepage)(struct page___211 *, struct writeback_control___3 *);
	int (*readpage)(struct file___206 *, struct page___211 *);
	int (*writepages)(struct address_space___206 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___211 *);
	int (*readpages)(struct file___206 *, struct address_space___206 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___206 *, struct address_space___206 *, loff_t, unsigned int, unsigned int, struct page___211 **, void **);
	int (*write_end)(struct file___206 *, struct address_space___206 *, loff_t, unsigned int, unsigned int, struct page___211 *, void *);
	sector_t (*bmap)(struct address_space___206 *, sector_t);
	void (*invalidatepage)(struct page___211 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___211 *, gfp_t);
	void (*freepage)(struct page___211 *);
	ssize_t (*direct_IO)(struct kiocb___206 *, struct iov_iter___127 *);
	int (*migratepage)(struct address_space___206 *, struct page___211 *, struct page___211 *, enum migrate_mode);
	bool (*isolate_page)(struct page___211 *, isolate_mode_t);
	void (*putback_page)(struct page___211 *);
	int (*launder_page)(struct page___211 *);
	int (*is_partially_uptodate)(struct page___211 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___211 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___206 *, struct page___211 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___206 *, sector_t *);
	void (*swap_deactivate)(struct file___206 *);
};

struct bio_vec___124;

struct iov_iter___127 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___124 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___206 {
	struct dentry___206 * (*lookup)(struct inode___206 *, struct dentry___206 *, unsigned int);
	const char * (*get_link)(struct dentry___206 *, struct inode___206 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___206 *, int);
	struct posix_acl * (*get_acl)(struct inode___206 *, int, bool);
	int (*readlink)(struct dentry___206 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___206 *, struct dentry___206 *, umode_t, bool);
	int (*link)(struct dentry___206 *, struct inode___206 *, struct dentry___206 *);
	int (*unlink)(struct inode___206 *, struct dentry___206 *);
	int (*symlink)(struct user_namespace *, struct inode___206 *, struct dentry___206 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___206 *, struct dentry___206 *, umode_t);
	int (*rmdir)(struct inode___206 *, struct dentry___206 *);
	int (*mknod)(struct user_namespace *, struct inode___206 *, struct dentry___206 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___206 *, struct dentry___206 *, struct inode___206 *, struct dentry___206 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___206 *, struct iattr___206 *);
	int (*getattr)(struct user_namespace *, const struct path___206 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___206 *, char *, size_t);
	int (*fiemap)(struct inode___206 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___206 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___206 *, struct dentry___206 *, struct file___206 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___206 *, struct dentry___206 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___206 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___206 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___206 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___206 {
	void (*fl_copy_lock)(struct file_lock___206 *, struct file_lock___206 *);
	void (*fl_release_private)(struct file_lock___206 *);
};

struct fasync_struct___206;

struct lock_manager_operations___206;

struct file_lock___206 {
	struct file_lock___206 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___206 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___206 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___206 *fl_ops;
	const struct lock_manager_operations___206 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___206 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___206 *);
	int (*lm_grant)(struct file_lock___206 *, int);
	bool (*lm_break)(struct file_lock___206 *);
	int (*lm_change)(struct file_lock___206 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___206 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___206 *);
};

struct fasync_struct___206 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___206 *fa_next;
	struct file___206 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___206 {
	struct inode___206 * (*alloc_inode)(struct super_block___206 *);
	void (*destroy_inode)(struct inode___206 *);
	void (*free_inode)(struct inode___206 *);
	void (*dirty_inode)(struct inode___206 *, int);
	int (*write_inode)(struct inode___206 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___206 *);
	void (*evict_inode)(struct inode___206 *);
	void (*put_super)(struct super_block___206 *);
	int (*sync_fs)(struct super_block___206 *, int);
	int (*freeze_super)(struct super_block___206 *);
	int (*freeze_fs)(struct super_block___206 *);
	int (*thaw_super)(struct super_block___206 *);
	int (*unfreeze_fs)(struct super_block___206 *);
	int (*statfs)(struct dentry___206 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___206 *, int *, char *);
	void (*umount_begin)(struct super_block___206 *);
	int (*show_options)(struct seq_file___9 *, struct dentry___206 *);
	int (*show_devname)(struct seq_file___9 *, struct dentry___206 *);
	int (*show_path)(struct seq_file___9 *, struct dentry___206 *);
	int (*show_stats)(struct seq_file___9 *, struct dentry___206 *);
	ssize_t (*quota_read)(struct super_block___206 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___206 *, int, const char *, size_t, loff_t);
	struct dquot___206 ** (*get_dquots)(struct inode___206 *);
	long int (*nr_cached_objects)(struct super_block___206 *, struct shrink_control___89 *);
	long int (*free_cached_objects)(struct super_block___206 *, struct shrink_control___89 *);
	struct file___206 * (*real_loop)(struct file___206 *);
};

struct gendisk___108;

struct block_device___108 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___206 *bd_inode;
	struct super_block___206 *bd_super;
	void *bd_claiming;
	struct device___174 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___194 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___108 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___206 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct kernel_param_ops___190 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___190 *);
	int (*get)(char *, const struct kernel_param___190 *);
	void (*free)(void *);
};

struct kparam_array___190;

struct kernel_param___190 {
	const char *name;
	struct module___190 *mod;
	const struct kernel_param_ops___190 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___190 *arr;
	};
};

struct kparam_array___190 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___190 *ops;
	void *elem;
};

struct module_attribute___190 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___190 *, struct module_kobject___190 *, char *);
	ssize_t (*store)(struct module_attribute___190 *, struct module_kobject___190 *, const char *, size_t);
	void (*setup)(struct module___190 *, const char *);
	int (*test)(struct module___190 *);
	void (*free)(struct module___190 *);
};

struct dev_pagemap_ops___201 {
	void (*page_free)(struct page___211 *);
	void (*kill)(struct dev_pagemap___201 *);
	void (*cleanup)(struct dev_pagemap___201 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___201 *);
};

struct fwnode_reference_args___173;

struct fwnode_endpoint___173;

struct fwnode_operations___173 {
	struct fwnode_handle___173 * (*get)(struct fwnode_handle___173 *);
	void (*put)(struct fwnode_handle___173 *);
	bool (*device_is_available)(const struct fwnode_handle___173 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___173 *, const struct device___174 *);
	bool (*property_present)(const struct fwnode_handle___173 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___173 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___173 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___173 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*get_parent)(const struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*get_next_child_node)(const struct fwnode_handle___173 *, struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*get_named_child_node)(const struct fwnode_handle___173 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___173 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___173 *);
	struct fwnode_handle___173 * (*graph_get_next_endpoint)(const struct fwnode_handle___173 *, struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*graph_get_remote_endpoint)(const struct fwnode_handle___173 *);
	struct fwnode_handle___173 * (*graph_get_port_parent)(struct fwnode_handle___173 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___173 *, struct fwnode_endpoint___173 *);
	int (*add_links)(struct fwnode_handle___173 *);
};

struct fwnode_endpoint___173 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___173 *local_fwnode;
};

struct fwnode_reference_args___173 {
	struct fwnode_handle___173 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bio_vec___124 {
	struct page___211 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct gendisk___108 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___108 *part0;
	const struct block_device_operations___81 *fops;
	struct request_queue___3 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___194 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___194 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct class_compat {
	struct kobject___194 *kobj;
};

struct wakeup_source___175;

struct wake_irq___4;

struct pm_subsys_data___6;

struct device___175;

struct dev_pm_qos___14;

struct dev_pm_info___175 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___175 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___4 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___175 *, s32);
	struct dev_pm_qos___14 *qos;
};

struct device_private___6;

struct device_type___175;

struct bus_type___175;

struct device_driver___175;

struct dev_pm_domain___175;

struct irq_domain___45;

struct device_node___73;

struct fwnode_handle___174;

struct class___175;

struct device___175 {
	struct kobject___189 kobj;
	struct device___175 *parent;
	struct device_private___6 *p;
	const char *init_name;
	const struct device_type___175 *type;
	struct bus_type___175 *bus;
	struct device_driver___175 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___175 power;
	struct dev_pm_domain___175 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___45 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___73 *of_node;
	struct fwnode_handle___174 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___175 *class;
	const struct attribute_group___189 **groups;
	void (*release)(struct device___175 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___175 {
	int (*prepare)(struct device___175 *);
	void (*complete)(struct device___175 *);
	int (*suspend)(struct device___175 *);
	int (*resume)(struct device___175 *);
	int (*freeze)(struct device___175 *);
	int (*thaw)(struct device___175 *);
	int (*poweroff)(struct device___175 *);
	int (*restore)(struct device___175 *);
	int (*suspend_late)(struct device___175 *);
	int (*resume_early)(struct device___175 *);
	int (*freeze_late)(struct device___175 *);
	int (*thaw_early)(struct device___175 *);
	int (*poweroff_late)(struct device___175 *);
	int (*restore_early)(struct device___175 *);
	int (*suspend_noirq)(struct device___175 *);
	int (*resume_noirq)(struct device___175 *);
	int (*freeze_noirq)(struct device___175 *);
	int (*thaw_noirq)(struct device___175 *);
	int (*poweroff_noirq)(struct device___175 *);
	int (*restore_noirq)(struct device___175 *);
	int (*runtime_suspend)(struct device___175 *);
	int (*runtime_resume)(struct device___175 *);
	int (*runtime_idle)(struct device___175 *);
};

struct pm_domain_data___6;

struct pm_subsys_data___6 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___6 *domain_data;
};

struct pm_domain_data___6 {
	struct list_head list_node;
	struct device___175 *dev;
};

struct wakeup_source___175 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___4 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___175 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___4 {
	struct device___175 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___14;

struct dev_pm_qos___14 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___14 *resume_latency_req;
	struct dev_pm_qos_request___14 *latency_tolerance_req;
	struct dev_pm_qos_request___14 *flags_req;
};

struct dev_pm_domain___175 {
	struct dev_pm_ops___175 ops;
	int (*start)(struct device___175 *);
	void (*detach)(struct device___175 *, bool);
	int (*activate)(struct device___175 *);
	void (*sync)(struct device___175 *);
	void (*dismiss)(struct device___175 *);
};

struct subsys_private___6;

struct bus_type___175 {
	const char *name;
	const char *dev_name;
	struct device___175 *dev_root;
	const struct attribute_group___189 **bus_groups;
	const struct attribute_group___189 **dev_groups;
	const struct attribute_group___189 **drv_groups;
	int (*match)(struct device___175 *, struct device_driver___175 *);
	int (*uevent)(struct device___175 *, struct kobj_uevent_env *);
	int (*probe)(struct device___175 *);
	void (*sync_state)(struct device___175 *);
	void (*remove)(struct device___175 *);
	void (*shutdown)(struct device___175 *);
	int (*online)(struct device___175 *);
	int (*offline)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	int (*num_vf)(struct device___175 *);
	int (*dma_configure)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___6 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___6;

struct device_driver___175 {
	const char *name;
	struct bus_type___175 *bus;
	struct module___185 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___175 *);
	void (*sync_state)(struct device___175 *);
	int (*remove)(struct device___175 *);
	void (*shutdown)(struct device___175 *);
	int (*suspend)(struct device___175 *, pm_message_t);
	int (*resume)(struct device___175 *);
	const struct attribute_group___189 **groups;
	const struct attribute_group___189 **dev_groups;
	const struct dev_pm_ops___175 *pm;
	void (*coredump)(struct device___175 *);
	struct driver_private___6 *p;
};

struct subsys_private___6 {
	struct kset___189 subsys;
	struct kset___189 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___189 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___175 *bus;
	struct kset___189 glue_dirs;
	struct class___175 *class;
};

struct device_type___175 {
	const char *name;
	const struct attribute_group___189 **groups;
	int (*uevent)(struct device___175 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___175 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___175 *);
	const struct dev_pm_ops___175 *pm;
};

struct class___175 {
	const char *name;
	struct module___185 *owner;
	const struct attribute_group___189 **class_groups;
	const struct attribute_group___189 **dev_groups;
	struct kobject___189 *dev_kobj;
	int (*dev_uevent)(struct device___175 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___175 *, umode_t *);
	void (*class_release)(struct class___175 *);
	void (*dev_release)(struct device___175 *);
	int (*shutdown_pre)(struct device___175 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___175 *);
	void (*get_ownership)(struct device___175 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___175 *pm;
	struct subsys_private___6 *p;
};

struct driver_private___6 {
	struct kobject___189 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___185 *mkobj;
	struct device_driver___175 *driver;
};

struct device_attribute___21 {
	struct attribute attr;
	ssize_t (*show)(struct device___175 *, struct device_attribute___21 *, char *);
	ssize_t (*store)(struct device___175 *, struct device_attribute___21 *, const char *, size_t);
};

typedef void (*dr_release_t___22)(struct device___175 *, void *);

struct device_private___6 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___175 *async_driver;
	char *deferred_probe_reason;
	struct device___175 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_domain_ops___45;

struct irq_domain_chip_generic___45;

struct irq_data___46;

struct irq_domain___45 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___45 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___174 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___45 *gc;
	struct irq_domain___45 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___46 *revmap[0];
};

struct fwnode_operations___174;

struct fwnode_handle___174 {
	struct fwnode_handle___174 *secondary;
	const struct fwnode_operations___174 *ops;
	struct device___175 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___73 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___174 fwnode;
	struct property___50 *properties;
	struct property___50 *deadprops;
	struct device_node___73 *parent;
	struct device_node___73 *child;
	struct device_node___73 *sibling;
	struct kobject___189 kobj;
	long unsigned int _flags;
	void *data;
};

struct platform_device___27 {
	const char *name;
	int id;
	bool id_auto;
	struct device___175 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___5 {
	struct device___175 *parent;
	struct fwnode_handle___174 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct platform_driver___25 {
	int (*probe)(struct platform_device___27 *);
	int (*remove)(struct platform_device___27 *);
	void (*shutdown)(struct platform_device___27 *);
	int (*suspend)(struct platform_device___27 *, pm_message_t);
	int (*resume)(struct platform_device___27 *);
	struct device_driver___175 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct fwnode_reference_args___174;

struct fwnode_endpoint___174;

struct fwnode_operations___174 {
	struct fwnode_handle___174 * (*get)(struct fwnode_handle___174 *);
	void (*put)(struct fwnode_handle___174 *);
	bool (*device_is_available)(const struct fwnode_handle___174 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___174 *, const struct device___175 *);
	bool (*property_present)(const struct fwnode_handle___174 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___174 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___174 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___174 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*get_parent)(const struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*get_next_child_node)(const struct fwnode_handle___174 *, struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*get_named_child_node)(const struct fwnode_handle___174 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___174 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___174 *);
	struct fwnode_handle___174 * (*graph_get_next_endpoint)(const struct fwnode_handle___174 *, struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*graph_get_remote_endpoint)(const struct fwnode_handle___174 *);
	struct fwnode_handle___174 * (*graph_get_port_parent)(struct fwnode_handle___174 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___174 *, struct fwnode_endpoint___174 *);
	int (*add_links)(struct fwnode_handle___174 *);
};

struct fwnode_endpoint___174 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___174 *local_fwnode;
};

struct fwnode_reference_args___174 {
	struct fwnode_handle___174 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_desc___47;

typedef void (*irq_flow_handler_t___47)(struct irq_desc___47 *);

struct irq_chip___46;

struct irq_data___46 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___46 *chip;
	struct irq_domain___45 *domain;
	struct irq_data___46 *parent_data;
	void *chip_data;
};

struct irq_desc___47 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___46 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___47 handle_irq;
	struct irqaction___28 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___189 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___185 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___46 {
	struct device___175 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___46 *);
	void (*irq_shutdown)(struct irq_data___46 *);
	void (*irq_enable)(struct irq_data___46 *);
	void (*irq_disable)(struct irq_data___46 *);
	void (*irq_ack)(struct irq_data___46 *);
	void (*irq_mask)(struct irq_data___46 *);
	void (*irq_mask_ack)(struct irq_data___46 *);
	void (*irq_unmask)(struct irq_data___46 *);
	void (*irq_eoi)(struct irq_data___46 *);
	int (*irq_set_affinity)(struct irq_data___46 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___46 *);
	int (*irq_set_type)(struct irq_data___46 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___46 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___46 *);
	void (*irq_bus_sync_unlock)(struct irq_data___46 *);
	void (*irq_cpu_online)(struct irq_data___46 *);
	void (*irq_cpu_offline)(struct irq_data___46 *);
	void (*irq_suspend)(struct irq_data___46 *);
	void (*irq_resume)(struct irq_data___46 *);
	void (*irq_pm_shutdown)(struct irq_data___46 *);
	void (*irq_calc_mask)(struct irq_data___46 *);
	void (*irq_print_chip)(struct irq_data___46 *, struct seq_file___177 *);
	int (*irq_request_resources)(struct irq_data___46 *);
	void (*irq_release_resources)(struct irq_data___46 *);
	void (*irq_compose_msi_msg)(struct irq_data___46 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___46 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___46 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___46 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___46 *, void *);
	void (*ipi_send_single)(struct irq_data___46 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___46 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___46 *);
	void (*irq_nmi_teardown)(struct irq_data___46 *);
	long unsigned int flags;
};

struct irq_chip_type___45 {
	struct irq_chip___46 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___47 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___45 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___45 *);
	void (*resume)(struct irq_chip_generic___45 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___45 *domain;
	struct list_head list;
	struct irq_chip_type___45 chip_types[0];
};

struct irq_domain_chip_generic___45 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___45 *gc[0];
};

struct irq_fwspec___43 {
	struct fwnode_handle___174 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___45 {
	int (*match)(struct irq_domain___45 *, struct device_node___73 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___45 *, struct irq_fwspec___43 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___45 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___45 *, unsigned int);
	int (*xlate)(struct irq_domain___45 *, struct device_node___73 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___45 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___45 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___45 *, struct irq_data___46 *, bool);
	void (*deactivate)(struct irq_domain___45 *, struct irq_data___46 *);
	int (*translate)(struct irq_domain___45 *, struct irq_fwspec___43 *, long unsigned int *, unsigned int *);
};

struct acpi_device___13;

struct acpi_hotplug_profile___13 {
	struct kobject___189 kobj;
	int (*scan_dependent)(struct acpi_device___13 *);
	void (*notify_online)(struct acpi_device___13 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___13 {
	void (*func)(struct acpi_device_wakeup_context___13 *);
	struct device___175 *dev;
};

struct acpi_device_wakeup___13 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___13 context;
	struct wakeup_source___175 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___13;

struct acpi_hotplug_context___13;

struct acpi_driver___13;

struct acpi_device___13 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___174 fwnode;
	struct acpi_device___13 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___13 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___13 *handler;
	struct acpi_hotplug_context___13 *hp;
	struct acpi_driver___13 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___175 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___13 *);
};

struct acpi_scan_handler___13 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___13 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___13 *);
	void (*bind)(struct device___175 *);
	void (*unbind)(struct device___175 *);
	struct acpi_hotplug_profile___13 hotplug;
};

struct acpi_hotplug_context___13 {
	struct acpi_device___13 *self;
	int (*notify)(struct acpi_device___13 *, u32);
	void (*uevent)(struct acpi_device___13 *, u32);
	void (*fixup)(struct acpi_device___13 *);
};

typedef int (*acpi_op_add___13)(struct acpi_device___13 *);

typedef int (*acpi_op_remove___13)(struct acpi_device___13 *);

typedef void (*acpi_op_notify___13)(struct acpi_device___13 *, u32);

struct acpi_device_ops___13 {
	acpi_op_add___13 add;
	acpi_op_remove___13 remove;
	acpi_op_notify___13 notify;
};

struct acpi_driver___13 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___13 ops;
	struct device_driver___175 drv;
	struct module___185 *owner;
};

struct dev_pm_qos_request___14 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___175 *dev;
};

struct irq_affinity_devres {
	unsigned int count;
	unsigned int irq[0];
};

struct platform_object {
	struct platform_device___27 pdev;
	char name[0];
};

struct wakeup_source___176;

struct device___176;

struct dev_pm_qos___15;

struct dev_pm_info___176 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___176 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___176 *, s32);
	struct dev_pm_qos___15 *qos;
};

struct device_private___7;

struct device_type___176;

struct bus_type___176;

struct device_driver___176;

struct dev_pm_domain___176;

struct irq_domain___46;

struct device_node___74;

struct fwnode_handle___175;

struct class___176;

struct device___176 {
	struct kobject___190 kobj;
	struct device___176 *parent;
	struct device_private___7 *p;
	const char *init_name;
	const struct device_type___176 *type;
	struct bus_type___176 *bus;
	struct device_driver___176 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___176 power;
	struct dev_pm_domain___176 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___46 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___74 *of_node;
	struct fwnode_handle___175 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___176 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___176 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___176 {
	int (*prepare)(struct device___176 *);
	void (*complete)(struct device___176 *);
	int (*suspend)(struct device___176 *);
	int (*resume)(struct device___176 *);
	int (*freeze)(struct device___176 *);
	int (*thaw)(struct device___176 *);
	int (*poweroff)(struct device___176 *);
	int (*restore)(struct device___176 *);
	int (*suspend_late)(struct device___176 *);
	int (*resume_early)(struct device___176 *);
	int (*freeze_late)(struct device___176 *);
	int (*thaw_early)(struct device___176 *);
	int (*poweroff_late)(struct device___176 *);
	int (*restore_early)(struct device___176 *);
	int (*suspend_noirq)(struct device___176 *);
	int (*resume_noirq)(struct device___176 *);
	int (*freeze_noirq)(struct device___176 *);
	int (*thaw_noirq)(struct device___176 *);
	int (*poweroff_noirq)(struct device___176 *);
	int (*restore_noirq)(struct device___176 *);
	int (*runtime_suspend)(struct device___176 *);
	int (*runtime_resume)(struct device___176 *);
	int (*runtime_idle)(struct device___176 *);
};

struct wakeup_source___176 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___176 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___15;

struct dev_pm_qos___15 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___15 *resume_latency_req;
	struct dev_pm_qos_request___15 *latency_tolerance_req;
	struct dev_pm_qos_request___15 *flags_req;
};

struct dev_pm_domain___176 {
	struct dev_pm_ops___176 ops;
	int (*start)(struct device___176 *);
	void (*detach)(struct device___176 *, bool);
	int (*activate)(struct device___176 *);
	void (*sync)(struct device___176 *);
	void (*dismiss)(struct device___176 *);
};

struct subsys_private___7;

struct bus_type___176 {
	const char *name;
	const char *dev_name;
	struct device___176 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___176 *, struct device_driver___176 *);
	int (*uevent)(struct device___176 *, struct kobj_uevent_env *);
	int (*probe)(struct device___176 *);
	void (*sync_state)(struct device___176 *);
	void (*remove)(struct device___176 *);
	void (*shutdown)(struct device___176 *);
	int (*online)(struct device___176 *);
	int (*offline)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	int (*num_vf)(struct device___176 *);
	int (*dma_configure)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___7 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___7;

struct device_driver___176 {
	const char *name;
	struct bus_type___176 *bus;
	struct module___186 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___176 *);
	void (*sync_state)(struct device___176 *);
	int (*remove)(struct device___176 *);
	void (*shutdown)(struct device___176 *);
	int (*suspend)(struct device___176 *, pm_message_t);
	int (*resume)(struct device___176 *);
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	const struct dev_pm_ops___176 *pm;
	void (*coredump)(struct device___176 *);
	struct driver_private___7 *p;
};

struct subsys_private___7 {
	struct kset___190 subsys;
	struct kset___190 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___190 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___176 *bus;
	struct kset___190 glue_dirs;
	struct class___176 *class;
};

struct device_type___176 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___176 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___176 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___176 *);
	const struct dev_pm_ops___176 *pm;
};

struct class___176 {
	const char *name;
	struct module___186 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___176 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___176 *, umode_t *);
	void (*class_release)(struct class___176 *);
	void (*dev_release)(struct device___176 *);
	int (*shutdown_pre)(struct device___176 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___176 *);
	void (*get_ownership)(struct device___176 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___176 *pm;
	struct subsys_private___7 *p;
};

struct driver_private___7 {
	struct kobject___190 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___186 *mkobj;
	struct device_driver___176 *driver;
};

struct device_attribute___22 {
	struct attribute attr;
	ssize_t (*show)(struct device___176 *, struct device_attribute___22 *, char *);
	ssize_t (*store)(struct device___176 *, struct device_attribute___22 *, const char *, size_t);
};

struct device_private___7 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___176 *async_driver;
	char *deferred_probe_reason;
	struct device___176 *device;
	u8 dead;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_domain_ops___46;

struct irq_domain_chip_generic___46;

struct irq_data___47;

struct irq_domain___46 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___46 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___175 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___46 *gc;
	struct irq_domain___46 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___47 *revmap[0];
};

struct fwnode_operations___175;

struct fwnode_handle___175 {
	struct fwnode_handle___175 *secondary;
	const struct fwnode_operations___175 *ops;
	struct device___176 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___74 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___175 fwnode;
	struct property___51 *properties;
	struct property___51 *deadprops;
	struct device_node___74 *parent;
	struct device_node___74 *child;
	struct device_node___74 *sibling;
	struct kobject___190 kobj;
	long unsigned int _flags;
	void *data;
};

struct cpu___3 {
	int node_id;
	int hotpluggable;
	struct device___176 dev;
};

struct irq_desc___48;

typedef void (*irq_flow_handler_t___48)(struct irq_desc___48 *);

struct irq_chip___47;

struct irq_data___47 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___47 *chip;
	struct irq_domain___46 *domain;
	struct irq_data___47 *parent_data;
	void *chip_data;
};

struct irq_desc___48 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___47 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___48 handle_irq;
	struct irqaction___29 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___190 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___186 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___175;

struct fwnode_endpoint___175;

struct fwnode_operations___175 {
	struct fwnode_handle___175 * (*get)(struct fwnode_handle___175 *);
	void (*put)(struct fwnode_handle___175 *);
	bool (*device_is_available)(const struct fwnode_handle___175 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___175 *, const struct device___176 *);
	bool (*property_present)(const struct fwnode_handle___175 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___175 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___175 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___175 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*get_parent)(const struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*get_next_child_node)(const struct fwnode_handle___175 *, struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*get_named_child_node)(const struct fwnode_handle___175 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___175 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___175 *);
	struct fwnode_handle___175 * (*graph_get_next_endpoint)(const struct fwnode_handle___175 *, struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*graph_get_remote_endpoint)(const struct fwnode_handle___175 *);
	struct fwnode_handle___175 * (*graph_get_port_parent)(struct fwnode_handle___175 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___175 *, struct fwnode_endpoint___175 *);
	int (*add_links)(struct fwnode_handle___175 *);
};

struct fwnode_endpoint___175 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___175 *local_fwnode;
};

struct fwnode_reference_args___175 {
	struct fwnode_handle___175 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_fwspec___44 {
	struct fwnode_handle___175 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___46 {
	int (*match)(struct irq_domain___46 *, struct device_node___74 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___46 *, struct irq_fwspec___44 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___46 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___46 *, unsigned int);
	int (*xlate)(struct irq_domain___46 *, struct device_node___74 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___46 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___46 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___46 *, struct irq_data___47 *, bool);
	void (*deactivate)(struct irq_domain___46 *, struct irq_data___47 *);
	int (*translate)(struct irq_domain___46 *, struct irq_fwspec___44 *, long unsigned int *, unsigned int *);
};

struct irq_chip_generic___46;

struct irq_domain_chip_generic___46 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___46 *gc[0];
};

struct irq_chip___47 {
	struct device___176 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___47 *);
	void (*irq_shutdown)(struct irq_data___47 *);
	void (*irq_enable)(struct irq_data___47 *);
	void (*irq_disable)(struct irq_data___47 *);
	void (*irq_ack)(struct irq_data___47 *);
	void (*irq_mask)(struct irq_data___47 *);
	void (*irq_mask_ack)(struct irq_data___47 *);
	void (*irq_unmask)(struct irq_data___47 *);
	void (*irq_eoi)(struct irq_data___47 *);
	int (*irq_set_affinity)(struct irq_data___47 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___47 *);
	int (*irq_set_type)(struct irq_data___47 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___47 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___47 *);
	void (*irq_bus_sync_unlock)(struct irq_data___47 *);
	void (*irq_cpu_online)(struct irq_data___47 *);
	void (*irq_cpu_offline)(struct irq_data___47 *);
	void (*irq_suspend)(struct irq_data___47 *);
	void (*irq_resume)(struct irq_data___47 *);
	void (*irq_pm_shutdown)(struct irq_data___47 *);
	void (*irq_calc_mask)(struct irq_data___47 *);
	void (*irq_print_chip)(struct irq_data___47 *, struct seq_file___178 *);
	int (*irq_request_resources)(struct irq_data___47 *);
	void (*irq_release_resources)(struct irq_data___47 *);
	void (*irq_compose_msi_msg)(struct irq_data___47 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___47 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___47 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___47 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___47 *, void *);
	void (*ipi_send_single)(struct irq_data___47 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___47 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___47 *);
	void (*irq_nmi_teardown)(struct irq_data___47 *);
	long unsigned int flags;
};

struct irq_chip_type___46 {
	struct irq_chip___47 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___48 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___46 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___46 *);
	void (*resume)(struct irq_chip_generic___46 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___46 *domain;
	struct list_head list;
	struct irq_chip_type___46 chip_types[0];
};

struct dev_pm_qos_request___15 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___176 *dev;
};

struct cpu_attr {
	struct device_attribute___22 attr;
	const struct cpumask * const map;
};

typedef struct kobject___169 *kobj_probe_t___2(dev_t, int *, void *);

struct probe {
	struct probe *next;
	dev_t dev;
	long unsigned int range;
	struct module___166 *owner;
	kobj_probe_t___2 *get;
	int (*lock)(dev_t, void *);
	void *data;
};

struct kobj_map___2 {
	struct probe *probes[255];
	struct mutex *lock;
};

typedef void (*dr_release_t___23)(struct device___176 *, void *);

typedef int (*dr_match_t___19)(struct device___176 *, void *, void *);

struct devres_node {
	struct list_head entry;
	dr_release_t___23 release;
	const char *name;
	size_t size;
};

struct devres___2 {
	struct devres_node node;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 data[0];
};

struct devres_group {
	struct devres_node node[2];
	void *id;
	int color;
};

struct action_devres {
	void *data;
	void (*action)(void *);
};

struct pages_devres {
	long unsigned int addr;
	unsigned int order;
};

struct attribute_container {
	struct list_head node;
	struct klist containers;
	struct class___176 *class;
	const struct attribute_group___190 *grp;
	struct device_attribute___22 **attrs;
	int (*match)(struct attribute_container *, struct device___176 *);
	long unsigned int flags;
};

struct internal_container {
	struct klist_node node;
	struct attribute_container *cont;
	struct device___176 classdev;
};

struct attribute_container___2 {
	struct list_head node;
	struct klist containers;
	struct class___160 *class;
	const struct attribute_group___41 *grp;
	struct device_attribute___11 **attrs;
	int (*match)(struct attribute_container___2 *, struct device___160 *);
	long unsigned int flags;
};

struct transport_container;

struct transport_class {
	struct class___160 class;
	int (*setup)(struct transport_container *, struct device___160 *, struct device___160 *);
	int (*configure)(struct transport_container *, struct device___160 *, struct device___160 *);
	int (*remove)(struct transport_container *, struct device___160 *, struct device___160 *);
};

struct transport_container {
	struct attribute_container___2 ac;
	const struct attribute_group___41 *statistics;
};

struct anon_transport_class {
	struct transport_class tclass;
	struct attribute_container___2 container;
};

struct wakeup_source___177;

struct device___177;

struct dev_pm_info___177 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___177 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___177 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___8;

struct device_type___177;

struct bus_type___177;

struct device_driver___177;

struct dev_pm_domain___177;

struct class___177;

struct device___177 {
	struct kobject___41 kobj;
	struct device___177 *parent;
	struct device_private___8 *p;
	const char *init_name;
	const struct device_type___177 *type;
	struct bus_type___177 *bus;
	struct device_driver___177 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___177 power;
	struct dev_pm_domain___177 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___7 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___177 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___177 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___177 {
	int (*prepare)(struct device___177 *);
	void (*complete)(struct device___177 *);
	int (*suspend)(struct device___177 *);
	int (*resume)(struct device___177 *);
	int (*freeze)(struct device___177 *);
	int (*thaw)(struct device___177 *);
	int (*poweroff)(struct device___177 *);
	int (*restore)(struct device___177 *);
	int (*suspend_late)(struct device___177 *);
	int (*resume_early)(struct device___177 *);
	int (*freeze_late)(struct device___177 *);
	int (*thaw_early)(struct device___177 *);
	int (*poweroff_late)(struct device___177 *);
	int (*restore_early)(struct device___177 *);
	int (*suspend_noirq)(struct device___177 *);
	int (*resume_noirq)(struct device___177 *);
	int (*freeze_noirq)(struct device___177 *);
	int (*thaw_noirq)(struct device___177 *);
	int (*poweroff_noirq)(struct device___177 *);
	int (*restore_noirq)(struct device___177 *);
	int (*runtime_suspend)(struct device___177 *);
	int (*runtime_resume)(struct device___177 *);
	int (*runtime_idle)(struct device___177 *);
};

struct wakeup_source___177 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___177 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___177 {
	struct dev_pm_ops___177 ops;
	int (*start)(struct device___177 *);
	void (*detach)(struct device___177 *, bool);
	int (*activate)(struct device___177 *);
	void (*sync)(struct device___177 *);
	void (*dismiss)(struct device___177 *);
};

struct subsys_private___8;

struct bus_type___177 {
	const char *name;
	const char *dev_name;
	struct device___177 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___177 *, struct device_driver___177 *);
	int (*uevent)(struct device___177 *, struct kobj_uevent_env *);
	int (*probe)(struct device___177 *);
	void (*sync_state)(struct device___177 *);
	void (*remove)(struct device___177 *);
	void (*shutdown)(struct device___177 *);
	int (*online)(struct device___177 *);
	int (*offline)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	int (*num_vf)(struct device___177 *);
	int (*dma_configure)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___8 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___8;

struct device_driver___177 {
	const char *name;
	struct bus_type___177 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___177 *);
	void (*sync_state)(struct device___177 *);
	int (*remove)(struct device___177 *);
	void (*shutdown)(struct device___177 *);
	int (*suspend)(struct device___177 *, pm_message_t);
	int (*resume)(struct device___177 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___177 *pm;
	void (*coredump)(struct device___177 *);
	struct driver_private___8 *p;
};

struct subsys_private___8 {
	struct kset___41 subsys;
	struct kset___41 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___41 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___177 *bus;
	struct kset___41 glue_dirs;
	struct class___177 *class;
};

struct device_type___177 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___177 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___177 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___177 *);
	const struct dev_pm_ops___177 *pm;
};

struct class___177 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___177 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___177 *, umode_t *);
	void (*class_release)(struct class___177 *);
	void (*dev_release)(struct device___177 *);
	int (*shutdown_pre)(struct device___177 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___177 *);
	void (*get_ownership)(struct device___177 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___177 *pm;
	struct subsys_private___8 *p;
};

struct module_kobject___191;

struct driver_private___8 {
	struct kobject___41 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___191 *mkobj;
	struct device_driver___177 *driver;
};

struct device_private___8 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___177 *async_driver;
	char *deferred_probe_reason;
	struct device___177 *device;
	u8 dead;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct container_dev___2 {
	struct device___177 dev;
	int (*offline)(struct container_dev___2 *);
};

struct irq_desc___49;

typedef void (*irq_flow_handler_t___49)(struct irq_desc___49 *);

struct irq_chip___48;

struct irq_domain___47;

struct irq_data___48 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___48 *chip;
	struct irq_domain___47 *domain;
	struct irq_data___48 *parent_data;
	void *chip_data;
};

struct kset___195;

struct kobj_type___195;

struct kernfs_node___195;

struct kobject___195 {
	const char *name;
	struct list_head entry;
	struct kobject___195 *parent;
	struct kset___195 *kset;
	struct kobj_type___195 *ktype;
	struct kernfs_node___195 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___32;

struct module___191;

struct irq_desc___49 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___48 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___49 handle_irq;
	struct irqaction___32 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___195 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___191 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___207;

struct super_block___207;

struct file_system_type___207 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___207 * (*mount)(struct file_system_type___207 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___207 *);
	struct module___191 *owner;
	struct file_system_type___207 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___207;

struct kiocb___207;

struct iov_iter___128;

struct poll_table_struct___136;

struct vm_area_struct___212;

struct inode___207;

struct file_lock___207;

struct page___212;

struct pipe_inode_info___68;

struct seq_file___182;

struct file_operations___208 {
	struct module___191 *owner;
	loff_t (*llseek)(struct file___207 *, loff_t, int);
	ssize_t (*read)(struct file___207 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___207 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___207 *, struct iov_iter___128 *);
	ssize_t (*write_iter)(struct kiocb___207 *, struct iov_iter___128 *);
	int (*iopoll)(struct kiocb___207 *, bool);
	int (*iterate)(struct file___207 *, struct dir_context *);
	int (*iterate_shared)(struct file___207 *, struct dir_context *);
	__poll_t (*poll)(struct file___207 *, struct poll_table_struct___136 *);
	long int (*unlocked_ioctl)(struct file___207 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___207 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___207 *, struct vm_area_struct___212 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___207 *, struct file___207 *);
	int (*flush)(struct file___207 *, fl_owner_t);
	int (*release)(struct inode___207 *, struct file___207 *);
	int (*fsync)(struct file___207 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___207 *, int);
	int (*lock)(struct file___207 *, int, struct file_lock___207 *);
	ssize_t (*sendpage)(struct file___207 *, struct page___212 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___207 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___207 *, long unsigned int);
	int (*flock)(struct file___207 *, int, struct file_lock___207 *);
	ssize_t (*splice_write)(struct pipe_inode_info___68 *, struct file___207 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___207 *, loff_t *, struct pipe_inode_info___68 *, size_t, unsigned int);
	int (*setlease)(struct file___207 *, long int, struct file_lock___207 **, void **);
	long int (*fallocate)(struct file___207 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___182 *, struct file___207 *);
	ssize_t (*copy_file_range)(struct file___207 *, loff_t, struct file___207 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___207 *, loff_t, struct file___207 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___207 *, loff_t, loff_t, int);
};

struct vmacache___212 {
	u64 seqnum;
	struct vm_area_struct___212 *vmas[4];
};

struct page_frag___212 {
	struct page___212 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___213;

struct pid___184;

struct nsproxy___193;

struct signal_struct___208;

struct css_set___142;

struct vm_struct___190;

struct task_struct___214 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___214 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___213 *mm;
	struct mm_struct___213 *active_mm;
	struct vmacache___212 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___214 *real_parent;
	struct task_struct___214 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___214 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___184 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___193 *nsproxy;
	struct signal_struct___208 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___214 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___105 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___142 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___68 *splice_pipe;
	struct page_frag___212 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___214 *oom_reaper_list;
	struct vm_struct___190 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___75 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___192 {
	struct kobject___195 kobj;
	struct module___191 *mod;
	struct kobject___195 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___191 {
	struct module___191 *mod;
	struct latch_tree_node node;
};

struct module_layout___191 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___191 mtn;
};

struct module_attribute___191;

struct kernel_param___191;

struct module___191 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___192 mkobj;
	struct module_attribute___191 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___195 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___191 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___191 core_layout;
	struct module_layout___191 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___212 *pgtable_t___212;

struct address_space___207;

struct page_pool___56;

struct dev_pagemap___202;

struct page___212 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___207 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___56 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___212 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___212 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___213 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___202 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___202;

struct vm_area_struct___212 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___212 *vm_next;
	struct vm_area_struct___212 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___213 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___202 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___207 *vm_file;
	struct file___207 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___212;

struct mm_struct___213 {
	struct {
		struct vm_area_struct___212 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___207 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___212 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___214 *owner;
		struct user_namespace___25 *user_ns;
		struct file___207 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___207;

struct address_space___207 {
	struct inode___207 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___207 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___178;

struct page_pool_params___56 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___178 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___56 {
	u32 count;
	struct page___212 *cache[128];
};

struct page_pool___56 {
	struct page_pool_params___56 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___212 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___56 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___202;

struct dev_pagemap___202 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___202 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___207;

struct path___207 {
	struct vfsmount___207 *mnt;
	struct dentry___207 *dentry;
};

struct fown_struct___184 {
	rwlock_t lock;
	struct pid___184 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___207 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___207 f_path;
	struct inode___207 *f_inode;
	const struct file_operations___208 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___184 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___207 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___202;

struct vm_operations_struct___202 {
	void (*open)(struct vm_area_struct___212 *);
	void (*close)(struct vm_area_struct___212 *);
	int (*may_split)(struct vm_area_struct___212 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___212 *);
	int (*mprotect)(struct vm_area_struct___212 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___202 *);
	vm_fault_t (*huge_fault)(struct vm_fault___202 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___202 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___212 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___202 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___202 *);
	int (*access)(struct vm_area_struct___212 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___212 *);
	int (*set_policy)(struct vm_area_struct___212 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___212 *, long unsigned int);
	struct page___212 * (*find_special_page)(struct vm_area_struct___212 *, long unsigned int);
};

struct core_thread___212 {
	struct task_struct___214 *task;
	struct core_thread___212 *next;
};

struct core_state___212 {
	atomic_t nr_threads;
	struct core_thread___212 dumper;
	struct completion startup;
};

struct vm_fault___202 {
	const struct {
		struct vm_area_struct___212 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___212 *cow_page;
	struct page___212 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___212 prealloc_pte;
};

struct kernfs_root___195;

struct kernfs_elem_dir___195 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___195 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___195;

struct kernfs_root___195 {
	struct kernfs_node___195 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___195 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___195 {
	struct kernfs_node___195 *target_kn;
};

struct kernfs_ops___195;

struct kernfs_elem_attr___195 {
	const struct kernfs_ops___195 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___195 *notify_next;
};

struct kernfs_node___195 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___195 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___195 dir;
		struct kernfs_elem_symlink___195 symlink;
		struct kernfs_elem_attr___195 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___195;

struct kernfs_ops___195 {
	int (*open)(struct kernfs_open_file___195 *);
	void (*release)(struct kernfs_open_file___195 *);
	int (*seq_show)(struct seq_file___182 *, void *);
	void * (*seq_start)(struct seq_file___182 *, loff_t *);
	void * (*seq_next)(struct seq_file___182 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___182 *, void *);
	ssize_t (*read)(struct kernfs_open_file___195 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___195 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___195 *, struct poll_table_struct___136 *);
	int (*mmap)(struct kernfs_open_file___195 *, struct vm_area_struct___212 *);
};

struct kernfs_syscall_ops___195 {
	int (*show_options)(struct seq_file___182 *, struct kernfs_root___195 *);
	int (*mkdir)(struct kernfs_node___195 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___195 *);
	int (*rename)(struct kernfs_node___195 *, struct kernfs_node___195 *, const char *);
	int (*show_path)(struct seq_file___182 *, struct kernfs_node___195 *, struct kernfs_root___195 *);
};

struct seq_operations___182;

struct seq_file___182 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___182 *op;
	int poll_event;
	const struct file___207 *file;
	void *private;
};

struct kernfs_open_file___195 {
	struct kernfs_node___195 *kn;
	struct file___207 *file;
	struct seq_file___182 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___202 *vm_ops;
};

typedef void (*poll_queue_proc___143)(struct file___207 *, wait_queue_head_t *, struct poll_table_struct___136 *);

struct poll_table_struct___136 {
	poll_queue_proc___143 _qproc;
	__poll_t _key;
};

struct pid_namespace___184;

struct upid___184 {
	int nr;
	struct pid_namespace___184 *ns;
};

struct pid_namespace___184 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___214 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___184 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___184 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___184 numbers[1];
};

struct signal_struct___208 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___214 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___214 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___184 *pids[4];
	struct pid___184 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___213 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___43;

struct cgroup_namespace___142;

struct nsproxy___193 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___184 *pid_ns_for_children;
	struct net___43 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___142 *cgroup_ns;
};

struct cgroup_subsys_state___142;

struct cgroup___142;

struct css_set___142 {
	struct cgroup_subsys_state___142 *subsys[14];
	refcount_t refcount;
	struct css_set___142 *dom_cset;
	struct cgroup___142 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___142 *mg_src_cgrp;
	struct cgroup___142 *mg_dst_cgrp;
	struct css_set___142 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___207;

struct pipe_buffer___68;

struct pipe_inode_info___68 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___212 *tmp_page;
	struct fasync_struct___207 *fasync_readers;
	struct fasync_struct___207 *fasync_writers;
	struct pipe_buffer___68 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___190 {
	struct vm_struct___190 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___212 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___195;

struct attribute_group___195 {
	const char *name;
	umode_t (*is_visible)(struct kobject___195 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___195 *, struct bin_attribute___195 *, int);
	struct attribute **attrs;
	struct bin_attribute___195 **bin_attrs;
};

struct bin_attribute___195 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___207 * (*f_mapping)();
	ssize_t (*read)(struct file___207 *, struct kobject___195 *, struct bin_attribute___195 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___207 *, struct kobject___195 *, struct bin_attribute___195 *, char *, loff_t, size_t);
	int (*mmap)(struct file___207 *, struct kobject___195 *, struct bin_attribute___195 *, struct vm_area_struct___212 *);
};

struct sysfs_ops___195 {
	ssize_t (*show)(struct kobject___195 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___195 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___195;

struct kset___195 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___195 kobj;
	const struct kset_uevent_ops___195 *uevent_ops;
};

struct kobj_type___195 {
	void (*release)(struct kobject___195 *);
	const struct sysfs_ops___195 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___195 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___195 *);
	const void * (*namespace)(struct kobject___195 *);
	void (*get_ownership)(struct kobject___195 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___195 {
	int (* const filter)(struct kset___195 *, struct kobject___195 *);
	const char * (* const name)(struct kset___195 *, struct kobject___195 *);
	int (* const uevent)(struct kset___195 *, struct kobject___195 *, struct kobj_uevent_env *);
};

struct fwnode_operations___176;

struct fwnode_handle___176 {
	struct fwnode_handle___176 *secondary;
	const struct fwnode_operations___176 *ops;
	struct device___178 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___176;

struct fwnode_endpoint___176;

struct fwnode_operations___176 {
	struct fwnode_handle___176 * (*get)(struct fwnode_handle___176 *);
	void (*put)(struct fwnode_handle___176 *);
	bool (*device_is_available)(const struct fwnode_handle___176 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___176 *, const struct device___178 *);
	bool (*property_present)(const struct fwnode_handle___176 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___176 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___176 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___176 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*get_parent)(const struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*get_next_child_node)(const struct fwnode_handle___176 *, struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*get_named_child_node)(const struct fwnode_handle___176 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___176 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___176 *);
	struct fwnode_handle___176 * (*graph_get_next_endpoint)(const struct fwnode_handle___176 *, struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*graph_get_remote_endpoint)(const struct fwnode_handle___176 *);
	struct fwnode_handle___176 * (*graph_get_port_parent)(struct fwnode_handle___176 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___176 *, struct fwnode_endpoint___176 *);
	int (*add_links)(struct fwnode_handle___176 *);
};

struct wakeup_source___178;

struct dev_pm_info___178 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___178 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___178 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___178;

struct bus_type___178;

struct device_driver___178;

struct dev_pm_domain___178;

struct device_node___75;

struct class___178;

struct device___178 {
	struct kobject___195 kobj;
	struct device___178 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___178 *type;
	struct bus_type___178 *bus;
	struct device_driver___178 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___178 power;
	struct dev_pm_domain___178 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___47 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___75 *of_node;
	struct fwnode_handle___176 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___178 *class;
	const struct attribute_group___195 **groups;
	void (*release)(struct device___178 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___176 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___176 *local_fwnode;
};

struct fwnode_reference_args___176 {
	struct fwnode_handle___176 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

typedef void * (*devcon_match_fn_t)(struct fwnode_handle___176 *, const char *, void *);

struct property___55 {
	char *name;
	int length;
	void *value;
	struct property___55 *next;
	long unsigned int _flags;
	struct bin_attribute___195 attr;
};

struct device_node___75 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___176 fwnode;
	struct property___55 *properties;
	struct property___55 *deadprops;
	struct device_node___75 *parent;
	struct device_node___75 *child;
	struct device_node___75 *sibling;
	struct kobject___195 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___45 {
	struct fwnode_handle___176 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___47 {
	int (*match)(struct irq_domain___47 *, struct device_node___75 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___47 *, struct irq_fwspec___45 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___47 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___47 *, unsigned int);
	int (*xlate)(struct irq_domain___47 *, struct device_node___75 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___47 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___47 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___47 *, struct irq_data___48 *, bool);
	void (*deactivate)(struct irq_domain___47 *, struct irq_data___48 *);
	int (*translate)(struct irq_domain___47 *, struct irq_fwspec___45 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___47;

struct irq_domain___47 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___47 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___176 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___47 *gc;
	struct irq_domain___47 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___48 *revmap[0];
};

struct irq_chip_generic___47;

struct irq_domain_chip_generic___47 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___47 *gc[0];
};

struct dev_pm_ops___178 {
	int (*prepare)(struct device___178 *);
	void (*complete)(struct device___178 *);
	int (*suspend)(struct device___178 *);
	int (*resume)(struct device___178 *);
	int (*freeze)(struct device___178 *);
	int (*thaw)(struct device___178 *);
	int (*poweroff)(struct device___178 *);
	int (*restore)(struct device___178 *);
	int (*suspend_late)(struct device___178 *);
	int (*resume_early)(struct device___178 *);
	int (*freeze_late)(struct device___178 *);
	int (*thaw_early)(struct device___178 *);
	int (*poweroff_late)(struct device___178 *);
	int (*restore_early)(struct device___178 *);
	int (*suspend_noirq)(struct device___178 *);
	int (*resume_noirq)(struct device___178 *);
	int (*freeze_noirq)(struct device___178 *);
	int (*thaw_noirq)(struct device___178 *);
	int (*poweroff_noirq)(struct device___178 *);
	int (*restore_noirq)(struct device___178 *);
	int (*runtime_suspend)(struct device___178 *);
	int (*runtime_resume)(struct device___178 *);
	int (*runtime_idle)(struct device___178 *);
};

struct wakeup_source___178 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___178 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___178 {
	struct dev_pm_ops___178 ops;
	int (*start)(struct device___178 *);
	void (*detach)(struct device___178 *, bool);
	int (*activate)(struct device___178 *);
	void (*sync)(struct device___178 *);
	void (*dismiss)(struct device___178 *);
};

struct bus_type___178 {
	const char *name;
	const char *dev_name;
	struct device___178 *dev_root;
	const struct attribute_group___195 **bus_groups;
	const struct attribute_group___195 **dev_groups;
	const struct attribute_group___195 **drv_groups;
	int (*match)(struct device___178 *, struct device_driver___178 *);
	int (*uevent)(struct device___178 *, struct kobj_uevent_env *);
	int (*probe)(struct device___178 *);
	void (*sync_state)(struct device___178 *);
	void (*remove)(struct device___178 *);
	void (*shutdown)(struct device___178 *);
	int (*online)(struct device___178 *);
	int (*offline)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	int (*num_vf)(struct device___178 *);
	int (*dma_configure)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___178 {
	const char *name;
	struct bus_type___178 *bus;
	struct module___191 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___178 *);
	void (*sync_state)(struct device___178 *);
	int (*remove)(struct device___178 *);
	void (*shutdown)(struct device___178 *);
	int (*suspend)(struct device___178 *, pm_message_t);
	int (*resume)(struct device___178 *);
	const struct attribute_group___195 **groups;
	const struct attribute_group___195 **dev_groups;
	const struct dev_pm_ops___178 *pm;
	void (*coredump)(struct device___178 *);
	struct driver_private *p;
};

struct device_type___178 {
	const char *name;
	const struct attribute_group___195 **groups;
	int (*uevent)(struct device___178 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___178 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___178 *);
	const struct dev_pm_ops___178 *pm;
};

struct class___178 {
	const char *name;
	struct module___191 *owner;
	const struct attribute_group___195 **class_groups;
	const struct attribute_group___195 **dev_groups;
	struct kobject___195 *dev_kobj;
	int (*dev_uevent)(struct device___178 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___178 *, umode_t *);
	void (*class_release)(struct class___178 *);
	void (*dev_release)(struct device___178 *);
	int (*shutdown_pre)(struct device___178 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___178 *);
	void (*get_ownership)(struct device___178 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___178 *pm;
	struct subsys_private *p;
};

struct dentry_operations___207;

struct dentry___207 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___207 *d_parent;
	struct qstr d_name;
	struct inode___207 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___207 *d_op;
	struct super_block___207 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___207;

struct cdev___52;

struct inode___207 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___207 *i_op;
	struct super_block___207 *i_sb;
	struct address_space___207 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___208 *i_fop;
		void (*free_inode)(struct inode___207 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___207 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___68 *i_pipe;
		struct cdev___52 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___207 {
	int (*d_revalidate)(struct dentry___207 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___207 *, unsigned int);
	int (*d_hash)(const struct dentry___207 *, struct qstr *);
	int (*d_compare)(const struct dentry___207 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___207 *);
	int (*d_init)(struct dentry___207 *);
	void (*d_release)(struct dentry___207 *);
	void (*d_prune)(struct dentry___207 *);
	void (*d_iput)(struct dentry___207 *, struct inode___207 *);
	char * (*d_dname)(struct dentry___207 *, char *, int);
	struct vfsmount___207 * (*d_automount)(struct path___207 *);
	int (*d_manage)(const struct path___207 *, bool);
	struct dentry___207 * (*d_real)(struct dentry___207 *, const struct inode___207 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___207;

struct mem_dqinfo___207 {
	struct quota_format_type___207 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___207;

struct quota_info___207 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___207 *files[3];
	struct mem_dqinfo___207 info[3];
	const struct quota_format_ops___207 *ops[3];
};

struct rcuwait___208 {
	struct task_struct___214 *task;
};

struct percpu_rw_semaphore___208 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___208 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___207 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___208 rw_sem[3];
};

struct super_operations___207;

struct dquot_operations___207;

struct quotactl_ops___207;

struct super_block___207 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___207 *s_type;
	const struct super_operations___207 *s_op;
	const struct dquot_operations___207 *dq_op;
	const struct quotactl_ops___207 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___207 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___207 s_dquot;
	struct sb_writers___207 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___207 *s_d_op;
	int cleancache_poolid;
	struct shrinker___89 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___207 {
	struct dentry___207 *mnt_root;
	struct super_block___207 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct cgroup_subsys___142;

struct cgroup_subsys_state___142 {
	struct cgroup___142 *cgroup;
	struct cgroup_subsys___142 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___142 *parent;
};

struct cgroup_file___142 {
	struct kernfs_node___195 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___142 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___214 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___142;

struct cgroup_rstat_cpu___142;

struct cgroup___142 {
	struct cgroup_subsys_state___142 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___195 *kn;
	struct cgroup_file___142 procs_file;
	struct cgroup_file___142 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___142 *subsys[14];
	struct cgroup_root___142 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___142 *dom_cgrp;
	struct cgroup___142 *old_dom_cgrp;
	struct cgroup_rstat_cpu___142 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___142 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___207 {
	struct file___207 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___207 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___99 *ki_waitq;
	};
};

struct iattr___207 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___207 *ia_file;
};

struct dquot___207 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___207 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___207 {
	int qf_fmt_id;
	const struct quota_format_ops___207 *qf_ops;
	struct module___191 *qf_owner;
	struct quota_format_type___207 *qf_next;
};

struct quota_format_ops___207 {
	int (*check_quota_file)(struct super_block___207 *, int);
	int (*read_file_info)(struct super_block___207 *, int);
	int (*write_file_info)(struct super_block___207 *, int);
	int (*free_file_info)(struct super_block___207 *, int);
	int (*read_dqblk)(struct dquot___207 *);
	int (*commit_dqblk)(struct dquot___207 *);
	int (*release_dqblk)(struct dquot___207 *);
	int (*get_next_id)(struct super_block___207 *, struct kqid *);
};

struct dquot_operations___207 {
	int (*write_dquot)(struct dquot___207 *);
	struct dquot___207 * (*alloc_dquot)(struct super_block___207 *, int);
	void (*destroy_dquot)(struct dquot___207 *);
	int (*acquire_dquot)(struct dquot___207 *);
	int (*release_dquot)(struct dquot___207 *);
	int (*mark_dirty)(struct dquot___207 *);
	int (*write_info)(struct super_block___207 *, int);
	qsize_t * (*get_reserved_space)(struct inode___207 *);
	int (*get_projid)(struct inode___207 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___207 *, qsize_t *);
	int (*get_next_id)(struct super_block___207 *, struct kqid *);
};

struct quotactl_ops___207 {
	int (*quota_on)(struct super_block___207 *, int, int, const struct path___207 *);
	int (*quota_off)(struct super_block___207 *, int);
	int (*quota_enable)(struct super_block___207 *, unsigned int);
	int (*quota_disable)(struct super_block___207 *, unsigned int);
	int (*quota_sync)(struct super_block___207 *, int);
	int (*set_info)(struct super_block___207 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___207 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___207 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___207 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___207 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___207 *, unsigned int);
};

struct address_space_operations___207 {
	int (*writepage)(struct page___212 *, struct writeback_control___3 *);
	int (*readpage)(struct file___207 *, struct page___212 *);
	int (*writepages)(struct address_space___207 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___212 *);
	int (*readpages)(struct file___207 *, struct address_space___207 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___207 *, struct address_space___207 *, loff_t, unsigned int, unsigned int, struct page___212 **, void **);
	int (*write_end)(struct file___207 *, struct address_space___207 *, loff_t, unsigned int, unsigned int, struct page___212 *, void *);
	sector_t (*bmap)(struct address_space___207 *, sector_t);
	void (*invalidatepage)(struct page___212 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___212 *, gfp_t);
	void (*freepage)(struct page___212 *);
	ssize_t (*direct_IO)(struct kiocb___207 *, struct iov_iter___128 *);
	int (*migratepage)(struct address_space___207 *, struct page___212 *, struct page___212 *, enum migrate_mode);
	bool (*isolate_page)(struct page___212 *, isolate_mode_t);
	void (*putback_page)(struct page___212 *);
	int (*launder_page)(struct page___212 *);
	int (*is_partially_uptodate)(struct page___212 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___212 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___207 *, struct page___212 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___207 *, sector_t *);
	void (*swap_deactivate)(struct file___207 *);
};

struct bio_vec___125;

struct iov_iter___128 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___125 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___68 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___52 {
	struct kobject___195 kobj;
	struct module___191 *owner;
	const struct file_operations___208 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___207 {
	struct dentry___207 * (*lookup)(struct inode___207 *, struct dentry___207 *, unsigned int);
	const char * (*get_link)(struct dentry___207 *, struct inode___207 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___207 *, int);
	struct posix_acl * (*get_acl)(struct inode___207 *, int, bool);
	int (*readlink)(struct dentry___207 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___207 *, struct dentry___207 *, umode_t, bool);
	int (*link)(struct dentry___207 *, struct inode___207 *, struct dentry___207 *);
	int (*unlink)(struct inode___207 *, struct dentry___207 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___207 *, struct dentry___207 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___207 *, struct dentry___207 *, umode_t);
	int (*rmdir)(struct inode___207 *, struct dentry___207 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___207 *, struct dentry___207 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___207 *, struct dentry___207 *, struct inode___207 *, struct dentry___207 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___207 *, struct iattr___207 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___207 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___207 *, char *, size_t);
	int (*fiemap)(struct inode___207 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___207 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___207 *, struct dentry___207 *, struct file___207 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___207 *, struct dentry___207 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___207 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___207 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___207 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___207 {
	void (*fl_copy_lock)(struct file_lock___207 *, struct file_lock___207 *);
	void (*fl_release_private)(struct file_lock___207 *);
};

struct lock_manager_operations___207;

struct file_lock___207 {
	struct file_lock___207 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___207 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___207 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___207 *fl_ops;
	const struct lock_manager_operations___207 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___207 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___207 *);
	int (*lm_grant)(struct file_lock___207 *, int);
	bool (*lm_break)(struct file_lock___207 *);
	int (*lm_change)(struct file_lock___207 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___207 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___207 *);
};

struct fasync_struct___207 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___207 *fa_next;
	struct file___207 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___207 {
	struct inode___207 * (*alloc_inode)(struct super_block___207 *);
	void (*destroy_inode)(struct inode___207 *);
	void (*free_inode)(struct inode___207 *);
	void (*dirty_inode)(struct inode___207 *, int);
	int (*write_inode)(struct inode___207 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___207 *);
	void (*evict_inode)(struct inode___207 *);
	void (*put_super)(struct super_block___207 *);
	int (*sync_fs)(struct super_block___207 *, int);
	int (*freeze_super)(struct super_block___207 *);
	int (*freeze_fs)(struct super_block___207 *);
	int (*thaw_super)(struct super_block___207 *);
	int (*unfreeze_fs)(struct super_block___207 *);
	int (*statfs)(struct dentry___207 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___207 *, int *, char *);
	void (*umount_begin)(struct super_block___207 *);
	int (*show_options)(struct seq_file___182 *, struct dentry___207 *);
	int (*show_devname)(struct seq_file___182 *, struct dentry___207 *);
	int (*show_path)(struct seq_file___182 *, struct dentry___207 *);
	int (*show_stats)(struct seq_file___182 *, struct dentry___207 *);
	ssize_t (*quota_read)(struct super_block___207 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___207 *, int, const char *, size_t, loff_t);
	struct dquot___207 ** (*get_dquots)(struct inode___207 *);
	long int (*nr_cached_objects)(struct super_block___207 *, struct shrink_control___89 *);
	long int (*free_cached_objects)(struct super_block___207 *, struct shrink_control___89 *);
	struct file___207 * (*real_loop)(struct file___207 *);
};

struct kernel_param_ops___191 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___191 *);
	int (*get)(char *, const struct kernel_param___191 *);
	void (*free)(void *);
};

struct kparam_array___191;

struct kernel_param___191 {
	const char *name;
	struct module___191 *mod;
	const struct kernel_param_ops___191 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___191 *arr;
	};
};

struct kparam_array___191 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___191 *ops;
	void *elem;
};

struct module_attribute___191 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___191 *, struct module_kobject___192 *, char *);
	ssize_t (*store)(struct module_attribute___191 *, struct module_kobject___192 *, const char *, size_t);
	void (*setup)(struct module___191 *, const char *);
	int (*test)(struct module___191 *);
	void (*free)(struct module___191 *);
};

struct acpi_device___14;

struct acpi_hotplug_profile___14 {
	struct kobject___195 kobj;
	int (*scan_dependent)(struct acpi_device___14 *);
	void (*notify_online)(struct acpi_device___14 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___14 {
	void (*func)(struct acpi_device_wakeup_context___14 *);
	struct device___178 *dev;
};

struct acpi_device_wakeup___14 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___14 context;
	struct wakeup_source___178 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___14;

struct acpi_hotplug_context___14;

struct acpi_driver___14;

struct acpi_device___14 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___176 fwnode;
	struct acpi_device___14 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___14 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___14 *handler;
	struct acpi_hotplug_context___14 *hp;
	struct acpi_driver___14 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___178 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___14 *);
};

struct acpi_scan_handler___14 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___14 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___14 *);
	void (*bind)(struct device___178 *);
	void (*unbind)(struct device___178 *);
	struct acpi_hotplug_profile___14 hotplug;
};

struct acpi_hotplug_context___14 {
	struct acpi_device___14 *self;
	int (*notify)(struct acpi_device___14 *, u32);
	void (*uevent)(struct acpi_device___14 *, u32);
	void (*fixup)(struct acpi_device___14 *);
};

typedef int (*acpi_op_add___14)(struct acpi_device___14 *);

typedef int (*acpi_op_remove___14)(struct acpi_device___14 *);

typedef void (*acpi_op_notify___14)(struct acpi_device___14 *, u32);

struct acpi_device_ops___14 {
	acpi_op_add___14 add;
	acpi_op_remove___14 remove;
	acpi_op_notify___14 notify;
};

struct acpi_driver___14 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___14 ops;
	struct device_driver___178 drv;
	struct module___191 *owner;
};

struct irq_chip___48 {
	struct device___178 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___48 *);
	void (*irq_shutdown)(struct irq_data___48 *);
	void (*irq_enable)(struct irq_data___48 *);
	void (*irq_disable)(struct irq_data___48 *);
	void (*irq_ack)(struct irq_data___48 *);
	void (*irq_mask)(struct irq_data___48 *);
	void (*irq_mask_ack)(struct irq_data___48 *);
	void (*irq_unmask)(struct irq_data___48 *);
	void (*irq_eoi)(struct irq_data___48 *);
	int (*irq_set_affinity)(struct irq_data___48 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___48 *);
	int (*irq_set_type)(struct irq_data___48 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___48 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___48 *);
	void (*irq_bus_sync_unlock)(struct irq_data___48 *);
	void (*irq_cpu_online)(struct irq_data___48 *);
	void (*irq_cpu_offline)(struct irq_data___48 *);
	void (*irq_suspend)(struct irq_data___48 *);
	void (*irq_resume)(struct irq_data___48 *);
	void (*irq_pm_shutdown)(struct irq_data___48 *);
	void (*irq_calc_mask)(struct irq_data___48 *);
	void (*irq_print_chip)(struct irq_data___48 *, struct seq_file___182 *);
	int (*irq_request_resources)(struct irq_data___48 *);
	void (*irq_release_resources)(struct irq_data___48 *);
	void (*irq_compose_msi_msg)(struct irq_data___48 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___48 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___48 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___48 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___48 *, void *);
	void (*ipi_send_single)(struct irq_data___48 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___48 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___48 *);
	void (*irq_nmi_teardown)(struct irq_data___48 *);
	long unsigned int flags;
};

struct irqaction___32 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___32 *next;
	irq_handler_t thread_fn;
	struct task_struct___214 *thread;
	struct irqaction___32 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___47 {
	struct irq_chip___48 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___49 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___47 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___47 *);
	void (*resume)(struct irq_chip_generic___47 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___47 *domain;
	struct list_head list;
	struct irq_chip_type___47 chip_types[0];
};

struct seq_operations___182 {
	void * (*start)(struct seq_file___182 *, loff_t *);
	void (*stop)(struct seq_file___182 *, void *);
	void * (*next)(struct seq_file___182 *, void *, loff_t *);
	int (*show)(struct seq_file___182 *, void *);
};

struct dev_pagemap_ops___202 {
	void (*page_free)(struct page___212 *);
	void (*kill)(struct dev_pagemap___202 *);
	void (*cleanup)(struct dev_pagemap___202 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___202 *);
};

struct fqdir___43;

struct netns_ipv4___43 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___43 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___40;

struct sk_buff___39;

struct dst_ops___43 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___43 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___40 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___39 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___39 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___39 *);
	int (*local_out)(struct net___43 *, struct sock *, struct sk_buff___39 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___39 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___43 {
	struct dst_ops___43 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___43 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___43 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___43 *fqdir;
};

struct sk_buff_head___38 {
	struct sk_buff___39 *next;
	struct sk_buff___39 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___43 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___43 xfrm4_dst_ops;
	struct dst_ops___43 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___43 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct idr netns_ids;
	struct ns_common___26 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___40 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___43 ipv4;
	struct netns_ipv6___43 ipv6;
	struct netns_ieee802154_lowpan___43 ieee802154_lowpan;
	struct netns_sctp___29 sctp;
	struct netns_nf___3 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___38 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___36 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___43 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___142 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___142 *root_cset;
};

struct bio_vec___125 {
	struct page___212 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct sk_buff___39 {
	union {
		struct {
			struct sk_buff___39 *next;
			struct sk_buff___39 *prev;
			union {
				struct net_device___40 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___30 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___39 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct pipe_buf_operations___68;

struct pipe_buffer___68 {
	struct page___212 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___68 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___68 {
	int (*confirm)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
	void (*release)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
	bool (*try_steal)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
	bool (*get)(struct pipe_inode_info___68 *, struct pipe_buffer___68 *);
};

typedef rx_handler_result_t rx_handler_func_t___38(struct sk_buff___39 **);

typedef struct {
	struct net___43 *net;
} possible_net_t___38;

struct netdev_name_node___38;

struct net_device_ops___38;

struct ethtool_ops___14;

struct xfrmdev_ops___38;

struct header_ops___38;

struct netdev_rx_queue___38;

struct netdev_queue___38;

struct dcbnl_rtnl_ops___38;

struct phy_device___2;

struct net_device___40 {
	char name[16];
	struct netdev_name_node___38 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___38 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___14 *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___38 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___38 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___195 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___38 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___38 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___38 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___38 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___38 = 0,
		NETREG_REGISTERED___38 = 1,
		NETREG_UNREGISTERING___38 = 2,
		NETREG_UNREGISTERED___38 = 3,
		NETREG_RELEASED___38 = 4,
		NETREG_DUMMY___38 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___38 = 0,
		RTNL_LINK_INITIALIZING___38 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___40 *);
	struct netpoll_info *npinfo;
	possible_net_t___38 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___178 dev;
	const struct attribute_group___195 *sysfs_groups[4];
	const struct attribute_group___195 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___38 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___2 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___36 xdp_state[3];
	long: 64;
};

struct inet_frags___43;

struct fqdir___43 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___43 *f;
	struct net___43 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___43;

struct inet_frags___43 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___43 *, const void *);
	void (*destructor)(struct inet_frag_queue___43 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___43 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___39 *fragments_tail;
	struct sk_buff___39 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___43 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___38 {
	int (*ieee_getets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___40 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___40 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___40 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___40 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___40 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___40 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___40 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___40 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___40 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___40 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___40 *);
	u8 (*setstate)(struct net_device___40 *, u8);
	void (*getpermhwaddr)(struct net_device___40 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___40 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___40 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___40 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___40 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___40 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___40 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___40 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___40 *, int, u8 *);
	void (*setpfccfg)(struct net_device___40 *, int, u8);
	void (*getpfccfg)(struct net_device___40 *, int, u8 *);
	u8 (*setall)(struct net_device___40 *);
	u8 (*getcap)(struct net_device___40 *, int, u8 *);
	int (*getnumtcs)(struct net_device___40 *, int, u8 *);
	int (*setnumtcs)(struct net_device___40 *, int, u8);
	u8 (*getpfcstate)(struct net_device___40 *);
	void (*setpfcstate)(struct net_device___40 *, u8);
	void (*getbcncfg)(struct net_device___40 *, int, u32 *);
	void (*setbcncfg)(struct net_device___40 *, int, u32);
	void (*getbcnrp)(struct net_device___40 *, int, u8 *);
	void (*setbcnrp)(struct net_device___40 *, int, u8);
	int (*setapp)(struct net_device___40 *, u8, u16, u8);
	int (*getapp)(struct net_device___40 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___40 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___40 *, int, u8);
	u8 (*getdcbx)(struct net_device___40 *);
	u8 (*setdcbx)(struct net_device___40 *, u8);
	int (*peer_getappinfo)(struct net_device___40 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___40 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___40 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___40 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___40 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___40 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___41;

typedef int (*bpf_iter_init_seq_priv_t___40)(void *, struct bpf_iter_aux_info___41 *);

struct bpf_map___41;

struct bpf_iter_aux_info___41 {
	struct bpf_map___41 *map;
};

struct bpf_iter_seq_info___40 {
	const struct seq_operations___182 *seq_ops;
	bpf_iter_init_seq_priv_t___40 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___41;

struct bpf_map_ops___40 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___41 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___41 *, struct file___207 *);
	void (*map_free)(struct bpf_map___41 *);
	int (*map_get_next_key)(struct bpf_map___41 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___41 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___41 *, void *);
	int (*map_lookup_batch)(struct bpf_map___41 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___41 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___41 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___41 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___41 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___41 *, void *);
	int (*map_update_elem)(struct bpf_map___41 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___41 *, void *);
	int (*map_push_elem)(struct bpf_map___41 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___41 *, void *);
	int (*map_peek_elem)(struct bpf_map___41 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___41 *, struct file___207 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___41 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___41 *, void *, struct seq_file___182 *);
	int (*map_check_btf)(const struct bpf_map___41 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___41 *, struct bpf_prog_aux___41 *);
	void (*map_poke_untrack)(struct bpf_map___41 *, struct bpf_prog_aux___41 *);
	void (*map_poke_run)(struct bpf_map___41 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___41 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___41 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___41 *, struct vm_area_struct___212 *);
	__poll_t (*map_poll)(struct bpf_map___41 *, struct file___207 *, struct poll_table_struct___136 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___41 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___41 *, const struct bpf_map___41 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___41 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___40 *iter_seq_info;
};

struct bpf_map___41 {
	const struct bpf_map_ops___40 *ops;
	struct bpf_map___41 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___40;

struct bpf_jit_poke_descriptor___40;

struct btf_mod_pair___40;

struct bpf_prog_offload___38;

struct bpf_prog_aux___41 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___40 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___40 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___36 *ops;
	struct bpf_map___41 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___40 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___41 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___38 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___38;

struct bpf_map_dev_ops___38 {
	int (*map_get_next_key)(struct bpf_offloaded_map___38 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___38 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___38 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___38 *, void *);
};

struct bpf_offloaded_map___38 {
	struct bpf_map___41 map;
	struct net_device___40 *netdev;
	const struct bpf_map_dev_ops___38 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___38 {
	struct bpf_prog *prog;
	struct net_device___40 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___40 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___191 *mod;
};

struct bpf_jit_poke_descriptor___40 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___41 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___40 {
	struct btf *btf;
	struct module___191 *module;
};

struct cftype___142;

struct cgroup_subsys___142 {
	struct cgroup_subsys_state___142 * (*css_alloc)(struct cgroup_subsys_state___142 *);
	int (*css_online)(struct cgroup_subsys_state___142 *);
	void (*css_offline)(struct cgroup_subsys_state___142 *);
	void (*css_released)(struct cgroup_subsys_state___142 *);
	void (*css_free)(struct cgroup_subsys_state___142 *);
	void (*css_reset)(struct cgroup_subsys_state___142 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___142 *, int);
	int (*css_extra_stat_show)(struct seq_file___182 *, struct cgroup_subsys_state___142 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___214 *, struct css_set___142 *);
	void (*cancel_fork)(struct task_struct___214 *, struct css_set___142 *);
	void (*fork)(struct task_struct___214 *);
	void (*exit)(struct task_struct___214 *);
	void (*release)(struct task_struct___214 *);
	void (*bind)(struct cgroup_subsys_state___142 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___142 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___142 *dfl_cftypes;
	struct cftype___142 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___142 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___142 *updated_children;
	struct cgroup___142 *updated_next;
};

struct cgroup_root___142 {
	struct kernfs_root___195 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___142 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___142 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___142 *ss;
	struct list_head node;
	struct kernfs_ops___195 *kf_ops;
	int (*open)(struct kernfs_open_file___195 *);
	void (*release)(struct kernfs_open_file___195 *);
	u64 (*read_u64)(struct cgroup_subsys_state___142 *, struct cftype___142 *);
	s64 (*read_s64)(struct cgroup_subsys_state___142 *, struct cftype___142 *);
	int (*seq_show)(struct seq_file___182 *, void *);
	void * (*seq_start)(struct seq_file___182 *, loff_t *);
	void * (*seq_next)(struct seq_file___182 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___182 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___142 *, struct cftype___142 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___142 *, struct cftype___142 *, s64);
	ssize_t (*write)(struct kernfs_open_file___195 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___195 *, struct poll_table_struct___136 *);
};

struct xdp_rxq_info___38 {
	struct net_device___40 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___38 {
	struct net_device___40 *dev;
};

struct xdp_buff___38 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___38 *rxq;
	struct xdp_txq_info___38 *txq;
	u32 frame_sz;
};

struct xdp_frame___38 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___40 *dev_rx;
};

struct netlink_callback___38 {
	struct sk_buff___39 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___39 *, struct netlink_callback___38 *);
	int (*done)(struct netlink_callback___38 *);
	void *data;
	struct module___191 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___38 {
	int (*create)(struct sk_buff___39 *, struct net_device___40 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___39 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___40 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___39 *);
};

struct netdev_queue___38 {
	struct net_device___40 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___195 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___40 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___38 {
	struct xdp_rxq_info___38 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___195 kobj;
	struct net_device___40 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___38 {
	enum net_device_path_type type;
	const struct net_device___40 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___38 = 0,
				DEV_PATH_BR_VLAN_TAG___38 = 1,
				DEV_PATH_BR_VLAN_UNTAG___38 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___38 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___38 {
	const struct net_device___40 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___38 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___36 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___38 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___38 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___39 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___38 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___40 *dev;
	const char *name;
};

struct net_device_ops___38 {
	int (*ndo_init)(struct net_device___40 *);
	void (*ndo_uninit)(struct net_device___40 *);
	int (*ndo_open)(struct net_device___40 *);
	int (*ndo_stop)(struct net_device___40 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___39 *, struct net_device___40 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___39 *, struct net_device___40 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___40 *, struct sk_buff___39 *, struct net_device___40 *);
	void (*ndo_change_rx_flags)(struct net_device___40 *, int);
	void (*ndo_set_rx_mode)(struct net_device___40 *);
	int (*ndo_set_mac_address)(struct net_device___40 *, void *);
	int (*ndo_validate_addr)(struct net_device___40 *);
	int (*ndo_do_ioctl)(struct net_device___40 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___40 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___40 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___40 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___40 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___40 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___40 *, int);
	int (*ndo_neigh_setup)(struct net_device___40 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___40 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___40 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___40 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___40 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___40 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___40 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___40 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___40 *);
	int (*ndo_netpoll_setup)(struct net_device___40 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___40 *);
	int (*ndo_set_vf_mac)(struct net_device___40 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___40 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___40 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___40 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___40 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___40 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___40 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___40 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___40 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___40 *, int, struct sk_buff___39 *);
	int (*ndo_get_vf_guid)(struct net_device___40 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___40 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___40 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___40 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___40 *);
	int (*ndo_fcoe_disable)(struct net_device___40 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___40 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___40 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___40 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___40 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___40 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___40 *, const struct sk_buff___39 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___40 *, struct net_device___40 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___40 *, struct net_device___40 *);
	struct net_device___40 * (*ndo_get_xmit_slave)(struct net_device___40 *, struct sk_buff___39 *, bool);
	struct net_device___40 * (*ndo_sk_get_lower_dev)(struct net_device___40 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___40 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___40 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___40 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___40 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___39 *, struct netlink_callback___38 *, struct net_device___40 *, struct net_device___40 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___39 *, struct nlattr **, struct net_device___40 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___40 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___39 *, u32, u32, struct net_device___40 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___40 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___40 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___40 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___40 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___40 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___40 *, struct net_device___40 *);
	void (*ndo_dfwd_del_station)(struct net_device___40 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___40 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___40 *);
	int (*ndo_change_proto_down)(struct net_device___40 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___40 *, struct sk_buff___39 *);
	void (*ndo_set_rx_headroom)(struct net_device___40 *, int);
	int (*ndo_bpf)(struct net_device___40 *, struct netdev_bpf___38 *);
	int (*ndo_xdp_xmit)(struct net_device___40 *, int, struct xdp_frame___38 **, u32);
	struct net_device___40 * (*ndo_xdp_get_xmit_slave)(struct net_device___40 *, struct xdp_buff___38 *);
	int (*ndo_xsk_wakeup)(struct net_device___40 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___40 *);
	int (*ndo_tunnel_ctl)(struct net_device___40 *, struct ip_tunnel_parm *, int);
	struct net_device___40 * (*ndo_get_peer_dev)(struct net_device___40 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___38 *, struct net_device_path___38 *);
};

struct ethtool_ops___14 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___40 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___40 *);
	void (*get_regs)(struct net_device___40 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___40 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___40 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___40 *);
	void (*set_msglevel)(struct net_device___40 *, u32);
	int (*nway_reset)(struct net_device___40 *);
	u32 (*get_link)(struct net_device___40 *);
	int (*get_link_ext_state)(struct net_device___40 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___40 *);
	int (*get_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___40 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___40 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___40 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___40 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___40 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___40 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___40 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___40 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___40 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___40 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___40 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___40 *);
	void (*complete)(struct net_device___40 *);
	u32 (*get_priv_flags)(struct net_device___40 *);
	int (*set_priv_flags)(struct net_device___40 *, u32);
	int (*get_sset_count)(struct net_device___40 *, int);
	int (*get_rxnfc)(struct net_device___40 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___40 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___40 *, struct ethtool_flash *);
	int (*reset)(struct net_device___40 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___40 *);
	u32 (*get_rxfh_indir_size)(struct net_device___40 *);
	int (*get_rxfh)(struct net_device___40 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___40 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___40 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___40 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___40 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___40 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___40 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___40 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___40 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___40 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___40 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___40 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___40 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___40 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___40 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___40 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___40 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___40 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___40 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___40 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___40 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___40 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___40 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___40 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___40 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___40 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___40 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___40 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___40 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___40 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___40 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct mii_bus___2;

struct mdio_device___2 {
	struct device___178 dev;
	struct mii_bus___2 *bus;
	char modalias[32];
	int (*bus_match)(struct device___178 *, struct device_driver___178 *);
	void (*device_free)(struct mdio_device___2 *);
	void (*device_remove)(struct mdio_device___2 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_c45_device_ids {
	u32 devices_in_package;
	u32 mmds_present;
	u32 device_ids[32];
};

enum phy_state {
	PHY_DOWN = 0,
	PHY_READY = 1,
	PHY_HALTED = 2,
	PHY_UP = 3,
	PHY_RUNNING = 4,
	PHY_NOLINK = 5,
	PHY_CABLETEST = 6,
};

typedef enum {
	PHY_INTERFACE_MODE_NA = 0,
	PHY_INTERFACE_MODE_INTERNAL = 1,
	PHY_INTERFACE_MODE_MII = 2,
	PHY_INTERFACE_MODE_GMII = 3,
	PHY_INTERFACE_MODE_SGMII = 4,
	PHY_INTERFACE_MODE_TBI = 5,
	PHY_INTERFACE_MODE_REVMII = 6,
	PHY_INTERFACE_MODE_RMII = 7,
	PHY_INTERFACE_MODE_REVRMII = 8,
	PHY_INTERFACE_MODE_RGMII = 9,
	PHY_INTERFACE_MODE_RGMII_ID = 10,
	PHY_INTERFACE_MODE_RGMII_RXID = 11,
	PHY_INTERFACE_MODE_RGMII_TXID = 12,
	PHY_INTERFACE_MODE_RTBI = 13,
	PHY_INTERFACE_MODE_SMII = 14,
	PHY_INTERFACE_MODE_XGMII = 15,
	PHY_INTERFACE_MODE_XLGMII = 16,
	PHY_INTERFACE_MODE_MOCA = 17,
	PHY_INTERFACE_MODE_QSGMII = 18,
	PHY_INTERFACE_MODE_TRGMII = 19,
	PHY_INTERFACE_MODE_100BASEX = 20,
	PHY_INTERFACE_MODE_1000BASEX = 21,
	PHY_INTERFACE_MODE_2500BASEX = 22,
	PHY_INTERFACE_MODE_5GBASER = 23,
	PHY_INTERFACE_MODE_RXAUI = 24,
	PHY_INTERFACE_MODE_XAUI = 25,
	PHY_INTERFACE_MODE_10GBASER = 26,
	PHY_INTERFACE_MODE_25GBASER = 27,
	PHY_INTERFACE_MODE_USXGMII = 28,
	PHY_INTERFACE_MODE_10GKR = 29,
	PHY_INTERFACE_MODE_MAX = 30,
} phy_interface_t;

struct phylink;

struct phy_driver;

struct phy_led_trigger;

struct mii_timestamper;

struct phy_device___2 {
	struct mdio_device___2 mdio;
	struct phy_driver *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___39 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___40 *attached_dev;
	struct mii_timestamper *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___2 *, bool);
	void (*adjust_link)(struct net_device___40 *);
	const struct macsec_ops *macsec_ops;
};

struct phy_tdr_config {
	u32 first;
	u32 last;
	u32 step;
	s8 pair;
};

struct mii_bus___2 {
	struct module___191 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___2 *, int, int);
	int (*write)(struct mii_bus___2 *, int, int, u16);
	int (*reset)(struct mii_bus___2 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___178 *parent;
	enum {
		MDIOBUS_ALLOCATED___2 = 1,
		MDIOBUS_REGISTERED___2 = 2,
		MDIOBUS_UNREGISTERED___2 = 3,
		MDIOBUS_RELEASED___2 = 4,
	} state;
	struct device___178 dev;
	struct mdio_device___2 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___2 = 0,
		MDIOBUS_C22___2 = 1,
		MDIOBUS_C45___2 = 2,
		MDIOBUS_C22_C45___2 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___2 {
	struct device_driver___178 driver;
	int flags;
};

struct mii_timestamper {
	bool (*rxtstamp)(struct mii_timestamper *, struct sk_buff___39 *, int);
	void (*txtstamp)(struct mii_timestamper *, struct sk_buff___39 *, int);
	int (*hwtstamp)(struct mii_timestamper *, struct ifreq *);
	void (*link_state)(struct mii_timestamper *, struct phy_device___2 *);
	int (*ts_info)(struct mii_timestamper *, struct ethtool_ts_info *);
	struct device___178 *device;
};

struct phy_driver {
	struct mdio_driver_common___2 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___2 *);
	int (*config_init)(struct phy_device___2 *);
	int (*probe)(struct phy_device___2 *);
	int (*get_features)(struct phy_device___2 *);
	int (*suspend)(struct phy_device___2 *);
	int (*resume)(struct phy_device___2 *);
	int (*config_aneg)(struct phy_device___2 *);
	int (*aneg_done)(struct phy_device___2 *);
	int (*read_status)(struct phy_device___2 *);
	int (*config_intr)(struct phy_device___2 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___2 *);
	void (*remove)(struct phy_device___2 *);
	int (*match_phy_device)(struct phy_device___2 *);
	int (*set_wol)(struct phy_device___2 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___2 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___2 *);
	int (*read_mmd)(struct phy_device___2 *, int, u16);
	int (*write_mmd)(struct phy_device___2 *, int, u16, u16);
	int (*read_page)(struct phy_device___2 *);
	int (*write_page)(struct phy_device___2 *, int);
	int (*module_info)(struct phy_device___2 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___2 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___2 *);
	int (*cable_test_tdr_start)(struct phy_device___2 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___2 *, bool *);
	int (*get_sset_count)(struct phy_device___2 *);
	void (*get_strings)(struct phy_device___2 *, u8 *);
	void (*get_stats)(struct phy_device___2 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___2 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___2 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___2 *, bool);
	int (*get_sqi)(struct phy_device___2 *);
	int (*get_sqi_max)(struct phy_device___2 *);
};

struct cache_type_info {
	const char *size_prop;
	const char *line_size_props[2];
	const char *nr_sets_prop;
};

struct wakeup_source___179;

struct device___179;

struct dev_pm_info___179 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___179 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___6 *subsys_data;
	void (*set_latency_tolerance)(struct device___179 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___9;

struct device_type___179;

struct bus_type___179;

struct device_driver___179;

struct dev_pm_domain___179;

struct fwnode_handle___177;

struct class___179;

struct device___179 {
	struct kobject___41 kobj;
	struct device___179 *parent;
	struct device_private___9 *p;
	const char *init_name;
	const struct device_type___179 *type;
	struct bus_type___179 *bus;
	struct device_driver___179 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___179 power;
	struct dev_pm_domain___179 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___177 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___179 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___179 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___179 {
	int (*prepare)(struct device___179 *);
	void (*complete)(struct device___179 *);
	int (*suspend)(struct device___179 *);
	int (*resume)(struct device___179 *);
	int (*freeze)(struct device___179 *);
	int (*thaw)(struct device___179 *);
	int (*poweroff)(struct device___179 *);
	int (*restore)(struct device___179 *);
	int (*suspend_late)(struct device___179 *);
	int (*resume_early)(struct device___179 *);
	int (*freeze_late)(struct device___179 *);
	int (*thaw_early)(struct device___179 *);
	int (*poweroff_late)(struct device___179 *);
	int (*restore_early)(struct device___179 *);
	int (*suspend_noirq)(struct device___179 *);
	int (*resume_noirq)(struct device___179 *);
	int (*freeze_noirq)(struct device___179 *);
	int (*thaw_noirq)(struct device___179 *);
	int (*poweroff_noirq)(struct device___179 *);
	int (*restore_noirq)(struct device___179 *);
	int (*runtime_suspend)(struct device___179 *);
	int (*runtime_resume)(struct device___179 *);
	int (*runtime_idle)(struct device___179 *);
};

struct wakeup_source___179 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___179 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___179 {
	struct dev_pm_ops___179 ops;
	int (*start)(struct device___179 *);
	void (*detach)(struct device___179 *, bool);
	int (*activate)(struct device___179 *);
	void (*sync)(struct device___179 *);
	void (*dismiss)(struct device___179 *);
};

struct subsys_private___9;

struct bus_type___179 {
	const char *name;
	const char *dev_name;
	struct device___179 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___179 *, struct device_driver___179 *);
	int (*uevent)(struct device___179 *, struct kobj_uevent_env *);
	int (*probe)(struct device___179 *);
	void (*sync_state)(struct device___179 *);
	void (*remove)(struct device___179 *);
	void (*shutdown)(struct device___179 *);
	int (*online)(struct device___179 *);
	int (*offline)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	int (*num_vf)(struct device___179 *);
	int (*dma_configure)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___9 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___9;

struct device_driver___179 {
	const char *name;
	struct bus_type___179 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___179 *);
	void (*sync_state)(struct device___179 *);
	int (*remove)(struct device___179 *);
	void (*shutdown)(struct device___179 *);
	int (*suspend)(struct device___179 *, pm_message_t);
	int (*resume)(struct device___179 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___179 *pm;
	void (*coredump)(struct device___179 *);
	struct driver_private___9 *p;
};

struct subsys_private___9 {
	struct kset___41 subsys;
	struct kset___41 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___41 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___179 *bus;
	struct kset___41 glue_dirs;
	struct class___179 *class;
};

struct device_type___179 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___179 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___179 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___179 *);
	const struct dev_pm_ops___179 *pm;
};

struct class___179 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___179 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___179 *, umode_t *);
	void (*class_release)(struct class___179 *);
	void (*dev_release)(struct device___179 *);
	int (*shutdown_pre)(struct device___179 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___179 *);
	void (*get_ownership)(struct device___179 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___179 *pm;
	struct subsys_private___9 *p;
};

struct driver_private___9 {
	struct kobject___41 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___191 *mkobj;
	struct device_driver___179 *driver;
};

struct device_private___9 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___179 *async_driver;
	char *deferred_probe_reason;
	struct device___179 *device;
	u8 dead;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___177;

struct fwnode_handle___177 {
	struct fwnode_handle___177 *secondary;
	const struct fwnode_operations___177 *ops;
	struct device___179 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___177;

struct fwnode_endpoint___177;

struct fwnode_operations___177 {
	struct fwnode_handle___177 * (*get)(struct fwnode_handle___177 *);
	void (*put)(struct fwnode_handle___177 *);
	bool (*device_is_available)(const struct fwnode_handle___177 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___177 *, const struct device___179 *);
	bool (*property_present)(const struct fwnode_handle___177 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___177 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___177 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___177 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*get_parent)(const struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*get_next_child_node)(const struct fwnode_handle___177 *, struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*get_named_child_node)(const struct fwnode_handle___177 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___177 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___177 *);
	struct fwnode_handle___177 * (*graph_get_next_endpoint)(const struct fwnode_handle___177 *, struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*graph_get_remote_endpoint)(const struct fwnode_handle___177 *);
	struct fwnode_handle___177 * (*graph_get_port_parent)(struct fwnode_handle___177 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___177 *, struct fwnode_endpoint___177 *);
	int (*add_links)(struct fwnode_handle___177 *);
};

struct fwnode_endpoint___177 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___177 *local_fwnode;
};

struct fwnode_reference_args___177 {
	struct fwnode_handle___177 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct software_node___2;

struct software_node_ref_args {
	const struct software_node___2 *node;
	unsigned int nargs;
	u64 args[8];
};

struct software_node___2 {
	const char *name;
	const struct software_node___2 *parent;
	const struct property_entry___2 *properties;
};

struct swnode {
	struct kobject___41 kobj;
	struct fwnode_handle___177 fwnode;
	const struct software_node___2 *node;
	int id;
	struct ida child_ids;
	struct list_head entry;
	struct list_head children;
	struct swnode *parent;
	unsigned int allocated;
	unsigned int managed;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wakeup_source___180;

struct pm_subsys_data___7;

struct device___180;

struct dev_pm_info___180 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___180 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___180 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___10;

struct device_type___180;

struct bus_type___180;

struct device_driver___180;

struct dev_pm_domain___180;

struct device_node___76;

struct fwnode_handle___178;

struct class___180;

struct device___180 {
	struct kobject___190 kobj;
	struct device___180 *parent;
	struct device_private___10 *p;
	const char *init_name;
	const struct device_type___180 *type;
	struct bus_type___180 *bus;
	struct device_driver___180 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___180 power;
	struct dev_pm_domain___180 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___76 *of_node;
	struct fwnode_handle___178 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___180 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___180 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___180 {
	int (*prepare)(struct device___180 *);
	void (*complete)(struct device___180 *);
	int (*suspend)(struct device___180 *);
	int (*resume)(struct device___180 *);
	int (*freeze)(struct device___180 *);
	int (*thaw)(struct device___180 *);
	int (*poweroff)(struct device___180 *);
	int (*restore)(struct device___180 *);
	int (*suspend_late)(struct device___180 *);
	int (*resume_early)(struct device___180 *);
	int (*freeze_late)(struct device___180 *);
	int (*thaw_early)(struct device___180 *);
	int (*poweroff_late)(struct device___180 *);
	int (*restore_early)(struct device___180 *);
	int (*suspend_noirq)(struct device___180 *);
	int (*resume_noirq)(struct device___180 *);
	int (*freeze_noirq)(struct device___180 *);
	int (*thaw_noirq)(struct device___180 *);
	int (*poweroff_noirq)(struct device___180 *);
	int (*restore_noirq)(struct device___180 *);
	int (*runtime_suspend)(struct device___180 *);
	int (*runtime_resume)(struct device___180 *);
	int (*runtime_idle)(struct device___180 *);
};

struct pm_domain_data___7;

struct pm_subsys_data___7 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___7 *domain_data;
};

struct pm_domain_data___7 {
	struct list_head list_node;
	struct device___180 *dev;
};

struct wakeup_source___180 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___180 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___180 {
	struct dev_pm_ops___180 ops;
	int (*start)(struct device___180 *);
	void (*detach)(struct device___180 *, bool);
	int (*activate)(struct device___180 *);
	void (*sync)(struct device___180 *);
	void (*dismiss)(struct device___180 *);
};

struct subsys_private___10;

struct bus_type___180 {
	const char *name;
	const char *dev_name;
	struct device___180 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___180 *, struct device_driver___180 *);
	int (*uevent)(struct device___180 *, struct kobj_uevent_env *);
	int (*probe)(struct device___180 *);
	void (*sync_state)(struct device___180 *);
	void (*remove)(struct device___180 *);
	void (*shutdown)(struct device___180 *);
	int (*online)(struct device___180 *);
	int (*offline)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	int (*num_vf)(struct device___180 *);
	int (*dma_configure)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___10 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___10;

struct device_driver___180 {
	const char *name;
	struct bus_type___180 *bus;
	struct module___186 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___180 *);
	void (*sync_state)(struct device___180 *);
	int (*remove)(struct device___180 *);
	void (*shutdown)(struct device___180 *);
	int (*suspend)(struct device___180 *, pm_message_t);
	int (*resume)(struct device___180 *);
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	const struct dev_pm_ops___180 *pm;
	void (*coredump)(struct device___180 *);
	struct driver_private___10 *p;
};

struct subsys_private___10 {
	struct kset___190 subsys;
	struct kset___190 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___190 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___180 *bus;
	struct kset___190 glue_dirs;
	struct class___180 *class;
};

struct device_type___180 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___180 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___180 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___180 *);
	const struct dev_pm_ops___180 *pm;
};

struct class___180 {
	const char *name;
	struct module___186 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___180 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___180 *, umode_t *);
	void (*class_release)(struct class___180 *);
	void (*dev_release)(struct device___180 *);
	int (*shutdown_pre)(struct device___180 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___180 *);
	void (*get_ownership)(struct device___180 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___180 *pm;
	struct subsys_private___10 *p;
};

struct driver_private___10 {
	struct kobject___190 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___186 *mkobj;
	struct device_driver___180 *driver;
};

struct device_private___10 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___180 *async_driver;
	char *deferred_probe_reason;
	struct device___180 *device;
	u8 dead;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___178;

struct fwnode_handle___178 {
	struct fwnode_handle___178 *secondary;
	const struct fwnode_operations___178 *ops;
	struct device___180 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___76 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___178 fwnode;
	struct property___51 *properties;
	struct property___51 *deadprops;
	struct device_node___76 *parent;
	struct device_node___76 *child;
	struct device_node___76 *sibling;
	struct kobject___190 kobj;
	long unsigned int _flags;
	void *data;
};

struct auxiliary_device_id {
	char name[32];
	kernel_ulong_t driver_data;
};

struct fwnode_reference_args___178;

struct fwnode_endpoint___178;

struct fwnode_operations___178 {
	struct fwnode_handle___178 * (*get)(struct fwnode_handle___178 *);
	void (*put)(struct fwnode_handle___178 *);
	bool (*device_is_available)(const struct fwnode_handle___178 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___178 *, const struct device___180 *);
	bool (*property_present)(const struct fwnode_handle___178 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___178 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___178 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___178 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*get_parent)(const struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*get_next_child_node)(const struct fwnode_handle___178 *, struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*get_named_child_node)(const struct fwnode_handle___178 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___178 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___178 *);
	struct fwnode_handle___178 * (*graph_get_next_endpoint)(const struct fwnode_handle___178 *, struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*graph_get_remote_endpoint)(const struct fwnode_handle___178 *);
	struct fwnode_handle___178 * (*graph_get_port_parent)(struct fwnode_handle___178 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___178 *, struct fwnode_endpoint___178 *);
	int (*add_links)(struct fwnode_handle___178 *);
};

struct fwnode_endpoint___178 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___178 *local_fwnode;
};

struct fwnode_reference_args___178 {
	struct fwnode_handle___178 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct auxiliary_device {
	struct device___180 dev;
	const char *name;
	u32 id;
};

struct auxiliary_driver {
	int (*probe)(struct auxiliary_device *, const struct auxiliary_device_id *);
	void (*remove)(struct auxiliary_device *);
	void (*shutdown)(struct auxiliary_device *);
	int (*suspend)(struct auxiliary_device *, pm_message_t);
	int (*resume)(struct auxiliary_device *);
	const char *name;
	struct device_driver___180 driver;
	const struct auxiliary_device_id *id_table;
};

struct fs_context___33;

struct fs_parameter_spec___22;

struct dentry___208;

struct super_block___208;

struct module___192;

struct file_system_type___208 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context___33 *);
	const struct fs_parameter_spec___22 *parameters;
	struct dentry___208 * (*mount)(struct file_system_type___208 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___208 *);
	struct module___192 *owner;
	struct file_system_type___208 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___208;

struct kiocb___208;

struct iov_iter___129;

struct poll_table_struct___137;

struct vm_area_struct___213;

struct inode___208;

struct file_lock___208;

struct page___213;

struct seq_file___183;

struct file_operations___209 {
	struct module___192 *owner;
	loff_t (*llseek)(struct file___208 *, loff_t, int);
	ssize_t (*read)(struct file___208 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___208 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___208 *, struct iov_iter___129 *);
	ssize_t (*write_iter)(struct kiocb___208 *, struct iov_iter___129 *);
	int (*iopoll)(struct kiocb___208 *, bool);
	int (*iterate)(struct file___208 *, struct dir_context *);
	int (*iterate_shared)(struct file___208 *, struct dir_context *);
	__poll_t (*poll)(struct file___208 *, struct poll_table_struct___137 *);
	long int (*unlocked_ioctl)(struct file___208 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___208 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___208 *, struct vm_area_struct___213 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___208 *, struct file___208 *);
	int (*flush)(struct file___208 *, fl_owner_t);
	int (*release)(struct inode___208 *, struct file___208 *);
	int (*fsync)(struct file___208 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___208 *, int);
	int (*lock)(struct file___208 *, int, struct file_lock___208 *);
	ssize_t (*sendpage)(struct file___208 *, struct page___213 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___208 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___208 *, long unsigned int);
	int (*flock)(struct file___208 *, int, struct file_lock___208 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___208 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___208 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___208 *, long int, struct file_lock___208 **, void **);
	long int (*fallocate)(struct file___208 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___183 *, struct file___208 *);
	ssize_t (*copy_file_range)(struct file___208 *, loff_t, struct file___208 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___208 *, loff_t, struct file___208 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___208 *, loff_t, loff_t, int);
};

struct vmacache___213 {
	u64 seqnum;
	struct vm_area_struct___213 *vmas[4];
};

struct page_frag___213 {
	struct page___213 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___76;

struct debug_info___76 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___76 *hbp_break[16];
	struct perf_event___76 *hbp_watch[16];
};

struct thread_struct___76 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___76 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___214;

struct pid___185;

struct nsproxy___194;

struct signal_struct___209;

struct bio_list___106;

struct backing_dev_info___99;

struct io_context___106;

struct css_set___143;

struct perf_event_context___76;

struct mem_cgroup___90;

struct request_queue___106;

struct vm_struct___191;

struct task_struct___215 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___215 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___214 *mm;
	struct mm_struct___214 *active_mm;
	struct vmacache___213 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___215 *real_parent;
	struct task_struct___215 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___215 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___185 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___194 *nsproxy;
	struct signal_struct___209 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___215 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___106 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___99 *backing_dev_info;
	struct io_context___106 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___143 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___76 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___213 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___90 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___90 *active_memcg;
	struct request_queue___106 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___215 *oom_reaper_list;
	struct vm_struct___191 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___76 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___196;

struct kobj_type___196;

struct kernfs_node___196;

struct kobject___196 {
	const char *name;
	struct list_head entry;
	struct kobject___196 *parent;
	struct kset___196 *kset;
	struct kobj_type___196 *ktype;
	struct kernfs_node___196 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___193 {
	struct kobject___196 kobj;
	struct module___192 *mod;
	struct kobject___196 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___192 {
	struct module___192 *mod;
	struct latch_tree_node node;
};

struct module_layout___192 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___192 mtn;
};

struct module_attribute___192;

struct kernel_param___192;

struct trace_event_call___70;

struct module___192 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___193 mkobj;
	struct module_attribute___192 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___196 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___192 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___192 core_layout;
	struct module_layout___192 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___70 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___76 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___215 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___76)(struct perf_event___76 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___76;

struct fasync_struct___208;

struct pid_namespace___185;

struct perf_cgroup___76;

struct perf_event___76 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___76 *group_leader;
	struct pmu___76 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___76 hw;
	struct perf_event_context___76 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___76 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___215 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___208 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___76 *aux_event;
	void (*destroy)(struct perf_event___76 *);
	struct callback_head callback_head;
	struct pid_namespace___185 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___76 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___76 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___70 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___76 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct dentry_operations___208;

struct dentry___208 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___208 *d_parent;
	struct qstr d_name;
	struct inode___208 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___208 *d_op;
	struct super_block___208 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___208;

struct address_space___208 {
	struct inode___208 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___208 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___208;

struct bdi_writeback___99;

struct inode___208 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___208 *i_op;
	struct super_block___208 *i_sb;
	struct address_space___208 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___99 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___209 *i_fop;
		void (*free_inode)(struct inode___208 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___208 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___68 *i_pipe;
		struct cdev___52 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___208;

struct path___208;

struct dentry_operations___208 {
	int (*d_revalidate)(struct dentry___208 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___208 *, unsigned int);
	int (*d_hash)(const struct dentry___208 *, struct qstr *);
	int (*d_compare)(const struct dentry___208 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___208 *);
	int (*d_init)(struct dentry___208 *);
	void (*d_release)(struct dentry___208 *);
	void (*d_prune)(struct dentry___208 *);
	void (*d_iput)(struct dentry___208 *, struct inode___208 *);
	char * (*d_dname)(struct dentry___208 *, char *, int);
	struct vfsmount___208 * (*d_automount)(struct path___208 *);
	int (*d_manage)(const struct path___208 *, bool);
	struct dentry___208 * (*d_real)(struct dentry___208 *, const struct inode___208 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___208;

struct mem_dqinfo___208 {
	struct quota_format_type___208 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___208;

struct quota_info___208 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___208 *files[3];
	struct mem_dqinfo___208 info[3];
	const struct quota_format_ops___208 *ops[3];
};

struct rcuwait___209 {
	struct task_struct___215 *task;
};

struct percpu_rw_semaphore___209 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___209 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___208 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___209 rw_sem[3];
};

struct shrink_control___90;

struct shrinker___90 {
	long unsigned int (*count_objects)(struct shrinker___90 *, struct shrink_control___90 *);
	long unsigned int (*scan_objects)(struct shrinker___90 *, struct shrink_control___90 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___208;

struct dquot_operations___208;

struct quotactl_ops___208;

struct xattr_handler___25;

struct block_device___109;

struct super_block___208 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___208 *s_type;
	const struct super_operations___208 *s_op;
	const struct dquot_operations___208 *dq_op;
	const struct quotactl_ops___208 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___208 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler___25 **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___109 *s_bdev;
	struct backing_dev_info___99 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___208 s_dquot;
	struct sb_writers___208 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___208 *s_d_op;
	int cleancache_poolid;
	struct shrinker___90 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___208 {
	struct dentry___208 *mnt_root;
	struct super_block___208 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct path___208 {
	struct vfsmount___208 *mnt;
	struct dentry___208 *dentry;
};

struct upid___185 {
	int nr;
	struct pid_namespace___185 *ns;
};

struct pid_namespace___185 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___215 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___185 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___185 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___185 numbers[1];
};

typedef struct page___213 *pgtable_t___213;

struct dev_pagemap___203;

struct page___213 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___208 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___56 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___213 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___213 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___214 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___203 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___203;

struct vm_area_struct___213 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___213 *vm_next;
	struct vm_area_struct___213 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___214 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___203 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___208 *vm_file;
	struct file___208 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___209 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___215 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___215 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___185 *pids[4];
	struct pid___185 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___214 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___213;

struct mm_struct___214 {
	struct {
		struct vm_area_struct___213 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___208 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___213 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___215 *owner;
		struct user_namespace___25 *user_ns;
		struct file___208 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___143;

struct nsproxy___194 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___185 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___143 *cgroup_ns;
};

struct bio___106;

struct bio_list___106 {
	struct bio___106 *head;
	struct bio___106 *tail;
};

struct cgroup_subsys_state___143;

struct bdi_writeback___99 {
	struct backing_dev_info___99 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___143 *memcg_css;
	struct cgroup_subsys_state___143 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___181;

struct backing_dev_info___99 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___99 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___181 *dev;
	char dev_name[64];
	struct device___181 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___208 *debug_dir;
};

struct io_cq___106;

struct io_context___106 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___106 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___143;

struct css_set___143 {
	struct cgroup_subsys_state___143 *subsys[14];
	refcount_t refcount;
	struct css_set___143 *dom_cset;
	struct cgroup___143 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___143 *mg_src_cgrp;
	struct cgroup___143 *mg_dst_cgrp;
	struct css_set___143 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___76 {
	struct pmu___76 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___215 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___76 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___143;

struct cgroup_subsys_state___143 {
	struct cgroup___143 *cgroup;
	struct cgroup_subsys___143 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___143 *parent;
};

struct cgroup_file___143 {
	struct kernfs_node___196 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___90;

struct mem_cgroup_per_node___90;

struct mem_cgroup___90 {
	struct cgroup_subsys_state___143 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___143 events_file;
	struct cgroup_file___143 events_local_file;
	struct cgroup_file___143 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___90 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___215 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___90 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___106;

struct blk_integrity___106 {
	const struct blk_integrity_profile___106 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___106 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___106 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___106;

struct elevator_queue___106;

struct blk_mq_ops___103;

struct blk_mq_hw_ctx___103;

struct gendisk___109;

struct blkcg_gq___101;

struct blk_mq_tag_set___103;

struct request_queue___106 {
	struct request___106 *last_merge;
	struct elevator_queue___106 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___103 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___103 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___109 *disk;
	struct kobject___196 kobj;
	struct kobject___196 *mq_kobj;
	struct blk_integrity___106 integrity;
	struct device___181 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___101 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___103 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___106 bio_split;
	struct dentry___208 *debugfs_dir;
	struct dentry___208 *sched_debugfs_dir;
	struct dentry___208 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___191 {
	struct vm_struct___191 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___213 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___90 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___90 *memcg;
};

struct dev_pagemap_ops___203;

struct dev_pagemap___203 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___203 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___185 {
	rwlock_t lock;
	struct pid___185 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___208 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___208 f_path;
	struct inode___208 *f_inode;
	const struct file_operations___209 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___185 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___208 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___203;

struct vm_operations_struct___203 {
	void (*open)(struct vm_area_struct___213 *);
	void (*close)(struct vm_area_struct___213 *);
	int (*may_split)(struct vm_area_struct___213 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___213 *);
	int (*mprotect)(struct vm_area_struct___213 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___203 *);
	vm_fault_t (*huge_fault)(struct vm_fault___203 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___203 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___213 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___203 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___203 *);
	int (*access)(struct vm_area_struct___213 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___213 *);
	int (*set_policy)(struct vm_area_struct___213 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___213 *, long unsigned int);
	struct page___213 * (*find_special_page)(struct vm_area_struct___213 *, long unsigned int);
};

struct core_thread___213 {
	struct task_struct___215 *task;
	struct core_thread___213 *next;
};

struct core_state___213 {
	atomic_t nr_threads;
	struct core_thread___213 dumper;
	struct completion startup;
};

struct vm_fault___203 {
	const struct {
		struct vm_area_struct___213 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___213 *cow_page;
	struct page___213 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___213 prealloc_pte;
};

struct pglist_data___97;

struct lruvec___97 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___97 *pgdat;
};

struct zone___97 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___97 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___97 {
	struct zone___97 *zone;
	int zone_idx;
};

struct zonelist___97 {
	struct zoneref___97 _zonerefs[321];
};

struct pglist_data___97 {
	struct zone___97 node_zones[5];
	struct zonelist___97 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___215 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___215 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___97 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___143 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___215 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___143;

struct cgroup_rstat_cpu___143;

struct cgroup___143 {
	struct cgroup_subsys_state___143 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___196 *kn;
	struct cgroup_file___143 procs_file;
	struct cgroup_file___143 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___143 *subsys[14];
	struct cgroup_root___143 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___143 *dom_cgrp;
	struct cgroup___143 *old_dom_cgrp;
	struct cgroup_rstat_cpu___143 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___143 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___106 {
	struct request_queue___106 *q;
	struct io_context___106 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___100;

struct kiocb___208 {
	struct file___208 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___208 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___100 *ki_waitq;
	};
};

struct iattr___208 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___208 *ia_file;
};

struct dquot___208 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___208 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___208 {
	int qf_fmt_id;
	const struct quota_format_ops___208 *qf_ops;
	struct module___192 *qf_owner;
	struct quota_format_type___208 *qf_next;
};

struct quota_format_ops___208 {
	int (*check_quota_file)(struct super_block___208 *, int);
	int (*read_file_info)(struct super_block___208 *, int);
	int (*write_file_info)(struct super_block___208 *, int);
	int (*free_file_info)(struct super_block___208 *, int);
	int (*read_dqblk)(struct dquot___208 *);
	int (*commit_dqblk)(struct dquot___208 *);
	int (*release_dqblk)(struct dquot___208 *);
	int (*get_next_id)(struct super_block___208 *, struct kqid *);
};

struct dquot_operations___208 {
	int (*write_dquot)(struct dquot___208 *);
	struct dquot___208 * (*alloc_dquot)(struct super_block___208 *, int);
	void (*destroy_dquot)(struct dquot___208 *);
	int (*acquire_dquot)(struct dquot___208 *);
	int (*release_dquot)(struct dquot___208 *);
	int (*mark_dirty)(struct dquot___208 *);
	int (*write_info)(struct super_block___208 *, int);
	qsize_t * (*get_reserved_space)(struct inode___208 *);
	int (*get_projid)(struct inode___208 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___208 *, qsize_t *);
	int (*get_next_id)(struct super_block___208 *, struct kqid *);
};

struct quotactl_ops___208 {
	int (*quota_on)(struct super_block___208 *, int, int, const struct path___208 *);
	int (*quota_off)(struct super_block___208 *, int);
	int (*quota_enable)(struct super_block___208 *, unsigned int);
	int (*quota_disable)(struct super_block___208 *, unsigned int);
	int (*quota_sync)(struct super_block___208 *, int);
	int (*set_info)(struct super_block___208 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___208 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___208 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___208 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___208 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___208 *, unsigned int);
};

struct wait_page_queue___100 {
	struct page___213 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___99;

struct readahead_control___100;

struct swap_info_struct___58;

struct address_space_operations___208 {
	int (*writepage)(struct page___213 *, struct writeback_control___99 *);
	int (*readpage)(struct file___208 *, struct page___213 *);
	int (*writepages)(struct address_space___208 *, struct writeback_control___99 *);
	int (*set_page_dirty)(struct page___213 *);
	int (*readpages)(struct file___208 *, struct address_space___208 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___100 *);
	int (*write_begin)(struct file___208 *, struct address_space___208 *, loff_t, unsigned int, unsigned int, struct page___213 **, void **);
	int (*write_end)(struct file___208 *, struct address_space___208 *, loff_t, unsigned int, unsigned int, struct page___213 *, void *);
	sector_t (*bmap)(struct address_space___208 *, sector_t);
	void (*invalidatepage)(struct page___213 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___213 *, gfp_t);
	void (*freepage)(struct page___213 *);
	ssize_t (*direct_IO)(struct kiocb___208 *, struct iov_iter___129 *);
	int (*migratepage)(struct address_space___208 *, struct page___213 *, struct page___213 *, enum migrate_mode);
	bool (*isolate_page)(struct page___213 *, isolate_mode_t);
	void (*putback_page)(struct page___213 *);
	int (*launder_page)(struct page___213 *);
	int (*is_partially_uptodate)(struct page___213 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___213 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___208 *, struct page___213 *);
	int (*swap_activate)(struct swap_info_struct___58 *, struct file___208 *, sector_t *);
	void (*swap_deactivate)(struct file___208 *);
};

struct writeback_control___99 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___99 *wb;
	struct inode___208 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___100 {
	struct file___208 *file;
	struct address_space___208 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___126;

struct iov_iter___129 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___126 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___58 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___109 *bdev;
	struct file___208 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___208 {
	struct dentry___208 * (*lookup)(struct inode___208 *, struct dentry___208 *, unsigned int);
	const char * (*get_link)(struct dentry___208 *, struct inode___208 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___208 *, int);
	struct posix_acl * (*get_acl)(struct inode___208 *, int, bool);
	int (*readlink)(struct dentry___208 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___208 *, struct dentry___208 *, umode_t, bool);
	int (*link)(struct dentry___208 *, struct inode___208 *, struct dentry___208 *);
	int (*unlink)(struct inode___208 *, struct dentry___208 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___208 *, struct dentry___208 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___208 *, struct dentry___208 *, umode_t);
	int (*rmdir)(struct inode___208 *, struct dentry___208 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___208 *, struct dentry___208 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___208 *, struct dentry___208 *, struct inode___208 *, struct dentry___208 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___208 *, struct iattr___208 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___208 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___208 *, char *, size_t);
	int (*fiemap)(struct inode___208 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___208 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___208 *, struct dentry___208 *, struct file___208 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___208 *, struct dentry___208 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___208 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___208 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___208 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___208 {
	void (*fl_copy_lock)(struct file_lock___208 *, struct file_lock___208 *);
	void (*fl_release_private)(struct file_lock___208 *);
};

struct lock_manager_operations___208;

struct file_lock___208 {
	struct file_lock___208 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___208 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___208 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___208 *fl_ops;
	const struct lock_manager_operations___208 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___208 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___208 *);
	int (*lm_grant)(struct file_lock___208 *, int);
	bool (*lm_break)(struct file_lock___208 *);
	int (*lm_change)(struct file_lock___208 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___208 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___208 *);
};

struct fasync_struct___208 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___208 *fa_next;
	struct file___208 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___208 {
	struct inode___208 * (*alloc_inode)(struct super_block___208 *);
	void (*destroy_inode)(struct inode___208 *);
	void (*free_inode)(struct inode___208 *);
	void (*dirty_inode)(struct inode___208 *, int);
	int (*write_inode)(struct inode___208 *, struct writeback_control___99 *);
	int (*drop_inode)(struct inode___208 *);
	void (*evict_inode)(struct inode___208 *);
	void (*put_super)(struct super_block___208 *);
	int (*sync_fs)(struct super_block___208 *, int);
	int (*freeze_super)(struct super_block___208 *);
	int (*freeze_fs)(struct super_block___208 *);
	int (*thaw_super)(struct super_block___208 *);
	int (*unfreeze_fs)(struct super_block___208 *);
	int (*statfs)(struct dentry___208 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___208 *, int *, char *);
	void (*umount_begin)(struct super_block___208 *);
	int (*show_options)(struct seq_file___183 *, struct dentry___208 *);
	int (*show_devname)(struct seq_file___183 *, struct dentry___208 *);
	int (*show_path)(struct seq_file___183 *, struct dentry___208 *);
	int (*show_stats)(struct seq_file___183 *, struct dentry___208 *);
	ssize_t (*quota_read)(struct super_block___208 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___208 *, int, const char *, size_t, loff_t);
	struct dquot___208 ** (*get_dquots)(struct inode___208 *);
	long int (*nr_cached_objects)(struct super_block___208 *, struct shrink_control___90 *);
	long int (*free_cached_objects)(struct super_block___208 *, struct shrink_control___90 *);
	struct file___208 * (*real_loop)(struct file___208 *);
};

struct xattr_handler___25 {
	const char *name;
	const char *prefix;
	int flags;
	bool (*list)(struct dentry___208 *);
	int (*get)(const struct xattr_handler___25 *, struct dentry___208 *, struct inode___208 *, const char *, void *, size_t);
	int (*set)(const struct xattr_handler___25 *, struct user_namespace___25 *, struct dentry___208 *, struct inode___208 *, const char *, const void *, size_t, int);
};

struct wakeup_source___181;

struct dev_pm_info___181 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___181 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___181 *, s32);
	struct dev_pm_qos *qos;
};

struct device_private___11;

struct device_type___181;

struct bus_type___181;

struct device_driver___181;

struct dev_pm_domain___181;

struct fwnode_handle___179;

struct class___181;

struct attribute_group___196;

struct device___181 {
	struct kobject___196 kobj;
	struct device___181 *parent;
	struct device_private___11 *p;
	const char *init_name;
	const struct device_type___181 *type;
	struct bus_type___181 *bus;
	struct device_driver___181 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___181 power;
	struct dev_pm_domain___181 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___179 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___181 *class;
	const struct attribute_group___196 **groups;
	void (*release)(struct device___181 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___109 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___208 *bd_inode;
	struct super_block___208 *bd_super;
	void *bd_claiming;
	struct device___181 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___196 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___109 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___208 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___144)(struct file___208 *, wait_queue_head_t *, struct poll_table_struct___137 *);

struct poll_table_struct___137 {
	poll_queue_proc___144 _qproc;
	__poll_t _key;
};

struct seq_operations___183;

struct seq_file___183 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___183 *op;
	int poll_event;
	const struct file___208 *file;
	void *private;
};

struct fc_log___33;

struct p_log___33 {
	const char *prefix;
	struct fc_log___33 *log;
};

struct fs_context_operations___33;

struct fs_context___33 {
	const struct fs_context_operations___33 *ops;
	struct mutex uapi_mutex;
	struct file_system_type___208 *fs_type;
	void *fs_private;
	void *sget_key;
	struct dentry___208 *root;
	struct user_namespace___25 *user_ns;
	struct net *net_ns;
	const struct cred___30 *cred;
	struct p_log___33 log;
	const char *source;
	void *security;
	void *s_fs_info;
	unsigned int sb_flags;
	unsigned int sb_flags_mask;
	unsigned int s_iflags;
	unsigned int lsm_flags;
	enum fs_context_purpose purpose: 8;
	enum fs_context_phase phase: 8;
	bool need_free: 1;
	bool global: 1;
	bool oldapi: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fs_parameter___33;

typedef int fs_param_type___22(struct p_log___33 *, const struct fs_parameter_spec___22 *, struct fs_parameter___33 *, struct fs_parse_result *);

struct fs_parameter_spec___22 {
	const char *name;
	fs_param_type___22 *type;
	u8 opt;
	short unsigned int flags;
	const void *data;
};

typedef void bio_end_io_t___106(struct bio___106 *);

struct bio_vec___126 {
	struct page___213 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___106;

struct bio___106 {
	struct bio___106 *bi_next;
	struct block_device___109 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___106 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___101 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___106 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___126 *bi_io_vec;
	struct bio_set___106 *bi_pool;
	struct bio_vec___126 bi_inline_vecs[0];
};

struct kernfs_root___196;

struct kernfs_elem_dir___196 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___196 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___196;

struct kernfs_root___196 {
	struct kernfs_node___196 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___196 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___196 {
	struct kernfs_node___196 *target_kn;
};

struct kernfs_ops___196;

struct kernfs_elem_attr___196 {
	const struct kernfs_ops___196 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___196 *notify_next;
};

struct kernfs_node___196 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___196 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___196 dir;
		struct kernfs_elem_symlink___196 symlink;
		struct kernfs_elem_attr___196 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___196;

struct kernfs_ops___196 {
	int (*open)(struct kernfs_open_file___196 *);
	void (*release)(struct kernfs_open_file___196 *);
	int (*seq_show)(struct seq_file___183 *, void *);
	void * (*seq_start)(struct seq_file___183 *, loff_t *);
	void * (*seq_next)(struct seq_file___183 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___183 *, void *);
	ssize_t (*read)(struct kernfs_open_file___196 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___196 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___196 *, struct poll_table_struct___137 *);
	int (*mmap)(struct kernfs_open_file___196 *, struct vm_area_struct___213 *);
};

struct kernfs_syscall_ops___196 {
	int (*show_options)(struct seq_file___183 *, struct kernfs_root___196 *);
	int (*mkdir)(struct kernfs_node___196 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___196 *);
	int (*rename)(struct kernfs_node___196 *, struct kernfs_node___196 *, const char *);
	int (*show_path)(struct seq_file___183 *, struct kernfs_node___196 *, struct kernfs_root___196 *);
};

struct kernfs_open_file___196 {
	struct kernfs_node___196 *kn;
	struct file___208 *file;
	struct seq_file___183 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___203 *vm_ops;
};

struct bin_attribute___196;

struct attribute_group___196 {
	const char *name;
	umode_t (*is_visible)(struct kobject___196 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___196 *, struct bin_attribute___196 *, int);
	struct attribute **attrs;
	struct bin_attribute___196 **bin_attrs;
};

struct bin_attribute___196 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___208 * (*f_mapping)();
	ssize_t (*read)(struct file___208 *, struct kobject___196 *, struct bin_attribute___196 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___208 *, struct kobject___196 *, struct bin_attribute___196 *, char *, loff_t, size_t);
	int (*mmap)(struct file___208 *, struct kobject___196 *, struct bin_attribute___196 *, struct vm_area_struct___213 *);
};

struct sysfs_ops___196 {
	ssize_t (*show)(struct kobject___196 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___196 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___196;

struct kset___196 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___196 kobj;
	const struct kset_uevent_ops___196 *uevent_ops;
};

struct kobj_type___196 {
	void (*release)(struct kobject___196 *);
	const struct sysfs_ops___196 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___196 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___196 *);
	const void * (*namespace)(struct kobject___196 *);
	void (*get_ownership)(struct kobject___196 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___196 {
	int (* const filter)(struct kset___196 *, struct kobject___196 *);
	const char * (* const name)(struct kset___196 *, struct kobject___196 *);
	int (* const uevent)(struct kset___196 *, struct kobject___196 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___181 {
	int (*prepare)(struct device___181 *);
	void (*complete)(struct device___181 *);
	int (*suspend)(struct device___181 *);
	int (*resume)(struct device___181 *);
	int (*freeze)(struct device___181 *);
	int (*thaw)(struct device___181 *);
	int (*poweroff)(struct device___181 *);
	int (*restore)(struct device___181 *);
	int (*suspend_late)(struct device___181 *);
	int (*resume_early)(struct device___181 *);
	int (*freeze_late)(struct device___181 *);
	int (*thaw_early)(struct device___181 *);
	int (*poweroff_late)(struct device___181 *);
	int (*restore_early)(struct device___181 *);
	int (*suspend_noirq)(struct device___181 *);
	int (*resume_noirq)(struct device___181 *);
	int (*freeze_noirq)(struct device___181 *);
	int (*thaw_noirq)(struct device___181 *);
	int (*poweroff_noirq)(struct device___181 *);
	int (*restore_noirq)(struct device___181 *);
	int (*runtime_suspend)(struct device___181 *);
	int (*runtime_resume)(struct device___181 *);
	int (*runtime_idle)(struct device___181 *);
};

struct wakeup_source___181 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___181 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___181 {
	struct dev_pm_ops___181 ops;
	int (*start)(struct device___181 *);
	void (*detach)(struct device___181 *, bool);
	int (*activate)(struct device___181 *);
	void (*sync)(struct device___181 *);
	void (*dismiss)(struct device___181 *);
};

struct subsys_private___11;

struct bus_type___181 {
	const char *name;
	const char *dev_name;
	struct device___181 *dev_root;
	const struct attribute_group___196 **bus_groups;
	const struct attribute_group___196 **dev_groups;
	const struct attribute_group___196 **drv_groups;
	int (*match)(struct device___181 *, struct device_driver___181 *);
	int (*uevent)(struct device___181 *, struct kobj_uevent_env *);
	int (*probe)(struct device___181 *);
	void (*sync_state)(struct device___181 *);
	void (*remove)(struct device___181 *);
	void (*shutdown)(struct device___181 *);
	int (*online)(struct device___181 *);
	int (*offline)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	int (*num_vf)(struct device___181 *);
	int (*dma_configure)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___11 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___11;

struct device_driver___181 {
	const char *name;
	struct bus_type___181 *bus;
	struct module___192 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___181 *);
	void (*sync_state)(struct device___181 *);
	int (*remove)(struct device___181 *);
	void (*shutdown)(struct device___181 *);
	int (*suspend)(struct device___181 *, pm_message_t);
	int (*resume)(struct device___181 *);
	const struct attribute_group___196 **groups;
	const struct attribute_group___196 **dev_groups;
	const struct dev_pm_ops___181 *pm;
	void (*coredump)(struct device___181 *);
	struct driver_private___11 *p;
};

struct subsys_private___11 {
	struct kset___196 subsys;
	struct kset___196 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___196 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___181 *bus;
	struct kset___196 glue_dirs;
	struct class___181 *class;
};

struct device_type___181 {
	const char *name;
	const struct attribute_group___196 **groups;
	int (*uevent)(struct device___181 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___181 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___181 *);
	const struct dev_pm_ops___181 *pm;
};

struct class___181 {
	const char *name;
	struct module___192 *owner;
	const struct attribute_group___196 **class_groups;
	const struct attribute_group___196 **dev_groups;
	struct kobject___196 *dev_kobj;
	int (*dev_uevent)(struct device___181 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___181 *, umode_t *);
	void (*class_release)(struct class___181 *);
	void (*dev_release)(struct device___181 *);
	int (*shutdown_pre)(struct device___181 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___181 *);
	void (*get_ownership)(struct device___181 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___181 *pm;
	struct subsys_private___11 *p;
};

struct driver_private___11 {
	struct kobject___196 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___193 *mkobj;
	struct device_driver___181 *driver;
};

struct device_private___11 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___181 *async_driver;
	char *deferred_probe_reason;
	struct device___181 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___179;

struct fwnode_handle___179 {
	struct fwnode_handle___179 *secondary;
	const struct fwnode_operations___179 *ops;
	struct device___181 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct dev_pagemap_ops___203 {
	void (*page_free)(struct page___213 *);
	void (*kill)(struct dev_pagemap___203 *);
	void (*cleanup)(struct dev_pagemap___203 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___203 *);
};

struct seq_operations___183 {
	void * (*start)(struct seq_file___183 *, loff_t *);
	void (*stop)(struct seq_file___183 *, void *);
	void * (*next)(struct seq_file___183 *, void *, loff_t *);
	int (*show)(struct seq_file___183 *, void *);
};

struct fwnode_reference_args___179;

struct fwnode_endpoint___179;

struct fwnode_operations___179 {
	struct fwnode_handle___179 * (*get)(struct fwnode_handle___179 *);
	void (*put)(struct fwnode_handle___179 *);
	bool (*device_is_available)(const struct fwnode_handle___179 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___179 *, const struct device___181 *);
	bool (*property_present)(const struct fwnode_handle___179 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___179 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___179 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___179 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*get_parent)(const struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*get_next_child_node)(const struct fwnode_handle___179 *, struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*get_named_child_node)(const struct fwnode_handle___179 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___179 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___179 *);
	struct fwnode_handle___179 * (*graph_get_next_endpoint)(const struct fwnode_handle___179 *, struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*graph_get_remote_endpoint)(const struct fwnode_handle___179 *);
	struct fwnode_handle___179 * (*graph_get_port_parent)(struct fwnode_handle___179 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___179 *, struct fwnode_endpoint___179 *);
	int (*add_links)(struct fwnode_handle___179 *);
};

struct fwnode_endpoint___179 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___179 *local_fwnode;
};

struct fwnode_reference_args___179 {
	struct fwnode_handle___179 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___143 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___143 *root_cset;
};

struct kernel_param_ops___192 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___192 *);
	int (*get)(char *, const struct kernel_param___192 *);
	void (*free)(void *);
};

struct kparam_array___192;

struct kernel_param___192 {
	const char *name;
	struct module___192 *mod;
	const struct kernel_param_ops___192 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___192 *arr;
	};
};

struct kparam_array___192 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___192 *ops;
	void *elem;
};

struct module_attribute___192 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___192 *, struct module_kobject___193 *, char *);
	ssize_t (*store)(struct module_attribute___192 *, struct module_kobject___193 *, const char *, size_t);
	void (*setup)(struct module___192 *, const char *);
	int (*test)(struct module___192 *);
	void (*free)(struct module___192 *);
};

struct trace_event_class___70;

struct trace_event_call___70 {
	struct list_head list;
	struct trace_event_class___70 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___36 *prog_array;
	int (*perf_perm)(struct trace_event_call___70 *, struct perf_event___76 *);
};

struct cftype___143;

struct cgroup_subsys___143 {
	struct cgroup_subsys_state___143 * (*css_alloc)(struct cgroup_subsys_state___143 *);
	int (*css_online)(struct cgroup_subsys_state___143 *);
	void (*css_offline)(struct cgroup_subsys_state___143 *);
	void (*css_released)(struct cgroup_subsys_state___143 *);
	void (*css_free)(struct cgroup_subsys_state___143 *);
	void (*css_reset)(struct cgroup_subsys_state___143 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___143 *, int);
	int (*css_extra_stat_show)(struct seq_file___183 *, struct cgroup_subsys_state___143 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___215 *, struct css_set___143 *);
	void (*cancel_fork)(struct task_struct___215 *, struct css_set___143 *);
	void (*fork)(struct task_struct___215 *);
	void (*exit)(struct task_struct___215 *);
	void (*release)(struct task_struct___215 *);
	void (*bind)(struct cgroup_subsys_state___143 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___143 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___143 *dfl_cftypes;
	struct cftype___143 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___143 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___143 *updated_children;
	struct cgroup___143 *updated_next;
};

struct cgroup_root___143 {
	struct kernfs_root___196 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___143 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___143 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___143 *ss;
	struct list_head node;
	struct kernfs_ops___196 *kf_ops;
	int (*open)(struct kernfs_open_file___196 *);
	void (*release)(struct kernfs_open_file___196 *);
	u64 (*read_u64)(struct cgroup_subsys_state___143 *, struct cftype___143 *);
	s64 (*read_s64)(struct cgroup_subsys_state___143 *, struct cftype___143 *);
	int (*seq_show)(struct seq_file___183 *, void *);
	void * (*seq_start)(struct seq_file___183 *, loff_t *);
	void * (*seq_next)(struct seq_file___183 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___183 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___143 *, struct cftype___143 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___143 *, struct cftype___143 *, s64);
	ssize_t (*write)(struct kernfs_open_file___196 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___196 *, struct poll_table_struct___137 *);
};

struct perf_cpu_context___76;

struct perf_output_handle___76;

struct pmu___76 {
	struct list_head entry;
	struct module___192 *module;
	struct device___181 *dev;
	const struct attribute_group___196 **attr_groups;
	const struct attribute_group___196 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___76 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___76 *);
	void (*pmu_disable)(struct pmu___76 *);
	int (*event_init)(struct perf_event___76 *);
	void (*event_mapped)(struct perf_event___76 *, struct mm_struct___214 *);
	void (*event_unmapped)(struct perf_event___76 *, struct mm_struct___214 *);
	int (*add)(struct perf_event___76 *, int);
	void (*del)(struct perf_event___76 *, int);
	void (*start)(struct perf_event___76 *, int);
	void (*stop)(struct perf_event___76 *, int);
	void (*read)(struct perf_event___76 *);
	void (*start_txn)(struct pmu___76 *, unsigned int);
	int (*commit_txn)(struct pmu___76 *);
	void (*cancel_txn)(struct pmu___76 *);
	int (*event_idx)(struct perf_event___76 *);
	void (*sched_task)(struct perf_event_context___76 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___76 *, struct perf_event_context___76 *);
	void * (*setup_aux)(struct perf_event___76 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___76 *, struct perf_output_handle___76 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___76 *);
	int (*aux_output_match)(struct perf_event___76 *);
	int (*filter_match)(struct perf_event___76 *);
	int (*check_period)(struct perf_event___76 *, u64);
};

struct perf_cpu_context___76 {
	struct perf_event_context___76 ctx;
	struct perf_event_context___76 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___76 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___76 **heap;
	struct perf_event___76 *heap_default[2];
};

struct perf_output_handle___76 {
	struct perf_event___76 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___76 {
	struct cgroup_subsys_state___143 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___70 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___70 *);
	};
};

struct trace_event_class___70 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___70 *, enum trace_reg, void *);
	struct trace_event_fields___70 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___70 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___70 *);
};

struct block_device_operations___106;

struct gendisk___109 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___109 *part0;
	const struct block_device_operations___106 *fops;
	struct request_queue___106 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___99 *bdi;
	struct kobject___196 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___196 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___106 {
	struct bio___106 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___126 *bip_vec;
	struct bio_vec___126 bip_inline_vecs[0];
};

struct blkcg___101;

struct blkg_policy_data___101;

struct blkcg_gq___101 {
	struct request_queue___106 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___101 *blkcg;
	struct blkcg_gq___101 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___101 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___106 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___106(struct request___106 *);

typedef void integrity_complete_fn___106(struct request___106 *, unsigned int);

struct blk_integrity_profile___106 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___106 *prepare_fn;
	integrity_complete_fn___106 *complete_fn;
	const char *name;
};

struct block_device_operations___106 {
	blk_qc_t (*submit_bio)(struct bio___106 *);
	int (*open)(struct block_device___109 *, fmode_t);
	void (*release)(struct gendisk___109 *, fmode_t);
	int (*rw_page)(struct block_device___109 *, sector_t, struct page___213 *, unsigned int);
	int (*ioctl)(struct block_device___109 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___109 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___109 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___109 *);
	int (*getgeo)(struct block_device___109 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___109 *, bool);
	void (*swap_slot_free_notify)(struct block_device___109 *, long unsigned int);
	int (*report_zones)(struct gendisk___109 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___109 *, umode_t *);
	struct module___192 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___109 *, sector_t *);
};

typedef void rq_end_io_fn___106(struct request___106 *, blk_status_t);

struct request___106 {
	struct request_queue___106 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___103 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___106 *bio;
	struct bio___106 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___126 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___106 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___106 *saved_end_io;
		} flush;
	};
	struct gendisk___109 *rq_disk;
	struct block_device___109 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___106 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___103 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___106 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___196 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___208 *debugfs_dir;
	struct dentry___208 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___106;

struct elevator_mq_ops___106 {
	int (*init_sched)(struct request_queue___106 *, struct elevator_type___106 *);
	void (*exit_sched)(struct elevator_queue___106 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___103 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___103 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___103 *);
	bool (*allow_merge)(struct request_queue___106 *, struct request___106 *, struct bio___106 *);
	bool (*bio_merge)(struct request_queue___106 *, struct bio___106 *, unsigned int);
	int (*request_merge)(struct request_queue___106 *, struct request___106 **, struct bio___106 *);
	void (*request_merged)(struct request_queue___106 *, struct request___106 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___106 *, struct request___106 *, struct request___106 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___106 *);
	void (*finish_request)(struct request___106 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___103 *, struct list_head *, bool);
	struct request___106 * (*dispatch_request)(struct blk_mq_hw_ctx___103 *);
	bool (*has_work)(struct blk_mq_hw_ctx___103 *);
	void (*completed_request)(struct request___106 *, u64);
	void (*requeue_request)(struct request___106 *);
	struct request___106 * (*former_request)(struct request_queue___106 *, struct request___106 *);
	struct request___106 * (*next_request)(struct request_queue___106 *, struct request___106 *);
	void (*init_icq)(struct io_cq___106 *);
	void (*exit_icq)(struct io_cq___106 *);
};

struct elv_fs_entry___106;

struct elevator_type___106 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___106 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___106 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___192 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___106 {
	struct elevator_type___106 *type;
	void *elevator_data;
	struct kobject___196 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___106 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___106 *, char *);
	ssize_t (*store)(struct elevator_queue___106 *, const char *, size_t);
};

struct blk_mq_queue_data___103;

struct blk_mq_ops___103 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___103 *, const struct blk_mq_queue_data___103 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___103 *);
	int (*get_budget)(struct request_queue___106 *);
	void (*put_budget)(struct request_queue___106 *, int);
	void (*set_rq_budget_token)(struct request___106 *, int);
	int (*get_rq_budget_token)(struct request___106 *);
	enum blk_eh_timer_return (*timeout)(struct request___106 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___103 *);
	void (*complete)(struct request___106 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___103 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___103 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___103 *, struct request___106 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___103 *, struct request___106 *, unsigned int);
	void (*initialize_rq_fn)(struct request___106 *);
	void (*cleanup_rq)(struct request___106 *);
	bool (*busy)(struct request_queue___106 *);
	int (*map_queues)(struct blk_mq_tag_set___103 *);
	void (*show_rq)(struct seq_file___183 *, struct request___106 *);
};

struct blk_mq_tag_set___103 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___103 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___103 {
	struct request___106 *rq;
	bool last;
};

struct blkcg_policy_data___101;

struct blkcg___101 {
	struct cgroup_subsys_state___143 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___101 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___101 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___101 {
	struct blkcg___101 *blkcg;
	int plid;
};

struct blkg_policy_data___101 {
	struct blkcg_gq___101 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___90 {
	struct mem_cgroup___90 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___90 {
	struct lruvec___97 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___90 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___90 *memcg;
};

struct obj_cgroup___90 {
	struct percpu_ref refcnt;
	struct mem_cgroup___90 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct fs_parameter___33 {
	const char *key;
	enum fs_value_type type: 8;
	long: 56;
	long: 64;
	union {
		char *string;
		void *blob;
		struct filename *name;
		struct file___208 *file;
	};
	size_t size;
	int dirfd;
};

struct fc_log___33 {
	refcount_t usage;
	u8 head;
	u8 tail;
	u8 need_free;
	struct module___192 *owner;
	char *buffer[8];
};

struct fs_context_operations___33 {
	void (*free)(struct fs_context___33 *);
	int (*dup)(struct fs_context___33 *, struct fs_context___33 *);
	int (*parse_param)(struct fs_context___33 *, struct fs_parameter___33 *);
	int (*parse_monolithic)(struct fs_context___33 *, void *);
	int (*get_tree)(struct fs_context___33 *);
	int (*reconfigure)(struct fs_context___33 *);
};

struct req {
	struct req *next;
	struct completion done;
	int err;
	const char *name;
	umode_t mode;
	kuid_t uid;
	kgid_t gid;
	struct device___181 *dev;
};

struct wakeup_source___182;

struct wake_irq___5;

struct device___182;

struct dev_pm_qos___16;

struct dev_pm_info___182 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___182 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___5 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___7 *subsys_data;
	void (*set_latency_tolerance)(struct device___182 *, s32);
	struct dev_pm_qos___16 *qos;
};

struct device_type___182;

struct bus_type___182;

struct device_driver___182;

struct dev_pm_domain___182;

struct class___182;

struct device___182 {
	struct kobject___41 kobj;
	struct device___182 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___182 *type;
	struct bus_type___182 *bus;
	struct device_driver___182 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___182 power;
	struct dev_pm_domain___182 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___7 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___182 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___182 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___182 {
	int (*prepare)(struct device___182 *);
	void (*complete)(struct device___182 *);
	int (*suspend)(struct device___182 *);
	int (*resume)(struct device___182 *);
	int (*freeze)(struct device___182 *);
	int (*thaw)(struct device___182 *);
	int (*poweroff)(struct device___182 *);
	int (*restore)(struct device___182 *);
	int (*suspend_late)(struct device___182 *);
	int (*resume_early)(struct device___182 *);
	int (*freeze_late)(struct device___182 *);
	int (*thaw_early)(struct device___182 *);
	int (*poweroff_late)(struct device___182 *);
	int (*restore_early)(struct device___182 *);
	int (*suspend_noirq)(struct device___182 *);
	int (*resume_noirq)(struct device___182 *);
	int (*freeze_noirq)(struct device___182 *);
	int (*thaw_noirq)(struct device___182 *);
	int (*poweroff_noirq)(struct device___182 *);
	int (*restore_noirq)(struct device___182 *);
	int (*runtime_suspend)(struct device___182 *);
	int (*runtime_resume)(struct device___182 *);
	int (*runtime_idle)(struct device___182 *);
};

struct wakeup_source___182 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___5 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___182 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___5 {
	struct device___182 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___16;

struct dev_pm_qos___16 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___16 *resume_latency_req;
	struct dev_pm_qos_request___16 *latency_tolerance_req;
	struct dev_pm_qos_request___16 *flags_req;
};

struct dev_pm_domain___182 {
	struct dev_pm_ops___182 ops;
	int (*start)(struct device___182 *);
	void (*detach)(struct device___182 *, bool);
	int (*activate)(struct device___182 *);
	void (*sync)(struct device___182 *);
	void (*dismiss)(struct device___182 *);
};

struct bus_type___182 {
	const char *name;
	const char *dev_name;
	struct device___182 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___182 *, struct device_driver___182 *);
	int (*uevent)(struct device___182 *, struct kobj_uevent_env *);
	int (*probe)(struct device___182 *);
	void (*sync_state)(struct device___182 *);
	void (*remove)(struct device___182 *);
	void (*shutdown)(struct device___182 *);
	int (*online)(struct device___182 *);
	int (*offline)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	int (*num_vf)(struct device___182 *);
	int (*dma_configure)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___182 {
	const char *name;
	struct bus_type___182 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___182 *);
	void (*sync_state)(struct device___182 *);
	int (*remove)(struct device___182 *);
	void (*shutdown)(struct device___182 *);
	int (*suspend)(struct device___182 *, pm_message_t);
	int (*resume)(struct device___182 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___182 *pm;
	void (*coredump)(struct device___182 *);
	struct driver_private *p;
};

struct device_type___182 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___182 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___182 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___182 *);
	const struct dev_pm_ops___182 *pm;
};

struct class___182 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___182 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___182 *, umode_t *);
	void (*class_release)(struct class___182 *);
	void (*dev_release)(struct device___182 *);
	int (*shutdown_pre)(struct device___182 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___182 *);
	void (*get_ownership)(struct device___182 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___182 *pm;
	struct subsys_private *p;
};

struct device_attribute___23 {
	struct attribute attr;
	ssize_t (*show)(struct device___182 *, struct device_attribute___23 *, char *);
	ssize_t (*store)(struct device___182 *, struct device_attribute___23 *, const char *, size_t);
};

struct dev_pm_qos_request___16 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___182 *dev;
};

struct wakeup_source___183;

struct wake_irq___6;

struct pm_subsys_data___8;

struct device___183;

struct dev_pm_qos___17;

struct dev_pm_info___183 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___183 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___6 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___8 *subsys_data;
	void (*set_latency_tolerance)(struct device___183 *, s32);
	struct dev_pm_qos___17 *qos;
};

struct device_type___183;

struct bus_type___183;

struct device_driver___183;

struct dev_pm_domain___183;

struct irq_domain___48;

struct device_node___77;

struct fwnode_handle___180;

struct class___183;

struct device___183 {
	struct kobject___190 kobj;
	struct device___183 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___183 *type;
	struct bus_type___183 *bus;
	struct device_driver___183 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___183 power;
	struct dev_pm_domain___183 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___48 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___77 *of_node;
	struct fwnode_handle___180 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___183 *class;
	const struct attribute_group___190 **groups;
	void (*release)(struct device___183 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___183 {
	int (*prepare)(struct device___183 *);
	void (*complete)(struct device___183 *);
	int (*suspend)(struct device___183 *);
	int (*resume)(struct device___183 *);
	int (*freeze)(struct device___183 *);
	int (*thaw)(struct device___183 *);
	int (*poweroff)(struct device___183 *);
	int (*restore)(struct device___183 *);
	int (*suspend_late)(struct device___183 *);
	int (*resume_early)(struct device___183 *);
	int (*freeze_late)(struct device___183 *);
	int (*thaw_early)(struct device___183 *);
	int (*poweroff_late)(struct device___183 *);
	int (*restore_early)(struct device___183 *);
	int (*suspend_noirq)(struct device___183 *);
	int (*resume_noirq)(struct device___183 *);
	int (*freeze_noirq)(struct device___183 *);
	int (*thaw_noirq)(struct device___183 *);
	int (*poweroff_noirq)(struct device___183 *);
	int (*restore_noirq)(struct device___183 *);
	int (*runtime_suspend)(struct device___183 *);
	int (*runtime_resume)(struct device___183 *);
	int (*runtime_idle)(struct device___183 *);
};

struct pm_domain_data___8;

struct pm_subsys_data___8 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___8 *domain_data;
};

struct pm_domain_data___8 {
	struct list_head list_node;
	struct device___183 *dev;
};

struct wakeup_source___183 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___6 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___183 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___6 {
	struct device___183 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___17;

struct dev_pm_qos___17 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___17 *resume_latency_req;
	struct dev_pm_qos_request___17 *latency_tolerance_req;
	struct dev_pm_qos_request___17 *flags_req;
};

struct dev_pm_domain___183 {
	struct dev_pm_ops___183 ops;
	int (*start)(struct device___183 *);
	void (*detach)(struct device___183 *, bool);
	int (*activate)(struct device___183 *);
	void (*sync)(struct device___183 *);
	void (*dismiss)(struct device___183 *);
};

struct bus_type___183 {
	const char *name;
	const char *dev_name;
	struct device___183 *dev_root;
	const struct attribute_group___190 **bus_groups;
	const struct attribute_group___190 **dev_groups;
	const struct attribute_group___190 **drv_groups;
	int (*match)(struct device___183 *, struct device_driver___183 *);
	int (*uevent)(struct device___183 *, struct kobj_uevent_env *);
	int (*probe)(struct device___183 *);
	void (*sync_state)(struct device___183 *);
	void (*remove)(struct device___183 *);
	void (*shutdown)(struct device___183 *);
	int (*online)(struct device___183 *);
	int (*offline)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	int (*num_vf)(struct device___183 *);
	int (*dma_configure)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___183 {
	const char *name;
	struct bus_type___183 *bus;
	struct module___186 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___183 *);
	void (*sync_state)(struct device___183 *);
	int (*remove)(struct device___183 *);
	void (*shutdown)(struct device___183 *);
	int (*suspend)(struct device___183 *, pm_message_t);
	int (*resume)(struct device___183 *);
	const struct attribute_group___190 **groups;
	const struct attribute_group___190 **dev_groups;
	const struct dev_pm_ops___183 *pm;
	void (*coredump)(struct device___183 *);
	struct driver_private *p;
};

struct device_type___183 {
	const char *name;
	const struct attribute_group___190 **groups;
	int (*uevent)(struct device___183 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___183 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___183 *);
	const struct dev_pm_ops___183 *pm;
};

struct class___183 {
	const char *name;
	struct module___186 *owner;
	const struct attribute_group___190 **class_groups;
	const struct attribute_group___190 **dev_groups;
	struct kobject___190 *dev_kobj;
	int (*dev_uevent)(struct device___183 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___183 *, umode_t *);
	void (*class_release)(struct class___183 *);
	void (*dev_release)(struct device___183 *);
	int (*shutdown_pre)(struct device___183 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___183 *);
	void (*get_ownership)(struct device___183 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___183 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___48;

struct irq_domain_chip_generic___48;

struct irq_data___49;

struct irq_domain___48 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___48 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___180 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___48 *gc;
	struct irq_domain___48 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___49 *revmap[0];
};

struct fwnode_operations___180;

struct fwnode_handle___180 {
	struct fwnode_handle___180 *secondary;
	const struct fwnode_operations___180 *ops;
	struct device___183 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___77 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___180 fwnode;
	struct property___51 *properties;
	struct property___51 *deadprops;
	struct device_node___77 *parent;
	struct device_node___77 *child;
	struct device_node___77 *sibling;
	struct kobject___190 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___50;

typedef void (*irq_flow_handler_t___50)(struct irq_desc___50 *);

struct irq_chip___49;

struct irq_data___49 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___49 *chip;
	struct irq_domain___48 *domain;
	struct irq_data___49 *parent_data;
	void *chip_data;
};

struct irq_desc___50 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___49 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___50 handle_irq;
	struct irqaction___29 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___190 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___186 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___180;

struct fwnode_endpoint___180;

struct fwnode_operations___180 {
	struct fwnode_handle___180 * (*get)(struct fwnode_handle___180 *);
	void (*put)(struct fwnode_handle___180 *);
	bool (*device_is_available)(const struct fwnode_handle___180 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___180 *, const struct device___183 *);
	bool (*property_present)(const struct fwnode_handle___180 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___180 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___180 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___180 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*get_parent)(const struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*get_next_child_node)(const struct fwnode_handle___180 *, struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*get_named_child_node)(const struct fwnode_handle___180 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___180 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___180 *);
	struct fwnode_handle___180 * (*graph_get_next_endpoint)(const struct fwnode_handle___180 *, struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*graph_get_remote_endpoint)(const struct fwnode_handle___180 *);
	struct fwnode_handle___180 * (*graph_get_port_parent)(struct fwnode_handle___180 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___180 *, struct fwnode_endpoint___180 *);
	int (*add_links)(struct fwnode_handle___180 *);
};

struct fwnode_endpoint___180 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___180 *local_fwnode;
};

struct fwnode_reference_args___180 {
	struct fwnode_handle___180 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_fwspec___46 {
	struct fwnode_handle___180 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___48 {
	int (*match)(struct irq_domain___48 *, struct device_node___77 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___48 *, struct irq_fwspec___46 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___48 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___48 *, unsigned int);
	int (*xlate)(struct irq_domain___48 *, struct device_node___77 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___48 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___48 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___48 *, struct irq_data___49 *, bool);
	void (*deactivate)(struct irq_domain___48 *, struct irq_data___49 *);
	int (*translate)(struct irq_domain___48 *, struct irq_fwspec___46 *, long unsigned int *, unsigned int *);
};

struct irq_chip_generic___48;

struct irq_domain_chip_generic___48 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___48 *gc[0];
};

struct irq_chip___49 {
	struct device___183 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___49 *);
	void (*irq_shutdown)(struct irq_data___49 *);
	void (*irq_enable)(struct irq_data___49 *);
	void (*irq_disable)(struct irq_data___49 *);
	void (*irq_ack)(struct irq_data___49 *);
	void (*irq_mask)(struct irq_data___49 *);
	void (*irq_mask_ack)(struct irq_data___49 *);
	void (*irq_unmask)(struct irq_data___49 *);
	void (*irq_eoi)(struct irq_data___49 *);
	int (*irq_set_affinity)(struct irq_data___49 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___49 *);
	int (*irq_set_type)(struct irq_data___49 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___49 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___49 *);
	void (*irq_bus_sync_unlock)(struct irq_data___49 *);
	void (*irq_cpu_online)(struct irq_data___49 *);
	void (*irq_cpu_offline)(struct irq_data___49 *);
	void (*irq_suspend)(struct irq_data___49 *);
	void (*irq_resume)(struct irq_data___49 *);
	void (*irq_pm_shutdown)(struct irq_data___49 *);
	void (*irq_calc_mask)(struct irq_data___49 *);
	void (*irq_print_chip)(struct irq_data___49 *, struct seq_file___178 *);
	int (*irq_request_resources)(struct irq_data___49 *);
	void (*irq_release_resources)(struct irq_data___49 *);
	void (*irq_compose_msi_msg)(struct irq_data___49 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___49 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___49 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___49 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___49 *, void *);
	void (*ipi_send_single)(struct irq_data___49 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___49 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___49 *);
	void (*irq_nmi_teardown)(struct irq_data___49 *);
	long unsigned int flags;
};

struct irq_chip_type___48 {
	struct irq_chip___49 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___50 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___48 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___48 *);
	void (*resume)(struct irq_chip_generic___48 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___48 *domain;
	struct list_head list;
	struct irq_chip_type___48 chip_types[0];
};

struct dev_pm_qos_request___17 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___183 *dev;
};

struct dentry___209;

struct super_block___209;

struct module___193;

struct file_system_type___209 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___209 * (*mount)(struct file_system_type___209 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___209 *);
	struct module___193 *owner;
	struct file_system_type___209 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___209;

struct kiocb___209;

struct poll_table_struct___138;

struct vm_area_struct___214;

struct inode___209;

struct file_lock___209;

struct page___214;

struct seq_file___184;

struct file_operations___210 {
	struct module___193 *owner;
	loff_t (*llseek)(struct file___209 *, loff_t, int);
	ssize_t (*read)(struct file___209 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___209 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___209 *, struct iov_iter___129 *);
	ssize_t (*write_iter)(struct kiocb___209 *, struct iov_iter___129 *);
	int (*iopoll)(struct kiocb___209 *, bool);
	int (*iterate)(struct file___209 *, struct dir_context *);
	int (*iterate_shared)(struct file___209 *, struct dir_context *);
	__poll_t (*poll)(struct file___209 *, struct poll_table_struct___138 *);
	long int (*unlocked_ioctl)(struct file___209 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___209 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___209 *, struct vm_area_struct___214 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___209 *, struct file___209 *);
	int (*flush)(struct file___209 *, fl_owner_t);
	int (*release)(struct inode___209 *, struct file___209 *);
	int (*fsync)(struct file___209 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___209 *, int);
	int (*lock)(struct file___209 *, int, struct file_lock___209 *);
	ssize_t (*sendpage)(struct file___209 *, struct page___214 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___209 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___209 *, long unsigned int);
	int (*flock)(struct file___209 *, int, struct file_lock___209 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___209 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___209 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___209 *, long int, struct file_lock___209 **, void **);
	long int (*fallocate)(struct file___209 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___184 *, struct file___209 *);
	ssize_t (*copy_file_range)(struct file___209 *, loff_t, struct file___209 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___209 *, loff_t, struct file___209 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___209 *, loff_t, loff_t, int);
};

struct vmacache___214 {
	u64 seqnum;
	struct vm_area_struct___214 *vmas[4];
};

struct page_frag___214 {
	struct page___214 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___77;

struct debug_info___77 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___77 *hbp_break[16];
	struct perf_event___77 *hbp_watch[16];
};

struct thread_struct___77 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___77 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___215;

struct pid___186;

struct nsproxy___195;

struct signal_struct___210;

struct css_set___144;

struct perf_event_context___77;

struct vm_struct___192;

struct task_struct___216 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___216 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___215 *mm;
	struct mm_struct___215 *active_mm;
	struct vmacache___214 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___216 *real_parent;
	struct task_struct___216 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___216 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___186 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___195 *nsproxy;
	struct signal_struct___210 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___216 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___106 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___144 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___77 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___214 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___216 *oom_reaper_list;
	struct vm_struct___192 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___77 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___197;

struct kobj_type___197;

struct kernfs_node___197;

struct kobject___197 {
	const char *name;
	struct list_head entry;
	struct kobject___197 *parent;
	struct kset___197 *kset;
	struct kobj_type___197 *ktype;
	struct kernfs_node___197 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___194 {
	struct kobject___197 kobj;
	struct module___193 *mod;
	struct kobject___197 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___193 {
	struct module___193 *mod;
	struct latch_tree_node node;
};

struct module_layout___193 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___193 mtn;
};

struct module_attribute___193;

struct kernel_param___193;

struct trace_event_call___71;

struct module___193 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___194 mkobj;
	struct module_attribute___193 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___197 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___193 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___193 core_layout;
	struct module_layout___193 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___71 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___77 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___216 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___77)(struct perf_event___77 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___77;

struct fasync_struct___209;

struct pid_namespace___186;

struct perf_cgroup___77;

struct perf_event___77 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___77 *group_leader;
	struct pmu___77 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___77 hw;
	struct perf_event_context___77 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___77 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___216 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___209 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___77 *aux_event;
	void (*destroy)(struct perf_event___77 *);
	struct callback_head callback_head;
	struct pid_namespace___186 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___77 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___77 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___71 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___77 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___186 {
	int nr;
	struct pid_namespace___186 *ns;
};

struct pid_namespace___186 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___216 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___186 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___186 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___186 numbers[1];
};

typedef struct page___214 *pgtable_t___214;

struct address_space___209;

struct dev_pagemap___204;

struct page___214 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___209 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___56 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___214 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___214 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___215 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___204 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___204;

struct vm_area_struct___214 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___214 *vm_next;
	struct vm_area_struct___214 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___215 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___204 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___209 *vm_file;
	struct file___209 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___210 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___216 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___216 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___186 *pids[4];
	struct pid___186 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___215 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___214;

struct mm_struct___215 {
	struct {
		struct vm_area_struct___214 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___209 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___214 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___216 *owner;
		struct user_namespace___25 *user_ns;
		struct file___209 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___144;

struct nsproxy___195 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___186 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___144 *cgroup_ns;
};

struct cgroup_subsys_state___144;

struct cgroup___144;

struct css_set___144 {
	struct cgroup_subsys_state___144 *subsys[14];
	refcount_t refcount;
	struct css_set___144 *dom_cset;
	struct cgroup___144 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___144 *mg_src_cgrp;
	struct cgroup___144 *mg_dst_cgrp;
	struct css_set___144 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___77 {
	struct pmu___77 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___216 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___77 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct vm_struct___192 {
	struct vm_struct___192 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___214 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___209;

struct address_space___209 {
	struct inode___209 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___209 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___204;

struct dev_pagemap___204 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___204 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___209;

struct path___209 {
	struct vfsmount___209 *mnt;
	struct dentry___209 *dentry;
};

struct fown_struct___186 {
	rwlock_t lock;
	struct pid___186 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___209 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___209 f_path;
	struct inode___209 *f_inode;
	const struct file_operations___210 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___186 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___209 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___204;

struct vm_operations_struct___204 {
	void (*open)(struct vm_area_struct___214 *);
	void (*close)(struct vm_area_struct___214 *);
	int (*may_split)(struct vm_area_struct___214 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___214 *);
	int (*mprotect)(struct vm_area_struct___214 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___204 *);
	vm_fault_t (*huge_fault)(struct vm_fault___204 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___204 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___214 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___204 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___204 *);
	int (*access)(struct vm_area_struct___214 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___214 *);
	int (*set_policy)(struct vm_area_struct___214 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___214 *, long unsigned int);
	struct page___214 * (*find_special_page)(struct vm_area_struct___214 *, long unsigned int);
};

struct core_thread___214 {
	struct task_struct___216 *task;
	struct core_thread___214 *next;
};

struct core_state___214 {
	atomic_t nr_threads;
	struct core_thread___214 dumper;
	struct completion startup;
};

struct vm_fault___204 {
	const struct {
		struct vm_area_struct___214 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___214 *cow_page;
	struct page___214 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___214 prealloc_pte;
};

struct kernfs_root___197;

struct kernfs_elem_dir___197 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___197 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___197;

struct kernfs_root___197 {
	struct kernfs_node___197 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___197 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___197 {
	struct kernfs_node___197 *target_kn;
};

struct kernfs_ops___197;

struct kernfs_elem_attr___197 {
	const struct kernfs_ops___197 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___197 *notify_next;
};

struct kernfs_node___197 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___197 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___197 dir;
		struct kernfs_elem_symlink___197 symlink;
		struct kernfs_elem_attr___197 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___197;

struct kernfs_ops___197 {
	int (*open)(struct kernfs_open_file___197 *);
	void (*release)(struct kernfs_open_file___197 *);
	int (*seq_show)(struct seq_file___184 *, void *);
	void * (*seq_start)(struct seq_file___184 *, loff_t *);
	void * (*seq_next)(struct seq_file___184 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___184 *, void *);
	ssize_t (*read)(struct kernfs_open_file___197 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___197 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___197 *, struct poll_table_struct___138 *);
	int (*mmap)(struct kernfs_open_file___197 *, struct vm_area_struct___214 *);
};

struct kernfs_syscall_ops___197 {
	int (*show_options)(struct seq_file___184 *, struct kernfs_root___197 *);
	int (*mkdir)(struct kernfs_node___197 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___197 *);
	int (*rename)(struct kernfs_node___197 *, struct kernfs_node___197 *, const char *);
	int (*show_path)(struct seq_file___184 *, struct kernfs_node___197 *, struct kernfs_root___197 *);
};

struct seq_operations___184;

struct seq_file___184 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___184 *op;
	int poll_event;
	const struct file___209 *file;
	void *private;
};

struct kernfs_open_file___197 {
	struct kernfs_node___197 *kn;
	struct file___209 *file;
	struct seq_file___184 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___204 *vm_ops;
};

typedef void (*poll_queue_proc___145)(struct file___209 *, wait_queue_head_t *, struct poll_table_struct___138 *);

struct poll_table_struct___138 {
	poll_queue_proc___145 _qproc;
	__poll_t _key;
};

struct bin_attribute___197;

struct attribute_group___197 {
	const char *name;
	umode_t (*is_visible)(struct kobject___197 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___197 *, struct bin_attribute___197 *, int);
	struct attribute **attrs;
	struct bin_attribute___197 **bin_attrs;
};

struct bin_attribute___197 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___209 * (*f_mapping)();
	ssize_t (*read)(struct file___209 *, struct kobject___197 *, struct bin_attribute___197 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___209 *, struct kobject___197 *, struct bin_attribute___197 *, char *, loff_t, size_t);
	int (*mmap)(struct file___209 *, struct kobject___197 *, struct bin_attribute___197 *, struct vm_area_struct___214 *);
};

struct sysfs_ops___197 {
	ssize_t (*show)(struct kobject___197 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___197 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___197;

struct kset___197 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___197 kobj;
	const struct kset_uevent_ops___197 *uevent_ops;
};

struct kobj_type___197 {
	void (*release)(struct kobject___197 *);
	const struct sysfs_ops___197 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___197 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___197 *);
	const void * (*namespace)(struct kobject___197 *);
	void (*get_ownership)(struct kobject___197 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___197 {
	int (* const filter)(struct kset___197 *, struct kobject___197 *);
	const char * (* const name)(struct kset___197 *, struct kobject___197 *);
	int (* const uevent)(struct kset___197 *, struct kobject___197 *, struct kobj_uevent_env *);
};

struct wakeup_source___184;

struct wake_irq___7;

struct device___184;

struct dev_pm_qos___18;

struct dev_pm_info___184 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___184 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___7 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___8 *subsys_data;
	void (*set_latency_tolerance)(struct device___184 *, s32);
	struct dev_pm_qos___18 *qos;
};

struct device_type___184;

struct bus_type___184;

struct device_driver___184;

struct dev_pm_domain___184;

struct device_node___78;

struct fwnode_handle___181;

struct class___184;

struct device___184 {
	struct kobject___197 kobj;
	struct device___184 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___184 *type;
	struct bus_type___184 *bus;
	struct device_driver___184 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___184 power;
	struct dev_pm_domain___184 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___78 *of_node;
	struct fwnode_handle___181 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___184 *class;
	const struct attribute_group___197 **groups;
	void (*release)(struct device___184 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___184 {
	int (*prepare)(struct device___184 *);
	void (*complete)(struct device___184 *);
	int (*suspend)(struct device___184 *);
	int (*resume)(struct device___184 *);
	int (*freeze)(struct device___184 *);
	int (*thaw)(struct device___184 *);
	int (*poweroff)(struct device___184 *);
	int (*restore)(struct device___184 *);
	int (*suspend_late)(struct device___184 *);
	int (*resume_early)(struct device___184 *);
	int (*freeze_late)(struct device___184 *);
	int (*thaw_early)(struct device___184 *);
	int (*poweroff_late)(struct device___184 *);
	int (*restore_early)(struct device___184 *);
	int (*suspend_noirq)(struct device___184 *);
	int (*resume_noirq)(struct device___184 *);
	int (*freeze_noirq)(struct device___184 *);
	int (*thaw_noirq)(struct device___184 *);
	int (*poweroff_noirq)(struct device___184 *);
	int (*restore_noirq)(struct device___184 *);
	int (*runtime_suspend)(struct device___184 *);
	int (*runtime_resume)(struct device___184 *);
	int (*runtime_idle)(struct device___184 *);
};

struct wakeup_source___184 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___7 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___184 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___7 {
	struct device___184 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___18;

struct dev_pm_qos___18 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___18 *resume_latency_req;
	struct dev_pm_qos_request___18 *latency_tolerance_req;
	struct dev_pm_qos_request___18 *flags_req;
};

struct dev_pm_domain___184 {
	struct dev_pm_ops___184 ops;
	int (*start)(struct device___184 *);
	void (*detach)(struct device___184 *, bool);
	int (*activate)(struct device___184 *);
	void (*sync)(struct device___184 *);
	void (*dismiss)(struct device___184 *);
};

struct bus_type___184 {
	const char *name;
	const char *dev_name;
	struct device___184 *dev_root;
	const struct attribute_group___197 **bus_groups;
	const struct attribute_group___197 **dev_groups;
	const struct attribute_group___197 **drv_groups;
	int (*match)(struct device___184 *, struct device_driver___184 *);
	int (*uevent)(struct device___184 *, struct kobj_uevent_env *);
	int (*probe)(struct device___184 *);
	void (*sync_state)(struct device___184 *);
	void (*remove)(struct device___184 *);
	void (*shutdown)(struct device___184 *);
	int (*online)(struct device___184 *);
	int (*offline)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	int (*num_vf)(struct device___184 *);
	int (*dma_configure)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___184 {
	const char *name;
	struct bus_type___184 *bus;
	struct module___193 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___184 *);
	void (*sync_state)(struct device___184 *);
	int (*remove)(struct device___184 *);
	void (*shutdown)(struct device___184 *);
	int (*suspend)(struct device___184 *, pm_message_t);
	int (*resume)(struct device___184 *);
	const struct attribute_group___197 **groups;
	const struct attribute_group___197 **dev_groups;
	const struct dev_pm_ops___184 *pm;
	void (*coredump)(struct device___184 *);
	struct driver_private *p;
};

struct device_type___184 {
	const char *name;
	const struct attribute_group___197 **groups;
	int (*uevent)(struct device___184 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___184 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___184 *);
	const struct dev_pm_ops___184 *pm;
};

struct class___184 {
	const char *name;
	struct module___193 *owner;
	const struct attribute_group___197 **class_groups;
	const struct attribute_group___197 **dev_groups;
	struct kobject___197 *dev_kobj;
	int (*dev_uevent)(struct device___184 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___184 *, umode_t *);
	void (*class_release)(struct class___184 *);
	void (*dev_release)(struct device___184 *);
	int (*shutdown_pre)(struct device___184 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___184 *);
	void (*get_ownership)(struct device___184 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___184 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___181;

struct fwnode_handle___181 {
	struct fwnode_handle___181 *secondary;
	const struct fwnode_operations___181 *ops;
	struct device___184 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___56;

struct device_node___78 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___181 fwnode;
	struct property___56 *properties;
	struct property___56 *deadprops;
	struct device_node___78 *parent;
	struct device_node___78 *child;
	struct device_node___78 *sibling;
	struct kobject___197 kobj;
	long unsigned int _flags;
	void *data;
};

enum pm_qos_flags_status___2 {
	PM_QOS_FLAGS_UNDEFINED___2 = 4294967295,
	PM_QOS_FLAGS_NONE___2 = 0,
	PM_QOS_FLAGS_SOME___2 = 1,
	PM_QOS_FLAGS_ALL___2 = 2,
};

struct dev_pm_qos_request___18 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___184 *dev;
};

struct fwnode_reference_args___181;

struct fwnode_endpoint___181;

struct fwnode_operations___181 {
	struct fwnode_handle___181 * (*get)(struct fwnode_handle___181 *);
	void (*put)(struct fwnode_handle___181 *);
	bool (*device_is_available)(const struct fwnode_handle___181 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___181 *, const struct device___184 *);
	bool (*property_present)(const struct fwnode_handle___181 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___181 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___181 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___181 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*get_parent)(const struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*get_next_child_node)(const struct fwnode_handle___181 *, struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*get_named_child_node)(const struct fwnode_handle___181 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___181 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___181 *);
	struct fwnode_handle___181 * (*graph_get_next_endpoint)(const struct fwnode_handle___181 *, struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*graph_get_remote_endpoint)(const struct fwnode_handle___181 *);
	struct fwnode_handle___181 * (*graph_get_port_parent)(struct fwnode_handle___181 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___181 *, struct fwnode_endpoint___181 *);
	int (*add_links)(struct fwnode_handle___181 *);
};

struct fwnode_endpoint___181 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___181 *local_fwnode;
};

struct fwnode_reference_args___181 {
	struct fwnode_handle___181 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___56 {
	char *name;
	int length;
	void *value;
	struct property___56 *next;
	long unsigned int _flags;
	struct bin_attribute___197 attr;
};

struct dev_pagemap_ops___204 {
	void (*page_free)(struct page___214 *);
	void (*kill)(struct dev_pagemap___204 *);
	void (*cleanup)(struct dev_pagemap___204 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___204 *);
};

struct dentry_operations___209;

struct dentry___209 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___209 *d_parent;
	struct qstr d_name;
	struct inode___209 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___209 *d_op;
	struct super_block___209 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___209;

struct inode___209 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___209 *i_op;
	struct super_block___209 *i_sb;
	struct address_space___209 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___210 *i_fop;
		void (*free_inode)(struct inode___209 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___209 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___68 *i_pipe;
		struct cdev___52 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___209 {
	int (*d_revalidate)(struct dentry___209 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___209 *, unsigned int);
	int (*d_hash)(const struct dentry___209 *, struct qstr *);
	int (*d_compare)(const struct dentry___209 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___209 *);
	int (*d_init)(struct dentry___209 *);
	void (*d_release)(struct dentry___209 *);
	void (*d_prune)(struct dentry___209 *);
	void (*d_iput)(struct dentry___209 *, struct inode___209 *);
	char * (*d_dname)(struct dentry___209 *, char *, int);
	struct vfsmount___209 * (*d_automount)(struct path___209 *);
	int (*d_manage)(const struct path___209 *, bool);
	struct dentry___209 * (*d_real)(struct dentry___209 *, const struct inode___209 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___209;

struct mem_dqinfo___209 {
	struct quota_format_type___209 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___209;

struct quota_info___209 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___209 *files[3];
	struct mem_dqinfo___209 info[3];
	const struct quota_format_ops___209 *ops[3];
};

struct rcuwait___210 {
	struct task_struct___216 *task;
};

struct percpu_rw_semaphore___210 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___210 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___209 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___210 rw_sem[3];
};

struct super_operations___209;

struct dquot_operations___209;

struct quotactl_ops___209;

struct super_block___209 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___209 *s_type;
	const struct super_operations___209 *s_op;
	const struct dquot_operations___209 *dq_op;
	const struct quotactl_ops___209 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___209 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___209 s_dquot;
	struct sb_writers___209 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___209 *s_d_op;
	int cleancache_poolid;
	struct shrinker___90 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___209 {
	struct dentry___209 *mnt_root;
	struct super_block___209 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct cgroup_subsys___144;

struct cgroup_subsys_state___144 {
	struct cgroup___144 *cgroup;
	struct cgroup_subsys___144 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___144 *parent;
};

struct cgroup_file___144 {
	struct kernfs_node___197 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___144 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___216 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___144;

struct cgroup_rstat_cpu___144;

struct cgroup___144 {
	struct cgroup_subsys_state___144 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___197 *kn;
	struct cgroup_file___144 procs_file;
	struct cgroup_file___144 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___144 *subsys[14];
	struct cgroup_root___144 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___144 *dom_cgrp;
	struct cgroup___144 *old_dom_cgrp;
	struct cgroup_rstat_cpu___144 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___144 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___209 {
	struct file___209 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___209 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___100 *ki_waitq;
	};
};

struct iattr___209 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___209 *ia_file;
};

struct dquot___209 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___209 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___209 {
	int qf_fmt_id;
	const struct quota_format_ops___209 *qf_ops;
	struct module___193 *qf_owner;
	struct quota_format_type___209 *qf_next;
};

struct quota_format_ops___209 {
	int (*check_quota_file)(struct super_block___209 *, int);
	int (*read_file_info)(struct super_block___209 *, int);
	int (*write_file_info)(struct super_block___209 *, int);
	int (*free_file_info)(struct super_block___209 *, int);
	int (*read_dqblk)(struct dquot___209 *);
	int (*commit_dqblk)(struct dquot___209 *);
	int (*release_dqblk)(struct dquot___209 *);
	int (*get_next_id)(struct super_block___209 *, struct kqid *);
};

struct dquot_operations___209 {
	int (*write_dquot)(struct dquot___209 *);
	struct dquot___209 * (*alloc_dquot)(struct super_block___209 *, int);
	void (*destroy_dquot)(struct dquot___209 *);
	int (*acquire_dquot)(struct dquot___209 *);
	int (*release_dquot)(struct dquot___209 *);
	int (*mark_dirty)(struct dquot___209 *);
	int (*write_info)(struct super_block___209 *, int);
	qsize_t * (*get_reserved_space)(struct inode___209 *);
	int (*get_projid)(struct inode___209 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___209 *, qsize_t *);
	int (*get_next_id)(struct super_block___209 *, struct kqid *);
};

struct quotactl_ops___209 {
	int (*quota_on)(struct super_block___209 *, int, int, const struct path___209 *);
	int (*quota_off)(struct super_block___209 *, int);
	int (*quota_enable)(struct super_block___209 *, unsigned int);
	int (*quota_disable)(struct super_block___209 *, unsigned int);
	int (*quota_sync)(struct super_block___209 *, int);
	int (*set_info)(struct super_block___209 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___209 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___209 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___209 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___209 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___209 *, unsigned int);
};

struct address_space_operations___209 {
	int (*writepage)(struct page___214 *, struct writeback_control___3 *);
	int (*readpage)(struct file___209 *, struct page___214 *);
	int (*writepages)(struct address_space___209 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___214 *);
	int (*readpages)(struct file___209 *, struct address_space___209 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___209 *, struct address_space___209 *, loff_t, unsigned int, unsigned int, struct page___214 **, void **);
	int (*write_end)(struct file___209 *, struct address_space___209 *, loff_t, unsigned int, unsigned int, struct page___214 *, void *);
	sector_t (*bmap)(struct address_space___209 *, sector_t);
	void (*invalidatepage)(struct page___214 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___214 *, gfp_t);
	void (*freepage)(struct page___214 *);
	ssize_t (*direct_IO)(struct kiocb___209 *, struct iov_iter___129 *);
	int (*migratepage)(struct address_space___209 *, struct page___214 *, struct page___214 *, enum migrate_mode);
	bool (*isolate_page)(struct page___214 *, isolate_mode_t);
	void (*putback_page)(struct page___214 *);
	int (*launder_page)(struct page___214 *);
	int (*is_partially_uptodate)(struct page___214 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___214 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___209 *, struct page___214 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___209 *, sector_t *);
	void (*swap_deactivate)(struct file___209 *);
};

struct inode_operations___209 {
	struct dentry___209 * (*lookup)(struct inode___209 *, struct dentry___209 *, unsigned int);
	const char * (*get_link)(struct dentry___209 *, struct inode___209 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___209 *, int);
	struct posix_acl * (*get_acl)(struct inode___209 *, int, bool);
	int (*readlink)(struct dentry___209 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___209 *, struct dentry___209 *, umode_t, bool);
	int (*link)(struct dentry___209 *, struct inode___209 *, struct dentry___209 *);
	int (*unlink)(struct inode___209 *, struct dentry___209 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___209 *, struct dentry___209 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___209 *, struct dentry___209 *, umode_t);
	int (*rmdir)(struct inode___209 *, struct dentry___209 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___209 *, struct dentry___209 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___209 *, struct dentry___209 *, struct inode___209 *, struct dentry___209 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___209 *, struct iattr___209 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___209 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___209 *, char *, size_t);
	int (*fiemap)(struct inode___209 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___209 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___209 *, struct dentry___209 *, struct file___209 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___209 *, struct dentry___209 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___209 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___209 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___209 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___209 {
	void (*fl_copy_lock)(struct file_lock___209 *, struct file_lock___209 *);
	void (*fl_release_private)(struct file_lock___209 *);
};

struct lock_manager_operations___209;

struct file_lock___209 {
	struct file_lock___209 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___209 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___209 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___209 *fl_ops;
	const struct lock_manager_operations___209 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___209 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___209 *);
	int (*lm_grant)(struct file_lock___209 *, int);
	bool (*lm_break)(struct file_lock___209 *);
	int (*lm_change)(struct file_lock___209 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___209 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___209 *);
};

struct fasync_struct___209 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___209 *fa_next;
	struct file___209 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___209 {
	struct inode___209 * (*alloc_inode)(struct super_block___209 *);
	void (*destroy_inode)(struct inode___209 *);
	void (*free_inode)(struct inode___209 *);
	void (*dirty_inode)(struct inode___209 *, int);
	int (*write_inode)(struct inode___209 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___209 *);
	void (*evict_inode)(struct inode___209 *);
	void (*put_super)(struct super_block___209 *);
	int (*sync_fs)(struct super_block___209 *, int);
	int (*freeze_super)(struct super_block___209 *);
	int (*freeze_fs)(struct super_block___209 *);
	int (*thaw_super)(struct super_block___209 *);
	int (*unfreeze_fs)(struct super_block___209 *);
	int (*statfs)(struct dentry___209 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___209 *, int *, char *);
	void (*umount_begin)(struct super_block___209 *);
	int (*show_options)(struct seq_file___184 *, struct dentry___209 *);
	int (*show_devname)(struct seq_file___184 *, struct dentry___209 *);
	int (*show_path)(struct seq_file___184 *, struct dentry___209 *);
	int (*show_stats)(struct seq_file___184 *, struct dentry___209 *);
	ssize_t (*quota_read)(struct super_block___209 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___209 *, int, const char *, size_t, loff_t);
	struct dquot___209 ** (*get_dquots)(struct inode___209 *);
	long int (*nr_cached_objects)(struct super_block___209 *, struct shrink_control___90 *);
	long int (*free_cached_objects)(struct super_block___209 *, struct shrink_control___90 *);
	struct file___209 * (*real_loop)(struct file___209 *);
};

struct seq_operations___184 {
	void * (*start)(struct seq_file___184 *, loff_t *);
	void (*stop)(struct seq_file___184 *, void *);
	void * (*next)(struct seq_file___184 *, void *, loff_t *);
	int (*show)(struct seq_file___184 *, void *);
};

struct cgroup_namespace___144 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___144 *root_cset;
};

struct kernel_param_ops___193 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___193 *);
	int (*get)(char *, const struct kernel_param___193 *);
	void (*free)(void *);
};

struct kparam_array___193;

struct kernel_param___193 {
	const char *name;
	struct module___193 *mod;
	const struct kernel_param_ops___193 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___193 *arr;
	};
};

struct kparam_array___193 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___193 *ops;
	void *elem;
};

struct module_attribute___193 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___193 *, struct module_kobject___194 *, char *);
	ssize_t (*store)(struct module_attribute___193 *, struct module_kobject___194 *, const char *, size_t);
	void (*setup)(struct module___193 *, const char *);
	int (*test)(struct module___193 *);
	void (*free)(struct module___193 *);
};

struct trace_event_class___71;

struct trace_event_call___71 {
	struct list_head list;
	struct trace_event_class___71 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___36 *prog_array;
	int (*perf_perm)(struct trace_event_call___71 *, struct perf_event___77 *);
};

struct cftype___144;

struct cgroup_subsys___144 {
	struct cgroup_subsys_state___144 * (*css_alloc)(struct cgroup_subsys_state___144 *);
	int (*css_online)(struct cgroup_subsys_state___144 *);
	void (*css_offline)(struct cgroup_subsys_state___144 *);
	void (*css_released)(struct cgroup_subsys_state___144 *);
	void (*css_free)(struct cgroup_subsys_state___144 *);
	void (*css_reset)(struct cgroup_subsys_state___144 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___144 *, int);
	int (*css_extra_stat_show)(struct seq_file___184 *, struct cgroup_subsys_state___144 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___216 *, struct css_set___144 *);
	void (*cancel_fork)(struct task_struct___216 *, struct css_set___144 *);
	void (*fork)(struct task_struct___216 *);
	void (*exit)(struct task_struct___216 *);
	void (*release)(struct task_struct___216 *);
	void (*bind)(struct cgroup_subsys_state___144 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___144 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___144 *dfl_cftypes;
	struct cftype___144 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___144 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___144 *updated_children;
	struct cgroup___144 *updated_next;
};

struct cgroup_root___144 {
	struct kernfs_root___197 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___144 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___144 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___144 *ss;
	struct list_head node;
	struct kernfs_ops___197 *kf_ops;
	int (*open)(struct kernfs_open_file___197 *);
	void (*release)(struct kernfs_open_file___197 *);
	u64 (*read_u64)(struct cgroup_subsys_state___144 *, struct cftype___144 *);
	s64 (*read_s64)(struct cgroup_subsys_state___144 *, struct cftype___144 *);
	int (*seq_show)(struct seq_file___184 *, void *);
	void * (*seq_start)(struct seq_file___184 *, loff_t *);
	void * (*seq_next)(struct seq_file___184 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___184 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___144 *, struct cftype___144 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___144 *, struct cftype___144 *, s64);
	ssize_t (*write)(struct kernfs_open_file___197 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___197 *, struct poll_table_struct___138 *);
};

struct perf_cpu_context___77;

struct perf_output_handle___77;

struct pmu___77 {
	struct list_head entry;
	struct module___193 *module;
	struct device___184 *dev;
	const struct attribute_group___197 **attr_groups;
	const struct attribute_group___197 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___77 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___77 *);
	void (*pmu_disable)(struct pmu___77 *);
	int (*event_init)(struct perf_event___77 *);
	void (*event_mapped)(struct perf_event___77 *, struct mm_struct___215 *);
	void (*event_unmapped)(struct perf_event___77 *, struct mm_struct___215 *);
	int (*add)(struct perf_event___77 *, int);
	void (*del)(struct perf_event___77 *, int);
	void (*start)(struct perf_event___77 *, int);
	void (*stop)(struct perf_event___77 *, int);
	void (*read)(struct perf_event___77 *);
	void (*start_txn)(struct pmu___77 *, unsigned int);
	int (*commit_txn)(struct pmu___77 *);
	void (*cancel_txn)(struct pmu___77 *);
	int (*event_idx)(struct perf_event___77 *);
	void (*sched_task)(struct perf_event_context___77 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___77 *, struct perf_event_context___77 *);
	void * (*setup_aux)(struct perf_event___77 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___77 *, struct perf_output_handle___77 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___77 *);
	int (*aux_output_match)(struct perf_event___77 *);
	int (*filter_match)(struct perf_event___77 *);
	int (*check_period)(struct perf_event___77 *, u64);
};

struct perf_cpu_context___77 {
	struct perf_event_context___77 ctx;
	struct perf_event_context___77 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___77 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___77 **heap;
	struct perf_event___77 *heap_default[2];
};

struct perf_output_handle___77 {
	struct perf_event___77 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___77 {
	struct cgroup_subsys_state___144 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___71 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___71 *);
	};
};

struct trace_event_class___71 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___71 *, enum trace_reg, void *);
	struct trace_event_fields___71 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___71 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___71 *);
};

struct wakeup_source___185;

struct wake_irq___8;

struct device___185;

struct dev_pm_qos___19;

struct dev_pm_info___185 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___185 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___8 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___8 *subsys_data;
	void (*set_latency_tolerance)(struct device___185 *, s32);
	struct dev_pm_qos___19 *qos;
};

struct device_private___12;

struct device_type___185;

struct bus_type___185;

struct device_driver___185;

struct dev_pm_domain___185;

struct class___185;

struct device___185 {
	struct kobject___41 kobj;
	struct device___185 *parent;
	struct device_private___12 *p;
	const char *init_name;
	const struct device_type___185 *type;
	struct bus_type___185 *bus;
	struct device_driver___185 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___185 power;
	struct dev_pm_domain___185 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___7 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___185 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___185 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___185 {
	int (*prepare)(struct device___185 *);
	void (*complete)(struct device___185 *);
	int (*suspend)(struct device___185 *);
	int (*resume)(struct device___185 *);
	int (*freeze)(struct device___185 *);
	int (*thaw)(struct device___185 *);
	int (*poweroff)(struct device___185 *);
	int (*restore)(struct device___185 *);
	int (*suspend_late)(struct device___185 *);
	int (*resume_early)(struct device___185 *);
	int (*freeze_late)(struct device___185 *);
	int (*thaw_early)(struct device___185 *);
	int (*poweroff_late)(struct device___185 *);
	int (*restore_early)(struct device___185 *);
	int (*suspend_noirq)(struct device___185 *);
	int (*resume_noirq)(struct device___185 *);
	int (*freeze_noirq)(struct device___185 *);
	int (*thaw_noirq)(struct device___185 *);
	int (*poweroff_noirq)(struct device___185 *);
	int (*restore_noirq)(struct device___185 *);
	int (*runtime_suspend)(struct device___185 *);
	int (*runtime_resume)(struct device___185 *);
	int (*runtime_idle)(struct device___185 *);
};

struct wakeup_source___185 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___8 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___185 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___8 {
	struct device___185 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___19;

struct dev_pm_qos___19 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___19 *resume_latency_req;
	struct dev_pm_qos_request___19 *latency_tolerance_req;
	struct dev_pm_qos_request___19 *flags_req;
};

struct dev_pm_domain___185 {
	struct dev_pm_ops___185 ops;
	int (*start)(struct device___185 *);
	void (*detach)(struct device___185 *, bool);
	int (*activate)(struct device___185 *);
	void (*sync)(struct device___185 *);
	void (*dismiss)(struct device___185 *);
};

struct subsys_private___12;

struct bus_type___185 {
	const char *name;
	const char *dev_name;
	struct device___185 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___185 *, struct device_driver___185 *);
	int (*uevent)(struct device___185 *, struct kobj_uevent_env *);
	int (*probe)(struct device___185 *);
	void (*sync_state)(struct device___185 *);
	void (*remove)(struct device___185 *);
	void (*shutdown)(struct device___185 *);
	int (*online)(struct device___185 *);
	int (*offline)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	int (*num_vf)(struct device___185 *);
	int (*dma_configure)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___12 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___12;

struct device_driver___185 {
	const char *name;
	struct bus_type___185 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___185 *);
	void (*sync_state)(struct device___185 *);
	int (*remove)(struct device___185 *);
	void (*shutdown)(struct device___185 *);
	int (*suspend)(struct device___185 *, pm_message_t);
	int (*resume)(struct device___185 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___185 *pm;
	void (*coredump)(struct device___185 *);
	struct driver_private___12 *p;
};

struct subsys_private___12 {
	struct kset___41 subsys;
	struct kset___41 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___41 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___185 *bus;
	struct kset___41 glue_dirs;
	struct class___185 *class;
};

struct device_type___185 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___185 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___185 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___185 *);
	const struct dev_pm_ops___185 *pm;
};

struct class___185 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___185 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___185 *, umode_t *);
	void (*class_release)(struct class___185 *);
	void (*dev_release)(struct device___185 *);
	int (*shutdown_pre)(struct device___185 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___185 *);
	void (*get_ownership)(struct device___185 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___185 *pm;
	struct subsys_private___12 *p;
};

struct driver_private___12 {
	struct kobject___41 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___191 *mkobj;
	struct device_driver___185 *driver;
};

struct device_private___12 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___185 *async_driver;
	char *deferred_probe_reason;
	struct device___185 *device;
	u8 dead;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct device_link___17 {
	struct device___185 *supplier;
	struct list_head s_node;
	struct device___185 *consumer;
	struct list_head c_node;
	struct device___185 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct dev_pm_qos_request___19 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___185 *dev;
};

typedef int (*pm_callback_t)(struct device___185 *);

struct wakeup_source___186;

struct wake_irq___9;

struct device___186;

struct dev_pm_qos___20;

struct dev_pm_info___186 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___186 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___9 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___8 *subsys_data;
	void (*set_latency_tolerance)(struct device___186 *, s32);
	struct dev_pm_qos___20 *qos;
};

struct device_type___186;

struct bus_type___186;

struct device_driver___186;

struct dev_pm_domain___186;

struct fwnode_handle___182;

struct class___186;

struct device___186 {
	struct kobject___41 kobj;
	struct device___186 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___186 *type;
	struct bus_type___186 *bus;
	struct device_driver___186 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___186 power;
	struct dev_pm_domain___186 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___182 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___186 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___186 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___186 {
	int (*prepare)(struct device___186 *);
	void (*complete)(struct device___186 *);
	int (*suspend)(struct device___186 *);
	int (*resume)(struct device___186 *);
	int (*freeze)(struct device___186 *);
	int (*thaw)(struct device___186 *);
	int (*poweroff)(struct device___186 *);
	int (*restore)(struct device___186 *);
	int (*suspend_late)(struct device___186 *);
	int (*resume_early)(struct device___186 *);
	int (*freeze_late)(struct device___186 *);
	int (*thaw_early)(struct device___186 *);
	int (*poweroff_late)(struct device___186 *);
	int (*restore_early)(struct device___186 *);
	int (*suspend_noirq)(struct device___186 *);
	int (*resume_noirq)(struct device___186 *);
	int (*freeze_noirq)(struct device___186 *);
	int (*thaw_noirq)(struct device___186 *);
	int (*poweroff_noirq)(struct device___186 *);
	int (*restore_noirq)(struct device___186 *);
	int (*runtime_suspend)(struct device___186 *);
	int (*runtime_resume)(struct device___186 *);
	int (*runtime_idle)(struct device___186 *);
};

struct wakeup_source___186 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___9 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___186 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___9 {
	struct device___186 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___20;

struct dev_pm_qos___20 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___20 *resume_latency_req;
	struct dev_pm_qos_request___20 *latency_tolerance_req;
	struct dev_pm_qos_request___20 *flags_req;
};

struct dev_pm_domain___186 {
	struct dev_pm_ops___186 ops;
	int (*start)(struct device___186 *);
	void (*detach)(struct device___186 *, bool);
	int (*activate)(struct device___186 *);
	void (*sync)(struct device___186 *);
	void (*dismiss)(struct device___186 *);
};

struct bus_type___186 {
	const char *name;
	const char *dev_name;
	struct device___186 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___186 *, struct device_driver___186 *);
	int (*uevent)(struct device___186 *, struct kobj_uevent_env *);
	int (*probe)(struct device___186 *);
	void (*sync_state)(struct device___186 *);
	void (*remove)(struct device___186 *);
	void (*shutdown)(struct device___186 *);
	int (*online)(struct device___186 *);
	int (*offline)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	int (*num_vf)(struct device___186 *);
	int (*dma_configure)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___186 {
	const char *name;
	struct bus_type___186 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___186 *);
	void (*sync_state)(struct device___186 *);
	int (*remove)(struct device___186 *);
	void (*shutdown)(struct device___186 *);
	int (*suspend)(struct device___186 *, pm_message_t);
	int (*resume)(struct device___186 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___186 *pm;
	void (*coredump)(struct device___186 *);
	struct driver_private *p;
};

struct device_type___186 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___186 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___186 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___186 *);
	const struct dev_pm_ops___186 *pm;
};

struct class___186 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___186 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___186 *, umode_t *);
	void (*class_release)(struct class___186 *);
	void (*dev_release)(struct device___186 *);
	int (*shutdown_pre)(struct device___186 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___186 *);
	void (*get_ownership)(struct device___186 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___186 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___182;

struct fwnode_handle___182 {
	struct fwnode_handle___182 *secondary;
	const struct fwnode_operations___182 *ops;
	struct device___186 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___182;

struct fwnode_endpoint___182;

struct fwnode_operations___182 {
	struct fwnode_handle___182 * (*get)(struct fwnode_handle___182 *);
	void (*put)(struct fwnode_handle___182 *);
	bool (*device_is_available)(const struct fwnode_handle___182 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___182 *, const struct device___186 *);
	bool (*property_present)(const struct fwnode_handle___182 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___182 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___182 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___182 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*get_parent)(const struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*get_next_child_node)(const struct fwnode_handle___182 *, struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*get_named_child_node)(const struct fwnode_handle___182 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___182 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___182 *);
	struct fwnode_handle___182 * (*graph_get_next_endpoint)(const struct fwnode_handle___182 *, struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*graph_get_remote_endpoint)(const struct fwnode_handle___182 *);
	struct fwnode_handle___182 * (*graph_get_port_parent)(struct fwnode_handle___182 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___182 *, struct fwnode_endpoint___182 *);
	int (*add_links)(struct fwnode_handle___182 *);
};

struct fwnode_endpoint___182 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___182 *local_fwnode;
};

struct fwnode_reference_args___182 {
	struct fwnode_handle___182 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___50;

struct irq_data___50 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___50 *chip;
	struct irq_domain___2 *domain;
	struct irq_data___50 *parent_data;
	void *chip_data;
};

struct irq_chip___50 {
	struct device___186 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___50 *);
	void (*irq_shutdown)(struct irq_data___50 *);
	void (*irq_enable)(struct irq_data___50 *);
	void (*irq_disable)(struct irq_data___50 *);
	void (*irq_ack)(struct irq_data___50 *);
	void (*irq_mask)(struct irq_data___50 *);
	void (*irq_mask_ack)(struct irq_data___50 *);
	void (*irq_unmask)(struct irq_data___50 *);
	void (*irq_eoi)(struct irq_data___50 *);
	int (*irq_set_affinity)(struct irq_data___50 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___50 *);
	int (*irq_set_type)(struct irq_data___50 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___50 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___50 *);
	void (*irq_bus_sync_unlock)(struct irq_data___50 *);
	void (*irq_cpu_online)(struct irq_data___50 *);
	void (*irq_cpu_offline)(struct irq_data___50 *);
	void (*irq_suspend)(struct irq_data___50 *);
	void (*irq_resume)(struct irq_data___50 *);
	void (*irq_pm_shutdown)(struct irq_data___50 *);
	void (*irq_calc_mask)(struct irq_data___50 *);
	void (*irq_print_chip)(struct irq_data___50 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___50 *);
	void (*irq_release_resources)(struct irq_data___50 *);
	void (*irq_compose_msi_msg)(struct irq_data___50 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___50 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___50 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___50 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___50 *, void *);
	void (*ipi_send_single)(struct irq_data___50 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___50 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___50 *);
	void (*irq_nmi_teardown)(struct irq_data___50 *);
	long unsigned int flags;
};

struct dev_pm_qos_request___20 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___186 *dev;
};

struct dentry___210;

struct super_block___210;

struct module___194;

struct file_system_type___210 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___210 * (*mount)(struct file_system_type___210 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___210 *);
	struct module___194 *owner;
	struct file_system_type___210 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___210;

struct kiocb___210;

struct iov_iter___130;

struct poll_table_struct___139;

struct vm_area_struct___215;

struct inode___210;

struct file_lock___210;

struct page___215;

struct seq_file___185;

struct file_operations___211 {
	struct module___194 *owner;
	loff_t (*llseek)(struct file___210 *, loff_t, int);
	ssize_t (*read)(struct file___210 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___210 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___210 *, struct iov_iter___130 *);
	ssize_t (*write_iter)(struct kiocb___210 *, struct iov_iter___130 *);
	int (*iopoll)(struct kiocb___210 *, bool);
	int (*iterate)(struct file___210 *, struct dir_context *);
	int (*iterate_shared)(struct file___210 *, struct dir_context *);
	__poll_t (*poll)(struct file___210 *, struct poll_table_struct___139 *);
	long int (*unlocked_ioctl)(struct file___210 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___210 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___210 *, struct vm_area_struct___215 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___210 *, struct file___210 *);
	int (*flush)(struct file___210 *, fl_owner_t);
	int (*release)(struct inode___210 *, struct file___210 *);
	int (*fsync)(struct file___210 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___210 *, int);
	int (*lock)(struct file___210 *, int, struct file_lock___210 *);
	ssize_t (*sendpage)(struct file___210 *, struct page___215 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___210 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___210 *, long unsigned int);
	int (*flock)(struct file___210 *, int, struct file_lock___210 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___210 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___210 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___210 *, long int, struct file_lock___210 **, void **);
	long int (*fallocate)(struct file___210 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___185 *, struct file___210 *);
	ssize_t (*copy_file_range)(struct file___210 *, loff_t, struct file___210 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___210 *, loff_t, struct file___210 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___210 *, loff_t, loff_t, int);
};

struct vmacache___215 {
	u64 seqnum;
	struct vm_area_struct___215 *vmas[4];
};

struct page_frag___215 {
	struct page___215 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___78;

struct debug_info___78 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___78 *hbp_break[16];
	struct perf_event___78 *hbp_watch[16];
};

struct thread_struct___78 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___78 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___216;

struct pid___187;

struct nsproxy___196;

struct signal_struct___211;

struct bio_list___107;

struct backing_dev_info___100;

struct io_context___107;

struct css_set___145;

struct perf_event_context___78;

struct mem_cgroup___91;

struct request_queue___107;

struct vm_struct___193;

struct task_struct___217 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___217 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___216 *mm;
	struct mm_struct___216 *active_mm;
	struct vmacache___215 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___217 *real_parent;
	struct task_struct___217 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___217 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___187 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___196 *nsproxy;
	struct signal_struct___211 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___217 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___107 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___100 *backing_dev_info;
	struct io_context___107 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___145 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___78 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___215 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___91 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___91 *active_memcg;
	struct request_queue___107 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___217 *oom_reaper_list;
	struct vm_struct___193 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___198;

struct kobj_type___198;

struct kernfs_node___198;

struct kobject___198 {
	const char *name;
	struct list_head entry;
	struct kobject___198 *parent;
	struct kset___198 *kset;
	struct kobj_type___198 *ktype;
	struct kernfs_node___198 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___195 {
	struct kobject___198 kobj;
	struct module___194 *mod;
	struct kobject___198 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___194 {
	struct module___194 *mod;
	struct latch_tree_node node;
};

struct module_layout___194 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___194 mtn;
};

struct module_attribute___194;

struct kernel_param___194;

struct trace_event_call___72;

struct module___194 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___195 mkobj;
	struct module_attribute___194 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___198 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___194 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___194 core_layout;
	struct module_layout___194 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___72 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___78 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___217 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___78)(struct perf_event___78 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___78;

struct fasync_struct___210;

struct pid_namespace___187;

struct perf_cgroup___78;

struct perf_event___78 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___78 *group_leader;
	struct pmu___78 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___78 hw;
	struct perf_event_context___78 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___78 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___217 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___210 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___78 *aux_event;
	void (*destroy)(struct perf_event___78 *);
	struct callback_head callback_head;
	struct pid_namespace___187 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___78 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___78 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___72 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___78 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___187 {
	int nr;
	struct pid_namespace___187 *ns;
};

struct pid_namespace___187 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___217 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___187 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___187 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___187 numbers[1];
};

typedef struct page___215 *pgtable_t___215;

struct address_space___210;

struct dev_pagemap___205;

struct page___215 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___210 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___56 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___215 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___215 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___216 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___205 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___205;

struct vm_area_struct___215 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___215 *vm_next;
	struct vm_area_struct___215 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___216 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___205 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___210 *vm_file;
	struct file___210 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___211 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___217 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___217 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___187 *pids[4];
	struct pid___187 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___216 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___215;

struct mm_struct___216 {
	struct {
		struct vm_area_struct___215 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___210 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___215 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___217 *owner;
		struct user_namespace___25 *user_ns;
		struct file___210 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___145;

struct nsproxy___196 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___187 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___145 *cgroup_ns;
};

struct bio___107;

struct bio_list___107 {
	struct bio___107 *head;
	struct bio___107 *tail;
};

struct cgroup_subsys_state___145;

struct bdi_writeback___100 {
	struct backing_dev_info___100 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___145 *memcg_css;
	struct cgroup_subsys_state___145 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___187;

struct backing_dev_info___100 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___100 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___187 *dev;
	char dev_name[64];
	struct device___187 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___210 *debug_dir;
};

struct io_cq___107;

struct io_context___107 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___107 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___145;

struct css_set___145 {
	struct cgroup_subsys_state___145 *subsys[14];
	refcount_t refcount;
	struct css_set___145 *dom_cset;
	struct cgroup___145 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___145 *mg_src_cgrp;
	struct cgroup___145 *mg_dst_cgrp;
	struct css_set___145 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___78 {
	struct pmu___78 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___217 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___78 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___145;

struct cgroup_subsys_state___145 {
	struct cgroup___145 *cgroup;
	struct cgroup_subsys___145 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___145 *parent;
};

struct cgroup_file___145 {
	struct kernfs_node___198 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___91;

struct mem_cgroup_per_node___91;

struct mem_cgroup___91 {
	struct cgroup_subsys_state___145 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___145 events_file;
	struct cgroup_file___145 events_local_file;
	struct cgroup_file___145 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___91 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___217 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___91 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___107;

struct blk_integrity___107 {
	const struct blk_integrity_profile___107 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___107 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___107 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___107;

struct elevator_queue___107;

struct blk_mq_ops___104;

struct blk_mq_hw_ctx___104;

struct gendisk___110;

struct blkcg_gq___102;

struct blk_mq_tag_set___104;

struct request_queue___107 {
	struct request___107 *last_merge;
	struct elevator_queue___107 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___104 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___104 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___110 *disk;
	struct kobject___198 kobj;
	struct kobject___198 *mq_kobj;
	struct blk_integrity___107 integrity;
	struct device___187 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___102 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___104 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___107 bio_split;
	struct dentry___210 *debugfs_dir;
	struct dentry___210 *sched_debugfs_dir;
	struct dentry___210 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___193 {
	struct vm_struct___193 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___215 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___210;

struct address_space___210 {
	struct inode___210 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___210 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___205;

struct dev_pagemap___205 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___205 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___210;

struct path___210 {
	struct vfsmount___210 *mnt;
	struct dentry___210 *dentry;
};

struct fown_struct___187 {
	rwlock_t lock;
	struct pid___187 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___210 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___210 f_path;
	struct inode___210 *f_inode;
	const struct file_operations___211 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___187 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___210 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___205;

struct vm_operations_struct___205 {
	void (*open)(struct vm_area_struct___215 *);
	void (*close)(struct vm_area_struct___215 *);
	int (*may_split)(struct vm_area_struct___215 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___215 *);
	int (*mprotect)(struct vm_area_struct___215 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___205 *);
	vm_fault_t (*huge_fault)(struct vm_fault___205 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___205 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___215 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___205 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___205 *);
	int (*access)(struct vm_area_struct___215 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___215 *);
	int (*set_policy)(struct vm_area_struct___215 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___215 *, long unsigned int);
	struct page___215 * (*find_special_page)(struct vm_area_struct___215 *, long unsigned int);
};

struct core_thread___215 {
	struct task_struct___217 *task;
	struct core_thread___215 *next;
};

struct core_state___215 {
	atomic_t nr_threads;
	struct core_thread___215 dumper;
	struct completion startup;
};

struct vm_fault___205 {
	const struct {
		struct vm_area_struct___215 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___215 *cow_page;
	struct page___215 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___215 prealloc_pte;
};

struct pglist_data___98;

struct lruvec___98 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___98 *pgdat;
};

struct zone___98 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___98 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___98 {
	struct zone___98 *zone;
	int zone_idx;
};

struct zonelist___98 {
	struct zoneref___98 _zonerefs[321];
};

struct pglist_data___98 {
	struct zone___98 node_zones[5];
	struct zonelist___98 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___217 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___217 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___98 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___198;

struct kernfs_elem_dir___198 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___198 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___198;

struct kernfs_root___198 {
	struct kernfs_node___198 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___198 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___198 {
	struct kernfs_node___198 *target_kn;
};

struct kernfs_ops___198;

struct kernfs_elem_attr___198 {
	const struct kernfs_ops___198 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___198 *notify_next;
};

struct kernfs_node___198 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___198 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___198 dir;
		struct kernfs_elem_symlink___198 symlink;
		struct kernfs_elem_attr___198 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___198;

struct kernfs_ops___198 {
	int (*open)(struct kernfs_open_file___198 *);
	void (*release)(struct kernfs_open_file___198 *);
	int (*seq_show)(struct seq_file___185 *, void *);
	void * (*seq_start)(struct seq_file___185 *, loff_t *);
	void * (*seq_next)(struct seq_file___185 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___185 *, void *);
	ssize_t (*read)(struct kernfs_open_file___198 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___198 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___198 *, struct poll_table_struct___139 *);
	int (*mmap)(struct kernfs_open_file___198 *, struct vm_area_struct___215 *);
};

struct kernfs_syscall_ops___198 {
	int (*show_options)(struct seq_file___185 *, struct kernfs_root___198 *);
	int (*mkdir)(struct kernfs_node___198 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___198 *);
	int (*rename)(struct kernfs_node___198 *, struct kernfs_node___198 *, const char *);
	int (*show_path)(struct seq_file___185 *, struct kernfs_node___198 *, struct kernfs_root___198 *);
};

struct seq_operations___185;

struct seq_file___185 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___185 *op;
	int poll_event;
	const struct file___210 *file;
	void *private;
};

struct kernfs_open_file___198 {
	struct kernfs_node___198 *kn;
	struct file___210 *file;
	struct seq_file___185 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___205 *vm_ops;
};

typedef void (*poll_queue_proc___146)(struct file___210 *, wait_queue_head_t *, struct poll_table_struct___139 *);

struct poll_table_struct___139 {
	poll_queue_proc___146 _qproc;
	__poll_t _key;
};

struct bin_attribute___198;

struct attribute_group___198 {
	const char *name;
	umode_t (*is_visible)(struct kobject___198 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___198 *, struct bin_attribute___198 *, int);
	struct attribute **attrs;
	struct bin_attribute___198 **bin_attrs;
};

struct bin_attribute___198 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___210 * (*f_mapping)();
	ssize_t (*read)(struct file___210 *, struct kobject___198 *, struct bin_attribute___198 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___210 *, struct kobject___198 *, struct bin_attribute___198 *, char *, loff_t, size_t);
	int (*mmap)(struct file___210 *, struct kobject___198 *, struct bin_attribute___198 *, struct vm_area_struct___215 *);
};

struct sysfs_ops___198 {
	ssize_t (*show)(struct kobject___198 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___198 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___198;

struct kset___198 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___198 kobj;
	const struct kset_uevent_ops___198 *uevent_ops;
};

struct kobj_type___198 {
	void (*release)(struct kobject___198 *);
	const struct sysfs_ops___198 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___198 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___198 *);
	const void * (*namespace)(struct kobject___198 *);
	void (*get_ownership)(struct kobject___198 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___198 {
	int (* const filter)(struct kset___198 *, struct kobject___198 *);
	const char * (* const name)(struct kset___198 *, struct kobject___198 *);
	int (* const uevent)(struct kset___198 *, struct kobject___198 *, struct kobj_uevent_env *);
};

struct wakeup_source___187;

struct wake_irq___10;

struct dev_pm_qos___21;

struct dev_pm_info___187 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___187 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___10 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___8 *subsys_data;
	void (*set_latency_tolerance)(struct device___187 *, s32);
	struct dev_pm_qos___21 *qos;
};

struct device_private___13;

struct device_type___187;

struct bus_type___187;

struct device_driver___187;

struct dev_pm_domain___187;

struct device_node___79;

struct fwnode_handle___183;

struct class___187;

struct device___187 {
	struct kobject___198 kobj;
	struct device___187 *parent;
	struct device_private___13 *p;
	const char *init_name;
	const struct device_type___187 *type;
	struct bus_type___187 *bus;
	struct device_driver___187 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___187 power;
	struct dev_pm_domain___187 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___79 *of_node;
	struct fwnode_handle___183 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___187 *class;
	const struct attribute_group___198 **groups;
	void (*release)(struct device___187 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___187 {
	int (*prepare)(struct device___187 *);
	void (*complete)(struct device___187 *);
	int (*suspend)(struct device___187 *);
	int (*resume)(struct device___187 *);
	int (*freeze)(struct device___187 *);
	int (*thaw)(struct device___187 *);
	int (*poweroff)(struct device___187 *);
	int (*restore)(struct device___187 *);
	int (*suspend_late)(struct device___187 *);
	int (*resume_early)(struct device___187 *);
	int (*freeze_late)(struct device___187 *);
	int (*thaw_early)(struct device___187 *);
	int (*poweroff_late)(struct device___187 *);
	int (*restore_early)(struct device___187 *);
	int (*suspend_noirq)(struct device___187 *);
	int (*resume_noirq)(struct device___187 *);
	int (*freeze_noirq)(struct device___187 *);
	int (*thaw_noirq)(struct device___187 *);
	int (*poweroff_noirq)(struct device___187 *);
	int (*restore_noirq)(struct device___187 *);
	int (*runtime_suspend)(struct device___187 *);
	int (*runtime_resume)(struct device___187 *);
	int (*runtime_idle)(struct device___187 *);
};

struct wakeup_source___187 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___10 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___187 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___10 {
	struct device___187 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___21;

struct dev_pm_qos___21 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___21 *resume_latency_req;
	struct dev_pm_qos_request___21 *latency_tolerance_req;
	struct dev_pm_qos_request___21 *flags_req;
};

struct dev_pm_domain___187 {
	struct dev_pm_ops___187 ops;
	int (*start)(struct device___187 *);
	void (*detach)(struct device___187 *, bool);
	int (*activate)(struct device___187 *);
	void (*sync)(struct device___187 *);
	void (*dismiss)(struct device___187 *);
};

struct subsys_private___13;

struct bus_type___187 {
	const char *name;
	const char *dev_name;
	struct device___187 *dev_root;
	const struct attribute_group___198 **bus_groups;
	const struct attribute_group___198 **dev_groups;
	const struct attribute_group___198 **drv_groups;
	int (*match)(struct device___187 *, struct device_driver___187 *);
	int (*uevent)(struct device___187 *, struct kobj_uevent_env *);
	int (*probe)(struct device___187 *);
	void (*sync_state)(struct device___187 *);
	void (*remove)(struct device___187 *);
	void (*shutdown)(struct device___187 *);
	int (*online)(struct device___187 *);
	int (*offline)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	int (*num_vf)(struct device___187 *);
	int (*dma_configure)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private___13 *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct driver_private___13;

struct device_driver___187 {
	const char *name;
	struct bus_type___187 *bus;
	struct module___194 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___187 *);
	void (*sync_state)(struct device___187 *);
	int (*remove)(struct device___187 *);
	void (*shutdown)(struct device___187 *);
	int (*suspend)(struct device___187 *, pm_message_t);
	int (*resume)(struct device___187 *);
	const struct attribute_group___198 **groups;
	const struct attribute_group___198 **dev_groups;
	const struct dev_pm_ops___187 *pm;
	void (*coredump)(struct device___187 *);
	struct driver_private___13 *p;
};

struct subsys_private___13 {
	struct kset___198 subsys;
	struct kset___198 *devices_kset;
	struct list_head interfaces;
	struct mutex mutex;
	struct kset___198 *drivers_kset;
	struct klist klist_devices;
	struct klist klist_drivers;
	struct blocking_notifier_head bus_notifier;
	unsigned int drivers_autoprobe: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bus_type___187 *bus;
	struct kset___198 glue_dirs;
	struct class___187 *class;
};

struct device_type___187 {
	const char *name;
	const struct attribute_group___198 **groups;
	int (*uevent)(struct device___187 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___187 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___187 *);
	const struct dev_pm_ops___187 *pm;
};

struct class___187 {
	const char *name;
	struct module___194 *owner;
	const struct attribute_group___198 **class_groups;
	const struct attribute_group___198 **dev_groups;
	struct kobject___198 *dev_kobj;
	int (*dev_uevent)(struct device___187 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___187 *, umode_t *);
	void (*class_release)(struct class___187 *);
	void (*dev_release)(struct device___187 *);
	int (*shutdown_pre)(struct device___187 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___187 *);
	void (*get_ownership)(struct device___187 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___187 *pm;
	struct subsys_private___13 *p;
};

struct driver_private___13 {
	struct kobject___198 kobj;
	struct klist klist_devices;
	struct klist_node knode_bus;
	struct module_kobject___195 *mkobj;
	struct device_driver___187 *driver;
};

struct device_private___13 {
	struct klist klist_children;
	struct klist_node knode_parent;
	struct klist_node knode_driver;
	struct klist_node knode_bus;
	struct klist_node knode_class;
	struct list_head deferred_probe;
	struct device_driver___187 *async_driver;
	char *deferred_probe_reason;
	struct device___187 *device;
	u8 dead: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___183;

struct fwnode_handle___183 {
	struct fwnode_handle___183 *secondary;
	const struct fwnode_operations___183 *ops;
	struct device___187 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___57;

struct device_node___79 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___183 fwnode;
	struct property___57 *properties;
	struct property___57 *deadprops;
	struct device_node___79 *parent;
	struct device_node___79 *child;
	struct device_node___79 *sibling;
	struct kobject___198 kobj;
	long unsigned int _flags;
	void *data;
};

struct device_link___18 {
	struct device___187 *supplier;
	struct list_head s_node;
	struct device___187 *consumer;
	struct list_head c_node;
	struct device___187 link_dev;
	enum device_link_state___2 status;
	u32 flags;
	refcount_t rpm_active;
	struct kref kref;
	struct work_struct rm_work;
	bool supplier_preactivated;
};

struct fwnode_reference_args___183;

struct fwnode_endpoint___183;

struct fwnode_operations___183 {
	struct fwnode_handle___183 * (*get)(struct fwnode_handle___183 *);
	void (*put)(struct fwnode_handle___183 *);
	bool (*device_is_available)(const struct fwnode_handle___183 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___183 *, const struct device___187 *);
	bool (*property_present)(const struct fwnode_handle___183 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___183 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___183 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___183 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*get_parent)(const struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*get_next_child_node)(const struct fwnode_handle___183 *, struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*get_named_child_node)(const struct fwnode_handle___183 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___183 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___183 *);
	struct fwnode_handle___183 * (*graph_get_next_endpoint)(const struct fwnode_handle___183 *, struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*graph_get_remote_endpoint)(const struct fwnode_handle___183 *);
	struct fwnode_handle___183 * (*graph_get_port_parent)(struct fwnode_handle___183 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___183 *, struct fwnode_endpoint___183 *);
	int (*add_links)(struct fwnode_handle___183 *);
};

struct fwnode_endpoint___183 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___183 *local_fwnode;
};

struct fwnode_reference_args___183 {
	struct fwnode_handle___183 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dentry_operations___210;

struct dentry___210 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___210 *d_parent;
	struct qstr d_name;
	struct inode___210 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___210 *d_op;
	struct super_block___210 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___210;

struct inode___210 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___210 *i_op;
	struct super_block___210 *i_sb;
	struct address_space___210 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___100 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___211 *i_fop;
		void (*free_inode)(struct inode___210 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___210 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___68 *i_pipe;
		struct cdev___52 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___210 {
	int (*d_revalidate)(struct dentry___210 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___210 *, unsigned int);
	int (*d_hash)(const struct dentry___210 *, struct qstr *);
	int (*d_compare)(const struct dentry___210 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___210 *);
	int (*d_init)(struct dentry___210 *);
	void (*d_release)(struct dentry___210 *);
	void (*d_prune)(struct dentry___210 *);
	void (*d_iput)(struct dentry___210 *, struct inode___210 *);
	char * (*d_dname)(struct dentry___210 *, char *, int);
	struct vfsmount___210 * (*d_automount)(struct path___210 *);
	int (*d_manage)(const struct path___210 *, bool);
	struct dentry___210 * (*d_real)(struct dentry___210 *, const struct inode___210 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___210;

struct mem_dqinfo___210 {
	struct quota_format_type___210 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___210;

struct quota_info___210 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___210 *files[3];
	struct mem_dqinfo___210 info[3];
	const struct quota_format_ops___210 *ops[3];
};

struct rcuwait___211 {
	struct task_struct___217 *task;
};

struct percpu_rw_semaphore___211 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___211 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___210 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___211 rw_sem[3];
};

struct shrink_control___91;

struct shrinker___91 {
	long unsigned int (*count_objects)(struct shrinker___91 *, struct shrink_control___91 *);
	long unsigned int (*scan_objects)(struct shrinker___91 *, struct shrink_control___91 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___210;

struct dquot_operations___210;

struct quotactl_ops___210;

struct block_device___110;

struct super_block___210 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___210 *s_type;
	const struct super_operations___210 *s_op;
	const struct dquot_operations___210 *dq_op;
	const struct quotactl_ops___210 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___210 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___110 *s_bdev;
	struct backing_dev_info___100 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___210 s_dquot;
	struct sb_writers___210 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___210 *s_d_op;
	int cleancache_poolid;
	struct shrinker___91 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___210 {
	struct dentry___210 *mnt_root;
	struct super_block___210 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___91 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___91 *memcg;
};

struct psi_group___145 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___217 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___145;

struct cgroup_rstat_cpu___145;

struct cgroup___145 {
	struct cgroup_subsys_state___145 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___198 *kn;
	struct cgroup_file___145 procs_file;
	struct cgroup_file___145 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___145 *subsys[14];
	struct cgroup_root___145 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___145 *dom_cgrp;
	struct cgroup___145 *old_dom_cgrp;
	struct cgroup_rstat_cpu___145 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___145 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___107 {
	struct request_queue___107 *q;
	struct io_context___107 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___101;

struct kiocb___210 {
	struct file___210 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___210 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___101 *ki_waitq;
	};
};

struct iattr___210 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___210 *ia_file;
};

struct dquot___210 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___210 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___210 {
	int qf_fmt_id;
	const struct quota_format_ops___210 *qf_ops;
	struct module___194 *qf_owner;
	struct quota_format_type___210 *qf_next;
};

struct quota_format_ops___210 {
	int (*check_quota_file)(struct super_block___210 *, int);
	int (*read_file_info)(struct super_block___210 *, int);
	int (*write_file_info)(struct super_block___210 *, int);
	int (*free_file_info)(struct super_block___210 *, int);
	int (*read_dqblk)(struct dquot___210 *);
	int (*commit_dqblk)(struct dquot___210 *);
	int (*release_dqblk)(struct dquot___210 *);
	int (*get_next_id)(struct super_block___210 *, struct kqid *);
};

struct dquot_operations___210 {
	int (*write_dquot)(struct dquot___210 *);
	struct dquot___210 * (*alloc_dquot)(struct super_block___210 *, int);
	void (*destroy_dquot)(struct dquot___210 *);
	int (*acquire_dquot)(struct dquot___210 *);
	int (*release_dquot)(struct dquot___210 *);
	int (*mark_dirty)(struct dquot___210 *);
	int (*write_info)(struct super_block___210 *, int);
	qsize_t * (*get_reserved_space)(struct inode___210 *);
	int (*get_projid)(struct inode___210 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___210 *, qsize_t *);
	int (*get_next_id)(struct super_block___210 *, struct kqid *);
};

struct quotactl_ops___210 {
	int (*quota_on)(struct super_block___210 *, int, int, const struct path___210 *);
	int (*quota_off)(struct super_block___210 *, int);
	int (*quota_enable)(struct super_block___210 *, unsigned int);
	int (*quota_disable)(struct super_block___210 *, unsigned int);
	int (*quota_sync)(struct super_block___210 *, int);
	int (*set_info)(struct super_block___210 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___210 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___210 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___210 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___210 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___210 *, unsigned int);
};

struct wait_page_queue___101 {
	struct page___215 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___100;

struct readahead_control___101;

struct swap_info_struct___59;

struct address_space_operations___210 {
	int (*writepage)(struct page___215 *, struct writeback_control___100 *);
	int (*readpage)(struct file___210 *, struct page___215 *);
	int (*writepages)(struct address_space___210 *, struct writeback_control___100 *);
	int (*set_page_dirty)(struct page___215 *);
	int (*readpages)(struct file___210 *, struct address_space___210 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___101 *);
	int (*write_begin)(struct file___210 *, struct address_space___210 *, loff_t, unsigned int, unsigned int, struct page___215 **, void **);
	int (*write_end)(struct file___210 *, struct address_space___210 *, loff_t, unsigned int, unsigned int, struct page___215 *, void *);
	sector_t (*bmap)(struct address_space___210 *, sector_t);
	void (*invalidatepage)(struct page___215 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___215 *, gfp_t);
	void (*freepage)(struct page___215 *);
	ssize_t (*direct_IO)(struct kiocb___210 *, struct iov_iter___130 *);
	int (*migratepage)(struct address_space___210 *, struct page___215 *, struct page___215 *, enum migrate_mode);
	bool (*isolate_page)(struct page___215 *, isolate_mode_t);
	void (*putback_page)(struct page___215 *);
	int (*launder_page)(struct page___215 *);
	int (*is_partially_uptodate)(struct page___215 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___215 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___210 *, struct page___215 *);
	int (*swap_activate)(struct swap_info_struct___59 *, struct file___210 *, sector_t *);
	void (*swap_deactivate)(struct file___210 *);
};

struct writeback_control___100 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___100 *wb;
	struct inode___210 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___101 {
	struct file___210 *file;
	struct address_space___210 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___127;

struct iov_iter___130 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___127 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___59 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___110 *bdev;
	struct file___210 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___210 {
	struct dentry___210 * (*lookup)(struct inode___210 *, struct dentry___210 *, unsigned int);
	const char * (*get_link)(struct dentry___210 *, struct inode___210 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___210 *, int);
	struct posix_acl * (*get_acl)(struct inode___210 *, int, bool);
	int (*readlink)(struct dentry___210 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___210 *, struct dentry___210 *, umode_t, bool);
	int (*link)(struct dentry___210 *, struct inode___210 *, struct dentry___210 *);
	int (*unlink)(struct inode___210 *, struct dentry___210 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___210 *, struct dentry___210 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___210 *, struct dentry___210 *, umode_t);
	int (*rmdir)(struct inode___210 *, struct dentry___210 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___210 *, struct dentry___210 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___210 *, struct dentry___210 *, struct inode___210 *, struct dentry___210 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___210 *, struct iattr___210 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___210 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___210 *, char *, size_t);
	int (*fiemap)(struct inode___210 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___210 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___210 *, struct dentry___210 *, struct file___210 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___210 *, struct dentry___210 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___210 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___210 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___210 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___210 {
	void (*fl_copy_lock)(struct file_lock___210 *, struct file_lock___210 *);
	void (*fl_release_private)(struct file_lock___210 *);
};

struct lock_manager_operations___210;

struct file_lock___210 {
	struct file_lock___210 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___210 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___210 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___210 *fl_ops;
	const struct lock_manager_operations___210 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___210 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___210 *);
	int (*lm_grant)(struct file_lock___210 *, int);
	bool (*lm_break)(struct file_lock___210 *);
	int (*lm_change)(struct file_lock___210 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___210 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___210 *);
};

struct fasync_struct___210 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___210 *fa_next;
	struct file___210 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___210 {
	struct inode___210 * (*alloc_inode)(struct super_block___210 *);
	void (*destroy_inode)(struct inode___210 *);
	void (*free_inode)(struct inode___210 *);
	void (*dirty_inode)(struct inode___210 *, int);
	int (*write_inode)(struct inode___210 *, struct writeback_control___100 *);
	int (*drop_inode)(struct inode___210 *);
	void (*evict_inode)(struct inode___210 *);
	void (*put_super)(struct super_block___210 *);
	int (*sync_fs)(struct super_block___210 *, int);
	int (*freeze_super)(struct super_block___210 *);
	int (*freeze_fs)(struct super_block___210 *);
	int (*thaw_super)(struct super_block___210 *);
	int (*unfreeze_fs)(struct super_block___210 *);
	int (*statfs)(struct dentry___210 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___210 *, int *, char *);
	void (*umount_begin)(struct super_block___210 *);
	int (*show_options)(struct seq_file___185 *, struct dentry___210 *);
	int (*show_devname)(struct seq_file___185 *, struct dentry___210 *);
	int (*show_path)(struct seq_file___185 *, struct dentry___210 *);
	int (*show_stats)(struct seq_file___185 *, struct dentry___210 *);
	ssize_t (*quota_read)(struct super_block___210 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___210 *, int, const char *, size_t, loff_t);
	struct dquot___210 ** (*get_dquots)(struct inode___210 *);
	long int (*nr_cached_objects)(struct super_block___210 *, struct shrink_control___91 *);
	long int (*free_cached_objects)(struct super_block___210 *, struct shrink_control___91 *);
	struct file___210 * (*real_loop)(struct file___210 *);
};

struct block_device___110 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___210 *bd_inode;
	struct super_block___210 *bd_super;
	void *bd_claiming;
	struct device___187 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___198 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___110 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___210 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___107(struct bio___107 *);

struct bio_vec___127 {
	struct page___215 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___107;

struct bio___107 {
	struct bio___107 *bi_next;
	struct block_device___110 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___107 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___102 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___107 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___127 *bi_io_vec;
	struct bio_set___107 *bi_pool;
	struct bio_vec___127 bi_inline_vecs[0];
};

struct seq_operations___185 {
	void * (*start)(struct seq_file___185 *, loff_t *);
	void (*stop)(struct seq_file___185 *, void *);
	void * (*next)(struct seq_file___185 *, void *, loff_t *);
	int (*show)(struct seq_file___185 *, void *);
};

struct cgroup_namespace___145 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___145 *root_cset;
};

struct kernel_param_ops___194 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___194 *);
	int (*get)(char *, const struct kernel_param___194 *);
	void (*free)(void *);
};

struct kparam_array___194;

struct kernel_param___194 {
	const char *name;
	struct module___194 *mod;
	const struct kernel_param_ops___194 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___194 *arr;
	};
};

struct kparam_array___194 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___194 *ops;
	void *elem;
};

struct module_attribute___194 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___194 *, struct module_kobject___195 *, char *);
	ssize_t (*store)(struct module_attribute___194 *, struct module_kobject___195 *, const char *, size_t);
	void (*setup)(struct module___194 *, const char *);
	int (*test)(struct module___194 *);
	void (*free)(struct module___194 *);
};

struct trace_event_class___72;

struct trace_event_call___72 {
	struct list_head list;
	struct trace_event_class___72 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___36 *prog_array;
	int (*perf_perm)(struct trace_event_call___72 *, struct perf_event___78 *);
};

struct dev_pagemap_ops___205 {
	void (*page_free)(struct page___215 *);
	void (*kill)(struct dev_pagemap___205 *);
	void (*cleanup)(struct dev_pagemap___205 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___205 *);
};

struct cftype___145;

struct cgroup_subsys___145 {
	struct cgroup_subsys_state___145 * (*css_alloc)(struct cgroup_subsys_state___145 *);
	int (*css_online)(struct cgroup_subsys_state___145 *);
	void (*css_offline)(struct cgroup_subsys_state___145 *);
	void (*css_released)(struct cgroup_subsys_state___145 *);
	void (*css_free)(struct cgroup_subsys_state___145 *);
	void (*css_reset)(struct cgroup_subsys_state___145 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___145 *, int);
	int (*css_extra_stat_show)(struct seq_file___185 *, struct cgroup_subsys_state___145 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___217 *, struct css_set___145 *);
	void (*cancel_fork)(struct task_struct___217 *, struct css_set___145 *);
	void (*fork)(struct task_struct___217 *);
	void (*exit)(struct task_struct___217 *);
	void (*release)(struct task_struct___217 *);
	void (*bind)(struct cgroup_subsys_state___145 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___145 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___145 *dfl_cftypes;
	struct cftype___145 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___145 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___145 *updated_children;
	struct cgroup___145 *updated_next;
};

struct cgroup_root___145 {
	struct kernfs_root___198 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___145 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___145 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___145 *ss;
	struct list_head node;
	struct kernfs_ops___198 *kf_ops;
	int (*open)(struct kernfs_open_file___198 *);
	void (*release)(struct kernfs_open_file___198 *);
	u64 (*read_u64)(struct cgroup_subsys_state___145 *, struct cftype___145 *);
	s64 (*read_s64)(struct cgroup_subsys_state___145 *, struct cftype___145 *);
	int (*seq_show)(struct seq_file___185 *, void *);
	void * (*seq_start)(struct seq_file___185 *, loff_t *);
	void * (*seq_next)(struct seq_file___185 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___185 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___145 *, struct cftype___145 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___145 *, struct cftype___145 *, s64);
	ssize_t (*write)(struct kernfs_open_file___198 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___198 *, struct poll_table_struct___139 *);
};

struct block_device_operations___107;

struct gendisk___110 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___110 *part0;
	const struct block_device_operations___107 *fops;
	struct request_queue___107 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___100 *bdi;
	struct kobject___198 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___198 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___107 {
	struct bio___107 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___127 *bip_vec;
	struct bio_vec___127 bip_inline_vecs[0];
};

struct blkcg___102;

struct blkg_policy_data___102;

struct blkcg_gq___102 {
	struct request_queue___107 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___102 *blkcg;
	struct blkcg_gq___102 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___102 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___107 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___107(struct request___107 *);

typedef void integrity_complete_fn___107(struct request___107 *, unsigned int);

struct blk_integrity_profile___107 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___107 *prepare_fn;
	integrity_complete_fn___107 *complete_fn;
	const char *name;
};

struct block_device_operations___107 {
	blk_qc_t (*submit_bio)(struct bio___107 *);
	int (*open)(struct block_device___110 *, fmode_t);
	void (*release)(struct gendisk___110 *, fmode_t);
	int (*rw_page)(struct block_device___110 *, sector_t, struct page___215 *, unsigned int);
	int (*ioctl)(struct block_device___110 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___110 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___110 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___110 *);
	int (*getgeo)(struct block_device___110 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___110 *, bool);
	void (*swap_slot_free_notify)(struct block_device___110 *, long unsigned int);
	int (*report_zones)(struct gendisk___110 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___110 *, umode_t *);
	struct module___194 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___110 *, sector_t *);
};

typedef void rq_end_io_fn___107(struct request___107 *, blk_status_t);

struct request___107 {
	struct request_queue___107 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___104 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___107 *bio;
	struct bio___107 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___127 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___107 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___107 *saved_end_io;
		} flush;
	};
	struct gendisk___110 *rq_disk;
	struct block_device___110 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___107 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___104 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___107 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___198 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___210 *debugfs_dir;
	struct dentry___210 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___107;

struct elevator_mq_ops___107 {
	int (*init_sched)(struct request_queue___107 *, struct elevator_type___107 *);
	void (*exit_sched)(struct elevator_queue___107 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___104 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___104 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___104 *);
	bool (*allow_merge)(struct request_queue___107 *, struct request___107 *, struct bio___107 *);
	bool (*bio_merge)(struct request_queue___107 *, struct bio___107 *, unsigned int);
	int (*request_merge)(struct request_queue___107 *, struct request___107 **, struct bio___107 *);
	void (*request_merged)(struct request_queue___107 *, struct request___107 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___107 *, struct request___107 *, struct request___107 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___107 *);
	void (*finish_request)(struct request___107 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___104 *, struct list_head *, bool);
	struct request___107 * (*dispatch_request)(struct blk_mq_hw_ctx___104 *);
	bool (*has_work)(struct blk_mq_hw_ctx___104 *);
	void (*completed_request)(struct request___107 *, u64);
	void (*requeue_request)(struct request___107 *);
	struct request___107 * (*former_request)(struct request_queue___107 *, struct request___107 *);
	struct request___107 * (*next_request)(struct request_queue___107 *, struct request___107 *);
	void (*init_icq)(struct io_cq___107 *);
	void (*exit_icq)(struct io_cq___107 *);
};

struct elv_fs_entry___107;

struct elevator_type___107 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___107 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___107 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___194 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___107 {
	struct elevator_type___107 *type;
	void *elevator_data;
	struct kobject___198 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___107 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___107 *, char *);
	ssize_t (*store)(struct elevator_queue___107 *, const char *, size_t);
};

struct blk_mq_queue_data___104;

struct blk_mq_ops___104 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___104 *, const struct blk_mq_queue_data___104 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___104 *);
	int (*get_budget)(struct request_queue___107 *);
	void (*put_budget)(struct request_queue___107 *, int);
	void (*set_rq_budget_token)(struct request___107 *, int);
	int (*get_rq_budget_token)(struct request___107 *);
	enum blk_eh_timer_return (*timeout)(struct request___107 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___104 *);
	void (*complete)(struct request___107 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___104 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___104 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___104 *, struct request___107 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___104 *, struct request___107 *, unsigned int);
	void (*initialize_rq_fn)(struct request___107 *);
	void (*cleanup_rq)(struct request___107 *);
	bool (*busy)(struct request_queue___107 *);
	int (*map_queues)(struct blk_mq_tag_set___104 *);
	void (*show_rq)(struct seq_file___185 *, struct request___107 *);
};

struct blk_mq_tag_set___104 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___104 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___104 {
	struct request___107 *rq;
	bool last;
};

struct blkcg_policy_data___102;

struct blkcg___102 {
	struct cgroup_subsys_state___145 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___102 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___102 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___102 {
	struct blkcg___102 *blkcg;
	int plid;
};

struct blkg_policy_data___102 {
	struct blkcg_gq___102 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___91 {
	struct mem_cgroup___91 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___91 {
	struct lruvec___98 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___91 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___91 *memcg;
};

struct obj_cgroup___91 {
	struct percpu_ref refcnt;
	struct mem_cgroup___91 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct property___57 {
	char *name;
	int length;
	void *value;
	struct property___57 *next;
	long unsigned int _flags;
	struct bin_attribute___198 attr;
};

struct dev_pm_qos_request___21 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___187 *dev;
};

struct perf_cpu_context___78;

struct perf_output_handle___78;

struct pmu___78 {
	struct list_head entry;
	struct module___194 *module;
	struct device___187 *dev;
	const struct attribute_group___198 **attr_groups;
	const struct attribute_group___198 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___78 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___78 *);
	void (*pmu_disable)(struct pmu___78 *);
	int (*event_init)(struct perf_event___78 *);
	void (*event_mapped)(struct perf_event___78 *, struct mm_struct___216 *);
	void (*event_unmapped)(struct perf_event___78 *, struct mm_struct___216 *);
	int (*add)(struct perf_event___78 *, int);
	void (*del)(struct perf_event___78 *, int);
	void (*start)(struct perf_event___78 *, int);
	void (*stop)(struct perf_event___78 *, int);
	void (*read)(struct perf_event___78 *);
	void (*start_txn)(struct pmu___78 *, unsigned int);
	int (*commit_txn)(struct pmu___78 *);
	void (*cancel_txn)(struct pmu___78 *);
	int (*event_idx)(struct perf_event___78 *);
	void (*sched_task)(struct perf_event_context___78 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___78 *, struct perf_event_context___78 *);
	void * (*setup_aux)(struct perf_event___78 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___78 *, struct perf_output_handle___78 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___78 *);
	int (*aux_output_match)(struct perf_event___78 *);
	int (*filter_match)(struct perf_event___78 *);
	int (*check_period)(struct perf_event___78 *, u64);
};

struct perf_cpu_context___78 {
	struct perf_event_context___78 ctx;
	struct perf_event_context___78 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___78 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___78 **heap;
	struct perf_event___78 *heap_default[2];
};

struct perf_output_handle___78 {
	struct perf_event___78 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___78 {
	struct cgroup_subsys_state___145 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___72 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___72 *);
	};
};

struct trace_event_class___72 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___72 *, enum trace_reg, void *);
	struct trace_event_fields___72 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___72 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___72 *);
};

typedef int (*pm_callback_t___2)(struct device___187 *);

struct dentry___211;

struct super_block___211;

struct module___195;

struct file_system_type___211 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___211 * (*mount)(struct file_system_type___211 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___211 *);
	struct module___195 *owner;
	struct file_system_type___211 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___211;

struct kiocb___211;

struct iov_iter___131;

struct vm_area_struct___216;

struct inode___211;

struct file_lock___211;

struct page___216;

struct seq_file___186;

struct file_operations___212 {
	struct module___195 *owner;
	loff_t (*llseek)(struct file___211 *, loff_t, int);
	ssize_t (*read)(struct file___211 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___211 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___211 *, struct iov_iter___131 *);
	ssize_t (*write_iter)(struct kiocb___211 *, struct iov_iter___131 *);
	int (*iopoll)(struct kiocb___211 *, bool);
	int (*iterate)(struct file___211 *, struct dir_context *);
	int (*iterate_shared)(struct file___211 *, struct dir_context *);
	__poll_t (*poll)(struct file___211 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___211 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___211 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___211 *, struct vm_area_struct___216 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___211 *, struct file___211 *);
	int (*flush)(struct file___211 *, fl_owner_t);
	int (*release)(struct inode___211 *, struct file___211 *);
	int (*fsync)(struct file___211 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___211 *, int);
	int (*lock)(struct file___211 *, int, struct file_lock___211 *);
	ssize_t (*sendpage)(struct file___211 *, struct page___216 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___211 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___211 *, long unsigned int);
	int (*flock)(struct file___211 *, int, struct file_lock___211 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___211 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___211 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___211 *, long int, struct file_lock___211 **, void **);
	long int (*fallocate)(struct file___211 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___186 *, struct file___211 *);
	ssize_t (*copy_file_range)(struct file___211 *, loff_t, struct file___211 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___211 *, loff_t, struct file___211 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___211 *, loff_t, loff_t, int);
};

struct vmacache___216 {
	u64 seqnum;
	struct vm_area_struct___216 *vmas[4];
};

struct page_frag___216 {
	struct page___216 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___217;

struct pid___188;

struct nsproxy___197;

struct signal_struct___212;

struct bio_list___108;

struct backing_dev_info___101;

struct io_context___108;

struct css_set___146;

struct mem_cgroup___92;

struct request_queue___108;

struct vm_struct___194;

struct task_struct___218 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___218 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___217 *mm;
	struct mm_struct___217 *active_mm;
	struct vmacache___216 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___218 *real_parent;
	struct task_struct___218 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___218 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___188 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___12 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___197 *nsproxy;
	struct signal_struct___212 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___218 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___108 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___101 *backing_dev_info;
	struct io_context___108 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___146 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___216 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___92 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___92 *active_memcg;
	struct request_queue___108 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___218 *oom_reaper_list;
	struct vm_struct___194 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___199;

struct kobj_type___199;

struct kernfs_node___199;

struct kobject___199 {
	const char *name;
	struct list_head entry;
	struct kobject___199 *parent;
	struct kset___199 *kset;
	struct kobj_type___199 *ktype;
	struct kernfs_node___199 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___196 {
	struct kobject___199 kobj;
	struct module___195 *mod;
	struct kobject___199 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___195 {
	struct module___195 *mod;
	struct latch_tree_node node;
};

struct module_layout___195 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___195 mtn;
};

struct module_attribute___195;

struct kernel_param___195;

struct module___195 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___196 mkobj;
	struct module_attribute___195 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___199 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___195 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___195 core_layout;
	struct module_layout___195 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___188;

struct upid___188 {
	int nr;
	struct pid_namespace___188 *ns;
};

struct pid_namespace___188 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___218 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___188 *parent;
	struct fs_pin *bacct;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___188 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___188 numbers[1];
};

typedef struct page___216 *pgtable_t___216;

struct address_space___211;

struct dev_pagemap___206;

struct page___216 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___211 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___56 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___216 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___216 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___217 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___206 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___206;

struct vm_area_struct___216 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___216 *vm_next;
	struct vm_area_struct___216 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___217 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___206 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___211 *vm_file;
	struct file___211 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___212 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___218 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___218 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___188 *pids[4];
	struct pid___188 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___217 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___216;

struct mm_struct___217 {
	struct {
		struct vm_area_struct___216 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___211 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___216 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___218 *owner;
		struct user_namespace___25 *user_ns;
		struct file___211 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___146;

struct nsproxy___197 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___188 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___146 *cgroup_ns;
};

struct bio___108;

struct bio_list___108 {
	struct bio___108 *head;
	struct bio___108 *tail;
};

struct cgroup_subsys_state___146;

struct bdi_writeback___101 {
	struct backing_dev_info___101 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___146 *memcg_css;
	struct cgroup_subsys_state___146 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___188;

struct backing_dev_info___101 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___101 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___188 *dev;
	char dev_name[64];
	struct device___188 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___211 *debug_dir;
};

struct io_cq___108;

struct io_context___108 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___108 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___146;

struct css_set___146 {
	struct cgroup_subsys_state___146 *subsys[14];
	refcount_t refcount;
	struct css_set___146 *dom_cset;
	struct cgroup___146 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___146 *mg_src_cgrp;
	struct cgroup___146 *mg_dst_cgrp;
	struct css_set___146 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___146;

struct cgroup_subsys_state___146 {
	struct cgroup___146 *cgroup;
	struct cgroup_subsys___146 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___146 *parent;
};

struct cgroup_file___146 {
	struct kernfs_node___199 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___92;

struct mem_cgroup_per_node___92;

struct mem_cgroup___92 {
	struct cgroup_subsys_state___146 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___146 events_file;
	struct cgroup_file___146 events_local_file;
	struct cgroup_file___146 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___92 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___218 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___92 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___108;

struct blk_integrity___108 {
	const struct blk_integrity_profile___108 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___108 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___108 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___108;

struct elevator_queue___108;

struct blk_mq_ops___105;

struct blk_mq_hw_ctx___105;

struct gendisk___111;

struct blkcg_gq___103;

struct blk_mq_tag_set___105;

struct request_queue___108 {
	struct request___108 *last_merge;
	struct elevator_queue___108 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___105 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___105 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___111 *disk;
	struct kobject___199 kobj;
	struct kobject___199 *mq_kobj;
	struct blk_integrity___108 integrity;
	struct device___188 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___103 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___105 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___108 bio_split;
	struct dentry___211 *debugfs_dir;
	struct dentry___211 *sched_debugfs_dir;
	struct dentry___211 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___194 {
	struct vm_struct___194 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___216 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___211;

struct address_space___211 {
	struct inode___211 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___211 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___206;

struct dev_pagemap___206 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___206 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___211;

struct path___211 {
	struct vfsmount___211 *mnt;
	struct dentry___211 *dentry;
};

struct fown_struct___188 {
	rwlock_t lock;
	struct pid___188 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___211 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___211 f_path;
	struct inode___211 *f_inode;
	const struct file_operations___212 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___188 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___211 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___206;

struct vm_operations_struct___206 {
	void (*open)(struct vm_area_struct___216 *);
	void (*close)(struct vm_area_struct___216 *);
	int (*may_split)(struct vm_area_struct___216 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___216 *);
	int (*mprotect)(struct vm_area_struct___216 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___206 *);
	vm_fault_t (*huge_fault)(struct vm_fault___206 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___206 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___216 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___206 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___206 *);
	int (*access)(struct vm_area_struct___216 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___216 *);
	int (*set_policy)(struct vm_area_struct___216 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___216 *, long unsigned int);
	struct page___216 * (*find_special_page)(struct vm_area_struct___216 *, long unsigned int);
};

struct core_thread___216 {
	struct task_struct___218 *task;
	struct core_thread___216 *next;
};

struct core_state___216 {
	atomic_t nr_threads;
	struct core_thread___216 dumper;
	struct completion startup;
};

struct vm_fault___206 {
	const struct {
		struct vm_area_struct___216 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___216 *cow_page;
	struct page___216 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___216 prealloc_pte;
};

struct fwnode_operations___184;

struct fwnode_handle___184 {
	struct fwnode_handle___184 *secondary;
	const struct fwnode_operations___184 *ops;
	struct device___188 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___184;

struct fwnode_endpoint___184;

struct fwnode_operations___184 {
	struct fwnode_handle___184 * (*get)(struct fwnode_handle___184 *);
	void (*put)(struct fwnode_handle___184 *);
	bool (*device_is_available)(const struct fwnode_handle___184 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___184 *, const struct device___188 *);
	bool (*property_present)(const struct fwnode_handle___184 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___184 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___184 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___184 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*get_parent)(const struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*get_next_child_node)(const struct fwnode_handle___184 *, struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*get_named_child_node)(const struct fwnode_handle___184 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___184 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___184 *);
	struct fwnode_handle___184 * (*graph_get_next_endpoint)(const struct fwnode_handle___184 *, struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*graph_get_remote_endpoint)(const struct fwnode_handle___184 *);
	struct fwnode_handle___184 * (*graph_get_port_parent)(struct fwnode_handle___184 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___184 *, struct fwnode_endpoint___184 *);
	int (*add_links)(struct fwnode_handle___184 *);
};

struct wakeup_source___188;

struct wake_irq___11;

struct pm_subsys_data___9;

struct dev_pm_qos___22;

struct dev_pm_info___188 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___188 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq___11 *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___9 *subsys_data;
	void (*set_latency_tolerance)(struct device___188 *, s32);
	struct dev_pm_qos___22 *qos;
};

struct device_type___188;

struct bus_type___188;

struct device_driver___188;

struct dev_pm_domain___188;

struct device_node___80;

struct class___188;

struct attribute_group___199;

struct device___188 {
	struct kobject___199 kobj;
	struct device___188 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___188 *type;
	struct bus_type___188 *bus;
	struct device_driver___188 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___188 power;
	struct dev_pm_domain___188 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___80 *of_node;
	struct fwnode_handle___184 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___188 *class;
	const struct attribute_group___199 **groups;
	void (*release)(struct device___188 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___184 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___184 *local_fwnode;
};

struct fwnode_reference_args___184 {
	struct fwnode_handle___184 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct pglist_data___99;

struct lruvec___99 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___99 *pgdat;
};

struct zone___99 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___99 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___99 {
	struct zone___99 *zone;
	int zone_idx;
};

struct zonelist___99 {
	struct zoneref___99 _zonerefs[321];
};

struct pglist_data___99 {
	struct zone___99 node_zones[5];
	struct zonelist___99 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___218 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___218 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___99 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___199;

struct kernfs_elem_dir___199 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___199 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___199;

struct kernfs_root___199 {
	struct kernfs_node___199 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___199 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___199 {
	struct kernfs_node___199 *target_kn;
};

struct kernfs_ops___199;

struct kernfs_elem_attr___199 {
	const struct kernfs_ops___199 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___199 *notify_next;
};

struct kernfs_node___199 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___199 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___199 dir;
		struct kernfs_elem_symlink___199 symlink;
		struct kernfs_elem_attr___199 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___199;

struct kernfs_ops___199 {
	int (*open)(struct kernfs_open_file___199 *);
	void (*release)(struct kernfs_open_file___199 *);
	int (*seq_show)(struct seq_file___186 *, void *);
	void * (*seq_start)(struct seq_file___186 *, loff_t *);
	void * (*seq_next)(struct seq_file___186 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___186 *, void *);
	ssize_t (*read)(struct kernfs_open_file___199 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___199 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___199 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___199 *, struct vm_area_struct___216 *);
};

struct kernfs_syscall_ops___199 {
	int (*show_options)(struct seq_file___186 *, struct kernfs_root___199 *);
	int (*mkdir)(struct kernfs_node___199 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___199 *);
	int (*rename)(struct kernfs_node___199 *, struct kernfs_node___199 *, const char *);
	int (*show_path)(struct seq_file___186 *, struct kernfs_node___199 *, struct kernfs_root___199 *);
};

struct seq_operations___186;

struct seq_file___186 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___186 *op;
	int poll_event;
	const struct file___211 *file;
	void *private;
};

struct kernfs_open_file___199 {
	struct kernfs_node___199 *kn;
	struct file___211 *file;
	struct seq_file___186 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___206 *vm_ops;
};

struct bin_attribute___199;

struct attribute_group___199 {
	const char *name;
	umode_t (*is_visible)(struct kobject___199 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___199 *, struct bin_attribute___199 *, int);
	struct attribute **attrs;
	struct bin_attribute___199 **bin_attrs;
};

struct bin_attribute___199 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___211 * (*f_mapping)();
	ssize_t (*read)(struct file___211 *, struct kobject___199 *, struct bin_attribute___199 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___211 *, struct kobject___199 *, struct bin_attribute___199 *, char *, loff_t, size_t);
	int (*mmap)(struct file___211 *, struct kobject___199 *, struct bin_attribute___199 *, struct vm_area_struct___216 *);
};

struct sysfs_ops___199 {
	ssize_t (*show)(struct kobject___199 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___199 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___199;

struct kset___199 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___199 kobj;
	const struct kset_uevent_ops___199 *uevent_ops;
};

struct kobj_type___199 {
	void (*release)(struct kobject___199 *);
	const struct sysfs_ops___199 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___199 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___199 *);
	const void * (*namespace)(struct kobject___199 *);
	void (*get_ownership)(struct kobject___199 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___199 {
	int (* const filter)(struct kset___199 *, struct kobject___199 *);
	const char * (* const name)(struct kset___199 *, struct kobject___199 *);
	int (* const uevent)(struct kset___199 *, struct kobject___199 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___188 {
	int (*prepare)(struct device___188 *);
	void (*complete)(struct device___188 *);
	int (*suspend)(struct device___188 *);
	int (*resume)(struct device___188 *);
	int (*freeze)(struct device___188 *);
	int (*thaw)(struct device___188 *);
	int (*poweroff)(struct device___188 *);
	int (*restore)(struct device___188 *);
	int (*suspend_late)(struct device___188 *);
	int (*resume_early)(struct device___188 *);
	int (*freeze_late)(struct device___188 *);
	int (*thaw_early)(struct device___188 *);
	int (*poweroff_late)(struct device___188 *);
	int (*restore_early)(struct device___188 *);
	int (*suspend_noirq)(struct device___188 *);
	int (*resume_noirq)(struct device___188 *);
	int (*freeze_noirq)(struct device___188 *);
	int (*thaw_noirq)(struct device___188 *);
	int (*poweroff_noirq)(struct device___188 *);
	int (*restore_noirq)(struct device___188 *);
	int (*runtime_suspend)(struct device___188 *);
	int (*runtime_resume)(struct device___188 *);
	int (*runtime_idle)(struct device___188 *);
};

struct pm_domain_data___9;

struct pm_subsys_data___9 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___9 *domain_data;
};

struct pm_domain_data___9 {
	struct list_head list_node;
	struct device___188 *dev;
};

struct wakeup_source___188 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq___11 *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___188 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wake_irq___11 {
	struct device___188 *dev;
	unsigned int status;
	int irq;
	const char *name;
};

struct dev_pm_qos_request___22;

struct dev_pm_qos___22 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___22 *resume_latency_req;
	struct dev_pm_qos_request___22 *latency_tolerance_req;
	struct dev_pm_qos_request___22 *flags_req;
};

struct dev_pm_domain___188 {
	struct dev_pm_ops___188 ops;
	int (*start)(struct device___188 *);
	void (*detach)(struct device___188 *, bool);
	int (*activate)(struct device___188 *);
	void (*sync)(struct device___188 *);
	void (*dismiss)(struct device___188 *);
};

struct bus_type___188 {
	const char *name;
	const char *dev_name;
	struct device___188 *dev_root;
	const struct attribute_group___199 **bus_groups;
	const struct attribute_group___199 **dev_groups;
	const struct attribute_group___199 **drv_groups;
	int (*match)(struct device___188 *, struct device_driver___188 *);
	int (*uevent)(struct device___188 *, struct kobj_uevent_env *);
	int (*probe)(struct device___188 *);
	void (*sync_state)(struct device___188 *);
	void (*remove)(struct device___188 *);
	void (*shutdown)(struct device___188 *);
	int (*online)(struct device___188 *);
	int (*offline)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	int (*num_vf)(struct device___188 *);
	int (*dma_configure)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___188 {
	const char *name;
	struct bus_type___188 *bus;
	struct module___195 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___188 *);
	void (*sync_state)(struct device___188 *);
	int (*remove)(struct device___188 *);
	void (*shutdown)(struct device___188 *);
	int (*suspend)(struct device___188 *, pm_message_t);
	int (*resume)(struct device___188 *);
	const struct attribute_group___199 **groups;
	const struct attribute_group___199 **dev_groups;
	const struct dev_pm_ops___188 *pm;
	void (*coredump)(struct device___188 *);
	struct driver_private *p;
};

struct device_type___188 {
	const char *name;
	const struct attribute_group___199 **groups;
	int (*uevent)(struct device___188 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___188 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___188 *);
	const struct dev_pm_ops___188 *pm;
};

struct class___188 {
	const char *name;
	struct module___195 *owner;
	const struct attribute_group___199 **class_groups;
	const struct attribute_group___199 **dev_groups;
	struct kobject___199 *dev_kobj;
	int (*dev_uevent)(struct device___188 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___188 *, umode_t *);
	void (*class_release)(struct class___188 *);
	void (*dev_release)(struct device___188 *);
	int (*shutdown_pre)(struct device___188 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___188 *);
	void (*get_ownership)(struct device___188 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___188 *pm;
	struct subsys_private *p;
};

struct property___58;

struct device_node___80 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___184 fwnode;
	struct property___58 *properties;
	struct property___58 *deadprops;
	struct device_node___80 *parent;
	struct device_node___80 *child;
	struct device_node___80 *sibling;
	struct kobject___199 kobj;
	long unsigned int _flags;
	void *data;
};

struct property___58 {
	char *name;
	int length;
	void *value;
	struct property___58 *next;
	long unsigned int _flags;
	struct bin_attribute___199 attr;
};

struct of_phandle_args___36 {
	struct device_node___80 *np;
	int args_count;
	uint32_t args[16];
};

struct of_phandle_iterator___2 {
	const char *cells_name;
	int cell_count;
	const struct device_node___80 *parent;
	const __be32 *list_end;
	const __be32 *phandle_end;
	const __be32 *cur;
	uint32_t cur_count;
	phandle phandle;
	struct device_node___80 *node;
};

enum genpd_notication {
	GENPD_NOTIFY_PRE_OFF = 0,
	GENPD_NOTIFY_OFF = 1,
	GENPD_NOTIFY_PRE_ON = 2,
	GENPD_NOTIFY_ON = 3,
};

struct dev_power_governor___5 {
	bool (*power_down_ok)(struct dev_pm_domain___188 *);
	bool (*suspend_ok)(struct device___188 *);
};

struct gpd_dev_ops___5 {
	int (*start)(struct device___188 *);
	int (*stop)(struct device___188 *);
};

struct genpd_power_state___5 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___184 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct generic_pm_domain___2 {
	struct device___188 dev;
	struct dev_pm_domain___188 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor___5 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___184 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain___2 *);
	int (*power_on)(struct generic_pm_domain___2 *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___2 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___2 *, unsigned int);
	struct gpd_dev_ops___5 dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain___2 *, struct device___188 *);
	void (*detach_dev)(struct generic_pm_domain___2 *, struct device___188 *);
	unsigned int flags;
	struct genpd_power_state___5 *states;
	void (*free_states)(struct genpd_power_state___5 *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

struct gpd_link {
	struct generic_pm_domain___2 *parent;
	struct list_head parent_node;
	struct generic_pm_domain___2 *child;
	struct list_head child_node;
	unsigned int performance_state;
	unsigned int prev_performance_state;
};

struct gpd_timing_data {
	s64 suspend_latency_ns;
	s64 resume_latency_ns;
	s64 effective_constraint_ns;
	bool constraint_changed;
	bool cached_suspend_ok;
};

struct generic_pm_domain_data {
	struct pm_domain_data___9 base;
	struct gpd_timing_data td;
	struct notifier_block nb;
	struct notifier_block *power_nb;
	int cpu;
	unsigned int performance_state;
	unsigned int default_pstate;
	unsigned int rpm_pstate;
	ktime_t next_wakeup;
	void *data;
};

typedef struct generic_pm_domain___2 * (*genpd_xlate_t___5)(struct of_phandle_args___36 *, void *);

struct genpd_onecell_data___5 {
	struct generic_pm_domain___2 **domains;
	unsigned int num_domains;
	genpd_xlate_t___5 xlate;
};

struct dev_pm_qos_request___22 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___188 *dev;
};

struct dentry_operations___211;

struct dentry___211 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___211 *d_parent;
	struct qstr d_name;
	struct inode___211 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___211 *d_op;
	struct super_block___211 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___211;

struct inode___211 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___211 *i_op;
	struct super_block___211 *i_sb;
	struct address_space___211 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___101 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___212 *i_fop;
		void (*free_inode)(struct inode___211 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___211 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___68 *i_pipe;
		struct cdev___52 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___211 {
	int (*d_revalidate)(struct dentry___211 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___211 *, unsigned int);
	int (*d_hash)(const struct dentry___211 *, struct qstr *);
	int (*d_compare)(const struct dentry___211 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___211 *);
	int (*d_init)(struct dentry___211 *);
	void (*d_release)(struct dentry___211 *);
	void (*d_prune)(struct dentry___211 *);
	void (*d_iput)(struct dentry___211 *, struct inode___211 *);
	char * (*d_dname)(struct dentry___211 *, char *, int);
	struct vfsmount___211 * (*d_automount)(struct path___211 *);
	int (*d_manage)(const struct path___211 *, bool);
	struct dentry___211 * (*d_real)(struct dentry___211 *, const struct inode___211 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___211;

struct mem_dqinfo___211 {
	struct quota_format_type___211 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___211;

struct quota_info___211 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___211 *files[3];
	struct mem_dqinfo___211 info[3];
	const struct quota_format_ops___211 *ops[3];
};

struct rcuwait___212 {
	struct task_struct___218 *task;
};

struct percpu_rw_semaphore___212 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___212 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___211 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___212 rw_sem[3];
};

struct shrink_control___92;

struct shrinker___92 {
	long unsigned int (*count_objects)(struct shrinker___92 *, struct shrink_control___92 *);
	long unsigned int (*scan_objects)(struct shrinker___92 *, struct shrink_control___92 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___211;

struct dquot_operations___211;

struct quotactl_ops___211;

struct block_device___111;

struct super_block___211 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___211 *s_type;
	const struct super_operations___211 *s_op;
	const struct dquot_operations___211 *dq_op;
	const struct quotactl_ops___211 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___211 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___12 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___111 *s_bdev;
	struct backing_dev_info___101 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___211 s_dquot;
	struct sb_writers___211 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___211 *s_d_op;
	int cleancache_poolid;
	struct shrinker___92 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___25 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___211 {
	struct dentry___211 *mnt_root;
	struct super_block___211 *mnt_sb;
	int mnt_flags;
	struct user_namespace___25 *mnt_userns;
};

struct shrink_control___92 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___92 *memcg;
};

struct psi_group___146 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___218 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___146;

struct cgroup_rstat_cpu___146;

struct cgroup___146 {
	struct cgroup_subsys_state___146 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___199 *kn;
	struct cgroup_file___146 procs_file;
	struct cgroup_file___146 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___146 *subsys[14];
	struct cgroup_root___146 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___146 *dom_cgrp;
	struct cgroup___146 *old_dom_cgrp;
	struct cgroup_rstat_cpu___146 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___146 psi;
	struct cgroup_bpf___36 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___108 {
	struct request_queue___108 *q;
	struct io_context___108 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___102;

struct kiocb___211 {
	struct file___211 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___211 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___102 *ki_waitq;
	};
};

struct iattr___211 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___211 *ia_file;
};

struct dquot___211 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___211 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___211 {
	int qf_fmt_id;
	const struct quota_format_ops___211 *qf_ops;
	struct module___195 *qf_owner;
	struct quota_format_type___211 *qf_next;
};

struct quota_format_ops___211 {
	int (*check_quota_file)(struct super_block___211 *, int);
	int (*read_file_info)(struct super_block___211 *, int);
	int (*write_file_info)(struct super_block___211 *, int);
	int (*free_file_info)(struct super_block___211 *, int);
	int (*read_dqblk)(struct dquot___211 *);
	int (*commit_dqblk)(struct dquot___211 *);
	int (*release_dqblk)(struct dquot___211 *);
	int (*get_next_id)(struct super_block___211 *, struct kqid *);
};

struct dquot_operations___211 {
	int (*write_dquot)(struct dquot___211 *);
	struct dquot___211 * (*alloc_dquot)(struct super_block___211 *, int);
	void (*destroy_dquot)(struct dquot___211 *);
	int (*acquire_dquot)(struct dquot___211 *);
	int (*release_dquot)(struct dquot___211 *);
	int (*mark_dirty)(struct dquot___211 *);
	int (*write_info)(struct super_block___211 *, int);
	qsize_t * (*get_reserved_space)(struct inode___211 *);
	int (*get_projid)(struct inode___211 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___211 *, qsize_t *);
	int (*get_next_id)(struct super_block___211 *, struct kqid *);
};

struct quotactl_ops___211 {
	int (*quota_on)(struct super_block___211 *, int, int, const struct path___211 *);
	int (*quota_off)(struct super_block___211 *, int);
	int (*quota_enable)(struct super_block___211 *, unsigned int);
	int (*quota_disable)(struct super_block___211 *, unsigned int);
	int (*quota_sync)(struct super_block___211 *, int);
	int (*set_info)(struct super_block___211 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___211 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___211 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___211 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___211 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___211 *, unsigned int);
};

struct wait_page_queue___102 {
	struct page___216 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___101;

struct readahead_control___102;

struct swap_info_struct___60;

struct address_space_operations___211 {
	int (*writepage)(struct page___216 *, struct writeback_control___101 *);
	int (*readpage)(struct file___211 *, struct page___216 *);
	int (*writepages)(struct address_space___211 *, struct writeback_control___101 *);
	int (*set_page_dirty)(struct page___216 *);
	int (*readpages)(struct file___211 *, struct address_space___211 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___102 *);
	int (*write_begin)(struct file___211 *, struct address_space___211 *, loff_t, unsigned int, unsigned int, struct page___216 **, void **);
	int (*write_end)(struct file___211 *, struct address_space___211 *, loff_t, unsigned int, unsigned int, struct page___216 *, void *);
	sector_t (*bmap)(struct address_space___211 *, sector_t);
	void (*invalidatepage)(struct page___216 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___216 *, gfp_t);
	void (*freepage)(struct page___216 *);
	ssize_t (*direct_IO)(struct kiocb___211 *, struct iov_iter___131 *);
	int (*migratepage)(struct address_space___211 *, struct page___216 *, struct page___216 *, enum migrate_mode);
	bool (*isolate_page)(struct page___216 *, isolate_mode_t);
	void (*putback_page)(struct page___216 *);
	int (*launder_page)(struct page___216 *);
	int (*is_partially_uptodate)(struct page___216 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___216 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___211 *, struct page___216 *);
	int (*swap_activate)(struct swap_info_struct___60 *, struct file___211 *, sector_t *);
	void (*swap_deactivate)(struct file___211 *);
};

struct writeback_control___101 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___101 *wb;
	struct inode___211 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___102 {
	struct file___211 *file;
	struct address_space___211 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___128;

struct iov_iter___131 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___128 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___60 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___111 *bdev;
	struct file___211 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___211 {
	struct dentry___211 * (*lookup)(struct inode___211 *, struct dentry___211 *, unsigned int);
	const char * (*get_link)(struct dentry___211 *, struct inode___211 *, struct delayed_call *);
	int (*permission)(struct user_namespace___25 *, struct inode___211 *, int);
	struct posix_acl * (*get_acl)(struct inode___211 *, int, bool);
	int (*readlink)(struct dentry___211 *, char *, int);
	int (*create)(struct user_namespace___25 *, struct inode___211 *, struct dentry___211 *, umode_t, bool);
	int (*link)(struct dentry___211 *, struct inode___211 *, struct dentry___211 *);
	int (*unlink)(struct inode___211 *, struct dentry___211 *);
	int (*symlink)(struct user_namespace___25 *, struct inode___211 *, struct dentry___211 *, const char *);
	int (*mkdir)(struct user_namespace___25 *, struct inode___211 *, struct dentry___211 *, umode_t);
	int (*rmdir)(struct inode___211 *, struct dentry___211 *);
	int (*mknod)(struct user_namespace___25 *, struct inode___211 *, struct dentry___211 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___25 *, struct inode___211 *, struct dentry___211 *, struct inode___211 *, struct dentry___211 *, unsigned int);
	int (*setattr)(struct user_namespace___25 *, struct dentry___211 *, struct iattr___211 *);
	int (*getattr)(struct user_namespace___25 *, const struct path___211 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___211 *, char *, size_t);
	int (*fiemap)(struct inode___211 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___211 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___211 *, struct dentry___211 *, struct file___211 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___25 *, struct inode___211 *, struct dentry___211 *, umode_t);
	int (*set_acl)(struct user_namespace___25 *, struct inode___211 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___25 *, struct dentry___211 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___211 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___211 {
	void (*fl_copy_lock)(struct file_lock___211 *, struct file_lock___211 *);
	void (*fl_release_private)(struct file_lock___211 *);
};

struct fasync_struct___211;

struct lock_manager_operations___211;

struct file_lock___211 {
	struct file_lock___211 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___211 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___211 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___211 *fl_ops;
	const struct lock_manager_operations___211 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___211 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___211 *);
	int (*lm_grant)(struct file_lock___211 *, int);
	bool (*lm_break)(struct file_lock___211 *);
	int (*lm_change)(struct file_lock___211 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___211 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___211 *);
};

struct fasync_struct___211 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___211 *fa_next;
	struct file___211 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___211 {
	struct inode___211 * (*alloc_inode)(struct super_block___211 *);
	void (*destroy_inode)(struct inode___211 *);
	void (*free_inode)(struct inode___211 *);
	void (*dirty_inode)(struct inode___211 *, int);
	int (*write_inode)(struct inode___211 *, struct writeback_control___101 *);
	int (*drop_inode)(struct inode___211 *);
	void (*evict_inode)(struct inode___211 *);
	void (*put_super)(struct super_block___211 *);
	int (*sync_fs)(struct super_block___211 *, int);
	int (*freeze_super)(struct super_block___211 *);
	int (*freeze_fs)(struct super_block___211 *);
	int (*thaw_super)(struct super_block___211 *);
	int (*unfreeze_fs)(struct super_block___211 *);
	int (*statfs)(struct dentry___211 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___211 *, int *, char *);
	void (*umount_begin)(struct super_block___211 *);
	int (*show_options)(struct seq_file___186 *, struct dentry___211 *);
	int (*show_devname)(struct seq_file___186 *, struct dentry___211 *);
	int (*show_path)(struct seq_file___186 *, struct dentry___211 *);
	int (*show_stats)(struct seq_file___186 *, struct dentry___211 *);
	ssize_t (*quota_read)(struct super_block___211 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___211 *, int, const char *, size_t, loff_t);
	struct dquot___211 ** (*get_dquots)(struct inode___211 *);
	long int (*nr_cached_objects)(struct super_block___211 *, struct shrink_control___92 *);
	long int (*free_cached_objects)(struct super_block___211 *, struct shrink_control___92 *);
	struct file___211 * (*real_loop)(struct file___211 *);
};

struct block_device___111 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___211 *bd_inode;
	struct super_block___211 *bd_super;
	void *bd_claiming;
	struct device___188 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___199 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___111 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___211 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___108(struct bio___108 *);

struct bio_vec___128 {
	struct page___216 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___108;

struct bio___108 {
	struct bio___108 *bi_next;
	struct block_device___111 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___108 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___103 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___108 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___128 *bi_io_vec;
	struct bio_set___108 *bi_pool;
	struct bio_vec___128 bi_inline_vecs[0];
};

struct seq_operations___186 {
	void * (*start)(struct seq_file___186 *, loff_t *);
	void (*stop)(struct seq_file___186 *, void *);
	void * (*next)(struct seq_file___186 *, void *, loff_t *);
	int (*show)(struct seq_file___186 *, void *);
};

struct cgroup_namespace___146 {
	struct ns_common___26 ns;
	struct user_namespace___25 *user_ns;
	struct ucounts___25 *ucounts;
	struct css_set___146 *root_cset;
};

struct kernel_param_ops___195 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___195 *);
	int (*get)(char *, const struct kernel_param___195 *);
	void (*free)(void *);
};

struct kparam_array___195;

struct kernel_param___195 {
	const char *name;
	struct module___195 *mod;
	const struct kernel_param_ops___195 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___195 *arr;
	};
};

struct kparam_array___195 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___195 *ops;
	void *elem;
};

struct module_attribute___195 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___195 *, struct module_kobject___196 *, char *);
	ssize_t (*store)(struct module_attribute___195 *, struct module_kobject___196 *, const char *, size_t);
	void (*setup)(struct module___195 *, const char *);
	int (*test)(struct module___195 *);
	void (*free)(struct module___195 *);
};

struct dev_pagemap_ops___206 {
	void (*page_free)(struct page___216 *);
	void (*kill)(struct dev_pagemap___206 *);
	void (*cleanup)(struct dev_pagemap___206 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___206 *);
};

struct cftype___146;

struct cgroup_subsys___146 {
	struct cgroup_subsys_state___146 * (*css_alloc)(struct cgroup_subsys_state___146 *);
	int (*css_online)(struct cgroup_subsys_state___146 *);
	void (*css_offline)(struct cgroup_subsys_state___146 *);
	void (*css_released)(struct cgroup_subsys_state___146 *);
	void (*css_free)(struct cgroup_subsys_state___146 *);
	void (*css_reset)(struct cgroup_subsys_state___146 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___146 *, int);
	int (*css_extra_stat_show)(struct seq_file___186 *, struct cgroup_subsys_state___146 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___218 *, struct css_set___146 *);
	void (*cancel_fork)(struct task_struct___218 *, struct css_set___146 *);
	void (*fork)(struct task_struct___218 *);
	void (*exit)(struct task_struct___218 *);
	void (*release)(struct task_struct___218 *);
	void (*bind)(struct cgroup_subsys_state___146 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___146 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___146 *dfl_cftypes;
	struct cftype___146 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___146 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___146 *updated_children;
	struct cgroup___146 *updated_next;
};

struct cgroup_root___146 {
	struct kernfs_root___199 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___146 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___146 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___146 *ss;
	struct list_head node;
	struct kernfs_ops___199 *kf_ops;
	int (*open)(struct kernfs_open_file___199 *);
	void (*release)(struct kernfs_open_file___199 *);
	u64 (*read_u64)(struct cgroup_subsys_state___146 *, struct cftype___146 *);
	s64 (*read_s64)(struct cgroup_subsys_state___146 *, struct cftype___146 *);
	int (*seq_show)(struct seq_file___186 *, void *);
	void * (*seq_start)(struct seq_file___186 *, loff_t *);
	void * (*seq_next)(struct seq_file___186 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___186 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___146 *, struct cftype___146 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___146 *, struct cftype___146 *, s64);
	ssize_t (*write)(struct kernfs_open_file___199 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___199 *, struct poll_table_struct___5 *);
};

struct block_device_operations___108;

struct gendisk___111 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___111 *part0;
	const struct block_device_operations___108 *fops;
	struct request_queue___108 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___101 *bdi;
	struct kobject___199 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___199 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___108 {
	struct bio___108 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___128 *bip_vec;
	struct bio_vec___128 bip_inline_vecs[0];
};

struct blkcg___103;

struct blkg_policy_data___103;

struct blkcg_gq___103 {
	struct request_queue___108 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___103 *blkcg;
	struct blkcg_gq___103 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___103 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___108 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___108(struct request___108 *);

typedef void integrity_complete_fn___108(struct request___108 *, unsigned int);

struct blk_integrity_profile___108 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___108 *prepare_fn;
	integrity_complete_fn___108 *complete_fn;
	const char *name;
};

struct block_device_operations___108 {
	blk_qc_t (*submit_bio)(struct bio___108 *);
	int (*open)(struct block_device___111 *, fmode_t);
	void (*release)(struct gendisk___111 *, fmode_t);
	int (*rw_page)(struct block_device___111 *, sector_t, struct page___216 *, unsigned int);
	int (*ioctl)(struct block_device___111 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___111 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___111 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___111 *);
	int (*getgeo)(struct block_device___111 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___111 *, bool);
	void (*swap_slot_free_notify)(struct block_device___111 *, long unsigned int);
	int (*report_zones)(struct gendisk___111 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___111 *, umode_t *);
	struct module___195 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___111 *, sector_t *);
};

typedef void rq_end_io_fn___108(struct request___108 *, blk_status_t);

struct request___108 {
	struct request_queue___108 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___105 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___108 *bio;
	struct bio___108 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___128 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___108 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___108 *saved_end_io;
		} flush;
	};
	struct gendisk___111 *rq_disk;
	struct block_device___111 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___108 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___105 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___108 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___199 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___211 *debugfs_dir;
	struct dentry___211 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___108;

struct elevator_mq_ops___108 {
	int (*init_sched)(struct request_queue___108 *, struct elevator_type___108 *);
	void (*exit_sched)(struct elevator_queue___108 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___105 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___105 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___105 *);
	bool (*allow_merge)(struct request_queue___108 *, struct request___108 *, struct bio___108 *);
	bool (*bio_merge)(struct request_queue___108 *, struct bio___108 *, unsigned int);
	int (*request_merge)(struct request_queue___108 *, struct request___108 **, struct bio___108 *);
	void (*request_merged)(struct request_queue___108 *, struct request___108 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___108 *, struct request___108 *, struct request___108 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___108 *);
	void (*finish_request)(struct request___108 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___105 *, struct list_head *, bool);
	struct request___108 * (*dispatch_request)(struct blk_mq_hw_ctx___105 *);
	bool (*has_work)(struct blk_mq_hw_ctx___105 *);
	void (*completed_request)(struct request___108 *, u64);
	void (*requeue_request)(struct request___108 *);
	struct request___108 * (*former_request)(struct request_queue___108 *, struct request___108 *);
	struct request___108 * (*next_request)(struct request_queue___108 *, struct request___108 *);
	void (*init_icq)(struct io_cq___108 *);
	void (*exit_icq)(struct io_cq___108 *);
};

struct elv_fs_entry___108;

struct elevator_type___108 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___108 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___108 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___195 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___108 {
	struct elevator_type___108 *type;
	void *elevator_data;
	struct kobject___199 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___108 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___108 *, char *);
	ssize_t (*store)(struct elevator_queue___108 *, const char *, size_t);
};

struct blk_mq_queue_data___105;

struct blk_mq_ops___105 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___105 *, const struct blk_mq_queue_data___105 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___105 *);
	int (*get_budget)(struct request_queue___108 *);
	void (*put_budget)(struct request_queue___108 *, int);
	void (*set_rq_budget_token)(struct request___108 *, int);
	int (*get_rq_budget_token)(struct request___108 *);
	enum blk_eh_timer_return (*timeout)(struct request___108 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___105 *);
	void (*complete)(struct request___108 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___105 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___105 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___105 *, struct request___108 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___105 *, struct request___108 *, unsigned int);
	void (*initialize_rq_fn)(struct request___108 *);
	void (*cleanup_rq)(struct request___108 *);
	bool (*busy)(struct request_queue___108 *);
	int (*map_queues)(struct blk_mq_tag_set___105 *);
	void (*show_rq)(struct seq_file___186 *, struct request___108 *);
};

struct blk_mq_tag_set___105 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___105 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___105 {
	struct request___108 *rq;
	bool last;
};

struct blkcg_policy_data___103;

struct blkcg___103 {
	struct cgroup_subsys_state___146 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___103 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___103 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___103 {
	struct blkcg___103 *blkcg;
	int plid;
};

struct blkg_policy_data___103 {
	struct blkcg_gq___103 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___92 {
	struct mem_cgroup___92 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___92 {
	struct lruvec___99 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___92 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___92 *memcg;
};

struct obj_cgroup___92 {
	struct percpu_ref refcnt;
	struct mem_cgroup___92 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct of_genpd_provider {
	struct list_head link;
	struct device_node___80 *node;
	genpd_xlate_t___5 xlate;
	void *data;
};

struct wakeup_source___189;

struct pm_subsys_data___10;

struct device___189;

struct dev_pm_qos___23;

struct dev_pm_info___189 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___189 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___10 *subsys_data;
	void (*set_latency_tolerance)(struct device___189 *, s32);
	struct dev_pm_qos___23 *qos;
};

struct device_type___189;

struct bus_type___189;

struct device_driver___189;

struct dev_pm_domain___189;

struct device_node___81;

struct fwnode_handle___185;

struct class___189;

struct device___189 {
	struct kobject___42 kobj;
	struct device___189 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___189 *type;
	struct bus_type___189 *bus;
	struct device_driver___189 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___189 power;
	struct dev_pm_domain___189 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___81 *of_node;
	struct fwnode_handle___185 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___189 *class;
	const struct attribute_group___42 **groups;
	void (*release)(struct device___189 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___189 {
	int (*prepare)(struct device___189 *);
	void (*complete)(struct device___189 *);
	int (*suspend)(struct device___189 *);
	int (*resume)(struct device___189 *);
	int (*freeze)(struct device___189 *);
	int (*thaw)(struct device___189 *);
	int (*poweroff)(struct device___189 *);
	int (*restore)(struct device___189 *);
	int (*suspend_late)(struct device___189 *);
	int (*resume_early)(struct device___189 *);
	int (*freeze_late)(struct device___189 *);
	int (*thaw_early)(struct device___189 *);
	int (*poweroff_late)(struct device___189 *);
	int (*restore_early)(struct device___189 *);
	int (*suspend_noirq)(struct device___189 *);
	int (*resume_noirq)(struct device___189 *);
	int (*freeze_noirq)(struct device___189 *);
	int (*thaw_noirq)(struct device___189 *);
	int (*poweroff_noirq)(struct device___189 *);
	int (*restore_noirq)(struct device___189 *);
	int (*runtime_suspend)(struct device___189 *);
	int (*runtime_resume)(struct device___189 *);
	int (*runtime_idle)(struct device___189 *);
};

struct pm_domain_data___10;

struct pm_subsys_data___10 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___10 *domain_data;
};

struct pm_domain_data___10 {
	struct list_head list_node;
	struct device___189 *dev;
};

struct wakeup_source___189 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___189 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___23;

struct dev_pm_qos___23 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___23 *resume_latency_req;
	struct dev_pm_qos_request___23 *latency_tolerance_req;
	struct dev_pm_qos_request___23 *flags_req;
};

struct dev_pm_domain___189 {
	struct dev_pm_ops___189 ops;
	int (*start)(struct device___189 *);
	void (*detach)(struct device___189 *, bool);
	int (*activate)(struct device___189 *);
	void (*sync)(struct device___189 *);
	void (*dismiss)(struct device___189 *);
};

struct bus_type___189 {
	const char *name;
	const char *dev_name;
	struct device___189 *dev_root;
	const struct attribute_group___42 **bus_groups;
	const struct attribute_group___42 **dev_groups;
	const struct attribute_group___42 **drv_groups;
	int (*match)(struct device___189 *, struct device_driver___189 *);
	int (*uevent)(struct device___189 *, struct kobj_uevent_env *);
	int (*probe)(struct device___189 *);
	void (*sync_state)(struct device___189 *);
	void (*remove)(struct device___189 *);
	void (*shutdown)(struct device___189 *);
	int (*online)(struct device___189 *);
	int (*offline)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	int (*num_vf)(struct device___189 *);
	int (*dma_configure)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___189 {
	const char *name;
	struct bus_type___189 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___189 *);
	void (*sync_state)(struct device___189 *);
	int (*remove)(struct device___189 *);
	void (*shutdown)(struct device___189 *);
	int (*suspend)(struct device___189 *, pm_message_t);
	int (*resume)(struct device___189 *);
	const struct attribute_group___42 **groups;
	const struct attribute_group___42 **dev_groups;
	const struct dev_pm_ops___189 *pm;
	void (*coredump)(struct device___189 *);
	struct driver_private *p;
};

struct device_type___189 {
	const char *name;
	const struct attribute_group___42 **groups;
	int (*uevent)(struct device___189 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___189 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___189 *);
	const struct dev_pm_ops___189 *pm;
};

struct class___189 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___42 **class_groups;
	const struct attribute_group___42 **dev_groups;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___189 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___189 *, umode_t *);
	void (*class_release)(struct class___189 *);
	void (*dev_release)(struct device___189 *);
	int (*shutdown_pre)(struct device___189 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___189 *);
	void (*get_ownership)(struct device___189 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___189 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___185;

struct fwnode_handle___185 {
	struct fwnode_handle___185 *secondary;
	const struct fwnode_operations___185 *ops;
	struct device___189 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___81 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___185 fwnode;
	struct property___20 *properties;
	struct property___20 *deadprops;
	struct device_node___81 *parent;
	struct device_node___81 *child;
	struct device_node___81 *sibling;
	struct kobject___42 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___185;

struct fwnode_endpoint___185;

struct fwnode_operations___185 {
	struct fwnode_handle___185 * (*get)(struct fwnode_handle___185 *);
	void (*put)(struct fwnode_handle___185 *);
	bool (*device_is_available)(const struct fwnode_handle___185 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___185 *, const struct device___189 *);
	bool (*property_present)(const struct fwnode_handle___185 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___185 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___185 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___185 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*get_parent)(const struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*get_next_child_node)(const struct fwnode_handle___185 *, struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*get_named_child_node)(const struct fwnode_handle___185 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___185 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___185 *);
	struct fwnode_handle___185 * (*graph_get_next_endpoint)(const struct fwnode_handle___185 *, struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*graph_get_remote_endpoint)(const struct fwnode_handle___185 *);
	struct fwnode_handle___185 * (*graph_get_port_parent)(struct fwnode_handle___185 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___185 *, struct fwnode_endpoint___185 *);
	int (*add_links)(struct fwnode_handle___185 *);
};

struct fwnode_endpoint___185 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___185 *local_fwnode;
};

struct fwnode_reference_args___185 {
	struct fwnode_handle___185 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_power_governor___6 {
	bool (*power_down_ok)(struct dev_pm_domain___189 *);
	bool (*suspend_ok)(struct device___189 *);
};

struct gpd_dev_ops___6 {
	int (*start)(struct device___189 *);
	int (*stop)(struct device___189 *);
};

struct genpd_power_state___6 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___185 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct generic_pm_domain___6 {
	struct device___189 dev;
	struct dev_pm_domain___189 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor___6 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___185 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain___6 *);
	int (*power_on)(struct generic_pm_domain___6 *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___6 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___6 *, unsigned int);
	struct gpd_dev_ops___6 dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain___6 *, struct device___189 *);
	void (*detach_dev)(struct generic_pm_domain___6 *, struct device___189 *);
	unsigned int flags;
	struct genpd_power_state___6 *states;
	void (*free_states)(struct genpd_power_state___6 *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

struct gpd_link___2 {
	struct generic_pm_domain___6 *parent;
	struct list_head parent_node;
	struct generic_pm_domain___6 *child;
	struct list_head child_node;
	unsigned int performance_state;
	unsigned int prev_performance_state;
};

struct generic_pm_domain_data___2 {
	struct pm_domain_data___10 base;
	struct gpd_timing_data td;
	struct notifier_block nb;
	struct notifier_block *power_nb;
	int cpu;
	unsigned int performance_state;
	unsigned int default_pstate;
	unsigned int rpm_pstate;
	ktime_t next_wakeup;
	void *data;
};

struct dev_pm_qos_request___23 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___189 *dev;
};

struct pm_clk_notifier_block {
	struct notifier_block nb;
	struct dev_pm_domain___189 *pm_domain;
	char *con_ids[0];
};

enum pce_status {
	PCE_STATUS_NONE = 0,
	PCE_STATUS_ACQUIRED = 1,
	PCE_STATUS_PREPARED = 2,
	PCE_STATUS_ENABLED = 3,
	PCE_STATUS_ERROR = 4,
};

struct pm_clock_entry {
	struct list_head node;
	char *con_id;
	struct clk *clk;
	enum pce_status status;
	bool enabled_when_prepared;
};

struct firmware_fallback_config {
	unsigned int force_sysfs_fallback;
	unsigned int ignore_sysfs_fallback;
	int old_timeout;
	int loading_timeout;
};

typedef void (*dr_release_t___24)(struct device___187 *, void *);

typedef int (*dr_match_t___20)(struct device___187 *, void *, void *);

struct builtin_fw {
	char *name;
	void *data;
	long unsigned int size;
};

enum fw_opt {
	FW_OPT_UEVENT = 1,
	FW_OPT_NOWAIT = 2,
	FW_OPT_USERHELPER = 4,
	FW_OPT_NO_WARN = 8,
	FW_OPT_NOCACHE = 16,
	FW_OPT_NOFALLBACK_SYSFS = 32,
	FW_OPT_FALLBACK_PLATFORM = 64,
	FW_OPT_PARTIAL = 128,
};

enum fw_status {
	FW_STATUS_UNKNOWN = 0,
	FW_STATUS_LOADING = 1,
	FW_STATUS_DONE = 2,
	FW_STATUS_ABORTED = 3,
};

struct fw_state {
	struct completion completion;
	enum fw_status status;
};

struct firmware_cache;

struct fw_priv {
	struct kref ref;
	struct list_head list;
	struct firmware_cache *fwc;
	struct fw_state fw_st;
	void *data;
	size_t size;
	size_t allocated_size;
	size_t offset;
	u32 opt_flags;
	bool is_paged_buf;
	struct page___215 **pages;
	int nr_pages;
	int page_array_size;
	bool need_uevent;
	struct list_head pending_list;
	const char *fw_name;
};

struct firmware_cache {
	spinlock_t lock;
	struct list_head head;
	int state;
	spinlock_t name_lock;
	struct list_head fw_names;
	struct delayed_work work;
	struct notifier_block pm_notify;
};

struct fw_cache_entry {
	struct list_head list;
	const char *name;
};

struct fw_name_devm {
	long unsigned int magic;
	const char *name;
};

struct firmware_work {
	struct work_struct work;
	struct module___194 *module;
	const char *name;
	struct device___187 *device;
	void *context;
	void (*cont)(const struct firmware *, void *);
	u32 opt_flags;
};

struct fw_sysfs {
	bool nowait;
	struct device___188 dev;
	struct fw_priv *fw_priv;
	struct firmware *fw;
};

typedef struct pglist_data___94 pg_data_t___16;

struct memory_block___3 {
	long unsigned int start_section_nr;
	long unsigned int state;
	int online_type;
	int nid;
	struct device___166 dev;
	long unsigned int nr_vmemmap_pages;
	struct memory_group *group;
	struct list_head group_next;
};

typedef int (*walk_memory_blocks_func_t___3)(struct memory_block___3 *, void *);

struct node_access_nodes {
	struct device___166 dev;
	struct list_head list_node;
	unsigned int access;
	struct node_hmem_attrs hmem_attrs;
};

struct node_cache_info {
	struct device___166 dev;
	struct list_head node;
	struct node_cache_attrs cache_attrs;
};

struct node_attr {
	struct device_attribute___22 attr;
	enum node_states state;
};

struct for_each_memory_block_cb_data {
	walk_memory_blocks_func_t___3 func;
	void *arg;
};

struct regmap_config___9 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___187 *, unsigned int);
	bool (*readable_reg)(struct device___187 *, unsigned int);
	bool (*volatile_reg)(struct device___187 *, unsigned int);
	bool (*precious_reg)(struct device___187 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___187 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___187 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct regmap___2;

struct regmap_async {
	struct list_head list;
	struct regmap___2 *map;
	void *work_buf;
};

struct reg_field {
	unsigned int reg;
	unsigned int lsb;
	unsigned int msb;
	unsigned int id_size;
	unsigned int id_offset;
};

struct regmap_format {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___2 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct hwspinlock;

struct regcache_ops;

struct regmap___2 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
		struct {
			raw_spinlock_t raw_spinlock;
			long unsigned int raw_spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___187 *dev;
	void *work_buf;
	struct regmap_format format;
	const struct regmap_bus *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___210 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___187 *, unsigned int);
	bool (*readable_reg)(struct device___187 *, unsigned int);
	bool (*volatile_reg)(struct device___187 *, unsigned int);
	bool (*precious_reg)(struct device___187 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___187 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___187 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
	bool can_sleep;
};

struct regcache_ops {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___2 *);
	int (*exit)(struct regmap___2 *);
	void (*debugfs_init)(struct regmap___2 *);
	int (*read)(struct regmap___2 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___2 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___2 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___2 *, unsigned int, unsigned int);
};

struct regmap_range_node {
	struct rb_node node;
	const char *name;
	struct regmap___2 *map;
	unsigned int range_min;
	unsigned int range_max;
	unsigned int selector_reg;
	unsigned int selector_mask;
	int selector_shift;
	unsigned int window_start;
	unsigned int window_len;
};

struct regmap_field {
	struct regmap___2 *regmap;
	unsigned int mask;
	unsigned int shift;
	unsigned int reg;
	unsigned int id_size;
	unsigned int id_offset;
};

struct trace_event_raw_regmap_reg {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int reg;
	unsigned int val;
	char __data[0];
};

struct trace_event_raw_regmap_block {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int reg;
	int count;
	char __data[0];
};

struct trace_event_raw_regcache_sync {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_status;
	u32 __data_loc_type;
	char __data[0];
};

struct trace_event_raw_regmap_bool {
	struct trace_entry ent;
	u32 __data_loc_name;
	int flag;
	char __data[0];
};

struct trace_event_raw_regmap_async {
	struct trace_entry ent;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_regcache_drop_region {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int from;
	unsigned int to;
	char __data[0];
};

struct trace_event_data_offsets_regmap_reg {
	u32 name;
};

struct trace_event_data_offsets_regmap_block {
	u32 name;
};

struct trace_event_data_offsets_regcache_sync {
	u32 name;
	u32 status;
	u32 type;
};

struct trace_event_data_offsets_regmap_bool {
	u32 name;
};

struct trace_event_data_offsets_regmap_async {
	u32 name;
};

struct trace_event_data_offsets_regcache_drop_region {
	u32 name;
};

typedef void (*btf_trace_regmap_reg_write)(void *, struct regmap___2 *, unsigned int, unsigned int);

typedef void (*btf_trace_regmap_reg_read)(void *, struct regmap___2 *, unsigned int, unsigned int);

typedef void (*btf_trace_regmap_reg_read_cache)(void *, struct regmap___2 *, unsigned int, unsigned int);

typedef void (*btf_trace_regmap_hw_read_start)(void *, struct regmap___2 *, unsigned int, int);

typedef void (*btf_trace_regmap_hw_read_done)(void *, struct regmap___2 *, unsigned int, int);

typedef void (*btf_trace_regmap_hw_write_start)(void *, struct regmap___2 *, unsigned int, int);

typedef void (*btf_trace_regmap_hw_write_done)(void *, struct regmap___2 *, unsigned int, int);

typedef void (*btf_trace_regcache_sync)(void *, struct regmap___2 *, const char *, const char *);

typedef void (*btf_trace_regmap_cache_only)(void *, struct regmap___2 *, bool);

typedef void (*btf_trace_regmap_cache_bypass)(void *, struct regmap___2 *, bool);

typedef void (*btf_trace_regmap_async_write_start)(void *, struct regmap___2 *, unsigned int, int);

typedef void (*btf_trace_regmap_async_io_complete)(void *, struct regmap___2 *);

typedef void (*btf_trace_regmap_async_complete_start)(void *, struct regmap___2 *);

typedef void (*btf_trace_regmap_async_complete_done)(void *, struct regmap___2 *);

typedef void (*btf_trace_regcache_drop_region)(void *, struct regmap___2 *, unsigned int, unsigned int);

struct regmap_async___2;

typedef int (*regmap_hw_async_write___2)(void *, const void *, size_t, const void *, size_t, struct regmap_async___2 *);

struct regmap___3;

struct regmap_async___2 {
	struct list_head list;
	struct regmap___3 *map;
	void *work_buf;
};

typedef struct regmap_async___2 * (*regmap_hw_async_alloc___2)();

struct regmap_bus___2 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___2 async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___2 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
	bool free_on_exit;
};

struct regmap_format___2 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___3 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___2;

struct regmap___3 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
		struct {
			raw_spinlock_t raw_spinlock;
			long unsigned int raw_spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___184 *dev;
	void *work_buf;
	struct regmap_format___2 format;
	const struct regmap_bus___2 *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___209 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___184 *, unsigned int);
	bool (*readable_reg)(struct device___184 *, unsigned int);
	bool (*volatile_reg)(struct device___184 *, unsigned int);
	bool (*precious_reg)(struct device___184 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___184 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___184 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops___2 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
	bool can_sleep;
};

struct regcache_ops___2 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___3 *);
	int (*exit)(struct regmap___3 *);
	void (*debugfs_init)(struct regmap___3 *);
	int (*read)(struct regmap___3 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___3 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___3 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___3 *, unsigned int, unsigned int);
};

struct regcache_rbtree_node {
	void *block;
	long int *cache_present;
	unsigned int base_reg;
	unsigned int blklen;
	struct rb_node node;
};

struct regcache_rbtree_ctx {
	struct rb_root root;
	struct regcache_rbtree_node *cached_rbnode;
};

struct regmap_debugfs_off_cache {
	struct list_head list;
	off_t min;
	off_t max;
	unsigned int base_reg;
	unsigned int max_reg;
};

struct regmap_debugfs_node {
	struct regmap___2 *map;
	struct list_head link;
};

struct regmap_async___3;

typedef int (*regmap_hw_async_write___3)(void *, const void *, size_t, const void *, size_t, struct regmap_async___3 *);

struct regmap___4;

struct regmap_async___3 {
	struct list_head list;
	struct regmap___4 *map;
	void *work_buf;
};

typedef struct regmap_async___3 * (*regmap_hw_async_alloc___3)();

struct regmap_bus___3 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___3 async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___3 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
	bool free_on_exit;
};

struct regmap_format___3 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___4 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___3;

struct regmap___4 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
		struct {
			raw_spinlock_t raw_spinlock;
			long unsigned int raw_spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___166 *dev;
	void *work_buf;
	struct regmap_format___3 format;
	const struct regmap_bus___3 *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___202 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___166 *, unsigned int);
	bool (*readable_reg)(struct device___166 *, unsigned int);
	bool (*volatile_reg)(struct device___166 *, unsigned int);
	bool (*precious_reg)(struct device___166 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___166 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___166 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops___3 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
	bool can_sleep;
};

struct regcache_ops___3 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___4 *);
	int (*exit)(struct regmap___4 *);
	void (*debugfs_init)(struct regmap___4 *);
	int (*read)(struct regmap___4 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___4 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___4 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___4 *, unsigned int, unsigned int);
};

struct dentry___212;

struct super_block___212;

struct module___196;

struct file_system_type___212 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___212 * (*mount)(struct file_system_type___212 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___212 *);
	struct module___196 *owner;
	struct file_system_type___212 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___212;

struct kiocb___212;

struct iov_iter___132;

struct poll_table_struct___140;

struct vm_area_struct___217;

struct inode___212;

struct file_lock___212;

struct page___217;

struct pipe_inode_info___69;

struct seq_file___187;

struct file_operations___213 {
	struct module___196 *owner;
	loff_t (*llseek)(struct file___212 *, loff_t, int);
	ssize_t (*read)(struct file___212 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___212 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___212 *, struct iov_iter___132 *);
	ssize_t (*write_iter)(struct kiocb___212 *, struct iov_iter___132 *);
	int (*iopoll)(struct kiocb___212 *, bool);
	int (*iterate)(struct file___212 *, struct dir_context *);
	int (*iterate_shared)(struct file___212 *, struct dir_context *);
	__poll_t (*poll)(struct file___212 *, struct poll_table_struct___140 *);
	long int (*unlocked_ioctl)(struct file___212 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___212 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___212 *, struct vm_area_struct___217 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___212 *, struct file___212 *);
	int (*flush)(struct file___212 *, fl_owner_t);
	int (*release)(struct inode___212 *, struct file___212 *);
	int (*fsync)(struct file___212 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___212 *, int);
	int (*lock)(struct file___212 *, int, struct file_lock___212 *);
	ssize_t (*sendpage)(struct file___212 *, struct page___217 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___212 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___212 *, long unsigned int);
	int (*flock)(struct file___212 *, int, struct file_lock___212 *);
	ssize_t (*splice_write)(struct pipe_inode_info___69 *, struct file___212 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___212 *, loff_t *, struct pipe_inode_info___69 *, size_t, unsigned int);
	int (*setlease)(struct file___212 *, long int, struct file_lock___212 **, void **);
	long int (*fallocate)(struct file___212 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___187 *, struct file___212 *);
	ssize_t (*copy_file_range)(struct file___212 *, loff_t, struct file___212 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___212 *, loff_t, struct file___212 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___212 *, loff_t, loff_t, int);
};

struct vmacache___217 {
	u64 seqnum;
	struct vm_area_struct___217 *vmas[4];
};

struct page_frag___217 {
	struct page___217 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___218;

struct pid___189;

struct nsproxy___198;

struct signal_struct___213;

struct vm_struct___195;

struct task_struct___219 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___219 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity___3 se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___218 *mm;
	struct mm_struct___218 *active_mm;
	struct vmacache___217 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___219 *real_parent;
	struct task_struct___219 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___219 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___189 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___30 *ptracer_cred;
	const struct cred___30 *real_cred;
	const struct cred___30 *cred;
	struct key___13 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___198 *nsproxy;
	struct signal_struct___213 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___219 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___108 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___69 *splice_pipe;
	struct page_frag___217 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___219 *oom_reaper_list;
	struct vm_struct___195 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___78 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___200;

struct kobj_type___200;

struct kernfs_node___200;

struct kobject___200 {
	const char *name;
	struct list_head entry;
	struct kobject___200 *parent;
	struct kset___200 *kset;
	struct kobj_type___200 *ktype;
	struct kernfs_node___200 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___197 {
	struct kobject___200 kobj;
	struct module___196 *mod;
	struct kobject___200 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___196 {
	struct module___196 *mod;
	struct latch_tree_node node;
};

struct module_layout___196 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___196 mtn;
};

struct module_attribute___196;

struct kernel_param___196;

struct module___196 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___197 mkobj;
	struct module_attribute___196 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___200 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___196 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___196 core_layout;
	struct module_layout___196 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___189;

struct upid___189 {
	int nr;
	struct pid_namespace___189 *ns;
};

struct pid_namespace___189 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___219 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___189 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___26 ns;
};

struct pid___189 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___189 numbers[1];
};

typedef struct page___217 *pgtable_t___217;

struct address_space___212;

struct page_pool___57;

struct dev_pagemap___207;

struct page___217 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___212 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___57 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___217 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___217 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___218 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___207 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___207;

struct vm_area_struct___217 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___217 *vm_next;
	struct vm_area_struct___217 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___218 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___207 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___212 *vm_file;
	struct file___212 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___213 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___219 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___219 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___189 *pids[4];
	struct pid___189 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___218 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___217;

struct mm_struct___218 {
	struct {
		struct vm_area_struct___217 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___212 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___217 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___219 *owner;
		struct user_namespace *user_ns;
		struct file___212 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___198 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___189 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct fasync_struct___212;

struct pipe_buffer___69;

struct pipe_inode_info___69 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___217 *tmp_page;
	struct fasync_struct___212 *fasync_readers;
	struct fasync_struct___212 *fasync_writers;
	struct pipe_buffer___69 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___195 {
	struct vm_struct___195 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___217 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___212;

struct address_space___212 {
	struct inode___212 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___212 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___190;

struct page_pool_params___57 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___190 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___57 {
	u32 count;
	struct page___217 *cache[128];
};

struct page_pool___57 {
	struct page_pool_params___57 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___217 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___57 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___207;

struct dev_pagemap___207 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___207 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___212;

struct path___212 {
	struct vfsmount___212 *mnt;
	struct dentry___212 *dentry;
};

struct fown_struct___189 {
	rwlock_t lock;
	struct pid___189 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___212 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___212 f_path;
	struct inode___212 *f_inode;
	const struct file_operations___213 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___189 f_owner;
	const struct cred___30 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___212 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___207;

struct vm_operations_struct___207 {
	void (*open)(struct vm_area_struct___217 *);
	void (*close)(struct vm_area_struct___217 *);
	int (*may_split)(struct vm_area_struct___217 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___217 *);
	int (*mprotect)(struct vm_area_struct___217 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___207 *);
	vm_fault_t (*huge_fault)(struct vm_fault___207 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___207 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___217 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___207 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___207 *);
	int (*access)(struct vm_area_struct___217 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___217 *);
	int (*set_policy)(struct vm_area_struct___217 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___217 *, long unsigned int);
	struct page___217 * (*find_special_page)(struct vm_area_struct___217 *, long unsigned int);
};

struct core_thread___217 {
	struct task_struct___219 *task;
	struct core_thread___217 *next;
};

struct core_state___217 {
	atomic_t nr_threads;
	struct core_thread___217 dumper;
	struct completion startup;
};

struct vm_fault___207 {
	const struct {
		struct vm_area_struct___217 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___217 *cow_page;
	struct page___217 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___217 prealloc_pte;
};

struct fwnode_operations___186;

struct fwnode_handle___186 {
	struct fwnode_handle___186 *secondary;
	const struct fwnode_operations___186 *ops;
	struct device___190 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___186;

struct fwnode_endpoint___186;

struct fwnode_operations___186 {
	struct fwnode_handle___186 * (*get)(struct fwnode_handle___186 *);
	void (*put)(struct fwnode_handle___186 *);
	bool (*device_is_available)(const struct fwnode_handle___186 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___186 *, const struct device___190 *);
	bool (*property_present)(const struct fwnode_handle___186 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___186 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___186 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___186 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*get_parent)(const struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*get_next_child_node)(const struct fwnode_handle___186 *, struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*get_named_child_node)(const struct fwnode_handle___186 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___186 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___186 *);
	struct fwnode_handle___186 * (*graph_get_next_endpoint)(const struct fwnode_handle___186 *, struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*graph_get_remote_endpoint)(const struct fwnode_handle___186 *);
	struct fwnode_handle___186 * (*graph_get_port_parent)(struct fwnode_handle___186 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___186 *, struct fwnode_endpoint___186 *);
	int (*add_links)(struct fwnode_handle___186 *);
};

struct wakeup_source___190;

struct dev_pm_info___190 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___190 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___10 *subsys_data;
	void (*set_latency_tolerance)(struct device___190 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___190;

struct bus_type___190;

struct device_driver___190;

struct dev_pm_domain___190;

struct irq_domain___49;

struct device_node___82;

struct class___190;

struct attribute_group___200;

struct device___190 {
	struct kobject___200 kobj;
	struct device___190 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___190 *type;
	struct bus_type___190 *bus;
	struct device_driver___190 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___190 power;
	struct dev_pm_domain___190 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___49 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___82 *of_node;
	struct fwnode_handle___186 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___190 *class;
	const struct attribute_group___200 **groups;
	void (*release)(struct device___190 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___186 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___186 *local_fwnode;
};

struct fwnode_reference_args___186 {
	struct fwnode_handle___186 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct regmap_config___10 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___190 *, unsigned int);
	bool (*readable_reg)(struct device___190 *, unsigned int);
	bool (*volatile_reg)(struct device___190 *, unsigned int);
	bool (*precious_reg)(struct device___190 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___190 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___190 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct regmap_async___4;

typedef int (*regmap_hw_async_write___4)(void *, const void *, size_t, const void *, size_t, struct regmap_async___4 *);

struct regmap___5;

struct regmap_async___4 {
	struct list_head list;
	struct regmap___5 *map;
	void *work_buf;
};

typedef struct regmap_async___4 * (*regmap_hw_async_alloc___4)();

struct regmap_bus___4 {
	bool fast_io;
	regmap_hw_write write;
	regmap_hw_gather_write gather_write;
	regmap_hw_async_write___4 async_write;
	regmap_hw_reg_write reg_write;
	regmap_hw_reg_update_bits reg_update_bits;
	regmap_hw_read read;
	regmap_hw_reg_read reg_read;
	regmap_hw_free_context free_context;
	regmap_hw_async_alloc___4 async_alloc;
	u8 read_flag_mask;
	enum regmap_endian reg_format_endian_default;
	enum regmap_endian val_format_endian_default;
	size_t max_raw_read;
	size_t max_raw_write;
	bool free_on_exit;
};

struct kernfs_root___200;

struct kernfs_elem_dir___200 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___200 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___200;

struct kernfs_root___200 {
	struct kernfs_node___200 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___200 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___200 {
	struct kernfs_node___200 *target_kn;
};

struct kernfs_ops___200;

struct kernfs_elem_attr___200 {
	const struct kernfs_ops___200 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___200 *notify_next;
};

struct kernfs_node___200 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___200 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___200 dir;
		struct kernfs_elem_symlink___200 symlink;
		struct kernfs_elem_attr___200 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___200;

struct kernfs_ops___200 {
	int (*open)(struct kernfs_open_file___200 *);
	void (*release)(struct kernfs_open_file___200 *);
	int (*seq_show)(struct seq_file___187 *, void *);
	void * (*seq_start)(struct seq_file___187 *, loff_t *);
	void * (*seq_next)(struct seq_file___187 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___187 *, void *);
	ssize_t (*read)(struct kernfs_open_file___200 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___200 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___200 *, struct poll_table_struct___140 *);
	int (*mmap)(struct kernfs_open_file___200 *, struct vm_area_struct___217 *);
};

struct kernfs_syscall_ops___200 {
	int (*show_options)(struct seq_file___187 *, struct kernfs_root___200 *);
	int (*mkdir)(struct kernfs_node___200 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___200 *);
	int (*rename)(struct kernfs_node___200 *, struct kernfs_node___200 *, const char *);
	int (*show_path)(struct seq_file___187 *, struct kernfs_node___200 *, struct kernfs_root___200 *);
};

struct seq_operations___187;

struct seq_file___187 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___187 *op;
	int poll_event;
	const struct file___212 *file;
	void *private;
};

struct kernfs_open_file___200 {
	struct kernfs_node___200 *kn;
	struct file___212 *file;
	struct seq_file___187 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___207 *vm_ops;
};

typedef void (*poll_queue_proc___147)(struct file___212 *, wait_queue_head_t *, struct poll_table_struct___140 *);

struct poll_table_struct___140 {
	poll_queue_proc___147 _qproc;
	__poll_t _key;
};

struct bin_attribute___200;

struct attribute_group___200 {
	const char *name;
	umode_t (*is_visible)(struct kobject___200 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___200 *, struct bin_attribute___200 *, int);
	struct attribute **attrs;
	struct bin_attribute___200 **bin_attrs;
};

struct bin_attribute___200 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___212 * (*f_mapping)();
	ssize_t (*read)(struct file___212 *, struct kobject___200 *, struct bin_attribute___200 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___212 *, struct kobject___200 *, struct bin_attribute___200 *, char *, loff_t, size_t);
	int (*mmap)(struct file___212 *, struct kobject___200 *, struct bin_attribute___200 *, struct vm_area_struct___217 *);
};

struct sysfs_ops___200 {
	ssize_t (*show)(struct kobject___200 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___200 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___200;

struct kset___200 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___200 kobj;
	const struct kset_uevent_ops___200 *uevent_ops;
};

struct kobj_type___200 {
	void (*release)(struct kobject___200 *);
	const struct sysfs_ops___200 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___200 **default_groups;
	const struct kobj_ns_type_operations___29 * (*child_ns_type)(struct kobject___200 *);
	const void * (*namespace)(struct kobject___200 *);
	void (*get_ownership)(struct kobject___200 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___200 {
	int (* const filter)(struct kset___200 *, struct kobject___200 *);
	const char * (* const name)(struct kset___200 *, struct kobject___200 *);
	int (* const uevent)(struct kset___200 *, struct kobject___200 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___190 {
	int (*prepare)(struct device___190 *);
	void (*complete)(struct device___190 *);
	int (*suspend)(struct device___190 *);
	int (*resume)(struct device___190 *);
	int (*freeze)(struct device___190 *);
	int (*thaw)(struct device___190 *);
	int (*poweroff)(struct device___190 *);
	int (*restore)(struct device___190 *);
	int (*suspend_late)(struct device___190 *);
	int (*resume_early)(struct device___190 *);
	int (*freeze_late)(struct device___190 *);
	int (*thaw_early)(struct device___190 *);
	int (*poweroff_late)(struct device___190 *);
	int (*restore_early)(struct device___190 *);
	int (*suspend_noirq)(struct device___190 *);
	int (*resume_noirq)(struct device___190 *);
	int (*freeze_noirq)(struct device___190 *);
	int (*thaw_noirq)(struct device___190 *);
	int (*poweroff_noirq)(struct device___190 *);
	int (*restore_noirq)(struct device___190 *);
	int (*runtime_suspend)(struct device___190 *);
	int (*runtime_resume)(struct device___190 *);
	int (*runtime_idle)(struct device___190 *);
};

struct wakeup_source___190 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___190 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___190 {
	struct dev_pm_ops___190 ops;
	int (*start)(struct device___190 *);
	void (*detach)(struct device___190 *, bool);
	int (*activate)(struct device___190 *);
	void (*sync)(struct device___190 *);
	void (*dismiss)(struct device___190 *);
};

struct bus_type___190 {
	const char *name;
	const char *dev_name;
	struct device___190 *dev_root;
	const struct attribute_group___200 **bus_groups;
	const struct attribute_group___200 **dev_groups;
	const struct attribute_group___200 **drv_groups;
	int (*match)(struct device___190 *, struct device_driver___190 *);
	int (*uevent)(struct device___190 *, struct kobj_uevent_env *);
	int (*probe)(struct device___190 *);
	void (*sync_state)(struct device___190 *);
	void (*remove)(struct device___190 *);
	void (*shutdown)(struct device___190 *);
	int (*online)(struct device___190 *);
	int (*offline)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	int (*num_vf)(struct device___190 *);
	int (*dma_configure)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___190 {
	const char *name;
	struct bus_type___190 *bus;
	struct module___196 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___190 *);
	void (*sync_state)(struct device___190 *);
	int (*remove)(struct device___190 *);
	void (*shutdown)(struct device___190 *);
	int (*suspend)(struct device___190 *, pm_message_t);
	int (*resume)(struct device___190 *);
	const struct attribute_group___200 **groups;
	const struct attribute_group___200 **dev_groups;
	const struct dev_pm_ops___190 *pm;
	void (*coredump)(struct device___190 *);
	struct driver_private *p;
};

struct device_type___190 {
	const char *name;
	const struct attribute_group___200 **groups;
	int (*uevent)(struct device___190 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___190 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___190 *);
	const struct dev_pm_ops___190 *pm;
};

struct class___190 {
	const char *name;
	struct module___196 *owner;
	const struct attribute_group___200 **class_groups;
	const struct attribute_group___200 **dev_groups;
	struct kobject___200 *dev_kobj;
	int (*dev_uevent)(struct device___190 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___190 *, umode_t *);
	void (*class_release)(struct class___190 *);
	void (*dev_release)(struct device___190 *);
	int (*shutdown_pre)(struct device___190 *);
	const struct kobj_ns_type_operations___29 *ns_type;
	const void * (*namespace)(struct device___190 *);
	void (*get_ownership)(struct device___190 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___190 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___49;

struct irq_domain_chip_generic___49;

struct irq_data___51;

struct irq_domain___49 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___49 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___186 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___49 *gc;
	struct irq_domain___49 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___51 *revmap[0];
};

struct property___59;

struct device_node___82 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___186 fwnode;
	struct property___59 *properties;
	struct property___59 *deadprops;
	struct device_node___82 *parent;
	struct device_node___82 *child;
	struct device_node___82 *sibling;
	struct kobject___200 kobj;
	long unsigned int _flags;
	void *data;
};

struct kthread_work___5;

typedef void (*kthread_work_func_t___5)(struct kthread_work___5 *);

struct kthread_worker___5;

struct kthread_work___5 {
	struct list_head node;
	kthread_work_func_t___5 func;
	struct kthread_worker___5 *worker;
	int canceling;
};

struct kthread_worker___5 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___219 *task;
	struct kthread_work___5 *current_work;
};

struct dev_pagemap_ops___207 {
	void (*page_free)(struct page___217 *);
	void (*kill)(struct dev_pagemap___207 *);
	void (*cleanup)(struct dev_pagemap___207 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___207 *);
};

struct dentry_operations___212;

struct dentry___212 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___212 *d_parent;
	struct qstr d_name;
	struct inode___212 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___212 *d_op;
	struct super_block___212 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___212;

struct cdev___53;

struct inode___212 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___212 *i_op;
	struct super_block___212 *i_sb;
	struct address_space___212 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___213 *i_fop;
		void (*free_inode)(struct inode___212 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___212 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___69 *i_pipe;
		struct cdev___53 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___212 {
	int (*d_revalidate)(struct dentry___212 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___212 *, unsigned int);
	int (*d_hash)(const struct dentry___212 *, struct qstr *);
	int (*d_compare)(const struct dentry___212 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___212 *);
	int (*d_init)(struct dentry___212 *);
	void (*d_release)(struct dentry___212 *);
	void (*d_prune)(struct dentry___212 *);
	void (*d_iput)(struct dentry___212 *, struct inode___212 *);
	char * (*d_dname)(struct dentry___212 *, char *, int);
	struct vfsmount___212 * (*d_automount)(struct path___212 *);
	int (*d_manage)(const struct path___212 *, bool);
	struct dentry___212 * (*d_real)(struct dentry___212 *, const struct inode___212 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___212;

struct mem_dqinfo___212 {
	struct quota_format_type___212 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___212;

struct quota_info___212 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___212 *files[3];
	struct mem_dqinfo___212 info[3];
	const struct quota_format_ops___212 *ops[3];
};

struct rcuwait___213 {
	struct task_struct___219 *task;
};

struct percpu_rw_semaphore___213 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___213 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___212 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___213 rw_sem[3];
};

struct super_operations___212;

struct dquot_operations___212;

struct quotactl_ops___212;

struct super_block___212 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___212 *s_type;
	const struct super_operations___212 *s_op;
	const struct dquot_operations___212 *dq_op;
	const struct quotactl_ops___212 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___212 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___13 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___212 s_dquot;
	struct sb_writers___212 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___212 *s_d_op;
	int cleancache_poolid;
	struct shrinker___92 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___212 {
	struct dentry___212 *mnt_root;
	struct super_block___212 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct kiocb___212 {
	struct file___212 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___212 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___102 *ki_waitq;
	};
};

struct iattr___212 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___212 *ia_file;
};

struct dquot___212 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___212 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___212 {
	int qf_fmt_id;
	const struct quota_format_ops___212 *qf_ops;
	struct module___196 *qf_owner;
	struct quota_format_type___212 *qf_next;
};

struct quota_format_ops___212 {
	int (*check_quota_file)(struct super_block___212 *, int);
	int (*read_file_info)(struct super_block___212 *, int);
	int (*write_file_info)(struct super_block___212 *, int);
	int (*free_file_info)(struct super_block___212 *, int);
	int (*read_dqblk)(struct dquot___212 *);
	int (*commit_dqblk)(struct dquot___212 *);
	int (*release_dqblk)(struct dquot___212 *);
	int (*get_next_id)(struct super_block___212 *, struct kqid *);
};

struct dquot_operations___212 {
	int (*write_dquot)(struct dquot___212 *);
	struct dquot___212 * (*alloc_dquot)(struct super_block___212 *, int);
	void (*destroy_dquot)(struct dquot___212 *);
	int (*acquire_dquot)(struct dquot___212 *);
	int (*release_dquot)(struct dquot___212 *);
	int (*mark_dirty)(struct dquot___212 *);
	int (*write_info)(struct super_block___212 *, int);
	qsize_t * (*get_reserved_space)(struct inode___212 *);
	int (*get_projid)(struct inode___212 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___212 *, qsize_t *);
	int (*get_next_id)(struct super_block___212 *, struct kqid *);
};

struct quotactl_ops___212 {
	int (*quota_on)(struct super_block___212 *, int, int, const struct path___212 *);
	int (*quota_off)(struct super_block___212 *, int);
	int (*quota_enable)(struct super_block___212 *, unsigned int);
	int (*quota_disable)(struct super_block___212 *, unsigned int);
	int (*quota_sync)(struct super_block___212 *, int);
	int (*set_info)(struct super_block___212 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___212 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___212 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___212 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___212 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___212 *, unsigned int);
};

struct address_space_operations___212 {
	int (*writepage)(struct page___217 *, struct writeback_control___3 *);
	int (*readpage)(struct file___212 *, struct page___217 *);
	int (*writepages)(struct address_space___212 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___217 *);
	int (*readpages)(struct file___212 *, struct address_space___212 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___212 *, struct address_space___212 *, loff_t, unsigned int, unsigned int, struct page___217 **, void **);
	int (*write_end)(struct file___212 *, struct address_space___212 *, loff_t, unsigned int, unsigned int, struct page___217 *, void *);
	sector_t (*bmap)(struct address_space___212 *, sector_t);
	void (*invalidatepage)(struct page___217 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___217 *, gfp_t);
	void (*freepage)(struct page___217 *);
	ssize_t (*direct_IO)(struct kiocb___212 *, struct iov_iter___132 *);
	int (*migratepage)(struct address_space___212 *, struct page___217 *, struct page___217 *, enum migrate_mode);
	bool (*isolate_page)(struct page___217 *, isolate_mode_t);
	void (*putback_page)(struct page___217 *);
	int (*launder_page)(struct page___217 *);
	int (*is_partially_uptodate)(struct page___217 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___217 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___212 *, struct page___217 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___212 *, sector_t *);
	void (*swap_deactivate)(struct file___212 *);
};

struct bio_vec___129;

struct iov_iter___132 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___129 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___69 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___53 {
	struct kobject___200 kobj;
	struct module___196 *owner;
	const struct file_operations___213 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___212 {
	struct dentry___212 * (*lookup)(struct inode___212 *, struct dentry___212 *, unsigned int);
	const char * (*get_link)(struct dentry___212 *, struct inode___212 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___212 *, int);
	struct posix_acl * (*get_acl)(struct inode___212 *, int, bool);
	int (*readlink)(struct dentry___212 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___212 *, struct dentry___212 *, umode_t, bool);
	int (*link)(struct dentry___212 *, struct inode___212 *, struct dentry___212 *);
	int (*unlink)(struct inode___212 *, struct dentry___212 *);
	int (*symlink)(struct user_namespace *, struct inode___212 *, struct dentry___212 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___212 *, struct dentry___212 *, umode_t);
	int (*rmdir)(struct inode___212 *, struct dentry___212 *);
	int (*mknod)(struct user_namespace *, struct inode___212 *, struct dentry___212 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___212 *, struct dentry___212 *, struct inode___212 *, struct dentry___212 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___212 *, struct iattr___212 *);
	int (*getattr)(struct user_namespace *, const struct path___212 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___212 *, char *, size_t);
	int (*fiemap)(struct inode___212 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___212 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___212 *, struct dentry___212 *, struct file___212 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___212 *, struct dentry___212 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___212 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___212 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___212 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___212 {
	void (*fl_copy_lock)(struct file_lock___212 *, struct file_lock___212 *);
	void (*fl_release_private)(struct file_lock___212 *);
};

struct lock_manager_operations___212;

struct file_lock___212 {
	struct file_lock___212 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___212 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___212 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___212 *fl_ops;
	const struct lock_manager_operations___212 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___212 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___212 *);
	int (*lm_grant)(struct file_lock___212 *, int);
	bool (*lm_break)(struct file_lock___212 *);
	int (*lm_change)(struct file_lock___212 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___212 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___212 *);
};

struct fasync_struct___212 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___212 *fa_next;
	struct file___212 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___212 {
	struct inode___212 * (*alloc_inode)(struct super_block___212 *);
	void (*destroy_inode)(struct inode___212 *);
	void (*free_inode)(struct inode___212 *);
	void (*dirty_inode)(struct inode___212 *, int);
	int (*write_inode)(struct inode___212 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___212 *);
	void (*evict_inode)(struct inode___212 *);
	void (*put_super)(struct super_block___212 *);
	int (*sync_fs)(struct super_block___212 *, int);
	int (*freeze_super)(struct super_block___212 *);
	int (*freeze_fs)(struct super_block___212 *);
	int (*thaw_super)(struct super_block___212 *);
	int (*unfreeze_fs)(struct super_block___212 *);
	int (*statfs)(struct dentry___212 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___212 *, int *, char *);
	void (*umount_begin)(struct super_block___212 *);
	int (*show_options)(struct seq_file___187 *, struct dentry___212 *);
	int (*show_devname)(struct seq_file___187 *, struct dentry___212 *);
	int (*show_path)(struct seq_file___187 *, struct dentry___212 *);
	int (*show_stats)(struct seq_file___187 *, struct dentry___212 *);
	ssize_t (*quota_read)(struct super_block___212 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___212 *, int, const char *, size_t, loff_t);
	struct dquot___212 ** (*get_dquots)(struct inode___212 *);
	long int (*nr_cached_objects)(struct super_block___212 *, struct shrink_control___92 *);
	long int (*free_cached_objects)(struct super_block___212 *, struct shrink_control___92 *);
	struct file___212 * (*real_loop)(struct file___212 *);
};

struct irq_desc___51;

typedef void (*irq_flow_handler_t___51)(struct irq_desc___51 *);

struct irq_chip___51;

struct irq_data___51 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___15 *common;
	struct irq_chip___51 *chip;
	struct irq_domain___49 *domain;
	struct irq_data___51 *parent_data;
	void *chip_data;
};

struct irqaction___33;

struct irq_desc___51 {
	struct irq_common_data___15 irq_common_data;
	struct irq_data___51 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___51 handle_irq;
	struct irqaction___33 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___200 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___196 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___51 {
	struct device___190 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___51 *);
	void (*irq_shutdown)(struct irq_data___51 *);
	void (*irq_enable)(struct irq_data___51 *);
	void (*irq_disable)(struct irq_data___51 *);
	void (*irq_ack)(struct irq_data___51 *);
	void (*irq_mask)(struct irq_data___51 *);
	void (*irq_mask_ack)(struct irq_data___51 *);
	void (*irq_unmask)(struct irq_data___51 *);
	void (*irq_eoi)(struct irq_data___51 *);
	int (*irq_set_affinity)(struct irq_data___51 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___51 *);
	int (*irq_set_type)(struct irq_data___51 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___51 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___51 *);
	void (*irq_bus_sync_unlock)(struct irq_data___51 *);
	void (*irq_cpu_online)(struct irq_data___51 *);
	void (*irq_cpu_offline)(struct irq_data___51 *);
	void (*irq_suspend)(struct irq_data___51 *);
	void (*irq_resume)(struct irq_data___51 *);
	void (*irq_pm_shutdown)(struct irq_data___51 *);
	void (*irq_calc_mask)(struct irq_data___51 *);
	void (*irq_print_chip)(struct irq_data___51 *, struct seq_file___187 *);
	int (*irq_request_resources)(struct irq_data___51 *);
	void (*irq_release_resources)(struct irq_data___51 *);
	void (*irq_compose_msi_msg)(struct irq_data___51 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___51 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___51 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___51 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___51 *, void *);
	void (*ipi_send_single)(struct irq_data___51 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___51 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___51 *);
	void (*irq_nmi_teardown)(struct irq_data___51 *);
	long unsigned int flags;
};

struct irqaction___33 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___33 *next;
	irq_handler_t thread_fn;
	struct task_struct___219 *thread;
	struct irqaction___33 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___49 {
	struct irq_chip___51 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___51 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___49 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___49 *);
	void (*resume)(struct irq_chip_generic___49 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___49 *domain;
	struct list_head list;
	struct irq_chip_type___49 chip_types[0];
};

struct irq_domain_chip_generic___49 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___49 *gc[0];
};

struct kernel_param_ops___196 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___196 *);
	int (*get)(char *, const struct kernel_param___196 *);
	void (*free)(void *);
};

struct kparam_array___196;

struct kernel_param___196 {
	const char *name;
	struct module___196 *mod;
	const struct kernel_param_ops___196 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___196 *arr;
	};
};

struct kparam_array___196 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___196 *ops;
	void *elem;
};

struct module_attribute___196 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___196 *, struct module_kobject___197 *, char *);
	ssize_t (*store)(struct module_attribute___196 *, struct module_kobject___197 *, const char *, size_t);
	void (*setup)(struct module___196 *, const char *);
	int (*test)(struct module___196 *);
	void (*free)(struct module___196 *);
};

struct bio_vec___129 {
	struct page___217 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct pipe_buf_operations___69;

struct pipe_buffer___69 {
	struct page___217 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___69 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___69 {
	int (*confirm)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
	void (*release)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
	bool (*try_steal)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
	bool (*get)(struct pipe_inode_info___69 *, struct pipe_buffer___69 *);
};

struct property___59 {
	char *name;
	int length;
	void *value;
	struct property___59 *next;
	long unsigned int _flags;
	struct bin_attribute___200 attr;
};

struct irq_fwspec___47 {
	struct fwnode_handle___186 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___49 {
	int (*match)(struct irq_domain___49 *, struct device_node___82 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___49 *, struct irq_fwspec___47 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___49 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___49 *, unsigned int);
	int (*xlate)(struct irq_domain___49 *, struct device_node___82 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___49 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___49 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___49 *, struct irq_data___51 *, bool);
	void (*deactivate)(struct irq_domain___49 *, struct irq_data___51 *);
	int (*translate)(struct irq_domain___49 *, struct irq_fwspec___47 *, long unsigned int *, unsigned int *);
};

struct seq_operations___187 {
	void * (*start)(struct seq_file___187 *, loff_t *);
	void (*stop)(struct seq_file___187 *, void *);
	void * (*next)(struct seq_file___187 *, void *, loff_t *);
	int (*show)(struct seq_file___187 *, void *);
};

struct spi_controller___2;

struct spi_device___2 {
	struct device___190 dev;
	struct spi_controller___2 *controller;
	struct spi_controller___2 *master;
	u32 max_speed_hz;
	u8 chip_select;
	u8 bits_per_word;
	bool rt;
	u32 mode;
	int irq;
	void *controller_state;
	void *controller_data;
	char modalias[32];
	const char *driver_override;
	int cs_gpio;
	struct gpio_desc *cs_gpiod;
	struct spi_delay word_delay;
	struct spi_delay cs_setup;
	struct spi_delay cs_hold;
	struct spi_delay cs_inactive;
	struct spi_statistics statistics;
};

struct spi_message___2;

struct spi_controller___2 {
	struct device___190 dev;
	struct list_head list;
	s16 bus_num;
	u16 num_chipselect;
	u16 dma_alignment;
	u32 mode_bits;
	u32 buswidth_override_bits;
	u32 bits_per_word_mask;
	u32 min_speed_hz;
	u32 max_speed_hz;
	u16 flags;
	bool devm_allocated;
	bool slave;
	size_t (*max_transfer_size)(struct spi_device___2 *);
	size_t (*max_message_size)(struct spi_device___2 *);
	struct mutex io_mutex;
	struct mutex add_lock;
	spinlock_t bus_lock_spinlock;
	struct mutex bus_lock_mutex;
	bool bus_lock_flag;
	int (*setup)(struct spi_device___2 *);
	int (*set_cs_timing)(struct spi_device___2 *);
	int (*transfer)(struct spi_device___2 *, struct spi_message___2 *);
	void (*cleanup)(struct spi_device___2 *);
	bool (*can_dma)(struct spi_controller___2 *, struct spi_device___2 *, struct spi_transfer *);
	struct device___190 *dma_map_dev;
	bool queued;
	struct kthread_worker___5 *kworker;
	struct kthread_work___5 pump_messages;
	spinlock_t queue_lock;
	struct list_head queue;
	struct spi_message___2 *cur_msg;
	bool idling;
	bool busy;
	bool running;
	bool rt;
	bool auto_runtime_pm;
	bool cur_msg_prepared;
	bool cur_msg_mapped;
	bool last_cs_enable;
	bool last_cs_mode_high;
	bool fallback;
	struct completion xfer_completion;
	size_t max_dma_len;
	int (*prepare_transfer_hardware)(struct spi_controller___2 *);
	int (*transfer_one_message)(struct spi_controller___2 *, struct spi_message___2 *);
	int (*unprepare_transfer_hardware)(struct spi_controller___2 *);
	int (*prepare_message)(struct spi_controller___2 *, struct spi_message___2 *);
	int (*unprepare_message)(struct spi_controller___2 *, struct spi_message___2 *);
	int (*slave_abort)(struct spi_controller___2 *);
	void (*set_cs)(struct spi_device___2 *, bool);
	int (*transfer_one)(struct spi_controller___2 *, struct spi_device___2 *, struct spi_transfer *);
	void (*handle_err)(struct spi_controller___2 *, struct spi_message___2 *);
	const struct spi_controller_mem_ops *mem_ops;
	int *cs_gpios;
	struct gpio_desc **cs_gpiods;
	bool use_gpio_descriptors;
	s8 unused_native_cs;
	s8 max_native_cs;
	struct spi_statistics statistics;
	struct dma_chan___6 *dma_tx;
	struct dma_chan___6 *dma_rx;
	void *dummy_rx;
	void *dummy_tx;
	int (*fw_translate_cs)(struct spi_controller___2 *, unsigned int);
	bool ptp_sts_supported;
	long unsigned int irq_flags;
};

struct spi_message___2 {
	struct list_head transfers;
	struct spi_device___2 *spi;
	unsigned int is_dma_mapped: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	void (*complete)(void *);
	void *context;
	unsigned int frame_length;
	unsigned int actual_length;
	int status;
	struct list_head queue;
	void *state;
	struct list_head resources;
};

struct regmap_format___4 {
	size_t buf_size;
	size_t reg_bytes;
	size_t pad_bytes;
	size_t val_bytes;
	void (*format_write)(struct regmap___5 *, unsigned int, unsigned int);
	void (*format_reg)(void *, unsigned int, unsigned int);
	void (*format_val)(void *, unsigned int, unsigned int);
	unsigned int (*parse_val)(const void *);
	void (*parse_inplace)(void *);
};

struct regcache_ops___4;

struct regmap___5 {
	union {
		struct mutex mutex;
		struct {
			spinlock_t spinlock;
			long unsigned int spinlock_flags;
		};
		struct {
			raw_spinlock_t raw_spinlock;
			long unsigned int raw_spinlock_flags;
		};
	};
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	gfp_t alloc_flags;
	struct device___190 *dev;
	void *work_buf;
	struct regmap_format___4 format;
	const struct regmap_bus___4 *bus;
	void *bus_context;
	const char *name;
	bool async;
	spinlock_t async_lock;
	wait_queue_head_t async_waitq;
	struct list_head async_list;
	struct list_head async_free;
	int async_ret;
	bool debugfs_disable;
	struct dentry___212 *debugfs;
	const char *debugfs_name;
	unsigned int debugfs_reg_len;
	unsigned int debugfs_val_len;
	unsigned int debugfs_tot_len;
	struct list_head debugfs_off_cache;
	struct mutex cache_lock;
	unsigned int max_register;
	bool (*writeable_reg)(struct device___190 *, unsigned int);
	bool (*readable_reg)(struct device___190 *, unsigned int);
	bool (*volatile_reg)(struct device___190 *, unsigned int);
	bool (*precious_reg)(struct device___190 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___190 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___190 *, unsigned int);
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	int (*reg_update_bits)(void *, unsigned int, unsigned int, unsigned int);
	bool defer_caching;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	int reg_shift;
	int reg_stride;
	int reg_stride_order;
	const struct regcache_ops___4 *cache_ops;
	enum regcache_type cache_type;
	unsigned int cache_size_raw;
	unsigned int cache_word_size;
	unsigned int num_reg_defaults;
	unsigned int num_reg_defaults_raw;
	bool cache_only;
	bool cache_bypass;
	bool cache_free;
	struct reg_default *reg_defaults;
	const void *reg_defaults_raw;
	void *cache;
	bool cache_dirty;
	bool no_sync_defaults;
	struct reg_sequence *patch;
	int patch_regs;
	bool use_single_read;
	bool use_single_write;
	bool can_multi_write;
	size_t max_raw_read;
	size_t max_raw_write;
	struct rb_root range_tree;
	void *selector_work_buf;
	struct hwspinlock *hwlock;
	bool can_sleep;
};

struct regcache_ops___4 {
	const char *name;
	enum regcache_type type;
	int (*init)(struct regmap___5 *);
	int (*exit)(struct regmap___5 *);
	void (*debugfs_init)(struct regmap___5 *);
	int (*read)(struct regmap___5 *, unsigned int, unsigned int *);
	int (*write)(struct regmap___5 *, unsigned int, unsigned int);
	int (*sync)(struct regmap___5 *, unsigned int, unsigned int);
	int (*drop)(struct regmap___5 *, unsigned int, unsigned int);
};

struct regmap_async_spi {
	struct regmap_async___4 core;
	struct spi_message___2 m;
	struct spi_transfer t[2];
};

struct regmap_mmio_context {
	void *regs;
	unsigned int val_bytes;
	bool relaxed_mmio;
	bool attached_clk;
	struct clk *clk;
	void (*reg_write)(struct regmap_mmio_context *, unsigned int, unsigned int);
	unsigned int (*reg_read)(struct regmap_mmio_context *, unsigned int);
};

typedef void (*dr_release_t___25)(struct device___190 *, void *);

typedef int (*dr_match_t___21)(struct device___190 *, void *, void *);

struct regmap_irq_type {
	unsigned int type_reg_offset;
	unsigned int type_reg_mask;
	unsigned int type_rising_val;
	unsigned int type_falling_val;
	unsigned int type_level_low_val;
	unsigned int type_level_high_val;
	unsigned int types_supported;
};

struct regmap_irq {
	unsigned int reg_offset;
	unsigned int mask;
	struct regmap_irq_type type;
};

struct regmap_irq_sub_irq_map {
	unsigned int num_regs;
	unsigned int *offset;
};

struct regmap_irq_chip {
	const char *name;
	unsigned int main_status;
	unsigned int num_main_status_bits;
	struct regmap_irq_sub_irq_map *sub_reg_offsets;
	int num_main_regs;
	unsigned int status_base;
	unsigned int mask_base;
	unsigned int unmask_base;
	unsigned int ack_base;
	unsigned int wake_base;
	unsigned int type_base;
	unsigned int *virt_reg_base;
	unsigned int irq_reg_stride;
	bool mask_writeonly: 1;
	bool init_ack_masked: 1;
	bool mask_invert: 1;
	bool use_ack: 1;
	bool ack_invert: 1;
	bool clear_ack: 1;
	bool wake_invert: 1;
	bool runtime_pm: 1;
	bool type_invert: 1;
	bool type_in_mask: 1;
	bool clear_on_unmask: 1;
	bool not_fixed_stride: 1;
	bool status_invert: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int num_regs;
	const struct regmap_irq *irqs;
	int num_irqs;
	int num_type_reg;
	int num_virt_regs;
	unsigned int type_reg_stride;
	int (*handle_pre_irq)(void *);
	int (*handle_post_irq)(void *);
	int (*set_type_virt)(unsigned int **, unsigned int, long unsigned int, int);
	void *irq_drv_data;
};

struct regmap_irq_chip_data___2 {
	struct mutex lock;
	struct irq_chip___51 irq_chip;
	struct regmap___5 *map;
	const struct regmap_irq_chip *chip;
	int irq_base;
	struct irq_domain___49 *domain;
	int irq;
	int wake_count;
	void *status_reg_buf;
	unsigned int *main_status_buf;
	unsigned int *status_buf;
	unsigned int *mask_buf;
	unsigned int *mask_buf_def;
	unsigned int *wake_buf;
	unsigned int *type_buf;
	unsigned int *type_buf_def;
	unsigned int **virt_buf;
	unsigned int irq_reg_stride;
	unsigned int type_reg_stride;
	bool clear_status;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct soc_device___2 {
	struct device___186 dev;
	struct soc_device_attribute___2 *attr;
	int soc_dev_num;
};

struct class_attribute___3 {
	struct attribute attr;
	ssize_t (*show)(struct class___190 *, struct class_attribute___3 *, char *);
	ssize_t (*store)(struct class___190 *, struct class_attribute___3 *, const char *, size_t);
};

struct devcd_entry {
	struct device___190 devcd_dev;
	void *data;
	size_t datalen;
	struct module___196 *owner;
	ssize_t (*read)(char *, loff_t, size_t, void *, size_t);
	void (*free)(void *);
	struct delayed_work del_wk;
	struct device___190 *failing_dev;
};

typedef void (*irq_write_msi_msg_t___4)(struct msi_desc___9 *, struct msi_msg *);

struct platform_msi_priv_data {
	struct device___139 *dev;
	void *host_data;
	const struct attribute_group___41 **msi_irq_groups;
	msi_alloc_info_t___5 arg;
	irq_write_msi_msg_t___4 write_msg;
	int devid;
};

struct cpu___4 {
	int node_id;
	int hotpluggable;
	struct device___154 dev;
};

struct cpufreq_governor___4;

struct cpufreq_policy___4 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___4 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___183 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___202 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___3 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___4 {
	char name[16];
	int (*init)(struct cpufreq_policy___4 *);
	void (*exit)(struct cpufreq_policy___4 *);
	int (*start)(struct cpufreq_policy___4 *);
	void (*stop)(struct cpufreq_policy___4 *);
	void (*limits)(struct cpufreq_policy___4 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___4 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___4 *, unsigned int);
	struct list_head governor_list;
	struct module___179 *owner;
	u8 flags;
};

struct pglist_data___100;

struct lruvec___100 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___100 *pgdat;
};

struct zone___100 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___100 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___100 {
	struct zone___100 *zone;
	int zone_idx;
};

struct zonelist___100 {
	struct zoneref___100 _zonerefs[321];
};

struct pglist_data___100 {
	struct zone___100 node_zones[5];
	struct zonelist___100 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___175 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___175 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___100 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

typedef struct pglist_data___100 pg_data_t___17;

struct trace_event_raw_devres {
	struct trace_entry ent;
	u32 __data_loc_devname;
	struct device___184 *dev;
	const char *op;
	void *node;
	const char *name;
	size_t size;
	char __data[0];
};

struct trace_event_data_offsets_devres {
	u32 devname;
};

typedef void (*btf_trace_devres_log)(void *, struct device___184 *, const char *, void *, const char *, size_t);

typedef unsigned int __kernel_old_dev_t;

struct device_attribute___24 {
	struct attribute attr;
	ssize_t (*show)(struct device___141 *, struct device_attribute___24 *, char *);
	ssize_t (*store)(struct device___141 *, struct device_attribute___24 *, const char *, size_t);
};

struct req_iterator___3 {
	struct bvec_iter iter;
	struct bio___91 *bio;
};

enum {
	LO_FLAGS_READ_ONLY = 1,
	LO_FLAGS_AUTOCLEAR = 4,
	LO_FLAGS_PARTSCAN = 8,
	LO_FLAGS_DIRECT_IO = 16,
};

struct loop_info {
	int lo_number;
	__kernel_old_dev_t lo_device;
	long unsigned int lo_inode;
	__kernel_old_dev_t lo_rdevice;
	int lo_offset;
	int lo_encrypt_type;
	int lo_encrypt_key_size;
	int lo_flags;
	char lo_name[64];
	unsigned char lo_encrypt_key[32];
	long unsigned int lo_init[2];
	char reserved[4];
};

struct loop_info64 {
	__u64 lo_device;
	__u64 lo_inode;
	__u64 lo_rdevice;
	__u64 lo_offset;
	__u64 lo_sizelimit;
	__u32 lo_number;
	__u32 lo_encrypt_type;
	__u32 lo_encrypt_key_size;
	__u32 lo_flags;
	__u8 lo_file_name[64];
	__u8 lo_crypt_name[64];
	__u8 lo_encrypt_key[32];
	__u64 lo_init[2];
};

struct loop_config {
	__u32 fd;
	__u32 block_size;
	struct loop_info64 info;
	__u64 __reserved[8];
};

enum {
	Lo_unbound = 0,
	Lo_bound = 1,
	Lo_rundown = 2,
	Lo_deleting = 3,
};

struct loop_func_table;

struct loop_device {
	int lo_number;
	atomic_t lo_refcnt;
	loff_t lo_offset;
	loff_t lo_sizelimit;
	int lo_flags;
	int (*transfer)(struct loop_device *, int, struct page___190 *, unsigned int, struct page___190 *, unsigned int, int, sector_t);
	char lo_file_name[64];
	char lo_crypt_name[64];
	char lo_encrypt_key[32];
	int lo_encrypt_key_size;
	struct loop_func_table *lo_encryption;
	__u32 lo_init[2];
	kuid_t lo_key_owner;
	int (*ioctl)(struct loop_device *, int, long unsigned int);
	struct file___185 *lo_backing_file;
	struct file___185 *lo_backing_virt_file;
	struct block_device___92 *lo_device;
	void *key_data;
	gfp_t old_gfp_mask;
	spinlock_t lo_lock;
	int lo_state;
	spinlock_t lo_work_lock;
	struct workqueue_struct *workqueue;
	struct work_struct rootcg_work;
	struct list_head rootcg_cmd_list;
	struct list_head idle_worker_list;
	struct rb_root worker_tree;
	struct timer_list timer;
	bool use_dio;
	bool sysfs_inited;
	struct request_queue___91 *lo_queue;
	struct blk_mq_tag_set___88 tag_set;
	struct gendisk___92 *lo_disk;
	struct mutex lo_mutex;
	bool idr_visible;
};

struct loop_func_table {
	int number;
	int (*transfer)(struct loop_device *, int, struct page___190 *, unsigned int, struct page___190 *, unsigned int, int, sector_t);
	int (*init)(struct loop_device *, const struct loop_info64 *);
	int (*release)(struct loop_device *);
	int (*ioctl)(struct loop_device *, int, long unsigned int);
	struct module___169 *owner;
};

struct loop_cmd {
	struct list_head list_entry;
	bool use_aio;
	atomic_t ref;
	long int ret;
	struct kiocb___185 iocb;
	struct bio_vec___107 *bvec;
	struct cgroup_subsys_state___125 *blkcg_css;
	struct cgroup_subsys_state___125 *memcg_css;
};

struct loop_worker {
	struct rb_node rb_node;
	struct work_struct work;
	struct list_head cmd_list;
	struct list_head idle_list;
	struct loop_device *lo;
	struct cgroup_subsys_state___125 *blkcg_css;
	long unsigned int last_ran_at;
};

struct compat_loop_info {
	compat_int_t lo_number;
	compat_dev_t lo_device;
	compat_ulong_t lo_inode;
	compat_dev_t lo_rdevice;
	compat_int_t lo_offset;
	compat_int_t lo_encrypt_type;
	compat_int_t lo_encrypt_key_size;
	compat_int_t lo_flags;
	char lo_name[64];
	unsigned char lo_encrypt_key[32];
	compat_ulong_t lo_init[2];
	char reserved[4];
};

struct cdrom_device_ops;

struct cdrom_device_info {
	const struct cdrom_device_ops *ops;
	struct list_head list;
	struct gendisk___111 *disk;
	void *handle;
	int mask;
	int speed;
	int capacity;
	unsigned int options: 30;
	unsigned int mc_flags: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int vfs_events;
	unsigned int ioctl_events;
	int use_count;
	char name[20];
	__u8 sanyo_slot: 2;
	__u8 keeplocked: 1;
	__u8 reserved: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int cdda_method;
	__u8 last_sense;
	__u8 media_written;
	short unsigned int mmc3_profile;
	int for_data;
	int (*exit)(struct cdrom_device_info *);
	int mrw_mode_page;
};

struct scsi_sense_hdr {
	u8 response_code;
	u8 sense_key;
	u8 asc;
	u8 ascq;
	u8 byte4;
	u8 byte5;
	u8 byte6;
	u8 additional_length;
};

struct cdrom_msf0 {
	__u8 minute;
	__u8 second;
	__u8 frame;
};

union cdrom_addr {
	struct cdrom_msf0 msf;
	int lba;
};

struct cdrom_multisession {
	union cdrom_addr addr;
	__u8 xa_flag;
	__u8 addr_format;
};

struct cdrom_mcn {
	__u8 medium_catalog_number[14];
};

struct packet_command {
	unsigned char cmd[12];
	unsigned char *buffer;
	unsigned int buflen;
	int stat;
	struct scsi_sense_hdr *sshdr;
	unsigned char data_direction;
	int quiet;
	int timeout;
	void *reserved[1];
};

struct cdrom_device_ops {
	int (*open)(struct cdrom_device_info *, int);
	void (*release)(struct cdrom_device_info *);
	int (*drive_status)(struct cdrom_device_info *, int);
	unsigned int (*check_events)(struct cdrom_device_info *, unsigned int, int);
	int (*tray_move)(struct cdrom_device_info *, int);
	int (*lock_door)(struct cdrom_device_info *, int);
	int (*select_speed)(struct cdrom_device_info *, int);
	int (*select_disc)(struct cdrom_device_info *, int);
	int (*get_last_session)(struct cdrom_device_info *, struct cdrom_multisession *);
	int (*get_mcn)(struct cdrom_device_info *, struct cdrom_mcn *);
	int (*reset)(struct cdrom_device_info *);
	int (*audio_ioctl)(struct cdrom_device_info *, unsigned int, void *);
	int (*generic_packet)(struct cdrom_device_info *, struct packet_command *);
	int (*read_cdda_bpc)(struct cdrom_device_info *, void *, u32, u32, u8 *);
	const int capability;
};

struct xenbus_device___3 {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___188 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
	struct semaphore reclaim_sem;
	atomic_t event_channels;
	atomic_t events;
	atomic_t spurious_events;
	atomic_t jiffies_eoi_delayed;
	unsigned int spurious_threshold;
};

struct xenbus_driver___3 {
	const char *name;
	const struct xenbus_device_id *ids;
	bool allow_rebind;
	int (*probe)(struct xenbus_device___3 *, const struct xenbus_device_id *);
	void (*otherend_changed)(struct xenbus_device___3 *, enum xenbus_state);
	int (*remove)(struct xenbus_device___3 *);
	int (*suspend)(struct xenbus_device___3 *);
	int (*resume)(struct xenbus_device___3 *);
	int (*uevent)(struct xenbus_device___3 *, struct kobj_uevent_env *);
	struct device_driver___188 driver;
	int (*read_otherend_details)(struct xenbus_device___3 *);
	int (*is_ready)(struct xenbus_device___3 *);
	void (*reclaim_memory)(struct xenbus_device___3 *);
};

typedef unsigned int RING_IDX;

typedef uint16_t blkif_vdev_t;

typedef uint64_t blkif_sector_t;

struct blkif_request_segment {
	grant_ref_t gref;
	uint8_t first_sect;
	uint8_t last_sect;
};

struct blkif_request_rw {
	uint8_t nr_segments;
	blkif_vdev_t handle;
	uint32_t _pad1;
	uint64_t id;
	blkif_sector_t sector_number;
	struct blkif_request_segment seg[11];
} __attribute__((packed));

struct blkif_request_discard {
	uint8_t flag;
	blkif_vdev_t _pad1;
	uint32_t _pad2;
	uint64_t id;
	blkif_sector_t sector_number;
	uint64_t nr_sectors;
	uint8_t _pad3;
} __attribute__((packed));

struct blkif_request_other {
	uint8_t _pad1;
	blkif_vdev_t _pad2;
	uint32_t _pad3;
	uint64_t id;
} __attribute__((packed));

struct blkif_request_indirect {
	uint8_t indirect_op;
	uint16_t nr_segments;
	uint32_t _pad1;
	uint64_t id;
	blkif_sector_t sector_number;
	blkif_vdev_t handle;
	uint16_t _pad2;
	grant_ref_t indirect_grefs[8];
	uint32_t _pad3;
} __attribute__((packed));

struct blkif_request {
	uint8_t operation;
	union {
		struct blkif_request_rw rw;
		struct blkif_request_discard discard;
		struct blkif_request_other other;
		struct blkif_request_indirect indirect;
	} u;
} __attribute__((packed));

struct blkif_response {
	uint64_t id;
	uint8_t operation;
	int16_t status;
};

union blkif_sring_entry {
	struct blkif_request req;
	struct blkif_response rsp;
};

struct blkif_sring {
	RING_IDX req_prod;
	RING_IDX req_event;
	RING_IDX rsp_prod;
	RING_IDX rsp_event;
	uint8_t __pad[48];
	union blkif_sring_entry ring[1];
};

struct blkif_front_ring {
	RING_IDX req_prod_pvt;
	RING_IDX rsp_cons;
	unsigned int nr_ents;
	struct blkif_sring *sring;
};

enum blkif_state {
	BLKIF_STATE_DISCONNECTED = 0,
	BLKIF_STATE_CONNECTED = 1,
	BLKIF_STATE_SUSPENDED = 2,
	BLKIF_STATE_ERROR = 3,
};

struct grant {
	grant_ref_t gref;
	struct page___216 *page;
	struct list_head node;
};

enum blk_req_status {
	REQ_PROCESSING = 0,
	REQ_WAITING = 1,
	REQ_DONE = 2,
	REQ_ERROR = 3,
	REQ_EOPNOTSUPP = 4,
};

struct blk_shadow {
	struct blkif_request req;
	struct request___108 *request;
	struct grant **grants_used;
	struct grant **indirect_grants;
	struct scatterlist *sg;
	unsigned int num_sg;
	enum blk_req_status status;
	long unsigned int associated_id;
};

struct blkif_req {
	blk_status_t error;
};

struct blkfront_info;

struct blkfront_ring_info {
	spinlock_t ring_lock;
	struct blkif_front_ring ring;
	unsigned int ring_ref[16];
	unsigned int evtchn;
	unsigned int irq;
	struct work_struct work;
	struct gnttab_free_callback callback;
	struct list_head indirect_pages;
	struct list_head grants;
	unsigned int persistent_gnts_c;
	long unsigned int shadow_free;
	struct blkfront_info *dev_info;
	struct blk_shadow shadow[0];
};

struct blkfront_info {
	struct mutex mutex;
	struct xenbus_device___3 *xbdev;
	struct gendisk___111 *gd;
	u16 sector_size;
	unsigned int physical_sector_size;
	int vdevice;
	blkif_vdev_t handle;
	enum blkif_state connected;
	unsigned int nr_ring_pages;
	struct request_queue___108 *rq;
	unsigned int feature_flush: 1;
	unsigned int feature_fua: 1;
	unsigned int feature_discard: 1;
	unsigned int feature_secdiscard: 1;
	unsigned int feature_persistent: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int discard_granularity;
	unsigned int discard_alignment;
	unsigned int max_indirect_segments;
	int is_ready;
	struct blk_mq_tag_set___105 tag_set;
	struct blkfront_ring_info *rinfo;
	unsigned int nr_rings;
	unsigned int rinfo_size;
	struct list_head requests;
	struct bio_list___108 bio_list;
	struct list_head info_list;
};

struct setup_rw_req {
	unsigned int grant_idx;
	struct blkif_request_segment *segments;
	struct blkfront_ring_info *rinfo;
	struct blkif_request *ring_req;
	grant_ref_t gref_head;
	unsigned int id;
	bool need_copy;
	unsigned int bvec_off;
	char *bvec_data;
	bool require_extra_req;
	struct blkif_request *extra_ring_req;
};

struct copy_from_grant {
	const struct blk_shadow *s;
	unsigned int grant_idx;
	unsigned int bvec_offset;
	char *bvec_data;
};

struct sram_config {
	int (*init)();
	bool map_only_reserved;
};

struct sram_partition {
	void *base;
	struct gen_pool *pool;
	struct bin_attribute___42 battr;
	struct mutex lock;
	struct list_head list;
};

struct sram_dev {
	const struct sram_config *config;
	struct device___189 *dev;
	void *virt_base;
	bool no_memory_wc;
	struct gen_pool *pool;
	struct clk *clk;
	struct sram_partition *partition;
	u32 partitions;
};

struct sram_reserve {
	struct list_head list;
	u32 start;
	u32 size;
	struct resource res;
	bool export;
	bool pool;
	bool protect_exec;
	const char *label;
};

struct i2c_board_info___2;

struct i2c_driver___2 {
	unsigned int class;
	int (*probe)(struct i2c_client___3 *, const struct i2c_device_id *);
	int (*remove)(struct i2c_client___3 *);
	int (*probe_new)(struct i2c_client___3 *);
	void (*shutdown)(struct i2c_client___3 *);
	void (*alert)(struct i2c_client___3 *, enum i2c_alert_protocol, unsigned int);
	int (*command)(struct i2c_client___3 *, unsigned int, void *);
	struct device_driver___154 driver;
	const struct i2c_device_id *id_table;
	int (*detect)(struct i2c_client___3 *, struct i2c_board_info___2 *);
	const short unsigned int *address_list;
	struct list_head clients;
};

struct i2c_board_info___2 {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	const char *dev_name;
	void *platform_data;
	struct device_node___57 *of_node;
	struct fwnode_handle___154 *fwnode;
	const struct software_node *swnode;
	const struct resource *resources;
	unsigned int num_resources;
	int irq;
};

struct mfd_cell_acpi_match;

struct mfd_cell {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___24 *);
	int (*disable)(struct platform_device___24 *);
	int (*suspend)(struct platform_device___24 *);
	int (*resume)(struct platform_device___24 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

struct regmap_config___11 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___154 *, unsigned int);
	bool (*readable_reg)(struct device___154 *, unsigned int);
	bool (*volatile_reg)(struct device___154 *, unsigned int);
	bool (*precious_reg)(struct device___154 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___154 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___154 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct mfd_cell_acpi_match {
	const char *pnpid;
	const long long unsigned int adr;
};

enum {
	CHIP_INVALID = 0,
	CHIP_PM8606 = 1,
	CHIP_PM8607 = 2,
	CHIP_MAX = 3,
};

enum pm8606_ref_gp_and_osc_clients {
	REF_GP_NO_CLIENTS = 0,
	WLED1_DUTY = 1,
	WLED2_DUTY = 2,
	WLED3_DUTY = 4,
	RGB1_ENABLE = 8,
	RGB2_ENABLE = 16,
	LDO_VBR_EN = 32,
	REF_GP_MAX_CLIENT = 65535,
};

enum {
	PM8607_IRQ_ONKEY = 0,
	PM8607_IRQ_EXTON = 1,
	PM8607_IRQ_CHG = 2,
	PM8607_IRQ_BAT = 3,
	PM8607_IRQ_RTC = 4,
	PM8607_IRQ_CC = 5,
	PM8607_IRQ_VBAT = 6,
	PM8607_IRQ_VCHG = 7,
	PM8607_IRQ_VSYS = 8,
	PM8607_IRQ_TINT = 9,
	PM8607_IRQ_GPADC0 = 10,
	PM8607_IRQ_GPADC1 = 11,
	PM8607_IRQ_GPADC2 = 12,
	PM8607_IRQ_GPADC3 = 13,
	PM8607_IRQ_AUDIO_SHORT = 14,
	PM8607_IRQ_PEN = 15,
	PM8607_IRQ_HEADSET = 16,
	PM8607_IRQ_HOOK = 17,
	PM8607_IRQ_MICIN = 18,
	PM8607_IRQ_CHG_FAIL = 19,
	PM8607_IRQ_CHG_DONE = 20,
	PM8607_IRQ_CHG_FAULT = 21,
};

struct pm860x_chip {
	struct device___154 *dev;
	struct mutex irq_lock;
	struct mutex osc_lock;
	struct i2c_client___3 *client;
	struct i2c_client___3 *companion;
	struct regmap *regmap;
	struct regmap *regmap_companion;
	int buck3_double;
	int companion_addr;
	short unsigned int osc_vote;
	int id;
	int irq_mode;
	int irq_base;
	int core_irq;
	unsigned char chip_version;
	unsigned char osc_status;
	unsigned int wakeup_flag;
};

enum {
	GI2C_PORT = 0,
	PI2C_PORT = 1,
};

struct pm860x_backlight_pdata {
	int pwm;
	int iset;
};

struct pm860x_led_pdata {
	int iset;
};

struct pm860x_rtc_pdata {
	int (*sync)(unsigned int);
	int vrtc;
};

struct pm860x_touch_pdata {
	int gpadc_prebias;
	int slot_cycle;
	int off_scale;
	int sw_cal;
	int tsi_prebias;
	int pen_prebias;
	int pen_prechg;
	int res_x;
	long unsigned int flags;
};

struct pm860x_power_pdata {
	int max_capacity;
	int resistor;
};

struct charger_desc;

struct pm860x_platform_data {
	struct pm860x_backlight_pdata *backlight;
	struct pm860x_led_pdata *led;
	struct pm860x_rtc_pdata *rtc;
	struct pm860x_touch_pdata *touch;
	struct pm860x_power_pdata *power;
	struct regulator_init_data___2 *buck1;
	struct regulator_init_data___2 *buck2;
	struct regulator_init_data___2 *buck3;
	struct regulator_init_data___2 *ldo1;
	struct regulator_init_data___2 *ldo2;
	struct regulator_init_data___2 *ldo3;
	struct regulator_init_data___2 *ldo4;
	struct regulator_init_data___2 *ldo5;
	struct regulator_init_data___2 *ldo6;
	struct regulator_init_data___2 *ldo7;
	struct regulator_init_data___2 *ldo8;
	struct regulator_init_data___2 *ldo9;
	struct regulator_init_data___2 *ldo10;
	struct regulator_init_data___2 *ldo12;
	struct regulator_init_data___2 *ldo_vibrator;
	struct regulator_init_data___2 *ldo14;
	struct charger_desc *chg_desc;
	int companion_addr;
	int i2c_port;
	int irq_mode;
	int irq_base;
	int num_leds;
	int num_backlights;
};

enum polling_modes {
	CM_POLL_DISABLE = 0,
	CM_POLL_ALWAYS = 1,
	CM_POLL_EXTERNAL_POWER_ONLY = 2,
	CM_POLL_CHARGING_ONLY = 3,
};

enum data_source {
	CM_BATTERY_PRESENT = 0,
	CM_NO_BATTERY = 1,
	CM_FUEL_GAUGE = 2,
	CM_CHARGER_STAT = 3,
};

struct charger_regulator;

struct charger_desc {
	const char *psy_name;
	enum polling_modes polling_mode;
	unsigned int polling_interval_ms;
	unsigned int fullbatt_vchkdrop_uV;
	unsigned int fullbatt_uV;
	unsigned int fullbatt_soc;
	unsigned int fullbatt_full_capacity;
	enum data_source battery_present;
	const char **psy_charger_stat;
	int num_charger_regulators;
	struct charger_regulator *charger_regulators;
	const struct attribute_group___183 **sysfs_groups;
	const char *psy_fuel_gauge;
	const char *thermal_zone;
	int temp_min;
	int temp_max;
	int temp_diff;
	bool measure_battery_temp;
	u32 charging_max_duration_ms;
	u32 discharging_max_duration_ms;
};

struct charger_manager;

struct charger_cable {
	const char *extcon_name;
	const char *name;
	struct extcon_dev *extcon_dev;
	u64 extcon_type;
	struct work_struct wq;
	struct notifier_block nb;
	bool attached;
	struct charger_regulator *charger;
	int min_uA;
	int max_uA;
	struct charger_manager *cm;
};

struct charger_regulator {
	const char *regulator_name;
	struct regulator *consumer;
	int externally_control;
	struct charger_cable *cables;
	int num_cables;
	struct attribute_group___183 attr_grp;
	struct device_attribute___17 attr_name;
	struct device_attribute___17 attr_state;
	struct device_attribute___17 attr_externally_control;
	struct attribute *attrs[4];
	struct charger_manager *cm;
};

struct charger_manager {
	struct list_head entry;
	struct device___154 *dev;
	struct charger_desc *desc;
	struct thermal_zone_device *tzd_batt;
	bool charger_enabled;
	int emergency_stop;
	char psy_name_buf[31];
	struct power_supply_desc charger_psy_desc;
	struct power_supply *charger_psy;
	u64 charging_start_time;
	u64 charging_end_time;
	int battery_status;
};

struct pm860x_irq_data {
	int reg;
	int mask_reg;
	int enable;
	int offs;
};

struct pm860x_chip___2 {
	struct device___166 *dev;
	struct mutex irq_lock;
	struct mutex osc_lock;
	struct i2c_client___2 *client;
	struct i2c_client___2 *companion;
	struct regmap *regmap;
	struct regmap *regmap_companion;
	int buck3_double;
	int companion_addr;
	short unsigned int osc_vote;
	int id;
	int irq_mode;
	int irq_base;
	int core_irq;
	unsigned char chip_version;
	unsigned char osc_status;
	unsigned int wakeup_flag;
};

struct bcm2835_pm___2 {
	struct device___190 *dev;
	void *base;
	void *asb;
};

struct mfd_cell___2;

struct platform_device___28 {
	const char *name;
	int id;
	bool id_auto;
	struct device___190 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell___2 *mfd_cell;
	struct pdev_archdata archdata;
};

struct mfd_cell___2 {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___28 *);
	int (*disable)(struct platform_device___28 *);
	int (*suspend)(struct platform_device___28 *);
	int (*resume)(struct platform_device___28 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

struct platform_driver___26 {
	int (*probe)(struct platform_device___28 *);
	int (*remove)(struct platform_device___28 *);
	void (*shutdown)(struct platform_device___28 *);
	int (*suspend)(struct platform_device___28 *, pm_message_t);
	int (*resume)(struct platform_device___28 *);
	struct device_driver___190 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct htcpld_chip_platform_data {
	unsigned int addr;
	unsigned int reset;
	unsigned int num_gpios;
	unsigned int gpio_out_base;
	unsigned int gpio_in_base;
	unsigned int irq_base;
	unsigned int num_irqs;
};

struct htcpld_core_platform_data {
	unsigned int int_reset_gpio_hi;
	unsigned int int_reset_gpio_lo;
	unsigned int i2c_adapter_id;
	struct htcpld_chip_platform_data *chip;
	unsigned int num_chip;
};

struct htcpld_chip {
	spinlock_t lock;
	u8 reset;
	u8 addr;
	struct device___154 *dev;
	struct i2c_client___3 *client;
	u8 cache_out;
	struct gpio_chip___9 chip_out;
	u8 cache_in;
	struct gpio_chip___9 chip_in;
	u16 irqs_enabled;
	uint irq_start;
	int nirqs;
	unsigned int flow_type;
	struct work_struct set_val_work;
};

struct htcpld_data {
	u16 irqs_enabled;
	uint irq_start;
	int nirqs;
	uint chained_irq;
	unsigned int int_reset_gpio_hi;
	unsigned int int_reset_gpio_lo;
	struct htcpld_chip *chip;
	unsigned int nchips;
};

struct mfd_cell___3;

struct platform_device___29 {
	const char *name;
	int id;
	bool id_auto;
	struct device___166 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell___3 *mfd_cell;
	struct pdev_archdata archdata;
};

struct mfd_cell___3 {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___29 *);
	int (*disable)(struct platform_device___29 *);
	int (*suspend)(struct platform_device___29 *);
	int (*resume)(struct platform_device___29 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

struct stmpe_client_info___2;

struct stmpe_variant_info___2;

struct stmpe___3 {
	struct regulator *vcc;
	struct regulator *vio;
	struct mutex lock;
	struct mutex irq_lock;
	struct device___166 *dev;
	struct irq_domain___41 *domain;
	void *client;
	struct stmpe_client_info___2 *ci;
	enum stmpe_partnum partnum;
	struct stmpe_variant_info___2 *variant;
	const u8 *regs;
	int irq;
	int num_gpios;
	u8 ier[2];
	u8 oldier[2];
	struct stmpe_platform_data *pdata;
	u8 sample_time;
	u8 mod_12b;
	u8 ref_sel;
	u8 adc_freq;
};

struct stmpe_client_info___2 {
	void *data;
	int irq;
	void *client;
	struct device___166 *dev;
	int (*read_byte)(struct stmpe___3 *, u8);
	int (*write_byte)(struct stmpe___3 *, u8, u8);
	int (*read_block)(struct stmpe___3 *, u8, u8, u8 *);
	int (*write_block)(struct stmpe___3 *, u8, u8, const u8 *);
	void (*init)(struct stmpe___3 *);
};

struct stmpe_variant_block;

struct stmpe_variant_info___2 {
	const char *name;
	u16 id_val;
	u16 id_mask;
	int num_gpios;
	int af_bits;
	const u8 *regs;
	struct stmpe_variant_block *blocks;
	int num_blocks;
	int num_irqs;
	int (*enable)(struct stmpe___3 *, unsigned int, bool);
	int (*get_altfunc)(struct stmpe___3 *, enum stmpe_block);
	int (*enable_autosleep)(struct stmpe___3 *, int);
};

struct stmpe_platform_data {
	int id;
	unsigned int blocks;
	unsigned int irq_trigger;
	bool autosleep;
	bool irq_over_gpio;
	int irq_gpio;
	int autosleep_timeout;
};

struct stmpe_variant_block {
	const struct mfd_cell___3 *cell;
	int irq;
	enum stmpe_block block;
};

struct mfd_cell___4;

struct platform_device___30 {
	const char *name;
	int id;
	bool id_auto;
	struct device___163 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell___4 *mfd_cell;
	struct pdev_archdata archdata;
};

struct mfd_cell___4 {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___30 *);
	int (*disable)(struct platform_device___30 *);
	int (*suspend)(struct platform_device___30 *);
	int (*resume)(struct platform_device___30 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

struct stmpe_client_info___3;

struct stmpe_variant_info___3;

struct stmpe___4 {
	struct regulator *vcc;
	struct regulator *vio;
	struct mutex lock;
	struct mutex irq_lock;
	struct device___163 *dev;
	struct irq_domain___40 *domain;
	void *client;
	struct stmpe_client_info___3 *ci;
	enum stmpe_partnum partnum;
	struct stmpe_variant_info___3 *variant;
	const u8 *regs;
	int irq;
	int num_gpios;
	u8 ier[2];
	u8 oldier[2];
	struct stmpe_platform_data *pdata;
	u8 sample_time;
	u8 mod_12b;
	u8 ref_sel;
	u8 adc_freq;
};

struct stmpe_client_info___3 {
	void *data;
	int irq;
	void *client;
	struct device___163 *dev;
	int (*read_byte)(struct stmpe___4 *, u8);
	int (*write_byte)(struct stmpe___4 *, u8, u8);
	int (*read_block)(struct stmpe___4 *, u8, u8, u8 *);
	int (*write_block)(struct stmpe___4 *, u8, u8, const u8 *);
	void (*init)(struct stmpe___4 *);
};

struct stmpe_variant_block___2;

struct stmpe_variant_info___3 {
	const char *name;
	u16 id_val;
	u16 id_mask;
	int num_gpios;
	int af_bits;
	const u8 *regs;
	struct stmpe_variant_block___2 *blocks;
	int num_blocks;
	int num_irqs;
	int (*enable)(struct stmpe___4 *, unsigned int, bool);
	int (*get_altfunc)(struct stmpe___4 *, enum stmpe_block);
	int (*enable_autosleep)(struct stmpe___4 *, int);
};

struct stmpe_variant_block___2 {
	const struct mfd_cell___4 *cell;
	int irq;
	enum stmpe_block block;
};

struct mfd_cell___5;

struct platform_device___31 {
	const char *name;
	int id;
	bool id_auto;
	struct device___160 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell___5 *mfd_cell;
	struct pdev_archdata archdata;
};

struct mfd_cell___5 {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___31 *);
	int (*disable)(struct platform_device___31 *);
	int (*suspend)(struct platform_device___31 *);
	int (*resume)(struct platform_device___31 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node___2 *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

struct platform_driver___27 {
	int (*probe)(struct platform_device___31 *);
	int (*remove)(struct platform_device___31 *);
	void (*shutdown)(struct platform_device___31 *);
	int (*suspend)(struct platform_device___31 *, pm_message_t);
	int (*resume)(struct platform_device___31 *);
	struct device_driver___160 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct prcm_data {
	int nsubdevs;
	const struct mfd_cell___5 *subdevs;
};

enum tx3589x_block {
	TC3589x_BLOCK_GPIO = 1,
	TC3589x_BLOCK_KEYPAD = 2,
};

struct tc3589x___2 {
	struct mutex lock;
	struct device___166 *dev;
	struct i2c_client___2 *i2c;
	struct irq_domain___41 *domain;
	int irq_base;
	int num_gpio;
	struct tc3589x_platform_data *pdata;
};

enum tc3589x_version {
	TC3589X_TC35890 = 0,
	TC3589X_TC35892 = 1,
	TC3589X_TC35893 = 2,
	TC3589X_TC35894 = 3,
	TC3589X_TC35895 = 4,
	TC3589X_TC35896 = 5,
	TC3589X_UNKNOWN = 6,
};

enum lochnagar_type {
	LOCHNAGAR1 = 0,
	LOCHNAGAR2 = 1,
};

struct lochnagar {
	enum lochnagar_type type;
	struct device___166 *dev;
	struct regmap *regmap;
	struct mutex analogue_config_lock;
};

struct lochnagar_config {
	int id;
	const char * const name;
	enum lochnagar_type type;
	const struct regmap_config___4 *regmap;
	const struct reg_sequence *patch;
	int npatch;
};

struct wm8400_platform_data {
	int (*platform_init)(struct device___166 *);
};

struct wm8400 {
	struct device___166 *dev;
	struct regmap *regmap;
	struct platform_device___29 regulators[6];
};

struct mfd_cell___6;

struct platform_device___32 {
	const char *name;
	int id;
	bool id_auto;
	struct device___38 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell___6 *mfd_cell;
	struct pdev_archdata archdata;
};

struct mfd_cell___6 {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___32 *);
	int (*disable)(struct platform_device___32 *);
	int (*suspend)(struct platform_device___32 *);
	int (*resume)(struct platform_device___32 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node___2 *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

struct regmap_config___12 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___38 *, unsigned int);
	bool (*readable_reg)(struct device___38 *, unsigned int);
	bool (*volatile_reg)(struct device___38 *, unsigned int);
	bool (*precious_reg)(struct device___38 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___38 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___38 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

enum wm831x_auxadc {
	WM831X_AUX_CAL = 15,
	WM831X_AUX_BKUP_BATT = 10,
	WM831X_AUX_WALL = 9,
	WM831X_AUX_BATT = 8,
	WM831X_AUX_USB = 7,
	WM831X_AUX_SYSVDD = 6,
	WM831X_AUX_BATT_TEMP = 5,
	WM831X_AUX_CHIP_TEMP = 4,
	WM831X_AUX_AUX4 = 3,
	WM831X_AUX_AUX3 = 2,
	WM831X_AUX_AUX2 = 1,
	WM831X_AUX_AUX1 = 0,
};

struct wm831x_backlight_pdata {
	int isink;
	int max_uA;
};

struct wm831x_backup_pdata {
	int charger_enable;
	int no_constant_voltage;
	int vlim;
	int ilim;
};

struct wm831x_battery_pdata {
	int enable;
	int fast_enable;
	int off_mask;
	int trickle_ilim;
	int vsel;
	int eoc_iterm;
	int fast_ilim;
	int timeout;
};

enum wm831x_status_src {
	WM831X_STATUS_PRESERVE = 0,
	WM831X_STATUS_OTP = 1,
	WM831X_STATUS_POWER = 2,
	WM831X_STATUS_CHARGER = 3,
	WM831X_STATUS_MANUAL = 4,
};

struct wm831x_status_pdata {
	enum wm831x_status_src default_src;
	const char *name;
	const char *default_trigger;
};

struct wm831x_touch_pdata {
	int fivewire;
	int isel;
	int rpu;
	int pressure;
	unsigned int data_irq;
	int data_irqf;
	unsigned int pd_irq;
	int pd_irqf;
};

enum wm831x_watchdog_action {
	WM831X_WDOG_NONE = 0,
	WM831X_WDOG_INTERRUPT = 1,
	WM831X_WDOG_RESET = 2,
	WM831X_WDOG_WAKE = 3,
};

struct wm831x_watchdog_pdata {
	enum wm831x_watchdog_action primary;
	enum wm831x_watchdog_action secondary;
	unsigned int software: 1;
	long: 31;
	long: 64;
};

struct wm831x;

struct wm831x_pdata {
	int wm831x_num;
	int (*pre_init)(struct wm831x *);
	int (*post_init)(struct wm831x *);
	bool irq_cmos;
	bool disable_touch;
	bool soft_shutdown;
	int irq_base;
	int gpio_base;
	int gpio_defaults[16];
	struct wm831x_backlight_pdata *backlight;
	struct wm831x_backup_pdata *backup;
	struct wm831x_battery_pdata *battery;
	struct wm831x_touch_pdata *touch;
	struct wm831x_watchdog_pdata *watchdog;
	struct wm831x_status_pdata *status[2];
	struct regulator_init_data *dcdc[4];
	struct regulator_init_data *epe[2];
	struct regulator_init_data *ldo[11];
	struct regulator_init_data *isink[2];
};

enum wm831x_parent {
	WM8310 = 33552,
	WM8311 = 33553,
	WM8312 = 33554,
	WM8320 = 33568,
	WM8321 = 33569,
	WM8325 = 33573,
	WM8326 = 33574,
};

typedef int (*wm831x_auxadc_read_fn)(struct wm831x *, enum wm831x_auxadc);

struct wm831x {
	struct mutex io_lock;
	struct device___38 *dev;
	struct regmap *regmap;
	struct wm831x_pdata pdata;
	enum wm831x_parent type;
	int irq;
	struct mutex irq_lock;
	struct irq_domain___13 *irq_domain;
	int irq_masks_cur[5];
	int irq_masks_cache[5];
	bool soft_shutdown;
	unsigned int has_gpio_ena: 1;
	unsigned int has_cs_sts: 1;
	unsigned int charger_irq_wake: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int num_gpio;
	int gpio_update[16];
	bool gpio_level_high[16];
	bool gpio_level_low[16];
	struct mutex auxadc_lock;
	struct list_head auxadc_pending;
	u16 auxadc_active;
	wm831x_auxadc_read_fn auxadc_read;
	struct mutex key_lock;
	unsigned int locked: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wm831x___2;

struct wm831x_pdata___2 {
	int wm831x_num;
	int (*pre_init)(struct wm831x___2 *);
	int (*post_init)(struct wm831x___2 *);
	bool irq_cmos;
	bool disable_touch;
	bool soft_shutdown;
	int irq_base;
	int gpio_base;
	int gpio_defaults[16];
	struct wm831x_backlight_pdata *backlight;
	struct wm831x_backup_pdata *backup;
	struct wm831x_battery_pdata *battery;
	struct wm831x_touch_pdata *touch;
	struct wm831x_watchdog_pdata *watchdog;
	struct wm831x_status_pdata *status[2];
	struct regulator_init_data *dcdc[4];
	struct regulator_init_data *epe[2];
	struct regulator_init_data *ldo[11];
	struct regulator_init_data *isink[2];
};

typedef int (*wm831x_auxadc_read_fn___2)(struct wm831x___2 *, enum wm831x_auxadc);

struct wm831x___2 {
	struct mutex io_lock;
	struct device___154 *dev;
	struct regmap *regmap;
	struct wm831x_pdata___2 pdata;
	enum wm831x_parent type;
	int irq;
	struct mutex irq_lock;
	struct irq_domain___35 *irq_domain;
	int irq_masks_cur[5];
	int irq_masks_cache[5];
	bool soft_shutdown;
	unsigned int has_gpio_ena: 1;
	unsigned int has_cs_sts: 1;
	unsigned int charger_irq_wake: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int num_gpio;
	int gpio_update[16];
	bool gpio_level_high[16];
	bool gpio_level_low[16];
	struct mutex auxadc_lock;
	struct list_head auxadc_pending;
	u16 auxadc_active;
	wm831x_auxadc_read_fn___2 auxadc_read;
	struct mutex key_lock;
	unsigned int locked: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wm831x_irq_data {
	int primary;
	int reg;
	int mask;
};

struct wm831x___3;

struct wm831x_pdata___3 {
	int wm831x_num;
	int (*pre_init)(struct wm831x___3 *);
	int (*post_init)(struct wm831x___3 *);
	bool irq_cmos;
	bool disable_touch;
	bool soft_shutdown;
	int irq_base;
	int gpio_base;
	int gpio_defaults[16];
	struct wm831x_backlight_pdata *backlight;
	struct wm831x_backup_pdata *backup;
	struct wm831x_battery_pdata *battery;
	struct wm831x_touch_pdata *touch;
	struct wm831x_watchdog_pdata *watchdog;
	struct wm831x_status_pdata *status[2];
	struct regulator_init_data *dcdc[4];
	struct regulator_init_data *epe[2];
	struct regulator_init_data *ldo[11];
	struct regulator_init_data *isink[2];
};

typedef int (*wm831x_auxadc_read_fn___3)(struct wm831x___3 *, enum wm831x_auxadc);

struct wm831x___3 {
	struct mutex io_lock;
	struct device___166 *dev;
	struct regmap *regmap;
	struct wm831x_pdata___3 pdata;
	enum wm831x_parent type;
	int irq;
	struct mutex irq_lock;
	struct irq_domain___41 *irq_domain;
	int irq_masks_cur[5];
	int irq_masks_cache[5];
	bool soft_shutdown;
	unsigned int has_gpio_ena: 1;
	unsigned int has_cs_sts: 1;
	unsigned int charger_irq_wake: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int num_gpio;
	int gpio_update[16];
	bool gpio_level_high[16];
	bool gpio_level_low[16];
	struct mutex auxadc_lock;
	struct list_head auxadc_pending;
	u16 auxadc_active;
	wm831x_auxadc_read_fn___3 auxadc_read;
	struct mutex key_lock;
	unsigned int locked: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wm831x_auxadc_req {
	struct list_head list;
	enum wm831x_auxadc input;
	int val;
	struct completion done;
};

struct spi_driver___2 {
	const struct spi_device_id *id_table;
	int (*probe)(struct spi_device___2 *);
	int (*remove)(struct spi_device___2 *);
	void (*shutdown)(struct spi_device___2 *);
	struct device_driver___190 driver;
};

struct wm831x___4;

struct wm831x_pdata___4 {
	int wm831x_num;
	int (*pre_init)(struct wm831x___4 *);
	int (*post_init)(struct wm831x___4 *);
	bool irq_cmos;
	bool disable_touch;
	bool soft_shutdown;
	int irq_base;
	int gpio_base;
	int gpio_defaults[16];
	struct wm831x_backlight_pdata *backlight;
	struct wm831x_backup_pdata *backup;
	struct wm831x_battery_pdata *battery;
	struct wm831x_touch_pdata *touch;
	struct wm831x_watchdog_pdata *watchdog;
	struct wm831x_status_pdata *status[2];
	struct regulator_init_data *dcdc[4];
	struct regulator_init_data *epe[2];
	struct regulator_init_data *ldo[11];
	struct regulator_init_data *isink[2];
};

typedef int (*wm831x_auxadc_read_fn___4)(struct wm831x___4 *, enum wm831x_auxadc);

struct wm831x___4 {
	struct mutex io_lock;
	struct device___190 *dev;
	struct regmap *regmap;
	struct wm831x_pdata___4 pdata;
	enum wm831x_parent type;
	int irq;
	struct mutex irq_lock;
	struct irq_domain___49 *irq_domain;
	int irq_masks_cur[5];
	int irq_masks_cache[5];
	bool soft_shutdown;
	unsigned int has_gpio_ena: 1;
	unsigned int has_cs_sts: 1;
	unsigned int charger_irq_wake: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int num_gpio;
	int gpio_update[16];
	bool gpio_level_high[16];
	bool gpio_level_low[16];
	struct mutex auxadc_lock;
	struct list_head auxadc_pending;
	u16 auxadc_active;
	wm831x_auxadc_read_fn___4 auxadc_read;
	struct mutex key_lock;
	unsigned int locked: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct wm8350_audio_platform_data {
	int vmid_discharge_msecs;
	int drain_msecs;
	int cap_discharge_msecs;
	int vmid_charge_msecs;
	u32 vmid_s_curve: 2;
	u32 dis_out4: 2;
	u32 dis_out3: 2;
	u32 dis_out2: 2;
	u32 dis_out1: 2;
	u32 vroi_out4: 1;
	u32 vroi_out3: 1;
	u32 vroi_out2: 1;
	u32 vroi_out1: 1;
	u32 vroi_enable: 1;
	u32 codec_current_on: 2;
	u32 codec_current_standby: 2;
	u32 codec_current_charge: 2;
	long: 30;
	long: 64;
	long: 64;
};

struct wm8350_codec {
	struct platform_device___29 *pdev;
	struct wm8350_audio_platform_data *platform_data;
};

struct wm8350_gpio {
	struct platform_device___29 *pdev;
};

struct led_trigger___3;

struct led_classdev___3 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___3 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___3 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___3 *);
	int (*blink_set)(struct led_classdev___3 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___3 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___3 *);
	struct device___166 *dev;
	const struct attribute_group___190 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___3 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___3 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___190 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___3 {
	const char *name;
	int (*activate)(struct led_classdev___3 *);
	void (*deactivate)(struct led_classdev___3 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___190 **groups;
};

struct wm8350_led {
	struct platform_device___29 *pdev;
	struct work_struct work;
	spinlock_t value_lock;
	enum led_brightness value;
	struct led_classdev___3 cdev;
	int max_uA_index;
	int enabled;
	struct regulator *isink;
	struct regulator_consumer_supply isink_consumer;
	struct regulator_init_data isink_init;
	struct regulator *dcdc;
	struct regulator_consumer_supply dcdc_consumer;
	struct regulator_init_data dcdc_init;
};

struct wm8350_pmic {
	int max_dcdc;
	int max_isink;
	int isink_A_dcdc;
	int isink_B_dcdc;
	u16 dcdc1_hib_mode;
	u16 dcdc3_hib_mode;
	u16 dcdc4_hib_mode;
	u16 dcdc6_hib_mode;
	struct platform_device___29 *pdev[12];
	struct wm8350_led led[2];
};

struct rtc_device___3;

struct wm8350_rtc {
	struct platform_device___29 *pdev;
	struct rtc_device___3 *rtc;
	int alarm_enabled;
	int update_enabled;
};

struct power_supply___2;

struct power_supply_desc___2 {
	const char *name;
	enum power_supply_type type;
	const enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	const enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___2 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___2 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___2 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___2 *);
	void (*set_charged)(struct power_supply___2 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___2 {
	const struct power_supply_desc___2 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___166 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device___3 *tcd;
	struct led_trigger___3 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___3 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___3 *full_trig;
	char *full_trig_name;
	struct led_trigger___3 *online_trig;
	char *online_trig_name;
	struct led_trigger___3 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct wm8350_charger_policy {
	int eoc_mA;
	int charge_mV;
	int fast_limit_mA;
	int fast_limit_USB_mA;
	int charge_timeout;
	int trickle_start_mV;
	int trickle_charge_mA;
	int trickle_charge_USB_mA;
};

struct wm8350_power {
	struct platform_device___29 *pdev;
	struct power_supply___2 *battery;
	struct power_supply___2 *usb;
	struct power_supply___2 *ac;
	struct wm8350_charger_policy *policy;
	int rev_g_coeff;
};

struct wm8350_wdt {
	struct platform_device___29 *pdev;
};

struct wm8350_hwmon {
	struct platform_device___29 *pdev;
	struct device___166 *classdev;
};

struct wm8350 {
	struct device___166 *dev;
	struct regmap *regmap;
	bool unlocked;
	struct mutex auxadc_mutex;
	struct completion auxadc_done;
	struct mutex irq_lock;
	int chip_irq;
	int irq_base;
	u16 irq_masks[7];
	struct wm8350_codec codec;
	struct wm8350_gpio gpio;
	struct wm8350_hwmon hwmon;
	struct wm8350_pmic pmic;
	struct wm8350_power power;
	struct wm8350_rtc rtc;
	struct wm8350_wdt wdt;
};

struct wm8350_platform_data {
	int (*init)(struct wm8350 *);
	int irq_high;
	int irq_base;
	int gpio_base;
};

struct wm8350_reg_access {
	u16 readable;
	u16 writable;
	u16 vol;
};

struct wm8350_irq_data {
	int primary;
	int reg;
	int mask;
	int primary_only;
};

struct rtc_class_ops___3 {
	int (*ioctl)(struct device___166 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___166 *, struct rtc_time *);
	int (*set_time)(struct device___166 *, struct rtc_time *);
	int (*read_alarm)(struct device___166 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___166 *, struct rtc_wkalrm *);
	int (*proc)(struct device___166 *, struct seq_file___178 *);
	int (*alarm_irq_enable)(struct device___166 *, unsigned int);
	int (*read_offset)(struct device___166 *, long int *);
	int (*set_offset)(struct device___166 *, long int);
};

struct rtc_timer___3 {
	struct timerqueue_node node;
	ktime_t period;
	void (*func)(struct rtc_device___3 *);
	struct rtc_device___3 *rtc;
	int enabled;
};

struct rtc_device___3 {
	struct device___166 dev;
	struct module___186 *owner;
	int id;
	const struct rtc_class_ops___3 *ops;
	struct mutex ops_lock;
	struct cdev___49 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___202 *async_queue;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer___3 aie_timer;
	struct rtc_timer___3 uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long unsigned int set_offset_nsec;
	long unsigned int features[1];
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct power_supply___3;

struct power_supply_desc___3 {
	const char *name;
	enum power_supply_type type;
	const enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	const enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___3 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___3 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___3 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___3 *);
	void (*set_charged)(struct power_supply___3 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___3 {
	const struct power_supply_desc___3 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___67 *of_node;
	void *drv_data;
	struct device___166 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device___3 *tcd;
	struct led_trigger___3 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___3 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___3 *full_trig;
	char *full_trig_name;
	struct led_trigger___3 *online_trig;
	char *online_trig_name;
	struct led_trigger___3 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct wm8350_power___2 {
	struct platform_device___29 *pdev;
	struct power_supply___3 *battery;
	struct power_supply___3 *usb;
	struct power_supply___3 *ac;
	struct wm8350_charger_policy *policy;
	int rev_g_coeff;
};

struct wm8350___2 {
	struct device___166 *dev;
	struct regmap *regmap;
	bool unlocked;
	struct mutex auxadc_mutex;
	struct completion auxadc_done;
	struct mutex irq_lock;
	int chip_irq;
	int irq_base;
	u16 irq_masks[7];
	struct wm8350_codec codec;
	struct wm8350_gpio gpio;
	struct wm8350_hwmon hwmon;
	struct wm8350_pmic pmic;
	struct wm8350_power___2 power;
	struct wm8350_rtc rtc;
	struct wm8350_wdt wdt;
};

struct wm8350_platform_data___2 {
	int (*init)(struct wm8350___2 *);
	int irq_high;
	int irq_base;
	int gpio_base;
};

struct tps65910___2 {
	struct device___166 *dev;
	struct i2c_client___2 *i2c_client;
	struct regmap *regmap;
	long unsigned int id;
	struct tps65910_board *of_plat_data;
	int chip_irq;
	struct regmap_irq_chip_data *irq_data;
};

struct tps65910_platform_data {
	int irq;
	int irq_base;
};

enum tps65912_irqs {
	TPS65912_IRQ_PWRHOLD_F = 0,
	TPS65912_IRQ_VMON = 1,
	TPS65912_IRQ_PWRON = 2,
	TPS65912_IRQ_PWRON_LP = 3,
	TPS65912_IRQ_PWRHOLD_R = 4,
	TPS65912_IRQ_HOTDIE = 5,
	TPS65912_IRQ_GPIO1_R = 6,
	TPS65912_IRQ_GPIO1_F = 7,
	TPS65912_IRQ_GPIO2_R = 8,
	TPS65912_IRQ_GPIO2_F = 9,
	TPS65912_IRQ_GPIO3_R = 10,
	TPS65912_IRQ_GPIO3_F = 11,
	TPS65912_IRQ_GPIO4_R = 12,
	TPS65912_IRQ_GPIO4_F = 13,
	TPS65912_IRQ_GPIO5_R = 14,
	TPS65912_IRQ_GPIO5_F = 15,
	TPS65912_IRQ_PGOOD_DCDC1 = 16,
	TPS65912_IRQ_PGOOD_DCDC2 = 17,
	TPS65912_IRQ_PGOOD_DCDC3 = 18,
	TPS65912_IRQ_PGOOD_DCDC4 = 19,
	TPS65912_IRQ_PGOOD_LDO1 = 20,
	TPS65912_IRQ_PGOOD_LDO2 = 21,
	TPS65912_IRQ_PGOOD_LDO3 = 22,
	TPS65912_IRQ_PGOOD_LDO4 = 23,
	TPS65912_IRQ_PGOOD_LDO5 = 24,
	TPS65912_IRQ_PGOOD_LDO6 = 25,
	TPS65912_IRQ_PGOOD_LDO7 = 26,
	TPS65912_IRQ_PGOOD_LDO8 = 27,
	TPS65912_IRQ_PGOOD_LDO9 = 28,
	TPS65912_IRQ_PGOOD_LDO10 = 29,
};

struct tps65912 {
	struct device___190 *dev;
	struct regmap *regmap;
	int irq;
	struct regmap_irq_chip_data *irq_data;
};

struct tps65912___2 {
	struct device___166 *dev;
	struct regmap *regmap;
	int irq;
	struct regmap_irq_chip_data *irq_data;
};

enum chips {
	TPS80031 = 1,
	TPS80032 = 2,
};

enum {
	TPS80031_INT_PWRON = 0,
	TPS80031_INT_RPWRON = 1,
	TPS80031_INT_SYS_VLOW = 2,
	TPS80031_INT_RTC_ALARM = 3,
	TPS80031_INT_RTC_PERIOD = 4,
	TPS80031_INT_HOT_DIE = 5,
	TPS80031_INT_VXX_SHORT = 6,
	TPS80031_INT_SPDURATION = 7,
	TPS80031_INT_WATCHDOG = 8,
	TPS80031_INT_BAT = 9,
	TPS80031_INT_SIM = 10,
	TPS80031_INT_MMC = 11,
	TPS80031_INT_RES = 12,
	TPS80031_INT_GPADC_RT = 13,
	TPS80031_INT_GPADC_SW2_EOC = 14,
	TPS80031_INT_CC_AUTOCAL = 15,
	TPS80031_INT_ID_WKUP = 16,
	TPS80031_INT_VBUSS_WKUP = 17,
	TPS80031_INT_ID = 18,
	TPS80031_INT_VBUS = 19,
	TPS80031_INT_CHRG_CTRL = 20,
	TPS80031_INT_EXT_CHRG = 21,
	TPS80031_INT_INT_CHRG = 22,
	TPS80031_INT_RES2 = 23,
	TPS80031_INT_BAT_TEMP_OVRANGE = 24,
	TPS80031_INT_BAT_REMOVED = 25,
	TPS80031_INT_VBUS_DET = 26,
	TPS80031_INT_VAC_DET = 27,
	TPS80031_INT_FAULT_WDG = 28,
	TPS80031_INT_LINCH_GATED = 29,
	TPS80031_INT_NR = 30,
};

enum {
	TPS80031_REGULATOR_VIO = 0,
	TPS80031_REGULATOR_SMPS1 = 1,
	TPS80031_REGULATOR_SMPS2 = 2,
	TPS80031_REGULATOR_SMPS3 = 3,
	TPS80031_REGULATOR_SMPS4 = 4,
	TPS80031_REGULATOR_VANA = 5,
	TPS80031_REGULATOR_LDO1 = 6,
	TPS80031_REGULATOR_LDO2 = 7,
	TPS80031_REGULATOR_LDO3 = 8,
	TPS80031_REGULATOR_LDO4 = 9,
	TPS80031_REGULATOR_LDO5 = 10,
	TPS80031_REGULATOR_LDO6 = 11,
	TPS80031_REGULATOR_LDO7 = 12,
	TPS80031_REGULATOR_LDOLN = 13,
	TPS80031_REGULATOR_LDOUSB = 14,
	TPS80031_REGULATOR_VBUS = 15,
	TPS80031_REGULATOR_REGEN1 = 16,
	TPS80031_REGULATOR_REGEN2 = 17,
	TPS80031_REGULATOR_SYSEN = 18,
	TPS80031_REGULATOR_MAX = 19,
};

enum tps80031_ext_control {
	TPS80031_PWR_REQ_INPUT_NONE = 0,
	TPS80031_PWR_REQ_INPUT_PREQ1 = 1,
	TPS80031_PWR_REQ_INPUT_PREQ2 = 2,
	TPS80031_PWR_REQ_INPUT_PREQ3 = 4,
	TPS80031_PWR_OFF_ON_SLEEP = 8,
	TPS80031_PWR_ON_ON_SLEEP = 16,
};

enum tps80031_pupd_pins {
	TPS80031_PREQ1 = 0,
	TPS80031_PREQ2A = 1,
	TPS80031_PREQ2B = 2,
	TPS80031_PREQ2C = 3,
	TPS80031_PREQ3 = 4,
	TPS80031_NRES_WARM = 5,
	TPS80031_PWM_FORCE = 6,
	TPS80031_CHRG_EXT_CHRG_STATZ = 7,
	TPS80031_SIM = 8,
	TPS80031_MMC = 9,
	TPS80031_GPADC_START = 10,
	TPS80031_DVSI2C_SCL = 11,
	TPS80031_DVSI2C_SDA = 12,
	TPS80031_CTLI2C_SCL = 13,
	TPS80031_CTLI2C_SDA = 14,
};

enum tps80031_pupd_settings {
	TPS80031_PUPD_NORMAL = 0,
	TPS80031_PUPD_PULLDOWN = 1,
	TPS80031_PUPD_PULLUP = 2,
};

struct tps80031 {
	struct device___166 *dev;
	long unsigned int chip_info;
	int es_version;
	struct i2c_client___2 *clients[4];
	struct regmap *regmap[4];
	struct regmap_irq_chip_data *irq_data;
};

struct tps80031_pupd_init_data {
	int input_pin;
	int setting;
};

struct tps80031_regulator_platform_data {
	struct regulator_init_data *reg_init_data;
	unsigned int ext_ctrl_flag;
	unsigned int config_flags;
};

struct tps80031_platform_data {
	int irq_base;
	bool use_power_off;
	struct tps80031_pupd_init_data *pupd_init_data;
	int pupd_init_data_size;
	struct tps80031_regulator_platform_data *regulator_pdata[19];
};

struct tps80031_pupd_data {
	u8 reg;
	u8 pullup_bit;
	u8 pulldown_bit;
};

struct matrix_keymap_data {
	const uint32_t *keymap;
	unsigned int keymap_size;
};

enum twl_module_ids {
	TWL_MODULE_USB = 0,
	TWL_MODULE_PIH = 1,
	TWL_MODULE_MAIN_CHARGE = 2,
	TWL_MODULE_PM_MASTER = 3,
	TWL_MODULE_PM_RECEIVER = 4,
	TWL_MODULE_RTC = 5,
	TWL_MODULE_PWM = 6,
	TWL_MODULE_LED = 7,
	TWL_MODULE_SECURED_REG = 8,
	TWL_MODULE_LAST = 9,
};

enum twl4030_module_ids {
	TWL4030_MODULE_AUDIO_VOICE = 9,
	TWL4030_MODULE_GPIO = 10,
	TWL4030_MODULE_INTBR = 11,
	TWL4030_MODULE_TEST = 12,
	TWL4030_MODULE_KEYPAD = 13,
	TWL4030_MODULE_MADC = 14,
	TWL4030_MODULE_INTERRUPTS = 15,
	TWL4030_MODULE_PRECHARGE = 16,
	TWL4030_MODULE_BACKUP = 17,
	TWL4030_MODULE_INT = 18,
	TWL5031_MODULE_ACCESSORY = 19,
	TWL5031_MODULE_INTERRUPTS = 20,
	TWL4030_MODULE_LAST = 21,
};

enum twl6030_module_ids {
	TWL6030_MODULE_ID0 = 9,
	TWL6030_MODULE_ID1 = 10,
	TWL6030_MODULE_ID2 = 11,
	TWL6030_MODULE_GPADC = 12,
	TWL6030_MODULE_GASGAUGE = 13,
	TWL6030_MODULE_LAST = 14,
};

struct twl4030_clock_init_data {
	bool ck32k_lowpwr_enable;
};

struct twl4030_bci_platform_data {
	int *battery_tmp_tbl;
	unsigned int tblsize;
	int bb_uvolt;
	int bb_uamp;
};

struct twl4030_gpio_platform_data {
	bool use_leds;
	u8 mmc_cd;
	u32 debounce;
	u32 pullups;
	u32 pulldowns;
	int (*setup)(struct device___147 *, unsigned int, unsigned int);
	int (*teardown)(struct device___147 *, unsigned int, unsigned int);
};

struct twl4030_madc_platform_data {
	int irq_line;
};

struct twl4030_keypad_data {
	const struct matrix_keymap_data *keymap_data;
	unsigned int rows;
	unsigned int cols;
	bool rep;
};

enum twl4030_usb_mode {
	T2_USB_MODE_ULPI = 1,
	T2_USB_MODE_CEA2011_3PIN = 2,
};

struct twl4030_usb_data {
	enum twl4030_usb_mode usb_mode;
	long unsigned int features;
	int (*phy_init)(struct device___147 *);
	int (*phy_exit)(struct device___147 *);
	int (*phy_power)(struct device___147 *, int, int);
	int (*phy_set_clock)(struct device___147 *, int);
	int (*phy_suspend)(struct device___147 *, int);
};

struct twl4030_ins {
	u16 pmb_message;
	u8 delay;
};

struct twl4030_script {
	struct twl4030_ins *script;
	unsigned int size;
	u8 flags;
};

struct twl4030_resconfig {
	u8 resource;
	u8 devgroup;
	u8 type;
	u8 type2;
	u8 remap_off;
	u8 remap_sleep;
};

struct twl4030_power_data {
	struct twl4030_script **scripts;
	unsigned int num;
	struct twl4030_resconfig *resource_config;
	struct twl4030_resconfig *board_config;
	bool use_poweroff;
	bool ac_charger_quirk;
};

struct twl4030_codec_data {
	unsigned int digimic_delay;
	unsigned int ramp_delay_value;
	unsigned int offset_cncl_path;
	unsigned int hs_extmute: 1;
	long: 63;
	long: 64;
	int hs_extmute_gpio;
};

struct twl4030_vibra_data {
	unsigned int coexist;
};

struct twl4030_audio_data {
	unsigned int audio_mclk;
	struct twl4030_codec_data *codec;
	struct twl4030_vibra_data *vibra;
	int audpwron_gpio;
	int naudint_irq;
	unsigned int irq_base;
};

struct twl4030_platform_data {
	struct twl4030_clock_init_data *clock;
	struct twl4030_bci_platform_data *bci;
	struct twl4030_gpio_platform_data *gpio;
	struct twl4030_madc_platform_data *madc;
	struct twl4030_keypad_data *keypad;
	struct twl4030_usb_data *usb;
	struct twl4030_power_data *power;
	struct twl4030_audio_data *audio;
	struct regulator_init_data___2 *vdac;
	struct regulator_init_data___2 *vaux1;
	struct regulator_init_data___2 *vaux2;
	struct regulator_init_data___2 *vaux3;
	struct regulator_init_data___2 *vdd1;
	struct regulator_init_data___2 *vdd2;
	struct regulator_init_data___2 *vdd3;
	struct regulator_init_data___2 *vpll1;
	struct regulator_init_data___2 *vpll2;
	struct regulator_init_data___2 *vmmc1;
	struct regulator_init_data___2 *vmmc2;
	struct regulator_init_data___2 *vsim;
	struct regulator_init_data___2 *vaux4;
	struct regulator_init_data___2 *vio;
	struct regulator_init_data___2 *vintana1;
	struct regulator_init_data___2 *vintana2;
	struct regulator_init_data___2 *vintdig;
	struct regulator_init_data___2 *vmmc;
	struct regulator_init_data___2 *vpp;
	struct regulator_init_data___2 *vusim;
	struct regulator_init_data___2 *vana;
	struct regulator_init_data___2 *vcxio;
	struct regulator_init_data___2 *vusb;
	struct regulator_init_data___2 *clk32kg;
	struct regulator_init_data___2 *v1v8;
	struct regulator_init_data___2 *v2v1;
	struct regulator_init_data___2 *ldo1;
	struct regulator_init_data___2 *ldo2;
	struct regulator_init_data___2 *ldo3;
	struct regulator_init_data___2 *ldo4;
	struct regulator_init_data___2 *ldo5;
	struct regulator_init_data___2 *ldo6;
	struct regulator_init_data___2 *ldo7;
	struct regulator_init_data___2 *ldoln;
	struct regulator_init_data___2 *ldousb;
	struct regulator_init_data___2 *smps3;
	struct regulator_init_data___2 *smps4;
	struct regulator_init_data___2 *vio6025;
};

struct twl_regulator_driver_data {
	int (*set_voltage)(void *, int);
	int (*get_voltage)(void *);
	void *data;
	long unsigned int features;
};

struct twl_client {
	struct i2c_client___3 *client;
	struct regmap *regmap;
};

struct twl_mapping {
	unsigned char sid;
	unsigned char base;
};

struct twl_private {
	bool ready;
	u32 twl_idcode;
	unsigned int twl_id;
	struct twl_mapping *twl_map;
	struct twl_client *twl_modules;
};

struct sih_irq_data {
	u8 isr_offset;
	u8 imr_offset;
};

struct sih {
	char name[8];
	u8 module;
	u8 control_offset;
	bool set_cor;
	u8 bits;
	u8 bytes_ixr;
	u8 edr_offset;
	u8 bytes_edr;
	u8 irq_lines;
	struct sih_irq_data mask[2];
};

struct sih_agent {
	int irq_base;
	const struct sih *sih;
	u32 imr;
	bool imr_change_pending;
	u32 edge_change;
	struct mutex irq_lock;
	char *irq_name;
};

struct twl6030_irq {
	unsigned int irq_base;
	int twl_irq;
	bool irq_wake_enabled;
	atomic_t wakeirqs;
	struct notifier_block pm_nb;
	struct irq_chip___26 irq_chip;
	struct irq_domain___25 *irq_domain;
	const int *irq_mapping_tbl;
};

enum twl4030_audio_res {
	TWL4030_AUDIO_RES_POWER = 0,
	TWL4030_AUDIO_RES_APLL = 1,
	TWL4030_AUDIO_RES_MAX = 2,
};

struct twl4030_audio_resource {
	int request_count;
	u8 reg;
	u8 mask;
};

struct twl4030_audio {
	unsigned int audio_mclk;
	struct mutex mutex;
	struct twl4030_audio_resource resource[2];
	struct mfd_cell___2 cells[2];
};

struct twl6040 {
	struct device___147 *dev;
	struct regmap *regmap;
	struct regmap_irq_chip_data *irq_data;
	struct regulator_bulk_data supplies[2];
	struct clk *clk32k;
	struct clk *mclk;
	struct mutex mutex;
	struct mutex irq_mutex;
	struct mfd_cell cells[4];
	struct completion ready;
	int audpwron;
	int power_count;
	int rev;
	int pll;
	unsigned int sysclk_rate;
	unsigned int mclk_rate;
	unsigned int irq;
	unsigned int irq_ready;
	unsigned int irq_th;
};

typedef void (*dr_release_t___26)(struct device___147 *, void *);

struct mfd_of_node_entry {
	struct list_head list;
	struct device___147 *dev;
	struct device_node___49 *np;
};

struct pcap_subdev {
	int id;
	const char *name;
	void *platform_data;
};

struct pcap_platform_data {
	unsigned int irq_base;
	unsigned int config;
	int gpio;
	void (*init)(void *);
	int num_subdevs;
	struct pcap_subdev *subdevs;
};

struct pcap_adc_request {
	u8 bank;
	u8 ch[2];
	u32 flags;
	void (*callback)(void *, u16 *);
	void *data;
};

struct pcap_adc_sync_request {
	u16 res[2];
	struct completion completion;
};

struct pcap_chip {
	struct spi_device___2 *spi;
	u32 buf;
	spinlock_t io_lock;
	unsigned int irq_base;
	u32 msr;
	struct work_struct isr_work;
	struct work_struct msr_work;
	struct workqueue_struct *workqueue;
	struct pcap_adc_request *adc_queue[8];
	u8 adc_head;
	u8 adc_tail;
	spinlock_t adc_lock;
};

struct da903x_subdev_info {
	int id;
	const char *name;
	void *platform_data;
};

struct da903x_platform_data {
	int num_subdevs;
	struct da903x_subdev_info *subdevs;
};

struct da903x_chip;

struct da903x_chip_ops {
	int (*init_chip)(struct da903x_chip *);
	int (*unmask_events)(struct da903x_chip *, unsigned int);
	int (*mask_events)(struct da903x_chip *, unsigned int);
	int (*read_events)(struct da903x_chip *, unsigned int *);
	int (*read_status)(struct da903x_chip *, unsigned int *);
};

struct da903x_chip {
	struct i2c_client___2 *client;
	struct device___15 *dev;
	const struct da903x_chip_ops *ops;
	int type;
	uint32_t events_mask;
	struct mutex lock;
	struct work_struct irq_work;
	struct blocking_notifier_head notifier_list;
};

struct da9052 {
	struct device___85 *dev;
	struct regmap *regmap;
	struct mutex auxadc_lock;
	struct completion done;
	int irq_base;
	struct regmap_irq_chip_data *irq_data;
	u8 chip_id;
	int chip_irq;
	int (*fix_io)(struct da9052 *, unsigned char);
};

struct da9052___2 {
	struct device___80 *dev;
	struct regmap *regmap;
	struct mutex auxadc_lock;
	struct completion done;
	int irq_base;
	struct regmap_irq_chip_data *irq_data;
	u8 chip_id;
	int chip_irq;
	int (*fix_io)(struct da9052___2 *, unsigned char);
};

struct led_platform_data;

struct da9052_pdata {
	struct led_platform_data *pled;
	int (*init)(struct da9052___2 *);
	int irq_base;
	int gpio_base;
	int use_for_apm;
	struct regulator_init_data *regulators[14];
};

enum da9052_chip_id {
	DA9052 = 0,
	DA9053_AA = 1,
	DA9053_BA = 2,
	DA9053_BB = 3,
	DA9053_BC = 4,
};

struct da9052___3 {
	struct device___190 *dev;
	struct regmap *regmap;
	struct mutex auxadc_lock;
	struct completion done;
	int irq_base;
	struct regmap_irq_chip_data *irq_data;
	u8 chip_id;
	int chip_irq;
	int (*fix_io)(struct da9052___3 *, unsigned char);
};

struct da9052___4 {
	struct device___15 *dev;
	struct regmap *regmap;
	struct mutex auxadc_lock;
	struct completion done;
	int irq_base;
	struct regmap_irq_chip_data *irq_data;
	u8 chip_id;
	int chip_irq;
	int (*fix_io)(struct da9052___4 *, unsigned char);
};

struct mfd_cell___7;

struct platform_device___33 {
	const char *name;
	int id;
	bool id_auto;
	struct device___15 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell___7 *mfd_cell;
	struct pdev_archdata archdata;
};

struct mfd_cell___7 {
	const char *name;
	int id;
	int level;
	int (*enable)(struct platform_device___33 *);
	int (*disable)(struct platform_device___33 *);
	int (*suspend)(struct platform_device___33 *);
	int (*resume)(struct platform_device___33 *);
	void *platform_data;
	size_t pdata_size;
	const struct software_node *swnode;
	const char *of_compatible;
	const u64 of_reg;
	bool use_of_reg;
	const struct mfd_cell_acpi_match *acpi_match;
	int num_resources;
	const struct resource *resources;
	bool ignore_resource_conflicts;
	bool pm_runtime_no_callbacks;
	const char * const *parent_supplies;
	int num_parent_supplies;
};

enum lp8788_int_id {
	LP8788_INT_TSDL = 0,
	LP8788_INT_TSDH = 1,
	LP8788_INT_UVLO = 2,
	LP8788_INT_FLAGMON = 3,
	LP8788_INT_PWRON_TIME = 4,
	LP8788_INT_PWRON = 5,
	LP8788_INT_COMP1 = 6,
	LP8788_INT_COMP2 = 7,
	LP8788_INT_CHG_INPUT_STATE = 8,
	LP8788_INT_CHG_STATE = 9,
	LP8788_INT_EOC = 10,
	LP8788_INT_CHG_RESTART = 11,
	LP8788_INT_RESTART_TIMEOUT = 12,
	LP8788_INT_FULLCHG_TIMEOUT = 13,
	LP8788_INT_PRECHG_TIMEOUT = 14,
	LP8788_INT_RTC_ALARM1 = 17,
	LP8788_INT_RTC_ALARM2 = 18,
	LP8788_INT_ENTER_SYS_SUPPORT = 19,
	LP8788_INT_EXIT_SYS_SUPPORT = 20,
	LP8788_INT_BATT_LOW = 21,
	LP8788_INT_NO_BATT = 22,
	LP8788_INT_MAX = 24,
};

enum lp8788_dvs_sel {
	DVS_SEL_V0 = 0,
	DVS_SEL_V1 = 1,
	DVS_SEL_V2 = 2,
	DVS_SEL_V3 = 3,
};

enum lp8788_charger_event {
	NO_CHARGER = 0,
	CHARGER_DETECTED = 1,
};

enum lp8788_bl_ctrl_mode {
	LP8788_BL_REGISTER_ONLY = 0,
	LP8788_BL_COMB_PWM_BASED = 1,
	LP8788_BL_COMB_REGISTER_BASED = 2,
};

enum lp8788_bl_dim_mode {
	LP8788_DIM_EXPONENTIAL = 0,
	LP8788_DIM_LINEAR = 1,
};

enum lp8788_bl_full_scale_current {
	LP8788_FULLSCALE_5000uA = 0,
	LP8788_FULLSCALE_8500uA = 1,
	LP8788_FULLSCALE_1200uA = 2,
	LP8788_FULLSCALE_1550uA = 3,
	LP8788_FULLSCALE_1900uA = 4,
	LP8788_FULLSCALE_2250uA = 5,
	LP8788_FULLSCALE_2600uA = 6,
	LP8788_FULLSCALE_2950uA = 7,
};

enum lp8788_bl_ramp_step {
	LP8788_RAMP_8us = 0,
	LP8788_RAMP_1024us = 1,
	LP8788_RAMP_2048us = 2,
	LP8788_RAMP_4096us = 3,
	LP8788_RAMP_8192us = 4,
	LP8788_RAMP_16384us = 5,
	LP8788_RAMP_32768us = 6,
	LP8788_RAMP_65538us = 7,
};

enum lp8788_isink_scale {
	LP8788_ISINK_SCALE_100mA = 0,
	LP8788_ISINK_SCALE_120mA = 1,
};

enum lp8788_isink_number {
	LP8788_ISINK_1 = 0,
	LP8788_ISINK_2 = 1,
	LP8788_ISINK_3 = 2,
};

enum lp8788_alarm_sel {
	LP8788_ALARM_1 = 0,
	LP8788_ALARM_2 = 1,
	LP8788_ALARM_MAX = 2,
};

struct lp8788_buck1_dvs {
	int gpio;
	enum lp8788_dvs_sel vsel;
};

struct lp8788_buck2_dvs {
	int gpio[2];
	enum lp8788_dvs_sel vsel;
};

struct lp8788_chg_param {
	u8 addr;
	u8 val;
};

struct lp8788;

struct lp8788_charger_platform_data {
	const char *adc_vbatt;
	const char *adc_batt_temp;
	unsigned int max_vbatt_mv;
	struct lp8788_chg_param *chg_params;
	int num_chg_params;
	void (*charger_event)(struct lp8788 *, enum lp8788_charger_event);
};

struct lp8788_platform_data;

struct lp8788 {
	struct device___15 *dev;
	struct regmap *regmap;
	struct irq_domain___9 *irqdm;
	int irq;
	struct lp8788_platform_data *pdata;
};

struct lp8788_backlight_platform_data {
	char *name;
	int initial_brightness;
	enum lp8788_bl_ctrl_mode bl_mode;
	enum lp8788_bl_dim_mode dim_mode;
	enum lp8788_bl_full_scale_current full_scale;
	enum lp8788_bl_ramp_step rise_time;
	enum lp8788_bl_ramp_step fall_time;
	enum pwm_polarity pwm_pol;
	unsigned int period_ns;
};

struct lp8788_led_platform_data {
	char *name;
	enum lp8788_isink_scale scale;
	enum lp8788_isink_number num;
	int iout_code;
};

struct lp8788_vib_platform_data {
	char *name;
	enum lp8788_isink_scale scale;
	enum lp8788_isink_number num;
	int iout_code;
	int pwm_code;
};

struct iio_map;

struct lp8788_platform_data {
	int (*init_func)(struct lp8788 *);
	struct regulator_init_data *buck_data[4];
	struct regulator_init_data *dldo_data[12];
	struct regulator_init_data *aldo_data[10];
	struct lp8788_buck1_dvs *buck1_dvs;
	struct lp8788_buck2_dvs *buck2_dvs;
	struct lp8788_charger_platform_data *chg_pdata;
	enum lp8788_alarm_sel alarm_sel;
	struct lp8788_backlight_platform_data *bl_pdata;
	struct lp8788_led_platform_data *led_pdata;
	struct lp8788_vib_platform_data *vib_pdata;
	struct iio_map *adc_pdata;
};

struct lp8788_irq_data {
	struct lp8788 *lp;
	struct mutex irq_lock;
	struct irq_domain___7 *domain;
	int enabled[24];
};

struct da9055 {
	struct regmap *regmap;
	struct regmap_irq_chip_data *irq_data;
	struct device___85 *dev;
	struct i2c_client *i2c_client;
	int irq_base;
	int chip_irq;
};

enum gpio_select {
	NO_GPIO = 0,
	GPIO_1 = 1,
	GPIO_2 = 2,
};

struct da9055_pdata {
	int (*init)(struct da9055 *);
	int irq_base;
	int gpio_base;
	struct regulator_init_data *regulators[8];
	bool reset_enable;
	int *gpio_ren;
	int *gpio_rsel;
	enum gpio_select *reg_ren;
	enum gpio_select *reg_rsel;
	struct gpio_desc **ena_gpiods;
};

struct da9055___2 {
	struct regmap *regmap;
	struct regmap_irq_chip_data *irq_data;
	struct device___15 *dev;
	struct i2c_client___2 *i2c_client;
	int irq_base;
	int chip_irq;
};

enum da9063_type {
	PMIC_TYPE_DA9063 = 0,
	PMIC_TYPE_DA9063L = 1,
};

enum da9063_irqs {
	DA9063_IRQ_ONKEY = 0,
	DA9063_IRQ_ALARM = 1,
	DA9063_IRQ_TICK = 2,
	DA9063_IRQ_ADC_RDY = 3,
	DA9063_IRQ_SEQ_RDY = 4,
	DA9063_IRQ_WAKE = 5,
	DA9063_IRQ_TEMP = 6,
	DA9063_IRQ_COMP_1V2 = 7,
	DA9063_IRQ_LDO_LIM = 8,
	DA9063_IRQ_REG_UVOV = 9,
	DA9063_IRQ_DVC_RDY = 10,
	DA9063_IRQ_VDD_MON = 11,
	DA9063_IRQ_WARN = 12,
	DA9063_IRQ_GPI0 = 13,
	DA9063_IRQ_GPI1 = 14,
	DA9063_IRQ_GPI2 = 15,
	DA9063_IRQ_GPI3 = 16,
	DA9063_IRQ_GPI4 = 17,
	DA9063_IRQ_GPI5 = 18,
	DA9063_IRQ_GPI6 = 19,
	DA9063_IRQ_GPI7 = 20,
	DA9063_IRQ_GPI8 = 21,
	DA9063_IRQ_GPI9 = 22,
	DA9063_IRQ_GPI10 = 23,
	DA9063_IRQ_GPI11 = 24,
	DA9063_IRQ_GPI12 = 25,
	DA9063_IRQ_GPI13 = 26,
	DA9063_IRQ_GPI14 = 27,
	DA9063_IRQ_GPI15 = 28,
};

struct da9063 {
	struct device___80 *dev;
	enum da9063_type type;
	unsigned char variant_code;
	unsigned int flags;
	struct regmap *regmap;
	int chip_irq;
	unsigned int irq_base;
	struct regmap_irq_chip_data *regmap_irq;
};

struct da9063___2 {
	struct device___85 *dev;
	enum da9063_type type;
	unsigned char variant_code;
	unsigned int flags;
	struct regmap *regmap;
	int chip_irq;
	unsigned int irq_base;
	struct regmap_irq_chip_data *regmap_irq;
};

enum da9063_variant_codes {
	PMIC_DA9063_AD = 3,
	PMIC_DA9063_BB = 5,
	PMIC_DA9063_CA = 6,
	PMIC_DA9063_DA = 7,
};

struct da9063___3 {
	struct device___15 *dev;
	enum da9063_type type;
	unsigned char variant_code;
	unsigned int flags;
	struct regmap *regmap;
	int chip_irq;
	unsigned int irq_base;
	struct regmap_irq_chip_data *regmap_irq;
};

enum da9063_page_sel_buf_fmt {
	DA9063_PAGE_SEL_BUF_PAGE_REG = 0,
	DA9063_PAGE_SEL_BUF_PAGE_VAL = 1,
	DA9063_PAGE_SEL_BUF_SIZE = 2,
};

enum da9063_paged_read_msgs {
	DA9063_PAGED_READ_MSG_PAGE_SEL = 0,
	DA9063_PAGED_READ_MSG_REG_SEL = 1,
	DA9063_PAGED_READ_MSG_DATA = 2,
	DA9063_PAGED_READ_MSG_CNT = 3,
};

enum {
	DA9063_DEV_ID_REG = 0,
	DA9063_VAR_ID_REG = 1,
	DA9063_CHIP_ID_REGS = 2,
};

struct max14577_regulator_platform_data {
	int id;
	struct regulator_init_data *initdata;
	struct device_node___10 *of_node;
};

struct max14577_platform_data {
	int irq_base;
	int gpio_pogo_vbatt_en;
	int gpio_pogo_vbus_en;
	int (*set_gpio_pogo_vbatt_en)(int);
	int (*set_gpio_pogo_vbus_en)(int);
	int (*set_gpio_pogo_cb)(int);
	struct max14577_regulator_platform_data *regulators;
};

struct maxim_charger_current {
	unsigned int min;
	unsigned int high_start;
	unsigned int high_step;
	unsigned int max;
};

enum maxim_device_type {
	MAXIM_DEVICE_TYPE_UNKNOWN = 0,
	MAXIM_DEVICE_TYPE_MAX14577 = 1,
	MAXIM_DEVICE_TYPE_MAX77836 = 2,
	MAXIM_DEVICE_TYPE_NUM = 3,
};

enum max14577_reg {
	MAX14577_REG_DEVICEID = 0,
	MAX14577_REG_INT1 = 1,
	MAX14577_REG_INT2 = 2,
	MAX14577_REG_INT3 = 3,
	MAX14577_REG_STATUS1 = 4,
	MAX14577_REG_STATUS2 = 5,
	MAX14577_REG_STATUS3 = 6,
	MAX14577_REG_INTMASK1 = 7,
	MAX14577_REG_INTMASK2 = 8,
	MAX14577_REG_INTMASK3 = 9,
	MAX14577_REG_CDETCTRL1 = 10,
	MAX14577_REG_RFU = 11,
	MAX14577_REG_CONTROL1 = 12,
	MAX14577_REG_CONTROL2 = 13,
	MAX14577_REG_CONTROL3 = 14,
	MAX14577_REG_CHGCTRL1 = 15,
	MAX14577_REG_CHGCTRL2 = 16,
	MAX14577_REG_CHGCTRL3 = 17,
	MAX14577_REG_CHGCTRL4 = 18,
	MAX14577_REG_CHGCTRL5 = 19,
	MAX14577_REG_CHGCTRL6 = 20,
	MAX14577_REG_CHGCTRL7 = 21,
	MAX14577_REG_END = 22,
};

enum max77836_pmic_reg {
	MAX77836_PMIC_REG_PMIC_ID = 32,
	MAX77836_PMIC_REG_PMIC_REV = 33,
	MAX77836_PMIC_REG_INTSRC = 34,
	MAX77836_PMIC_REG_INTSRC_MASK = 35,
	MAX77836_PMIC_REG_TOPSYS_INT = 36,
	MAX77836_PMIC_REG_TOPSYS_INT_MASK = 38,
	MAX77836_PMIC_REG_TOPSYS_STAT = 40,
	MAX77836_PMIC_REG_MRSTB_CNTL = 42,
	MAX77836_PMIC_REG_LSCNFG = 43,
	MAX77836_LDO_REG_CNFG1_LDO1 = 81,
	MAX77836_LDO_REG_CNFG2_LDO1 = 82,
	MAX77836_LDO_REG_CNFG1_LDO2 = 83,
	MAX77836_LDO_REG_CNFG2_LDO2 = 84,
	MAX77836_LDO_REG_CNFG_LDO_BIAS = 85,
	MAX77836_COMP_REG_COMP1 = 96,
	MAX77836_PMIC_REG_END = 97,
};

enum max77836_fg_reg {
	MAX77836_FG_REG_VCELL_MSB = 2,
	MAX77836_FG_REG_VCELL_LSB = 3,
	MAX77836_FG_REG_SOC_MSB = 4,
	MAX77836_FG_REG_SOC_LSB = 5,
	MAX77836_FG_REG_MODE_H = 6,
	MAX77836_FG_REG_MODE_L = 7,
	MAX77836_FG_REG_VERSION_MSB = 8,
	MAX77836_FG_REG_VERSION_LSB = 9,
	MAX77836_FG_REG_HIBRT_H = 10,
	MAX77836_FG_REG_HIBRT_L = 11,
	MAX77836_FG_REG_CONFIG_H = 12,
	MAX77836_FG_REG_CONFIG_L = 13,
	MAX77836_FG_REG_VALRT_MIN = 20,
	MAX77836_FG_REG_VALRT_MAX = 21,
	MAX77836_FG_REG_CRATE_MSB = 22,
	MAX77836_FG_REG_CRATE_LSB = 23,
	MAX77836_FG_REG_VRESET = 24,
	MAX77836_FG_REG_FGID = 25,
	MAX77836_FG_REG_STATUS_H = 26,
	MAX77836_FG_REG_STATUS_L = 27,
	MAX77836_FG_REG_END = 28,
};

struct max14577 {
	struct device___15 *dev;
	struct i2c_client___2 *i2c;
	struct i2c_client___2 *i2c_pmic;
	enum maxim_device_type dev_type;
	struct regmap *regmap;
	struct regmap *regmap_pmic;
	struct regmap_irq_chip_data *irq_data;
	struct regmap_irq_chip_data *irq_data_pmic;
	int irq;
};

enum {
	MAX77620_IRQ_TOP_GLBL = 0,
	MAX77620_IRQ_TOP_SD = 1,
	MAX77620_IRQ_TOP_LDO = 2,
	MAX77620_IRQ_TOP_GPIO = 3,
	MAX77620_IRQ_TOP_RTC = 4,
	MAX77620_IRQ_TOP_32K = 5,
	MAX77620_IRQ_TOP_ONOFF = 6,
	MAX77620_IRQ_LBT_MBATLOW = 7,
	MAX77620_IRQ_LBT_TJALRM1 = 8,
	MAX77620_IRQ_LBT_TJALRM2 = 9,
};

enum max77620_chip_id {
	MAX77620 = 0,
	MAX20024 = 1,
	MAX77663 = 2,
};

struct max77620_chip {
	struct device___147 *dev;
	struct regmap *rmap;
	int chip_irq;
	enum max77620_chip_id chip_id;
	bool sleep_enable;
	bool enable_global_lpm;
	int shutdown_fps_period[3];
	int suspend_fps_period[3];
	struct regmap_irq_chip_data *top_irq_data;
	struct regmap_irq_chip_data *gpio_irq_data;
};

enum max77686_pmic_reg {
	MAX77686_REG_DEVICE_ID = 0,
	MAX77686_REG_INTSRC = 1,
	MAX77686_REG_INT1 = 2,
	MAX77686_REG_INT2 = 3,
	MAX77686_REG_INT1MSK = 4,
	MAX77686_REG_INT2MSK = 5,
	MAX77686_REG_STATUS1 = 6,
	MAX77686_REG_STATUS2 = 7,
	MAX77686_REG_PWRON = 8,
	MAX77686_REG_ONOFF_DELAY = 9,
	MAX77686_REG_MRSTB = 10,
	MAX77686_REG_BUCK1CTRL = 16,
	MAX77686_REG_BUCK1OUT = 17,
	MAX77686_REG_BUCK2CTRL1 = 18,
	MAX77686_REG_BUCK234FREQ = 19,
	MAX77686_REG_BUCK2DVS1 = 20,
	MAX77686_REG_BUCK2DVS2 = 21,
	MAX77686_REG_BUCK2DVS3 = 22,
	MAX77686_REG_BUCK2DVS4 = 23,
	MAX77686_REG_BUCK2DVS5 = 24,
	MAX77686_REG_BUCK2DVS6 = 25,
	MAX77686_REG_BUCK2DVS7 = 26,
	MAX77686_REG_BUCK2DVS8 = 27,
	MAX77686_REG_BUCK3CTRL1 = 28,
	MAX77686_REG_BUCK3DVS1 = 30,
	MAX77686_REG_BUCK3DVS2 = 31,
	MAX77686_REG_BUCK3DVS3 = 32,
	MAX77686_REG_BUCK3DVS4 = 33,
	MAX77686_REG_BUCK3DVS5 = 34,
	MAX77686_REG_BUCK3DVS6 = 35,
	MAX77686_REG_BUCK3DVS7 = 36,
	MAX77686_REG_BUCK3DVS8 = 37,
	MAX77686_REG_BUCK4CTRL1 = 38,
	MAX77686_REG_BUCK4DVS1 = 40,
	MAX77686_REG_BUCK4DVS2 = 41,
	MAX77686_REG_BUCK4DVS3 = 42,
	MAX77686_REG_BUCK4DVS4 = 43,
	MAX77686_REG_BUCK4DVS5 = 44,
	MAX77686_REG_BUCK4DVS6 = 45,
	MAX77686_REG_BUCK4DVS7 = 46,
	MAX77686_REG_BUCK4DVS8 = 47,
	MAX77686_REG_BUCK5CTRL = 48,
	MAX77686_REG_BUCK5OUT = 49,
	MAX77686_REG_BUCK6CTRL = 50,
	MAX77686_REG_BUCK6OUT = 51,
	MAX77686_REG_BUCK7CTRL = 52,
	MAX77686_REG_BUCK7OUT = 53,
	MAX77686_REG_BUCK8CTRL = 54,
	MAX77686_REG_BUCK8OUT = 55,
	MAX77686_REG_BUCK9CTRL = 56,
	MAX77686_REG_BUCK9OUT = 57,
	MAX77686_REG_LDO1CTRL1 = 64,
	MAX77686_REG_LDO2CTRL1 = 65,
	MAX77686_REG_LDO3CTRL1 = 66,
	MAX77686_REG_LDO4CTRL1 = 67,
	MAX77686_REG_LDO5CTRL1 = 68,
	MAX77686_REG_LDO6CTRL1 = 69,
	MAX77686_REG_LDO7CTRL1 = 70,
	MAX77686_REG_LDO8CTRL1 = 71,
	MAX77686_REG_LDO9CTRL1 = 72,
	MAX77686_REG_LDO10CTRL1 = 73,
	MAX77686_REG_LDO11CTRL1 = 74,
	MAX77686_REG_LDO12CTRL1 = 75,
	MAX77686_REG_LDO13CTRL1 = 76,
	MAX77686_REG_LDO14CTRL1 = 77,
	MAX77686_REG_LDO15CTRL1 = 78,
	MAX77686_REG_LDO16CTRL1 = 79,
	MAX77686_REG_LDO17CTRL1 = 80,
	MAX77686_REG_LDO18CTRL1 = 81,
	MAX77686_REG_LDO19CTRL1 = 82,
	MAX77686_REG_LDO20CTRL1 = 83,
	MAX77686_REG_LDO21CTRL1 = 84,
	MAX77686_REG_LDO22CTRL1 = 85,
	MAX77686_REG_LDO23CTRL1 = 86,
	MAX77686_REG_LDO24CTRL1 = 87,
	MAX77686_REG_LDO25CTRL1 = 88,
	MAX77686_REG_LDO26CTRL1 = 89,
	MAX77686_REG_LDO1CTRL2 = 96,
	MAX77686_REG_LDO2CTRL2 = 97,
	MAX77686_REG_LDO3CTRL2 = 98,
	MAX77686_REG_LDO4CTRL2 = 99,
	MAX77686_REG_LDO5CTRL2 = 100,
	MAX77686_REG_LDO6CTRL2 = 101,
	MAX77686_REG_LDO7CTRL2 = 102,
	MAX77686_REG_LDO8CTRL2 = 103,
	MAX77686_REG_LDO9CTRL2 = 104,
	MAX77686_REG_LDO10CTRL2 = 105,
	MAX77686_REG_LDO11CTRL2 = 106,
	MAX77686_REG_LDO12CTRL2 = 107,
	MAX77686_REG_LDO13CTRL2 = 108,
	MAX77686_REG_LDO14CTRL2 = 109,
	MAX77686_REG_LDO15CTRL2 = 110,
	MAX77686_REG_LDO16CTRL2 = 111,
	MAX77686_REG_LDO17CTRL2 = 112,
	MAX77686_REG_LDO18CTRL2 = 113,
	MAX77686_REG_LDO19CTRL2 = 114,
	MAX77686_REG_LDO20CTRL2 = 115,
	MAX77686_REG_LDO21CTRL2 = 116,
	MAX77686_REG_LDO22CTRL2 = 117,
	MAX77686_REG_LDO23CTRL2 = 118,
	MAX77686_REG_LDO24CTRL2 = 119,
	MAX77686_REG_LDO25CTRL2 = 120,
	MAX77686_REG_LDO26CTRL2 = 121,
	MAX77686_REG_BBAT_CHG = 126,
	MAX77686_REG_32KHZ = 127,
	MAX77686_REG_PMIC_END = 128,
};

enum max77802_pmic_reg {
	MAX77802_REG_DEVICE_ID = 0,
	MAX77802_REG_INTSRC = 1,
	MAX77802_REG_INT1 = 2,
	MAX77802_REG_INT2 = 3,
	MAX77802_REG_INT1MSK = 4,
	MAX77802_REG_INT2MSK = 5,
	MAX77802_REG_STATUS1 = 6,
	MAX77802_REG_STATUS2 = 7,
	MAX77802_REG_PWRON = 8,
	MAX77802_REG_MRSTB = 10,
	MAX77802_REG_EPWRHOLD = 11,
	MAX77802_REG_BOOSTCTRL = 14,
	MAX77802_REG_BOOSTOUT = 15,
	MAX77802_REG_BUCK1CTRL = 16,
	MAX77802_REG_BUCK1DVS1 = 17,
	MAX77802_REG_BUCK1DVS2 = 18,
	MAX77802_REG_BUCK1DVS3 = 19,
	MAX77802_REG_BUCK1DVS4 = 20,
	MAX77802_REG_BUCK1DVS5 = 21,
	MAX77802_REG_BUCK1DVS6 = 22,
	MAX77802_REG_BUCK1DVS7 = 23,
	MAX77802_REG_BUCK1DVS8 = 24,
	MAX77802_REG_BUCK2CTRL1 = 26,
	MAX77802_REG_BUCK2CTRL2 = 27,
	MAX77802_REG_BUCK2PHTRAN = 28,
	MAX77802_REG_BUCK2DVS1 = 29,
	MAX77802_REG_BUCK2DVS2 = 30,
	MAX77802_REG_BUCK2DVS3 = 31,
	MAX77802_REG_BUCK2DVS4 = 32,
	MAX77802_REG_BUCK2DVS5 = 33,
	MAX77802_REG_BUCK2DVS6 = 34,
	MAX77802_REG_BUCK2DVS7 = 35,
	MAX77802_REG_BUCK2DVS8 = 36,
	MAX77802_REG_BUCK3CTRL1 = 39,
	MAX77802_REG_BUCK3DVS1 = 40,
	MAX77802_REG_BUCK3DVS2 = 41,
	MAX77802_REG_BUCK3DVS3 = 42,
	MAX77802_REG_BUCK3DVS4 = 43,
	MAX77802_REG_BUCK3DVS5 = 44,
	MAX77802_REG_BUCK3DVS6 = 45,
	MAX77802_REG_BUCK3DVS7 = 46,
	MAX77802_REG_BUCK3DVS8 = 47,
	MAX77802_REG_BUCK4CTRL1 = 55,
	MAX77802_REG_BUCK4DVS1 = 56,
	MAX77802_REG_BUCK4DVS2 = 57,
	MAX77802_REG_BUCK4DVS3 = 58,
	MAX77802_REG_BUCK4DVS4 = 59,
	MAX77802_REG_BUCK4DVS5 = 60,
	MAX77802_REG_BUCK4DVS6 = 61,
	MAX77802_REG_BUCK4DVS7 = 62,
	MAX77802_REG_BUCK4DVS8 = 63,
	MAX77802_REG_BUCK5CTRL = 65,
	MAX77802_REG_BUCK5OUT = 66,
	MAX77802_REG_BUCK6CTRL = 68,
	MAX77802_REG_BUCK6DVS1 = 69,
	MAX77802_REG_BUCK6DVS2 = 70,
	MAX77802_REG_BUCK6DVS3 = 71,
	MAX77802_REG_BUCK6DVS4 = 72,
	MAX77802_REG_BUCK6DVS5 = 73,
	MAX77802_REG_BUCK6DVS6 = 74,
	MAX77802_REG_BUCK6DVS7 = 75,
	MAX77802_REG_BUCK6DVS8 = 76,
	MAX77802_REG_BUCK7CTRL = 78,
	MAX77802_REG_BUCK7OUT = 79,
	MAX77802_REG_BUCK8CTRL = 81,
	MAX77802_REG_BUCK8OUT = 82,
	MAX77802_REG_BUCK9CTRL = 84,
	MAX77802_REG_BUCK9OUT = 85,
	MAX77802_REG_BUCK10CTRL = 87,
	MAX77802_REG_BUCK10OUT = 88,
	MAX77802_REG_LDO1CTRL1 = 96,
	MAX77802_REG_LDO2CTRL1 = 97,
	MAX77802_REG_LDO3CTRL1 = 98,
	MAX77802_REG_LDO4CTRL1 = 99,
	MAX77802_REG_LDO5CTRL1 = 100,
	MAX77802_REG_LDO6CTRL1 = 101,
	MAX77802_REG_LDO7CTRL1 = 102,
	MAX77802_REG_LDO8CTRL1 = 103,
	MAX77802_REG_LDO9CTRL1 = 104,
	MAX77802_REG_LDO10CTRL1 = 105,
	MAX77802_REG_LDO11CTRL1 = 106,
	MAX77802_REG_LDO12CTRL1 = 107,
	MAX77802_REG_LDO13CTRL1 = 108,
	MAX77802_REG_LDO14CTRL1 = 109,
	MAX77802_REG_LDO15CTRL1 = 110,
	MAX77802_REG_LDO17CTRL1 = 112,
	MAX77802_REG_LDO18CTRL1 = 113,
	MAX77802_REG_LDO19CTRL1 = 114,
	MAX77802_REG_LDO20CTRL1 = 115,
	MAX77802_REG_LDO21CTRL1 = 116,
	MAX77802_REG_LDO22CTRL1 = 117,
	MAX77802_REG_LDO23CTRL1 = 118,
	MAX77802_REG_LDO24CTRL1 = 119,
	MAX77802_REG_LDO25CTRL1 = 120,
	MAX77802_REG_LDO26CTRL1 = 121,
	MAX77802_REG_LDO27CTRL1 = 122,
	MAX77802_REG_LDO28CTRL1 = 123,
	MAX77802_REG_LDO29CTRL1 = 124,
	MAX77802_REG_LDO30CTRL1 = 125,
	MAX77802_REG_LDO32CTRL1 = 127,
	MAX77802_REG_LDO33CTRL1 = 128,
	MAX77802_REG_LDO34CTRL1 = 129,
	MAX77802_REG_LDO35CTRL1 = 130,
	MAX77802_REG_LDO1CTRL2 = 144,
	MAX77802_REG_LDO2CTRL2 = 145,
	MAX77802_REG_LDO3CTRL2 = 146,
	MAX77802_REG_LDO4CTRL2 = 147,
	MAX77802_REG_LDO5CTRL2 = 148,
	MAX77802_REG_LDO6CTRL2 = 149,
	MAX77802_REG_LDO7CTRL2 = 150,
	MAX77802_REG_LDO8CTRL2 = 151,
	MAX77802_REG_LDO9CTRL2 = 152,
	MAX77802_REG_LDO10CTRL2 = 153,
	MAX77802_REG_LDO11CTRL2 = 154,
	MAX77802_REG_LDO12CTRL2 = 155,
	MAX77802_REG_LDO13CTRL2 = 156,
	MAX77802_REG_LDO14CTRL2 = 157,
	MAX77802_REG_LDO15CTRL2 = 158,
	MAX77802_REG_LDO17CTRL2 = 160,
	MAX77802_REG_LDO18CTRL2 = 161,
	MAX77802_REG_LDO19CTRL2 = 162,
	MAX77802_REG_LDO20CTRL2 = 163,
	MAX77802_REG_LDO21CTRL2 = 164,
	MAX77802_REG_LDO22CTRL2 = 165,
	MAX77802_REG_LDO23CTRL2 = 166,
	MAX77802_REG_LDO24CTRL2 = 167,
	MAX77802_REG_LDO25CTRL2 = 168,
	MAX77802_REG_LDO26CTRL2 = 169,
	MAX77802_REG_LDO27CTRL2 = 170,
	MAX77802_REG_LDO28CTRL2 = 171,
	MAX77802_REG_LDO29CTRL2 = 172,
	MAX77802_REG_LDO30CTRL2 = 173,
	MAX77802_REG_LDO32CTRL2 = 175,
	MAX77802_REG_LDO33CTRL2 = 176,
	MAX77802_REG_LDO34CTRL2 = 177,
	MAX77802_REG_LDO35CTRL2 = 178,
	MAX77802_REG_BBAT_CHG = 180,
	MAX77802_REG_32KHZ = 181,
	MAX77802_REG_PMIC_END = 182,
};

enum max77802_rtc_reg {
	MAX77802_RTC_INT = 192,
	MAX77802_RTC_INTM = 193,
	MAX77802_RTC_CONTROLM = 194,
	MAX77802_RTC_CONTROL = 195,
	MAX77802_RTC_UPDATE0 = 196,
	MAX77802_RTC_UPDATE1 = 197,
	MAX77802_WTSR_SMPL_CNTL = 198,
	MAX77802_RTC_SEC = 199,
	MAX77802_RTC_MIN = 200,
	MAX77802_RTC_HOUR = 201,
	MAX77802_RTC_WEEKDAY = 202,
	MAX77802_RTC_MONTH = 203,
	MAX77802_RTC_YEAR = 204,
	MAX77802_RTC_DATE = 205,
	MAX77802_RTC_AE1 = 206,
	MAX77802_ALARM1_SEC = 207,
	MAX77802_ALARM1_MIN = 208,
	MAX77802_ALARM1_HOUR = 209,
	MAX77802_ALARM1_WEEKDAY = 210,
	MAX77802_ALARM1_MONTH = 211,
	MAX77802_ALARM1_YEAR = 212,
	MAX77802_ALARM1_DATE = 213,
	MAX77802_RTC_AE2 = 214,
	MAX77802_ALARM2_SEC = 215,
	MAX77802_ALARM2_MIN = 216,
	MAX77802_ALARM2_HOUR = 217,
	MAX77802_ALARM2_WEEKDAY = 218,
	MAX77802_ALARM2_MONTH = 219,
	MAX77802_ALARM2_YEAR = 220,
	MAX77802_ALARM2_DATE = 221,
	MAX77802_RTC_END = 223,
};

enum max77686_irq_source {
	PMIC_INT1 = 0,
	PMIC_INT2 = 1,
	RTC_INT = 2,
	MAX77686_IRQ_GROUP_NR = 3,
};

struct max77686_dev {
	struct device___15 *dev;
	struct i2c_client___2 *i2c;
	long unsigned int type;
	struct regmap *regmap;
	struct regmap_irq_chip_data *irq_data;
	int irq;
	struct mutex irqlock;
	int irq_masks_cur[3];
	int irq_masks_cache[3];
};

enum max77686_types {
	TYPE_MAX77686 = 0,
	TYPE_MAX77802 = 1,
};

enum max77693_types {
	TYPE_MAX77693_UNKNOWN = 0,
	TYPE_MAX77693 = 1,
	TYPE_MAX77843 = 2,
	TYPE_MAX77693_NUM = 3,
};

struct max77693_dev {
	struct device___15 *dev;
	struct i2c_client___2 *i2c;
	struct i2c_client___2 *i2c_muic;
	struct i2c_client___2 *i2c_haptic;
	struct i2c_client___2 *i2c_chg;
	enum max77693_types type;
	struct regmap *regmap;
	struct regmap *regmap_muic;
	struct regmap *regmap_haptic;
	struct regmap *regmap_chg;
	struct regmap_irq_chip_data *irq_data_led;
	struct regmap_irq_chip_data *irq_data_topsys;
	struct regmap_irq_chip_data *irq_data_chg;
	struct regmap_irq_chip_data *irq_data_muic;
	int irq;
};

enum max77693_pmic_reg {
	MAX77693_LED_REG_IFLASH1 = 0,
	MAX77693_LED_REG_IFLASH2 = 1,
	MAX77693_LED_REG_ITORCH = 2,
	MAX77693_LED_REG_ITORCHTIMER = 3,
	MAX77693_LED_REG_FLASH_TIMER = 4,
	MAX77693_LED_REG_FLASH_EN = 5,
	MAX77693_LED_REG_MAX_FLASH1 = 6,
	MAX77693_LED_REG_MAX_FLASH2 = 7,
	MAX77693_LED_REG_MAX_FLASH3 = 8,
	MAX77693_LED_REG_MAX_FLASH4 = 9,
	MAX77693_LED_REG_VOUT_CNTL = 10,
	MAX77693_LED_REG_VOUT_FLASH1 = 11,
	MAX77693_LED_REG_VOUT_FLASH2 = 12,
	MAX77693_LED_REG_FLASH_INT = 14,
	MAX77693_LED_REG_FLASH_INT_MASK = 15,
	MAX77693_LED_REG_FLASH_STATUS = 16,
	MAX77693_PMIC_REG_PMIC_ID1 = 32,
	MAX77693_PMIC_REG_PMIC_ID2 = 33,
	MAX77693_PMIC_REG_INTSRC = 34,
	MAX77693_PMIC_REG_INTSRC_MASK = 35,
	MAX77693_PMIC_REG_TOPSYS_INT = 36,
	MAX77693_PMIC_REG_TOPSYS_INT_MASK = 38,
	MAX77693_PMIC_REG_TOPSYS_STAT = 40,
	MAX77693_PMIC_REG_MAINCTRL1 = 42,
	MAX77693_PMIC_REG_LSCNFG = 43,
	MAX77693_CHG_REG_CHG_INT = 176,
	MAX77693_CHG_REG_CHG_INT_MASK = 177,
	MAX77693_CHG_REG_CHG_INT_OK = 178,
	MAX77693_CHG_REG_CHG_DETAILS_00 = 179,
	MAX77693_CHG_REG_CHG_DETAILS_01 = 180,
	MAX77693_CHG_REG_CHG_DETAILS_02 = 181,
	MAX77693_CHG_REG_CHG_DETAILS_03 = 182,
	MAX77693_CHG_REG_CHG_CNFG_00 = 183,
	MAX77693_CHG_REG_CHG_CNFG_01 = 184,
	MAX77693_CHG_REG_CHG_CNFG_02 = 185,
	MAX77693_CHG_REG_CHG_CNFG_03 = 186,
	MAX77693_CHG_REG_CHG_CNFG_04 = 187,
	MAX77693_CHG_REG_CHG_CNFG_05 = 188,
	MAX77693_CHG_REG_CHG_CNFG_06 = 189,
	MAX77693_CHG_REG_CHG_CNFG_07 = 190,
	MAX77693_CHG_REG_CHG_CNFG_08 = 191,
	MAX77693_CHG_REG_CHG_CNFG_09 = 192,
	MAX77693_CHG_REG_CHG_CNFG_10 = 193,
	MAX77693_CHG_REG_CHG_CNFG_11 = 194,
	MAX77693_CHG_REG_CHG_CNFG_12 = 195,
	MAX77693_CHG_REG_CHG_CNFG_13 = 196,
	MAX77693_CHG_REG_CHG_CNFG_14 = 197,
	MAX77693_CHG_REG_SAFEOUT_CTRL = 198,
	MAX77693_PMIC_REG_END = 199,
};

enum max77693_muic_reg {
	MAX77693_MUIC_REG_ID = 0,
	MAX77693_MUIC_REG_INT1 = 1,
	MAX77693_MUIC_REG_INT2 = 2,
	MAX77693_MUIC_REG_INT3 = 3,
	MAX77693_MUIC_REG_STATUS1 = 4,
	MAX77693_MUIC_REG_STATUS2 = 5,
	MAX77693_MUIC_REG_STATUS3 = 6,
	MAX77693_MUIC_REG_INTMASK1 = 7,
	MAX77693_MUIC_REG_INTMASK2 = 8,
	MAX77693_MUIC_REG_INTMASK3 = 9,
	MAX77693_MUIC_REG_CDETCTRL1 = 10,
	MAX77693_MUIC_REG_CDETCTRL2 = 11,
	MAX77693_MUIC_REG_CTRL1 = 12,
	MAX77693_MUIC_REG_CTRL2 = 13,
	MAX77693_MUIC_REG_CTRL3 = 14,
	MAX77693_MUIC_REG_END = 15,
};

enum max77693_haptic_reg {
	MAX77693_HAPTIC_REG_STATUS = 0,
	MAX77693_HAPTIC_REG_CONFIG1 = 1,
	MAX77693_HAPTIC_REG_CONFIG2 = 2,
	MAX77693_HAPTIC_REG_CONFIG_CHNL = 3,
	MAX77693_HAPTIC_REG_CONFG_CYC1 = 4,
	MAX77693_HAPTIC_REG_CONFG_CYC2 = 5,
	MAX77693_HAPTIC_REG_CONFIG_PER1 = 6,
	MAX77693_HAPTIC_REG_CONFIG_PER2 = 7,
	MAX77693_HAPTIC_REG_CONFIG_PER3 = 8,
	MAX77693_HAPTIC_REG_CONFIG_PER4 = 9,
	MAX77693_HAPTIC_REG_CONFIG_DUTY1 = 10,
	MAX77693_HAPTIC_REG_CONFIG_DUTY2 = 11,
	MAX77693_HAPTIC_REG_CONFIG_PWM1 = 12,
	MAX77693_HAPTIC_REG_CONFIG_PWM2 = 13,
	MAX77693_HAPTIC_REG_CONFIG_PWM3 = 14,
	MAX77693_HAPTIC_REG_CONFIG_PWM4 = 15,
	MAX77693_HAPTIC_REG_REV = 16,
	MAX77693_HAPTIC_REG_END = 17,
};

enum max77843_sys_reg {
	MAX77843_SYS_REG_PMICID = 0,
	MAX77843_SYS_REG_PMICREV = 1,
	MAX77843_SYS_REG_MAINCTRL1 = 2,
	MAX77843_SYS_REG_INTSRC = 34,
	MAX77843_SYS_REG_INTSRCMASK = 35,
	MAX77843_SYS_REG_SYSINTSRC = 36,
	MAX77843_SYS_REG_SYSINTMASK = 38,
	MAX77843_SYS_REG_TOPSYS_STAT = 40,
	MAX77843_SYS_REG_SAFEOUTCTRL = 198,
	MAX77843_SYS_REG_END = 199,
};

enum max77843_charger_reg {
	MAX77843_CHG_REG_CHG_INT = 176,
	MAX77843_CHG_REG_CHG_INT_MASK = 177,
	MAX77843_CHG_REG_CHG_INT_OK = 178,
	MAX77843_CHG_REG_CHG_DTLS_00 = 179,
	MAX77843_CHG_REG_CHG_DTLS_01 = 180,
	MAX77843_CHG_REG_CHG_DTLS_02 = 181,
	MAX77843_CHG_REG_CHG_CNFG_00 = 183,
	MAX77843_CHG_REG_CHG_CNFG_01 = 184,
	MAX77843_CHG_REG_CHG_CNFG_02 = 185,
	MAX77843_CHG_REG_CHG_CNFG_03 = 186,
	MAX77843_CHG_REG_CHG_CNFG_04 = 187,
	MAX77843_CHG_REG_CHG_CNFG_06 = 189,
	MAX77843_CHG_REG_CHG_CNFG_07 = 190,
	MAX77843_CHG_REG_CHG_CNFG_09 = 192,
	MAX77843_CHG_REG_CHG_CNFG_10 = 193,
	MAX77843_CHG_REG_CHG_CNFG_11 = 194,
	MAX77843_CHG_REG_CHG_CNFG_12 = 195,
	MAX77843_CHG_REG_END = 196,
};

enum {
	MAX8925_IRQ_VCHG_DC_OVP = 0,
	MAX8925_IRQ_VCHG_DC_F = 1,
	MAX8925_IRQ_VCHG_DC_R = 2,
	MAX8925_IRQ_VCHG_THM_OK_R = 3,
	MAX8925_IRQ_VCHG_THM_OK_F = 4,
	MAX8925_IRQ_VCHG_SYSLOW_F = 5,
	MAX8925_IRQ_VCHG_SYSLOW_R = 6,
	MAX8925_IRQ_VCHG_RST = 7,
	MAX8925_IRQ_VCHG_DONE = 8,
	MAX8925_IRQ_VCHG_TOPOFF = 9,
	MAX8925_IRQ_VCHG_TMR_FAULT = 10,
	MAX8925_IRQ_GPM_RSTIN = 11,
	MAX8925_IRQ_GPM_MPL = 12,
	MAX8925_IRQ_GPM_SW_3SEC = 13,
	MAX8925_IRQ_GPM_EXTON_F = 14,
	MAX8925_IRQ_GPM_EXTON_R = 15,
	MAX8925_IRQ_GPM_SW_1SEC = 16,
	MAX8925_IRQ_GPM_SW_F = 17,
	MAX8925_IRQ_GPM_SW_R = 18,
	MAX8925_IRQ_GPM_SYSCKEN_F = 19,
	MAX8925_IRQ_GPM_SYSCKEN_R = 20,
	MAX8925_IRQ_RTC_ALARM1 = 21,
	MAX8925_IRQ_RTC_ALARM0 = 22,
	MAX8925_IRQ_TSC_STICK = 23,
	MAX8925_IRQ_TSC_NSTICK = 24,
	MAX8925_NR_IRQS = 25,
};

struct max8925_chip {
	struct device___15 *dev;
	struct i2c_client___2 *i2c;
	struct i2c_client___2 *adc;
	struct i2c_client___2 *rtc;
	struct mutex io_lock;
	struct mutex irq_lock;
	int irq_base;
	int core_irq;
	int tsc_irq;
	unsigned int wakeup_flag;
};

struct max8925_backlight_pdata {
	int lxw_scl;
	int lxw_freq;
	int dual_string;
};

struct max8925_touch_pdata {
	unsigned int flags;
};

struct max8925_power_pdata {
	int (*set_charger)(int);
	unsigned int batt_detect: 1;
	unsigned int topoff_threshold: 2;
	unsigned int fast_charge: 3;
	unsigned int no_temp_support: 1;
	unsigned int no_insert_detect: 1;
	long: 63;
	long: 64;
	char **supplied_to;
	int num_supplicants;
};

struct max8925_platform_data {
	struct max8925_backlight_pdata *backlight;
	struct max8925_touch_pdata *touch;
	struct max8925_power_pdata *power;
	struct regulator_init_data *sd1;
	struct regulator_init_data *sd2;
	struct regulator_init_data *sd3;
	struct regulator_init_data *ldo1;
	struct regulator_init_data *ldo2;
	struct regulator_init_data *ldo3;
	struct regulator_init_data *ldo4;
	struct regulator_init_data *ldo5;
	struct regulator_init_data *ldo6;
	struct regulator_init_data *ldo7;
	struct regulator_init_data *ldo8;
	struct regulator_init_data *ldo9;
	struct regulator_init_data *ldo10;
	struct regulator_init_data *ldo11;
	struct regulator_init_data *ldo12;
	struct regulator_init_data *ldo13;
	struct regulator_init_data *ldo14;
	struct regulator_init_data *ldo15;
	struct regulator_init_data *ldo16;
	struct regulator_init_data *ldo17;
	struct regulator_init_data *ldo18;
	struct regulator_init_data *ldo19;
	struct regulator_init_data *ldo20;
	int irq_base;
	int tsc_irq;
};

enum {
	FLAGS_ADC = 1,
	FLAGS_RTC = 2,
};

struct max8925_irq_data {
	int reg;
	int mask_reg;
	int enable;
	int offs;
	int flags;
	int tsc_irq;
};

struct max8997_regulator_data {
	int id;
	struct regulator_init_data *initdata;
	struct device_node___10 *reg_node;
};

struct max8997_muic_reg_data {
	u8 addr;
	u8 data;
};

struct max8997_muic_platform_data {
	struct max8997_muic_reg_data *init_data;
	int num_init_data;
	int detcable_delay_ms;
	int path_usb;
	int path_uart;
};

enum max8997_haptic_motor_type {
	MAX8997_HAPTIC_ERM = 0,
	MAX8997_HAPTIC_LRA = 1,
};

enum max8997_haptic_pulse_mode {
	MAX8997_EXTERNAL_MODE = 0,
	MAX8997_INTERNAL_MODE = 1,
};

enum max8997_haptic_pwm_divisor {
	MAX8997_PWM_DIVISOR_32 = 0,
	MAX8997_PWM_DIVISOR_64 = 1,
	MAX8997_PWM_DIVISOR_128 = 2,
	MAX8997_PWM_DIVISOR_256 = 3,
};

struct max8997_haptic_platform_data {
	unsigned int pwm_channel_id;
	unsigned int pwm_period;
	enum max8997_haptic_motor_type type;
	enum max8997_haptic_pulse_mode mode;
	enum max8997_haptic_pwm_divisor pwm_divisor;
	unsigned int internal_mode_pattern;
	unsigned int pattern_cycle;
	unsigned int pattern_signal_period;
};

enum max8997_led_mode {
	MAX8997_NONE = 0,
	MAX8997_FLASH_MODE = 1,
	MAX8997_MOVIE_MODE = 2,
	MAX8997_FLASH_PIN_CONTROL_MODE = 3,
	MAX8997_MOVIE_PIN_CONTROL_MODE = 4,
};

struct max8997_led_platform_data {
	enum max8997_led_mode mode[2];
	u8 brightness[2];
};

struct max8997_platform_data {
	int ono;
	struct max8997_regulator_data *regulators;
	int num_regulators;
	bool ignore_gpiodvs_side_effect;
	int buck125_gpios[3];
	int buck125_default_idx;
	unsigned int buck1_voltage[8];
	bool buck1_gpiodvs;
	unsigned int buck2_voltage[8];
	bool buck2_gpiodvs;
	unsigned int buck5_voltage[8];
	bool buck5_gpiodvs;
	int eoc_mA;
	int timeout;
	struct max8997_muic_platform_data *muic_pdata;
	struct max8997_haptic_platform_data *haptic_pdata;
	struct max8997_led_platform_data *led_pdata;
};

enum max8997_pmic_reg {
	MAX8997_REG_PMIC_ID0 = 0,
	MAX8997_REG_PMIC_ID1 = 1,
	MAX8997_REG_INTSRC = 2,
	MAX8997_REG_INT1 = 3,
	MAX8997_REG_INT2 = 4,
	MAX8997_REG_INT3 = 5,
	MAX8997_REG_INT4 = 6,
	MAX8997_REG_INT1MSK = 8,
	MAX8997_REG_INT2MSK = 9,
	MAX8997_REG_INT3MSK = 10,
	MAX8997_REG_INT4MSK = 11,
	MAX8997_REG_STATUS1 = 13,
	MAX8997_REG_STATUS2 = 14,
	MAX8997_REG_STATUS3 = 15,
	MAX8997_REG_STATUS4 = 16,
	MAX8997_REG_MAINCON1 = 19,
	MAX8997_REG_MAINCON2 = 20,
	MAX8997_REG_BUCKRAMP = 21,
	MAX8997_REG_BUCK1CTRL = 24,
	MAX8997_REG_BUCK1DVS1 = 25,
	MAX8997_REG_BUCK1DVS2 = 26,
	MAX8997_REG_BUCK1DVS3 = 27,
	MAX8997_REG_BUCK1DVS4 = 28,
	MAX8997_REG_BUCK1DVS5 = 29,
	MAX8997_REG_BUCK1DVS6 = 30,
	MAX8997_REG_BUCK1DVS7 = 31,
	MAX8997_REG_BUCK1DVS8 = 32,
	MAX8997_REG_BUCK2CTRL = 33,
	MAX8997_REG_BUCK2DVS1 = 34,
	MAX8997_REG_BUCK2DVS2 = 35,
	MAX8997_REG_BUCK2DVS3 = 36,
	MAX8997_REG_BUCK2DVS4 = 37,
	MAX8997_REG_BUCK2DVS5 = 38,
	MAX8997_REG_BUCK2DVS6 = 39,
	MAX8997_REG_BUCK2DVS7 = 40,
	MAX8997_REG_BUCK2DVS8 = 41,
	MAX8997_REG_BUCK3CTRL = 42,
	MAX8997_REG_BUCK3DVS = 43,
	MAX8997_REG_BUCK4CTRL = 44,
	MAX8997_REG_BUCK4DVS = 45,
	MAX8997_REG_BUCK5CTRL = 46,
	MAX8997_REG_BUCK5DVS1 = 47,
	MAX8997_REG_BUCK5DVS2 = 48,
	MAX8997_REG_BUCK5DVS3 = 49,
	MAX8997_REG_BUCK5DVS4 = 50,
	MAX8997_REG_BUCK5DVS5 = 51,
	MAX8997_REG_BUCK5DVS6 = 52,
	MAX8997_REG_BUCK5DVS7 = 53,
	MAX8997_REG_BUCK5DVS8 = 54,
	MAX8997_REG_BUCK6CTRL = 55,
	MAX8997_REG_BUCK6BPSKIPCTRL = 56,
	MAX8997_REG_BUCK7CTRL = 57,
	MAX8997_REG_BUCK7DVS = 58,
	MAX8997_REG_LDO1CTRL = 59,
	MAX8997_REG_LDO2CTRL = 60,
	MAX8997_REG_LDO3CTRL = 61,
	MAX8997_REG_LDO4CTRL = 62,
	MAX8997_REG_LDO5CTRL = 63,
	MAX8997_REG_LDO6CTRL = 64,
	MAX8997_REG_LDO7CTRL = 65,
	MAX8997_REG_LDO8CTRL = 66,
	MAX8997_REG_LDO9CTRL = 67,
	MAX8997_REG_LDO10CTRL = 68,
	MAX8997_REG_LDO11CTRL = 69,
	MAX8997_REG_LDO12CTRL = 70,
	MAX8997_REG_LDO13CTRL = 71,
	MAX8997_REG_LDO14CTRL = 72,
	MAX8997_REG_LDO15CTRL = 73,
	MAX8997_REG_LDO16CTRL = 74,
	MAX8997_REG_LDO17CTRL = 75,
	MAX8997_REG_LDO18CTRL = 76,
	MAX8997_REG_LDO21CTRL = 77,
	MAX8997_REG_MBCCTRL1 = 80,
	MAX8997_REG_MBCCTRL2 = 81,
	MAX8997_REG_MBCCTRL3 = 82,
	MAX8997_REG_MBCCTRL4 = 83,
	MAX8997_REG_MBCCTRL5 = 84,
	MAX8997_REG_MBCCTRL6 = 85,
	MAX8997_REG_OTPCGHCVS = 86,
	MAX8997_REG_SAFEOUTCTRL = 90,
	MAX8997_REG_LBCNFG1 = 94,
	MAX8997_REG_LBCNFG2 = 95,
	MAX8997_REG_BBCCTRL = 96,
	MAX8997_REG_FLASH1_CUR = 99,
	MAX8997_REG_FLASH2_CUR = 100,
	MAX8997_REG_MOVIE_CUR = 101,
	MAX8997_REG_GSMB_CUR = 102,
	MAX8997_REG_BOOST_CNTL = 103,
	MAX8997_REG_LEN_CNTL = 104,
	MAX8997_REG_FLASH_CNTL = 105,
	MAX8997_REG_WDT_CNTL = 106,
	MAX8997_REG_MAXFLASH1 = 107,
	MAX8997_REG_MAXFLASH2 = 108,
	MAX8997_REG_FLASHSTATUS = 109,
	MAX8997_REG_FLASHSTATUSMASK = 110,
	MAX8997_REG_GPIOCNTL1 = 112,
	MAX8997_REG_GPIOCNTL2 = 113,
	MAX8997_REG_GPIOCNTL3 = 114,
	MAX8997_REG_GPIOCNTL4 = 115,
	MAX8997_REG_GPIOCNTL5 = 116,
	MAX8997_REG_GPIOCNTL6 = 117,
	MAX8997_REG_GPIOCNTL7 = 118,
	MAX8997_REG_GPIOCNTL8 = 119,
	MAX8997_REG_GPIOCNTL9 = 120,
	MAX8997_REG_GPIOCNTL10 = 121,
	MAX8997_REG_GPIOCNTL11 = 122,
	MAX8997_REG_GPIOCNTL12 = 123,
	MAX8997_REG_LDO1CONFIG = 128,
	MAX8997_REG_LDO2CONFIG = 129,
	MAX8997_REG_LDO3CONFIG = 130,
	MAX8997_REG_LDO4CONFIG = 131,
	MAX8997_REG_LDO5CONFIG = 132,
	MAX8997_REG_LDO6CONFIG = 133,
	MAX8997_REG_LDO7CONFIG = 134,
	MAX8997_REG_LDO8CONFIG = 135,
	MAX8997_REG_LDO9CONFIG = 136,
	MAX8997_REG_LDO10CONFIG = 137,
	MAX8997_REG_LDO11CONFIG = 138,
	MAX8997_REG_LDO12CONFIG = 139,
	MAX8997_REG_LDO13CONFIG = 140,
	MAX8997_REG_LDO14CONFIG = 141,
	MAX8997_REG_LDO15CONFIG = 142,
	MAX8997_REG_LDO16CONFIG = 143,
	MAX8997_REG_LDO17CONFIG = 144,
	MAX8997_REG_LDO18CONFIG = 145,
	MAX8997_REG_LDO21CONFIG = 146,
	MAX8997_REG_DVSOKTIMER1 = 151,
	MAX8997_REG_DVSOKTIMER2 = 152,
	MAX8997_REG_DVSOKTIMER4 = 153,
	MAX8997_REG_DVSOKTIMER5 = 154,
	MAX8997_REG_PMIC_END = 155,
};

enum max8997_muic_reg {
	MAX8997_MUIC_REG_ID = 0,
	MAX8997_MUIC_REG_INT1 = 1,
	MAX8997_MUIC_REG_INT2 = 2,
	MAX8997_MUIC_REG_INT3 = 3,
	MAX8997_MUIC_REG_STATUS1 = 4,
	MAX8997_MUIC_REG_STATUS2 = 5,
	MAX8997_MUIC_REG_STATUS3 = 6,
	MAX8997_MUIC_REG_INTMASK1 = 7,
	MAX8997_MUIC_REG_INTMASK2 = 8,
	MAX8997_MUIC_REG_INTMASK3 = 9,
	MAX8997_MUIC_REG_CDETCTRL = 10,
	MAX8997_MUIC_REG_CONTROL1 = 12,
	MAX8997_MUIC_REG_CONTROL2 = 13,
	MAX8997_MUIC_REG_CONTROL3 = 14,
	MAX8997_MUIC_REG_END = 15,
};

enum max8997_haptic_reg {
	MAX8997_HAPTIC_REG_GENERAL = 0,
	MAX8997_HAPTIC_REG_CONF1 = 1,
	MAX8997_HAPTIC_REG_CONF2 = 2,
	MAX8997_HAPTIC_REG_DRVCONF = 3,
	MAX8997_HAPTIC_REG_CYCLECONF1 = 4,
	MAX8997_HAPTIC_REG_CYCLECONF2 = 5,
	MAX8997_HAPTIC_REG_SIGCONF1 = 6,
	MAX8997_HAPTIC_REG_SIGCONF2 = 7,
	MAX8997_HAPTIC_REG_SIGCONF3 = 8,
	MAX8997_HAPTIC_REG_SIGCONF4 = 9,
	MAX8997_HAPTIC_REG_SIGDC1 = 10,
	MAX8997_HAPTIC_REG_SIGDC2 = 11,
	MAX8997_HAPTIC_REG_SIGPWMDC1 = 12,
	MAX8997_HAPTIC_REG_SIGPWMDC2 = 13,
	MAX8997_HAPTIC_REG_SIGPWMDC3 = 14,
	MAX8997_HAPTIC_REG_SIGPWMDC4 = 15,
	MAX8997_HAPTIC_REG_MTR_REV = 16,
	MAX8997_HAPTIC_REG_END = 17,
};

enum max8997_irq_source {
	PMIC_INT1___2 = 0,
	PMIC_INT2___2 = 1,
	PMIC_INT3 = 2,
	PMIC_INT4 = 3,
	FUEL_GAUGE = 4,
	MUIC_INT1 = 5,
	MUIC_INT2 = 6,
	MUIC_INT3 = 7,
	GPIO_LOW = 8,
	GPIO_HI = 9,
	FLASH_STATUS = 10,
	MAX8997_IRQ_GROUP_NR = 11,
};

struct max8997_dev {
	struct device___15 *dev;
	struct max8997_platform_data *pdata;
	struct i2c_client___2 *i2c;
	struct i2c_client___2 *rtc;
	struct i2c_client___2 *haptic;
	struct i2c_client___2 *muic;
	struct mutex iolock;
	long unsigned int type;
	struct platform_device___33 *battery;
	int irq;
	int ono;
	struct irq_domain___9 *irq_domain;
	struct mutex irqlock;
	int irq_masks_cur[11];
	int irq_masks_cache[11];
	u8 reg_dump[187];
	bool gpio_status[12];
};

enum max8997_types {
	TYPE_MAX8997 = 0,
	TYPE_MAX8966 = 1,
};

enum max8997_irq {
	MAX8997_PMICIRQ_PWRONR = 0,
	MAX8997_PMICIRQ_PWRONF = 1,
	MAX8997_PMICIRQ_PWRON1SEC = 2,
	MAX8997_PMICIRQ_JIGONR = 3,
	MAX8997_PMICIRQ_JIGONF = 4,
	MAX8997_PMICIRQ_LOWBAT2 = 5,
	MAX8997_PMICIRQ_LOWBAT1 = 6,
	MAX8997_PMICIRQ_JIGR = 7,
	MAX8997_PMICIRQ_JIGF = 8,
	MAX8997_PMICIRQ_MR = 9,
	MAX8997_PMICIRQ_DVS1OK = 10,
	MAX8997_PMICIRQ_DVS2OK = 11,
	MAX8997_PMICIRQ_DVS3OK = 12,
	MAX8997_PMICIRQ_DVS4OK = 13,
	MAX8997_PMICIRQ_CHGINS = 14,
	MAX8997_PMICIRQ_CHGRM = 15,
	MAX8997_PMICIRQ_DCINOVP = 16,
	MAX8997_PMICIRQ_TOPOFFR = 17,
	MAX8997_PMICIRQ_CHGRSTF = 18,
	MAX8997_PMICIRQ_MBCHGTMEXPD = 19,
	MAX8997_PMICIRQ_RTC60S = 20,
	MAX8997_PMICIRQ_RTCA1 = 21,
	MAX8997_PMICIRQ_RTCA2 = 22,
	MAX8997_PMICIRQ_SMPL_INT = 23,
	MAX8997_PMICIRQ_RTC1S = 24,
	MAX8997_PMICIRQ_WTSR = 25,
	MAX8997_MUICIRQ_ADCError = 26,
	MAX8997_MUICIRQ_ADCLow = 27,
	MAX8997_MUICIRQ_ADC = 28,
	MAX8997_MUICIRQ_VBVolt = 29,
	MAX8997_MUICIRQ_DBChg = 30,
	MAX8997_MUICIRQ_DCDTmr = 31,
	MAX8997_MUICIRQ_ChgDetRun = 32,
	MAX8997_MUICIRQ_ChgTyp = 33,
	MAX8997_MUICIRQ_OVP = 34,
	MAX8997_IRQ_NR = 35,
};

struct max8997_irq_data {
	int mask;
	enum max8997_irq_source group;
};

struct max8998_regulator_data {
	int id;
	struct regulator_init_data *initdata;
	struct device_node___10 *reg_node;
};

struct max8998_platform_data {
	struct max8998_regulator_data *regulators;
	int num_regulators;
	unsigned int irq_base;
	int ono;
	bool buck_voltage_lock;
	int buck1_voltage[4];
	int buck2_voltage[2];
	int buck1_set1;
	int buck1_set2;
	int buck1_default_idx;
	int buck2_set3;
	int buck2_default_idx;
	bool wakeup;
	bool rtc_delay;
	int eoc;
	int restart;
	int timeout;
};

enum {
	MAX8998_REG_IRQ1 = 0,
	MAX8998_REG_IRQ2 = 1,
	MAX8998_REG_IRQ3 = 2,
	MAX8998_REG_IRQ4 = 3,
	MAX8998_REG_IRQM1 = 4,
	MAX8998_REG_IRQM2 = 5,
	MAX8998_REG_IRQM3 = 6,
	MAX8998_REG_IRQM4 = 7,
	MAX8998_REG_STATUS1 = 8,
	MAX8998_REG_STATUS2 = 9,
	MAX8998_REG_STATUSM1 = 10,
	MAX8998_REG_STATUSM2 = 11,
	MAX8998_REG_CHGR1 = 12,
	MAX8998_REG_CHGR2 = 13,
	MAX8998_REG_LDO_ACTIVE_DISCHARGE1 = 14,
	MAX8998_REG_LDO_ACTIVE_DISCHARGE2 = 15,
	MAX8998_REG_BUCK_ACTIVE_DISCHARGE3 = 16,
	MAX8998_REG_ONOFF1 = 17,
	MAX8998_REG_ONOFF2 = 18,
	MAX8998_REG_ONOFF3 = 19,
	MAX8998_REG_ONOFF4 = 20,
	MAX8998_REG_BUCK1_VOLTAGE1 = 21,
	MAX8998_REG_BUCK1_VOLTAGE2 = 22,
	MAX8998_REG_BUCK1_VOLTAGE3 = 23,
	MAX8998_REG_BUCK1_VOLTAGE4 = 24,
	MAX8998_REG_BUCK2_VOLTAGE1 = 25,
	MAX8998_REG_BUCK2_VOLTAGE2 = 26,
	MAX8998_REG_BUCK3 = 27,
	MAX8998_REG_BUCK4 = 28,
	MAX8998_REG_LDO2_LDO3 = 29,
	MAX8998_REG_LDO4 = 30,
	MAX8998_REG_LDO5 = 31,
	MAX8998_REG_LDO6 = 32,
	MAX8998_REG_LDO7 = 33,
	MAX8998_REG_LDO8_LDO9 = 34,
	MAX8998_REG_LDO10_LDO11 = 35,
	MAX8998_REG_LDO12 = 36,
	MAX8998_REG_LDO13 = 37,
	MAX8998_REG_LDO14 = 38,
	MAX8998_REG_LDO15 = 39,
	MAX8998_REG_LDO16 = 40,
	MAX8998_REG_LDO17 = 41,
	MAX8998_REG_BKCHR = 42,
	MAX8998_REG_LBCNFG1 = 43,
	MAX8998_REG_LBCNFG2 = 44,
};

enum {
	TYPE_MAX8998 = 0,
	TYPE_LP3974 = 1,
	TYPE_LP3979 = 2,
};

struct max8998_dev {
	struct device___15 *dev;
	struct max8998_platform_data *pdata;
	struct i2c_client___2 *i2c;
	struct i2c_client___2 *rtc;
	struct mutex iolock;
	struct mutex irqlock;
	unsigned int irq_base;
	struct irq_domain___9 *irq_domain;
	int irq;
	int ono;
	u8 irq_masks_cur[4];
	u8 irq_masks_cache[4];
	long unsigned int type;
	bool wakeup;
};

struct max8998_reg_dump {
	u8 addr;
	u8 val;
};

enum {
	MAX8998_IRQ_DCINF = 0,
	MAX8998_IRQ_DCINR = 1,
	MAX8998_IRQ_JIGF = 2,
	MAX8998_IRQ_JIGR = 3,
	MAX8998_IRQ_PWRONF = 4,
	MAX8998_IRQ_PWRONR = 5,
	MAX8998_IRQ_WTSREVNT = 6,
	MAX8998_IRQ_SMPLEVNT = 7,
	MAX8998_IRQ_ALARM1 = 8,
	MAX8998_IRQ_ALARM0 = 9,
	MAX8998_IRQ_ONKEY1S = 10,
	MAX8998_IRQ_TOPOFFR = 11,
	MAX8998_IRQ_DCINOVPR = 12,
	MAX8998_IRQ_CHGRSTF = 13,
	MAX8998_IRQ_DONER = 14,
	MAX8998_IRQ_CHGFAULT = 15,
	MAX8998_IRQ_LOBAT1 = 16,
	MAX8998_IRQ_LOBAT2 = 17,
	MAX8998_IRQ_NR = 18,
};

struct max8998_platform_data___2;

struct max8998_dev___2 {
	struct device___38 *dev;
	struct max8998_platform_data___2 *pdata;
	struct i2c_client *i2c;
	struct i2c_client *rtc;
	struct mutex iolock;
	struct mutex irqlock;
	unsigned int irq_base;
	struct irq_domain___13 *irq_domain;
	int irq;
	int ono;
	u8 irq_masks_cur[4];
	u8 irq_masks_cache[4];
	long unsigned int type;
	bool wakeup;
};

struct max8998_irq_data {
	int reg;
	int mask;
};

struct max8997_dev___2;

struct platform_device_info___6 {
	struct device___15 *parent;
	struct fwnode_handle___15 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct adp5520_gpio_platform_data {
	unsigned int gpio_start;
	u8 gpio_en_mask;
	u8 gpio_pullup_mask;
};

struct adp5520_keys_platform_data {
	int rows_en_mask;
	int cols_en_mask;
	const short unsigned int *keymap;
	short unsigned int keymapsize;
	unsigned int repeat: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct led_info;

struct adp5520_leds_platform_data {
	int num_leds;
	struct led_info *leds;
	u8 fade_in;
	u8 fade_out;
	u8 led_on_time;
};

struct adp5520_backlight_platform_data {
	u8 fade_in;
	u8 fade_out;
	u8 fade_led_law;
	u8 en_ambl_sens;
	u8 abml_filt;
	u8 l1_daylight_max;
	u8 l1_daylight_dim;
	u8 l2_office_max;
	u8 l2_office_dim;
	u8 l3_dark_max;
	u8 l3_dark_dim;
	u8 l2_trip;
	u8 l2_hyst;
	u8 l3_trip;
	u8 l3_hyst;
};

struct adp5520_platform_data {
	struct adp5520_keys_platform_data *keys;
	struct adp5520_gpio_platform_data *gpio;
	struct adp5520_leds_platform_data *leds;
	struct adp5520_backlight_platform_data *backlight;
};

struct adp5520_chip {
	struct i2c_client___2 *client;
	struct device___15 *dev;
	struct mutex lock;
	struct blocking_notifier_head notifier_list;
	int irq;
	long unsigned int id;
	uint8_t mode;
};

struct tps6586x_subdev_info___2 {
	int id;
	const char *name;
	void *platform_data;
	struct device_node___10 *of_node;
};

struct tps6586x_platform_data___2 {
	int num_subdevs;
	struct tps6586x_subdev_info___2 *subdevs;
	int gpio_base;
	int irq_base;
	bool pm_off;
	struct regulator_init_data *reg_init_data[15];
};

struct tps6586x_irq_data {
	u8 mask_reg;
	u8 mask_mask;
};

struct tps6586x {
	struct device___15 *dev;
	struct i2c_client___2 *client;
	struct regmap *regmap;
	int version;
	int irq;
	struct irq_chip___9 irq_chip;
	struct mutex irq_lock;
	int irq_base;
	u32 irq_en;
	u8 mask_reg[5];
	struct irq_domain___9 *irq_domain;
};

enum {
	TPS65090_IRQ_INTERRUPT = 0,
	TPS65090_IRQ_VAC_STATUS_CHANGE = 1,
	TPS65090_IRQ_VSYS_STATUS_CHANGE = 2,
	TPS65090_IRQ_BAT_STATUS_CHANGE = 3,
	TPS65090_IRQ_CHARGING_STATUS_CHANGE = 4,
	TPS65090_IRQ_CHARGING_COMPLETE = 5,
	TPS65090_IRQ_OVERLOAD_DCDC1 = 6,
	TPS65090_IRQ_OVERLOAD_DCDC2 = 7,
	TPS65090_IRQ_OVERLOAD_DCDC3 = 8,
	TPS65090_IRQ_OVERLOAD_FET1 = 9,
	TPS65090_IRQ_OVERLOAD_FET2 = 10,
	TPS65090_IRQ_OVERLOAD_FET3 = 11,
	TPS65090_IRQ_OVERLOAD_FET4 = 12,
	TPS65090_IRQ_OVERLOAD_FET5 = 13,
	TPS65090_IRQ_OVERLOAD_FET6 = 14,
	TPS65090_IRQ_OVERLOAD_FET7 = 15,
};

enum {
	TPS65090_REGULATOR_DCDC1 = 0,
	TPS65090_REGULATOR_DCDC2 = 1,
	TPS65090_REGULATOR_DCDC3 = 2,
	TPS65090_REGULATOR_FET1 = 3,
	TPS65090_REGULATOR_FET2 = 4,
	TPS65090_REGULATOR_FET3 = 5,
	TPS65090_REGULATOR_FET4 = 6,
	TPS65090_REGULATOR_FET5 = 7,
	TPS65090_REGULATOR_FET6 = 8,
	TPS65090_REGULATOR_FET7 = 9,
	TPS65090_REGULATOR_LDO1 = 10,
	TPS65090_REGULATOR_LDO2 = 11,
	TPS65090_REGULATOR_MAX = 12,
};

struct tps65090 {
	struct device___15 *dev;
	struct regmap *rmap;
	struct regmap_irq_chip_data *irq_data;
};

struct tps65090_regulator_plat_data {
	struct regulator_init_data *reg_init_data;
	bool enable_ext_control;
	struct gpio_desc *gpiod;
	bool overcurrent_wait_valid;
	int overcurrent_wait;
};

struct tps65090_platform_data {
	int irq_base;
	char **supplied_to;
	size_t num_supplicants;
	int enable_low_current_chrg;
	struct tps65090_regulator_plat_data *reg_pdata[12];
};

enum tps65090_cells {
	PMIC = 0,
	CHARGER = 1,
};

enum aat2870_id {
	AAT2870_ID_BL = 0,
	AAT2870_ID_LDOA = 1,
	AAT2870_ID_LDOB = 2,
	AAT2870_ID_LDOC = 3,
	AAT2870_ID_LDOD = 4,
};

struct aat2870_register {
	bool readable;
	bool writeable;
	u8 value;
};

struct aat2870_data {
	struct device___147 *dev;
	struct i2c_client___3 *client;
	struct mutex io_lock;
	struct aat2870_register *reg_cache;
	int en_pin;
	bool is_enable;
	int (*init)(struct aat2870_data *);
	void (*uninit)(struct aat2870_data *);
	int (*read)(struct aat2870_data *, u8, u8 *);
	int (*write)(struct aat2870_data *, u8, u8);
	int (*update)(struct aat2870_data *, u8, u8, u8);
	struct dentry___189 *dentry_root;
};

struct aat2870_subdev_info {
	int id;
	const char *name;
	void *platform_data;
};

struct aat2870_platform_data {
	int en_pin;
	struct aat2870_subdev_info *subdevs;
	int num_subdevs;
	int (*init)(struct aat2870_data *);
	void (*uninit)(struct aat2870_data *);
};

struct ww_acquire_ctx___7;

struct ww_mutex___5 {
	struct mutex base;
	struct ww_acquire_ctx___7 *ctx;
};

struct ww_acquire_ctx___7 {
	struct task_struct___19 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct regulator_dev___5;

struct regulator_ops___5 {
	int (*list_voltage)(struct regulator_dev___5 *, unsigned int);
	int (*set_voltage)(struct regulator_dev___5 *, int, int, unsigned int *);
	int (*map_voltage)(struct regulator_dev___5 *, int, int);
	int (*set_voltage_sel)(struct regulator_dev___5 *, unsigned int);
	int (*get_voltage)(struct regulator_dev___5 *);
	int (*get_voltage_sel)(struct regulator_dev___5 *);
	int (*set_current_limit)(struct regulator_dev___5 *, int, int);
	int (*get_current_limit)(struct regulator_dev___5 *);
	int (*set_input_current_limit)(struct regulator_dev___5 *, int);
	int (*set_over_current_protection)(struct regulator_dev___5 *, int, int, bool);
	int (*set_over_voltage_protection)(struct regulator_dev___5 *, int, int, bool);
	int (*set_under_voltage_protection)(struct regulator_dev___5 *, int, int, bool);
	int (*set_thermal_protection)(struct regulator_dev___5 *, int, int, bool);
	int (*set_active_discharge)(struct regulator_dev___5 *, bool);
	int (*enable)(struct regulator_dev___5 *);
	int (*disable)(struct regulator_dev___5 *);
	int (*is_enabled)(struct regulator_dev___5 *);
	int (*set_mode)(struct regulator_dev___5 *, unsigned int);
	unsigned int (*get_mode)(struct regulator_dev___5 *);
	int (*get_error_flags)(struct regulator_dev___5 *, unsigned int *);
	int (*enable_time)(struct regulator_dev___5 *);
	int (*set_ramp_delay)(struct regulator_dev___5 *, int);
	int (*set_voltage_time)(struct regulator_dev___5 *, int, int);
	int (*set_voltage_time_sel)(struct regulator_dev___5 *, unsigned int, unsigned int);
	int (*set_soft_start)(struct regulator_dev___5 *);
	int (*get_status)(struct regulator_dev___5 *);
	unsigned int (*get_optimum_mode)(struct regulator_dev___5 *, int, int, int);
	int (*set_load)(struct regulator_dev___5 *, int);
	int (*set_bypass)(struct regulator_dev___5 *, bool);
	int (*get_bypass)(struct regulator_dev___5 *, bool *);
	int (*set_suspend_voltage)(struct regulator_dev___5 *, int);
	int (*set_suspend_enable)(struct regulator_dev___5 *);
	int (*set_suspend_disable)(struct regulator_dev___5 *);
	int (*set_suspend_mode)(struct regulator_dev___5 *, unsigned int);
	int (*resume)(struct regulator_dev___5 *);
	int (*set_pull_down)(struct regulator_dev___5 *);
};

struct coupling_desc___5 {
	struct regulator_dev___5 **coupled_rdevs;
	struct regulator_coupler *coupler;
	int n_resolved;
	int n_coupled;
};

struct regulator_desc___5;

struct regulator_dev___5 {
	const struct regulator_desc___5 *desc;
	int exclusive;
	u32 use_count;
	u32 open_count;
	u32 bypass_count;
	struct list_head list;
	struct list_head consumer_list;
	struct coupling_desc___5 coupling_desc;
	struct blocking_notifier_head notifier;
	struct ww_mutex___5 mutex;
	struct task_struct___19 *mutex_owner;
	int ref_cnt;
	struct module___19 *owner;
	struct device___15 dev;
	struct regulation_constraints *constraints;
	struct regulator *supply;
	const char *supply_name;
	struct regmap *regmap;
	struct delayed_work disable_work;
	void *reg_data;
	struct dentry___18 *debugfs;
	struct regulator_enable_gpio *ena_pin;
	unsigned int ena_gpio_state: 1;
	unsigned int is_switch: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	ktime_t last_off;
	int cached_err;
	bool use_cached_err;
	spinlock_t err_lock;
};

struct regulator_config___4;

struct regulator_desc___5 {
	const char *name;
	const char *supply_name;
	const char *of_match;
	bool of_match_full_name;
	const char *regulators_node;
	int (*of_parse_cb)(struct device_node___10 *, const struct regulator_desc___5 *, struct regulator_config___4 *);
	int id;
	unsigned int continuous_voltage_range: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int n_voltages;
	unsigned int n_current_limits;
	const struct regulator_ops___5 *ops;
	int irq;
	enum regulator_type type;
	struct module___19 *owner;
	unsigned int min_uV;
	unsigned int uV_step;
	unsigned int linear_min_sel;
	int fixed_uV;
	unsigned int ramp_delay;
	int min_dropout_uV;
	const struct linear_range *linear_ranges;
	const unsigned int *linear_range_selectors;
	int n_linear_ranges;
	const unsigned int *volt_table;
	const unsigned int *curr_table;
	unsigned int vsel_range_reg;
	unsigned int vsel_range_mask;
	unsigned int vsel_reg;
	unsigned int vsel_mask;
	unsigned int vsel_step;
	unsigned int csel_reg;
	unsigned int csel_mask;
	unsigned int apply_reg;
	unsigned int apply_bit;
	unsigned int enable_reg;
	unsigned int enable_mask;
	unsigned int enable_val;
	unsigned int disable_val;
	bool enable_is_inverted;
	unsigned int bypass_reg;
	unsigned int bypass_mask;
	unsigned int bypass_val_on;
	unsigned int bypass_val_off;
	unsigned int active_discharge_on;
	unsigned int active_discharge_off;
	unsigned int active_discharge_mask;
	unsigned int active_discharge_reg;
	unsigned int soft_start_reg;
	unsigned int soft_start_mask;
	unsigned int soft_start_val_on;
	unsigned int pull_down_reg;
	unsigned int pull_down_mask;
	unsigned int pull_down_val_on;
	unsigned int ramp_reg;
	unsigned int ramp_mask;
	const unsigned int *ramp_delay_table;
	unsigned int n_ramp_values;
	unsigned int enable_time;
	unsigned int off_on_delay;
	unsigned int poll_enabled_time;
	unsigned int (*of_map_mode)(unsigned int);
};

struct regulator_config___4 {
	struct device___15 *dev;
	const struct regulator_init_data *init_data;
	void *driver_data;
	struct device_node___10 *of_node;
	struct regmap *regmap;
	struct gpio_desc *ena_gpiod;
};

struct palmas_pmic_driver_data___3;

struct palmas_pmic___3;

struct palmas_resource___3;

struct palmas_usb___3;

struct palmas___3 {
	struct device___15 *dev;
	struct i2c_client___2 *i2c_clients[3];
	struct regmap *regmap[3];
	int id;
	unsigned int features;
	int irq;
	u32 irq_mask;
	struct mutex irq_lock;
	struct regmap_irq_chip_data *irq_data;
	struct palmas_pmic_driver_data___3 *pmic_ddata;
	struct palmas_pmic___3 *pmic;
	struct palmas_gpadc *gpadc;
	struct palmas_resource___3 *resource;
	struct palmas_usb___3 *usb;
	u8 gpio_muxed;
	u8 led_muxed;
	u8 pwm_muxed;
};

struct palmas_pmic_driver_data___3 {
	int smps_start;
	int smps_end;
	int ldo_begin;
	int ldo_end;
	int max_reg;
	bool has_regen3;
	struct palmas_regs_info *palmas_regs_info;
	struct of_regulator_match *palmas_matches;
	struct palmas_sleep_requestor_info *sleep_req_info;
	int (*smps_register)(struct palmas_pmic___3 *, struct palmas_pmic_driver_data___3 *, struct palmas_pmic_platform_data *, const char *, struct regulator_config___4);
	int (*ldo_register)(struct palmas_pmic___3 *, struct palmas_pmic_driver_data___3 *, struct palmas_pmic_platform_data *, const char *, struct regulator_config___4);
};

struct palmas_pmic___3 {
	struct palmas___3 *palmas;
	struct device___15 *dev;
	struct regulator_desc___5 desc[27];
	struct mutex mutex;
	int smps123;
	int smps457;
	int smps12;
	int range[10];
	unsigned int ramp_delay[10];
	unsigned int current_reg_mode[10];
};

struct palmas_resource___3 {
	struct palmas___3 *palmas;
	struct device___15 *dev;
};

struct palmas_usb___3 {
	struct palmas___3 *palmas;
	struct device___15 *dev;
	struct extcon_dev *edev;
	int id_otg_irq;
	int id_irq;
	int vbus_otg_irq;
	int vbus_irq;
	int gpio_id_irq;
	int gpio_vbus_irq;
	struct gpio_desc *id_gpiod;
	struct gpio_desc *vbus_gpiod;
	long unsigned int sw_debounce_jiffies;
	struct delayed_work wq_detectid;
	enum palmas_usb_state linkstat;
	int wakeup;
	bool enable_vbus_detection;
	bool enable_id_detection;
	bool enable_gpio_id_detection;
	bool enable_gpio_vbus_detection;
};

enum {
	PALMAS_EXT_CONTROL_ENABLE1 = 1,
	PALMAS_EXT_CONTROL_ENABLE2 = 2,
	PALMAS_EXT_CONTROL_NSLEEP = 4,
};

enum palmas_external_requestor_id {
	PALMAS_EXTERNAL_REQSTR_ID_REGEN1 = 0,
	PALMAS_EXTERNAL_REQSTR_ID_REGEN2 = 1,
	PALMAS_EXTERNAL_REQSTR_ID_SYSEN1 = 2,
	PALMAS_EXTERNAL_REQSTR_ID_SYSEN2 = 3,
	PALMAS_EXTERNAL_REQSTR_ID_CLK32KG = 4,
	PALMAS_EXTERNAL_REQSTR_ID_CLK32KGAUDIO = 5,
	PALMAS_EXTERNAL_REQSTR_ID_REGEN3 = 6,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS12 = 7,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS3 = 8,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS45 = 9,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS6 = 10,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS7 = 11,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS8 = 12,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS9 = 13,
	PALMAS_EXTERNAL_REQSTR_ID_SMPS10 = 14,
	PALMAS_EXTERNAL_REQSTR_ID_LDO1 = 15,
	PALMAS_EXTERNAL_REQSTR_ID_LDO2 = 16,
	PALMAS_EXTERNAL_REQSTR_ID_LDO3 = 17,
	PALMAS_EXTERNAL_REQSTR_ID_LDO4 = 18,
	PALMAS_EXTERNAL_REQSTR_ID_LDO5 = 19,
	PALMAS_EXTERNAL_REQSTR_ID_LDO6 = 20,
	PALMAS_EXTERNAL_REQSTR_ID_LDO7 = 21,
	PALMAS_EXTERNAL_REQSTR_ID_LDO8 = 22,
	PALMAS_EXTERNAL_REQSTR_ID_LDO9 = 23,
	PALMAS_EXTERNAL_REQSTR_ID_LDOLN = 24,
	PALMAS_EXTERNAL_REQSTR_ID_LDOUSB = 25,
	PALMAS_EXTERNAL_REQSTR_ID_MAX = 26,
};

enum tps65917_irqs {
	TPS65917_RESERVED1 = 0,
	TPS65917_PWRON_IRQ = 1,
	TPS65917_LONG_PRESS_KEY_IRQ = 2,
	TPS65917_RESERVED2 = 3,
	TPS65917_PWRDOWN_IRQ = 4,
	TPS65917_HOTDIE_IRQ = 5,
	TPS65917_VSYS_MON_IRQ = 6,
	TPS65917_RESERVED3 = 7,
	TPS65917_RESERVED4 = 8,
	TPS65917_OTP_ERROR_IRQ = 9,
	TPS65917_WDT_IRQ = 10,
	TPS65917_RESERVED5 = 11,
	TPS65917_RESET_IN_IRQ = 12,
	TPS65917_FSD_IRQ = 13,
	TPS65917_SHORT_IRQ = 14,
	TPS65917_RESERVED6 = 15,
	TPS65917_GPADC_AUTO_0_IRQ = 16,
	TPS65917_GPADC_AUTO_1_IRQ = 17,
	TPS65917_GPADC_EOC_SW_IRQ = 18,
	TPS65917_RESREVED6 = 19,
	TPS65917_RESERVED7 = 20,
	TPS65917_RESERVED8 = 21,
	TPS65917_RESERVED9 = 22,
	TPS65917_VBUS_IRQ = 23,
	TPS65917_GPIO_0_IRQ = 24,
	TPS65917_GPIO_1_IRQ = 25,
	TPS65917_GPIO_2_IRQ = 26,
	TPS65917_GPIO_3_IRQ = 27,
	TPS65917_GPIO_4_IRQ = 28,
	TPS65917_GPIO_5_IRQ = 29,
	TPS65917_GPIO_6_IRQ = 30,
	TPS65917_RESERVED10 = 31,
	TPS65917_NUM_IRQ = 32,
};

struct palmas_driver_data {
	unsigned int *features;
	struct regmap_irq_chip *irq_chip;
};

enum {
	RC5T583_DS_NONE = 0,
	RC5T583_DS_DC0 = 1,
	RC5T583_DS_DC1 = 2,
	RC5T583_DS_DC2 = 3,
	RC5T583_DS_DC3 = 4,
	RC5T583_DS_LDO0 = 5,
	RC5T583_DS_LDO1 = 6,
	RC5T583_DS_LDO2 = 7,
	RC5T583_DS_LDO3 = 8,
	RC5T583_DS_LDO4 = 9,
	RC5T583_DS_LDO5 = 10,
	RC5T583_DS_LDO6 = 11,
	RC5T583_DS_LDO7 = 12,
	RC5T583_DS_LDO8 = 13,
	RC5T583_DS_LDO9 = 14,
	RC5T583_DS_PSO0 = 15,
	RC5T583_DS_PSO1 = 16,
	RC5T583_DS_PSO2 = 17,
	RC5T583_DS_PSO3 = 18,
	RC5T583_DS_PSO4 = 19,
	RC5T583_DS_PSO5 = 20,
	RC5T583_DS_PSO6 = 21,
	RC5T583_DS_PSO7 = 22,
	RC5T583_DS_MAX = 23,
};

enum {
	RC5T583_EXT_PWRREQ1_CONTROL = 1,
	RC5T583_EXT_PWRREQ2_CONTROL = 2,
};

struct rc5t583___2 {
	struct device___15 *dev;
	struct regmap *regmap;
	int chip_irq;
	int irq_base;
	struct mutex irq_lock;
	long unsigned int group_irq_en[5];
	uint8_t intc_inten_reg;
	uint8_t irq_en_reg[8];
	uint8_t gpedge_reg[2];
};

struct deepsleep_control_data {
	u8 reg_add;
	u8 ds_pos_bit;
};

enum int_type {
	SYS_INT = 1,
	DCDC_INT = 2,
	RTC_INT___2 = 4,
	ADC_INT = 8,
	GPIO_INT = 16,
};

struct rc5t583_irq_data {
	u8 int_type;
	u8 master_bit;
	u8 int_en_bit;
	u8 mask_reg_index;
	int grp_index;
};

enum sec_device_type {
	S5M8751X = 0,
	S5M8763X = 1,
	S5M8767X = 2,
	S2MPA01 = 3,
	S2MPS11X = 4,
	S2MPS13X = 5,
	S2MPS14X = 6,
	S2MPS15X = 7,
	S2MPU02 = 8,
};

struct sec_platform_data;

struct sec_pmic_dev {
	struct device___147 *dev;
	struct sec_platform_data *pdata;
	struct regmap *regmap_pmic;
	struct i2c_client___3 *i2c;
	long unsigned int device_type;
	int irq;
	struct regmap_irq_chip_data *irq_data;
};

struct sec_regulator_data;

struct sec_opmode_data;

struct sec_platform_data {
	struct sec_regulator_data *regulators;
	struct sec_opmode_data *opmode;
	int num_regulators;
	int buck_gpios[3];
	int buck_ds[3];
	unsigned int buck2_voltage[8];
	bool buck2_gpiodvs;
	unsigned int buck3_voltage[8];
	bool buck3_gpiodvs;
	unsigned int buck4_voltage[8];
	bool buck4_gpiodvs;
	int buck_default_idx;
	int buck_ramp_delay;
	bool buck2_ramp_enable;
	bool buck3_ramp_enable;
	bool buck4_ramp_enable;
	int buck2_init;
	int buck3_init;
	int buck4_init;
	bool manual_poweroff;
	bool disable_wrstbi;
};

struct sec_regulator_data {
	int id;
	struct regulator_init_data *initdata;
	struct device_node___49 *reg_node;
	struct gpio_desc *ext_control_gpiod;
};

struct sec_opmode_data {
	int id;
	unsigned int mode;
};

enum s2mpa01_reg {
	S2MPA01_REG_ID = 0,
	S2MPA01_REG_INT1 = 1,
	S2MPA01_REG_INT2 = 2,
	S2MPA01_REG_INT3 = 3,
	S2MPA01_REG_INT1M = 4,
	S2MPA01_REG_INT2M = 5,
	S2MPA01_REG_INT3M = 6,
	S2MPA01_REG_ST1 = 7,
	S2MPA01_REG_ST2 = 8,
	S2MPA01_REG_PWRONSRC = 9,
	S2MPA01_REG_OFFSRC = 10,
	S2MPA01_REG_RTC_BUF = 11,
	S2MPA01_REG_CTRL1 = 12,
	S2MPA01_REG_ETC_TEST = 13,
	S2MPA01_REG_RSVD1 = 14,
	S2MPA01_REG_BU_CHG = 15,
	S2MPA01_REG_RAMP1 = 16,
	S2MPA01_REG_RAMP2 = 17,
	S2MPA01_REG_LDO_DSCH1 = 18,
	S2MPA01_REG_LDO_DSCH2 = 19,
	S2MPA01_REG_LDO_DSCH3 = 20,
	S2MPA01_REG_LDO_DSCH4 = 21,
	S2MPA01_REG_OTP_ADRL = 22,
	S2MPA01_REG_OTP_ADRH = 23,
	S2MPA01_REG_OTP_DATA = 24,
	S2MPA01_REG_MON1SEL = 25,
	S2MPA01_REG_MON2SEL = 26,
	S2MPA01_REG_LEE = 27,
	S2MPA01_REG_RSVD2 = 28,
	S2MPA01_REG_RSVD3 = 29,
	S2MPA01_REG_RSVD4 = 30,
	S2MPA01_REG_RSVD5 = 31,
	S2MPA01_REG_RSVD6 = 32,
	S2MPA01_REG_TOP_RSVD = 33,
	S2MPA01_REG_DVS_SEL = 34,
	S2MPA01_REG_DVS_PTR = 35,
	S2MPA01_REG_DVS_DATA = 36,
	S2MPA01_REG_RSVD_NO = 37,
	S2MPA01_REG_UVLO = 38,
	S2MPA01_REG_LEE_NO = 39,
	S2MPA01_REG_B1CTRL1 = 40,
	S2MPA01_REG_B1CTRL2 = 41,
	S2MPA01_REG_B2CTRL1 = 42,
	S2MPA01_REG_B2CTRL2 = 43,
	S2MPA01_REG_B3CTRL1 = 44,
	S2MPA01_REG_B3CTRL2 = 45,
	S2MPA01_REG_B4CTRL1 = 46,
	S2MPA01_REG_B4CTRL2 = 47,
	S2MPA01_REG_B5CTRL1 = 48,
	S2MPA01_REG_B5CTRL2 = 49,
	S2MPA01_REG_B5CTRL3 = 50,
	S2MPA01_REG_B5CTRL4 = 51,
	S2MPA01_REG_B5CTRL5 = 52,
	S2MPA01_REG_B5CTRL6 = 53,
	S2MPA01_REG_B6CTRL1 = 54,
	S2MPA01_REG_B6CTRL2 = 55,
	S2MPA01_REG_B7CTRL1 = 56,
	S2MPA01_REG_B7CTRL2 = 57,
	S2MPA01_REG_B8CTRL1 = 58,
	S2MPA01_REG_B8CTRL2 = 59,
	S2MPA01_REG_B9CTRL1 = 60,
	S2MPA01_REG_B9CTRL2 = 61,
	S2MPA01_REG_B10CTRL1 = 62,
	S2MPA01_REG_B10CTRL2 = 63,
	S2MPA01_REG_L1CTRL = 64,
	S2MPA01_REG_L2CTRL = 65,
	S2MPA01_REG_L3CTRL = 66,
	S2MPA01_REG_L4CTRL = 67,
	S2MPA01_REG_L5CTRL = 68,
	S2MPA01_REG_L6CTRL = 69,
	S2MPA01_REG_L7CTRL = 70,
	S2MPA01_REG_L8CTRL = 71,
	S2MPA01_REG_L9CTRL = 72,
	S2MPA01_REG_L10CTRL = 73,
	S2MPA01_REG_L11CTRL = 74,
	S2MPA01_REG_L12CTRL = 75,
	S2MPA01_REG_L13CTRL = 76,
	S2MPA01_REG_L14CTRL = 77,
	S2MPA01_REG_L15CTRL = 78,
	S2MPA01_REG_L16CTRL = 79,
	S2MPA01_REG_L17CTRL = 80,
	S2MPA01_REG_L18CTRL = 81,
	S2MPA01_REG_L19CTRL = 82,
	S2MPA01_REG_L20CTRL = 83,
	S2MPA01_REG_L21CTRL = 84,
	S2MPA01_REG_L22CTRL = 85,
	S2MPA01_REG_L23CTRL = 86,
	S2MPA01_REG_L24CTRL = 87,
	S2MPA01_REG_L25CTRL = 88,
	S2MPA01_REG_L26CTRL = 89,
	S2MPA01_REG_LDO_OVCB1 = 90,
	S2MPA01_REG_LDO_OVCB2 = 91,
	S2MPA01_REG_LDO_OVCB3 = 92,
	S2MPA01_REG_LDO_OVCB4 = 93,
};

enum s2mps11_reg {
	S2MPS11_REG_ID = 0,
	S2MPS11_REG_INT1 = 1,
	S2MPS11_REG_INT2 = 2,
	S2MPS11_REG_INT3 = 3,
	S2MPS11_REG_INT1M = 4,
	S2MPS11_REG_INT2M = 5,
	S2MPS11_REG_INT3M = 6,
	S2MPS11_REG_ST1 = 7,
	S2MPS11_REG_ST2 = 8,
	S2MPS11_REG_OFFSRC = 9,
	S2MPS11_REG_PWRONSRC = 10,
	S2MPS11_REG_RTC_CTRL = 11,
	S2MPS11_REG_CTRL1 = 12,
	S2MPS11_REG_ETC_TEST = 13,
	S2MPS11_REG_RSVD3 = 14,
	S2MPS11_REG_BU_CHG = 15,
	S2MPS11_REG_RAMP = 16,
	S2MPS11_REG_RAMP_BUCK = 17,
	S2MPS11_REG_LDO1_8 = 18,
	S2MPS11_REG_LDO9_16 = 19,
	S2MPS11_REG_LDO17_24 = 20,
	S2MPS11_REG_LDO25_32 = 21,
	S2MPS11_REG_LDO33_38 = 22,
	S2MPS11_REG_LDO1_8_1 = 23,
	S2MPS11_REG_LDO9_16_1 = 24,
	S2MPS11_REG_LDO17_24_1 = 25,
	S2MPS11_REG_LDO25_32_1 = 26,
	S2MPS11_REG_LDO33_38_1 = 27,
	S2MPS11_REG_OTP_ADRL = 28,
	S2MPS11_REG_OTP_ADRH = 29,
	S2MPS11_REG_OTP_DATA = 30,
	S2MPS11_REG_MON1SEL = 31,
	S2MPS11_REG_MON2SEL = 32,
	S2MPS11_REG_LEE = 33,
	S2MPS11_REG_RSVD_NO = 34,
	S2MPS11_REG_UVLO = 35,
	S2MPS11_REG_LEE_NO = 36,
	S2MPS11_REG_B1CTRL1 = 37,
	S2MPS11_REG_B1CTRL2 = 38,
	S2MPS11_REG_B2CTRL1 = 39,
	S2MPS11_REG_B2CTRL2 = 40,
	S2MPS11_REG_B3CTRL1 = 41,
	S2MPS11_REG_B3CTRL2 = 42,
	S2MPS11_REG_B4CTRL1 = 43,
	S2MPS11_REG_B4CTRL2 = 44,
	S2MPS11_REG_B5CTRL1 = 45,
	S2MPS11_REG_BUCK5_SW = 46,
	S2MPS11_REG_B5CTRL2 = 47,
	S2MPS11_REG_B5CTRL3 = 48,
	S2MPS11_REG_B5CTRL4 = 49,
	S2MPS11_REG_B5CTRL5 = 50,
	S2MPS11_REG_B6CTRL1 = 51,
	S2MPS11_REG_B6CTRL2 = 52,
	S2MPS11_REG_B7CTRL1 = 53,
	S2MPS11_REG_B7CTRL2 = 54,
	S2MPS11_REG_B8CTRL1 = 55,
	S2MPS11_REG_B8CTRL2 = 56,
	S2MPS11_REG_B9CTRL1 = 57,
	S2MPS11_REG_B9CTRL2 = 58,
	S2MPS11_REG_B10CTRL1 = 59,
	S2MPS11_REG_B10CTRL2 = 60,
	S2MPS11_REG_L1CTRL = 61,
	S2MPS11_REG_L2CTRL = 62,
	S2MPS11_REG_L3CTRL = 63,
	S2MPS11_REG_L4CTRL = 64,
	S2MPS11_REG_L5CTRL = 65,
	S2MPS11_REG_L6CTRL = 66,
	S2MPS11_REG_L7CTRL = 67,
	S2MPS11_REG_L8CTRL = 68,
	S2MPS11_REG_L9CTRL = 69,
	S2MPS11_REG_L10CTRL = 70,
	S2MPS11_REG_L11CTRL = 71,
	S2MPS11_REG_L12CTRL = 72,
	S2MPS11_REG_L13CTRL = 73,
	S2MPS11_REG_L14CTRL = 74,
	S2MPS11_REG_L15CTRL = 75,
	S2MPS11_REG_L16CTRL = 76,
	S2MPS11_REG_L17CTRL = 77,
	S2MPS11_REG_L18CTRL = 78,
	S2MPS11_REG_L19CTRL = 79,
	S2MPS11_REG_L20CTRL = 80,
	S2MPS11_REG_L21CTRL = 81,
	S2MPS11_REG_L22CTRL = 82,
	S2MPS11_REG_L23CTRL = 83,
	S2MPS11_REG_L24CTRL = 84,
	S2MPS11_REG_L25CTRL = 85,
	S2MPS11_REG_L26CTRL = 86,
	S2MPS11_REG_L27CTRL = 87,
	S2MPS11_REG_L28CTRL = 88,
	S2MPS11_REG_L29CTRL = 89,
	S2MPS11_REG_L30CTRL = 90,
	S2MPS11_REG_L31CTRL = 91,
	S2MPS11_REG_L32CTRL = 92,
	S2MPS11_REG_L33CTRL = 93,
	S2MPS11_REG_L34CTRL = 94,
	S2MPS11_REG_L35CTRL = 95,
	S2MPS11_REG_L36CTRL = 96,
	S2MPS11_REG_L37CTRL = 97,
	S2MPS11_REG_L38CTRL = 98,
};

enum s2mps13_reg {
	S2MPS13_REG_ID = 0,
	S2MPS13_REG_INT1 = 1,
	S2MPS13_REG_INT2 = 2,
	S2MPS13_REG_INT3 = 3,
	S2MPS13_REG_INT1M = 4,
	S2MPS13_REG_INT2M = 5,
	S2MPS13_REG_INT3M = 6,
	S2MPS13_REG_ST1 = 7,
	S2MPS13_REG_ST2 = 8,
	S2MPS13_REG_PWRONSRC = 9,
	S2MPS13_REG_OFFSRC = 10,
	S2MPS13_REG_BU_CHG = 11,
	S2MPS13_REG_RTCCTRL = 12,
	S2MPS13_REG_CTRL1 = 13,
	S2MPS13_REG_CTRL2 = 14,
	S2MPS13_REG_RSVD1 = 15,
	S2MPS13_REG_RSVD2 = 16,
	S2MPS13_REG_RSVD3 = 17,
	S2MPS13_REG_RSVD4 = 18,
	S2MPS13_REG_RSVD5 = 19,
	S2MPS13_REG_RSVD6 = 20,
	S2MPS13_REG_CTRL3 = 21,
	S2MPS13_REG_RSVD7 = 22,
	S2MPS13_REG_RSVD8 = 23,
	S2MPS13_REG_WRSTBI = 24,
	S2MPS13_REG_B1CTRL = 25,
	S2MPS13_REG_B1OUT = 26,
	S2MPS13_REG_B2CTRL = 27,
	S2MPS13_REG_B2OUT = 28,
	S2MPS13_REG_B3CTRL = 29,
	S2MPS13_REG_B3OUT = 30,
	S2MPS13_REG_B4CTRL = 31,
	S2MPS13_REG_B4OUT = 32,
	S2MPS13_REG_B5CTRL = 33,
	S2MPS13_REG_B5OUT = 34,
	S2MPS13_REG_B6CTRL = 35,
	S2MPS13_REG_B6OUT = 36,
	S2MPS13_REG_B7CTRL = 37,
	S2MPS13_REG_B7SW = 38,
	S2MPS13_REG_B7OUT = 39,
	S2MPS13_REG_B8CTRL = 40,
	S2MPS13_REG_B8OUT = 41,
	S2MPS13_REG_B9CTRL = 42,
	S2MPS13_REG_B9OUT = 43,
	S2MPS13_REG_B10CTRL = 44,
	S2MPS13_REG_B10OUT = 45,
	S2MPS13_REG_BB1CTRL = 46,
	S2MPS13_REG_BB1OUT = 47,
	S2MPS13_REG_BUCK_RAMP1 = 48,
	S2MPS13_REG_BUCK_RAMP2 = 49,
	S2MPS13_REG_LDO_DVS1 = 50,
	S2MPS13_REG_LDO_DVS2 = 51,
	S2MPS13_REG_LDO_DVS3 = 52,
	S2MPS13_REG_B6OUT2 = 53,
	S2MPS13_REG_L1CTRL = 54,
	S2MPS13_REG_L2CTRL = 55,
	S2MPS13_REG_L3CTRL = 56,
	S2MPS13_REG_L4CTRL = 57,
	S2MPS13_REG_L5CTRL = 58,
	S2MPS13_REG_L6CTRL = 59,
	S2MPS13_REG_L7CTRL = 60,
	S2MPS13_REG_L8CTRL = 61,
	S2MPS13_REG_L9CTRL = 62,
	S2MPS13_REG_L10CTRL = 63,
	S2MPS13_REG_L11CTRL = 64,
	S2MPS13_REG_L12CTRL = 65,
	S2MPS13_REG_L13CTRL = 66,
	S2MPS13_REG_L14CTRL = 67,
	S2MPS13_REG_L15CTRL = 68,
	S2MPS13_REG_L16CTRL = 69,
	S2MPS13_REG_L17CTRL = 70,
	S2MPS13_REG_L18CTRL = 71,
	S2MPS13_REG_L19CTRL = 72,
	S2MPS13_REG_L20CTRL = 73,
	S2MPS13_REG_L21CTRL = 74,
	S2MPS13_REG_L22CTRL = 75,
	S2MPS13_REG_L23CTRL = 76,
	S2MPS13_REG_L24CTRL = 77,
	S2MPS13_REG_L25CTRL = 78,
	S2MPS13_REG_L26CTRL = 79,
	S2MPS13_REG_L27CTRL = 80,
	S2MPS13_REG_L28CTRL = 81,
	S2MPS13_REG_L29CTRL = 82,
	S2MPS13_REG_L30CTRL = 83,
	S2MPS13_REG_L31CTRL = 84,
	S2MPS13_REG_L32CTRL = 85,
	S2MPS13_REG_L33CTRL = 86,
	S2MPS13_REG_L34CTRL = 87,
	S2MPS13_REG_L35CTRL = 88,
	S2MPS13_REG_L36CTRL = 89,
	S2MPS13_REG_L37CTRL = 90,
	S2MPS13_REG_L38CTRL = 91,
	S2MPS13_REG_L39CTRL = 92,
	S2MPS13_REG_L40CTRL = 93,
	S2MPS13_REG_LDODSCH1 = 94,
	S2MPS13_REG_LDODSCH2 = 95,
	S2MPS13_REG_LDODSCH3 = 96,
	S2MPS13_REG_LDODSCH4 = 97,
	S2MPS13_REG_LDODSCH5 = 98,
};

enum s2mps14_reg {
	S2MPS14_REG_ID = 0,
	S2MPS14_REG_INT1 = 1,
	S2MPS14_REG_INT2 = 2,
	S2MPS14_REG_INT3 = 3,
	S2MPS14_REG_INT1M = 4,
	S2MPS14_REG_INT2M = 5,
	S2MPS14_REG_INT3M = 6,
	S2MPS14_REG_ST1 = 7,
	S2MPS14_REG_ST2 = 8,
	S2MPS14_REG_PWRONSRC = 9,
	S2MPS14_REG_OFFSRC = 10,
	S2MPS14_REG_BU_CHG = 11,
	S2MPS14_REG_RTCCTRL = 12,
	S2MPS14_REG_CTRL1 = 13,
	S2MPS14_REG_CTRL2 = 14,
	S2MPS14_REG_RSVD1 = 15,
	S2MPS14_REG_RSVD2 = 16,
	S2MPS14_REG_RSVD3 = 17,
	S2MPS14_REG_RSVD4 = 18,
	S2MPS14_REG_RSVD5 = 19,
	S2MPS14_REG_RSVD6 = 20,
	S2MPS14_REG_CTRL3 = 21,
	S2MPS14_REG_RSVD7 = 22,
	S2MPS14_REG_RSVD8 = 23,
	S2MPS14_REG_WRSTBI = 24,
	S2MPS14_REG_B1CTRL1 = 25,
	S2MPS14_REG_B1CTRL2 = 26,
	S2MPS14_REG_B2CTRL1 = 27,
	S2MPS14_REG_B2CTRL2 = 28,
	S2MPS14_REG_B3CTRL1 = 29,
	S2MPS14_REG_B3CTRL2 = 30,
	S2MPS14_REG_B4CTRL1 = 31,
	S2MPS14_REG_B4CTRL2 = 32,
	S2MPS14_REG_B5CTRL1 = 33,
	S2MPS14_REG_B5CTRL2 = 34,
	S2MPS14_REG_L1CTRL = 35,
	S2MPS14_REG_L2CTRL = 36,
	S2MPS14_REG_L3CTRL = 37,
	S2MPS14_REG_L4CTRL = 38,
	S2MPS14_REG_L5CTRL = 39,
	S2MPS14_REG_L6CTRL = 40,
	S2MPS14_REG_L7CTRL = 41,
	S2MPS14_REG_L8CTRL = 42,
	S2MPS14_REG_L9CTRL = 43,
	S2MPS14_REG_L10CTRL = 44,
	S2MPS14_REG_L11CTRL = 45,
	S2MPS14_REG_L12CTRL = 46,
	S2MPS14_REG_L13CTRL = 47,
	S2MPS14_REG_L14CTRL = 48,
	S2MPS14_REG_L15CTRL = 49,
	S2MPS14_REG_L16CTRL = 50,
	S2MPS14_REG_L17CTRL = 51,
	S2MPS14_REG_L18CTRL = 52,
	S2MPS14_REG_L19CTRL = 53,
	S2MPS14_REG_L20CTRL = 54,
	S2MPS14_REG_L21CTRL = 55,
	S2MPS14_REG_L22CTRL = 56,
	S2MPS14_REG_L23CTRL = 57,
	S2MPS14_REG_L24CTRL = 58,
	S2MPS14_REG_L25CTRL = 59,
	S2MPS14_REG_LDODSCH1 = 60,
	S2MPS14_REG_LDODSCH2 = 61,
	S2MPS14_REG_LDODSCH3 = 62,
};

enum s2mps15_reg {
	S2MPS15_REG_ID = 0,
	S2MPS15_REG_INT1 = 1,
	S2MPS15_REG_INT2 = 2,
	S2MPS15_REG_INT3 = 3,
	S2MPS15_REG_INT1M = 4,
	S2MPS15_REG_INT2M = 5,
	S2MPS15_REG_INT3M = 6,
	S2MPS15_REG_ST1 = 7,
	S2MPS15_REG_ST2 = 8,
	S2MPS15_REG_PWRONSRC = 9,
	S2MPS15_REG_OFFSRC = 10,
	S2MPS15_REG_BU_CHG = 11,
	S2MPS15_REG_RTC_BUF = 12,
	S2MPS15_REG_CTRL1 = 13,
	S2MPS15_REG_CTRL2 = 14,
	S2MPS15_REG_RSVD1 = 15,
	S2MPS15_REG_RSVD2 = 16,
	S2MPS15_REG_RSVD3 = 17,
	S2MPS15_REG_RSVD4 = 18,
	S2MPS15_REG_RSVD5 = 19,
	S2MPS15_REG_RSVD6 = 20,
	S2MPS15_REG_CTRL3 = 21,
	S2MPS15_REG_RSVD7 = 22,
	S2MPS15_REG_RSVD8 = 23,
	S2MPS15_REG_RSVD9 = 24,
	S2MPS15_REG_B1CTRL1 = 25,
	S2MPS15_REG_B1CTRL2 = 26,
	S2MPS15_REG_B2CTRL1 = 27,
	S2MPS15_REG_B2CTRL2 = 28,
	S2MPS15_REG_B3CTRL1 = 29,
	S2MPS15_REG_B3CTRL2 = 30,
	S2MPS15_REG_B4CTRL1 = 31,
	S2MPS15_REG_B4CTRL2 = 32,
	S2MPS15_REG_B5CTRL1 = 33,
	S2MPS15_REG_B5CTRL2 = 34,
	S2MPS15_REG_B6CTRL1 = 35,
	S2MPS15_REG_B6CTRL2 = 36,
	S2MPS15_REG_B7CTRL1 = 37,
	S2MPS15_REG_B7CTRL2 = 38,
	S2MPS15_REG_B8CTRL1 = 39,
	S2MPS15_REG_B8CTRL2 = 40,
	S2MPS15_REG_B9CTRL1 = 41,
	S2MPS15_REG_B9CTRL2 = 42,
	S2MPS15_REG_B10CTRL1 = 43,
	S2MPS15_REG_B10CTRL2 = 44,
	S2MPS15_REG_BBCTRL1 = 45,
	S2MPS15_REG_BBCTRL2 = 46,
	S2MPS15_REG_BRAMP = 47,
	S2MPS15_REG_LDODVS1 = 48,
	S2MPS15_REG_LDODVS2 = 49,
	S2MPS15_REG_LDODVS3 = 50,
	S2MPS15_REG_LDODVS4 = 51,
	S2MPS15_REG_L1CTRL = 52,
	S2MPS15_REG_L2CTRL = 53,
	S2MPS15_REG_L3CTRL = 54,
	S2MPS15_REG_L4CTRL = 55,
	S2MPS15_REG_L5CTRL = 56,
	S2MPS15_REG_L6CTRL = 57,
	S2MPS15_REG_L7CTRL = 58,
	S2MPS15_REG_L8CTRL = 59,
	S2MPS15_REG_L9CTRL = 60,
	S2MPS15_REG_L10CTRL = 61,
	S2MPS15_REG_L11CTRL = 62,
	S2MPS15_REG_L12CTRL = 63,
	S2MPS15_REG_L13CTRL = 64,
	S2MPS15_REG_L14CTRL = 65,
	S2MPS15_REG_L15CTRL = 66,
	S2MPS15_REG_L16CTRL = 67,
	S2MPS15_REG_L17CTRL = 68,
	S2MPS15_REG_L18CTRL = 69,
	S2MPS15_REG_L19CTRL = 70,
	S2MPS15_REG_L20CTRL = 71,
	S2MPS15_REG_L21CTRL = 72,
	S2MPS15_REG_L22CTRL = 73,
	S2MPS15_REG_L23CTRL = 74,
	S2MPS15_REG_L24CTRL = 75,
	S2MPS15_REG_L25CTRL = 76,
	S2MPS15_REG_L26CTRL = 77,
	S2MPS15_REG_L27CTRL = 78,
	S2MPS15_REG_LDODSCH1 = 79,
	S2MPS15_REG_LDODSCH2 = 80,
	S2MPS15_REG_LDODSCH3 = 81,
	S2MPS15_REG_LDODSCH4 = 82,
};

enum S2MPU02_reg {
	S2MPU02_REG_ID = 0,
	S2MPU02_REG_INT1 = 1,
	S2MPU02_REG_INT2 = 2,
	S2MPU02_REG_INT3 = 3,
	S2MPU02_REG_INT1M = 4,
	S2MPU02_REG_INT2M = 5,
	S2MPU02_REG_INT3M = 6,
	S2MPU02_REG_ST1 = 7,
	S2MPU02_REG_ST2 = 8,
	S2MPU02_REG_PWRONSRC = 9,
	S2MPU02_REG_OFFSRC = 10,
	S2MPU02_REG_BU_CHG = 11,
	S2MPU02_REG_RTCCTRL = 12,
	S2MPU02_REG_PMCTRL1 = 13,
	S2MPU02_REG_RSVD1 = 14,
	S2MPU02_REG_RSVD2 = 15,
	S2MPU02_REG_RSVD3 = 16,
	S2MPU02_REG_RSVD4 = 17,
	S2MPU02_REG_RSVD5 = 18,
	S2MPU02_REG_RSVD6 = 19,
	S2MPU02_REG_RSVD7 = 20,
	S2MPU02_REG_WRSTEN = 21,
	S2MPU02_REG_RSVD8 = 22,
	S2MPU02_REG_RSVD9 = 23,
	S2MPU02_REG_RSVD10 = 24,
	S2MPU02_REG_B1CTRL1 = 25,
	S2MPU02_REG_B1CTRL2 = 26,
	S2MPU02_REG_B2CTRL1 = 27,
	S2MPU02_REG_B2CTRL2 = 28,
	S2MPU02_REG_B3CTRL1 = 29,
	S2MPU02_REG_B3CTRL2 = 30,
	S2MPU02_REG_B4CTRL1 = 31,
	S2MPU02_REG_B4CTRL2 = 32,
	S2MPU02_REG_B5CTRL1 = 33,
	S2MPU02_REG_B5CTRL2 = 34,
	S2MPU02_REG_B5CTRL3 = 35,
	S2MPU02_REG_B5CTRL4 = 36,
	S2MPU02_REG_B5CTRL5 = 37,
	S2MPU02_REG_B6CTRL1 = 38,
	S2MPU02_REG_B6CTRL2 = 39,
	S2MPU02_REG_B7CTRL1 = 40,
	S2MPU02_REG_B7CTRL2 = 41,
	S2MPU02_REG_RAMP1 = 42,
	S2MPU02_REG_RAMP2 = 43,
	S2MPU02_REG_L1CTRL = 44,
	S2MPU02_REG_L2CTRL1 = 45,
	S2MPU02_REG_L2CTRL2 = 46,
	S2MPU02_REG_L2CTRL3 = 47,
	S2MPU02_REG_L2CTRL4 = 48,
	S2MPU02_REG_L3CTRL = 49,
	S2MPU02_REG_L4CTRL = 50,
	S2MPU02_REG_L5CTRL = 51,
	S2MPU02_REG_L6CTRL = 52,
	S2MPU02_REG_L7CTRL = 53,
	S2MPU02_REG_L8CTRL = 54,
	S2MPU02_REG_L9CTRL = 55,
	S2MPU02_REG_L10CTRL = 56,
	S2MPU02_REG_L11CTRL = 57,
	S2MPU02_REG_L12CTRL = 58,
	S2MPU02_REG_L13CTRL = 59,
	S2MPU02_REG_L14CTRL = 60,
	S2MPU02_REG_L15CTRL = 61,
	S2MPU02_REG_L16CTRL = 62,
	S2MPU02_REG_L17CTRL = 63,
	S2MPU02_REG_L18CTRL = 64,
	S2MPU02_REG_L19CTRL = 65,
	S2MPU02_REG_L20CTRL = 66,
	S2MPU02_REG_L21CTRL = 67,
	S2MPU02_REG_L22CTRL = 68,
	S2MPU02_REG_L23CTRL = 69,
	S2MPU02_REG_L24CTRL = 70,
	S2MPU02_REG_L25CTRL = 71,
	S2MPU02_REG_L26CTRL = 72,
	S2MPU02_REG_L27CTRL = 73,
	S2MPU02_REG_L28CTRL = 74,
	S2MPU02_REG_LDODSCH1 = 75,
	S2MPU02_REG_LDODSCH2 = 76,
	S2MPU02_REG_LDODSCH3 = 77,
	S2MPU02_REG_LDODSCH4 = 78,
	S2MPU02_REG_SELMIF = 79,
	S2MPU02_REG_RSVD11 = 80,
	S2MPU02_REG_RSVD12 = 81,
	S2MPU02_REG_RSVD13 = 82,
	S2MPU02_REG_DVSSEL = 83,
	S2MPU02_REG_DVSPTR = 84,
	S2MPU02_REG_DVSDATA = 85,
};

enum s5m8763_reg {
	S5M8763_REG_IRQ1 = 0,
	S5M8763_REG_IRQ2 = 1,
	S5M8763_REG_IRQ3 = 2,
	S5M8763_REG_IRQ4 = 3,
	S5M8763_REG_IRQM1 = 4,
	S5M8763_REG_IRQM2 = 5,
	S5M8763_REG_IRQM3 = 6,
	S5M8763_REG_IRQM4 = 7,
	S5M8763_REG_STATUS1 = 8,
	S5M8763_REG_STATUS2 = 9,
	S5M8763_REG_STATUSM1 = 10,
	S5M8763_REG_STATUSM2 = 11,
	S5M8763_REG_CHGR1 = 12,
	S5M8763_REG_CHGR2 = 13,
	S5M8763_REG_LDO_ACTIVE_DISCHARGE1 = 14,
	S5M8763_REG_LDO_ACTIVE_DISCHARGE2 = 15,
	S5M8763_REG_BUCK_ACTIVE_DISCHARGE3 = 16,
	S5M8763_REG_ONOFF1 = 17,
	S5M8763_REG_ONOFF2 = 18,
	S5M8763_REG_ONOFF3 = 19,
	S5M8763_REG_ONOFF4 = 20,
	S5M8763_REG_BUCK1_VOLTAGE1 = 21,
	S5M8763_REG_BUCK1_VOLTAGE2 = 22,
	S5M8763_REG_BUCK1_VOLTAGE3 = 23,
	S5M8763_REG_BUCK1_VOLTAGE4 = 24,
	S5M8763_REG_BUCK2_VOLTAGE1 = 25,
	S5M8763_REG_BUCK2_VOLTAGE2 = 26,
	S5M8763_REG_BUCK3 = 27,
	S5M8763_REG_BUCK4 = 28,
	S5M8763_REG_LDO1_LDO2 = 29,
	S5M8763_REG_LDO3 = 30,
	S5M8763_REG_LDO4 = 31,
	S5M8763_REG_LDO5 = 32,
	S5M8763_REG_LDO6 = 33,
	S5M8763_REG_LDO7 = 34,
	S5M8763_REG_LDO7_LDO8 = 35,
	S5M8763_REG_LDO9_LDO10 = 36,
	S5M8763_REG_LDO11 = 37,
	S5M8763_REG_LDO12 = 38,
	S5M8763_REG_LDO13 = 39,
	S5M8763_REG_LDO14 = 40,
	S5M8763_REG_LDO15 = 41,
	S5M8763_REG_LDO16 = 42,
	S5M8763_REG_BKCHR = 43,
	S5M8763_REG_LBCNFG1 = 44,
	S5M8763_REG_LBCNFG2 = 45,
};

enum s5m8767_reg {
	S5M8767_REG_ID = 0,
	S5M8767_REG_INT1 = 1,
	S5M8767_REG_INT2 = 2,
	S5M8767_REG_INT3 = 3,
	S5M8767_REG_INT1M = 4,
	S5M8767_REG_INT2M = 5,
	S5M8767_REG_INT3M = 6,
	S5M8767_REG_STATUS1 = 7,
	S5M8767_REG_STATUS2 = 8,
	S5M8767_REG_STATUS3 = 9,
	S5M8767_REG_CTRL1 = 10,
	S5M8767_REG_CTRL2 = 11,
	S5M8767_REG_LOWBAT1 = 12,
	S5M8767_REG_LOWBAT2 = 13,
	S5M8767_REG_BUCHG = 14,
	S5M8767_REG_DVSRAMP = 15,
	S5M8767_REG_DVSTIMER2 = 16,
	S5M8767_REG_DVSTIMER3 = 17,
	S5M8767_REG_DVSTIMER4 = 18,
	S5M8767_REG_LDO1 = 19,
	S5M8767_REG_LDO2 = 20,
	S5M8767_REG_LDO3 = 21,
	S5M8767_REG_LDO4 = 22,
	S5M8767_REG_LDO5 = 23,
	S5M8767_REG_LDO6 = 24,
	S5M8767_REG_LDO7 = 25,
	S5M8767_REG_LDO8 = 26,
	S5M8767_REG_LDO9 = 27,
	S5M8767_REG_LDO10 = 28,
	S5M8767_REG_LDO11 = 29,
	S5M8767_REG_LDO12 = 30,
	S5M8767_REG_LDO13 = 31,
	S5M8767_REG_LDO14 = 32,
	S5M8767_REG_LDO15 = 33,
	S5M8767_REG_LDO16 = 34,
	S5M8767_REG_LDO17 = 35,
	S5M8767_REG_LDO18 = 36,
	S5M8767_REG_LDO19 = 37,
	S5M8767_REG_LDO20 = 38,
	S5M8767_REG_LDO21 = 39,
	S5M8767_REG_LDO22 = 40,
	S5M8767_REG_LDO23 = 41,
	S5M8767_REG_LDO24 = 42,
	S5M8767_REG_LDO25 = 43,
	S5M8767_REG_LDO26 = 44,
	S5M8767_REG_LDO27 = 45,
	S5M8767_REG_LDO28 = 46,
	S5M8767_REG_UVLO = 49,
	S5M8767_REG_BUCK1CTRL1 = 50,
	S5M8767_REG_BUCK1CTRL2 = 51,
	S5M8767_REG_BUCK2CTRL = 52,
	S5M8767_REG_BUCK2DVS1 = 53,
	S5M8767_REG_BUCK2DVS2 = 54,
	S5M8767_REG_BUCK2DVS3 = 55,
	S5M8767_REG_BUCK2DVS4 = 56,
	S5M8767_REG_BUCK2DVS5 = 57,
	S5M8767_REG_BUCK2DVS6 = 58,
	S5M8767_REG_BUCK2DVS7 = 59,
	S5M8767_REG_BUCK2DVS8 = 60,
	S5M8767_REG_BUCK3CTRL = 61,
	S5M8767_REG_BUCK3DVS1 = 62,
	S5M8767_REG_BUCK3DVS2 = 63,
	S5M8767_REG_BUCK3DVS3 = 64,
	S5M8767_REG_BUCK3DVS4 = 65,
	S5M8767_REG_BUCK3DVS5 = 66,
	S5M8767_REG_BUCK3DVS6 = 67,
	S5M8767_REG_BUCK3DVS7 = 68,
	S5M8767_REG_BUCK3DVS8 = 69,
	S5M8767_REG_BUCK4CTRL = 70,
	S5M8767_REG_BUCK4DVS1 = 71,
	S5M8767_REG_BUCK4DVS2 = 72,
	S5M8767_REG_BUCK4DVS3 = 73,
	S5M8767_REG_BUCK4DVS4 = 74,
	S5M8767_REG_BUCK4DVS5 = 75,
	S5M8767_REG_BUCK4DVS6 = 76,
	S5M8767_REG_BUCK4DVS7 = 77,
	S5M8767_REG_BUCK4DVS8 = 78,
	S5M8767_REG_BUCK5CTRL1 = 79,
	S5M8767_REG_BUCK5CTRL2 = 80,
	S5M8767_REG_BUCK5CTRL3 = 81,
	S5M8767_REG_BUCK5CTRL4 = 82,
	S5M8767_REG_BUCK5CTRL5 = 83,
	S5M8767_REG_BUCK6CTRL1 = 84,
	S5M8767_REG_BUCK6CTRL2 = 85,
	S5M8767_REG_BUCK7CTRL1 = 86,
	S5M8767_REG_BUCK7CTRL2 = 87,
	S5M8767_REG_BUCK8CTRL1 = 88,
	S5M8767_REG_BUCK8CTRL2 = 89,
	S5M8767_REG_BUCK9CTRL1 = 90,
	S5M8767_REG_BUCK9CTRL2 = 91,
	S5M8767_REG_LDO1CTRL = 92,
	S5M8767_REG_LDO2_1CTRL = 93,
	S5M8767_REG_LDO2_2CTRL = 94,
	S5M8767_REG_LDO2_3CTRL = 95,
	S5M8767_REG_LDO2_4CTRL = 96,
	S5M8767_REG_LDO3CTRL = 97,
	S5M8767_REG_LDO4CTRL = 98,
	S5M8767_REG_LDO5CTRL = 99,
	S5M8767_REG_LDO6CTRL = 100,
	S5M8767_REG_LDO7CTRL = 101,
	S5M8767_REG_LDO8CTRL = 102,
	S5M8767_REG_LDO9CTRL = 103,
	S5M8767_REG_LDO10CTRL = 104,
	S5M8767_REG_LDO11CTRL = 105,
	S5M8767_REG_LDO12CTRL = 106,
	S5M8767_REG_LDO13CTRL = 107,
	S5M8767_REG_LDO14CTRL = 108,
	S5M8767_REG_LDO15CTRL = 109,
	S5M8767_REG_LDO16CTRL = 110,
	S5M8767_REG_LDO17CTRL = 111,
	S5M8767_REG_LDO18CTRL = 112,
	S5M8767_REG_LDO19CTRL = 113,
	S5M8767_REG_LDO20CTRL = 114,
	S5M8767_REG_LDO21CTRL = 115,
	S5M8767_REG_LDO22CTRL = 116,
	S5M8767_REG_LDO23CTRL = 117,
	S5M8767_REG_LDO24CTRL = 118,
	S5M8767_REG_LDO25CTRL = 119,
	S5M8767_REG_LDO26CTRL = 120,
	S5M8767_REG_LDO27CTRL = 121,
	S5M8767_REG_LDO28CTRL = 122,
};

struct sec_pmic_dev___2 {
	struct device___85 *dev;
	struct sec_platform_data *pdata;
	struct regmap *regmap_pmic;
	struct i2c_client *i2c;
	long unsigned int device_type;
	int irq;
	struct regmap_irq_chip_data *irq_data;
};

enum s2mps11_irq {
	S2MPS11_IRQ_PWRONF = 0,
	S2MPS11_IRQ_PWRONR = 1,
	S2MPS11_IRQ_JIGONBF = 2,
	S2MPS11_IRQ_JIGONBR = 3,
	S2MPS11_IRQ_ACOKBF = 4,
	S2MPS11_IRQ_ACOKBR = 5,
	S2MPS11_IRQ_PWRON1S = 6,
	S2MPS11_IRQ_MRB = 7,
	S2MPS11_IRQ_RTC60S = 8,
	S2MPS11_IRQ_RTCA1 = 9,
	S2MPS11_IRQ_RTCA0 = 10,
	S2MPS11_IRQ_SMPL = 11,
	S2MPS11_IRQ_RTC1S = 12,
	S2MPS11_IRQ_WTSR = 13,
	S2MPS11_IRQ_INT120C = 14,
	S2MPS11_IRQ_INT140C = 15,
	S2MPS11_IRQ_NR = 16,
};

enum s2mps14_irq {
	S2MPS14_IRQ_PWRONF = 0,
	S2MPS14_IRQ_PWRONR = 1,
	S2MPS14_IRQ_JIGONBF = 2,
	S2MPS14_IRQ_JIGONBR = 3,
	S2MPS14_IRQ_ACOKBF = 4,
	S2MPS14_IRQ_ACOKBR = 5,
	S2MPS14_IRQ_PWRON1S = 6,
	S2MPS14_IRQ_MRB = 7,
	S2MPS14_IRQ_RTC60S = 8,
	S2MPS14_IRQ_RTCA1 = 9,
	S2MPS14_IRQ_RTCA0 = 10,
	S2MPS14_IRQ_SMPL = 11,
	S2MPS14_IRQ_RTC1S = 12,
	S2MPS14_IRQ_WTSR = 13,
	S2MPS14_IRQ_INT120C = 14,
	S2MPS14_IRQ_INT140C = 15,
	S2MPS14_IRQ_TSD = 16,
	S2MPS14_IRQ_NR = 17,
};

enum s2mpu02_irq {
	S2MPU02_IRQ_PWRONF = 0,
	S2MPU02_IRQ_PWRONR = 1,
	S2MPU02_IRQ_JIGONBF = 2,
	S2MPU02_IRQ_JIGONBR = 3,
	S2MPU02_IRQ_ACOKBF = 4,
	S2MPU02_IRQ_ACOKBR = 5,
	S2MPU02_IRQ_PWRON1S = 6,
	S2MPU02_IRQ_MRB = 7,
	S2MPU02_IRQ_RTC60S = 8,
	S2MPU02_IRQ_RTCA1 = 9,
	S2MPU02_IRQ_RTCA0 = 10,
	S2MPU02_IRQ_SMPL = 11,
	S2MPU02_IRQ_RTC1S = 12,
	S2MPU02_IRQ_WTSR = 13,
	S2MPU02_IRQ_INT120C = 14,
	S2MPU02_IRQ_INT140C = 15,
	S2MPU02_IRQ_TSD = 16,
	S2MPU02_IRQ_NR = 17,
};

enum s5m8767_irq {
	S5M8767_IRQ_PWRR = 0,
	S5M8767_IRQ_PWRF = 1,
	S5M8767_IRQ_PWR1S = 2,
	S5M8767_IRQ_JIGR = 3,
	S5M8767_IRQ_JIGF = 4,
	S5M8767_IRQ_LOWBAT2 = 5,
	S5M8767_IRQ_LOWBAT1 = 6,
	S5M8767_IRQ_MRB = 7,
	S5M8767_IRQ_DVSOK2 = 8,
	S5M8767_IRQ_DVSOK3 = 9,
	S5M8767_IRQ_DVSOK4 = 10,
	S5M8767_IRQ_RTC60S = 11,
	S5M8767_IRQ_RTCA1 = 12,
	S5M8767_IRQ_RTCA2 = 13,
	S5M8767_IRQ_SMPL = 14,
	S5M8767_IRQ_RTC1S = 15,
	S5M8767_IRQ_WTSR = 16,
	S5M8767_IRQ_NR = 17,
};

enum s5m8763_irq {
	S5M8763_IRQ_DCINF = 0,
	S5M8763_IRQ_DCINR = 1,
	S5M8763_IRQ_JIGF = 2,
	S5M8763_IRQ_JIGR = 3,
	S5M8763_IRQ_PWRONF = 4,
	S5M8763_IRQ_PWRONR = 5,
	S5M8763_IRQ_WTSREVNT = 6,
	S5M8763_IRQ_SMPLEVNT = 7,
	S5M8763_IRQ_ALARM1 = 8,
	S5M8763_IRQ_ALARM0 = 9,
	S5M8763_IRQ_ONKEY1S = 10,
	S5M8763_IRQ_TOPOFFR = 11,
	S5M8763_IRQ_DCINOVPR = 12,
	S5M8763_IRQ_CHGRSTF = 13,
	S5M8763_IRQ_DONER = 14,
	S5M8763_IRQ_CHGFAULT = 15,
	S5M8763_IRQ_LOBAT1 = 16,
	S5M8763_IRQ_LOBAT2 = 17,
	S5M8763_IRQ_NR = 18,
};

struct syscon_platform_data {
	const char *label;
};

struct regmap_config___13 {
	const char *name;
	int reg_bits;
	int reg_stride;
	int pad_bits;
	int val_bits;
	bool (*writeable_reg)(struct device___39 *, unsigned int);
	bool (*readable_reg)(struct device___39 *, unsigned int);
	bool (*volatile_reg)(struct device___39 *, unsigned int);
	bool (*precious_reg)(struct device___39 *, unsigned int);
	bool (*writeable_noinc_reg)(struct device___39 *, unsigned int);
	bool (*readable_noinc_reg)(struct device___39 *, unsigned int);
	bool disable_locking;
	regmap_lock lock;
	regmap_unlock unlock;
	void *lock_arg;
	int (*reg_read)(void *, unsigned int, unsigned int *);
	int (*reg_write)(void *, unsigned int, unsigned int);
	bool fast_io;
	unsigned int max_register;
	const struct regmap_access_table *wr_table;
	const struct regmap_access_table *rd_table;
	const struct regmap_access_table *volatile_table;
	const struct regmap_access_table *precious_table;
	const struct regmap_access_table *wr_noinc_table;
	const struct regmap_access_table *rd_noinc_table;
	const struct reg_default *reg_defaults;
	unsigned int num_reg_defaults;
	enum regcache_type cache_type;
	const void *reg_defaults_raw;
	unsigned int num_reg_defaults_raw;
	long unsigned int read_flag_mask;
	long unsigned int write_flag_mask;
	bool zero_flag_mask;
	bool use_single_read;
	bool use_single_write;
	bool use_relaxed_mmio;
	bool can_multi_write;
	enum regmap_endian reg_format_endian;
	enum regmap_endian val_format_endian;
	const struct regmap_range_cfg *ranges;
	unsigned int num_ranges;
	bool use_hwlock;
	bool use_raw_spinlock;
	unsigned int hwlock_id;
	unsigned int hwlock_mode;
	bool can_sleep;
};

struct syscon {
	struct device_node___23 *np;
	struct regmap *regmap;
	struct list_head list;
};

struct platform_driver___28 {
	int (*probe)(struct platform_device___33 *);
	int (*remove)(struct platform_device___33 *);
	void (*shutdown)(struct platform_device___33 *);
	int (*suspend)(struct platform_device___33 *, pm_message_t);
	int (*resume)(struct platform_device___33 *);
	struct device_driver___85 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum {
	AS3711_REGULATOR_SD_1 = 0,
	AS3711_REGULATOR_SD_2 = 1,
	AS3711_REGULATOR_SD_3 = 2,
	AS3711_REGULATOR_SD_4 = 3,
	AS3711_REGULATOR_LDO_1 = 4,
	AS3711_REGULATOR_LDO_2 = 5,
	AS3711_REGULATOR_LDO_3 = 6,
	AS3711_REGULATOR_LDO_4 = 7,
	AS3711_REGULATOR_LDO_5 = 8,
	AS3711_REGULATOR_LDO_6 = 9,
	AS3711_REGULATOR_LDO_7 = 10,
	AS3711_REGULATOR_LDO_8 = 11,
	AS3711_REGULATOR_MAX = 12,
};

struct as3711 {
	struct device___147 *dev;
	struct regmap *regmap;
};

enum as3711_su2_feedback {
	AS3711_SU2_VOLTAGE = 0,
	AS3711_SU2_CURR1 = 1,
	AS3711_SU2_CURR2 = 2,
	AS3711_SU2_CURR3 = 3,
	AS3711_SU2_CURR_AUTO = 4,
};

enum as3711_su2_fbprot {
	AS3711_SU2_LX_SD4 = 0,
	AS3711_SU2_GPIO2 = 1,
	AS3711_SU2_GPIO3 = 2,
	AS3711_SU2_GPIO4 = 3,
};

struct as3711_regulator_pdata {
	struct regulator_init_data *init_data[12];
};

struct as3711_bl_pdata {
	bool su1_fb;
	int su1_max_uA;
	bool su2_fb;
	int su2_max_uA;
	enum as3711_su2_feedback su2_feedback;
	enum as3711_su2_fbprot su2_fbprot;
	bool su2_auto_curr1;
	bool su2_auto_curr2;
	bool su2_auto_curr3;
};

struct as3711_platform_data {
	struct as3711_regulator_pdata regulator;
	struct as3711_bl_pdata backlight;
};

enum {
	AS3711_REGULATOR = 0,
	AS3711_BACKLIGHT = 1,
};

enum as3722_irq {
	AS3722_IRQ_LID = 0,
	AS3722_IRQ_ACOK = 1,
	AS3722_IRQ_ENABLE1 = 2,
	AS3722_IRQ_OCCUR_ALARM_SD0 = 3,
	AS3722_IRQ_ONKEY_LONG_PRESS = 4,
	AS3722_IRQ_ONKEY = 5,
	AS3722_IRQ_OVTMP = 6,
	AS3722_IRQ_LOWBAT = 7,
	AS3722_IRQ_SD0_LV = 8,
	AS3722_IRQ_SD1_LV = 9,
	AS3722_IRQ_SD2_LV = 10,
	AS3722_IRQ_PWM1_OV_PROT = 11,
	AS3722_IRQ_PWM2_OV_PROT = 12,
	AS3722_IRQ_ENABLE2 = 13,
	AS3722_IRQ_SD6_LV = 14,
	AS3722_IRQ_RTC_REP = 15,
	AS3722_IRQ_RTC_ALARM = 16,
	AS3722_IRQ_GPIO1 = 17,
	AS3722_IRQ_GPIO2 = 18,
	AS3722_IRQ_GPIO3 = 19,
	AS3722_IRQ_GPIO4 = 20,
	AS3722_IRQ_GPIO5 = 21,
	AS3722_IRQ_WATCHDOG = 22,
	AS3722_IRQ_ENABLE3 = 23,
	AS3722_IRQ_TEMP_SD0_SHUTDOWN = 24,
	AS3722_IRQ_TEMP_SD1_SHUTDOWN = 25,
	AS3722_IRQ_TEMP_SD2_SHUTDOWN = 26,
	AS3722_IRQ_TEMP_SD0_ALARM = 27,
	AS3722_IRQ_TEMP_SD1_ALARM = 28,
	AS3722_IRQ_TEMP_SD6_ALARM = 29,
	AS3722_IRQ_OCCUR_ALARM_SD6 = 30,
	AS3722_IRQ_ADC = 31,
	AS3722_IRQ_MAX = 32,
};

struct as3722___2 {
	struct device___147 *dev;
	struct regmap *regmap;
	int chip_irq;
	long unsigned int irq_flags;
	bool en_intern_int_pullup;
	bool en_intern_i2c_pullup;
	bool en_ac_ok_pwr_on;
	struct regmap_irq_chip_data *irq_data;
};

struct altr_a10sr {
	struct device___190 *dev;
	struct regmap *regmap;
};

struct altr_sysmgr {
	struct regmap *regmap;
};

struct dentry___213;

struct super_block___213;

struct module___197;

struct file_system_type___213 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___213 * (*mount)(struct file_system_type___213 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___213 *);
	struct module___197 *owner;
	struct file_system_type___213 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___213;

struct kiocb___213;

struct iov_iter___133;

struct vm_area_struct___218;

struct inode___213;

struct file_lock___213;

struct page___218;

struct seq_file___188;

struct file_operations___214 {
	struct module___197 *owner;
	loff_t (*llseek)(struct file___213 *, loff_t, int);
	ssize_t (*read)(struct file___213 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___213 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___213 *, struct iov_iter___133 *);
	ssize_t (*write_iter)(struct kiocb___213 *, struct iov_iter___133 *);
	int (*iopoll)(struct kiocb___213 *, bool);
	int (*iterate)(struct file___213 *, struct dir_context *);
	int (*iterate_shared)(struct file___213 *, struct dir_context *);
	__poll_t (*poll)(struct file___213 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___213 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___213 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___213 *, struct vm_area_struct___218 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___213 *, struct file___213 *);
	int (*flush)(struct file___213 *, fl_owner_t);
	int (*release)(struct inode___213 *, struct file___213 *);
	int (*fsync)(struct file___213 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___213 *, int);
	int (*lock)(struct file___213 *, int, struct file_lock___213 *);
	ssize_t (*sendpage)(struct file___213 *, struct page___218 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___213 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___213 *, long unsigned int);
	int (*flock)(struct file___213 *, int, struct file_lock___213 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___213 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___213 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___213 *, long int, struct file_lock___213 **, void **);
	long int (*fallocate)(struct file___213 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___188 *, struct file___213 *);
	ssize_t (*copy_file_range)(struct file___213 *, loff_t, struct file___213 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___213 *, loff_t, struct file___213 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___213 *, loff_t, loff_t, int);
};

struct vmacache___218 {
	u64 seqnum;
	struct vm_area_struct___218 *vmas[4];
};

struct page_frag___218 {
	struct page___218 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___219;

struct pid___190;

struct nsproxy___199;

struct signal_struct___214;

struct bio_list___109;

struct backing_dev_info___102;

struct io_context___109;

struct css_set___147;

struct mem_cgroup___93;

struct request_queue___109;

struct vm_struct___196;

struct task_struct___220 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___220 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___219 *mm;
	struct mm_struct___219 *active_mm;
	struct vmacache___218 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___220 *real_parent;
	struct task_struct___220 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___220 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___190 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___199 *nsproxy;
	struct signal_struct___214 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___220 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___109 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___102 *backing_dev_info;
	struct io_context___109 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___147 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___218 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___93 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___93 *active_memcg;
	struct request_queue___109 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___220 *oom_reaper_list;
	struct vm_struct___196 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___61 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___201;

struct kobj_type___201;

struct kernfs_node___201;

struct kobject___201 {
	const char *name;
	struct list_head entry;
	struct kobject___201 *parent;
	struct kset___201 *kset;
	struct kobj_type___201 *ktype;
	struct kernfs_node___201 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___198 {
	struct kobject___201 kobj;
	struct module___197 *mod;
	struct kobject___201 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___197 {
	struct module___197 *mod;
	struct latch_tree_node node;
};

struct module_layout___197 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___197 mtn;
};

struct module_attribute___197;

struct kernel_param___197;

struct module___197 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___198 mkobj;
	struct module_attribute___197 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___201 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___197 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___197 core_layout;
	struct module_layout___197 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___190;

struct upid___190 {
	int nr;
	struct pid_namespace___190 *ns;
};

struct pid_namespace___190 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___220 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___190 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___190 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___190 numbers[1];
};

typedef struct page___218 *pgtable_t___218;

struct address_space___213;

struct dev_pagemap___208;

struct page___218 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___213 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___218 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___218 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___219 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___208 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___208;

struct vm_area_struct___218 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___218 *vm_next;
	struct vm_area_struct___218 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___219 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___208 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___213 *vm_file;
	struct file___213 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___214 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___220 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___220 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___190 *pids[4];
	struct pid___190 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___219 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___218;

struct mm_struct___219 {
	struct {
		struct vm_area_struct___218 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___213 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___218 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___220 *owner;
		struct user_namespace___14 *user_ns;
		struct file___213 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___147;

struct nsproxy___199 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___190 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___147 *cgroup_ns;
};

struct bio___109;

struct bio_list___109 {
	struct bio___109 *head;
	struct bio___109 *tail;
};

struct cgroup_subsys_state___147;

struct bdi_writeback___102 {
	struct backing_dev_info___102 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___147 *memcg_css;
	struct cgroup_subsys_state___147 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___191;

struct backing_dev_info___102 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___102 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___191 *dev;
	char dev_name[64];
	struct device___191 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___213 *debug_dir;
};

struct io_cq___109;

struct io_context___109 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___109 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___147;

struct css_set___147 {
	struct cgroup_subsys_state___147 *subsys[14];
	refcount_t refcount;
	struct css_set___147 *dom_cset;
	struct cgroup___147 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___147 *mg_src_cgrp;
	struct cgroup___147 *mg_dst_cgrp;
	struct css_set___147 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___147;

struct cgroup_subsys_state___147 {
	struct cgroup___147 *cgroup;
	struct cgroup_subsys___147 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___147 *parent;
};

struct cgroup_file___147 {
	struct kernfs_node___201 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___93;

struct mem_cgroup_per_node___93;

struct mem_cgroup___93 {
	struct cgroup_subsys_state___147 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___147 events_file;
	struct cgroup_file___147 events_local_file;
	struct cgroup_file___147 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___93 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___220 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___93 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___109;

struct blk_integrity___109 {
	const struct blk_integrity_profile___109 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___109 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___109 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___109;

struct elevator_queue___109;

struct blk_mq_ops___106;

struct blk_mq_hw_ctx___106;

struct gendisk___112;

struct blkcg_gq___104;

struct blk_mq_tag_set___106;

struct request_queue___109 {
	struct request___109 *last_merge;
	struct elevator_queue___109 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___106 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___106 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___112 *disk;
	struct kobject___201 kobj;
	struct kobject___201 *mq_kobj;
	struct blk_integrity___109 integrity;
	struct device___191 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___104 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___106 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___109 bio_split;
	struct dentry___213 *debugfs_dir;
	struct dentry___213 *sched_debugfs_dir;
	struct dentry___213 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___196 {
	struct vm_struct___196 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___218 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___213;

struct address_space___213 {
	struct inode___213 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___213 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___208;

struct dev_pagemap___208 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___208 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___213;

struct path___213 {
	struct vfsmount___213 *mnt;
	struct dentry___213 *dentry;
};

struct fown_struct___190 {
	rwlock_t lock;
	struct pid___190 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___213 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___213 f_path;
	struct inode___213 *f_inode;
	const struct file_operations___214 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___190 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___213 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___208;

struct vm_operations_struct___208 {
	void (*open)(struct vm_area_struct___218 *);
	void (*close)(struct vm_area_struct___218 *);
	int (*may_split)(struct vm_area_struct___218 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___218 *);
	int (*mprotect)(struct vm_area_struct___218 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___208 *);
	vm_fault_t (*huge_fault)(struct vm_fault___208 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___208 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___218 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___208 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___208 *);
	int (*access)(struct vm_area_struct___218 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___218 *);
	int (*set_policy)(struct vm_area_struct___218 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___218 *, long unsigned int);
	struct page___218 * (*find_special_page)(struct vm_area_struct___218 *, long unsigned int);
};

struct core_thread___218 {
	struct task_struct___220 *task;
	struct core_thread___218 *next;
};

struct core_state___218 {
	atomic_t nr_threads;
	struct core_thread___218 dumper;
	struct completion startup;
};

struct vm_fault___208 {
	const struct {
		struct vm_area_struct___218 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___218 *cow_page;
	struct page___218 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___218 prealloc_pte;
};

struct pglist_data___101;

struct lruvec___101 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___101 *pgdat;
};

struct zone___101 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___101 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___101 {
	struct zone___101 *zone;
	int zone_idx;
};

struct zonelist___101 {
	struct zoneref___101 _zonerefs[321];
};

struct pglist_data___101 {
	struct zone___101 node_zones[5];
	struct zonelist___101 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___220 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___220 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___101 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct io_cq___109 {
	struct request_queue___109 *q;
	struct io_context___109 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct dentry_operations___213;

struct dentry___213 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___213 *d_parent;
	struct qstr d_name;
	struct inode___213 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___213 *d_op;
	struct super_block___213 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___213;

struct inode___213 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___213 *i_op;
	struct super_block___213 *i_sb;
	struct address_space___213 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___102 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___214 *i_fop;
		void (*free_inode)(struct inode___213 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___213 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___213 {
	int (*d_revalidate)(struct dentry___213 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___213 *, unsigned int);
	int (*d_hash)(const struct dentry___213 *, struct qstr *);
	int (*d_compare)(const struct dentry___213 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___213 *);
	int (*d_init)(struct dentry___213 *);
	void (*d_release)(struct dentry___213 *);
	void (*d_prune)(struct dentry___213 *);
	void (*d_iput)(struct dentry___213 *, struct inode___213 *);
	char * (*d_dname)(struct dentry___213 *, char *, int);
	struct vfsmount___213 * (*d_automount)(struct path___213 *);
	int (*d_manage)(const struct path___213 *, bool);
	struct dentry___213 * (*d_real)(struct dentry___213 *, const struct inode___213 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___213;

struct mem_dqinfo___213 {
	struct quota_format_type___213 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___213;

struct quota_info___213 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___213 *files[3];
	struct mem_dqinfo___213 info[3];
	const struct quota_format_ops___213 *ops[3];
};

struct rcuwait___214 {
	struct task_struct___220 *task;
};

struct percpu_rw_semaphore___214 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___214 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___213 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___214 rw_sem[3];
};

struct shrink_control___93;

struct shrinker___93 {
	long unsigned int (*count_objects)(struct shrinker___93 *, struct shrink_control___93 *);
	long unsigned int (*scan_objects)(struct shrinker___93 *, struct shrink_control___93 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___213;

struct dquot_operations___213;

struct quotactl_ops___213;

struct block_device___112;

struct super_block___213 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___213 *s_type;
	const struct super_operations___213 *s_op;
	const struct dquot_operations___213 *dq_op;
	const struct quotactl_ops___213 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___213 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___112 *s_bdev;
	struct backing_dev_info___102 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___213 s_dquot;
	struct sb_writers___213 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___213 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___213 {
	struct dentry___213 *mnt_root;
	struct super_block___213 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___93 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___93 *memcg;
};

struct psi_group___147 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___220 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___147;

struct cgroup_rstat_cpu___147;

struct cgroup___147 {
	struct cgroup_subsys_state___147 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___201 *kn;
	struct cgroup_file___147 procs_file;
	struct cgroup_file___147 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___147 *subsys[14];
	struct cgroup_root___147 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___147 *dom_cgrp;
	struct cgroup___147 *old_dom_cgrp;
	struct cgroup_rstat_cpu___147 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___147 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct wait_page_queue___103;

struct kiocb___213 {
	struct file___213 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___213 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___103 *ki_waitq;
	};
};

struct iattr___213 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___213 *ia_file;
};

struct dquot___213 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___213 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___213 {
	int qf_fmt_id;
	const struct quota_format_ops___213 *qf_ops;
	struct module___197 *qf_owner;
	struct quota_format_type___213 *qf_next;
};

struct quota_format_ops___213 {
	int (*check_quota_file)(struct super_block___213 *, int);
	int (*read_file_info)(struct super_block___213 *, int);
	int (*write_file_info)(struct super_block___213 *, int);
	int (*free_file_info)(struct super_block___213 *, int);
	int (*read_dqblk)(struct dquot___213 *);
	int (*commit_dqblk)(struct dquot___213 *);
	int (*release_dqblk)(struct dquot___213 *);
	int (*get_next_id)(struct super_block___213 *, struct kqid *);
};

struct dquot_operations___213 {
	int (*write_dquot)(struct dquot___213 *);
	struct dquot___213 * (*alloc_dquot)(struct super_block___213 *, int);
	void (*destroy_dquot)(struct dquot___213 *);
	int (*acquire_dquot)(struct dquot___213 *);
	int (*release_dquot)(struct dquot___213 *);
	int (*mark_dirty)(struct dquot___213 *);
	int (*write_info)(struct super_block___213 *, int);
	qsize_t * (*get_reserved_space)(struct inode___213 *);
	int (*get_projid)(struct inode___213 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___213 *, qsize_t *);
	int (*get_next_id)(struct super_block___213 *, struct kqid *);
};

struct quotactl_ops___213 {
	int (*quota_on)(struct super_block___213 *, int, int, const struct path___213 *);
	int (*quota_off)(struct super_block___213 *, int);
	int (*quota_enable)(struct super_block___213 *, unsigned int);
	int (*quota_disable)(struct super_block___213 *, unsigned int);
	int (*quota_sync)(struct super_block___213 *, int);
	int (*set_info)(struct super_block___213 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___213 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___213 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___213 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___213 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___213 *, unsigned int);
};

struct wait_page_queue___103 {
	struct page___218 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___102;

struct readahead_control___103;

struct swap_info_struct___61;

struct address_space_operations___213 {
	int (*writepage)(struct page___218 *, struct writeback_control___102 *);
	int (*readpage)(struct file___213 *, struct page___218 *);
	int (*writepages)(struct address_space___213 *, struct writeback_control___102 *);
	int (*set_page_dirty)(struct page___218 *);
	int (*readpages)(struct file___213 *, struct address_space___213 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___103 *);
	int (*write_begin)(struct file___213 *, struct address_space___213 *, loff_t, unsigned int, unsigned int, struct page___218 **, void **);
	int (*write_end)(struct file___213 *, struct address_space___213 *, loff_t, unsigned int, unsigned int, struct page___218 *, void *);
	sector_t (*bmap)(struct address_space___213 *, sector_t);
	void (*invalidatepage)(struct page___218 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___218 *, gfp_t);
	void (*freepage)(struct page___218 *);
	ssize_t (*direct_IO)(struct kiocb___213 *, struct iov_iter___133 *);
	int (*migratepage)(struct address_space___213 *, struct page___218 *, struct page___218 *, enum migrate_mode);
	bool (*isolate_page)(struct page___218 *, isolate_mode_t);
	void (*putback_page)(struct page___218 *);
	int (*launder_page)(struct page___218 *);
	int (*is_partially_uptodate)(struct page___218 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___218 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___213 *, struct page___218 *);
	int (*swap_activate)(struct swap_info_struct___61 *, struct file___213 *, sector_t *);
	void (*swap_deactivate)(struct file___213 *);
};

struct writeback_control___102 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___102 *wb;
	struct inode___213 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___103 {
	struct file___213 *file;
	struct address_space___213 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___130;

struct iov_iter___133 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___130 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___61 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___112 *bdev;
	struct file___213 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___213 {
	struct dentry___213 * (*lookup)(struct inode___213 *, struct dentry___213 *, unsigned int);
	const char * (*get_link)(struct dentry___213 *, struct inode___213 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___213 *, int);
	struct posix_acl * (*get_acl)(struct inode___213 *, int, bool);
	int (*readlink)(struct dentry___213 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___213 *, struct dentry___213 *, umode_t, bool);
	int (*link)(struct dentry___213 *, struct inode___213 *, struct dentry___213 *);
	int (*unlink)(struct inode___213 *, struct dentry___213 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___213 *, struct dentry___213 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___213 *, struct dentry___213 *, umode_t);
	int (*rmdir)(struct inode___213 *, struct dentry___213 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___213 *, struct dentry___213 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___213 *, struct dentry___213 *, struct inode___213 *, struct dentry___213 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___213 *, struct iattr___213 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___213 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___213 *, char *, size_t);
	int (*fiemap)(struct inode___213 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___213 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___213 *, struct dentry___213 *, struct file___213 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___213 *, struct dentry___213 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___213 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___213 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___213 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___213 {
	void (*fl_copy_lock)(struct file_lock___213 *, struct file_lock___213 *);
	void (*fl_release_private)(struct file_lock___213 *);
};

struct fasync_struct___213;

struct lock_manager_operations___213;

struct file_lock___213 {
	struct file_lock___213 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___213 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___213 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___213 *fl_ops;
	const struct lock_manager_operations___213 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___213 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___213 *);
	int (*lm_grant)(struct file_lock___213 *, int);
	bool (*lm_break)(struct file_lock___213 *);
	int (*lm_change)(struct file_lock___213 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___213 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___213 *);
};

struct fasync_struct___213 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___213 *fa_next;
	struct file___213 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___213 {
	struct inode___213 * (*alloc_inode)(struct super_block___213 *);
	void (*destroy_inode)(struct inode___213 *);
	void (*free_inode)(struct inode___213 *);
	void (*dirty_inode)(struct inode___213 *, int);
	int (*write_inode)(struct inode___213 *, struct writeback_control___102 *);
	int (*drop_inode)(struct inode___213 *);
	void (*evict_inode)(struct inode___213 *);
	void (*put_super)(struct super_block___213 *);
	int (*sync_fs)(struct super_block___213 *, int);
	int (*freeze_super)(struct super_block___213 *);
	int (*freeze_fs)(struct super_block___213 *);
	int (*thaw_super)(struct super_block___213 *);
	int (*unfreeze_fs)(struct super_block___213 *);
	int (*statfs)(struct dentry___213 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___213 *, int *, char *);
	void (*umount_begin)(struct super_block___213 *);
	int (*show_options)(struct seq_file___188 *, struct dentry___213 *);
	int (*show_devname)(struct seq_file___188 *, struct dentry___213 *);
	int (*show_path)(struct seq_file___188 *, struct dentry___213 *);
	int (*show_stats)(struct seq_file___188 *, struct dentry___213 *);
	ssize_t (*quota_read)(struct super_block___213 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___213 *, int, const char *, size_t, loff_t);
	struct dquot___213 ** (*get_dquots)(struct inode___213 *);
	long int (*nr_cached_objects)(struct super_block___213 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___213 *, struct shrink_control___93 *);
	struct file___213 * (*real_loop)(struct file___213 *);
};

struct wakeup_source___191;

struct dev_pm_info___191 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___191 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___191 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___191;

struct bus_type___191;

struct device_driver___191;

struct dev_pm_domain___191;

struct fwnode_handle___187;

struct class___191;

struct attribute_group___201;

struct device___191 {
	struct kobject___201 kobj;
	struct device___191 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___191 *type;
	struct bus_type___191 *bus;
	struct device_driver___191 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___191 power;
	struct dev_pm_domain___191 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___187 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___191 *class;
	const struct attribute_group___201 **groups;
	void (*release)(struct device___191 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___112 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___213 *bd_inode;
	struct super_block___213 *bd_super;
	void *bd_claiming;
	struct device___191 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___201 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___112 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___213 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___188;

struct seq_file___188 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___188 *op;
	int poll_event;
	const struct file___213 *file;
	void *private;
};

typedef void bio_end_io_t___109(struct bio___109 *);

struct bio_vec___130 {
	struct page___218 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___109;

struct bio___109 {
	struct bio___109 *bi_next;
	struct block_device___112 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___109 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___104 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___109 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___130 *bi_io_vec;
	struct bio_set___109 *bi_pool;
	struct bio_vec___130 bi_inline_vecs[0];
};

struct dev_pagemap_ops___208 {
	void (*page_free)(struct page___218 *);
	void (*kill)(struct dev_pagemap___208 *);
	void (*cleanup)(struct dev_pagemap___208 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___208 *);
};

struct fwnode_operations___187;

struct fwnode_handle___187 {
	struct fwnode_handle___187 *secondary;
	const struct fwnode_operations___187 *ops;
	struct device___191 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___187;

struct fwnode_endpoint___187;

struct fwnode_operations___187 {
	struct fwnode_handle___187 * (*get)(struct fwnode_handle___187 *);
	void (*put)(struct fwnode_handle___187 *);
	bool (*device_is_available)(const struct fwnode_handle___187 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___187 *, const struct device___191 *);
	bool (*property_present)(const struct fwnode_handle___187 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___187 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___187 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___187 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*get_parent)(const struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*get_next_child_node)(const struct fwnode_handle___187 *, struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*get_named_child_node)(const struct fwnode_handle___187 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___187 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___187 *);
	struct fwnode_handle___187 * (*graph_get_next_endpoint)(const struct fwnode_handle___187 *, struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*graph_get_remote_endpoint)(const struct fwnode_handle___187 *);
	struct fwnode_handle___187 * (*graph_get_port_parent)(struct fwnode_handle___187 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___187 *, struct fwnode_endpoint___187 *);
	int (*add_links)(struct fwnode_handle___187 *);
};

struct fwnode_endpoint___187 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___187 *local_fwnode;
};

struct fwnode_reference_args___187 {
	struct fwnode_handle___187 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___201;

struct kernfs_elem_dir___201 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___201 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___201;

struct kernfs_root___201 {
	struct kernfs_node___201 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___201 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___201 {
	struct kernfs_node___201 *target_kn;
};

struct kernfs_ops___201;

struct kernfs_elem_attr___201 {
	const struct kernfs_ops___201 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___201 *notify_next;
};

struct kernfs_node___201 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___201 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___201 dir;
		struct kernfs_elem_symlink___201 symlink;
		struct kernfs_elem_attr___201 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___201;

struct kernfs_ops___201 {
	int (*open)(struct kernfs_open_file___201 *);
	void (*release)(struct kernfs_open_file___201 *);
	int (*seq_show)(struct seq_file___188 *, void *);
	void * (*seq_start)(struct seq_file___188 *, loff_t *);
	void * (*seq_next)(struct seq_file___188 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___188 *, void *);
	ssize_t (*read)(struct kernfs_open_file___201 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___201 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___201 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___201 *, struct vm_area_struct___218 *);
};

struct kernfs_syscall_ops___201 {
	int (*show_options)(struct seq_file___188 *, struct kernfs_root___201 *);
	int (*mkdir)(struct kernfs_node___201 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___201 *);
	int (*rename)(struct kernfs_node___201 *, struct kernfs_node___201 *, const char *);
	int (*show_path)(struct seq_file___188 *, struct kernfs_node___201 *, struct kernfs_root___201 *);
};

struct kernfs_open_file___201 {
	struct kernfs_node___201 *kn;
	struct file___213 *file;
	struct seq_file___188 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___208 *vm_ops;
};

struct bin_attribute___201;

struct attribute_group___201 {
	const char *name;
	umode_t (*is_visible)(struct kobject___201 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___201 *, struct bin_attribute___201 *, int);
	struct attribute **attrs;
	struct bin_attribute___201 **bin_attrs;
};

struct bin_attribute___201 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___213 * (*f_mapping)();
	ssize_t (*read)(struct file___213 *, struct kobject___201 *, struct bin_attribute___201 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___213 *, struct kobject___201 *, struct bin_attribute___201 *, char *, loff_t, size_t);
	int (*mmap)(struct file___213 *, struct kobject___201 *, struct bin_attribute___201 *, struct vm_area_struct___218 *);
};

struct sysfs_ops___201 {
	ssize_t (*show)(struct kobject___201 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___201 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___201;

struct kset___201 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___201 kobj;
	const struct kset_uevent_ops___201 *uevent_ops;
};

struct kobj_type___201 {
	void (*release)(struct kobject___201 *);
	const struct sysfs_ops___201 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___201 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___201 *);
	const void * (*namespace)(struct kobject___201 *);
	void (*get_ownership)(struct kobject___201 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___201 {
	int (* const filter)(struct kset___201 *, struct kobject___201 *);
	const char * (* const name)(struct kset___201 *, struct kobject___201 *);
	int (* const uevent)(struct kset___201 *, struct kobject___201 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___197 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___197 *);
	int (*get)(char *, const struct kernel_param___197 *);
	void (*free)(void *);
};

struct kparam_array___197;

struct kernel_param___197 {
	const char *name;
	struct module___197 *mod;
	const struct kernel_param_ops___197 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___197 *arr;
	};
};

struct kparam_array___197 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___197 *ops;
	void *elem;
};

struct module_attribute___197 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___197 *, struct module_kobject___198 *, char *);
	ssize_t (*store)(struct module_attribute___197 *, struct module_kobject___198 *, const char *, size_t);
	void (*setup)(struct module___197 *, const char *);
	int (*test)(struct module___197 *);
	void (*free)(struct module___197 *);
};

struct cgroup_namespace___147 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___147 *root_cset;
};

struct dev_pm_ops___191 {
	int (*prepare)(struct device___191 *);
	void (*complete)(struct device___191 *);
	int (*suspend)(struct device___191 *);
	int (*resume)(struct device___191 *);
	int (*freeze)(struct device___191 *);
	int (*thaw)(struct device___191 *);
	int (*poweroff)(struct device___191 *);
	int (*restore)(struct device___191 *);
	int (*suspend_late)(struct device___191 *);
	int (*resume_early)(struct device___191 *);
	int (*freeze_late)(struct device___191 *);
	int (*thaw_early)(struct device___191 *);
	int (*poweroff_late)(struct device___191 *);
	int (*restore_early)(struct device___191 *);
	int (*suspend_noirq)(struct device___191 *);
	int (*resume_noirq)(struct device___191 *);
	int (*freeze_noirq)(struct device___191 *);
	int (*thaw_noirq)(struct device___191 *);
	int (*poweroff_noirq)(struct device___191 *);
	int (*restore_noirq)(struct device___191 *);
	int (*runtime_suspend)(struct device___191 *);
	int (*runtime_resume)(struct device___191 *);
	int (*runtime_idle)(struct device___191 *);
};

struct wakeup_source___191 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___191 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___191 {
	struct dev_pm_ops___191 ops;
	int (*start)(struct device___191 *);
	void (*detach)(struct device___191 *, bool);
	int (*activate)(struct device___191 *);
	void (*sync)(struct device___191 *);
	void (*dismiss)(struct device___191 *);
};

struct bus_type___191 {
	const char *name;
	const char *dev_name;
	struct device___191 *dev_root;
	const struct attribute_group___201 **bus_groups;
	const struct attribute_group___201 **dev_groups;
	const struct attribute_group___201 **drv_groups;
	int (*match)(struct device___191 *, struct device_driver___191 *);
	int (*uevent)(struct device___191 *, struct kobj_uevent_env *);
	int (*probe)(struct device___191 *);
	void (*sync_state)(struct device___191 *);
	void (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	int (*online)(struct device___191 *);
	int (*offline)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	int (*num_vf)(struct device___191 *);
	int (*dma_configure)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___191 {
	const char *name;
	struct bus_type___191 *bus;
	struct module___197 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___191 *);
	void (*sync_state)(struct device___191 *);
	int (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	int (*suspend)(struct device___191 *, pm_message_t);
	int (*resume)(struct device___191 *);
	const struct attribute_group___201 **groups;
	const struct attribute_group___201 **dev_groups;
	const struct dev_pm_ops___191 *pm;
	void (*coredump)(struct device___191 *);
	struct driver_private *p;
};

struct device_type___191 {
	const char *name;
	const struct attribute_group___201 **groups;
	int (*uevent)(struct device___191 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___191 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___191 *);
	const struct dev_pm_ops___191 *pm;
};

struct class___191 {
	const char *name;
	struct module___197 *owner;
	const struct attribute_group___201 **class_groups;
	const struct attribute_group___201 **dev_groups;
	struct kobject___201 *dev_kobj;
	int (*dev_uevent)(struct device___191 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___191 *, umode_t *);
	void (*class_release)(struct class___191 *);
	void (*dev_release)(struct device___191 *);
	int (*shutdown_pre)(struct device___191 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___191 *);
	void (*get_ownership)(struct device___191 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___191 *pm;
	struct subsys_private *p;
};

struct device_attribute___25 {
	struct attribute attr;
	ssize_t (*show)(struct device___191 *, struct device_attribute___25 *, char *);
	ssize_t (*store)(struct device___191 *, struct device_attribute___25 *, const char *, size_t);
};

struct block_device_operations___109;

struct badblocks___2;

struct gendisk___112 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___112 *part0;
	const struct block_device_operations___109 *fops;
	struct request_queue___109 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___102 *bdi;
	struct kobject___201 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___201 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks___2 *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___109 {
	struct bio___109 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___130 *bip_vec;
	struct bio_vec___130 bip_inline_vecs[0];
};

struct blkcg___104;

struct blkg_policy_data___104;

struct blkcg_gq___104 {
	struct request_queue___109 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___104 *blkcg;
	struct blkcg_gq___104 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___104 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___109 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

struct badrange {
	struct list_head list;
	spinlock_t lock;
};

enum {
	NDD_ALIASING = 0,
	NDD_UNARMED = 1,
	NDD_LOCKED = 2,
	NDD_SECURITY_OVERWRITE = 3,
	NDD_WORK_PENDING = 4,
	NDD_NOBLK = 5,
	NDD_LABELING = 6,
	ND_IOCTL_MAX_BUFLEN = 4194304,
	ND_CMD_MAX_ELEM = 5,
	ND_CMD_MAX_ENVELOPE = 256,
	ND_MAX_MAPPINGS = 32,
	ND_REGION_PAGEMAP = 0,
	ND_REGION_PERSIST_CACHE = 1,
	ND_REGION_PERSIST_MEMCTRL = 2,
	ND_REGION_ASYNC = 3,
	DPA_RESOURCE_ADJUSTED = 1,
};

struct nvdimm_bus_descriptor;

struct nvdimm;

typedef int (*ndctl_fn)(struct nvdimm_bus_descriptor *, struct nvdimm *, unsigned int, void *, unsigned int, int *);

struct nvdimm_bus_fw_ops;

struct nvdimm_bus_descriptor {
	const struct attribute_group___201 **attr_groups;
	long unsigned int cmd_mask;
	long unsigned int dimm_family_mask;
	long unsigned int bus_family_mask;
	struct module___197 *module;
	char *provider_name;
	struct device_node___2 *of_node;
	ndctl_fn ndctl;
	int (*flush_probe)(struct nvdimm_bus_descriptor *);
	int (*clear_to_send)(struct nvdimm_bus_descriptor *, struct nvdimm *, unsigned int, void *);
	const struct nvdimm_bus_fw_ops *fw_ops;
};

struct nvdimm_security_ops;

struct nvdimm_fw_ops;

struct nvdimm {
	long unsigned int flags;
	void *provider_data;
	long unsigned int cmd_mask;
	struct device___191 dev;
	atomic_t busy;
	int id;
	int num_flush;
	struct resource *flush_wpq;
	const char *dimm_id;
	struct {
		const struct nvdimm_security_ops *ops;
		long unsigned int flags;
		long unsigned int ext_flags;
		unsigned int overwrite_tmo;
		struct kernfs_node___201 *overwrite_state;
	} sec;
	struct delayed_work dwork;
	const struct nvdimm_fw_ops *fw_ops;
};

enum nvdimm_fwa_state {
	NVDIMM_FWA_INVALID = 0,
	NVDIMM_FWA_IDLE = 1,
	NVDIMM_FWA_ARMED = 2,
	NVDIMM_FWA_BUSY = 3,
	NVDIMM_FWA_ARM_OVERFLOW = 4,
};

enum nvdimm_fwa_capability {
	NVDIMM_FWA_CAP_INVALID = 0,
	NVDIMM_FWA_CAP_NONE = 1,
	NVDIMM_FWA_CAP_QUIESCE = 2,
	NVDIMM_FWA_CAP_LIVE = 3,
};

struct nvdimm_bus_fw_ops {
	enum nvdimm_fwa_state (*activate_state)(struct nvdimm_bus_descriptor *);
	enum nvdimm_fwa_capability (*capability)(struct nvdimm_bus_descriptor *);
	int (*activate)(struct nvdimm_bus_descriptor *);
};

struct nvdimm_bus {
	struct nvdimm_bus_descriptor *nd_desc;
	wait_queue_head_t wait;
	struct list_head list;
	struct device___191 dev;
	int id;
	int probe_active;
	atomic_t ioctl_active;
	struct list_head mapping_list;
	struct mutex reconfig_mutex;
	struct badrange badrange;
};

struct nvdimm_key_data {
	u8 data[32];
};

enum nvdimm_passphrase_type {
	NVDIMM_USER = 0,
	NVDIMM_MASTER = 1,
};

struct nvdimm_security_ops {
	long unsigned int (*get_flags)(struct nvdimm *, enum nvdimm_passphrase_type);
	int (*freeze)(struct nvdimm *);
	int (*change_key)(struct nvdimm *, const struct nvdimm_key_data *, const struct nvdimm_key_data *, enum nvdimm_passphrase_type);
	int (*unlock)(struct nvdimm *, const struct nvdimm_key_data *);
	int (*disable)(struct nvdimm *, const struct nvdimm_key_data *);
	int (*erase)(struct nvdimm *, const struct nvdimm_key_data *, enum nvdimm_passphrase_type);
	int (*overwrite)(struct nvdimm *, const struct nvdimm_key_data *);
	int (*query_overwrite)(struct nvdimm *);
};

enum nvdimm_fwa_trigger {
	NVDIMM_FWA_ARM = 0,
	NVDIMM_FWA_DISARM = 1,
};

enum nvdimm_fwa_result {
	NVDIMM_FWA_RESULT_INVALID = 0,
	NVDIMM_FWA_RESULT_NONE = 1,
	NVDIMM_FWA_RESULT_SUCCESS = 2,
	NVDIMM_FWA_RESULT_NOTSTAGED = 3,
	NVDIMM_FWA_RESULT_NEEDRESET = 4,
	NVDIMM_FWA_RESULT_FAIL = 5,
};

struct nvdimm_fw_ops {
	enum nvdimm_fwa_state (*activate_state)(struct nvdimm *);
	enum nvdimm_fwa_result (*activate_result)(struct nvdimm *);
	int (*arm)(struct nvdimm *, enum nvdimm_fwa_trigger);
};

struct seq_operations___188 {
	void * (*start)(struct seq_file___188 *, loff_t *);
	void (*stop)(struct seq_file___188 *, void *);
	void * (*next)(struct seq_file___188 *, void *, loff_t *);
	int (*show)(struct seq_file___188 *, void *);
};

struct cftype___147;

struct cgroup_subsys___147 {
	struct cgroup_subsys_state___147 * (*css_alloc)(struct cgroup_subsys_state___147 *);
	int (*css_online)(struct cgroup_subsys_state___147 *);
	void (*css_offline)(struct cgroup_subsys_state___147 *);
	void (*css_released)(struct cgroup_subsys_state___147 *);
	void (*css_free)(struct cgroup_subsys_state___147 *);
	void (*css_reset)(struct cgroup_subsys_state___147 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___147 *, int);
	int (*css_extra_stat_show)(struct seq_file___188 *, struct cgroup_subsys_state___147 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___220 *, struct css_set___147 *);
	void (*cancel_fork)(struct task_struct___220 *, struct css_set___147 *);
	void (*fork)(struct task_struct___220 *);
	void (*exit)(struct task_struct___220 *);
	void (*release)(struct task_struct___220 *);
	void (*bind)(struct cgroup_subsys_state___147 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___147 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___147 *dfl_cftypes;
	struct cftype___147 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___147 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___147 *updated_children;
	struct cgroup___147 *updated_next;
};

struct cgroup_root___147 {
	struct kernfs_root___201 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___147 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___147 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___147 *ss;
	struct list_head node;
	struct kernfs_ops___201 *kf_ops;
	int (*open)(struct kernfs_open_file___201 *);
	void (*release)(struct kernfs_open_file___201 *);
	u64 (*read_u64)(struct cgroup_subsys_state___147 *, struct cftype___147 *);
	s64 (*read_s64)(struct cgroup_subsys_state___147 *, struct cftype___147 *);
	int (*seq_show)(struct seq_file___188 *, void *);
	void * (*seq_start)(struct seq_file___188 *, loff_t *);
	void * (*seq_next)(struct seq_file___188 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___188 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___147 *, struct cftype___147 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___147 *, struct cftype___147 *, s64);
	ssize_t (*write)(struct kernfs_open_file___201 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___201 *, struct poll_table_struct___5 *);
};

typedef void integrity_prepare_fn___109(struct request___109 *);

typedef void integrity_complete_fn___109(struct request___109 *, unsigned int);

struct blk_integrity_profile___109 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___109 *prepare_fn;
	integrity_complete_fn___109 *complete_fn;
	const char *name;
};

struct block_device_operations___109 {
	blk_qc_t (*submit_bio)(struct bio___109 *);
	int (*open)(struct block_device___112 *, fmode_t);
	void (*release)(struct gendisk___112 *, fmode_t);
	int (*rw_page)(struct block_device___112 *, sector_t, struct page___218 *, unsigned int);
	int (*ioctl)(struct block_device___112 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___112 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___112 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___112 *);
	int (*getgeo)(struct block_device___112 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___112 *, bool);
	void (*swap_slot_free_notify)(struct block_device___112 *, long unsigned int);
	int (*report_zones)(struct gendisk___112 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___112 *, umode_t *);
	struct module___197 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___112 *, sector_t *);
};

struct badblocks___2 {
	struct device___191 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

typedef void rq_end_io_fn___109(struct request___109 *, blk_status_t);

struct request___109 {
	struct request_queue___109 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___106 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___109 *bio;
	struct bio___109 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___130 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___109 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___109 *saved_end_io;
		} flush;
	};
	struct gendisk___112 *rq_disk;
	struct block_device___112 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___109 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___106 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___109 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___201 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___213 *debugfs_dir;
	struct dentry___213 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___109;

struct elevator_mq_ops___109 {
	int (*init_sched)(struct request_queue___109 *, struct elevator_type___109 *);
	void (*exit_sched)(struct elevator_queue___109 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___106 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___106 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___106 *);
	bool (*allow_merge)(struct request_queue___109 *, struct request___109 *, struct bio___109 *);
	bool (*bio_merge)(struct request_queue___109 *, struct bio___109 *, unsigned int);
	int (*request_merge)(struct request_queue___109 *, struct request___109 **, struct bio___109 *);
	void (*request_merged)(struct request_queue___109 *, struct request___109 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___109 *, struct request___109 *, struct request___109 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___109 *);
	void (*finish_request)(struct request___109 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___106 *, struct list_head *, bool);
	struct request___109 * (*dispatch_request)(struct blk_mq_hw_ctx___106 *);
	bool (*has_work)(struct blk_mq_hw_ctx___106 *);
	void (*completed_request)(struct request___109 *, u64);
	void (*requeue_request)(struct request___109 *);
	struct request___109 * (*former_request)(struct request_queue___109 *, struct request___109 *);
	struct request___109 * (*next_request)(struct request_queue___109 *, struct request___109 *);
	void (*init_icq)(struct io_cq___109 *);
	void (*exit_icq)(struct io_cq___109 *);
};

struct elv_fs_entry___109;

struct elevator_type___109 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___109 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___109 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___197 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___109 {
	struct elevator_type___109 *type;
	void *elevator_data;
	struct kobject___201 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___109 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___109 *, char *);
	ssize_t (*store)(struct elevator_queue___109 *, const char *, size_t);
};

struct blk_mq_queue_data___106;

struct blk_mq_ops___106 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___106 *, const struct blk_mq_queue_data___106 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___106 *);
	int (*get_budget)(struct request_queue___109 *);
	void (*put_budget)(struct request_queue___109 *, int);
	void (*set_rq_budget_token)(struct request___109 *, int);
	int (*get_rq_budget_token)(struct request___109 *);
	enum blk_eh_timer_return (*timeout)(struct request___109 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___106 *);
	void (*complete)(struct request___109 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___106 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___106 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___106 *, struct request___109 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___106 *, struct request___109 *, unsigned int);
	void (*initialize_rq_fn)(struct request___109 *);
	void (*cleanup_rq)(struct request___109 *);
	bool (*busy)(struct request_queue___109 *);
	int (*map_queues)(struct blk_mq_tag_set___106 *);
	void (*show_rq)(struct seq_file___188 *, struct request___109 *);
};

struct blk_mq_tag_set___106 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___106 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___106 {
	struct request___109 *rq;
	bool last;
};

struct blkcg_policy_data___104;

struct blkcg___104 {
	struct cgroup_subsys_state___147 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___104 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___104 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___104 {
	struct blkcg___104 *blkcg;
	int plid;
};

struct blkg_policy_data___104 {
	struct blkcg_gq___104 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___93 {
	struct mem_cgroup___93 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___93 {
	struct lruvec___101 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___93 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___93 *memcg;
};

struct obj_cgroup___93 {
	struct percpu_ref refcnt;
	struct mem_cgroup___93 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum {
	ND_CMD_IMPLEMENTED = 0,
	ND_CMD_ARS_CAP = 1,
	ND_CMD_ARS_START = 2,
	ND_CMD_ARS_STATUS = 3,
	ND_CMD_CLEAR_ERROR = 4,
	ND_CMD_SMART = 1,
	ND_CMD_SMART_THRESHOLD = 2,
	ND_CMD_DIMM_FLAGS = 3,
	ND_CMD_GET_CONFIG_SIZE = 4,
	ND_CMD_GET_CONFIG_DATA = 5,
	ND_CMD_SET_CONFIG_DATA = 6,
	ND_CMD_VENDOR_EFFECT_LOG_SIZE = 7,
	ND_CMD_VENDOR_EFFECT_LOG = 8,
	ND_CMD_VENDOR = 9,
	ND_CMD_CALL = 10,
};

enum {
	NSINDEX_SIG_LEN = 16,
	NSINDEX_ALIGN = 256,
	NSINDEX_SEQ_MASK = 3,
	NSLABEL_UUID_LEN = 16,
	NSLABEL_NAME_LEN = 64,
	NSLABEL_FLAG_ROLABEL = 1,
	NSLABEL_FLAG_LOCAL = 2,
	NSLABEL_FLAG_BTT = 4,
	NSLABEL_FLAG_UPDATING = 8,
	BTT_ALIGN = 4096,
	BTTINFO_SIG_LEN = 16,
	BTTINFO_UUID_LEN = 16,
	BTTINFO_FLAG_ERROR = 1,
	BTTINFO_MAJOR_VERSION = 1,
	ND_LABEL_MIN_SIZE = 1024,
	ND_LABEL_ID_SIZE = 50,
	ND_NSINDEX_INIT = 1,
};

struct nvdimm_map {
	struct nvdimm_bus *nvdimm_bus;
	struct list_head list;
	resource_size_t offset;
	long unsigned int flags;
	size_t size;
	union {
		void *mem;
		void *iomem;
	};
	struct kref kref;
};

struct badrange_entry {
	u64 start;
	u64 length;
	struct list_head list;
};

struct nd_cmd_desc {
	int in_num;
	int out_num;
	u32 in_sizes[5];
	int out_sizes[5];
};

struct nd_interleave_set {
	u64 cookie1;
	u64 cookie2;
	u64 altcookie;
	guid_t type_guid;
};

struct nvdimm_drvdata;

struct nd_mapping {
	struct nvdimm *nvdimm;
	u64 start;
	u64 size;
	int position;
	struct list_head labels;
	struct mutex lock;
	struct nvdimm_drvdata *ndd;
};

struct nd_percpu_lane;

struct nd_region {
	struct device___191 dev;
	struct ida ns_ida;
	struct ida btt_ida;
	struct ida pfn_ida;
	struct ida dax_ida;
	long unsigned int flags;
	struct device___191 *ns_seed;
	struct device___191 *btt_seed;
	struct device___191 *pfn_seed;
	struct device___191 *dax_seed;
	long unsigned int align;
	u16 ndr_mappings;
	u64 ndr_size;
	u64 ndr_start;
	int id;
	int num_lanes;
	int ro;
	int numa_node;
	int target_node;
	void *provider_data;
	struct kernfs_node___201 *bb_state;
	struct badblocks___2 bb;
	struct nd_interleave_set *nd_set;
	struct nd_percpu_lane *lane;
	int (*flush)(struct nd_region *, struct bio___109 *);
	struct nd_mapping mapping[0];
};

struct nd_cmd_get_config_size {
	__u32 status;
	__u32 config_size;
	__u32 max_xfer;
};

struct nd_cmd_set_config_hdr {
	__u32 in_offset;
	__u32 in_length;
	__u8 in_buf[0];
};

struct nd_cmd_vendor_hdr {
	__u32 opcode;
	__u32 in_length;
	__u8 in_buf[0];
};

struct nd_cmd_ars_cap {
	__u64 address;
	__u64 length;
	__u32 status;
	__u32 max_ars_out;
	__u32 clear_err_unit;
	__u16 flags;
	__u16 reserved;
};

struct nd_cmd_clear_error {
	__u64 address;
	__u64 length;
	__u32 status;
	__u8 reserved[4];
	__u64 cleared;
};

struct nd_cmd_pkg {
	__u64 nd_family;
	__u64 nd_command;
	__u32 nd_size_in;
	__u32 nd_size_out;
	__u32 nd_reserved2[9];
	__u32 nd_fw_size;
	unsigned char nd_payload[0];
};

enum nvdimm_event {
	NVDIMM_REVALIDATE_POISON = 0,
	NVDIMM_REVALIDATE_REGION = 1,
};

enum nvdimm_claim_class {
	NVDIMM_CCLASS_NONE = 0,
	NVDIMM_CCLASS_BTT = 1,
	NVDIMM_CCLASS_BTT2 = 2,
	NVDIMM_CCLASS_PFN = 3,
	NVDIMM_CCLASS_DAX = 4,
	NVDIMM_CCLASS_UNKNOWN = 5,
};

struct nd_device_driver {
	struct device_driver___191 drv;
	long unsigned int type;
	int (*probe)(struct device___191 *);
	void (*remove)(struct device___191 *);
	void (*shutdown)(struct device___191 *);
	void (*notify)(struct device___191 *, enum nvdimm_event);
};

struct nd_namespace_common {
	int force_raw;
	struct device___191 dev;
	struct device___191 *claim;
	enum nvdimm_claim_class claim_class;
	int (*rw_bytes)(struct nd_namespace_common *, resource_size_t, void *, size_t, int, long unsigned int);
};

struct nd_namespace_io {
	struct nd_namespace_common common;
	struct resource res;
	resource_size_t size;
	void *addr;
	struct badblocks___2 bb;
};

struct nvdimm_drvdata {
	struct device___191 *dev;
	int nslabel_size;
	struct nd_cmd_get_config_size nsarea;
	void *data;
	int ns_current;
	int ns_next;
	struct resource dpa;
	struct kref kref;
};

struct nd_percpu_lane {
	int count;
	spinlock_t lock;
};

struct btt;

struct nd_btt {
	struct device___191 dev;
	struct nd_namespace_common *ndns;
	struct btt *btt;
	long unsigned int lbasize;
	u64 size;
	u8 *uuid;
	int id;
	int initial_offset;
	u16 version_major;
	u16 version_minor;
};

enum nd_pfn_mode {
	PFN_MODE_NONE = 0,
	PFN_MODE_RAM = 1,
	PFN_MODE_PMEM = 2,
};

struct nd_pfn_sb;

struct nd_pfn {
	int id;
	u8 *uuid;
	struct device___191 dev;
	long unsigned int align;
	long unsigned int npfns;
	enum nd_pfn_mode mode;
	struct nd_pfn_sb *pfn_sb;
	struct nd_namespace_common *ndns;
};

struct nd_pfn_sb {
	u8 signature[16];
	u8 uuid[16];
	u8 parent_uuid[16];
	__le32 flags;
	__le16 version_major;
	__le16 version_minor;
	__le64 dataoff;
	__le64 npfns;
	__le32 mode;
	__le32 start_pad;
	__le32 end_trunc;
	__le32 align;
	__le32 page_size;
	__le16 page_struct_size;
	u8 padding[3994];
	__le64 checksum;
};

struct nd_dax {
	struct nd_pfn nd_pfn;
};

enum nd_async_mode {
	ND_SYNC = 0,
	ND_ASYNC = 1,
};

struct clear_badblocks_context {
	resource_size_t phys;
	resource_size_t cleared;
};

enum nd_ioctl_mode {
	BUS_IOCTL = 0,
	DIMM_IOCTL = 1,
};

struct nd_cmd_get_config_data_hdr {
	__u32 in_offset;
	__u32 in_length;
	__u32 status;
	__u8 out_buf[0];
};

struct nd_blk_region {
	int (*enable)(struct nvdimm_bus *, struct device___191 *);
	int (*do_io)(struct nd_blk_region *, resource_size_t, void *, u64, int);
	void *blk_provider_data;
	struct nd_region nd_region;
};

enum nvdimm_security_bits {
	NVDIMM_SECURITY_DISABLED = 0,
	NVDIMM_SECURITY_UNLOCKED = 1,
	NVDIMM_SECURITY_LOCKED = 2,
	NVDIMM_SECURITY_FROZEN = 3,
	NVDIMM_SECURITY_OVERWRITE = 4,
};

struct nd_label_id {
	char id[50];
};

struct blk_alloc_info {
	struct nd_mapping *nd_mapping;
	resource_size_t available;
	resource_size_t busy;
	struct resource *res;
};

enum nd_driver_flags {
	ND_DRIVER_DIMM = 2,
	ND_DRIVER_REGION_PMEM = 4,
	ND_DRIVER_REGION_BLK = 8,
	ND_DRIVER_NAMESPACE_IO = 16,
	ND_DRIVER_NAMESPACE_PMEM = 32,
	ND_DRIVER_NAMESPACE_BLK = 64,
	ND_DRIVER_DAX_PMEM = 128,
};

struct nd_mapping_desc {
	struct nvdimm *nvdimm;
	u64 start;
	u64 size;
	int position;
};

struct nd_region_desc {
	struct resource *res;
	struct nd_mapping_desc *mapping;
	u16 num_mappings;
	const struct attribute_group___201 **attr_groups;
	struct nd_interleave_set *nd_set;
	void *provider_data;
	int num_lanes;
	int numa_node;
	int target_node;
	long unsigned int flags;
	struct device_node___2 *of_node;
	int (*flush)(struct nd_region *, struct bio___109 *);
};

struct nd_blk_region_desc {
	int (*enable)(struct nvdimm_bus *, struct device___191 *);
	int (*do_io)(struct nd_blk_region *, resource_size_t, void *, u64, int);
	struct nd_region_desc ndr_desc;
};

struct nd_namespace_index {
	u8 sig[16];
	u8 flags[3];
	u8 labelsize;
	__le32 seq;
	__le64 myoff;
	__le64 mysize;
	__le64 otheroff;
	__le64 labeloff;
	__le32 nslot;
	__le16 major;
	__le16 minor;
	__le64 checksum;
	u8 free[0];
};

struct nd_namespace_label {
	u8 uuid[16];
	u8 name[64];
	__le32 flags;
	__le16 nlabel;
	__le16 position;
	__le64 isetcookie;
	__le64 lbasize;
	__le64 dpa;
	__le64 rawsize;
	__le32 slot;
	u8 align;
	u8 reserved[3];
	guid_t type_guid;
	guid_t abstraction_guid;
	u8 reserved2[88];
	__le64 checksum;
};

enum {
	ND_MAX_LANES = 256,
	INT_LBASIZE_ALIGNMENT = 64,
	NVDIMM_IO_ATOMIC = 1,
};

struct nd_region_data {
	int ns_count;
	int ns_active;
	unsigned int hints_shift;
	void *flush_wpq[0];
};

struct nd_label_ent {
	struct list_head list;
	long unsigned int flags;
	struct nd_namespace_label *label;
};

struct conflict_context {
	struct nd_region *nd_region;
	resource_size_t start;
	resource_size_t size;
};

enum {
	ND_MIN_NAMESPACE_SIZE = 4096,
};

struct nd_namespace_pmem {
	struct nd_namespace_io nsio;
	long unsigned int lbasize;
	char *alt_name;
	u8 *uuid;
	int id;
};

struct nd_namespace_blk {
	struct nd_namespace_common common;
	char *alt_name;
	u8 *uuid;
	int id;
	long unsigned int lbasize;
	resource_size_t size;
	int num_resources;
	struct resource **res;
};

enum nd_label_flags {
	ND_LABEL_REAP = 0,
};

enum alloc_loc {
	ALLOC_ERR = 0,
	ALLOC_BEFORE = 1,
	ALLOC_MID = 2,
	ALLOC_AFTER = 3,
};

struct btt {
	struct gendisk___112 *btt_disk;
	struct list_head arena_list;
	struct dentry___213 *debugfs_dir;
	struct nd_btt *nd_btt;
	u64 nlba;
	long long unsigned int rawsize;
	u32 lbasize;
	u32 sector_size;
	struct nd_region *nd_region;
	struct mutex init_lock;
	int init_state;
	int num_arenas;
	struct badblocks___2 *phys_bb;
};

struct nd_gen_sb {
	char reserved[4088];
	__le64 checksum;
};

struct btt_sb {
	u8 signature[16];
	u8 uuid[16];
	u8 parent_uuid[16];
	__le32 flags;
	__le16 version_major;
	__le16 version_minor;
	__le32 external_lbasize;
	__le32 external_nlba;
	__le32 internal_lbasize;
	__le32 internal_nlba;
	__le32 nfree;
	__le32 infosize;
	__le64 nextoff;
	__le64 dataoff;
	__le64 mapoff;
	__le64 logoff;
	__le64 info2off;
	u8 padding[3968];
	__le64 checksum;
};

typedef int (*request_key_actor_t___13)(struct key___2 *, void *);

enum nvdimmsec_op_ids {
	OP_FREEZE = 0,
	OP_DISABLE = 1,
	OP_UPDATE = 2,
	OP_ERASE = 3,
	OP_OVERWRITE = 4,
	OP_MASTER_UPDATE = 5,
	OP_MASTER_ERASE = 6,
};

struct pseudo_fs_context___10 {
	const struct super_operations___200 *ops;
	const struct xattr_handler **xattr;
	const struct dentry_operations___200 *dops;
	long unsigned int magic;
};

struct device_attribute___26 {
	struct attribute attr;
	ssize_t (*show)(struct device___164 *, struct device_attribute___26 *, char *);
	ssize_t (*store)(struct device___164 *, struct device_attribute___26 *, const char *, size_t);
};

struct dax_operations {
	long int (*direct_access)(struct dax_device *, long unsigned int, long int, void **, pfn_t *);
	bool (*dax_supported)(struct dax_device *, struct block_device___103 *, int, sector_t, sector_t);
	size_t (*copy_from_iter)(struct dax_device *, long unsigned int, void *, size_t, struct iov_iter___121 *);
	size_t (*copy_to_iter)(struct dax_device *, long unsigned int, void *, size_t, struct iov_iter___121 *);
	int (*zero_page_range)(struct dax_device *, long unsigned int, size_t);
};

struct dax_device {
	struct hlist_node list;
	struct inode___200 inode;
	struct cdev___47 cdev;
	const char *host;
	void *private;
	long unsigned int flags;
	const struct dax_operations *ops;
};

enum dax_device_flags {
	DAXDEV_ALIVE = 0,
	DAXDEV_WRITE_CACHE = 1,
	DAXDEV_SYNC = 2,
};

struct dax_region {
	int id;
	int target_node;
	struct kref kref;
	struct device___10 *dev;
	unsigned int align;
	struct ida ida;
	struct resource res;
	struct device___10 *seed;
	struct device___10 *youngest;
};

struct dax_mapping {
	struct device___10 dev;
	int range_id;
	int id;
};

struct dev_dax_range {
	long unsigned int pgoff;
	struct range range;
	struct dax_mapping *mapping;
};

struct dev_dax {
	struct dax_region *region;
	struct dax_device *dax_dev;
	unsigned int align;
	int target_node;
	int id;
	struct ida ida;
	struct device___10 dev;
	struct dev_pagemap___12 *pgmap;
	int nr_range;
	struct dev_dax_range *ranges;
};

enum dev_dax_subsys {
	DEV_DAX_BUS = 0,
	DEV_DAX_CLASS = 1,
};

struct dev_dax_data {
	struct dax_region *dax_region;
	struct dev_pagemap___12 *pgmap;
	enum dev_dax_subsys subsys;
	resource_size_t size;
	int id;
};

struct dax_device_driver {
	struct device_driver___10 drv;
	struct list_head ids;
	int match_always;
	int (*probe)(struct dev_dax *);
	void (*remove)(struct dev_dax *);
};

struct dax_id {
	struct list_head list;
	char dev_name[30];
};

enum id_action {
	ID_REMOVE = 0,
	ID_ADD = 1,
};

struct memregion_info {
	int target_node;
};

struct ww_acquire_ctx___8;

struct ww_mutex___6 {
	struct mutex base;
	struct ww_acquire_ctx___8 *ctx;
};

struct ww_acquire_ctx___8 {
	struct task_struct___101 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct seqcount_ww_mutex {
	seqcount_t seqcount;
};

typedef struct seqcount_ww_mutex seqcount_ww_mutex_t;

struct dma_buf_map {
	union {
		void *vaddr_iomem;
		void *vaddr;
	};
	bool is_iomem;
};

struct dma_fence_ops;

struct dma_fence {
	spinlock_t *lock;
	const struct dma_fence_ops *ops;
	union {
		struct list_head cb_list;
		ktime_t timestamp;
		struct callback_head rcu;
	};
	u64 context;
	u64 seqno;
	long unsigned int flags;
	struct kref refcount;
	int error;
};

struct dma_fence_ops {
	bool use_64bit_seqno;
	const char * (*get_driver_name)(struct dma_fence *);
	const char * (*get_timeline_name)(struct dma_fence *);
	bool (*enable_signaling)(struct dma_fence *);
	bool (*signaled)(struct dma_fence *);
	long int (*wait)(struct dma_fence *, bool, long int);
	void (*release)(struct dma_fence *);
	void (*fence_value_str)(struct dma_fence *, char *, int);
	void (*timeline_value_str)(struct dma_fence *, char *, int);
};

enum dma_fence_flag_bits {
	DMA_FENCE_FLAG_SIGNALED_BIT = 0,
	DMA_FENCE_FLAG_TIMESTAMP_BIT = 1,
	DMA_FENCE_FLAG_ENABLE_SIGNAL_BIT = 2,
	DMA_FENCE_FLAG_USER_BITS = 3,
};

struct dma_fence_cb;

typedef void (*dma_fence_func_t)(struct dma_fence *, struct dma_fence_cb *);

struct dma_fence_cb {
	struct list_head node;
	dma_fence_func_t func;
};

struct dma_buf;

struct dma_buf_attachment;

struct dma_buf_ops {
	bool cache_sgt_mapping;
	int (*attach)(struct dma_buf *, struct dma_buf_attachment *);
	void (*detach)(struct dma_buf *, struct dma_buf_attachment *);
	int (*pin)(struct dma_buf_attachment *);
	void (*unpin)(struct dma_buf_attachment *);
	struct sg_table * (*map_dma_buf)(struct dma_buf_attachment *, enum dma_data_direction);
	void (*unmap_dma_buf)(struct dma_buf_attachment *, struct sg_table *, enum dma_data_direction);
	void (*release)(struct dma_buf *);
	int (*begin_cpu_access)(struct dma_buf *, enum dma_data_direction);
	int (*end_cpu_access)(struct dma_buf *, enum dma_data_direction);
	int (*mmap)(struct dma_buf *, struct vm_area_struct___99 *);
	int (*vmap)(struct dma_buf *, struct dma_buf_map *);
	void (*vunmap)(struct dma_buf *, struct dma_buf_map *);
};

struct dma_buf_poll_cb_t {
	struct dma_fence_cb cb;
	wait_queue_head_t *poll;
	__poll_t active;
};

struct dma_resv;

struct dma_buf {
	size_t size;
	struct file___94 *file;
	struct list_head attachments;
	const struct dma_buf_ops *ops;
	struct mutex lock;
	unsigned int vmapping_counter;
	struct dma_buf_map vmap_ptr;
	const char *exp_name;
	const char *name;
	spinlock_t name_lock;
	struct module___91 *owner;
	struct list_head list_node;
	void *priv;
	struct dma_resv *resv;
	wait_queue_head_t poll;
	struct dma_buf_poll_cb_t cb_in;
	struct dma_buf_poll_cb_t cb_out;
};

struct dma_buf_attach_ops;

struct dma_buf_attachment {
	struct dma_buf *dmabuf;
	struct device___78 *dev;
	struct list_head node;
	struct sg_table *sgt;
	enum dma_data_direction dir;
	bool peer2peer;
	const struct dma_buf_attach_ops *importer_ops;
	void *importer_priv;
	void *priv;
};

struct dma_resv_list;

struct dma_resv {
	struct ww_mutex___6 lock;
	seqcount_ww_mutex_t seq;
	struct dma_fence *fence_excl;
	struct dma_resv_list *fence;
};

struct dma_buf_attach_ops {
	bool allow_peer2peer;
	void (*move_notify)(struct dma_buf_attachment *);
};

struct dma_buf_export_info {
	const char *exp_name;
	struct module___91 *owner;
	const struct dma_buf_ops *ops;
	size_t size;
	int flags;
	struct dma_resv *resv;
	void *priv;
};

typedef struct poll_table_struct___68 poll_table___36;

struct dma_resv_list {
	struct callback_head rcu;
	u32 shared_count;
	u32 shared_max;
	struct dma_fence *shared[0];
};

struct dma_buf_sync {
	__u64 flags;
};

struct dma_buf_list {
	struct list_head head;
	struct mutex lock;
};

struct trace_event_raw_dma_fence {
	struct trace_entry ent;
	u32 __data_loc_driver;
	u32 __data_loc_timeline;
	unsigned int context;
	unsigned int seqno;
	char __data[0];
};

struct trace_event_data_offsets_dma_fence {
	u32 driver;
	u32 timeline;
};

typedef void (*btf_trace_dma_fence_emit)(void *, struct dma_fence *);

typedef void (*btf_trace_dma_fence_init)(void *, struct dma_fence *);

typedef void (*btf_trace_dma_fence_destroy)(void *, struct dma_fence *);

typedef void (*btf_trace_dma_fence_enable_signal)(void *, struct dma_fence *);

typedef void (*btf_trace_dma_fence_signaled)(void *, struct dma_fence *);

typedef void (*btf_trace_dma_fence_wait_start)(void *, struct dma_fence *);

typedef void (*btf_trace_dma_fence_wait_end)(void *, struct dma_fence *);

struct default_wait_cb {
	struct dma_fence_cb base;
	struct task_struct___108 *task;
};

struct dma_fence_array;

struct dma_fence_array_cb {
	struct dma_fence_cb cb;
	struct dma_fence_array *array;
};

struct dma_fence_array {
	struct dma_fence base;
	spinlock_t lock;
	unsigned int num_fences;
	atomic_t num_pending;
	struct dma_fence **fences;
	struct irq_work work;
};

struct dma_fence_chain {
	struct dma_fence base;
	struct dma_fence *prev;
	u64 prev_seqno;
	struct dma_fence *fence;
	union {
		struct dma_fence_cb cb;
		struct irq_work work;
	};
	spinlock_t lock;
};

struct ww_acquire_ctx___9;

struct ww_mutex___7 {
	struct mutex base;
	struct ww_acquire_ctx___9 *ctx;
};

struct ww_acquire_ctx___9 {
	struct task_struct___115 *task;
	long unsigned int stamp;
	unsigned int acquired;
	short unsigned int wounded;
	short unsigned int is_wait_die;
};

struct dma_resv___2 {
	struct ww_mutex___7 lock;
	seqcount_ww_mutex_t seq;
	struct dma_fence *fence_excl;
	struct dma_resv_list *fence;
};

struct dma_buf___2;

struct dma_buf_attachment___2;

struct dma_buf_ops___2 {
	bool cache_sgt_mapping;
	int (*attach)(struct dma_buf___2 *, struct dma_buf_attachment___2 *);
	void (*detach)(struct dma_buf___2 *, struct dma_buf_attachment___2 *);
	int (*pin)(struct dma_buf_attachment___2 *);
	void (*unpin)(struct dma_buf_attachment___2 *);
	struct sg_table * (*map_dma_buf)(struct dma_buf_attachment___2 *, enum dma_data_direction);
	void (*unmap_dma_buf)(struct dma_buf_attachment___2 *, struct sg_table *, enum dma_data_direction);
	void (*release)(struct dma_buf___2 *);
	int (*begin_cpu_access)(struct dma_buf___2 *, enum dma_data_direction);
	int (*end_cpu_access)(struct dma_buf___2 *, enum dma_data_direction);
	int (*mmap)(struct dma_buf___2 *, struct vm_area_struct___110 *);
	int (*vmap)(struct dma_buf___2 *, struct dma_buf_map *);
	void (*vunmap)(struct dma_buf___2 *, struct dma_buf_map *);
};

struct dma_buf___2 {
	size_t size;
	struct file___105 *file;
	struct list_head attachments;
	const struct dma_buf_ops___2 *ops;
	struct mutex lock;
	unsigned int vmapping_counter;
	struct dma_buf_map vmap_ptr;
	const char *exp_name;
	const char *name;
	spinlock_t name_lock;
	struct module___8 *owner;
	struct list_head list_node;
	void *priv;
	struct dma_resv *resv;
	wait_queue_head_t poll;
	struct dma_buf_poll_cb_t cb_in;
	struct dma_buf_poll_cb_t cb_out;
};

struct dma_buf_attach_ops___2;

struct dma_buf_attachment___2 {
	struct dma_buf___2 *dmabuf;
	struct device___85 *dev;
	struct list_head node;
	struct sg_table *sgt;
	enum dma_data_direction dir;
	bool peer2peer;
	const struct dma_buf_attach_ops___2 *importer_ops;
	void *importer_priv;
	void *priv;
};

struct dma_buf_attach_ops___2 {
	bool allow_peer2peer;
	void (*move_notify)(struct dma_buf_attachment___2 *);
};

enum seqno_fence_condition {
	SEQNO_FENCE_WAIT_GEQUAL = 0,
	SEQNO_FENCE_WAIT_NONZERO = 1,
};

struct seqno_fence {
	struct dma_fence base;
	const struct dma_fence_ops *ops;
	struct dma_buf___2 *sync_buf;
	uint32_t seqno_ofs;
	enum seqno_fence_condition condition;
};

struct dma_buf___3;

struct dma_buf_attachment___3;

struct dma_buf_ops___3 {
	bool cache_sgt_mapping;
	int (*attach)(struct dma_buf___3 *, struct dma_buf_attachment___3 *);
	void (*detach)(struct dma_buf___3 *, struct dma_buf_attachment___3 *);
	int (*pin)(struct dma_buf_attachment___3 *);
	void (*unpin)(struct dma_buf_attachment___3 *);
	struct sg_table * (*map_dma_buf)(struct dma_buf_attachment___3 *, enum dma_data_direction);
	void (*unmap_dma_buf)(struct dma_buf_attachment___3 *, struct sg_table *, enum dma_data_direction);
	void (*release)(struct dma_buf___3 *);
	int (*begin_cpu_access)(struct dma_buf___3 *, enum dma_data_direction);
	int (*end_cpu_access)(struct dma_buf___3 *, enum dma_data_direction);
	int (*mmap)(struct dma_buf___3 *, struct vm_area_struct___90 *);
	int (*vmap)(struct dma_buf___3 *, struct dma_buf_map *);
	void (*vunmap)(struct dma_buf___3 *, struct dma_buf_map *);
};

struct dma_buf___3 {
	size_t size;
	struct file___85 *file;
	struct list_head attachments;
	const struct dma_buf_ops___3 *ops;
	struct mutex lock;
	unsigned int vmapping_counter;
	struct dma_buf_map vmap_ptr;
	const char *exp_name;
	const char *name;
	spinlock_t name_lock;
	struct module___83 *owner;
	struct list_head list_node;
	void *priv;
	struct dma_resv *resv;
	wait_queue_head_t poll;
	struct dma_buf_poll_cb_t cb_in;
	struct dma_buf_poll_cb_t cb_out;
};

struct dma_buf_attach_ops___3;

struct dma_buf_attachment___3 {
	struct dma_buf___3 *dmabuf;
	struct device___71 *dev;
	struct list_head node;
	struct sg_table *sgt;
	enum dma_data_direction dir;
	bool peer2peer;
	const struct dma_buf_attach_ops___3 *importer_ops;
	void *importer_priv;
	void *priv;
};

struct dma_buf_attach_ops___3 {
	bool allow_peer2peer;
	void (*move_notify)(struct dma_buf_attachment___3 *);
};

struct dma_heap;

struct dma_heap_ops {
	struct dma_buf___3 * (*allocate)(struct dma_heap *, long unsigned int, long unsigned int, long unsigned int);
};

struct dma_heap {
	const char *name;
	const struct dma_heap_ops *ops;
	void *priv;
	dev_t heap_devt;
	struct list_head list;
	struct cdev___20 heap_cdev;
};

struct dma_heap_export_info {
	const char *name;
	const struct dma_heap_ops *ops;
	void *priv;
};

struct dma_heap_allocation_data {
	__u64 len;
	__u32 fd;
	__u32 fd_flags;
	__u64 heap_flags;
};

struct dma_buf_export_info___2 {
	const char *exp_name;
	struct module___84 *owner;
	const struct dma_buf_ops___3 *ops;
	size_t size;
	int flags;
	struct dma_resv *resv;
	void *priv;
};

struct system_heap_buffer {
	struct dma_heap *heap;
	struct list_head attachments;
	struct mutex lock;
	long unsigned int len;
	struct sg_table sg_table;
	int vmap_cnt;
	void *vaddr;
};

struct dma_heap_attachment {
	struct device___72 *dev;
	struct sg_table *table;
	struct list_head list;
	bool mapped;
};

struct dma_buf___4;

struct dma_buf_attachment___4;

struct dma_buf_ops___4 {
	bool cache_sgt_mapping;
	int (*attach)(struct dma_buf___4 *, struct dma_buf_attachment___4 *);
	void (*detach)(struct dma_buf___4 *, struct dma_buf_attachment___4 *);
	int (*pin)(struct dma_buf_attachment___4 *);
	void (*unpin)(struct dma_buf_attachment___4 *);
	struct sg_table * (*map_dma_buf)(struct dma_buf_attachment___4 *, enum dma_data_direction);
	void (*unmap_dma_buf)(struct dma_buf_attachment___4 *, struct sg_table *, enum dma_data_direction);
	void (*release)(struct dma_buf___4 *);
	int (*begin_cpu_access)(struct dma_buf___4 *, enum dma_data_direction);
	int (*end_cpu_access)(struct dma_buf___4 *, enum dma_data_direction);
	int (*mmap)(struct dma_buf___4 *, struct vm_area_struct___91 *);
	int (*vmap)(struct dma_buf___4 *, struct dma_buf_map *);
	void (*vunmap)(struct dma_buf___4 *, struct dma_buf_map *);
};

struct dma_buf___4 {
	size_t size;
	struct file___86 *file;
	struct list_head attachments;
	const struct dma_buf_ops___4 *ops;
	struct mutex lock;
	unsigned int vmapping_counter;
	struct dma_buf_map vmap_ptr;
	const char *exp_name;
	const char *name;
	spinlock_t name_lock;
	struct module___84 *owner;
	struct list_head list_node;
	void *priv;
	struct dma_resv *resv;
	wait_queue_head_t poll;
	struct dma_buf_poll_cb_t cb_in;
	struct dma_buf_poll_cb_t cb_out;
};

struct dma_buf_attach_ops___4;

struct dma_buf_attachment___4 {
	struct dma_buf___4 *dmabuf;
	struct device___15 *dev;
	struct list_head node;
	struct sg_table *sgt;
	enum dma_data_direction dir;
	bool peer2peer;
	const struct dma_buf_attach_ops___4 *importer_ops;
	void *importer_priv;
	void *priv;
};

struct dma_buf_attach_ops___4 {
	bool allow_peer2peer;
	void (*move_notify)(struct dma_buf_attachment___4 *);
};

struct dma_buf_export_info___3 {
	const char *exp_name;
	struct module___84 *owner;
	const struct dma_buf_ops___4 *ops;
	size_t size;
	int flags;
	struct dma_resv *resv;
	void *priv;
};

struct dma_heap_ops___2 {
	struct dma_buf___4 * (*allocate)(struct dma_heap *, long unsigned int, long unsigned int, long unsigned int);
};

struct dma_heap_export_info___2 {
	const char *name;
	const struct dma_heap_ops___2 *ops;
	void *priv;
};

struct cma_heap {
	struct dma_heap *heap;
	struct cma *cma;
};

struct cma_heap_buffer {
	struct cma_heap *heap;
	struct list_head attachments;
	struct mutex lock;
	long unsigned int len;
	struct page___91 *cma_pages;
	struct page___91 **pages;
	long unsigned int pagecount;
	int vmap_cnt;
	void *vaddr;
};

struct dma_heap_attachment___2 {
	struct device___15 *dev;
	struct sg_table table;
	struct list_head list;
	bool mapped;
};

typedef struct poll_table_struct___77 poll_table___37;

struct sync_file {
	struct file___107 *file;
	char user_name[32];
	struct list_head sync_file_list;
	wait_queue_head_t wq;
	long unsigned int flags;
	struct dma_fence *fence;
	struct dma_fence_cb cb;
};

struct sync_merge_data {
	char name[32];
	__s32 fd2;
	__s32 fence;
	__u32 flags;
	__u32 pad;
};

struct sync_fence_info {
	char obj_name[32];
	char driver_name[32];
	__s32 status;
	__u32 flags;
	__u64 timestamp_ns;
};

struct sync_file_info {
	char name[32];
	__s32 status;
	__u32 flags;
	__u32 num_fences;
	__u32 pad;
	__u64 sync_fence_info;
};

struct sync_file___2 {
	struct file___101 *file;
	char user_name[32];
	struct list_head sync_file_list;
	wait_queue_head_t wq;
	long unsigned int flags;
	struct dma_fence *fence;
	struct dma_fence_cb cb;
};

struct sync_timeline {
	struct kref kref;
	char name[32];
	u64 context;
	int value;
	struct rb_root pt_tree;
	struct list_head pt_list;
	spinlock_t lock;
	struct list_head sync_timeline_list;
};

struct sync_pt {
	struct dma_fence base;
	struct list_head link;
	struct rb_node node;
};

struct trace_event_raw_sync_timeline {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 value;
	char __data[0];
};

struct trace_event_data_offsets_sync_timeline {
	u32 name;
};

typedef void (*btf_trace_sync_timeline)(void *, struct sync_timeline *);

struct sw_sync_create_fence_data {
	__u32 value;
	char name[32];
	__s32 fence;
};

struct miscdevice___8 {
	int minor;
	const char *name;
	const struct file_operations___94 *fops;
	struct list_head list;
	struct device___78 *parent;
	struct device___78 *this_device;
	const struct attribute_group___93 **groups;
	const char *nodename;
	umode_t mode;
};

struct udmabuf_create {
	__u32 memfd;
	__u32 flags;
	__u64 offset;
	__u64 size;
};

struct udmabuf_create_item {
	__u32 memfd;
	__u32 __pad;
	__u64 offset;
	__u64 size;
};

struct udmabuf_create_list {
	__u32 flags;
	__u32 count;
	struct udmabuf_create_item list[0];
};

struct udmabuf {
	long unsigned int pagecount;
	struct page___99 **pages;
	struct sg_table *sg;
	struct miscdevice___8 *device;
};

enum sam_status {
	SAM_STAT_GOOD = 0,
	SAM_STAT_CHECK_CONDITION = 2,
	SAM_STAT_CONDITION_MET = 4,
	SAM_STAT_BUSY = 8,
	SAM_STAT_INTERMEDIATE = 16,
	SAM_STAT_INTERMEDIATE_CONDITION_MET = 20,
	SAM_STAT_RESERVATION_CONFLICT = 24,
	SAM_STAT_COMMAND_TERMINATED = 34,
	SAM_STAT_TASK_SET_FULL = 40,
	SAM_STAT_ACA_ACTIVE = 48,
	SAM_STAT_TASK_ABORTED = 64,
};

enum scsi_host_status {
	DID_OK = 0,
	DID_NO_CONNECT = 1,
	DID_BUS_BUSY = 2,
	DID_TIME_OUT = 3,
	DID_BAD_TARGET = 4,
	DID_ABORT = 5,
	DID_PARITY = 6,
	DID_ERROR = 7,
	DID_RESET = 8,
	DID_BAD_INTR = 9,
	DID_PASSTHROUGH = 10,
	DID_SOFT_ERROR = 11,
	DID_IMM_RETRY = 12,
	DID_REQUEUE = 13,
	DID_TRANSPORT_DISRUPTED = 14,
	DID_TRANSPORT_FAILFAST = 15,
	DID_TARGET_FAILURE = 16,
	DID_NEXUS_FAILURE = 17,
	DID_ALLOC_FAILURE = 18,
	DID_MEDIUM_ERROR = 19,
	DID_TRANSPORT_MARGINAL = 20,
};

enum scsi_disposition {
	NEEDS_RETRY = 8193,
	SUCCESS = 8194,
	FAILED = 8195,
	QUEUED = 8196,
	SOFT_ERROR = 8197,
	ADD_TO_MLQUEUE = 8198,
	TIMEOUT_ERROR = 8199,
	SCSI_RETURN_NOT_HANDLED = 8200,
	FAST_IO_FAIL = 8201,
};

typedef __u64 blist_flags_t;

enum scsi_device_state {
	SDEV_CREATED = 1,
	SDEV_RUNNING = 2,
	SDEV_CANCEL = 3,
	SDEV_DEL = 4,
	SDEV_QUIESCE = 5,
	SDEV_OFFLINE = 6,
	SDEV_TRANSPORT_OFFLINE = 7,
	SDEV_BLOCK = 8,
	SDEV_CREATED_BLOCK = 9,
};

struct scsi_vpd {
	struct callback_head rcu;
	int len;
	unsigned char data[0];
};

struct Scsi_Host;

struct scsi_target;

struct scsi_device_handler;

struct scsi_device {
	struct Scsi_Host *host;
	struct request_queue___38 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable;
	unsigned int changed;
	unsigned int busy;
	unsigned int lockable;
	unsigned int locked;
	unsigned int borken;
	unsigned int disconnect;
	unsigned int soft_reset;
	unsigned int sdtr;
	unsigned int wdtr;
	unsigned int ppr: 1;
	unsigned int tagged_supported;
	unsigned int simple_tags;
	unsigned int was_reset;
	unsigned int expecting_cc_ua;
	unsigned int use_10_for_rw;
	unsigned int use_10_for_ms;
	unsigned int set_dbd_for_ms;
	unsigned int no_report_opcodes;
	unsigned int no_write_same;
	unsigned int use_16_for_rw;
	unsigned int skip_ms_page_8;
	unsigned int skip_ms_page_3f;
	unsigned int skip_vpd_pages;
	unsigned int try_vpd_pages;
	unsigned int use_192_bytes_for_3f;
	unsigned int no_start_on_add;
	unsigned int allow_restart;
	unsigned int manage_start_stop;
	unsigned int start_stop_pwr_cond;
	unsigned int no_uld_attach;
	unsigned int select_no_atn;
	unsigned int fix_capacity;
	unsigned int guess_capacity;
	unsigned int retry_hwerror;
	unsigned int last_sector_bug;
	unsigned int no_read_disc_info;
	unsigned int no_read_capacity_16;
	unsigned int try_rc_10_first;
	unsigned int security_supported;
	unsigned int is_visible;
	unsigned int wce_default_on;
	unsigned int no_dif;
	unsigned int broken_fua;
	unsigned int lun_in_cdb;
	unsigned int unmap_limit_for_ws;
	unsigned int rpm_autosuspend;
	unsigned int ignore_media_change;
	unsigned int silence_suspend;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___69 sdev_gendev;
	struct device___69 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___85 *quiesced_by;
	long unsigned int sdev_data[0];
};

enum scsi_host_state {
	SHOST_CREATED = 1,
	SHOST_RUNNING = 2,
	SHOST_CANCEL = 3,
	SHOST_DEL = 4,
	SHOST_RECOVERY = 5,
	SHOST_CANCEL_RECOVERY = 6,
	SHOST_DEL_RECOVERY = 7,
};

struct scsi_host_template;

struct scsi_transport_template;

struct Scsi_Host {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___85 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___37 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___69 shost_gendev;
	struct device___69 shost_dev;
	void *shost_data;
	struct device___69 *dma_dev;
	long unsigned int hostdata[0];
};

enum scsi_target_state {
	STARGET_CREATED = 1,
	STARGET_RUNNING = 2,
	STARGET_REMOVE = 3,
	STARGET_CREATED_REMOVE = 4,
	STARGET_DEL = 5,
};

struct scsi_target {
	struct scsi_device *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___69 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct scsi_host_cmd_pool;

struct scsi_cmnd;

struct scsi_host_template {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host *, struct scsi_cmnd *);
	void (*commit_rqs)(struct Scsi_Host *, u16);
	struct module___76 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host *);
	int (*ioctl)(struct scsi_device *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host *, struct scsi_cmnd *);
	int (*exit_cmd_priv)(struct Scsi_Host *, struct scsi_cmnd *);
	int (*eh_abort_handler)(struct scsi_cmnd *);
	int (*eh_device_reset_handler)(struct scsi_cmnd *);
	int (*eh_target_reset_handler)(struct scsi_cmnd *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd *);
	int (*eh_host_reset_handler)(struct scsi_cmnd *);
	int (*slave_alloc)(struct scsi_device *);
	int (*slave_configure)(struct scsi_device *);
	void (*slave_destroy)(struct scsi_device *);
	int (*target_alloc)(struct scsi_target *);
	void (*target_destroy)(struct scsi_target *);
	int (*scan_finished)(struct Scsi_Host *, long unsigned int);
	void (*scan_start)(struct Scsi_Host *);
	int (*change_queue_depth)(struct scsi_device *, int);
	int (*map_queues)(struct Scsi_Host *);
	int (*mq_poll)(struct Scsi_Host *, unsigned int);
	bool (*dma_need_drain)(struct request___38 *);
	int (*bios_param)(struct scsi_device *, struct block_device___39 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device *);
	int (*show_info)(struct seq_file___74 *, struct Scsi_Host *);
	int (*write_info)(struct Scsi_Host *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd *);
	int (*host_reset)(struct Scsi_Host *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___9 **shost_attrs;
	struct device_attribute___9 **sdev_attrs;
	const struct attribute_group___78 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_request {
	unsigned char __cmd[16];
	unsigned char *cmd;
	short unsigned int cmd_len;
	int result;
	unsigned int sense_len;
	unsigned int resid_len;
	int retries;
	void *sense;
};

struct scsi_data_buffer {
	struct sg_table table;
	unsigned int length;
};

struct scsi_pointer {
	char *ptr;
	int this_residual;
	struct scatterlist *buffer;
	int buffers_residual;
	dma_addr_t dma_handle;
	volatile int Status;
	volatile int Message;
	volatile int have_data_in;
	volatile int sent_command;
	volatile int phase;
};

struct scsi_cmnd {
	struct scsi_request req;
	struct scsi_device *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

enum scsi_prot_operations {
	SCSI_PROT_NORMAL = 0,
	SCSI_PROT_READ_INSERT = 1,
	SCSI_PROT_WRITE_STRIP = 2,
	SCSI_PROT_READ_STRIP = 3,
	SCSI_PROT_WRITE_INSERT = 4,
	SCSI_PROT_READ_PASS = 5,
	SCSI_PROT_WRITE_PASS = 6,
};

struct scsi_driver {
	struct device_driver___69 gendrv;
	void (*rescan)(struct device___69 *);
	blk_status_t (*init_command)(struct scsi_cmnd *);
	void (*uninit_command)(struct scsi_cmnd *);
	int (*done)(struct scsi_cmnd *);
	int (*eh_action)(struct scsi_cmnd *, int);
	void (*eh_reset)(struct scsi_cmnd *);
};

struct trace_event_raw_scsi_dispatch_cmd_start {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct trace_event_raw_scsi_dispatch_cmd_error {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	int rtn;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct trace_event_raw_scsi_cmd_done_timeout_template {
	struct trace_entry ent;
	unsigned int host_no;
	unsigned int channel;
	unsigned int id;
	unsigned int lun;
	int result;
	unsigned int opcode;
	unsigned int cmd_len;
	unsigned int data_sglen;
	unsigned int prot_sglen;
	unsigned char prot_op;
	u32 __data_loc_cmnd;
	char __data[0];
};

struct trace_event_raw_scsi_eh_wakeup {
	struct trace_entry ent;
	unsigned int host_no;
	char __data[0];
};

struct trace_event_data_offsets_scsi_dispatch_cmd_start {
	u32 cmnd;
};

struct trace_event_data_offsets_scsi_dispatch_cmd_error {
	u32 cmnd;
};

struct trace_event_data_offsets_scsi_cmd_done_timeout_template {
	u32 cmnd;
};

struct trace_event_data_offsets_scsi_eh_wakeup {};

typedef void (*btf_trace_scsi_dispatch_cmd_start)(void *, struct scsi_cmnd *);

typedef void (*btf_trace_scsi_dispatch_cmd_error)(void *, struct scsi_cmnd *, int);

typedef void (*btf_trace_scsi_dispatch_cmd_done)(void *, struct scsi_cmnd *);

typedef void (*btf_trace_scsi_dispatch_cmd_timeout)(void *, struct scsi_cmnd *);

typedef void (*btf_trace_scsi_eh_wakeup)(void *, struct Scsi_Host *);

struct attribute_container___3 {
	struct list_head node;
	struct klist containers;
	struct class___85 *class;
	const struct attribute_group___101 *grp;
	struct device_attribute___7 **attrs;
	int (*match)(struct attribute_container___3 *, struct device___85 *);
	long unsigned int flags;
};

struct transport_container___2 {
	struct attribute_container___3 ac;
	const struct attribute_group___101 *statistics;
};

struct Scsi_Host___2;

struct scsi_target___2;

struct scsi_device___2 {
	struct Scsi_Host___2 *host;
	struct request_queue___49 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___2 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable;
	unsigned int changed;
	unsigned int busy;
	unsigned int lockable;
	unsigned int locked;
	unsigned int borken;
	unsigned int disconnect;
	unsigned int soft_reset;
	unsigned int sdtr;
	unsigned int wdtr;
	unsigned int ppr: 1;
	unsigned int tagged_supported;
	unsigned int simple_tags;
	unsigned int was_reset;
	unsigned int expecting_cc_ua;
	unsigned int use_10_for_rw;
	unsigned int use_10_for_ms;
	unsigned int set_dbd_for_ms;
	unsigned int no_report_opcodes;
	unsigned int no_write_same;
	unsigned int use_16_for_rw;
	unsigned int skip_ms_page_8;
	unsigned int skip_ms_page_3f;
	unsigned int skip_vpd_pages;
	unsigned int try_vpd_pages;
	unsigned int use_192_bytes_for_3f;
	unsigned int no_start_on_add;
	unsigned int allow_restart;
	unsigned int manage_start_stop;
	unsigned int start_stop_pwr_cond;
	unsigned int no_uld_attach;
	unsigned int select_no_atn;
	unsigned int fix_capacity;
	unsigned int guess_capacity;
	unsigned int retry_hwerror;
	unsigned int last_sector_bug;
	unsigned int no_read_disc_info;
	unsigned int no_read_capacity_16;
	unsigned int try_rc_10_first;
	unsigned int security_supported;
	unsigned int is_visible;
	unsigned int wce_default_on;
	unsigned int no_dif;
	unsigned int broken_fua;
	unsigned int lun_in_cdb;
	unsigned int unmap_limit_for_ws;
	unsigned int rpm_autosuspend;
	unsigned int ignore_media_change;
	unsigned int silence_suspend;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___85 sdev_gendev;
	struct device___85 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___112 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___2;

struct Scsi_Host___2 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___112 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___2 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___48 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___85 shost_gendev;
	struct device___85 shost_dev;
	void *shost_data;
	struct device___85 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_target___2 {
	struct scsi_device___2 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___85 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

typedef bool busy_tag_iter_fn___3(struct request___49 *, void *, bool);

struct scsi_cmnd___2;

struct scsi_host_template___2 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___2 *, struct scsi_cmnd___2 *);
	void (*commit_rqs)(struct Scsi_Host___2 *, u16);
	struct module___99 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___2 *);
	int (*ioctl)(struct scsi_device___2 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___2 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___2 *, struct scsi_cmnd___2 *);
	int (*exit_cmd_priv)(struct Scsi_Host___2 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___2 *);
	int (*slave_configure)(struct scsi_device___2 *);
	void (*slave_destroy)(struct scsi_device___2 *);
	int (*target_alloc)(struct scsi_target___2 *);
	void (*target_destroy)(struct scsi_target___2 *);
	int (*scan_finished)(struct Scsi_Host___2 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___2 *);
	int (*change_queue_depth)(struct scsi_device___2 *, int);
	int (*map_queues)(struct Scsi_Host___2 *);
	int (*mq_poll)(struct Scsi_Host___2 *, unsigned int);
	bool (*dma_need_drain)(struct request___49 *);
	int (*bios_param)(struct scsi_device___2 *, struct block_device___50 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___2 *);
	int (*show_info)(struct seq_file___97 *, struct Scsi_Host___2 *);
	int (*write_info)(struct Scsi_Host___2 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___2 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___7 **shost_attrs;
	struct device_attribute___7 **sdev_attrs;
	const struct attribute_group___101 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_cmnd___2 {
	struct scsi_request req;
	struct scsi_device___2 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___2 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

struct scsi_transport_template {
	struct transport_container___2 host_attrs;
	struct transport_container___2 target_attrs;
	struct transport_container___2 device_attrs;
	int (*user_scan)(struct Scsi_Host___2 *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void (*eh_strategy_handler)(struct Scsi_Host___2 *);
};

struct scsi_host_busy_iter_data {
	bool (*fn)(struct scsi_cmnd___2 *, void *, bool);
	void *priv;
};

struct dentry___214;

struct super_block___214;

struct module___198;

struct file_system_type___214 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___214 * (*mount)(struct file_system_type___214 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___214 *);
	struct module___198 *owner;
	struct file_system_type___214 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___214;

struct kiocb___214;

struct iov_iter___134;

struct vm_area_struct___219;

struct inode___214;

struct file_lock___214;

struct page___219;

struct seq_file___189;

struct file_operations___215 {
	struct module___198 *owner;
	loff_t (*llseek)(struct file___214 *, loff_t, int);
	ssize_t (*read)(struct file___214 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___214 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___214 *, struct iov_iter___134 *);
	ssize_t (*write_iter)(struct kiocb___214 *, struct iov_iter___134 *);
	int (*iopoll)(struct kiocb___214 *, bool);
	int (*iterate)(struct file___214 *, struct dir_context *);
	int (*iterate_shared)(struct file___214 *, struct dir_context *);
	__poll_t (*poll)(struct file___214 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___214 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___214 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___214 *, struct vm_area_struct___219 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___214 *, struct file___214 *);
	int (*flush)(struct file___214 *, fl_owner_t);
	int (*release)(struct inode___214 *, struct file___214 *);
	int (*fsync)(struct file___214 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___214 *, int);
	int (*lock)(struct file___214 *, int, struct file_lock___214 *);
	ssize_t (*sendpage)(struct file___214 *, struct page___219 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___214 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___214 *, long unsigned int);
	int (*flock)(struct file___214 *, int, struct file_lock___214 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___214 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___214 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___214 *, long int, struct file_lock___214 **, void **);
	long int (*fallocate)(struct file___214 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___189 *, struct file___214 *);
	ssize_t (*copy_file_range)(struct file___214 *, loff_t, struct file___214 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___214 *, loff_t, struct file___214 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___214 *, loff_t, loff_t, int);
};

struct vmacache___219 {
	u64 seqnum;
	struct vm_area_struct___219 *vmas[4];
};

struct page_frag___219 {
	struct page___219 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___220;

struct pid___191;

struct nsproxy___200;

struct signal_struct___215;

struct bio_list___110;

struct io_context___110;

struct request_queue___110;

struct vm_struct___197;

struct task_struct___221 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___221 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___220 *mm;
	struct mm_struct___220 *active_mm;
	struct vmacache___219 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___221 *real_parent;
	struct task_struct___221 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___221 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___191 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___200 *nsproxy;
	struct signal_struct___215 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___221 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___110 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___110 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___219 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___110 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___221 *oom_reaper_list;
	struct vm_struct___197 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___61 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___202;

struct kobj_type___202;

struct kernfs_node___202;

struct kobject___202 {
	const char *name;
	struct list_head entry;
	struct kobject___202 *parent;
	struct kset___202 *kset;
	struct kobj_type___202 *ktype;
	struct kernfs_node___202 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___199 {
	struct kobject___202 kobj;
	struct module___198 *mod;
	struct kobject___202 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___198 {
	struct module___198 *mod;
	struct latch_tree_node node;
};

struct module_layout___198 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___198 mtn;
};

struct module_attribute___198;

struct kernel_param___198;

struct module___198 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___199 mkobj;
	struct module_attribute___198 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___202 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___198 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___198 core_layout;
	struct module_layout___198 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___191;

struct upid___191 {
	int nr;
	struct pid_namespace___191 *ns;
};

struct pid_namespace___191 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___221 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___191 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___191 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___191 numbers[1];
};

typedef struct page___219 *pgtable_t___219;

struct address_space___214;

struct dev_pagemap___209;

struct page___219 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___214 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___219 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___219 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___220 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___209 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___209;

struct vm_area_struct___219 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___219 *vm_next;
	struct vm_area_struct___219 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___220 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___209 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___214 *vm_file;
	struct file___214 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___215 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___221 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___221 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___191 *pids[4];
	struct pid___191 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___220 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___219;

struct mm_struct___220 {
	struct {
		struct vm_area_struct___219 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___214 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___219 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___221 *owner;
		struct user_namespace *user_ns;
		struct file___214 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___200 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___191 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___110;

struct bio_list___110 {
	struct bio___110 *head;
	struct bio___110 *tail;
};

struct io_cq___110;

struct io_context___110 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___110 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___110;

struct blk_integrity___110 {
	const struct blk_integrity_profile___110 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___110 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___110 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___110;

struct elevator_queue___110;

struct blk_mq_ops___107;

struct blk_mq_hw_ctx___107;

struct gendisk___113;

struct device___192;

struct blk_mq_tag_set___107;

struct request_queue___110 {
	struct request___110 *last_merge;
	struct elevator_queue___110 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___107 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___107 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___113 *disk;
	struct kobject___202 kobj;
	struct kobject___202 *mq_kobj;
	struct blk_integrity___110 integrity;
	struct device___192 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___107 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___110 bio_split;
	struct dentry___214 *debugfs_dir;
	struct dentry___214 *sched_debugfs_dir;
	struct dentry___214 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___197 {
	struct vm_struct___197 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___219 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___214;

struct address_space___214 {
	struct inode___214 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___214 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___209;

struct dev_pagemap___209 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___209 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___214;

struct path___214 {
	struct vfsmount___214 *mnt;
	struct dentry___214 *dentry;
};

struct fown_struct___191 {
	rwlock_t lock;
	struct pid___191 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___214 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___214 f_path;
	struct inode___214 *f_inode;
	const struct file_operations___215 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___191 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___214 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___209;

struct vm_operations_struct___209 {
	void (*open)(struct vm_area_struct___219 *);
	void (*close)(struct vm_area_struct___219 *);
	int (*may_split)(struct vm_area_struct___219 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___219 *);
	int (*mprotect)(struct vm_area_struct___219 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___209 *);
	vm_fault_t (*huge_fault)(struct vm_fault___209 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___209 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___219 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___209 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___209 *);
	int (*access)(struct vm_area_struct___219 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___219 *);
	int (*set_policy)(struct vm_area_struct___219 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___219 *, long unsigned int);
	struct page___219 * (*find_special_page)(struct vm_area_struct___219 *, long unsigned int);
};

struct core_thread___219 {
	struct task_struct___221 *task;
	struct core_thread___219 *next;
};

struct core_state___219 {
	atomic_t nr_threads;
	struct core_thread___219 dumper;
	struct completion startup;
};

struct vm_fault___209 {
	const struct {
		struct vm_area_struct___219 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___219 *cow_page;
	struct page___219 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___219 prealloc_pte;
};

struct dentry_operations___214;

struct dentry___214 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___214 *d_parent;
	struct qstr d_name;
	struct inode___214 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___214 *d_op;
	struct super_block___214 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___214;

struct inode___214 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___214 *i_op;
	struct super_block___214 *i_sb;
	struct address_space___214 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___215 *i_fop;
		void (*free_inode)(struct inode___214 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___214 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___214 {
	int (*d_revalidate)(struct dentry___214 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___214 *, unsigned int);
	int (*d_hash)(const struct dentry___214 *, struct qstr *);
	int (*d_compare)(const struct dentry___214 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___214 *);
	int (*d_init)(struct dentry___214 *);
	void (*d_release)(struct dentry___214 *);
	void (*d_prune)(struct dentry___214 *);
	void (*d_iput)(struct dentry___214 *, struct inode___214 *);
	char * (*d_dname)(struct dentry___214 *, char *, int);
	struct vfsmount___214 * (*d_automount)(struct path___214 *);
	int (*d_manage)(const struct path___214 *, bool);
	struct dentry___214 * (*d_real)(struct dentry___214 *, const struct inode___214 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___214;

struct mem_dqinfo___214 {
	struct quota_format_type___214 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___214;

struct quota_info___214 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___214 *files[3];
	struct mem_dqinfo___214 info[3];
	const struct quota_format_ops___214 *ops[3];
};

struct rcuwait___215 {
	struct task_struct___221 *task;
};

struct percpu_rw_semaphore___215 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___215 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___214 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___215 rw_sem[3];
};

struct super_operations___214;

struct dquot_operations___214;

struct quotactl_ops___214;

struct block_device___113;

struct super_block___214 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___214 *s_type;
	const struct super_operations___214 *s_op;
	const struct dquot_operations___214 *dq_op;
	const struct quotactl_ops___214 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___214 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___113 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___214 s_dquot;
	struct sb_writers___214 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___214 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___214 {
	struct dentry___214 *mnt_root;
	struct super_block___214 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___110 {
	struct request_queue___110 *q;
	struct io_context___110 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___214 {
	struct file___214 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___214 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___103 *ki_waitq;
	};
};

struct iattr___214 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___214 *ia_file;
};

struct dquot___214 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___214 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___214 {
	int qf_fmt_id;
	const struct quota_format_ops___214 *qf_ops;
	struct module___198 *qf_owner;
	struct quota_format_type___214 *qf_next;
};

struct quota_format_ops___214 {
	int (*check_quota_file)(struct super_block___214 *, int);
	int (*read_file_info)(struct super_block___214 *, int);
	int (*write_file_info)(struct super_block___214 *, int);
	int (*free_file_info)(struct super_block___214 *, int);
	int (*read_dqblk)(struct dquot___214 *);
	int (*commit_dqblk)(struct dquot___214 *);
	int (*release_dqblk)(struct dquot___214 *);
	int (*get_next_id)(struct super_block___214 *, struct kqid *);
};

struct dquot_operations___214 {
	int (*write_dquot)(struct dquot___214 *);
	struct dquot___214 * (*alloc_dquot)(struct super_block___214 *, int);
	void (*destroy_dquot)(struct dquot___214 *);
	int (*acquire_dquot)(struct dquot___214 *);
	int (*release_dquot)(struct dquot___214 *);
	int (*mark_dirty)(struct dquot___214 *);
	int (*write_info)(struct super_block___214 *, int);
	qsize_t * (*get_reserved_space)(struct inode___214 *);
	int (*get_projid)(struct inode___214 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___214 *, qsize_t *);
	int (*get_next_id)(struct super_block___214 *, struct kqid *);
};

struct quotactl_ops___214 {
	int (*quota_on)(struct super_block___214 *, int, int, const struct path___214 *);
	int (*quota_off)(struct super_block___214 *, int);
	int (*quota_enable)(struct super_block___214 *, unsigned int);
	int (*quota_disable)(struct super_block___214 *, unsigned int);
	int (*quota_sync)(struct super_block___214 *, int);
	int (*set_info)(struct super_block___214 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___214 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___214 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___214 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___214 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___214 *, unsigned int);
};

struct address_space_operations___214 {
	int (*writepage)(struct page___219 *, struct writeback_control___3 *);
	int (*readpage)(struct file___214 *, struct page___219 *);
	int (*writepages)(struct address_space___214 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___219 *);
	int (*readpages)(struct file___214 *, struct address_space___214 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___214 *, struct address_space___214 *, loff_t, unsigned int, unsigned int, struct page___219 **, void **);
	int (*write_end)(struct file___214 *, struct address_space___214 *, loff_t, unsigned int, unsigned int, struct page___219 *, void *);
	sector_t (*bmap)(struct address_space___214 *, sector_t);
	void (*invalidatepage)(struct page___219 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___219 *, gfp_t);
	void (*freepage)(struct page___219 *);
	ssize_t (*direct_IO)(struct kiocb___214 *, struct iov_iter___134 *);
	int (*migratepage)(struct address_space___214 *, struct page___219 *, struct page___219 *, enum migrate_mode);
	bool (*isolate_page)(struct page___219 *, isolate_mode_t);
	void (*putback_page)(struct page___219 *);
	int (*launder_page)(struct page___219 *);
	int (*is_partially_uptodate)(struct page___219 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___219 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___214 *, struct page___219 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___214 *, sector_t *);
	void (*swap_deactivate)(struct file___214 *);
};

struct bio_vec___131;

struct iov_iter___134 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___131 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___214 {
	struct dentry___214 * (*lookup)(struct inode___214 *, struct dentry___214 *, unsigned int);
	const char * (*get_link)(struct dentry___214 *, struct inode___214 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___214 *, int);
	struct posix_acl * (*get_acl)(struct inode___214 *, int, bool);
	int (*readlink)(struct dentry___214 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___214 *, struct dentry___214 *, umode_t, bool);
	int (*link)(struct dentry___214 *, struct inode___214 *, struct dentry___214 *);
	int (*unlink)(struct inode___214 *, struct dentry___214 *);
	int (*symlink)(struct user_namespace *, struct inode___214 *, struct dentry___214 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___214 *, struct dentry___214 *, umode_t);
	int (*rmdir)(struct inode___214 *, struct dentry___214 *);
	int (*mknod)(struct user_namespace *, struct inode___214 *, struct dentry___214 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___214 *, struct dentry___214 *, struct inode___214 *, struct dentry___214 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___214 *, struct iattr___214 *);
	int (*getattr)(struct user_namespace *, const struct path___214 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___214 *, char *, size_t);
	int (*fiemap)(struct inode___214 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___214 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___214 *, struct dentry___214 *, struct file___214 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___214 *, struct dentry___214 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___214 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___214 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___214 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___214 {
	void (*fl_copy_lock)(struct file_lock___214 *, struct file_lock___214 *);
	void (*fl_release_private)(struct file_lock___214 *);
};

struct fasync_struct___214;

struct lock_manager_operations___214;

struct file_lock___214 {
	struct file_lock___214 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___214 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___214 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___214 *fl_ops;
	const struct lock_manager_operations___214 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___214 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___214 *);
	int (*lm_grant)(struct file_lock___214 *, int);
	bool (*lm_break)(struct file_lock___214 *);
	int (*lm_change)(struct file_lock___214 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___214 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___214 *);
};

struct fasync_struct___214 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___214 *fa_next;
	struct file___214 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___214 {
	struct inode___214 * (*alloc_inode)(struct super_block___214 *);
	void (*destroy_inode)(struct inode___214 *);
	void (*free_inode)(struct inode___214 *);
	void (*dirty_inode)(struct inode___214 *, int);
	int (*write_inode)(struct inode___214 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___214 *);
	void (*evict_inode)(struct inode___214 *);
	void (*put_super)(struct super_block___214 *);
	int (*sync_fs)(struct super_block___214 *, int);
	int (*freeze_super)(struct super_block___214 *);
	int (*freeze_fs)(struct super_block___214 *);
	int (*thaw_super)(struct super_block___214 *);
	int (*unfreeze_fs)(struct super_block___214 *);
	int (*statfs)(struct dentry___214 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___214 *, int *, char *);
	void (*umount_begin)(struct super_block___214 *);
	int (*show_options)(struct seq_file___189 *, struct dentry___214 *);
	int (*show_devname)(struct seq_file___189 *, struct dentry___214 *);
	int (*show_path)(struct seq_file___189 *, struct dentry___214 *);
	int (*show_stats)(struct seq_file___189 *, struct dentry___214 *);
	ssize_t (*quota_read)(struct super_block___214 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___214 *, int, const char *, size_t, loff_t);
	struct dquot___214 ** (*get_dquots)(struct inode___214 *);
	long int (*nr_cached_objects)(struct super_block___214 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___214 *, struct shrink_control___93 *);
	struct file___214 * (*real_loop)(struct file___214 *);
};

struct wakeup_source___192;

struct dev_pm_info___192 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___192 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___192 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___192;

struct bus_type___192;

struct device_driver___192;

struct dev_pm_domain___192;

struct fwnode_handle___188;

struct class___192;

struct attribute_group___202;

struct device___192 {
	struct kobject___202 kobj;
	struct device___192 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___192 *type;
	struct bus_type___192 *bus;
	struct device_driver___192 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___192 power;
	struct dev_pm_domain___192 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___188 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___192 *class;
	const struct attribute_group___202 **groups;
	void (*release)(struct device___192 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___113 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___214 *bd_inode;
	struct super_block___214 *bd_super;
	void *bd_claiming;
	struct device___192 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___202 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___113 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___214 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___189;

struct seq_file___189 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___189 *op;
	int poll_event;
	const struct file___214 *file;
	void *private;
};

typedef void bio_end_io_t___110(struct bio___110 *);

struct bio_vec___131 {
	struct page___219 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___110;

struct bio___110 {
	struct bio___110 *bi_next;
	struct block_device___113 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___110 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___110 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___131 *bi_io_vec;
	struct bio_set___110 *bi_pool;
	struct bio_vec___131 bi_inline_vecs[0];
};

struct kernfs_root___202;

struct kernfs_elem_dir___202 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___202 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___202;

struct kernfs_root___202 {
	struct kernfs_node___202 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___202 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___202 {
	struct kernfs_node___202 *target_kn;
};

struct kernfs_ops___202;

struct kernfs_elem_attr___202 {
	const struct kernfs_ops___202 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___202 *notify_next;
};

struct kernfs_node___202 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___202 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___202 dir;
		struct kernfs_elem_symlink___202 symlink;
		struct kernfs_elem_attr___202 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___202;

struct kernfs_ops___202 {
	int (*open)(struct kernfs_open_file___202 *);
	void (*release)(struct kernfs_open_file___202 *);
	int (*seq_show)(struct seq_file___189 *, void *);
	void * (*seq_start)(struct seq_file___189 *, loff_t *);
	void * (*seq_next)(struct seq_file___189 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___189 *, void *);
	ssize_t (*read)(struct kernfs_open_file___202 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___202 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___202 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___202 *, struct vm_area_struct___219 *);
};

struct kernfs_syscall_ops___202 {
	int (*show_options)(struct seq_file___189 *, struct kernfs_root___202 *);
	int (*mkdir)(struct kernfs_node___202 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___202 *);
	int (*rename)(struct kernfs_node___202 *, struct kernfs_node___202 *, const char *);
	int (*show_path)(struct seq_file___189 *, struct kernfs_node___202 *, struct kernfs_root___202 *);
};

struct kernfs_open_file___202 {
	struct kernfs_node___202 *kn;
	struct file___214 *file;
	struct seq_file___189 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___209 *vm_ops;
};

struct bin_attribute___202;

struct attribute_group___202 {
	const char *name;
	umode_t (*is_visible)(struct kobject___202 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___202 *, struct bin_attribute___202 *, int);
	struct attribute **attrs;
	struct bin_attribute___202 **bin_attrs;
};

struct bin_attribute___202 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___214 * (*f_mapping)();
	ssize_t (*read)(struct file___214 *, struct kobject___202 *, struct bin_attribute___202 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___214 *, struct kobject___202 *, struct bin_attribute___202 *, char *, loff_t, size_t);
	int (*mmap)(struct file___214 *, struct kobject___202 *, struct bin_attribute___202 *, struct vm_area_struct___219 *);
};

struct sysfs_ops___202 {
	ssize_t (*show)(struct kobject___202 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___202 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___202;

struct kset___202 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___202 kobj;
	const struct kset_uevent_ops___202 *uevent_ops;
};

struct kobj_type___202 {
	void (*release)(struct kobject___202 *);
	const struct sysfs_ops___202 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___202 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___202 *);
	const void * (*namespace)(struct kobject___202 *);
	void (*get_ownership)(struct kobject___202 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___202 {
	int (* const filter)(struct kset___202 *, struct kobject___202 *);
	const char * (* const name)(struct kset___202 *, struct kobject___202 *);
	int (* const uevent)(struct kset___202 *, struct kobject___202 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___198 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___198 *);
	int (*get)(char *, const struct kernel_param___198 *);
	void (*free)(void *);
};

struct kparam_array___198;

struct kernel_param___198 {
	const char *name;
	struct module___198 *mod;
	const struct kernel_param_ops___198 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___198 *arr;
	};
};

struct kparam_array___198 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___198 *ops;
	void *elem;
};

struct module_attribute___198 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___198 *, struct module_kobject___199 *, char *);
	ssize_t (*store)(struct module_attribute___198 *, struct module_kobject___199 *, const char *, size_t);
	void (*setup)(struct module___198 *, const char *);
	int (*test)(struct module___198 *);
	void (*free)(struct module___198 *);
};

struct dev_pagemap_ops___209 {
	void (*page_free)(struct page___219 *);
	void (*kill)(struct dev_pagemap___209 *);
	void (*cleanup)(struct dev_pagemap___209 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___209 *);
};

struct fwnode_operations___188;

struct fwnode_handle___188 {
	struct fwnode_handle___188 *secondary;
	const struct fwnode_operations___188 *ops;
	struct device___192 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___188;

struct fwnode_endpoint___188;

struct fwnode_operations___188 {
	struct fwnode_handle___188 * (*get)(struct fwnode_handle___188 *);
	void (*put)(struct fwnode_handle___188 *);
	bool (*device_is_available)(const struct fwnode_handle___188 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___188 *, const struct device___192 *);
	bool (*property_present)(const struct fwnode_handle___188 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___188 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___188 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___188 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*get_parent)(const struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*get_next_child_node)(const struct fwnode_handle___188 *, struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*get_named_child_node)(const struct fwnode_handle___188 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___188 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___188 *);
	struct fwnode_handle___188 * (*graph_get_next_endpoint)(const struct fwnode_handle___188 *, struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*graph_get_remote_endpoint)(const struct fwnode_handle___188 *);
	struct fwnode_handle___188 * (*graph_get_port_parent)(struct fwnode_handle___188 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___188 *, struct fwnode_endpoint___188 *);
	int (*add_links)(struct fwnode_handle___188 *);
};

struct fwnode_endpoint___188 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___188 *local_fwnode;
};

struct fwnode_reference_args___188 {
	struct fwnode_handle___188 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___192 {
	int (*prepare)(struct device___192 *);
	void (*complete)(struct device___192 *);
	int (*suspend)(struct device___192 *);
	int (*resume)(struct device___192 *);
	int (*freeze)(struct device___192 *);
	int (*thaw)(struct device___192 *);
	int (*poweroff)(struct device___192 *);
	int (*restore)(struct device___192 *);
	int (*suspend_late)(struct device___192 *);
	int (*resume_early)(struct device___192 *);
	int (*freeze_late)(struct device___192 *);
	int (*thaw_early)(struct device___192 *);
	int (*poweroff_late)(struct device___192 *);
	int (*restore_early)(struct device___192 *);
	int (*suspend_noirq)(struct device___192 *);
	int (*resume_noirq)(struct device___192 *);
	int (*freeze_noirq)(struct device___192 *);
	int (*thaw_noirq)(struct device___192 *);
	int (*poweroff_noirq)(struct device___192 *);
	int (*restore_noirq)(struct device___192 *);
	int (*runtime_suspend)(struct device___192 *);
	int (*runtime_resume)(struct device___192 *);
	int (*runtime_idle)(struct device___192 *);
};

struct wakeup_source___192 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___192 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___192 {
	struct dev_pm_ops___192 ops;
	int (*start)(struct device___192 *);
	void (*detach)(struct device___192 *, bool);
	int (*activate)(struct device___192 *);
	void (*sync)(struct device___192 *);
	void (*dismiss)(struct device___192 *);
};

struct bus_type___192 {
	const char *name;
	const char *dev_name;
	struct device___192 *dev_root;
	const struct attribute_group___202 **bus_groups;
	const struct attribute_group___202 **dev_groups;
	const struct attribute_group___202 **drv_groups;
	int (*match)(struct device___192 *, struct device_driver___192 *);
	int (*uevent)(struct device___192 *, struct kobj_uevent_env *);
	int (*probe)(struct device___192 *);
	void (*sync_state)(struct device___192 *);
	void (*remove)(struct device___192 *);
	void (*shutdown)(struct device___192 *);
	int (*online)(struct device___192 *);
	int (*offline)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	int (*num_vf)(struct device___192 *);
	int (*dma_configure)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___192 {
	const char *name;
	struct bus_type___192 *bus;
	struct module___198 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___192 *);
	void (*sync_state)(struct device___192 *);
	int (*remove)(struct device___192 *);
	void (*shutdown)(struct device___192 *);
	int (*suspend)(struct device___192 *, pm_message_t);
	int (*resume)(struct device___192 *);
	const struct attribute_group___202 **groups;
	const struct attribute_group___202 **dev_groups;
	const struct dev_pm_ops___192 *pm;
	void (*coredump)(struct device___192 *);
	struct driver_private *p;
};

struct device_type___192 {
	const char *name;
	const struct attribute_group___202 **groups;
	int (*uevent)(struct device___192 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___192 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___192 *);
	const struct dev_pm_ops___192 *pm;
};

struct class___192 {
	const char *name;
	struct module___198 *owner;
	const struct attribute_group___202 **class_groups;
	const struct attribute_group___202 **dev_groups;
	struct kobject___202 *dev_kobj;
	int (*dev_uevent)(struct device___192 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___192 *, umode_t *);
	void (*class_release)(struct class___192 *);
	void (*dev_release)(struct device___192 *);
	int (*shutdown_pre)(struct device___192 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___192 *);
	void (*get_ownership)(struct device___192 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___192 *pm;
	struct subsys_private *p;
};

struct device_attribute___27 {
	struct attribute attr;
	ssize_t (*show)(struct device___192 *, struct device_attribute___27 *, char *);
	ssize_t (*store)(struct device___192 *, struct device_attribute___27 *, const char *, size_t);
};

struct block_device_operations___110;

struct cdrom_device_info___2;

struct gendisk___113 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___113 *part0;
	const struct block_device_operations___110 *fops;
	struct request_queue___110 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___202 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___202 integrity_kobj;
	struct cdrom_device_info___2 *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___110 {
	struct bio___110 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___131 *bip_vec;
	struct bio_vec___131 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___110(struct request___110 *);

typedef void integrity_complete_fn___110(struct request___110 *, unsigned int);

struct blk_integrity_profile___110 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___110 *prepare_fn;
	integrity_complete_fn___110 *complete_fn;
	const char *name;
};

struct block_device_operations___110 {
	blk_qc_t (*submit_bio)(struct bio___110 *);
	int (*open)(struct block_device___113 *, fmode_t);
	void (*release)(struct gendisk___113 *, fmode_t);
	int (*rw_page)(struct block_device___113 *, sector_t, struct page___219 *, unsigned int);
	int (*ioctl)(struct block_device___113 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___113 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___113 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___113 *);
	int (*getgeo)(struct block_device___113 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___113 *, bool);
	void (*swap_slot_free_notify)(struct block_device___113 *, long unsigned int);
	int (*report_zones)(struct gendisk___113 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___113 *, umode_t *);
	struct module___198 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___113 *, sector_t *);
};

struct cdrom_device_ops___2;

struct cdrom_device_info___2 {
	const struct cdrom_device_ops___2 *ops;
	struct list_head list;
	struct gendisk___113 *disk;
	void *handle;
	int mask;
	int speed;
	int capacity;
	unsigned int options: 30;
	unsigned int mc_flags: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int vfs_events;
	unsigned int ioctl_events;
	int use_count;
	char name[20];
	__u8 sanyo_slot: 2;
	__u8 keeplocked: 1;
	__u8 reserved: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int cdda_method;
	__u8 last_sense;
	__u8 media_written;
	short unsigned int mmc3_profile;
	int for_data;
	int (*exit)(struct cdrom_device_info___2 *);
	int mrw_mode_page;
};

typedef void rq_end_io_fn___110(struct request___110 *, blk_status_t);

struct request___110 {
	struct request_queue___110 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___107 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___110 *bio;
	struct bio___110 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___131 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___110 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___110 *saved_end_io;
		} flush;
	};
	struct gendisk___113 *rq_disk;
	struct block_device___113 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___110 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___107 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___110 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___202 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___214 *debugfs_dir;
	struct dentry___214 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___110;

struct elevator_mq_ops___110 {
	int (*init_sched)(struct request_queue___110 *, struct elevator_type___110 *);
	void (*exit_sched)(struct elevator_queue___110 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___107 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___107 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___107 *);
	bool (*allow_merge)(struct request_queue___110 *, struct request___110 *, struct bio___110 *);
	bool (*bio_merge)(struct request_queue___110 *, struct bio___110 *, unsigned int);
	int (*request_merge)(struct request_queue___110 *, struct request___110 **, struct bio___110 *);
	void (*request_merged)(struct request_queue___110 *, struct request___110 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___110 *, struct request___110 *, struct request___110 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___110 *);
	void (*finish_request)(struct request___110 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___107 *, struct list_head *, bool);
	struct request___110 * (*dispatch_request)(struct blk_mq_hw_ctx___107 *);
	bool (*has_work)(struct blk_mq_hw_ctx___107 *);
	void (*completed_request)(struct request___110 *, u64);
	void (*requeue_request)(struct request___110 *);
	struct request___110 * (*former_request)(struct request_queue___110 *, struct request___110 *);
	struct request___110 * (*next_request)(struct request_queue___110 *, struct request___110 *);
	void (*init_icq)(struct io_cq___110 *);
	void (*exit_icq)(struct io_cq___110 *);
};

struct elv_fs_entry___110;

struct elevator_type___110 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___110 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___110 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___198 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___110 {
	struct elevator_type___110 *type;
	void *elevator_data;
	struct kobject___202 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___110 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___110 *, char *);
	ssize_t (*store)(struct elevator_queue___110 *, const char *, size_t);
};

struct blk_mq_queue_data___107;

struct blk_mq_ops___107 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___107 *, const struct blk_mq_queue_data___107 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___107 *);
	int (*get_budget)(struct request_queue___110 *);
	void (*put_budget)(struct request_queue___110 *, int);
	void (*set_rq_budget_token)(struct request___110 *, int);
	int (*get_rq_budget_token)(struct request___110 *);
	enum blk_eh_timer_return (*timeout)(struct request___110 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___107 *);
	void (*complete)(struct request___110 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___107 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___107 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___107 *, struct request___110 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___107 *, struct request___110 *, unsigned int);
	void (*initialize_rq_fn)(struct request___110 *);
	void (*cleanup_rq)(struct request___110 *);
	bool (*busy)(struct request_queue___110 *);
	int (*map_queues)(struct blk_mq_tag_set___107 *);
	void (*show_rq)(struct seq_file___189 *, struct request___110 *);
};

struct blk_mq_tag_set___107 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___107 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct rq_map_data___3 {
	struct page___219 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct request_sense;

struct cdrom_generic_command {
	unsigned char cmd[12];
	unsigned char *buffer;
	unsigned int buflen;
	int stat;
	struct request_sense *sense;
	unsigned char data_direction;
	int quiet;
	int timeout;
	union {
		void *reserved[1];
		void *unused;
	};
};

struct request_sense {
	__u8 error_code: 7;
	__u8 valid: 1;
	__u8 segment_number;
	__u8 sense_key: 4;
	__u8 reserved2: 1;
	__u8 ili: 1;
	__u8 reserved1: 2;
	int: 22;
	__u8 information[4];
	__u8 add_sense_len;
	__u8 command_info[4];
	__u8 asc;
	__u8 ascq;
	__u8 fruc;
	__u8 sks[3];
	__u8 asb[46];
};

struct cdrom_device_ops___2 {
	int (*open)(struct cdrom_device_info___2 *, int);
	void (*release)(struct cdrom_device_info___2 *);
	int (*drive_status)(struct cdrom_device_info___2 *, int);
	unsigned int (*check_events)(struct cdrom_device_info___2 *, unsigned int, int);
	int (*tray_move)(struct cdrom_device_info___2 *, int);
	int (*lock_door)(struct cdrom_device_info___2 *, int);
	int (*select_speed)(struct cdrom_device_info___2 *, int);
	int (*select_disc)(struct cdrom_device_info___2 *, int);
	int (*get_last_session)(struct cdrom_device_info___2 *, struct cdrom_multisession *);
	int (*get_mcn)(struct cdrom_device_info___2 *, struct cdrom_mcn *);
	int (*reset)(struct cdrom_device_info___2 *);
	int (*audio_ioctl)(struct cdrom_device_info___2 *, unsigned int, void *);
	int (*generic_packet)(struct cdrom_device_info___2 *, struct packet_command *);
	int (*read_cdda_bpc)(struct cdrom_device_info___2 *, void *, u32, u32, u8 *);
	const int capability;
};

enum scsi_msg_byte {
	COMMAND_COMPLETE = 0,
	EXTENDED_MESSAGE = 1,
	SAVE_POINTERS = 2,
	RESTORE_POINTERS = 3,
	DISCONNECT = 4,
	INITIATOR_ERROR = 5,
	ABORT_TASK_SET = 6,
	MESSAGE_REJECT = 7,
	NOP = 8,
	MSG_PARITY_ERROR = 9,
	LINKED_CMD_COMPLETE = 10,
	LINKED_FLG_CMD_COMPLETE = 11,
	TARGET_RESET = 12,
	ABORT_TASK = 13,
	CLEAR_TASK_SET = 14,
	INITIATE_RECOVERY = 15,
	RELEASE_RECOVERY = 16,
	TERMINATE_IO_PROC = 17,
	CLEAR_ACA = 22,
	LOGICAL_UNIT_RESET = 23,
	SIMPLE_QUEUE_TAG = 32,
	HEAD_OF_QUEUE_TAG = 33,
	ORDERED_QUEUE_TAG = 34,
	IGNORE_WIDE_RESIDUE = 35,
	ACA = 36,
	QAS_REQUEST = 85,
	BUS_DEVICE_RESET = 12,
	ABORT = 6,
};

struct Scsi_Host___3;

struct scsi_target___3;

struct scsi_device___3 {
	struct Scsi_Host___3 *host;
	struct request_queue___110 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___3 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___192 sdev_gendev;
	struct device___192 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___221 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___3;

struct Scsi_Host___3 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___221 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___3 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___107 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___192 shost_gendev;
	struct device___192 shost_dev;
	void *shost_data;
	struct device___192 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_target___3 {
	struct scsi_device___3 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___192 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct seq_operations___189 {
	void * (*start)(struct seq_file___189 *, loff_t *);
	void (*stop)(struct seq_file___189 *, void *);
	void * (*next)(struct seq_file___189 *, void *, loff_t *);
	int (*show)(struct seq_file___189 *, void *);
};

struct blk_mq_queue_data___107 {
	struct request___110 *rq;
	bool last;
};

struct scsi_cmnd___3;

struct scsi_host_template___3 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___3 *, struct scsi_cmnd___3 *);
	void (*commit_rqs)(struct Scsi_Host___3 *, u16);
	struct module___198 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___3 *);
	int (*ioctl)(struct scsi_device___3 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___3 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___3 *, struct scsi_cmnd___3 *);
	int (*exit_cmd_priv)(struct Scsi_Host___3 *, struct scsi_cmnd___3 *);
	int (*eh_abort_handler)(struct scsi_cmnd___3 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___3 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___3 *);
	int (*slave_alloc)(struct scsi_device___3 *);
	int (*slave_configure)(struct scsi_device___3 *);
	void (*slave_destroy)(struct scsi_device___3 *);
	int (*target_alloc)(struct scsi_target___3 *);
	void (*target_destroy)(struct scsi_target___3 *);
	int (*scan_finished)(struct Scsi_Host___3 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___3 *);
	int (*change_queue_depth)(struct scsi_device___3 *, int);
	int (*map_queues)(struct Scsi_Host___3 *);
	int (*mq_poll)(struct Scsi_Host___3 *, unsigned int);
	bool (*dma_need_drain)(struct request___110 *);
	int (*bios_param)(struct scsi_device___3 *, struct block_device___113 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___3 *);
	int (*show_info)(struct seq_file___189 *, struct Scsi_Host___3 *);
	int (*write_info)(struct Scsi_Host___3 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___3 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___3 *);
	int (*host_reset)(struct Scsi_Host___3 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___27 **shost_attrs;
	struct device_attribute___27 **sdev_attrs;
	const struct attribute_group___202 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_cmnd___3 {
	struct scsi_request req;
	struct scsi_device___3 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___3 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

struct scsi_ioctl_command {
	unsigned int inlen;
	unsigned int outlen;
	unsigned char data[0];
};

struct scsi_idlun {
	__u32 dev_id;
	__u32 host_unique_id;
};

struct sg_io_hdr {
	int interface_id;
	int dxfer_direction;
	unsigned char cmd_len;
	unsigned char mx_sb_len;
	short unsigned int iovec_count;
	unsigned int dxfer_len;
	void *dxferp;
	unsigned char *cmdp;
	void *sbp;
	unsigned int timeout;
	unsigned int flags;
	int pack_id;
	void *usr_ptr;
	unsigned char status;
	unsigned char masked_status;
	unsigned char msg_status;
	unsigned char sb_len_wr;
	short unsigned int host_status;
	short unsigned int driver_status;
	int resid;
	unsigned int duration;
	unsigned int info;
};

struct compat_sg_io_hdr {
	compat_int_t interface_id;
	compat_int_t dxfer_direction;
	unsigned char cmd_len;
	unsigned char mx_sb_len;
	short unsigned int iovec_count;
	compat_uint_t dxfer_len;
	compat_uint_t dxferp;
	compat_uptr_t cmdp;
	compat_uptr_t sbp;
	compat_uint_t timeout;
	compat_uint_t flags;
	compat_int_t pack_id;
	compat_uptr_t usr_ptr;
	unsigned char status;
	unsigned char masked_status;
	unsigned char msg_status;
	unsigned char sb_len_wr;
	short unsigned int host_status;
	short unsigned int driver_status;
	compat_int_t resid;
	compat_uint_t duration;
	compat_uint_t info;
};

struct compat_cdrom_generic_command {
	unsigned char cmd[12];
	compat_caddr_t buffer;
	compat_uint_t buflen;
	compat_int_t stat;
	compat_caddr_t sense;
	unsigned char data_direction;
	unsigned char pad[3];
	compat_int_t quiet;
	compat_int_t timeout;
	compat_caddr_t unused;
};

enum {
	OMAX_SB_LEN = 16,
};

typedef int filler_t___8(void *, struct page___107 *);

typedef void (*activate_complete)(void *, int);

struct scsi_device_handler {
	struct list_head list;
	struct module___99 *module;
	const char *name;
	enum scsi_disposition (*check_sense)(struct scsi_device___2 *, struct scsi_sense_hdr *);
	int (*attach)(struct scsi_device___2 *);
	void (*detach)(struct scsi_device___2 *);
	int (*activate)(struct scsi_device___2 *, activate_complete, void *);
	blk_status_t (*prep_fn)(struct scsi_device___2 *, struct request___49 *);
	int (*set_params)(struct scsi_device___2 *, const char *);
	void (*rescan)(struct scsi_device___2 *);
};

struct scsi_driver___2 {
	struct device_driver___85 gendrv;
	void (*rescan)(struct device___85 *);
	blk_status_t (*init_command)(struct scsi_cmnd___2 *);
	void (*uninit_command)(struct scsi_cmnd___2 *);
	int (*done)(struct scsi_cmnd___2 *);
	int (*eh_action)(struct scsi_cmnd___2 *, int);
	void (*eh_reset)(struct scsi_cmnd___2 *);
};

struct scsi_eh_save {
	int result;
	unsigned int resid_len;
	int eh_eflags;
	enum dma_data_direction data_direction;
	unsigned int underflow;
	unsigned char cmd_len;
	unsigned char prot_op;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	unsigned char eh_cmnd[16];
	struct scatterlist sense_sgl;
};

struct scsi_mode_data {
	__u32 length;
	__u16 block_descriptor_length;
	__u8 medium_type;
	__u8 device_specific;
	__u8 header_length;
	__u8 longlba: 1;
	long: 31;
	long: 64;
};

struct scsi_event {
	enum scsi_device_event evt_type;
	struct list_head node;
};

enum scsi_host_prot_capabilities {
	SHOST_DIF_TYPE1_PROTECTION = 1,
	SHOST_DIF_TYPE2_PROTECTION = 2,
	SHOST_DIF_TYPE3_PROTECTION = 4,
	SHOST_DIX_TYPE0_PROTECTION = 8,
	SHOST_DIX_TYPE1_PROTECTION = 16,
	SHOST_DIX_TYPE2_PROTECTION = 32,
	SHOST_DIX_TYPE3_PROTECTION = 64,
};

enum {
	ACTION_FAIL = 0,
	ACTION_REPREP = 1,
	ACTION_RETRY = 2,
	ACTION_DELAYED_RETRY = 3,
};

struct value_name_pair;

struct sa_name_list {
	int opcode;
	const struct value_name_pair *arr;
	int arr_sz;
};

struct value_name_pair {
	int value;
	const char *name;
};

struct error_info {
	short unsigned int code12;
	short unsigned int size;
};

struct error_info2 {
	unsigned char code1;
	unsigned char code2_min;
	unsigned char code2_max;
	const char *str;
	const char *fmt;
};

struct scsi_lun {
	__u8 scsi_lun[8];
};

enum scsi_timeouts {
	SCSI_DEFAULT_EH_TIMEOUT = 2500,
};

enum scsi_scan_mode {
	SCSI_SCAN_INITIAL = 0,
	SCSI_SCAN_RESCAN = 1,
	SCSI_SCAN_MANUAL = 2,
};

struct async_scan_data {
	struct list_head list;
	struct Scsi_Host___2 *shost;
	struct completion prev_finished;
};

enum scsi_devinfo_key {
	SCSI_DEVINFO_GLOBAL = 0,
	SCSI_DEVINFO_SPI = 1,
};

struct scsi_dev_info_list {
	struct list_head dev_info_list;
	char vendor[8];
	char model[16];
	blist_flags_t flags;
	unsigned int compatible;
};

struct scsi_dev_info_list_table {
	struct list_head node;
	struct list_head scsi_dev_info_list;
	const char *name;
	int key;
};

struct double_list {
	struct list_head *top;
	struct list_head *bottom;
};

struct scsi_nl_hdr {
	__u8 version;
	__u8 transport;
	__u16 magic;
	__u16 msgtype;
	__u16 msglen;
};

struct ctl_table_header___2;

struct ctl_node___2 {
	struct rb_node node;
	struct ctl_table_header___2 *header;
};

struct completion___2;

struct ctl_table_root___2;

struct ctl_table_set___2;

struct ctl_dir___2;

struct ctl_table_header___2 {
	union {
		struct {
			struct ctl_table___2 *ctl_table;
			int used;
			int count;
			int nreg;
		};
		struct callback_head rcu;
	};
	struct completion___2 *unregistering;
	struct ctl_table___2 *ctl_table_arg;
	struct ctl_table_root___2 *root;
	struct ctl_table_set___2 *set;
	struct ctl_dir___2 *parent;
	struct ctl_node___2 *node;
	struct hlist_head inodes;
};

struct swait_queue_head___2 {
	raw_spinlock_t___2 lock;
	struct list_head task_list;
};

struct completion___2 {
	unsigned int done;
	struct swait_queue_head___2 wait;
};

struct ctl_dir___2 {
	struct ctl_table_header___2 header;
	struct rb_root root;
};

struct ctl_table_set___2 {
	int (*is_seen)(struct ctl_table_set___2 *);
	struct ctl_dir___2 dir;
};

struct ctl_table_root___2 {
	struct ctl_table_set___2 default_set;
	struct ctl_table_set___2 * (*lookup)(struct ctl_table_root___2 *);
	void (*set_ownership)(struct ctl_table_header___2 *, struct ctl_table___2 *, kuid_t *, kgid_t *);
	int (*permissions)(struct ctl_table_header___2 *, struct ctl_table___2 *);
};

struct scsi_varlen_cdb_hdr {
	__u8 opcode;
	__u8 control;
	__u8 misc[5];
	__u8 additional_cdb_length;
	__be16 service_action;
};

enum {
	SCSI_DH_OK = 0,
	SCSI_DH_DEV_FAILED = 1,
	SCSI_DH_DEV_TEMP_BUSY = 2,
	SCSI_DH_DEV_UNSUPP = 3,
	SCSI_DH_DEVICE_MAX = 4,
	SCSI_DH_NOTCONN = 5,
	SCSI_DH_CONN_FAILURE = 6,
	SCSI_DH_TRANSPORT_MAX = 7,
	SCSI_DH_IO = 8,
	SCSI_DH_INVALID_IO = 9,
	SCSI_DH_RETRY = 10,
	SCSI_DH_IMM_RETRY = 11,
	SCSI_DH_TIMED_OUT = 12,
	SCSI_DH_RES_TEMP_UNAVAIL = 13,
	SCSI_DH_DEV_OFFLINED = 14,
	SCSI_DH_NOMEM = 15,
	SCSI_DH_NOSYS = 16,
	SCSI_DH_DRIVER_MAX = 17,
};

struct scsi_dh_blist {
	const char *vendor;
	const char *model;
	const char *driver;
};

typedef int bsg_sg_io_fn___2(struct request_queue___49 *, struct sg_io_v4 *, fmode_t, unsigned int);

struct dentry___215;

struct super_block___215;

struct module___199;

struct file_system_type___215 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___215 * (*mount)(struct file_system_type___215 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___215 *);
	struct module___199 *owner;
	struct file_system_type___215 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___215;

struct kiocb___215;

struct iov_iter___135;

struct vm_area_struct___220;

struct inode___215;

struct file_lock___215;

struct page___220;

struct seq_file___190;

struct file_operations___216 {
	struct module___199 *owner;
	loff_t (*llseek)(struct file___215 *, loff_t, int);
	ssize_t (*read)(struct file___215 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___215 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___215 *, struct iov_iter___135 *);
	ssize_t (*write_iter)(struct kiocb___215 *, struct iov_iter___135 *);
	int (*iopoll)(struct kiocb___215 *, bool);
	int (*iterate)(struct file___215 *, struct dir_context *);
	int (*iterate_shared)(struct file___215 *, struct dir_context *);
	__poll_t (*poll)(struct file___215 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___215 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___215 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___215 *, struct vm_area_struct___220 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___215 *, struct file___215 *);
	int (*flush)(struct file___215 *, fl_owner_t);
	int (*release)(struct inode___215 *, struct file___215 *);
	int (*fsync)(struct file___215 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___215 *, int);
	int (*lock)(struct file___215 *, int, struct file_lock___215 *);
	ssize_t (*sendpage)(struct file___215 *, struct page___220 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___215 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___215 *, long unsigned int);
	int (*flock)(struct file___215 *, int, struct file_lock___215 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___215 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___215 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___215 *, long int, struct file_lock___215 **, void **);
	long int (*fallocate)(struct file___215 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___190 *, struct file___215 *);
	ssize_t (*copy_file_range)(struct file___215 *, loff_t, struct file___215 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___215 *, loff_t, struct file___215 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___215 *, loff_t, loff_t, int);
};

struct vmacache___220 {
	u64 seqnum;
	struct vm_area_struct___220 *vmas[4];
};

struct page_frag___220 {
	struct page___220 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___221;

struct pid___192;

struct nsproxy___201;

struct signal_struct___216;

struct bio_list___111;

struct io_context___111;

struct request_queue___111;

struct vm_struct___198;

struct task_struct___222 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___222 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___221 *mm;
	struct mm_struct___221 *active_mm;
	struct vmacache___220 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___222 *real_parent;
	struct task_struct___222 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___222 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___192 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___201 *nsproxy;
	struct signal_struct___216 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___222 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___111 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___111 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___220 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___111 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___222 *oom_reaper_list;
	struct vm_struct___198 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___61 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___203;

struct kobj_type___203;

struct kernfs_node___203;

struct kobject___203 {
	const char *name;
	struct list_head entry;
	struct kobject___203 *parent;
	struct kset___203 *kset;
	struct kobj_type___203 *ktype;
	struct kernfs_node___203 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___200 {
	struct kobject___203 kobj;
	struct module___199 *mod;
	struct kobject___203 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___199 {
	struct module___199 *mod;
	struct latch_tree_node node;
};

struct module_layout___199 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___199 mtn;
};

struct module_attribute___199;

struct kernel_param___199;

struct module___199 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___200 mkobj;
	struct module_attribute___199 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___203 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___199 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___199 core_layout;
	struct module_layout___199 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___192;

struct upid___192 {
	int nr;
	struct pid_namespace___192 *ns;
};

struct pid_namespace___192 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___222 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___192 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___192 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___192 numbers[1];
};

typedef struct page___220 *pgtable_t___220;

struct address_space___215;

struct dev_pagemap___210;

struct page___220 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___215 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___220 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___220 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___221 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___210 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___210;

struct vm_area_struct___220 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___220 *vm_next;
	struct vm_area_struct___220 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___221 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___210 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___215 *vm_file;
	struct file___215 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___216 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___222 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___222 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___192 *pids[4];
	struct pid___192 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___221 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___220;

struct mm_struct___221 {
	struct {
		struct vm_area_struct___220 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___215 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___220 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___222 *owner;
		struct user_namespace *user_ns;
		struct file___215 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___201 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___192 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___111;

struct bio_list___111 {
	struct bio___111 *head;
	struct bio___111 *tail;
};

struct io_cq___111;

struct io_context___111 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___111 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___111;

struct blk_integrity___111 {
	const struct blk_integrity_profile___111 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___111 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___111 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___111;

struct elevator_queue___111;

struct blk_mq_ops___108;

struct blk_mq_hw_ctx___108;

struct gendisk___114;

struct device___193;

struct blk_mq_tag_set___108;

struct request_queue___111 {
	struct request___111 *last_merge;
	struct elevator_queue___111 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___108 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___108 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___114 *disk;
	struct kobject___203 kobj;
	struct kobject___203 *mq_kobj;
	struct blk_integrity___111 integrity;
	struct device___193 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___108 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___111 bio_split;
	struct dentry___215 *debugfs_dir;
	struct dentry___215 *sched_debugfs_dir;
	struct dentry___215 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___198 {
	struct vm_struct___198 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___220 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___215;

struct address_space___215 {
	struct inode___215 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___215 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___210;

struct dev_pagemap___210 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___210 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___215;

struct path___215 {
	struct vfsmount___215 *mnt;
	struct dentry___215 *dentry;
};

struct fown_struct___192 {
	rwlock_t lock;
	struct pid___192 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___215 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___215 f_path;
	struct inode___215 *f_inode;
	const struct file_operations___216 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___192 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___215 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___210;

struct vm_operations_struct___210 {
	void (*open)(struct vm_area_struct___220 *);
	void (*close)(struct vm_area_struct___220 *);
	int (*may_split)(struct vm_area_struct___220 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___220 *);
	int (*mprotect)(struct vm_area_struct___220 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___210 *);
	vm_fault_t (*huge_fault)(struct vm_fault___210 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___210 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___220 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___210 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___210 *);
	int (*access)(struct vm_area_struct___220 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___220 *);
	int (*set_policy)(struct vm_area_struct___220 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___220 *, long unsigned int);
	struct page___220 * (*find_special_page)(struct vm_area_struct___220 *, long unsigned int);
};

struct core_thread___220 {
	struct task_struct___222 *task;
	struct core_thread___220 *next;
};

struct core_state___220 {
	atomic_t nr_threads;
	struct core_thread___220 dumper;
	struct completion startup;
};

struct vm_fault___210 {
	const struct {
		struct vm_area_struct___220 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___220 *cow_page;
	struct page___220 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___220 prealloc_pte;
};

struct dentry_operations___215;

struct dentry___215 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___215 *d_parent;
	struct qstr d_name;
	struct inode___215 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___215 *d_op;
	struct super_block___215 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___215;

struct inode___215 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___215 *i_op;
	struct super_block___215 *i_sb;
	struct address_space___215 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___216 *i_fop;
		void (*free_inode)(struct inode___215 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___215 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___38 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___215 {
	int (*d_revalidate)(struct dentry___215 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___215 *, unsigned int);
	int (*d_hash)(const struct dentry___215 *, struct qstr *);
	int (*d_compare)(const struct dentry___215 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___215 *);
	int (*d_init)(struct dentry___215 *);
	void (*d_release)(struct dentry___215 *);
	void (*d_prune)(struct dentry___215 *);
	void (*d_iput)(struct dentry___215 *, struct inode___215 *);
	char * (*d_dname)(struct dentry___215 *, char *, int);
	struct vfsmount___215 * (*d_automount)(struct path___215 *);
	int (*d_manage)(const struct path___215 *, bool);
	struct dentry___215 * (*d_real)(struct dentry___215 *, const struct inode___215 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___215;

struct mem_dqinfo___215 {
	struct quota_format_type___215 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___215;

struct quota_info___215 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___215 *files[3];
	struct mem_dqinfo___215 info[3];
	const struct quota_format_ops___215 *ops[3];
};

struct rcuwait___216 {
	struct task_struct___222 *task;
};

struct percpu_rw_semaphore___216 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___216 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___215 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___216 rw_sem[3];
};

struct super_operations___215;

struct dquot_operations___215;

struct quotactl_ops___215;

struct block_device___114;

struct super_block___215 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___215 *s_type;
	const struct super_operations___215 *s_op;
	const struct dquot_operations___215 *dq_op;
	const struct quotactl_ops___215 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___215 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___114 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___215 s_dquot;
	struct sb_writers___215 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___215 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___215 {
	struct dentry___215 *mnt_root;
	struct super_block___215 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___111 {
	struct request_queue___111 *q;
	struct io_context___111 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___215 {
	struct file___215 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___215 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___103 *ki_waitq;
	};
};

struct iattr___215 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___215 *ia_file;
};

struct dquot___215 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___215 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___215 {
	int qf_fmt_id;
	const struct quota_format_ops___215 *qf_ops;
	struct module___199 *qf_owner;
	struct quota_format_type___215 *qf_next;
};

struct quota_format_ops___215 {
	int (*check_quota_file)(struct super_block___215 *, int);
	int (*read_file_info)(struct super_block___215 *, int);
	int (*write_file_info)(struct super_block___215 *, int);
	int (*free_file_info)(struct super_block___215 *, int);
	int (*read_dqblk)(struct dquot___215 *);
	int (*commit_dqblk)(struct dquot___215 *);
	int (*release_dqblk)(struct dquot___215 *);
	int (*get_next_id)(struct super_block___215 *, struct kqid *);
};

struct dquot_operations___215 {
	int (*write_dquot)(struct dquot___215 *);
	struct dquot___215 * (*alloc_dquot)(struct super_block___215 *, int);
	void (*destroy_dquot)(struct dquot___215 *);
	int (*acquire_dquot)(struct dquot___215 *);
	int (*release_dquot)(struct dquot___215 *);
	int (*mark_dirty)(struct dquot___215 *);
	int (*write_info)(struct super_block___215 *, int);
	qsize_t * (*get_reserved_space)(struct inode___215 *);
	int (*get_projid)(struct inode___215 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___215 *, qsize_t *);
	int (*get_next_id)(struct super_block___215 *, struct kqid *);
};

struct quotactl_ops___215 {
	int (*quota_on)(struct super_block___215 *, int, int, const struct path___215 *);
	int (*quota_off)(struct super_block___215 *, int);
	int (*quota_enable)(struct super_block___215 *, unsigned int);
	int (*quota_disable)(struct super_block___215 *, unsigned int);
	int (*quota_sync)(struct super_block___215 *, int);
	int (*set_info)(struct super_block___215 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___215 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___215 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___215 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___215 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___215 *, unsigned int);
};

struct address_space_operations___215 {
	int (*writepage)(struct page___220 *, struct writeback_control___3 *);
	int (*readpage)(struct file___215 *, struct page___220 *);
	int (*writepages)(struct address_space___215 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___220 *);
	int (*readpages)(struct file___215 *, struct address_space___215 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___215 *, struct address_space___215 *, loff_t, unsigned int, unsigned int, struct page___220 **, void **);
	int (*write_end)(struct file___215 *, struct address_space___215 *, loff_t, unsigned int, unsigned int, struct page___220 *, void *);
	sector_t (*bmap)(struct address_space___215 *, sector_t);
	void (*invalidatepage)(struct page___220 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___220 *, gfp_t);
	void (*freepage)(struct page___220 *);
	ssize_t (*direct_IO)(struct kiocb___215 *, struct iov_iter___135 *);
	int (*migratepage)(struct address_space___215 *, struct page___220 *, struct page___220 *, enum migrate_mode);
	bool (*isolate_page)(struct page___220 *, isolate_mode_t);
	void (*putback_page)(struct page___220 *);
	int (*launder_page)(struct page___220 *);
	int (*is_partially_uptodate)(struct page___220 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___220 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___215 *, struct page___220 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___215 *, sector_t *);
	void (*swap_deactivate)(struct file___215 *);
};

struct bio_vec___132;

struct iov_iter___135 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___132 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___215 {
	struct dentry___215 * (*lookup)(struct inode___215 *, struct dentry___215 *, unsigned int);
	const char * (*get_link)(struct dentry___215 *, struct inode___215 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___215 *, int);
	struct posix_acl * (*get_acl)(struct inode___215 *, int, bool);
	int (*readlink)(struct dentry___215 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___215 *, struct dentry___215 *, umode_t, bool);
	int (*link)(struct dentry___215 *, struct inode___215 *, struct dentry___215 *);
	int (*unlink)(struct inode___215 *, struct dentry___215 *);
	int (*symlink)(struct user_namespace *, struct inode___215 *, struct dentry___215 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___215 *, struct dentry___215 *, umode_t);
	int (*rmdir)(struct inode___215 *, struct dentry___215 *);
	int (*mknod)(struct user_namespace *, struct inode___215 *, struct dentry___215 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___215 *, struct dentry___215 *, struct inode___215 *, struct dentry___215 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___215 *, struct iattr___215 *);
	int (*getattr)(struct user_namespace *, const struct path___215 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___215 *, char *, size_t);
	int (*fiemap)(struct inode___215 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___215 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___215 *, struct dentry___215 *, struct file___215 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___215 *, struct dentry___215 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___215 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___215 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___215 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___215 {
	void (*fl_copy_lock)(struct file_lock___215 *, struct file_lock___215 *);
	void (*fl_release_private)(struct file_lock___215 *);
};

struct fasync_struct___215;

struct lock_manager_operations___215;

struct file_lock___215 {
	struct file_lock___215 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___215 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___215 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___215 *fl_ops;
	const struct lock_manager_operations___215 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___215 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___215 *);
	int (*lm_grant)(struct file_lock___215 *, int);
	bool (*lm_break)(struct file_lock___215 *);
	int (*lm_change)(struct file_lock___215 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___215 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___215 *);
};

struct fasync_struct___215 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___215 *fa_next;
	struct file___215 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___215 {
	struct inode___215 * (*alloc_inode)(struct super_block___215 *);
	void (*destroy_inode)(struct inode___215 *);
	void (*free_inode)(struct inode___215 *);
	void (*dirty_inode)(struct inode___215 *, int);
	int (*write_inode)(struct inode___215 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___215 *);
	void (*evict_inode)(struct inode___215 *);
	void (*put_super)(struct super_block___215 *);
	int (*sync_fs)(struct super_block___215 *, int);
	int (*freeze_super)(struct super_block___215 *);
	int (*freeze_fs)(struct super_block___215 *);
	int (*thaw_super)(struct super_block___215 *);
	int (*unfreeze_fs)(struct super_block___215 *);
	int (*statfs)(struct dentry___215 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___215 *, int *, char *);
	void (*umount_begin)(struct super_block___215 *);
	int (*show_options)(struct seq_file___190 *, struct dentry___215 *);
	int (*show_devname)(struct seq_file___190 *, struct dentry___215 *);
	int (*show_path)(struct seq_file___190 *, struct dentry___215 *);
	int (*show_stats)(struct seq_file___190 *, struct dentry___215 *);
	ssize_t (*quota_read)(struct super_block___215 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___215 *, int, const char *, size_t, loff_t);
	struct dquot___215 ** (*get_dquots)(struct inode___215 *);
	long int (*nr_cached_objects)(struct super_block___215 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___215 *, struct shrink_control___93 *);
	struct file___215 * (*real_loop)(struct file___215 *);
};

struct wakeup_source___193;

struct dev_pm_info___193 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___193 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___193 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___193;

struct bus_type___193;

struct device_driver___193;

struct dev_pm_domain___193;

struct fwnode_handle___189;

struct class___193;

struct attribute_group___203;

struct device___193 {
	struct kobject___203 kobj;
	struct device___193 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___193 *type;
	struct bus_type___193 *bus;
	struct device_driver___193 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___193 power;
	struct dev_pm_domain___193 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___189 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___193 *class;
	const struct attribute_group___203 **groups;
	void (*release)(struct device___193 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___114 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___215 *bd_inode;
	struct super_block___215 *bd_super;
	void *bd_claiming;
	struct device___193 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___203 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___114 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___215 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___190;

struct seq_file___190 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___190 *op;
	int poll_event;
	const struct file___215 *file;
	void *private;
};

typedef void bio_end_io_t___111(struct bio___111 *);

struct bio_vec___132 {
	struct page___220 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___111;

struct bio___111 {
	struct bio___111 *bi_next;
	struct block_device___114 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___111 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___111 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___132 *bi_io_vec;
	struct bio_set___111 *bi_pool;
	struct bio_vec___132 bi_inline_vecs[0];
};

struct kernfs_root___203;

struct kernfs_elem_dir___203 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___203 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___203;

struct kernfs_root___203 {
	struct kernfs_node___203 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___203 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___203 {
	struct kernfs_node___203 *target_kn;
};

struct kernfs_ops___203;

struct kernfs_elem_attr___203 {
	const struct kernfs_ops___203 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___203 *notify_next;
};

struct kernfs_node___203 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___203 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___203 dir;
		struct kernfs_elem_symlink___203 symlink;
		struct kernfs_elem_attr___203 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___203;

struct kernfs_ops___203 {
	int (*open)(struct kernfs_open_file___203 *);
	void (*release)(struct kernfs_open_file___203 *);
	int (*seq_show)(struct seq_file___190 *, void *);
	void * (*seq_start)(struct seq_file___190 *, loff_t *);
	void * (*seq_next)(struct seq_file___190 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___190 *, void *);
	ssize_t (*read)(struct kernfs_open_file___203 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___203 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___203 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___203 *, struct vm_area_struct___220 *);
};

struct kernfs_syscall_ops___203 {
	int (*show_options)(struct seq_file___190 *, struct kernfs_root___203 *);
	int (*mkdir)(struct kernfs_node___203 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___203 *);
	int (*rename)(struct kernfs_node___203 *, struct kernfs_node___203 *, const char *);
	int (*show_path)(struct seq_file___190 *, struct kernfs_node___203 *, struct kernfs_root___203 *);
};

struct kernfs_open_file___203 {
	struct kernfs_node___203 *kn;
	struct file___215 *file;
	struct seq_file___190 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___210 *vm_ops;
};

struct bin_attribute___203;

struct attribute_group___203 {
	const char *name;
	umode_t (*is_visible)(struct kobject___203 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___203 *, struct bin_attribute___203 *, int);
	struct attribute **attrs;
	struct bin_attribute___203 **bin_attrs;
};

struct bin_attribute___203 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___215 * (*f_mapping)();
	ssize_t (*read)(struct file___215 *, struct kobject___203 *, struct bin_attribute___203 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___215 *, struct kobject___203 *, struct bin_attribute___203 *, char *, loff_t, size_t);
	int (*mmap)(struct file___215 *, struct kobject___203 *, struct bin_attribute___203 *, struct vm_area_struct___220 *);
};

struct sysfs_ops___203 {
	ssize_t (*show)(struct kobject___203 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___203 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___203;

struct kset___203 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___203 kobj;
	const struct kset_uevent_ops___203 *uevent_ops;
};

struct kobj_type___203 {
	void (*release)(struct kobject___203 *);
	const struct sysfs_ops___203 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___203 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___203 *);
	const void * (*namespace)(struct kobject___203 *);
	void (*get_ownership)(struct kobject___203 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___203 {
	int (* const filter)(struct kset___203 *, struct kobject___203 *);
	const char * (* const name)(struct kset___203 *, struct kobject___203 *);
	int (* const uevent)(struct kset___203 *, struct kobject___203 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___199 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___199 *);
	int (*get)(char *, const struct kernel_param___199 *);
	void (*free)(void *);
};

struct kparam_array___199;

struct kernel_param___199 {
	const char *name;
	struct module___199 *mod;
	const struct kernel_param_ops___199 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___199 *arr;
	};
};

struct kparam_array___199 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___199 *ops;
	void *elem;
};

struct module_attribute___199 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___199 *, struct module_kobject___200 *, char *);
	ssize_t (*store)(struct module_attribute___199 *, struct module_kobject___200 *, const char *, size_t);
	void (*setup)(struct module___199 *, const char *);
	int (*test)(struct module___199 *);
	void (*free)(struct module___199 *);
};

struct dev_pagemap_ops___210 {
	void (*page_free)(struct page___220 *);
	void (*kill)(struct dev_pagemap___210 *);
	void (*cleanup)(struct dev_pagemap___210 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___210 *);
};

struct fwnode_operations___189;

struct fwnode_handle___189 {
	struct fwnode_handle___189 *secondary;
	const struct fwnode_operations___189 *ops;
	struct device___193 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___189;

struct fwnode_endpoint___189;

struct fwnode_operations___189 {
	struct fwnode_handle___189 * (*get)(struct fwnode_handle___189 *);
	void (*put)(struct fwnode_handle___189 *);
	bool (*device_is_available)(const struct fwnode_handle___189 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___189 *, const struct device___193 *);
	bool (*property_present)(const struct fwnode_handle___189 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___189 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___189 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___189 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*get_parent)(const struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*get_next_child_node)(const struct fwnode_handle___189 *, struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*get_named_child_node)(const struct fwnode_handle___189 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___189 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___189 *);
	struct fwnode_handle___189 * (*graph_get_next_endpoint)(const struct fwnode_handle___189 *, struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*graph_get_remote_endpoint)(const struct fwnode_handle___189 *);
	struct fwnode_handle___189 * (*graph_get_port_parent)(struct fwnode_handle___189 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___189 *, struct fwnode_endpoint___189 *);
	int (*add_links)(struct fwnode_handle___189 *);
};

struct fwnode_endpoint___189 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___189 *local_fwnode;
};

struct fwnode_reference_args___189 {
	struct fwnode_handle___189 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___193 {
	int (*prepare)(struct device___193 *);
	void (*complete)(struct device___193 *);
	int (*suspend)(struct device___193 *);
	int (*resume)(struct device___193 *);
	int (*freeze)(struct device___193 *);
	int (*thaw)(struct device___193 *);
	int (*poweroff)(struct device___193 *);
	int (*restore)(struct device___193 *);
	int (*suspend_late)(struct device___193 *);
	int (*resume_early)(struct device___193 *);
	int (*freeze_late)(struct device___193 *);
	int (*thaw_early)(struct device___193 *);
	int (*poweroff_late)(struct device___193 *);
	int (*restore_early)(struct device___193 *);
	int (*suspend_noirq)(struct device___193 *);
	int (*resume_noirq)(struct device___193 *);
	int (*freeze_noirq)(struct device___193 *);
	int (*thaw_noirq)(struct device___193 *);
	int (*poweroff_noirq)(struct device___193 *);
	int (*restore_noirq)(struct device___193 *);
	int (*runtime_suspend)(struct device___193 *);
	int (*runtime_resume)(struct device___193 *);
	int (*runtime_idle)(struct device___193 *);
};

struct wakeup_source___193 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___193 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___193 {
	struct dev_pm_ops___193 ops;
	int (*start)(struct device___193 *);
	void (*detach)(struct device___193 *, bool);
	int (*activate)(struct device___193 *);
	void (*sync)(struct device___193 *);
	void (*dismiss)(struct device___193 *);
};

struct bus_type___193 {
	const char *name;
	const char *dev_name;
	struct device___193 *dev_root;
	const struct attribute_group___203 **bus_groups;
	const struct attribute_group___203 **dev_groups;
	const struct attribute_group___203 **drv_groups;
	int (*match)(struct device___193 *, struct device_driver___193 *);
	int (*uevent)(struct device___193 *, struct kobj_uevent_env *);
	int (*probe)(struct device___193 *);
	void (*sync_state)(struct device___193 *);
	void (*remove)(struct device___193 *);
	void (*shutdown)(struct device___193 *);
	int (*online)(struct device___193 *);
	int (*offline)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	int (*num_vf)(struct device___193 *);
	int (*dma_configure)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___193 {
	const char *name;
	struct bus_type___193 *bus;
	struct module___199 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___193 *);
	void (*sync_state)(struct device___193 *);
	int (*remove)(struct device___193 *);
	void (*shutdown)(struct device___193 *);
	int (*suspend)(struct device___193 *, pm_message_t);
	int (*resume)(struct device___193 *);
	const struct attribute_group___203 **groups;
	const struct attribute_group___203 **dev_groups;
	const struct dev_pm_ops___193 *pm;
	void (*coredump)(struct device___193 *);
	struct driver_private *p;
};

struct device_type___193 {
	const char *name;
	const struct attribute_group___203 **groups;
	int (*uevent)(struct device___193 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___193 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___193 *);
	const struct dev_pm_ops___193 *pm;
};

struct class___193 {
	const char *name;
	struct module___199 *owner;
	const struct attribute_group___203 **class_groups;
	const struct attribute_group___203 **dev_groups;
	struct kobject___203 *dev_kobj;
	int (*dev_uevent)(struct device___193 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___193 *, umode_t *);
	void (*class_release)(struct class___193 *);
	void (*dev_release)(struct device___193 *);
	int (*shutdown_pre)(struct device___193 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___193 *);
	void (*get_ownership)(struct device___193 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___193 *pm;
	struct subsys_private *p;
};

struct device_attribute___28 {
	struct attribute attr;
	ssize_t (*show)(struct device___193 *, struct device_attribute___28 *, char *);
	ssize_t (*store)(struct device___193 *, struct device_attribute___28 *, const char *, size_t);
};

struct block_device_operations___111;

struct gendisk___114 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___114 *part0;
	const struct block_device_operations___111 *fops;
	struct request_queue___111 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___203 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___203 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___111 {
	struct bio___111 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___132 *bip_vec;
	struct bio_vec___132 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___111(struct request___111 *);

typedef void integrity_complete_fn___111(struct request___111 *, unsigned int);

struct blk_integrity_profile___111 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___111 *prepare_fn;
	integrity_complete_fn___111 *complete_fn;
	const char *name;
};

struct pr_ops___2;

struct block_device_operations___111 {
	blk_qc_t (*submit_bio)(struct bio___111 *);
	int (*open)(struct block_device___114 *, fmode_t);
	void (*release)(struct gendisk___114 *, fmode_t);
	int (*rw_page)(struct block_device___114 *, sector_t, struct page___220 *, unsigned int);
	int (*ioctl)(struct block_device___114 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___114 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___114 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___114 *);
	int (*getgeo)(struct block_device___114 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___114 *, bool);
	void (*swap_slot_free_notify)(struct block_device___114 *, long unsigned int);
	int (*report_zones)(struct gendisk___114 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___114 *, umode_t *);
	struct module___199 *owner;
	const struct pr_ops___2 *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___114 *, sector_t *);
};

typedef void rq_end_io_fn___111(struct request___111 *, blk_status_t);

struct request___111 {
	struct request_queue___111 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___108 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___111 *bio;
	struct bio___111 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___132 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___111 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___111 *saved_end_io;
		} flush;
	};
	struct gendisk___114 *rq_disk;
	struct block_device___114 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___111 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___108 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___111 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___203 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___215 *debugfs_dir;
	struct dentry___215 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___111;

struct elevator_mq_ops___111 {
	int (*init_sched)(struct request_queue___111 *, struct elevator_type___111 *);
	void (*exit_sched)(struct elevator_queue___111 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___108 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___108 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___108 *);
	bool (*allow_merge)(struct request_queue___111 *, struct request___111 *, struct bio___111 *);
	bool (*bio_merge)(struct request_queue___111 *, struct bio___111 *, unsigned int);
	int (*request_merge)(struct request_queue___111 *, struct request___111 **, struct bio___111 *);
	void (*request_merged)(struct request_queue___111 *, struct request___111 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___111 *, struct request___111 *, struct request___111 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___111 *);
	void (*finish_request)(struct request___111 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___108 *, struct list_head *, bool);
	struct request___111 * (*dispatch_request)(struct blk_mq_hw_ctx___108 *);
	bool (*has_work)(struct blk_mq_hw_ctx___108 *);
	void (*completed_request)(struct request___111 *, u64);
	void (*requeue_request)(struct request___111 *);
	struct request___111 * (*former_request)(struct request_queue___111 *, struct request___111 *);
	struct request___111 * (*next_request)(struct request_queue___111 *, struct request___111 *);
	void (*init_icq)(struct io_cq___111 *);
	void (*exit_icq)(struct io_cq___111 *);
};

struct elv_fs_entry___111;

struct elevator_type___111 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___111 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___111 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___199 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___111 {
	struct elevator_type___111 *type;
	void *elevator_data;
	struct kobject___203 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___111 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___111 *, char *);
	ssize_t (*store)(struct elevator_queue___111 *, const char *, size_t);
};

struct blk_mq_queue_data___108;

struct blk_mq_ops___108 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___108 *, const struct blk_mq_queue_data___108 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___108 *);
	int (*get_budget)(struct request_queue___111 *);
	void (*put_budget)(struct request_queue___111 *, int);
	void (*set_rq_budget_token)(struct request___111 *, int);
	int (*get_rq_budget_token)(struct request___111 *);
	enum blk_eh_timer_return (*timeout)(struct request___111 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___108 *);
	void (*complete)(struct request___111 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___108 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___108 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___108 *, struct request___111 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___108 *, struct request___111 *, unsigned int);
	void (*initialize_rq_fn)(struct request___111 *);
	void (*cleanup_rq)(struct request___111 *);
	bool (*busy)(struct request_queue___111 *);
	int (*map_queues)(struct blk_mq_tag_set___108 *);
	void (*show_rq)(struct seq_file___190 *, struct request___111 *);
};

struct blk_mq_tag_set___108 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___108 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct pr_ops___2 {
	int (*pr_register)(struct block_device___114 *, u64, u64, u32);
	int (*pr_reserve)(struct block_device___114 *, u64, enum pr_type, u32);
	int (*pr_release)(struct block_device___114 *, u64, enum pr_type);
	int (*pr_preempt)(struct block_device___114 *, u64, u64, enum pr_type, bool);
	int (*pr_clear)(struct block_device___114 *, u64);
};

struct Scsi_Host___4;

struct scsi_target___4;

struct scsi_device___4 {
	struct Scsi_Host___4 *host;
	struct request_queue___111 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___4 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___193 sdev_gendev;
	struct device___193 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___222 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___4;

struct Scsi_Host___4 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___222 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___4 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___108 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___193 shost_gendev;
	struct device___193 shost_dev;
	void *shost_data;
	struct device___193 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_target___4 {
	struct scsi_device___4 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___193 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct seq_operations___190 {
	void * (*start)(struct seq_file___190 *, loff_t *);
	void (*stop)(struct seq_file___190 *, void *);
	void * (*next)(struct seq_file___190 *, void *, loff_t *);
	int (*show)(struct seq_file___190 *, void *);
};

struct blk_mq_queue_data___108 {
	struct request___111 *rq;
	bool last;
};

struct scsi_cmnd___4;

struct scsi_host_template___4 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___4 *, struct scsi_cmnd___4 *);
	void (*commit_rqs)(struct Scsi_Host___4 *, u16);
	struct module___199 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___4 *);
	int (*ioctl)(struct scsi_device___4 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___4 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___4 *, struct scsi_cmnd___4 *);
	int (*exit_cmd_priv)(struct Scsi_Host___4 *, struct scsi_cmnd___4 *);
	int (*eh_abort_handler)(struct scsi_cmnd___4 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___4 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___4 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___4 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___4 *);
	int (*slave_alloc)(struct scsi_device___4 *);
	int (*slave_configure)(struct scsi_device___4 *);
	void (*slave_destroy)(struct scsi_device___4 *);
	int (*target_alloc)(struct scsi_target___4 *);
	void (*target_destroy)(struct scsi_target___4 *);
	int (*scan_finished)(struct Scsi_Host___4 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___4 *);
	int (*change_queue_depth)(struct scsi_device___4 *, int);
	int (*map_queues)(struct Scsi_Host___4 *);
	int (*mq_poll)(struct Scsi_Host___4 *, unsigned int);
	bool (*dma_need_drain)(struct request___111 *);
	int (*bios_param)(struct scsi_device___4 *, struct block_device___114 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___4 *);
	int (*show_info)(struct seq_file___190 *, struct Scsi_Host___4 *);
	int (*write_info)(struct Scsi_Host___4 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___4 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___4 *);
	int (*host_reset)(struct Scsi_Host___4 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___28 **shost_attrs;
	struct device_attribute___28 **sdev_attrs;
	const struct attribute_group___203 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_cmnd___4 {
	struct scsi_request req;
	struct scsi_device___4 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___4 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

enum scsi_prot_flags {
	SCSI_PROT_TRANSFER_PI = 1,
	SCSI_PROT_GUARD_CHECK = 2,
	SCSI_PROT_REF_CHECK = 4,
	SCSI_PROT_REF_INCREMENT = 8,
	SCSI_PROT_IP_CHECKSUM = 16,
};

struct scsi_driver___3 {
	struct device_driver___193 gendrv;
	void (*rescan)(struct device___193 *);
	blk_status_t (*init_command)(struct scsi_cmnd___4 *);
	void (*uninit_command)(struct scsi_cmnd___4 *);
	int (*done)(struct scsi_cmnd___4 *);
	int (*eh_action)(struct scsi_cmnd___4 *, int);
	void (*eh_reset)(struct scsi_cmnd___4 *);
};

enum {
	SD_EXT_CDB_SIZE = 32,
	SD_MEMPOOL_SIZE = 2,
};

enum {
	SD_DEF_XFER_BLOCKS = 65535,
	SD_MAX_XFER_BLOCKS = 4294967295,
	SD_MAX_WS10_BLOCKS = 65535,
	SD_MAX_WS16_BLOCKS = 8388607,
};

enum {
	SD_LBP_FULL = 0,
	SD_LBP_UNMAP = 1,
	SD_LBP_WS16 = 2,
	SD_LBP_WS10 = 3,
	SD_LBP_ZERO = 4,
	SD_LBP_DISABLE = 5,
};

enum {
	SD_ZERO_WRITE = 0,
	SD_ZERO_WS = 1,
	SD_ZERO_WS16_UNMAP = 2,
	SD_ZERO_WS10_UNMAP = 3,
};

struct opal_dev___2;

struct scsi_disk {
	struct scsi_driver___3 *driver;
	struct scsi_device___4 *device;
	struct device___193 dev;
	struct gendisk___114 *disk;
	struct opal_dev___2 *opal_dev;
	u32 nr_zones;
	u32 rev_nr_zones;
	u32 zone_blocks;
	u32 rev_zone_blocks;
	u32 zones_optimal_open;
	u32 zones_optimal_nonseq;
	u32 zones_max_open;
	u32 *zones_wp_offset;
	spinlock_t zones_wp_offset_lock;
	u32 *rev_wp_offset;
	struct mutex rev_mutex;
	struct work_struct zone_wp_offset_work;
	char *zone_wp_update_buf;
	atomic_t openers;
	sector_t capacity;
	int max_retries;
	u32 max_xfer_blocks;
	u32 opt_xfer_blocks;
	u32 max_ws_blocks;
	u32 max_unmap_blocks;
	u32 unmap_granularity;
	u32 unmap_alignment;
	u32 index;
	unsigned int physical_block_size;
	unsigned int max_medium_access_timeouts;
	unsigned int medium_access_timed_out;
	u8 media_present;
	u8 write_prot;
	u8 protection_type;
	u8 provisioning_mode;
	u8 zeroing_mode;
	unsigned int ATO;
	unsigned int cache_override: 1;
	unsigned int WCE;
	unsigned int RCD;
	unsigned int DPOFUA: 1;
	unsigned int first_scan: 1;
	unsigned int lbpme: 1;
	unsigned int lbprz: 1;
	unsigned int lbpu: 1;
	unsigned int lbpws: 1;
	unsigned int lbpws10: 1;
	unsigned int lbpvpd: 1;
	unsigned int ws10: 1;
	unsigned int ws16: 1;
	unsigned int rc_basis: 2;
	unsigned int zoned: 2;
	unsigned int urswrz: 1;
	unsigned int security: 1;
	unsigned int ignore_medium_access_errors: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum scsi_host_guard_type {
	SHOST_DIX_GUARD_CRC = 1,
	SHOST_DIX_GUARD_IP = 2,
};

enum zbc_zone_type {
	ZBC_ZONE_TYPE_CONV = 1,
	ZBC_ZONE_TYPE_SEQWRITE_REQ = 2,
	ZBC_ZONE_TYPE_SEQWRITE_PREF = 3,
};

enum zbc_zone_cond {
	ZBC_ZONE_COND_NO_WP = 0,
	ZBC_ZONE_COND_EMPTY = 1,
	ZBC_ZONE_COND_IMP_OPEN = 2,
	ZBC_ZONE_COND_EXP_OPEN = 3,
	ZBC_ZONE_COND_CLOSED = 4,
	ZBC_ZONE_COND_READONLY = 13,
	ZBC_ZONE_COND_FULL = 14,
	ZBC_ZONE_COND_OFFLINE = 15,
};

enum {
	mechtype_caddy = 0,
	mechtype_tray = 1,
	mechtype_popup = 2,
	mechtype_individual_changer = 4,
	mechtype_cartridge_changer = 5,
};

struct event_header {
	__be16 data_len;
	__u8 notification_class: 3;
	__u8 reserved1: 4;
	__u8 nea: 1;
	int: 23;
	__u8 supp_event_class;
};

struct media_event_desc {
	__u8 media_event_code: 4;
	__u8 reserved1: 4;
	__u8 door_open: 1;
	__u8 media_present: 1;
	__u8 reserved2: 6;
	short: 10;
	__u8 start_slot;
	__u8 end_slot;
};

struct Scsi_Host___5;

struct scsi_target___5;

struct scsi_device___5 {
	struct Scsi_Host___5 *host;
	struct request_queue___110 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___5 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___192 sdev_gendev;
	struct device___192 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___221 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___5;

struct Scsi_Host___5 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___221 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___5 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___107 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___192 shost_gendev;
	struct device___192 shost_dev;
	void *shost_data;
	struct device___192 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_target___5 {
	struct scsi_device___5 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___192 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct scsi_cmnd___5;

struct scsi_driver___4 {
	struct device_driver___192 gendrv;
	void (*rescan)(struct device___192 *);
	blk_status_t (*init_command)(struct scsi_cmnd___5 *);
	void (*uninit_command)(struct scsi_cmnd___5 *);
	int (*done)(struct scsi_cmnd___5 *);
	int (*eh_action)(struct scsi_cmnd___5 *, int);
	void (*eh_reset)(struct scsi_cmnd___5 *);
};

struct scsi_cmnd___5 {
	struct scsi_request req;
	struct scsi_device___5 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___5 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

struct scsi_host_template___5 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___5 *, struct scsi_cmnd___5 *);
	void (*commit_rqs)(struct Scsi_Host___5 *, u16);
	struct module___198 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___5 *);
	int (*ioctl)(struct scsi_device___5 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___5 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___5 *, struct scsi_cmnd___5 *);
	int (*exit_cmd_priv)(struct Scsi_Host___5 *, struct scsi_cmnd___5 *);
	int (*eh_abort_handler)(struct scsi_cmnd___5 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___5 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___5 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___5 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___5 *);
	int (*slave_alloc)(struct scsi_device___5 *);
	int (*slave_configure)(struct scsi_device___5 *);
	void (*slave_destroy)(struct scsi_device___5 *);
	int (*target_alloc)(struct scsi_target___5 *);
	void (*target_destroy)(struct scsi_target___5 *);
	int (*scan_finished)(struct Scsi_Host___5 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___5 *);
	int (*change_queue_depth)(struct scsi_device___5 *, int);
	int (*map_queues)(struct Scsi_Host___5 *);
	int (*mq_poll)(struct Scsi_Host___5 *, unsigned int);
	bool (*dma_need_drain)(struct request___110 *);
	int (*bios_param)(struct scsi_device___5 *, struct block_device___113 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___5 *);
	int (*show_info)(struct seq_file___189 *, struct Scsi_Host___5 *);
	int (*write_info)(struct Scsi_Host___5 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___5 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___5 *);
	int (*host_reset)(struct Scsi_Host___5 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___27 **shost_attrs;
	struct device_attribute___27 **sdev_attrs;
	const struct attribute_group___202 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_cd {
	struct scsi_driver___4 *driver;
	unsigned int capacity;
	struct scsi_device___5 *device;
	unsigned int vendor;
	long unsigned int ms_offset;
	unsigned int writeable: 1;
	unsigned int use;
	unsigned int xa_flag: 1;
	unsigned int readcd_known: 1;
	unsigned int readcd_cdda: 1;
	unsigned int media_present: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int tur_mismatch;
	bool tur_changed: 1;
	bool get_event_changed: 1;
	bool ignore_get_event: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct cdrom_device_info___2 cdi;
	struct mutex lock;
	struct kref kref;
	struct gendisk___113 *disk;
};

typedef struct scsi_cd Scsi_CD;

struct cdrom_ti {
	__u8 cdti_trk0;
	__u8 cdti_ind0;
	__u8 cdti_trk1;
	__u8 cdti_ind1;
};

struct cdrom_tochdr {
	__u8 cdth_trk0;
	__u8 cdth_trk1;
};

struct cdrom_tocentry {
	__u8 cdte_track;
	__u8 cdte_adr: 4;
	__u8 cdte_ctrl: 4;
	short: 12;
	__u8 cdte_format;
	union cdrom_addr cdte_addr;
	__u8 cdte_datamode;
};

struct ccs_modesel_head {
	__u8 _r1;
	__u8 medium;
	__u8 _r2;
	__u8 block_desc_length;
	__u8 density;
	__u8 number_blocks_hi;
	__u8 number_blocks_med;
	__u8 number_blocks_lo;
	__u8 _r3;
	__u8 block_length_hi;
	__u8 block_length_med;
	__u8 block_length_lo;
};

struct dentry___216;

struct super_block___216;

struct module___200;

struct file_system_type___216 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___216 * (*mount)(struct file_system_type___216 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___216 *);
	struct module___200 *owner;
	struct file_system_type___216 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___216;

struct kiocb___216;

struct iov_iter___136;

struct poll_table_struct___141;

struct vm_area_struct___221;

struct inode___216;

struct file_lock___216;

struct page___221;

struct seq_file___191;

struct file_operations___217 {
	struct module___200 *owner;
	loff_t (*llseek)(struct file___216 *, loff_t, int);
	ssize_t (*read)(struct file___216 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___216 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___216 *, struct iov_iter___136 *);
	ssize_t (*write_iter)(struct kiocb___216 *, struct iov_iter___136 *);
	int (*iopoll)(struct kiocb___216 *, bool);
	int (*iterate)(struct file___216 *, struct dir_context *);
	int (*iterate_shared)(struct file___216 *, struct dir_context *);
	__poll_t (*poll)(struct file___216 *, struct poll_table_struct___141 *);
	long int (*unlocked_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___216 *, struct vm_area_struct___221 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___216 *, struct file___216 *);
	int (*flush)(struct file___216 *, fl_owner_t);
	int (*release)(struct inode___216 *, struct file___216 *);
	int (*fsync)(struct file___216 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___216 *, int);
	int (*lock)(struct file___216 *, int, struct file_lock___216 *);
	ssize_t (*sendpage)(struct file___216 *, struct page___221 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___216 *, long unsigned int);
	int (*flock)(struct file___216 *, int, struct file_lock___216 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___216 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___216 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___216 *, long int, struct file_lock___216 **, void **);
	long int (*fallocate)(struct file___216 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___191 *, struct file___216 *);
	ssize_t (*copy_file_range)(struct file___216 *, loff_t, struct file___216 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___216 *, loff_t, struct file___216 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___216 *, loff_t, loff_t, int);
};

struct vmacache___221 {
	u64 seqnum;
	struct vm_area_struct___221 *vmas[4];
};

struct page_frag___221 {
	struct page___221 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___222;

struct pid___193;

struct nsproxy___202;

struct signal_struct___217;

struct bio_list___112;

struct io_context___112;

struct request_queue___112;

struct vm_struct___199;

struct task_struct___223 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___223 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___222 *mm;
	struct mm_struct___222 *active_mm;
	struct vmacache___221 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___223 *real_parent;
	struct task_struct___223 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___223 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___193 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___202 *nsproxy;
	struct signal_struct___217 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___223 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___112 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___112 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___221 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___112 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___223 *oom_reaper_list;
	struct vm_struct___199 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___61 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___204;

struct kobj_type___204;

struct kernfs_node___204;

struct kobject___204 {
	const char *name;
	struct list_head entry;
	struct kobject___204 *parent;
	struct kset___204 *kset;
	struct kobj_type___204 *ktype;
	struct kernfs_node___204 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___201 {
	struct kobject___204 kobj;
	struct module___200 *mod;
	struct kobject___204 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___200 {
	struct module___200 *mod;
	struct latch_tree_node node;
};

struct module_layout___200 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___200 mtn;
};

struct module_attribute___200;

struct kernel_param___200;

struct module___200 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___201 mkobj;
	struct module_attribute___200 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___204 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___200 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___200 core_layout;
	struct module_layout___200 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___193;

struct upid___193 {
	int nr;
	struct pid_namespace___193 *ns;
};

struct pid_namespace___193 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___223 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___193 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___193 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___193 numbers[1];
};

typedef struct page___221 *pgtable_t___221;

struct address_space___216;

struct dev_pagemap___211;

struct page___221 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___216 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___221 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___221 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___222 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___211 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___211;

struct vm_area_struct___221 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___221 *vm_next;
	struct vm_area_struct___221 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___222 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___211 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___216 *vm_file;
	struct file___216 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___217 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___223 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___223 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___193 *pids[4];
	struct pid___193 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___222 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___221;

struct mm_struct___222 {
	struct {
		struct vm_area_struct___221 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___221 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___223 *owner;
		struct user_namespace *user_ns;
		struct file___216 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___202 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___193 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___112;

struct bio_list___112 {
	struct bio___112 *head;
	struct bio___112 *tail;
};

struct io_cq___112;

struct io_context___112 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___112 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___112;

struct blk_integrity___112 {
	const struct blk_integrity_profile___112 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___112 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___112 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___112;

struct elevator_queue___112;

struct blk_mq_ops___109;

struct blk_mq_hw_ctx___109;

struct gendisk___115;

struct device___194;

struct blk_trace___5;

struct blk_mq_tag_set___109;

struct request_queue___112 {
	struct request___112 *last_merge;
	struct elevator_queue___112 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___109 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___109 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___115 *disk;
	struct kobject___204 kobj;
	struct kobject___204 *mq_kobj;
	struct blk_integrity___112 integrity;
	struct device___194 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___5 *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___109 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___112 bio_split;
	struct dentry___216 *debugfs_dir;
	struct dentry___216 *sched_debugfs_dir;
	struct dentry___216 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___199 {
	struct vm_struct___199 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___221 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___216;

struct address_space___216 {
	struct inode___216 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___216 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___211;

struct dev_pagemap___211 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___211 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___216;

struct path___216 {
	struct vfsmount___216 *mnt;
	struct dentry___216 *dentry;
};

struct fown_struct___193 {
	rwlock_t lock;
	struct pid___193 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___216 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___216 f_path;
	struct inode___216 *f_inode;
	const struct file_operations___217 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___193 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___216 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___211;

struct vm_operations_struct___211 {
	void (*open)(struct vm_area_struct___221 *);
	void (*close)(struct vm_area_struct___221 *);
	int (*may_split)(struct vm_area_struct___221 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___221 *);
	int (*mprotect)(struct vm_area_struct___221 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___211 *);
	vm_fault_t (*huge_fault)(struct vm_fault___211 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___211 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___221 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___211 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___211 *);
	int (*access)(struct vm_area_struct___221 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___221 *);
	int (*set_policy)(struct vm_area_struct___221 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___221 *, long unsigned int);
	struct page___221 * (*find_special_page)(struct vm_area_struct___221 *, long unsigned int);
};

struct core_thread___221 {
	struct task_struct___223 *task;
	struct core_thread___221 *next;
};

struct core_state___221 {
	atomic_t nr_threads;
	struct core_thread___221 dumper;
	struct completion startup;
};

struct vm_fault___211 {
	const struct {
		struct vm_area_struct___221 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___221 *cow_page;
	struct page___221 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___221 prealloc_pte;
};

struct dentry_operations___216;

struct dentry___216 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___216 *d_parent;
	struct qstr d_name;
	struct inode___216 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___216 *d_op;
	struct super_block___216 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___216;

struct cdev___54;

struct inode___216 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___216 *i_op;
	struct super_block___216 *i_sb;
	struct address_space___216 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___217 *i_fop;
		void (*free_inode)(struct inode___216 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___216 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___54 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___216 {
	int (*d_revalidate)(struct dentry___216 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___216 *, unsigned int);
	int (*d_hash)(const struct dentry___216 *, struct qstr *);
	int (*d_compare)(const struct dentry___216 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___216 *);
	int (*d_init)(struct dentry___216 *);
	void (*d_release)(struct dentry___216 *);
	void (*d_prune)(struct dentry___216 *);
	void (*d_iput)(struct dentry___216 *, struct inode___216 *);
	char * (*d_dname)(struct dentry___216 *, char *, int);
	struct vfsmount___216 * (*d_automount)(struct path___216 *);
	int (*d_manage)(const struct path___216 *, bool);
	struct dentry___216 * (*d_real)(struct dentry___216 *, const struct inode___216 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___216;

struct mem_dqinfo___216 {
	struct quota_format_type___216 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___216;

struct quota_info___216 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___216 *files[3];
	struct mem_dqinfo___216 info[3];
	const struct quota_format_ops___216 *ops[3];
};

struct rcuwait___217 {
	struct task_struct___223 *task;
};

struct percpu_rw_semaphore___217 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___217 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___216 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___217 rw_sem[3];
};

struct super_operations___216;

struct dquot_operations___216;

struct quotactl_ops___216;

struct block_device___115;

struct super_block___216 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___216 *s_type;
	const struct super_operations___216 *s_op;
	const struct dquot_operations___216 *dq_op;
	const struct quotactl_ops___216 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___216 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___115 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___216 s_dquot;
	struct sb_writers___216 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___216 *s_d_op;
	int cleancache_poolid;
	struct shrinker___93 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___216 {
	struct dentry___216 *mnt_root;
	struct super_block___216 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___112 {
	struct request_queue___112 *q;
	struct io_context___112 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___216 {
	struct file___216 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___216 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___103 *ki_waitq;
	};
};

struct iattr___216 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___216 *ia_file;
};

struct dquot___216 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___216 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___216 {
	int qf_fmt_id;
	const struct quota_format_ops___216 *qf_ops;
	struct module___200 *qf_owner;
	struct quota_format_type___216 *qf_next;
};

struct quota_format_ops___216 {
	int (*check_quota_file)(struct super_block___216 *, int);
	int (*read_file_info)(struct super_block___216 *, int);
	int (*write_file_info)(struct super_block___216 *, int);
	int (*free_file_info)(struct super_block___216 *, int);
	int (*read_dqblk)(struct dquot___216 *);
	int (*commit_dqblk)(struct dquot___216 *);
	int (*release_dqblk)(struct dquot___216 *);
	int (*get_next_id)(struct super_block___216 *, struct kqid *);
};

struct dquot_operations___216 {
	int (*write_dquot)(struct dquot___216 *);
	struct dquot___216 * (*alloc_dquot)(struct super_block___216 *, int);
	void (*destroy_dquot)(struct dquot___216 *);
	int (*acquire_dquot)(struct dquot___216 *);
	int (*release_dquot)(struct dquot___216 *);
	int (*mark_dirty)(struct dquot___216 *);
	int (*write_info)(struct super_block___216 *, int);
	qsize_t * (*get_reserved_space)(struct inode___216 *);
	int (*get_projid)(struct inode___216 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___216 *, qsize_t *);
	int (*get_next_id)(struct super_block___216 *, struct kqid *);
};

struct quotactl_ops___216 {
	int (*quota_on)(struct super_block___216 *, int, int, const struct path___216 *);
	int (*quota_off)(struct super_block___216 *, int);
	int (*quota_enable)(struct super_block___216 *, unsigned int);
	int (*quota_disable)(struct super_block___216 *, unsigned int);
	int (*quota_sync)(struct super_block___216 *, int);
	int (*set_info)(struct super_block___216 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___216 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___216 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___216 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___216 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___216 *, unsigned int);
};

struct address_space_operations___216 {
	int (*writepage)(struct page___221 *, struct writeback_control___3 *);
	int (*readpage)(struct file___216 *, struct page___221 *);
	int (*writepages)(struct address_space___216 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___221 *);
	int (*readpages)(struct file___216 *, struct address_space___216 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___216 *, struct address_space___216 *, loff_t, unsigned int, unsigned int, struct page___221 **, void **);
	int (*write_end)(struct file___216 *, struct address_space___216 *, loff_t, unsigned int, unsigned int, struct page___221 *, void *);
	sector_t (*bmap)(struct address_space___216 *, sector_t);
	void (*invalidatepage)(struct page___221 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___221 *, gfp_t);
	void (*freepage)(struct page___221 *);
	ssize_t (*direct_IO)(struct kiocb___216 *, struct iov_iter___136 *);
	int (*migratepage)(struct address_space___216 *, struct page___221 *, struct page___221 *, enum migrate_mode);
	bool (*isolate_page)(struct page___221 *, isolate_mode_t);
	void (*putback_page)(struct page___221 *);
	int (*launder_page)(struct page___221 *);
	int (*is_partially_uptodate)(struct page___221 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___221 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___216 *, struct page___221 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___216 *, sector_t *);
	void (*swap_deactivate)(struct file___216 *);
};

struct bio_vec___133;

struct iov_iter___136 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___133 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___54 {
	struct kobject___204 kobj;
	struct module___200 *owner;
	const struct file_operations___217 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___216 {
	struct dentry___216 * (*lookup)(struct inode___216 *, struct dentry___216 *, unsigned int);
	const char * (*get_link)(struct dentry___216 *, struct inode___216 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___216 *, int);
	struct posix_acl * (*get_acl)(struct inode___216 *, int, bool);
	int (*readlink)(struct dentry___216 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___216 *, struct dentry___216 *, umode_t, bool);
	int (*link)(struct dentry___216 *, struct inode___216 *, struct dentry___216 *);
	int (*unlink)(struct inode___216 *, struct dentry___216 *);
	int (*symlink)(struct user_namespace *, struct inode___216 *, struct dentry___216 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___216 *, struct dentry___216 *, umode_t);
	int (*rmdir)(struct inode___216 *, struct dentry___216 *);
	int (*mknod)(struct user_namespace *, struct inode___216 *, struct dentry___216 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___216 *, struct dentry___216 *, struct inode___216 *, struct dentry___216 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___216 *, struct iattr___216 *);
	int (*getattr)(struct user_namespace *, const struct path___216 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___216 *, char *, size_t);
	int (*fiemap)(struct inode___216 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___216 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___216 *, struct dentry___216 *, struct file___216 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___216 *, struct dentry___216 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___216 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___216 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___216 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___216 {
	void (*fl_copy_lock)(struct file_lock___216 *, struct file_lock___216 *);
	void (*fl_release_private)(struct file_lock___216 *);
};

struct fasync_struct___216;

struct lock_manager_operations___216;

struct file_lock___216 {
	struct file_lock___216 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___216 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___216 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___216 *fl_ops;
	const struct lock_manager_operations___216 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___216 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___216 *);
	int (*lm_grant)(struct file_lock___216 *, int);
	bool (*lm_break)(struct file_lock___216 *);
	int (*lm_change)(struct file_lock___216 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___216 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___216 *);
};

struct fasync_struct___216 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___216 *fa_next;
	struct file___216 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___216 {
	struct inode___216 * (*alloc_inode)(struct super_block___216 *);
	void (*destroy_inode)(struct inode___216 *);
	void (*free_inode)(struct inode___216 *);
	void (*dirty_inode)(struct inode___216 *, int);
	int (*write_inode)(struct inode___216 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___216 *);
	void (*evict_inode)(struct inode___216 *);
	void (*put_super)(struct super_block___216 *);
	int (*sync_fs)(struct super_block___216 *, int);
	int (*freeze_super)(struct super_block___216 *);
	int (*freeze_fs)(struct super_block___216 *);
	int (*thaw_super)(struct super_block___216 *);
	int (*unfreeze_fs)(struct super_block___216 *);
	int (*statfs)(struct dentry___216 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___216 *, int *, char *);
	void (*umount_begin)(struct super_block___216 *);
	int (*show_options)(struct seq_file___191 *, struct dentry___216 *);
	int (*show_devname)(struct seq_file___191 *, struct dentry___216 *);
	int (*show_path)(struct seq_file___191 *, struct dentry___216 *);
	int (*show_stats)(struct seq_file___191 *, struct dentry___216 *);
	ssize_t (*quota_read)(struct super_block___216 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___216 *, int, const char *, size_t, loff_t);
	struct dquot___216 ** (*get_dquots)(struct inode___216 *);
	long int (*nr_cached_objects)(struct super_block___216 *, struct shrink_control___93 *);
	long int (*free_cached_objects)(struct super_block___216 *, struct shrink_control___93 *);
	struct file___216 * (*real_loop)(struct file___216 *);
};

struct wakeup_source___194;

struct dev_pm_info___194 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___194 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___194 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___194;

struct bus_type___194;

struct device_driver___194;

struct dev_pm_domain___194;

struct fwnode_handle___190;

struct class___194;

struct attribute_group___204;

struct device___194 {
	struct kobject___204 kobj;
	struct device___194 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___194 *type;
	struct bus_type___194 *bus;
	struct device_driver___194 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___194 power;
	struct dev_pm_domain___194 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___190 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___194 *class;
	const struct attribute_group___204 **groups;
	void (*release)(struct device___194 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___115 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___216 *bd_inode;
	struct super_block___216 *bd_super;
	void *bd_claiming;
	struct device___194 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___204 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___115 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___216 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___148)(struct file___216 *, wait_queue_head_t *, struct poll_table_struct___141 *);

struct poll_table_struct___141 {
	poll_queue_proc___148 _qproc;
	__poll_t _key;
};

struct seq_operations___191;

struct seq_file___191 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___191 *op;
	int poll_event;
	const struct file___216 *file;
	void *private;
};

typedef void bio_end_io_t___112(struct bio___112 *);

struct bio_vec___133 {
	struct page___221 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___112;

struct bio___112 {
	struct bio___112 *bi_next;
	struct block_device___115 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___112 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___112 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___133 *bi_io_vec;
	struct bio_set___112 *bi_pool;
	struct bio_vec___133 bi_inline_vecs[0];
};

struct kernfs_root___204;

struct kernfs_elem_dir___204 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___204 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___204;

struct kernfs_root___204 {
	struct kernfs_node___204 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___204 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___204 {
	struct kernfs_node___204 *target_kn;
};

struct kernfs_ops___204;

struct kernfs_elem_attr___204 {
	const struct kernfs_ops___204 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___204 *notify_next;
};

struct kernfs_node___204 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___204 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___204 dir;
		struct kernfs_elem_symlink___204 symlink;
		struct kernfs_elem_attr___204 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___204;

struct kernfs_ops___204 {
	int (*open)(struct kernfs_open_file___204 *);
	void (*release)(struct kernfs_open_file___204 *);
	int (*seq_show)(struct seq_file___191 *, void *);
	void * (*seq_start)(struct seq_file___191 *, loff_t *);
	void * (*seq_next)(struct seq_file___191 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___191 *, void *);
	ssize_t (*read)(struct kernfs_open_file___204 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___204 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___204 *, struct poll_table_struct___141 *);
	int (*mmap)(struct kernfs_open_file___204 *, struct vm_area_struct___221 *);
};

struct kernfs_syscall_ops___204 {
	int (*show_options)(struct seq_file___191 *, struct kernfs_root___204 *);
	int (*mkdir)(struct kernfs_node___204 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___204 *);
	int (*rename)(struct kernfs_node___204 *, struct kernfs_node___204 *, const char *);
	int (*show_path)(struct seq_file___191 *, struct kernfs_node___204 *, struct kernfs_root___204 *);
};

struct kernfs_open_file___204 {
	struct kernfs_node___204 *kn;
	struct file___216 *file;
	struct seq_file___191 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___211 *vm_ops;
};

struct bin_attribute___204;

struct attribute_group___204 {
	const char *name;
	umode_t (*is_visible)(struct kobject___204 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___204 *, struct bin_attribute___204 *, int);
	struct attribute **attrs;
	struct bin_attribute___204 **bin_attrs;
};

struct bin_attribute___204 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___216 * (*f_mapping)();
	ssize_t (*read)(struct file___216 *, struct kobject___204 *, struct bin_attribute___204 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___216 *, struct kobject___204 *, struct bin_attribute___204 *, char *, loff_t, size_t);
	int (*mmap)(struct file___216 *, struct kobject___204 *, struct bin_attribute___204 *, struct vm_area_struct___221 *);
};

struct sysfs_ops___204 {
	ssize_t (*show)(struct kobject___204 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___204 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___204;

struct kset___204 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___204 kobj;
	const struct kset_uevent_ops___204 *uevent_ops;
};

struct kobj_type___204 {
	void (*release)(struct kobject___204 *);
	const struct sysfs_ops___204 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___204 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___204 *);
	const void * (*namespace)(struct kobject___204 *);
	void (*get_ownership)(struct kobject___204 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___204 {
	int (* const filter)(struct kset___204 *, struct kobject___204 *);
	const char * (* const name)(struct kset___204 *, struct kobject___204 *);
	int (* const uevent)(struct kset___204 *, struct kobject___204 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___200 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___200 *);
	int (*get)(char *, const struct kernel_param___200 *);
	void (*free)(void *);
};

struct kparam_array___200;

struct kernel_param___200 {
	const char *name;
	struct module___200 *mod;
	const struct kernel_param_ops___200 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___200 *arr;
	};
};

struct kparam_array___200 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___200 *ops;
	void *elem;
};

struct module_attribute___200 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___200 *, struct module_kobject___201 *, char *);
	ssize_t (*store)(struct module_attribute___200 *, struct module_kobject___201 *, const char *, size_t);
	void (*setup)(struct module___200 *, const char *);
	int (*test)(struct module___200 *);
	void (*free)(struct module___200 *);
};

struct module_version_attribute___7 {
	struct module_attribute___200 mattr;
	const char *module_name;
	const char *version;
};

struct dev_pagemap_ops___211 {
	void (*page_free)(struct page___221 *);
	void (*kill)(struct dev_pagemap___211 *);
	void (*cleanup)(struct dev_pagemap___211 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___211 *);
};

typedef struct poll_table_struct___141 poll_table___38;

struct dev_pm_ops___194 {
	int (*prepare)(struct device___194 *);
	void (*complete)(struct device___194 *);
	int (*suspend)(struct device___194 *);
	int (*resume)(struct device___194 *);
	int (*freeze)(struct device___194 *);
	int (*thaw)(struct device___194 *);
	int (*poweroff)(struct device___194 *);
	int (*restore)(struct device___194 *);
	int (*suspend_late)(struct device___194 *);
	int (*resume_early)(struct device___194 *);
	int (*freeze_late)(struct device___194 *);
	int (*thaw_early)(struct device___194 *);
	int (*poweroff_late)(struct device___194 *);
	int (*restore_early)(struct device___194 *);
	int (*suspend_noirq)(struct device___194 *);
	int (*resume_noirq)(struct device___194 *);
	int (*freeze_noirq)(struct device___194 *);
	int (*thaw_noirq)(struct device___194 *);
	int (*poweroff_noirq)(struct device___194 *);
	int (*restore_noirq)(struct device___194 *);
	int (*runtime_suspend)(struct device___194 *);
	int (*runtime_resume)(struct device___194 *);
	int (*runtime_idle)(struct device___194 *);
};

struct wakeup_source___194 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___194 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___194 {
	struct dev_pm_ops___194 ops;
	int (*start)(struct device___194 *);
	void (*detach)(struct device___194 *, bool);
	int (*activate)(struct device___194 *);
	void (*sync)(struct device___194 *);
	void (*dismiss)(struct device___194 *);
};

struct bus_type___194 {
	const char *name;
	const char *dev_name;
	struct device___194 *dev_root;
	const struct attribute_group___204 **bus_groups;
	const struct attribute_group___204 **dev_groups;
	const struct attribute_group___204 **drv_groups;
	int (*match)(struct device___194 *, struct device_driver___194 *);
	int (*uevent)(struct device___194 *, struct kobj_uevent_env *);
	int (*probe)(struct device___194 *);
	void (*sync_state)(struct device___194 *);
	void (*remove)(struct device___194 *);
	void (*shutdown)(struct device___194 *);
	int (*online)(struct device___194 *);
	int (*offline)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	int (*num_vf)(struct device___194 *);
	int (*dma_configure)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___194 {
	const char *name;
	struct bus_type___194 *bus;
	struct module___200 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___194 *);
	void (*sync_state)(struct device___194 *);
	int (*remove)(struct device___194 *);
	void (*shutdown)(struct device___194 *);
	int (*suspend)(struct device___194 *, pm_message_t);
	int (*resume)(struct device___194 *);
	const struct attribute_group___204 **groups;
	const struct attribute_group___204 **dev_groups;
	const struct dev_pm_ops___194 *pm;
	void (*coredump)(struct device___194 *);
	struct driver_private *p;
};

struct device_type___194 {
	const char *name;
	const struct attribute_group___204 **groups;
	int (*uevent)(struct device___194 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___194 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___194 *);
	const struct dev_pm_ops___194 *pm;
};

struct class___194 {
	const char *name;
	struct module___200 *owner;
	const struct attribute_group___204 **class_groups;
	const struct attribute_group___204 **dev_groups;
	struct kobject___204 *dev_kobj;
	int (*dev_uevent)(struct device___194 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___194 *, umode_t *);
	void (*class_release)(struct class___194 *);
	void (*dev_release)(struct device___194 *);
	int (*shutdown_pre)(struct device___194 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___194 *);
	void (*get_ownership)(struct device___194 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___194 *pm;
	struct subsys_private *p;
};

struct class_interface___4 {
	struct list_head node;
	struct class___194 *class;
	int (*add_dev)(struct device___194 *, struct class_interface___4 *);
	void (*remove_dev)(struct device___194 *, struct class_interface___4 *);
};

struct device_attribute___29 {
	struct attribute attr;
	ssize_t (*show)(struct device___194 *, struct device_attribute___29 *, char *);
	ssize_t (*store)(struct device___194 *, struct device_attribute___29 *, const char *, size_t);
};

struct fwnode_operations___190;

struct fwnode_handle___190 {
	struct fwnode_handle___190 *secondary;
	const struct fwnode_operations___190 *ops;
	struct device___194 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___191 {
	void * (*start)(struct seq_file___191 *, loff_t *);
	void (*stop)(struct seq_file___191 *, void *);
	void * (*next)(struct seq_file___191 *, void *, loff_t *);
	int (*show)(struct seq_file___191 *, void *);
};

struct fwnode_reference_args___190;

struct fwnode_endpoint___190;

struct fwnode_operations___190 {
	struct fwnode_handle___190 * (*get)(struct fwnode_handle___190 *);
	void (*put)(struct fwnode_handle___190 *);
	bool (*device_is_available)(const struct fwnode_handle___190 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___190 *, const struct device___194 *);
	bool (*property_present)(const struct fwnode_handle___190 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___190 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___190 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___190 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*get_parent)(const struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*get_next_child_node)(const struct fwnode_handle___190 *, struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*get_named_child_node)(const struct fwnode_handle___190 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___190 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___190 *);
	struct fwnode_handle___190 * (*graph_get_next_endpoint)(const struct fwnode_handle___190 *, struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*graph_get_remote_endpoint)(const struct fwnode_handle___190 *);
	struct fwnode_handle___190 * (*graph_get_port_parent)(struct fwnode_handle___190 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___190 *, struct fwnode_endpoint___190 *);
	int (*add_links)(struct fwnode_handle___190 *);
};

struct fwnode_endpoint___190 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___190 *local_fwnode;
};

struct fwnode_reference_args___190 {
	struct fwnode_handle___190 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct block_device_operations___112;

struct gendisk___115 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___115 *part0;
	const struct block_device_operations___112 *fops;
	struct request_queue___112 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___204 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___204 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___112 {
	struct bio___112 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___133 *bip_vec;
	struct bio_vec___133 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___112(struct request___112 *);

typedef void integrity_complete_fn___112(struct request___112 *, unsigned int);

struct blk_integrity_profile___112 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___112 *prepare_fn;
	integrity_complete_fn___112 *complete_fn;
	const char *name;
};

struct block_device_operations___112 {
	blk_qc_t (*submit_bio)(struct bio___112 *);
	int (*open)(struct block_device___115 *, fmode_t);
	void (*release)(struct gendisk___115 *, fmode_t);
	int (*rw_page)(struct block_device___115 *, sector_t, struct page___221 *, unsigned int);
	int (*ioctl)(struct block_device___115 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___115 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___115 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___115 *);
	int (*getgeo)(struct block_device___115 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___115 *, bool);
	void (*swap_slot_free_notify)(struct block_device___115 *, long unsigned int);
	int (*report_zones)(struct gendisk___115 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___115 *, umode_t *);
	struct module___200 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___115 *, sector_t *);
};

typedef void rq_end_io_fn___112(struct request___112 *, blk_status_t);

struct request___112 {
	struct request_queue___112 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___109 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___112 *bio;
	struct bio___112 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___133 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___112 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___112 *saved_end_io;
		} flush;
	};
	struct gendisk___115 *rq_disk;
	struct block_device___115 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___112 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___109 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___112 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___204 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___216 *debugfs_dir;
	struct dentry___216 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___112;

struct elevator_mq_ops___112 {
	int (*init_sched)(struct request_queue___112 *, struct elevator_type___112 *);
	void (*exit_sched)(struct elevator_queue___112 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___109 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___109 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___109 *);
	bool (*allow_merge)(struct request_queue___112 *, struct request___112 *, struct bio___112 *);
	bool (*bio_merge)(struct request_queue___112 *, struct bio___112 *, unsigned int);
	int (*request_merge)(struct request_queue___112 *, struct request___112 **, struct bio___112 *);
	void (*request_merged)(struct request_queue___112 *, struct request___112 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___112 *, struct request___112 *, struct request___112 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___112 *);
	void (*finish_request)(struct request___112 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___109 *, struct list_head *, bool);
	struct request___112 * (*dispatch_request)(struct blk_mq_hw_ctx___109 *);
	bool (*has_work)(struct blk_mq_hw_ctx___109 *);
	void (*completed_request)(struct request___112 *, u64);
	void (*requeue_request)(struct request___112 *);
	struct request___112 * (*former_request)(struct request_queue___112 *, struct request___112 *);
	struct request___112 * (*next_request)(struct request_queue___112 *, struct request___112 *);
	void (*init_icq)(struct io_cq___112 *);
	void (*exit_icq)(struct io_cq___112 *);
};

struct elv_fs_entry___112;

struct elevator_type___112 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___112 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___112 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___200 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___112 {
	struct elevator_type___112 *type;
	void *elevator_data;
	struct kobject___204 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___112 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___112 *, char *);
	ssize_t (*store)(struct elevator_queue___112 *, const char *, size_t);
};

struct blk_mq_queue_data___109;

struct blk_mq_ops___109 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___109 *, const struct blk_mq_queue_data___109 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___109 *);
	int (*get_budget)(struct request_queue___112 *);
	void (*put_budget)(struct request_queue___112 *, int);
	void (*set_rq_budget_token)(struct request___112 *, int);
	int (*get_rq_budget_token)(struct request___112 *);
	enum blk_eh_timer_return (*timeout)(struct request___112 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___109 *);
	void (*complete)(struct request___112 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___109 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___109 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___109 *, struct request___112 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___109 *, struct request___112 *, unsigned int);
	void (*initialize_rq_fn)(struct request___112 *);
	void (*cleanup_rq)(struct request___112 *);
	bool (*busy)(struct request_queue___112 *);
	int (*map_queues)(struct blk_mq_tag_set___109 *);
	void (*show_rq)(struct seq_file___191 *, struct request___112 *);
};

struct rchan___6;

struct blk_trace___5 {
	int trace_state;
	struct rchan___6 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___216 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_mq_tag_set___109 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___109 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct rq_map_data___4 {
	struct page___221 **pages;
	int page_order;
	int nr_entries;
	long unsigned int offset;
	int null_mapped;
	int from_user;
};

struct rchan_buf___6 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___6 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___216 *dentry;
	struct kref kref;
	struct page___221 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___6;

struct rchan___6 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___6 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___6 **buf;
	int is_global;
	struct list_head list;
	struct dentry___216 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___6 {
	int (*subbuf_start)(struct rchan_buf___6 *, void *, void *, size_t);
	struct dentry___216 * (*create_buf_file)(const char *, struct dentry___216 *, umode_t, struct rchan_buf___6 *, int *);
	int (*remove_buf_file)(struct dentry___216 *);
};

struct Scsi_Host___6;

struct scsi_target___6;

struct scsi_device___6 {
	struct Scsi_Host___6 *host;
	struct request_queue___112 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___6 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable;
	unsigned int changed;
	unsigned int busy;
	unsigned int lockable;
	unsigned int locked;
	unsigned int borken;
	unsigned int disconnect;
	unsigned int soft_reset;
	unsigned int sdtr;
	unsigned int wdtr;
	unsigned int ppr: 1;
	unsigned int tagged_supported;
	unsigned int simple_tags;
	unsigned int was_reset;
	unsigned int expecting_cc_ua;
	unsigned int use_10_for_rw;
	unsigned int use_10_for_ms;
	unsigned int set_dbd_for_ms;
	unsigned int no_report_opcodes;
	unsigned int no_write_same;
	unsigned int use_16_for_rw;
	unsigned int skip_ms_page_8;
	unsigned int skip_ms_page_3f;
	unsigned int skip_vpd_pages;
	unsigned int try_vpd_pages;
	unsigned int use_192_bytes_for_3f;
	unsigned int no_start_on_add;
	unsigned int allow_restart;
	unsigned int manage_start_stop;
	unsigned int start_stop_pwr_cond;
	unsigned int no_uld_attach;
	unsigned int select_no_atn;
	unsigned int fix_capacity;
	unsigned int guess_capacity;
	unsigned int retry_hwerror;
	unsigned int last_sector_bug;
	unsigned int no_read_disc_info;
	unsigned int no_read_capacity_16;
	unsigned int try_rc_10_first;
	unsigned int security_supported;
	unsigned int is_visible;
	unsigned int wce_default_on;
	unsigned int no_dif;
	unsigned int broken_fua;
	unsigned int lun_in_cdb;
	unsigned int unmap_limit_for_ws;
	unsigned int rpm_autosuspend;
	unsigned int ignore_media_change;
	unsigned int silence_suspend;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___194 sdev_gendev;
	struct device___194 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___223 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___6;

struct Scsi_Host___6 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___223 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___6 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___109 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___194 shost_gendev;
	struct device___194 shost_dev;
	void *shost_data;
	struct device___194 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_target___6 {
	struct scsi_device___6 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___194 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct blk_mq_queue_data___109 {
	struct request___112 *rq;
	bool last;
};

struct scsi_cmnd___6;

struct scsi_host_template___6 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___6 *, struct scsi_cmnd___6 *);
	void (*commit_rqs)(struct Scsi_Host___6 *, u16);
	struct module___200 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___6 *);
	int (*ioctl)(struct scsi_device___6 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___6 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___6 *, struct scsi_cmnd___6 *);
	int (*exit_cmd_priv)(struct Scsi_Host___6 *, struct scsi_cmnd___6 *);
	int (*eh_abort_handler)(struct scsi_cmnd___6 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___6 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___6 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___6 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___6 *);
	int (*slave_alloc)(struct scsi_device___6 *);
	int (*slave_configure)(struct scsi_device___6 *);
	void (*slave_destroy)(struct scsi_device___6 *);
	int (*target_alloc)(struct scsi_target___6 *);
	void (*target_destroy)(struct scsi_target___6 *);
	int (*scan_finished)(struct Scsi_Host___6 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___6 *);
	int (*change_queue_depth)(struct scsi_device___6 *, int);
	int (*map_queues)(struct Scsi_Host___6 *);
	int (*mq_poll)(struct Scsi_Host___6 *, unsigned int);
	bool (*dma_need_drain)(struct request___112 *);
	int (*bios_param)(struct scsi_device___6 *, struct block_device___115 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___6 *);
	int (*show_info)(struct seq_file___191 *, struct Scsi_Host___6 *);
	int (*write_info)(struct Scsi_Host___6 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___6 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___6 *);
	int (*host_reset)(struct Scsi_Host___6 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___29 **shost_attrs;
	struct device_attribute___29 **sdev_attrs;
	const struct attribute_group___204 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_cmnd___6 {
	struct scsi_request req;
	struct scsi_device___6 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___6 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

typedef struct sg_io_hdr sg_io_hdr_t;

struct sg_scsi_id {
	int host_no;
	int channel;
	int scsi_id;
	int lun;
	int scsi_type;
	short int h_cmd_per_lun;
	short int d_queue_depth;
	int unused[2];
};

typedef struct sg_scsi_id sg_scsi_id_t;

struct sg_req_info {
	char req_state;
	char orphan;
	char sg_io_owned;
	char problem;
	int pack_id;
	void *usr_ptr;
	unsigned int duration;
	int unused;
};

typedef struct sg_req_info sg_req_info_t;

struct sg_header {
	int pack_len;
	int reply_len;
	int pack_id;
	int result;
	unsigned int twelve_byte: 1;
	unsigned int target_status: 5;
	unsigned int host_status: 8;
	unsigned int driver_status: 8;
	unsigned int other_flags: 10;
	long: 22;
	long: 64;
	long: 64;
	unsigned char sense_buffer[16];
};

struct proc_ops___22 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___216 *, struct file___216 *);
	ssize_t (*proc_read)(struct file___216 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___216 *, struct iov_iter___136 *);
	ssize_t (*proc_write)(struct file___216 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___216 *, loff_t, int);
	int (*proc_release)(struct inode___216 *, struct file___216 *);
	__poll_t (*proc_poll)(struct file___216 *, struct poll_table_struct___141 *);
	long int (*proc_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___216 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___216 *, struct vm_area_struct___221 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___216 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct sg_scatter_hold {
	short unsigned int k_use_sg;
	unsigned int sglist_len;
	unsigned int bufflen;
	struct page___221 **pages;
	int page_order;
	char dio_in_use;
	unsigned char cmd_opcode;
};

typedef struct sg_scatter_hold Sg_scatter_hold;

struct sg_fd;

struct sg_request {
	struct list_head entry;
	struct sg_fd *parentfp;
	Sg_scatter_hold data;
	sg_io_hdr_t header;
	unsigned char sense_b[96];
	char res_used;
	char orphan;
	char sg_io_owned;
	char done;
	struct request___112 *rq;
	struct bio___112 *bio;
	struct execute_work ew;
};

typedef struct sg_request Sg_request;

struct sg_device;

struct sg_fd {
	struct list_head sfd_siblings;
	struct sg_device *parentdp;
	wait_queue_head_t read_wait;
	rwlock_t rq_list_lock;
	struct mutex f_mutex;
	int timeout;
	int timeout_user;
	Sg_scatter_hold reserve;
	struct list_head rq_list;
	struct fasync_struct___216 *async_qp;
	Sg_request req_arr[16];
	char force_packid;
	char cmd_q;
	unsigned char next_cmd_len;
	char keep_orphan;
	char mmap_called;
	char res_in_use;
	struct kref f_ref;
	struct execute_work ew;
};

struct sg_device {
	struct scsi_device___6 *device;
	wait_queue_head_t open_wait;
	struct mutex open_rel_lock;
	int sg_tablesize;
	u32 index;
	struct list_head sfds;
	rwlock_t sfd_lock;
	atomic_t detaching;
	bool exclude;
	int open_cnt;
	char sgdebug;
	char name[32];
	struct cdev___54 *cdev;
	struct kref d_ref;
};

typedef struct sg_fd Sg_fd;

typedef struct sg_device Sg_device;

struct compat_sg_req_info {
	char req_state;
	char orphan;
	char sg_io_owned;
	char problem;
	int pack_id;
	compat_uptr_t usr_ptr;
	unsigned int duration;
	int unused;
};

struct sg_proc_deviter {
	loff_t index;
	size_t max;
};

struct dentry___217;

struct super_block___217;

struct module___201;

struct file_system_type___217 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___217 * (*mount)(struct file_system_type___217 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___217 *);
	struct module___201 *owner;
	struct file_system_type___217 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___217;

struct kiocb___217;

struct iov_iter___137;

struct poll_table_struct___142;

struct vm_area_struct___222;

struct inode___217;

struct file_lock___217;

struct page___222;

struct seq_file___192;

struct file_operations___218 {
	struct module___201 *owner;
	loff_t (*llseek)(struct file___217 *, loff_t, int);
	ssize_t (*read)(struct file___217 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___217 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___217 *, struct iov_iter___137 *);
	ssize_t (*write_iter)(struct kiocb___217 *, struct iov_iter___137 *);
	int (*iopoll)(struct kiocb___217 *, bool);
	int (*iterate)(struct file___217 *, struct dir_context *);
	int (*iterate_shared)(struct file___217 *, struct dir_context *);
	__poll_t (*poll)(struct file___217 *, struct poll_table_struct___142 *);
	long int (*unlocked_ioctl)(struct file___217 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___217 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___217 *, struct vm_area_struct___222 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___217 *, struct file___217 *);
	int (*flush)(struct file___217 *, fl_owner_t);
	int (*release)(struct inode___217 *, struct file___217 *);
	int (*fsync)(struct file___217 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___217 *, int);
	int (*lock)(struct file___217 *, int, struct file_lock___217 *);
	ssize_t (*sendpage)(struct file___217 *, struct page___222 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___217 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___217 *, long unsigned int);
	int (*flock)(struct file___217 *, int, struct file_lock___217 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___217 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___217 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___217 *, long int, struct file_lock___217 **, void **);
	long int (*fallocate)(struct file___217 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___192 *, struct file___217 *);
	ssize_t (*copy_file_range)(struct file___217 *, loff_t, struct file___217 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___217 *, loff_t, struct file___217 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___217 *, loff_t, loff_t, int);
};

struct vmacache___222 {
	u64 seqnum;
	struct vm_area_struct___222 *vmas[4];
};

struct page_frag___222 {
	struct page___222 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___79;

struct debug_info___79 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___79 *hbp_break[16];
	struct perf_event___79 *hbp_watch[16];
};

struct thread_struct___79 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___79 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___223;

struct pid___194;

struct nsproxy___203;

struct signal_struct___218;

struct bio_list___113;

struct backing_dev_info___103;

struct io_context___113;

struct css_set___148;

struct perf_event_context___79;

struct mem_cgroup___94;

struct request_queue___113;

struct vm_struct___200;

struct task_struct___224 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___224 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___223 *mm;
	struct mm_struct___223 *active_mm;
	struct vmacache___222 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___224 *real_parent;
	struct task_struct___224 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___224 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___194 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___203 *nsproxy;
	struct signal_struct___218 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___224 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___113 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___103 *backing_dev_info;
	struct io_context___113 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___148 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___79 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___222 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___94 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___94 *active_memcg;
	struct request_queue___113 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___224 *oom_reaper_list;
	struct vm_struct___200 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___79 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___205;

struct kobj_type___205;

struct kernfs_node___205;

struct kobject___205 {
	const char *name;
	struct list_head entry;
	struct kobject___205 *parent;
	struct kset___205 *kset;
	struct kobj_type___205 *ktype;
	struct kernfs_node___205 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___202 {
	struct kobject___205 kobj;
	struct module___201 *mod;
	struct kobject___205 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___201 {
	struct module___201 *mod;
	struct latch_tree_node node;
};

struct module_layout___201 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___201 mtn;
};

struct module_attribute___201;

struct kernel_param___201;

struct trace_event_call___73;

struct module___201 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___202 mkobj;
	struct module_attribute___201 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___205 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___201 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___201 core_layout;
	struct module_layout___201 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___73 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___79 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___224 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___79)(struct perf_event___79 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___79;

struct fasync_struct___217;

struct pid_namespace___194;

struct perf_cgroup___79;

struct perf_event___79 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___79 *group_leader;
	struct pmu___79 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___79 hw;
	struct perf_event_context___79 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___79 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___224 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___217 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___79 *aux_event;
	void (*destroy)(struct perf_event___79 *);
	struct callback_head callback_head;
	struct pid_namespace___194 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___79 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___79 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___73 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___79 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___194 {
	int nr;
	struct pid_namespace___194 *ns;
};

struct pid_namespace___194 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___224 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___194 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___194 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___194 numbers[1];
};

typedef struct page___222 *pgtable_t___222;

struct address_space___217;

struct dev_pagemap___212;

struct page___222 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___217 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___222 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___222 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___223 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___212 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___212;

struct vm_area_struct___222 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___222 *vm_next;
	struct vm_area_struct___222 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___223 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___212 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___217 *vm_file;
	struct file___217 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___218 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___224 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___224 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___194 *pids[4];
	struct pid___194 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___223 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___222;

struct mm_struct___223 {
	struct {
		struct vm_area_struct___222 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___217 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___222 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___224 *owner;
		struct user_namespace___14 *user_ns;
		struct file___217 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___148;

struct nsproxy___203 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___194 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___148 *cgroup_ns;
};

struct bio___113;

struct bio_list___113 {
	struct bio___113 *head;
	struct bio___113 *tail;
};

struct cgroup_subsys_state___148;

struct bdi_writeback___103 {
	struct backing_dev_info___103 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___148 *memcg_css;
	struct cgroup_subsys_state___148 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___195;

struct backing_dev_info___103 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___103 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___195 *dev;
	char dev_name[64];
	struct device___195 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___217 *debug_dir;
};

struct io_cq___113;

struct io_context___113 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___113 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___148;

struct css_set___148 {
	struct cgroup_subsys_state___148 *subsys[14];
	refcount_t refcount;
	struct css_set___148 *dom_cset;
	struct cgroup___148 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___148 *mg_src_cgrp;
	struct cgroup___148 *mg_dst_cgrp;
	struct css_set___148 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___79 {
	struct pmu___79 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___224 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___79 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___148;

struct cgroup_subsys_state___148 {
	struct cgroup___148 *cgroup;
	struct cgroup_subsys___148 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___148 *parent;
};

struct cgroup_file___148 {
	struct kernfs_node___205 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___94;

struct mem_cgroup_per_node___94;

struct mem_cgroup___94 {
	struct cgroup_subsys_state___148 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___148 events_file;
	struct cgroup_file___148 events_local_file;
	struct cgroup_file___148 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___94 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___224 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___94 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___113;

struct blk_integrity___113 {
	const struct blk_integrity_profile___113 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___113 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___113 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___113;

struct elevator_queue___113;

struct blk_mq_ops___110;

struct blk_mq_hw_ctx___110;

struct gendisk___116;

struct blkcg_gq___105;

struct blk_mq_tag_set___110;

struct request_queue___113 {
	struct request___113 *last_merge;
	struct elevator_queue___113 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___110 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___110 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___116 *disk;
	struct kobject___205 kobj;
	struct kobject___205 *mq_kobj;
	struct blk_integrity___113 integrity;
	struct device___195 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___105 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___110 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___113 bio_split;
	struct dentry___217 *debugfs_dir;
	struct dentry___217 *sched_debugfs_dir;
	struct dentry___217 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___200 {
	struct vm_struct___200 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___222 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___217;

struct address_space___217 {
	struct inode___217 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___217 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___212;

struct dev_pagemap___212 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___212 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___217;

struct path___217 {
	struct vfsmount___217 *mnt;
	struct dentry___217 *dentry;
};

struct fown_struct___194 {
	rwlock_t lock;
	struct pid___194 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___217 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___217 f_path;
	struct inode___217 *f_inode;
	const struct file_operations___218 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___194 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___217 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___212;

struct vm_operations_struct___212 {
	void (*open)(struct vm_area_struct___222 *);
	void (*close)(struct vm_area_struct___222 *);
	int (*may_split)(struct vm_area_struct___222 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___222 *);
	int (*mprotect)(struct vm_area_struct___222 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___212 *);
	vm_fault_t (*huge_fault)(struct vm_fault___212 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___212 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___222 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___212 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___212 *);
	int (*access)(struct vm_area_struct___222 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___222 *);
	int (*set_policy)(struct vm_area_struct___222 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___222 *, long unsigned int);
	struct page___222 * (*find_special_page)(struct vm_area_struct___222 *, long unsigned int);
};

struct core_thread___222 {
	struct task_struct___224 *task;
	struct core_thread___222 *next;
};

struct core_state___222 {
	atomic_t nr_threads;
	struct core_thread___222 dumper;
	struct completion startup;
};

struct vm_fault___212 {
	const struct {
		struct vm_area_struct___222 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___222 *cow_page;
	struct page___222 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___222 prealloc_pte;
};

struct pglist_data___102;

struct lruvec___102 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___102 *pgdat;
};

struct zone___102 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___102 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___102 {
	struct zone___102 *zone;
	int zone_idx;
};

struct zonelist___102 {
	struct zoneref___102 _zonerefs[321];
};

struct pglist_data___102 {
	struct zone___102 node_zones[5];
	struct zonelist___102 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___224 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___224 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___102 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___217;

struct dentry___217 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___217 *d_parent;
	struct qstr d_name;
	struct inode___217 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___217 *d_op;
	struct super_block___217 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___217;

struct cdev___55;

struct inode___217 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___217 *i_op;
	struct super_block___217 *i_sb;
	struct address_space___217 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___103 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___218 *i_fop;
		void (*free_inode)(struct inode___217 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___217 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___55 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___217 {
	int (*d_revalidate)(struct dentry___217 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___217 *, unsigned int);
	int (*d_hash)(const struct dentry___217 *, struct qstr *);
	int (*d_compare)(const struct dentry___217 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___217 *);
	int (*d_init)(struct dentry___217 *);
	void (*d_release)(struct dentry___217 *);
	void (*d_prune)(struct dentry___217 *);
	void (*d_iput)(struct dentry___217 *, struct inode___217 *);
	char * (*d_dname)(struct dentry___217 *, char *, int);
	struct vfsmount___217 * (*d_automount)(struct path___217 *);
	int (*d_manage)(const struct path___217 *, bool);
	struct dentry___217 * (*d_real)(struct dentry___217 *, const struct inode___217 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___217;

struct mem_dqinfo___217 {
	struct quota_format_type___217 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___217;

struct quota_info___217 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___217 *files[3];
	struct mem_dqinfo___217 info[3];
	const struct quota_format_ops___217 *ops[3];
};

struct rcuwait___218 {
	struct task_struct___224 *task;
};

struct percpu_rw_semaphore___218 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___218 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___217 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___218 rw_sem[3];
};

struct shrink_control___94;

struct shrinker___94 {
	long unsigned int (*count_objects)(struct shrinker___94 *, struct shrink_control___94 *);
	long unsigned int (*scan_objects)(struct shrinker___94 *, struct shrink_control___94 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___217;

struct dquot_operations___217;

struct quotactl_ops___217;

struct block_device___116;

struct super_block___217 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___217 *s_type;
	const struct super_operations___217 *s_op;
	const struct dquot_operations___217 *dq_op;
	const struct quotactl_ops___217 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___217 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___116 *s_bdev;
	struct backing_dev_info___103 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___217 s_dquot;
	struct sb_writers___217 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___217 *s_d_op;
	int cleancache_poolid;
	struct shrinker___94 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___217 {
	struct dentry___217 *mnt_root;
	struct super_block___217 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___94 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___94 *memcg;
};

struct psi_group___148 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___224 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___148;

struct cgroup_rstat_cpu___148;

struct cgroup___148 {
	struct cgroup_subsys_state___148 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___205 *kn;
	struct cgroup_file___148 procs_file;
	struct cgroup_file___148 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___148 *subsys[14];
	struct cgroup_root___148 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___148 *dom_cgrp;
	struct cgroup___148 *old_dom_cgrp;
	struct cgroup_rstat_cpu___148 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___148 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___113 {
	struct request_queue___113 *q;
	struct io_context___113 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___104;

struct kiocb___217 {
	struct file___217 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___217 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___104 *ki_waitq;
	};
};

struct iattr___217 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___217 *ia_file;
};

struct dquot___217 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___217 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___217 {
	int qf_fmt_id;
	const struct quota_format_ops___217 *qf_ops;
	struct module___201 *qf_owner;
	struct quota_format_type___217 *qf_next;
};

struct quota_format_ops___217 {
	int (*check_quota_file)(struct super_block___217 *, int);
	int (*read_file_info)(struct super_block___217 *, int);
	int (*write_file_info)(struct super_block___217 *, int);
	int (*free_file_info)(struct super_block___217 *, int);
	int (*read_dqblk)(struct dquot___217 *);
	int (*commit_dqblk)(struct dquot___217 *);
	int (*release_dqblk)(struct dquot___217 *);
	int (*get_next_id)(struct super_block___217 *, struct kqid *);
};

struct dquot_operations___217 {
	int (*write_dquot)(struct dquot___217 *);
	struct dquot___217 * (*alloc_dquot)(struct super_block___217 *, int);
	void (*destroy_dquot)(struct dquot___217 *);
	int (*acquire_dquot)(struct dquot___217 *);
	int (*release_dquot)(struct dquot___217 *);
	int (*mark_dirty)(struct dquot___217 *);
	int (*write_info)(struct super_block___217 *, int);
	qsize_t * (*get_reserved_space)(struct inode___217 *);
	int (*get_projid)(struct inode___217 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___217 *, qsize_t *);
	int (*get_next_id)(struct super_block___217 *, struct kqid *);
};

struct quotactl_ops___217 {
	int (*quota_on)(struct super_block___217 *, int, int, const struct path___217 *);
	int (*quota_off)(struct super_block___217 *, int);
	int (*quota_enable)(struct super_block___217 *, unsigned int);
	int (*quota_disable)(struct super_block___217 *, unsigned int);
	int (*quota_sync)(struct super_block___217 *, int);
	int (*set_info)(struct super_block___217 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___217 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___217 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___217 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___217 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___217 *, unsigned int);
};

struct wait_page_queue___104 {
	struct page___222 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___103;

struct readahead_control___104;

struct swap_info_struct___62;

struct address_space_operations___217 {
	int (*writepage)(struct page___222 *, struct writeback_control___103 *);
	int (*readpage)(struct file___217 *, struct page___222 *);
	int (*writepages)(struct address_space___217 *, struct writeback_control___103 *);
	int (*set_page_dirty)(struct page___222 *);
	int (*readpages)(struct file___217 *, struct address_space___217 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___104 *);
	int (*write_begin)(struct file___217 *, struct address_space___217 *, loff_t, unsigned int, unsigned int, struct page___222 **, void **);
	int (*write_end)(struct file___217 *, struct address_space___217 *, loff_t, unsigned int, unsigned int, struct page___222 *, void *);
	sector_t (*bmap)(struct address_space___217 *, sector_t);
	void (*invalidatepage)(struct page___222 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___222 *, gfp_t);
	void (*freepage)(struct page___222 *);
	ssize_t (*direct_IO)(struct kiocb___217 *, struct iov_iter___137 *);
	int (*migratepage)(struct address_space___217 *, struct page___222 *, struct page___222 *, enum migrate_mode);
	bool (*isolate_page)(struct page___222 *, isolate_mode_t);
	void (*putback_page)(struct page___222 *);
	int (*launder_page)(struct page___222 *);
	int (*is_partially_uptodate)(struct page___222 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___222 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___217 *, struct page___222 *);
	int (*swap_activate)(struct swap_info_struct___62 *, struct file___217 *, sector_t *);
	void (*swap_deactivate)(struct file___217 *);
};

struct writeback_control___103 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___103 *wb;
	struct inode___217 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___104 {
	struct file___217 *file;
	struct address_space___217 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___134;

struct iov_iter___137 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___134 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___62 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___116 *bdev;
	struct file___217 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___55 {
	struct kobject___205 kobj;
	struct module___201 *owner;
	const struct file_operations___218 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___217 {
	struct dentry___217 * (*lookup)(struct inode___217 *, struct dentry___217 *, unsigned int);
	const char * (*get_link)(struct dentry___217 *, struct inode___217 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___217 *, int);
	struct posix_acl * (*get_acl)(struct inode___217 *, int, bool);
	int (*readlink)(struct dentry___217 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___217 *, struct dentry___217 *, umode_t, bool);
	int (*link)(struct dentry___217 *, struct inode___217 *, struct dentry___217 *);
	int (*unlink)(struct inode___217 *, struct dentry___217 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___217 *, struct dentry___217 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___217 *, struct dentry___217 *, umode_t);
	int (*rmdir)(struct inode___217 *, struct dentry___217 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___217 *, struct dentry___217 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___217 *, struct dentry___217 *, struct inode___217 *, struct dentry___217 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___217 *, struct iattr___217 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___217 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___217 *, char *, size_t);
	int (*fiemap)(struct inode___217 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___217 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___217 *, struct dentry___217 *, struct file___217 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___217 *, struct dentry___217 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___217 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___217 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___217 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___217 {
	void (*fl_copy_lock)(struct file_lock___217 *, struct file_lock___217 *);
	void (*fl_release_private)(struct file_lock___217 *);
};

struct lock_manager_operations___217;

struct file_lock___217 {
	struct file_lock___217 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___217 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___217 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___217 *fl_ops;
	const struct lock_manager_operations___217 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___217 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___217 *);
	int (*lm_grant)(struct file_lock___217 *, int);
	bool (*lm_break)(struct file_lock___217 *);
	int (*lm_change)(struct file_lock___217 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___217 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___217 *);
};

struct fasync_struct___217 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___217 *fa_next;
	struct file___217 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___217 {
	struct inode___217 * (*alloc_inode)(struct super_block___217 *);
	void (*destroy_inode)(struct inode___217 *);
	void (*free_inode)(struct inode___217 *);
	void (*dirty_inode)(struct inode___217 *, int);
	int (*write_inode)(struct inode___217 *, struct writeback_control___103 *);
	int (*drop_inode)(struct inode___217 *);
	void (*evict_inode)(struct inode___217 *);
	void (*put_super)(struct super_block___217 *);
	int (*sync_fs)(struct super_block___217 *, int);
	int (*freeze_super)(struct super_block___217 *);
	int (*freeze_fs)(struct super_block___217 *);
	int (*thaw_super)(struct super_block___217 *);
	int (*unfreeze_fs)(struct super_block___217 *);
	int (*statfs)(struct dentry___217 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___217 *, int *, char *);
	void (*umount_begin)(struct super_block___217 *);
	int (*show_options)(struct seq_file___192 *, struct dentry___217 *);
	int (*show_devname)(struct seq_file___192 *, struct dentry___217 *);
	int (*show_path)(struct seq_file___192 *, struct dentry___217 *);
	int (*show_stats)(struct seq_file___192 *, struct dentry___217 *);
	ssize_t (*quota_read)(struct super_block___217 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___217 *, int, const char *, size_t, loff_t);
	struct dquot___217 ** (*get_dquots)(struct inode___217 *);
	long int (*nr_cached_objects)(struct super_block___217 *, struct shrink_control___94 *);
	long int (*free_cached_objects)(struct super_block___217 *, struct shrink_control___94 *);
	struct file___217 * (*real_loop)(struct file___217 *);
};

struct wakeup_source___195;

struct dev_pm_info___195 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___195 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___195 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___195;

struct bus_type___195;

struct device_driver___195;

struct dev_pm_domain___195;

struct irq_domain___50;

struct device_node___83;

struct fwnode_handle___191;

struct class___195;

struct attribute_group___205;

struct device___195 {
	struct kobject___205 kobj;
	struct device___195 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___195 *type;
	struct bus_type___195 *bus;
	struct device_driver___195 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___195 power;
	struct dev_pm_domain___195 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___50 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___83 *of_node;
	struct fwnode_handle___191 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___195 *class;
	const struct attribute_group___205 **groups;
	void (*release)(struct device___195 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___116 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___217 *bd_inode;
	struct super_block___217 *bd_super;
	void *bd_claiming;
	struct device___195 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___205 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___116 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___217 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___149)(struct file___217 *, wait_queue_head_t *, struct poll_table_struct___142 *);

struct poll_table_struct___142 {
	poll_queue_proc___149 _qproc;
	__poll_t _key;
};

struct seq_operations___192;

struct seq_file___192 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___192 *op;
	int poll_event;
	const struct file___217 *file;
	void *private;
};

typedef void bio_end_io_t___113(struct bio___113 *);

struct bio_vec___134 {
	struct page___222 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___113;

struct bio___113 {
	struct bio___113 *bi_next;
	struct block_device___116 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___113 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___105 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___113 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___134 *bi_io_vec;
	struct bio_set___113 *bi_pool;
	struct bio_vec___134 bi_inline_vecs[0];
};

struct kernfs_root___205;

struct kernfs_elem_dir___205 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___205 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___205;

struct kernfs_root___205 {
	struct kernfs_node___205 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___205 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___205 {
	struct kernfs_node___205 *target_kn;
};

struct kernfs_ops___205;

struct kernfs_elem_attr___205 {
	const struct kernfs_ops___205 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___205 *notify_next;
};

struct kernfs_node___205 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___205 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___205 dir;
		struct kernfs_elem_symlink___205 symlink;
		struct kernfs_elem_attr___205 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___205;

struct kernfs_ops___205 {
	int (*open)(struct kernfs_open_file___205 *);
	void (*release)(struct kernfs_open_file___205 *);
	int (*seq_show)(struct seq_file___192 *, void *);
	void * (*seq_start)(struct seq_file___192 *, loff_t *);
	void * (*seq_next)(struct seq_file___192 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___192 *, void *);
	ssize_t (*read)(struct kernfs_open_file___205 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___205 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___205 *, struct poll_table_struct___142 *);
	int (*mmap)(struct kernfs_open_file___205 *, struct vm_area_struct___222 *);
};

struct kernfs_syscall_ops___205 {
	int (*show_options)(struct seq_file___192 *, struct kernfs_root___205 *);
	int (*mkdir)(struct kernfs_node___205 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___205 *);
	int (*rename)(struct kernfs_node___205 *, struct kernfs_node___205 *, const char *);
	int (*show_path)(struct seq_file___192 *, struct kernfs_node___205 *, struct kernfs_root___205 *);
};

struct kernfs_open_file___205 {
	struct kernfs_node___205 *kn;
	struct file___217 *file;
	struct seq_file___192 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___212 *vm_ops;
};

struct bin_attribute___205;

struct attribute_group___205 {
	const char *name;
	umode_t (*is_visible)(struct kobject___205 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___205 *, struct bin_attribute___205 *, int);
	struct attribute **attrs;
	struct bin_attribute___205 **bin_attrs;
};

struct bin_attribute___205 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___217 * (*f_mapping)();
	ssize_t (*read)(struct file___217 *, struct kobject___205 *, struct bin_attribute___205 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___217 *, struct kobject___205 *, struct bin_attribute___205 *, char *, loff_t, size_t);
	int (*mmap)(struct file___217 *, struct kobject___205 *, struct bin_attribute___205 *, struct vm_area_struct___222 *);
};

struct sysfs_ops___205 {
	ssize_t (*show)(struct kobject___205 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___205 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___205;

struct kset___205 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___205 kobj;
	const struct kset_uevent_ops___205 *uevent_ops;
};

struct kobj_type___205 {
	void (*release)(struct kobject___205 *);
	const struct sysfs_ops___205 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___205 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___205 *);
	const void * (*namespace)(struct kobject___205 *);
	void (*get_ownership)(struct kobject___205 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___205 {
	int (* const filter)(struct kset___205 *, struct kobject___205 *);
	const char * (* const name)(struct kset___205 *, struct kobject___205 *);
	int (* const uevent)(struct kset___205 *, struct kobject___205 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___201 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___201 *);
	int (*get)(char *, const struct kernel_param___201 *);
	void (*free)(void *);
};

struct kparam_array___201;

struct kernel_param___201 {
	const char *name;
	struct module___201 *mod;
	const struct kernel_param_ops___201 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___201 *arr;
	};
};

struct kparam_array___201 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___201 *ops;
	void *elem;
};

struct module_attribute___201 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___201 *, struct module_kobject___202 *, char *);
	ssize_t (*store)(struct module_attribute___201 *, struct module_kobject___202 *, const char *, size_t);
	void (*setup)(struct module___201 *, const char *);
	int (*test)(struct module___201 *);
	void (*free)(struct module___201 *);
};

struct module_version_attribute___8 {
	struct module_attribute___201 mattr;
	const char *module_name;
	const char *version;
};

struct trace_event_class___73;

struct trace_event_call___73 {
	struct list_head list;
	struct trace_event_class___73 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___73 *, struct perf_event___79 *);
};

struct dev_pm_ops___195 {
	int (*prepare)(struct device___195 *);
	void (*complete)(struct device___195 *);
	int (*suspend)(struct device___195 *);
	int (*resume)(struct device___195 *);
	int (*freeze)(struct device___195 *);
	int (*thaw)(struct device___195 *);
	int (*poweroff)(struct device___195 *);
	int (*restore)(struct device___195 *);
	int (*suspend_late)(struct device___195 *);
	int (*resume_early)(struct device___195 *);
	int (*freeze_late)(struct device___195 *);
	int (*thaw_early)(struct device___195 *);
	int (*poweroff_late)(struct device___195 *);
	int (*restore_early)(struct device___195 *);
	int (*suspend_noirq)(struct device___195 *);
	int (*resume_noirq)(struct device___195 *);
	int (*freeze_noirq)(struct device___195 *);
	int (*thaw_noirq)(struct device___195 *);
	int (*poweroff_noirq)(struct device___195 *);
	int (*restore_noirq)(struct device___195 *);
	int (*runtime_suspend)(struct device___195 *);
	int (*runtime_resume)(struct device___195 *);
	int (*runtime_idle)(struct device___195 *);
};

struct wakeup_source___195 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___195 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___195 {
	struct dev_pm_ops___195 ops;
	int (*start)(struct device___195 *);
	void (*detach)(struct device___195 *, bool);
	int (*activate)(struct device___195 *);
	void (*sync)(struct device___195 *);
	void (*dismiss)(struct device___195 *);
};

struct bus_type___195 {
	const char *name;
	const char *dev_name;
	struct device___195 *dev_root;
	const struct attribute_group___205 **bus_groups;
	const struct attribute_group___205 **dev_groups;
	const struct attribute_group___205 **drv_groups;
	int (*match)(struct device___195 *, struct device_driver___195 *);
	int (*uevent)(struct device___195 *, struct kobj_uevent_env *);
	int (*probe)(struct device___195 *);
	void (*sync_state)(struct device___195 *);
	void (*remove)(struct device___195 *);
	void (*shutdown)(struct device___195 *);
	int (*online)(struct device___195 *);
	int (*offline)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	int (*num_vf)(struct device___195 *);
	int (*dma_configure)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___195 {
	const char *name;
	struct bus_type___195 *bus;
	struct module___201 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___195 *);
	void (*sync_state)(struct device___195 *);
	int (*remove)(struct device___195 *);
	void (*shutdown)(struct device___195 *);
	int (*suspend)(struct device___195 *, pm_message_t);
	int (*resume)(struct device___195 *);
	const struct attribute_group___205 **groups;
	const struct attribute_group___205 **dev_groups;
	const struct dev_pm_ops___195 *pm;
	void (*coredump)(struct device___195 *);
	struct driver_private *p;
};

struct device_type___195 {
	const char *name;
	const struct attribute_group___205 **groups;
	int (*uevent)(struct device___195 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___195 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___195 *);
	const struct dev_pm_ops___195 *pm;
};

struct class___195 {
	const char *name;
	struct module___201 *owner;
	const struct attribute_group___205 **class_groups;
	const struct attribute_group___205 **dev_groups;
	struct kobject___205 *dev_kobj;
	int (*dev_uevent)(struct device___195 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___195 *, umode_t *);
	void (*class_release)(struct class___195 *);
	void (*dev_release)(struct device___195 *);
	int (*shutdown_pre)(struct device___195 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___195 *);
	void (*get_ownership)(struct device___195 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___195 *pm;
	struct subsys_private *p;
};

struct device_attribute___30 {
	struct attribute attr;
	ssize_t (*show)(struct device___195 *, struct device_attribute___30 *, char *);
	ssize_t (*store)(struct device___195 *, struct device_attribute___30 *, const char *, size_t);
};

typedef void (*dr_release_t___27)(struct device___195 *, void *);

struct irq_domain_ops___50;

struct irq_domain_chip_generic___50;

struct irq_data___52;

struct irq_domain___50 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___50 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___191 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___50 *gc;
	struct irq_domain___50 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___52 *revmap[0];
};

struct fwnode_operations___191;

struct fwnode_handle___191 {
	struct fwnode_handle___191 *secondary;
	const struct fwnode_operations___191 *ops;
	struct device___195 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___60;

struct device_node___83 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___191 fwnode;
	struct property___60 *properties;
	struct property___60 *deadprops;
	struct device_node___83 *parent;
	struct device_node___83 *child;
	struct device_node___83 *sibling;
	struct kobject___205 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___52;

typedef void (*irq_flow_handler_t___52)(struct irq_desc___52 *);

struct irq_chip___52;

struct irq_data___52 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___52 *chip;
	struct irq_domain___50 *domain;
	struct irq_data___52 *parent_data;
	void *chip_data;
};

struct irqaction___34;

struct irq_desc___52 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___52 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___52 handle_irq;
	struct irqaction___34 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___205 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___201 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___191;

struct fwnode_endpoint___191;

struct fwnode_operations___191 {
	struct fwnode_handle___191 * (*get)(struct fwnode_handle___191 *);
	void (*put)(struct fwnode_handle___191 *);
	bool (*device_is_available)(const struct fwnode_handle___191 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___191 *, const struct device___195 *);
	bool (*property_present)(const struct fwnode_handle___191 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___191 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___191 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___191 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*get_parent)(const struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*get_next_child_node)(const struct fwnode_handle___191 *, struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*get_named_child_node)(const struct fwnode_handle___191 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___191 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___191 *);
	struct fwnode_handle___191 * (*graph_get_next_endpoint)(const struct fwnode_handle___191 *, struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*graph_get_remote_endpoint)(const struct fwnode_handle___191 *);
	struct fwnode_handle___191 * (*graph_get_port_parent)(struct fwnode_handle___191 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___191 *, struct fwnode_endpoint___191 *);
	int (*add_links)(struct fwnode_handle___191 *);
};

struct fwnode_endpoint___191 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___191 *local_fwnode;
};

struct fwnode_reference_args___191 {
	struct fwnode_handle___191 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___52 {
	struct device___195 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___52 *);
	void (*irq_shutdown)(struct irq_data___52 *);
	void (*irq_enable)(struct irq_data___52 *);
	void (*irq_disable)(struct irq_data___52 *);
	void (*irq_ack)(struct irq_data___52 *);
	void (*irq_mask)(struct irq_data___52 *);
	void (*irq_mask_ack)(struct irq_data___52 *);
	void (*irq_unmask)(struct irq_data___52 *);
	void (*irq_eoi)(struct irq_data___52 *);
	int (*irq_set_affinity)(struct irq_data___52 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___52 *);
	int (*irq_set_type)(struct irq_data___52 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___52 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___52 *);
	void (*irq_bus_sync_unlock)(struct irq_data___52 *);
	void (*irq_cpu_online)(struct irq_data___52 *);
	void (*irq_cpu_offline)(struct irq_data___52 *);
	void (*irq_suspend)(struct irq_data___52 *);
	void (*irq_resume)(struct irq_data___52 *);
	void (*irq_pm_shutdown)(struct irq_data___52 *);
	void (*irq_calc_mask)(struct irq_data___52 *);
	void (*irq_print_chip)(struct irq_data___52 *, struct seq_file___192 *);
	int (*irq_request_resources)(struct irq_data___52 *);
	void (*irq_release_resources)(struct irq_data___52 *);
	void (*irq_compose_msi_msg)(struct irq_data___52 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___52 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___52 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___52 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___52 *, void *);
	void (*ipi_send_single)(struct irq_data___52 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___52 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___52 *);
	void (*irq_nmi_teardown)(struct irq_data___52 *);
	long unsigned int flags;
};

struct irqaction___34 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___34 *next;
	irq_handler_t thread_fn;
	struct task_struct___224 *thread;
	struct irqaction___34 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___50 {
	struct irq_chip___52 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___52 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___50 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___50 *);
	void (*resume)(struct irq_chip_generic___50 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___50 *domain;
	struct list_head list;
	struct irq_chip_type___50 chip_types[0];
};

struct irq_domain_chip_generic___50 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___50 *gc[0];
};

struct pci_bus___17;

struct pci_slot___17 {
	struct pci_bus___17 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___205 kobj;
};

struct pci_dev___17;

struct pci_ops___17;

struct pci_bus___17 {
	struct list_head node;
	struct pci_bus___17 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___17 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___17 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___195 *bridge;
	struct device___195 dev;
	struct bin_attribute___205 *legacy_io;
	struct bin_attribute___205 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___17;

struct pci_dev___17 {
	struct list_head bus_list;
	struct pci_bus___17 *bus;
	struct pci_bus___17 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___17 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___17 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___17 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___195 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___205 *res_attr[17];
	struct bin_attribute___205 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___205 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___17 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___17;

struct pci_driver___17 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___17 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___17 *);
	int (*suspend)(struct pci_dev___17 *, pm_message_t);
	int (*resume)(struct pci_dev___17 *);
	void (*shutdown)(struct pci_dev___17 *);
	int (*sriov_configure)(struct pci_dev___17 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___17 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___17 *);
	const struct pci_error_handlers___17 *err_handler;
	const struct attribute_group___205 **groups;
	const struct attribute_group___205 **dev_groups;
	struct device_driver___195 driver;
	struct pci_dynids dynids;
};

struct pci_ops___17 {
	int (*add_bus)(struct pci_bus___17 *);
	void (*remove_bus)(struct pci_bus___17 *);
	void * (*map_bus)(struct pci_bus___17 *, unsigned int, int);
	int (*read)(struct pci_bus___17 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___17 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___17 {
	pci_ers_result_t (*error_detected)(struct pci_dev___17 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___17 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___17 *);
	void (*reset_prepare)(struct pci_dev___17 *);
	void (*reset_done)(struct pci_dev___17 *);
	void (*resume)(struct pci_dev___17 *);
};

struct dev_pagemap_ops___212 {
	void (*page_free)(struct page___222 *);
	void (*kill)(struct dev_pagemap___212 *);
	void (*cleanup)(struct dev_pagemap___212 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___212 *);
};

struct cgroup_namespace___148 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___148 *root_cset;
};

struct block_device_operations___113;

struct cdrom_device_info___3;

struct gendisk___116 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___116 *part0;
	const struct block_device_operations___113 *fops;
	struct request_queue___113 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___103 *bdi;
	struct kobject___205 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___205 integrity_kobj;
	struct cdrom_device_info___3 *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___113 {
	struct bio___113 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___134 *bip_vec;
	struct bio_vec___134 bip_inline_vecs[0];
};

struct blkcg___105;

struct blkg_policy_data___105;

struct blkcg_gq___105 {
	struct request_queue___113 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___105 *blkcg;
	struct blkcg_gq___105 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___105 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___113 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___113(struct request___113 *);

typedef void integrity_complete_fn___113(struct request___113 *, unsigned int);

struct blk_integrity_profile___113 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___113 *prepare_fn;
	integrity_complete_fn___113 *complete_fn;
	const char *name;
};

struct block_device_operations___113 {
	blk_qc_t (*submit_bio)(struct bio___113 *);
	int (*open)(struct block_device___116 *, fmode_t);
	void (*release)(struct gendisk___116 *, fmode_t);
	int (*rw_page)(struct block_device___116 *, sector_t, struct page___222 *, unsigned int);
	int (*ioctl)(struct block_device___116 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___116 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___116 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___116 *);
	int (*getgeo)(struct block_device___116 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___116 *, bool);
	void (*swap_slot_free_notify)(struct block_device___116 *, long unsigned int);
	int (*report_zones)(struct gendisk___116 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___116 *, umode_t *);
	struct module___201 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___116 *, sector_t *);
};

struct cdrom_device_ops___3;

struct cdrom_device_info___3 {
	const struct cdrom_device_ops___3 *ops;
	struct list_head list;
	struct gendisk___116 *disk;
	void *handle;
	int mask;
	int speed;
	int capacity;
	unsigned int options: 30;
	unsigned int mc_flags: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int vfs_events;
	unsigned int ioctl_events;
	int use_count;
	char name[20];
	__u8 sanyo_slot: 2;
	__u8 keeplocked: 1;
	__u8 reserved: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int cdda_method;
	__u8 last_sense;
	__u8 media_written;
	short unsigned int mmc3_profile;
	int for_data;
	int (*exit)(struct cdrom_device_info___3 *);
	int mrw_mode_page;
};

typedef void rq_end_io_fn___113(struct request___113 *, blk_status_t);

struct request___113 {
	struct request_queue___113 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___110 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___113 *bio;
	struct bio___113 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___134 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___113 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___113 *saved_end_io;
		} flush;
	};
	struct gendisk___116 *rq_disk;
	struct block_device___116 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___113 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___110 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___113 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___205 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___217 *debugfs_dir;
	struct dentry___217 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___113;

struct elevator_mq_ops___113 {
	int (*init_sched)(struct request_queue___113 *, struct elevator_type___113 *);
	void (*exit_sched)(struct elevator_queue___113 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___110 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___110 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___110 *);
	bool (*allow_merge)(struct request_queue___113 *, struct request___113 *, struct bio___113 *);
	bool (*bio_merge)(struct request_queue___113 *, struct bio___113 *, unsigned int);
	int (*request_merge)(struct request_queue___113 *, struct request___113 **, struct bio___113 *);
	void (*request_merged)(struct request_queue___113 *, struct request___113 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___113 *, struct request___113 *, struct request___113 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___113 *);
	void (*finish_request)(struct request___113 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___110 *, struct list_head *, bool);
	struct request___113 * (*dispatch_request)(struct blk_mq_hw_ctx___110 *);
	bool (*has_work)(struct blk_mq_hw_ctx___110 *);
	void (*completed_request)(struct request___113 *, u64);
	void (*requeue_request)(struct request___113 *);
	struct request___113 * (*former_request)(struct request_queue___113 *, struct request___113 *);
	struct request___113 * (*next_request)(struct request_queue___113 *, struct request___113 *);
	void (*init_icq)(struct io_cq___113 *);
	void (*exit_icq)(struct io_cq___113 *);
};

struct elv_fs_entry___113;

struct elevator_type___113 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___113 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___113 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___201 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___113 {
	struct elevator_type___113 *type;
	void *elevator_data;
	struct kobject___205 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___113 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___113 *, char *);
	ssize_t (*store)(struct elevator_queue___113 *, const char *, size_t);
};

struct blk_mq_queue_data___110;

struct blk_mq_ops___110 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___110 *, const struct blk_mq_queue_data___110 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___110 *);
	int (*get_budget)(struct request_queue___113 *);
	void (*put_budget)(struct request_queue___113 *, int);
	void (*set_rq_budget_token)(struct request___113 *, int);
	int (*get_rq_budget_token)(struct request___113 *);
	enum blk_eh_timer_return (*timeout)(struct request___113 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___110 *);
	void (*complete)(struct request___113 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___110 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___110 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___110 *, struct request___113 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___110 *, struct request___113 *, unsigned int);
	void (*initialize_rq_fn)(struct request___113 *);
	void (*cleanup_rq)(struct request___113 *);
	bool (*busy)(struct request_queue___113 *);
	int (*map_queues)(struct blk_mq_tag_set___110 *);
	void (*show_rq)(struct seq_file___192 *, struct request___113 *);
};

struct blk_mq_tag_set___110 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___110 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___192 {
	void * (*start)(struct seq_file___192 *, loff_t *);
	void (*stop)(struct seq_file___192 *, void *);
	void * (*next)(struct seq_file___192 *, void *, loff_t *);
	int (*show)(struct seq_file___192 *, void *);
};

struct cftype___148;

struct cgroup_subsys___148 {
	struct cgroup_subsys_state___148 * (*css_alloc)(struct cgroup_subsys_state___148 *);
	int (*css_online)(struct cgroup_subsys_state___148 *);
	void (*css_offline)(struct cgroup_subsys_state___148 *);
	void (*css_released)(struct cgroup_subsys_state___148 *);
	void (*css_free)(struct cgroup_subsys_state___148 *);
	void (*css_reset)(struct cgroup_subsys_state___148 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___148 *, int);
	int (*css_extra_stat_show)(struct seq_file___192 *, struct cgroup_subsys_state___148 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___224 *, struct css_set___148 *);
	void (*cancel_fork)(struct task_struct___224 *, struct css_set___148 *);
	void (*fork)(struct task_struct___224 *);
	void (*exit)(struct task_struct___224 *);
	void (*release)(struct task_struct___224 *);
	void (*bind)(struct cgroup_subsys_state___148 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___148 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___148 *dfl_cftypes;
	struct cftype___148 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___148 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___148 *updated_children;
	struct cgroup___148 *updated_next;
};

struct cgroup_root___148 {
	struct kernfs_root___205 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___148 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___148 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___148 *ss;
	struct list_head node;
	struct kernfs_ops___205 *kf_ops;
	int (*open)(struct kernfs_open_file___205 *);
	void (*release)(struct kernfs_open_file___205 *);
	u64 (*read_u64)(struct cgroup_subsys_state___148 *, struct cftype___148 *);
	s64 (*read_s64)(struct cgroup_subsys_state___148 *, struct cftype___148 *);
	int (*seq_show)(struct seq_file___192 *, void *);
	void * (*seq_start)(struct seq_file___192 *, loff_t *);
	void * (*seq_next)(struct seq_file___192 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___192 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___148 *, struct cftype___148 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___148 *, struct cftype___148 *, s64);
	ssize_t (*write)(struct kernfs_open_file___205 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___205 *, struct poll_table_struct___142 *);
};

struct blk_mq_queue_data___110 {
	struct request___113 *rq;
	bool last;
};

struct blkcg_policy_data___105;

struct blkcg___105 {
	struct cgroup_subsys_state___148 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___105 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___105 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___105 {
	struct blkcg___105 *blkcg;
	int plid;
};

struct blkg_policy_data___105 {
	struct blkcg_gq___105 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___94 {
	struct mem_cgroup___94 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___94 {
	struct lruvec___102 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___94 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___94 *memcg;
};

struct obj_cgroup___94 {
	struct percpu_ref refcnt;
	struct mem_cgroup___94 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct Scsi_Host___7;

struct scsi_target___7;

struct scsi_device___7 {
	struct Scsi_Host___7 *host;
	struct request_queue___113 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___7 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___195 sdev_gendev;
	struct device___195 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___224 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_host_template___7;

struct Scsi_Host___7 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___224 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___7 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___110 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___195 shost_gendev;
	struct device___195 shost_dev;
	void *shost_data;
	struct device___195 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_target___7 {
	struct scsi_device___7 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___195 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct scsi_cmnd___7;

struct scsi_host_template___7 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___7 *, struct scsi_cmnd___7 *);
	void (*commit_rqs)(struct Scsi_Host___7 *, u16);
	struct module___201 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___7 *);
	int (*ioctl)(struct scsi_device___7 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___7 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___7 *, struct scsi_cmnd___7 *);
	int (*exit_cmd_priv)(struct Scsi_Host___7 *, struct scsi_cmnd___7 *);
	int (*eh_abort_handler)(struct scsi_cmnd___7 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___7 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___7 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___7 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___7 *);
	int (*slave_alloc)(struct scsi_device___7 *);
	int (*slave_configure)(struct scsi_device___7 *);
	void (*slave_destroy)(struct scsi_device___7 *);
	int (*target_alloc)(struct scsi_target___7 *);
	void (*target_destroy)(struct scsi_target___7 *);
	int (*scan_finished)(struct Scsi_Host___7 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___7 *);
	int (*change_queue_depth)(struct scsi_device___7 *, int);
	int (*map_queues)(struct Scsi_Host___7 *);
	int (*mq_poll)(struct Scsi_Host___7 *, unsigned int);
	bool (*dma_need_drain)(struct request___113 *);
	int (*bios_param)(struct scsi_device___7 *, struct block_device___116 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___7 *);
	int (*show_info)(struct seq_file___192 *, struct Scsi_Host___7 *);
	int (*write_info)(struct Scsi_Host___7 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___7 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___7 *);
	int (*host_reset)(struct Scsi_Host___7 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___30 **shost_attrs;
	struct device_attribute___30 **sdev_attrs;
	const struct attribute_group___205 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_cmnd___7 {
	struct scsi_request req;
	struct scsi_device___7 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___7 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

enum {
	ATA_MAX_DEVICES = 2,
	ATA_MAX_PRD = 256,
	ATA_SECT_SIZE = 512,
	ATA_MAX_SECTORS_128 = 128,
	ATA_MAX_SECTORS = 256,
	ATA_MAX_SECTORS_1024 = 1024,
	ATA_MAX_SECTORS_LBA48 = 65535,
	ATA_MAX_SECTORS_TAPE = 65535,
	ATA_MAX_TRIM_RNUM = 64,
	ATA_ID_WORDS = 256,
	ATA_ID_CONFIG = 0,
	ATA_ID_CYLS = 1,
	ATA_ID_HEADS = 3,
	ATA_ID_SECTORS = 6,
	ATA_ID_SERNO = 10,
	ATA_ID_BUF_SIZE = 21,
	ATA_ID_FW_REV = 23,
	ATA_ID_PROD = 27,
	ATA_ID_MAX_MULTSECT = 47,
	ATA_ID_DWORD_IO = 48,
	ATA_ID_TRUSTED = 48,
	ATA_ID_CAPABILITY = 49,
	ATA_ID_OLD_PIO_MODES = 51,
	ATA_ID_OLD_DMA_MODES = 52,
	ATA_ID_FIELD_VALID = 53,
	ATA_ID_CUR_CYLS = 54,
	ATA_ID_CUR_HEADS = 55,
	ATA_ID_CUR_SECTORS = 56,
	ATA_ID_MULTSECT = 59,
	ATA_ID_LBA_CAPACITY = 60,
	ATA_ID_SWDMA_MODES = 62,
	ATA_ID_MWDMA_MODES = 63,
	ATA_ID_PIO_MODES = 64,
	ATA_ID_EIDE_DMA_MIN = 65,
	ATA_ID_EIDE_DMA_TIME = 66,
	ATA_ID_EIDE_PIO = 67,
	ATA_ID_EIDE_PIO_IORDY = 68,
	ATA_ID_ADDITIONAL_SUPP = 69,
	ATA_ID_QUEUE_DEPTH = 75,
	ATA_ID_SATA_CAPABILITY = 76,
	ATA_ID_SATA_CAPABILITY_2 = 77,
	ATA_ID_FEATURE_SUPP = 78,
	ATA_ID_MAJOR_VER = 80,
	ATA_ID_COMMAND_SET_1 = 82,
	ATA_ID_COMMAND_SET_2 = 83,
	ATA_ID_CFSSE = 84,
	ATA_ID_CFS_ENABLE_1 = 85,
	ATA_ID_CFS_ENABLE_2 = 86,
	ATA_ID_CSF_DEFAULT = 87,
	ATA_ID_UDMA_MODES = 88,
	ATA_ID_HW_CONFIG = 93,
	ATA_ID_SPG = 98,
	ATA_ID_LBA_CAPACITY_2 = 100,
	ATA_ID_SECTOR_SIZE = 106,
	ATA_ID_WWN = 108,
	ATA_ID_LOGICAL_SECTOR_SIZE = 117,
	ATA_ID_COMMAND_SET_3 = 119,
	ATA_ID_COMMAND_SET_4 = 120,
	ATA_ID_LAST_LUN = 126,
	ATA_ID_DLF = 128,
	ATA_ID_CSFO = 129,
	ATA_ID_CFA_POWER = 160,
	ATA_ID_CFA_KEY_MGMT = 162,
	ATA_ID_CFA_MODES = 163,
	ATA_ID_DATA_SET_MGMT = 169,
	ATA_ID_SCT_CMD_XPORT = 206,
	ATA_ID_ROT_SPEED = 217,
	ATA_ID_PIO4 = 2,
	ATA_ID_SERNO_LEN = 20,
	ATA_ID_FW_REV_LEN = 8,
	ATA_ID_PROD_LEN = 40,
	ATA_ID_WWN_LEN = 8,
	ATA_PCI_CTL_OFS = 2,
	ATA_PIO0 = 1,
	ATA_PIO1 = 3,
	ATA_PIO2 = 7,
	ATA_PIO3 = 15,
	ATA_PIO4 = 31,
	ATA_PIO5 = 63,
	ATA_PIO6 = 127,
	ATA_PIO4_ONLY = 16,
	ATA_SWDMA0 = 1,
	ATA_SWDMA1 = 3,
	ATA_SWDMA2 = 7,
	ATA_SWDMA2_ONLY = 4,
	ATA_MWDMA0 = 1,
	ATA_MWDMA1 = 3,
	ATA_MWDMA2 = 7,
	ATA_MWDMA3 = 15,
	ATA_MWDMA4 = 31,
	ATA_MWDMA12_ONLY = 6,
	ATA_MWDMA2_ONLY = 4,
	ATA_UDMA0 = 1,
	ATA_UDMA1 = 3,
	ATA_UDMA2 = 7,
	ATA_UDMA3 = 15,
	ATA_UDMA4 = 31,
	ATA_UDMA5 = 63,
	ATA_UDMA6 = 127,
	ATA_UDMA7 = 255,
	ATA_UDMA24_ONLY = 20,
	ATA_UDMA_MASK_40C = 7,
	ATA_PRD_SZ = 8,
	ATA_PRD_TBL_SZ = 2048,
	ATA_PRD_EOT = 2147483648,
	ATA_DMA_TABLE_OFS = 4,
	ATA_DMA_STATUS = 2,
	ATA_DMA_CMD = 0,
	ATA_DMA_WR = 8,
	ATA_DMA_START = 1,
	ATA_DMA_INTR = 4,
	ATA_DMA_ERR = 2,
	ATA_DMA_ACTIVE = 1,
	ATA_HOB = 128,
	ATA_NIEN = 2,
	ATA_LBA = 64,
	ATA_DEV1 = 16,
	ATA_DEVICE_OBS = 160,
	ATA_DEVCTL_OBS = 8,
	ATA_BUSY = 128,
	ATA_DRDY = 64,
	ATA_DF = 32,
	ATA_DSC = 16,
	ATA_DRQ = 8,
	ATA_CORR = 4,
	ATA_SENSE = 2,
	ATA_ERR = 1,
	ATA_SRST = 4,
	ATA_ICRC = 128,
	ATA_BBK = 128,
	ATA_UNC = 64,
	ATA_MC = 32,
	ATA_IDNF = 16,
	ATA_MCR = 8,
	ATA_ABORTED = 4,
	ATA_TRK0NF = 2,
	ATA_AMNF = 1,
	ATAPI_LFS = 240,
	ATAPI_EOM = 2,
	ATAPI_ILI = 1,
	ATAPI_IO = 2,
	ATAPI_COD = 1,
	ATA_REG_DATA = 0,
	ATA_REG_ERR = 1,
	ATA_REG_NSECT = 2,
	ATA_REG_LBAL = 3,
	ATA_REG_LBAM = 4,
	ATA_REG_LBAH = 5,
	ATA_REG_DEVICE = 6,
	ATA_REG_STATUS = 7,
	ATA_REG_FEATURE = 1,
	ATA_REG_CMD = 7,
	ATA_REG_BYTEL = 4,
	ATA_REG_BYTEH = 5,
	ATA_REG_DEVSEL = 6,
	ATA_REG_IRQ = 2,
	ATA_CMD_DEV_RESET = 8,
	ATA_CMD_CHK_POWER = 229,
	ATA_CMD_STANDBY = 226,
	ATA_CMD_IDLE = 227,
	ATA_CMD_EDD = 144,
	ATA_CMD_DOWNLOAD_MICRO = 146,
	ATA_CMD_DOWNLOAD_MICRO_DMA = 147,
	ATA_CMD_NOP = 0,
	ATA_CMD_FLUSH = 231,
	ATA_CMD_FLUSH_EXT = 234,
	ATA_CMD_ID_ATA = 236,
	ATA_CMD_ID_ATAPI = 161,
	ATA_CMD_SERVICE = 162,
	ATA_CMD_READ = 200,
	ATA_CMD_READ_EXT = 37,
	ATA_CMD_READ_QUEUED = 38,
	ATA_CMD_READ_STREAM_EXT = 43,
	ATA_CMD_READ_STREAM_DMA_EXT = 42,
	ATA_CMD_WRITE = 202,
	ATA_CMD_WRITE_EXT = 53,
	ATA_CMD_WRITE_QUEUED = 54,
	ATA_CMD_WRITE_STREAM_EXT = 59,
	ATA_CMD_WRITE_STREAM_DMA_EXT = 58,
	ATA_CMD_WRITE_FUA_EXT = 61,
	ATA_CMD_WRITE_QUEUED_FUA_EXT = 62,
	ATA_CMD_FPDMA_READ = 96,
	ATA_CMD_FPDMA_WRITE = 97,
	ATA_CMD_NCQ_NON_DATA = 99,
	ATA_CMD_FPDMA_SEND = 100,
	ATA_CMD_FPDMA_RECV = 101,
	ATA_CMD_PIO_READ = 32,
	ATA_CMD_PIO_READ_EXT = 36,
	ATA_CMD_PIO_WRITE = 48,
	ATA_CMD_PIO_WRITE_EXT = 52,
	ATA_CMD_READ_MULTI = 196,
	ATA_CMD_READ_MULTI_EXT = 41,
	ATA_CMD_WRITE_MULTI = 197,
	ATA_CMD_WRITE_MULTI_EXT = 57,
	ATA_CMD_WRITE_MULTI_FUA_EXT = 206,
	ATA_CMD_SET_FEATURES = 239,
	ATA_CMD_SET_MULTI = 198,
	ATA_CMD_PACKET = 160,
	ATA_CMD_VERIFY = 64,
	ATA_CMD_VERIFY_EXT = 66,
	ATA_CMD_WRITE_UNCORR_EXT = 69,
	ATA_CMD_STANDBYNOW1 = 224,
	ATA_CMD_IDLEIMMEDIATE = 225,
	ATA_CMD_SLEEP = 230,
	ATA_CMD_INIT_DEV_PARAMS = 145,
	ATA_CMD_READ_NATIVE_MAX = 248,
	ATA_CMD_READ_NATIVE_MAX_EXT = 39,
	ATA_CMD_SET_MAX = 249,
	ATA_CMD_SET_MAX_EXT = 55,
	ATA_CMD_READ_LOG_EXT = 47,
	ATA_CMD_WRITE_LOG_EXT = 63,
	ATA_CMD_READ_LOG_DMA_EXT = 71,
	ATA_CMD_WRITE_LOG_DMA_EXT = 87,
	ATA_CMD_TRUSTED_NONDATA = 91,
	ATA_CMD_TRUSTED_RCV = 92,
	ATA_CMD_TRUSTED_RCV_DMA = 93,
	ATA_CMD_TRUSTED_SND = 94,
	ATA_CMD_TRUSTED_SND_DMA = 95,
	ATA_CMD_PMP_READ = 228,
	ATA_CMD_PMP_READ_DMA = 233,
	ATA_CMD_PMP_WRITE = 232,
	ATA_CMD_PMP_WRITE_DMA = 235,
	ATA_CMD_CONF_OVERLAY = 177,
	ATA_CMD_SEC_SET_PASS = 241,
	ATA_CMD_SEC_UNLOCK = 242,
	ATA_CMD_SEC_ERASE_PREP = 243,
	ATA_CMD_SEC_ERASE_UNIT = 244,
	ATA_CMD_SEC_FREEZE_LOCK = 245,
	ATA_CMD_SEC_DISABLE_PASS = 246,
	ATA_CMD_CONFIG_STREAM = 81,
	ATA_CMD_SMART = 176,
	ATA_CMD_MEDIA_LOCK = 222,
	ATA_CMD_MEDIA_UNLOCK = 223,
	ATA_CMD_DSM = 6,
	ATA_CMD_CHK_MED_CRD_TYP = 209,
	ATA_CMD_CFA_REQ_EXT_ERR = 3,
	ATA_CMD_CFA_WRITE_NE = 56,
	ATA_CMD_CFA_TRANS_SECT = 135,
	ATA_CMD_CFA_ERASE = 192,
	ATA_CMD_CFA_WRITE_MULT_NE = 205,
	ATA_CMD_REQ_SENSE_DATA = 11,
	ATA_CMD_SANITIZE_DEVICE = 180,
	ATA_CMD_ZAC_MGMT_IN = 74,
	ATA_CMD_ZAC_MGMT_OUT = 159,
	ATA_CMD_RESTORE = 16,
	ATA_SUBCMD_FPDMA_RECV_RD_LOG_DMA_EXT = 1,
	ATA_SUBCMD_FPDMA_RECV_ZAC_MGMT_IN = 2,
	ATA_SUBCMD_FPDMA_SEND_DSM = 0,
	ATA_SUBCMD_FPDMA_SEND_WR_LOG_DMA_EXT = 2,
	ATA_SUBCMD_NCQ_NON_DATA_ABORT_QUEUE = 0,
	ATA_SUBCMD_NCQ_NON_DATA_SET_FEATURES = 5,
	ATA_SUBCMD_NCQ_NON_DATA_ZERO_EXT = 6,
	ATA_SUBCMD_NCQ_NON_DATA_ZAC_MGMT_OUT = 7,
	ATA_SUBCMD_ZAC_MGMT_IN_REPORT_ZONES = 0,
	ATA_SUBCMD_ZAC_MGMT_OUT_CLOSE_ZONE = 1,
	ATA_SUBCMD_ZAC_MGMT_OUT_FINISH_ZONE = 2,
	ATA_SUBCMD_ZAC_MGMT_OUT_OPEN_ZONE = 3,
	ATA_SUBCMD_ZAC_MGMT_OUT_RESET_WRITE_POINTER = 4,
	ATA_LOG_DIRECTORY = 0,
	ATA_LOG_SATA_NCQ = 16,
	ATA_LOG_NCQ_NON_DATA = 18,
	ATA_LOG_NCQ_SEND_RECV = 19,
	ATA_LOG_IDENTIFY_DEVICE = 48,
	ATA_LOG_SECURITY = 6,
	ATA_LOG_SATA_SETTINGS = 8,
	ATA_LOG_ZONED_INFORMATION = 9,
	ATA_LOG_DEVSLP_OFFSET = 48,
	ATA_LOG_DEVSLP_SIZE = 8,
	ATA_LOG_DEVSLP_MDAT = 0,
	ATA_LOG_DEVSLP_MDAT_MASK = 31,
	ATA_LOG_DEVSLP_DETO = 1,
	ATA_LOG_DEVSLP_VALID = 7,
	ATA_LOG_DEVSLP_VALID_MASK = 128,
	ATA_LOG_NCQ_PRIO_OFFSET = 9,
	ATA_LOG_NCQ_SEND_RECV_SUBCMDS_OFFSET = 0,
	ATA_LOG_NCQ_SEND_RECV_SUBCMDS_DSM = 1,
	ATA_LOG_NCQ_SEND_RECV_DSM_OFFSET = 4,
	ATA_LOG_NCQ_SEND_RECV_DSM_TRIM = 1,
	ATA_LOG_NCQ_SEND_RECV_RD_LOG_OFFSET = 8,
	ATA_LOG_NCQ_SEND_RECV_RD_LOG_SUPPORTED = 1,
	ATA_LOG_NCQ_SEND_RECV_WR_LOG_OFFSET = 12,
	ATA_LOG_NCQ_SEND_RECV_WR_LOG_SUPPORTED = 1,
	ATA_LOG_NCQ_SEND_RECV_ZAC_MGMT_OFFSET = 16,
	ATA_LOG_NCQ_SEND_RECV_ZAC_MGMT_OUT_SUPPORTED = 1,
	ATA_LOG_NCQ_SEND_RECV_ZAC_MGMT_IN_SUPPORTED = 2,
	ATA_LOG_NCQ_SEND_RECV_SIZE = 20,
	ATA_LOG_NCQ_NON_DATA_SUBCMDS_OFFSET = 0,
	ATA_LOG_NCQ_NON_DATA_ABORT_OFFSET = 0,
	ATA_LOG_NCQ_NON_DATA_ABORT_NCQ = 1,
	ATA_LOG_NCQ_NON_DATA_ABORT_ALL = 2,
	ATA_LOG_NCQ_NON_DATA_ABORT_STREAMING = 4,
	ATA_LOG_NCQ_NON_DATA_ABORT_NON_STREAMING = 8,
	ATA_LOG_NCQ_NON_DATA_ABORT_SELECTED = 16,
	ATA_LOG_NCQ_NON_DATA_ZAC_MGMT_OFFSET = 28,
	ATA_LOG_NCQ_NON_DATA_ZAC_MGMT_OUT = 1,
	ATA_LOG_NCQ_NON_DATA_SIZE = 64,
	ATA_CMD_READ_LONG = 34,
	ATA_CMD_READ_LONG_ONCE = 35,
	ATA_CMD_WRITE_LONG = 50,
	ATA_CMD_WRITE_LONG_ONCE = 51,
	SETFEATURES_XFER = 3,
	XFER_UDMA_7 = 71,
	XFER_UDMA_6 = 70,
	XFER_UDMA_5 = 69,
	XFER_UDMA_4 = 68,
	XFER_UDMA_3 = 67,
	XFER_UDMA_2 = 66,
	XFER_UDMA_1 = 65,
	XFER_UDMA_0 = 64,
	XFER_MW_DMA_4 = 36,
	XFER_MW_DMA_3 = 35,
	XFER_MW_DMA_2 = 34,
	XFER_MW_DMA_1 = 33,
	XFER_MW_DMA_0 = 32,
	XFER_SW_DMA_2 = 18,
	XFER_SW_DMA_1 = 17,
	XFER_SW_DMA_0 = 16,
	XFER_PIO_6 = 14,
	XFER_PIO_5 = 13,
	XFER_PIO_4 = 12,
	XFER_PIO_3 = 11,
	XFER_PIO_2 = 10,
	XFER_PIO_1 = 9,
	XFER_PIO_0 = 8,
	XFER_PIO_SLOW = 0,
	SETFEATURES_WC_ON = 2,
	SETFEATURES_WC_OFF = 130,
	SETFEATURES_RA_ON = 170,
	SETFEATURES_RA_OFF = 85,
	SETFEATURES_AAM_ON = 66,
	SETFEATURES_AAM_OFF = 194,
	SETFEATURES_SPINUP = 7,
	SETFEATURES_SPINUP_TIMEOUT = 30000,
	SETFEATURES_SATA_ENABLE = 16,
	SETFEATURES_SATA_DISABLE = 144,
	SATA_FPDMA_OFFSET = 1,
	SATA_FPDMA_AA = 2,
	SATA_DIPM = 3,
	SATA_FPDMA_IN_ORDER = 4,
	SATA_AN = 5,
	SATA_SSP = 6,
	SATA_DEVSLP = 9,
	SETFEATURE_SENSE_DATA = 195,
	ATA_SET_MAX_ADDR = 0,
	ATA_SET_MAX_PASSWD = 1,
	ATA_SET_MAX_LOCK = 2,
	ATA_SET_MAX_UNLOCK = 3,
	ATA_SET_MAX_FREEZE_LOCK = 4,
	ATA_SET_MAX_PASSWD_DMA = 5,
	ATA_SET_MAX_UNLOCK_DMA = 6,
	ATA_DCO_RESTORE = 192,
	ATA_DCO_FREEZE_LOCK = 193,
	ATA_DCO_IDENTIFY = 194,
	ATA_DCO_SET = 195,
	ATA_SMART_ENABLE = 216,
	ATA_SMART_READ_VALUES = 208,
	ATA_SMART_READ_THRESHOLDS = 209,
	ATA_DSM_TRIM = 1,
	ATA_SMART_LBAM_PASS = 79,
	ATA_SMART_LBAH_PASS = 194,
	ATAPI_PKT_DMA = 1,
	ATAPI_DMADIR = 4,
	ATAPI_CDB_LEN = 16,
	SATA_PMP_MAX_PORTS = 15,
	SATA_PMP_CTRL_PORT = 15,
	SATA_PMP_GSCR_DWORDS = 128,
	SATA_PMP_GSCR_PROD_ID = 0,
	SATA_PMP_GSCR_REV = 1,
	SATA_PMP_GSCR_PORT_INFO = 2,
	SATA_PMP_GSCR_ERROR = 32,
	SATA_PMP_GSCR_ERROR_EN = 33,
	SATA_PMP_GSCR_FEAT = 64,
	SATA_PMP_GSCR_FEAT_EN = 96,
	SATA_PMP_PSCR_STATUS = 0,
	SATA_PMP_PSCR_ERROR = 1,
	SATA_PMP_PSCR_CONTROL = 2,
	SATA_PMP_FEAT_BIST = 1,
	SATA_PMP_FEAT_PMREQ = 2,
	SATA_PMP_FEAT_DYNSSC = 4,
	SATA_PMP_FEAT_NOTIFY = 8,
	ATA_CBL_NONE = 0,
	ATA_CBL_PATA40 = 1,
	ATA_CBL_PATA80 = 2,
	ATA_CBL_PATA40_SHORT = 3,
	ATA_CBL_PATA_UNK = 4,
	ATA_CBL_PATA_IGN = 5,
	ATA_CBL_SATA = 6,
	SCR_STATUS = 0,
	SCR_ERROR = 1,
	SCR_CONTROL = 2,
	SCR_ACTIVE = 3,
	SCR_NOTIFICATION = 4,
	SERR_DATA_RECOVERED = 1,
	SERR_COMM_RECOVERED = 2,
	SERR_DATA = 256,
	SERR_PERSISTENT = 512,
	SERR_PROTOCOL = 1024,
	SERR_INTERNAL = 2048,
	SERR_PHYRDY_CHG = 65536,
	SERR_PHY_INT_ERR = 131072,
	SERR_COMM_WAKE = 262144,
	SERR_10B_8B_ERR = 524288,
	SERR_DISPARITY = 1048576,
	SERR_CRC = 2097152,
	SERR_HANDSHAKE = 4194304,
	SERR_LINK_SEQ_ERR = 8388608,
	SERR_TRANS_ST_ERROR = 16777216,
	SERR_UNRECOG_FIS = 33554432,
	SERR_DEV_XCHG = 67108864,
};

enum ata_prot_flags {
	ATA_PROT_FLAG_PIO = 1,
	ATA_PROT_FLAG_DMA = 2,
	ATA_PROT_FLAG_NCQ = 4,
	ATA_PROT_FLAG_ATAPI = 8,
	ATA_PROT_UNKNOWN = 255,
	ATA_PROT_NODATA = 0,
	ATA_PROT_PIO = 1,
	ATA_PROT_DMA = 2,
	ATA_PROT_NCQ_NODATA = 4,
	ATA_PROT_NCQ = 6,
	ATAPI_PROT_NODATA = 8,
	ATAPI_PROT_PIO = 9,
	ATAPI_PROT_DMA = 10,
};

struct ata_bmdma_prd {
	__le32 addr;
	__le32 flags_len;
};

struct property___60 {
	char *name;
	int length;
	void *value;
	struct property___60 *next;
	long unsigned int _flags;
	struct bin_attribute___205 attr;
};

struct irq_fwspec___48 {
	struct fwnode_handle___191 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___50 {
	int (*match)(struct irq_domain___50 *, struct device_node___83 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___50 *, struct irq_fwspec___48 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___50 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___50 *, unsigned int);
	int (*xlate)(struct irq_domain___50 *, struct device_node___83 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___50 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___50 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___50 *, struct irq_data___52 *, bool);
	void (*deactivate)(struct irq_domain___50 *, struct irq_data___52 *);
	int (*translate)(struct irq_domain___50 *, struct irq_fwspec___48 *, long unsigned int *, unsigned int *);
};

struct cdrom_device_ops___3 {
	int (*open)(struct cdrom_device_info___3 *, int);
	void (*release)(struct cdrom_device_info___3 *);
	int (*drive_status)(struct cdrom_device_info___3 *, int);
	unsigned int (*check_events)(struct cdrom_device_info___3 *, unsigned int, int);
	int (*tray_move)(struct cdrom_device_info___3 *, int);
	int (*lock_door)(struct cdrom_device_info___3 *, int);
	int (*select_speed)(struct cdrom_device_info___3 *, int);
	int (*select_disc)(struct cdrom_device_info___3 *, int);
	int (*get_last_session)(struct cdrom_device_info___3 *, struct cdrom_multisession *);
	int (*get_mcn)(struct cdrom_device_info___3 *, struct cdrom_mcn *);
	int (*reset)(struct cdrom_device_info___3 *);
	int (*audio_ioctl)(struct cdrom_device_info___3 *, unsigned int, void *);
	int (*generic_packet)(struct cdrom_device_info___3 *, struct packet_command *);
	int (*read_cdda_bpc)(struct cdrom_device_info___3 *, void *, u32, u32, u8 *);
	const int capability;
};

enum {
	ATA_MSG_DRV = 1,
	ATA_MSG_INFO = 2,
	ATA_MSG_PROBE = 4,
	ATA_MSG_WARN = 8,
	ATA_MSG_MALLOC = 16,
	ATA_MSG_CTL = 32,
	ATA_MSG_INTR = 64,
	ATA_MSG_ERR = 128,
};

enum {
	LIBATA_MAX_PRD = 128,
	LIBATA_DUMB_MAX_PRD = 64,
	ATA_DEF_QUEUE = 1,
	ATA_MAX_QUEUE = 32,
	ATA_TAG_INTERNAL = 32,
	ATA_SHORT_PAUSE = 16,
	ATAPI_MAX_DRAIN = 16384,
	ATA_ALL_DEVICES = 3,
	ATA_SHT_EMULATED = 1,
	ATA_SHT_THIS_ID = 4294967295,
	ATA_TFLAG_LBA48 = 1,
	ATA_TFLAG_ISADDR = 2,
	ATA_TFLAG_DEVICE = 4,
	ATA_TFLAG_WRITE = 8,
	ATA_TFLAG_LBA = 16,
	ATA_TFLAG_FUA = 32,
	ATA_TFLAG_POLLING = 64,
	ATA_DFLAG_LBA = 1,
	ATA_DFLAG_LBA48 = 2,
	ATA_DFLAG_CDB_INTR = 4,
	ATA_DFLAG_NCQ = 8,
	ATA_DFLAG_FLUSH_EXT = 16,
	ATA_DFLAG_ACPI_PENDING = 32,
	ATA_DFLAG_ACPI_FAILED = 64,
	ATA_DFLAG_AN = 128,
	ATA_DFLAG_TRUSTED = 256,
	ATA_DFLAG_DMADIR = 1024,
	ATA_DFLAG_CFG_MASK = 4095,
	ATA_DFLAG_PIO = 4096,
	ATA_DFLAG_NCQ_OFF = 8192,
	ATA_DFLAG_SLEEPING = 32768,
	ATA_DFLAG_DUBIOUS_XFER = 65536,
	ATA_DFLAG_NO_UNLOAD = 131072,
	ATA_DFLAG_UNLOCK_HPA = 262144,
	ATA_DFLAG_NCQ_SEND_RECV = 524288,
	ATA_DFLAG_NCQ_PRIO = 1048576,
	ATA_DFLAG_NCQ_PRIO_ENABLE = 2097152,
	ATA_DFLAG_INIT_MASK = 16777215,
	ATA_DFLAG_DETACH = 16777216,
	ATA_DFLAG_DETACHED = 33554432,
	ATA_DFLAG_DA = 67108864,
	ATA_DFLAG_DEVSLP = 134217728,
	ATA_DFLAG_ACPI_DISABLED = 268435456,
	ATA_DFLAG_D_SENSE = 536870912,
	ATA_DFLAG_ZAC = 1073741824,
	ATA_DFLAG_FEATURES_MASK = 202899712,
	ATA_DEV_UNKNOWN = 0,
	ATA_DEV_ATA = 1,
	ATA_DEV_ATA_UNSUP = 2,
	ATA_DEV_ATAPI = 3,
	ATA_DEV_ATAPI_UNSUP = 4,
	ATA_DEV_PMP = 5,
	ATA_DEV_PMP_UNSUP = 6,
	ATA_DEV_SEMB = 7,
	ATA_DEV_SEMB_UNSUP = 8,
	ATA_DEV_ZAC = 9,
	ATA_DEV_ZAC_UNSUP = 10,
	ATA_DEV_NONE = 11,
	ATA_LFLAG_NO_HRST = 2,
	ATA_LFLAG_NO_SRST = 4,
	ATA_LFLAG_ASSUME_ATA = 8,
	ATA_LFLAG_ASSUME_SEMB = 16,
	ATA_LFLAG_ASSUME_CLASS = 24,
	ATA_LFLAG_NO_RETRY = 32,
	ATA_LFLAG_DISABLED = 64,
	ATA_LFLAG_SW_ACTIVITY = 128,
	ATA_LFLAG_NO_LPM = 256,
	ATA_LFLAG_RST_ONCE = 512,
	ATA_LFLAG_CHANGED = 1024,
	ATA_LFLAG_NO_DB_DELAY = 2048,
	ATA_FLAG_SLAVE_POSS = 1,
	ATA_FLAG_SATA = 2,
	ATA_FLAG_NO_LPM = 4,
	ATA_FLAG_NO_LOG_PAGE = 32,
	ATA_FLAG_NO_ATAPI = 64,
	ATA_FLAG_PIO_DMA = 128,
	ATA_FLAG_PIO_LBA48 = 256,
	ATA_FLAG_PIO_POLLING = 512,
	ATA_FLAG_NCQ = 1024,
	ATA_FLAG_NO_POWEROFF_SPINDOWN = 2048,
	ATA_FLAG_NO_HIBERNATE_SPINDOWN = 4096,
	ATA_FLAG_DEBUGMSG = 8192,
	ATA_FLAG_FPDMA_AA = 16384,
	ATA_FLAG_IGN_SIMPLEX = 32768,
	ATA_FLAG_NO_IORDY = 65536,
	ATA_FLAG_ACPI_SATA = 131072,
	ATA_FLAG_AN = 262144,
	ATA_FLAG_PMP = 524288,
	ATA_FLAG_FPDMA_AUX = 1048576,
	ATA_FLAG_EM = 2097152,
	ATA_FLAG_SW_ACTIVITY = 4194304,
	ATA_FLAG_NO_DIPM = 8388608,
	ATA_FLAG_SAS_HOST = 16777216,
	ATA_PFLAG_EH_PENDING = 1,
	ATA_PFLAG_EH_IN_PROGRESS = 2,
	ATA_PFLAG_FROZEN = 4,
	ATA_PFLAG_RECOVERED = 8,
	ATA_PFLAG_LOADING = 16,
	ATA_PFLAG_SCSI_HOTPLUG = 64,
	ATA_PFLAG_INITIALIZING = 128,
	ATA_PFLAG_RESETTING = 256,
	ATA_PFLAG_UNLOADING = 512,
	ATA_PFLAG_UNLOADED = 1024,
	ATA_PFLAG_SUSPENDED = 131072,
	ATA_PFLAG_PM_PENDING = 262144,
	ATA_PFLAG_INIT_GTM_VALID = 524288,
	ATA_PFLAG_PIO32 = 1048576,
	ATA_PFLAG_PIO32CHANGE = 2097152,
	ATA_PFLAG_EXTERNAL = 4194304,
	ATA_QCFLAG_ACTIVE = 1,
	ATA_QCFLAG_DMAMAP = 2,
	ATA_QCFLAG_IO = 8,
	ATA_QCFLAG_RESULT_TF = 16,
	ATA_QCFLAG_CLEAR_EXCL = 32,
	ATA_QCFLAG_QUIET = 64,
	ATA_QCFLAG_RETRY = 128,
	ATA_QCFLAG_FAILED = 65536,
	ATA_QCFLAG_SENSE_VALID = 131072,
	ATA_QCFLAG_EH_SCHEDULED = 262144,
	ATA_HOST_SIMPLEX = 1,
	ATA_HOST_STARTED = 2,
	ATA_HOST_PARALLEL_SCAN = 4,
	ATA_HOST_IGNORE_ATA = 8,
	ATA_TMOUT_BOOT = 30000,
	ATA_TMOUT_BOOT_QUICK = 7000,
	ATA_TMOUT_INTERNAL_QUICK = 5000,
	ATA_TMOUT_MAX_PARK = 30000,
	ATA_TMOUT_FF_WAIT_LONG = 2000,
	ATA_TMOUT_FF_WAIT = 800,
	ATA_WAIT_AFTER_RESET = 150,
	ATA_TMOUT_PMP_SRST_WAIT = 5000,
	ATA_TMOUT_SPURIOUS_PHY = 10000,
	BUS_UNKNOWN = 0,
	BUS_DMA = 1,
	BUS_IDLE = 2,
	BUS_NOINTR = 3,
	BUS_NODATA = 4,
	BUS_TIMER = 5,
	BUS_PIO = 6,
	BUS_EDD = 7,
	BUS_IDENTIFY = 8,
	BUS_PACKET = 9,
	PORT_UNKNOWN = 0,
	PORT_ENABLED = 1,
	PORT_DISABLED = 2,
	ATA_NR_PIO_MODES = 7,
	ATA_NR_MWDMA_MODES = 5,
	ATA_NR_UDMA_MODES = 8,
	ATA_SHIFT_PIO = 0,
	ATA_SHIFT_MWDMA = 7,
	ATA_SHIFT_UDMA = 12,
	ATA_SHIFT_PRIO = 6,
	ATA_PRIO_HIGH = 2,
	ATA_DMA_PAD_SZ = 4,
	ATA_ERING_SIZE = 32,
	ATA_DEFER_LINK = 1,
	ATA_DEFER_PORT = 2,
	ATA_EH_DESC_LEN = 80,
	ATA_EH_REVALIDATE = 1,
	ATA_EH_SOFTRESET = 2,
	ATA_EH_HARDRESET = 4,
	ATA_EH_RESET = 6,
	ATA_EH_ENABLE_LINK = 8,
	ATA_EH_PARK = 32,
	ATA_EH_PERDEV_MASK = 33,
	ATA_EH_ALL_ACTIONS = 15,
	ATA_EHI_HOTPLUGGED = 1,
	ATA_EHI_NO_AUTOPSY = 4,
	ATA_EHI_QUIET = 8,
	ATA_EHI_NO_RECOVERY = 16,
	ATA_EHI_DID_SOFTRESET = 65536,
	ATA_EHI_DID_HARDRESET = 131072,
	ATA_EHI_PRINTINFO = 262144,
	ATA_EHI_SETMODE = 524288,
	ATA_EHI_POST_SETMODE = 1048576,
	ATA_EHI_DID_RESET = 196608,
	ATA_EHI_TO_SLAVE_MASK = 12,
	ATA_EH_MAX_TRIES = 5,
	ATA_LINK_RESUME_TRIES = 5,
	ATA_PROBE_MAX_TRIES = 3,
	ATA_EH_DEV_TRIES = 3,
	ATA_EH_PMP_TRIES = 5,
	ATA_EH_PMP_LINK_TRIES = 3,
	SATA_PMP_RW_TIMEOUT = 3000,
	ATA_EH_CMD_TIMEOUT_TABLE_SIZE = 7,
	ATA_HORKAGE_DIAGNOSTIC = 1,
	ATA_HORKAGE_NODMA = 2,
	ATA_HORKAGE_NONCQ = 4,
	ATA_HORKAGE_MAX_SEC_128 = 8,
	ATA_HORKAGE_BROKEN_HPA = 16,
	ATA_HORKAGE_DISABLE = 32,
	ATA_HORKAGE_HPA_SIZE = 64,
	ATA_HORKAGE_IVB = 256,
	ATA_HORKAGE_STUCK_ERR = 512,
	ATA_HORKAGE_BRIDGE_OK = 1024,
	ATA_HORKAGE_ATAPI_MOD16_DMA = 2048,
	ATA_HORKAGE_FIRMWARE_WARN = 4096,
	ATA_HORKAGE_1_5_GBPS = 8192,
	ATA_HORKAGE_NOSETXFER = 16384,
	ATA_HORKAGE_BROKEN_FPDMA_AA = 32768,
	ATA_HORKAGE_DUMP_ID = 65536,
	ATA_HORKAGE_MAX_SEC_LBA48 = 131072,
	ATA_HORKAGE_ATAPI_DMADIR = 262144,
	ATA_HORKAGE_NO_NCQ_TRIM = 524288,
	ATA_HORKAGE_NOLPM = 1048576,
	ATA_HORKAGE_WD_BROKEN_LPM = 2097152,
	ATA_HORKAGE_ZERO_AFTER_TRIM = 4194304,
	ATA_HORKAGE_NO_DMA_LOG = 8388608,
	ATA_HORKAGE_NOTRIM = 16777216,
	ATA_HORKAGE_MAX_SEC_1024 = 33554432,
	ATA_HORKAGE_MAX_TRIM_128M = 67108864,
	ATA_HORKAGE_NO_NCQ_ON_ATI = 134217728,
	ATA_DMA_MASK_ATA = 1,
	ATA_DMA_MASK_ATAPI = 2,
	ATA_DMA_MASK_CFA = 4,
	ATAPI_READ = 0,
	ATAPI_WRITE = 1,
	ATAPI_READ_CD = 2,
	ATAPI_PASS_THRU = 3,
	ATAPI_MISC = 4,
	ATA_TIMING_SETUP = 1,
	ATA_TIMING_ACT8B = 2,
	ATA_TIMING_REC8B = 4,
	ATA_TIMING_CYC8B = 8,
	ATA_TIMING_8BIT = 14,
	ATA_TIMING_ACTIVE = 16,
	ATA_TIMING_RECOVER = 32,
	ATA_TIMING_DMACK_HOLD = 64,
	ATA_TIMING_CYCLE = 128,
	ATA_TIMING_UDMA = 256,
	ATA_TIMING_ALL = 511,
	ATA_ACPI_FILTER_SETXFER = 1,
	ATA_ACPI_FILTER_LOCK = 2,
	ATA_ACPI_FILTER_DIPM = 4,
	ATA_ACPI_FILTER_FPDMA_OFFSET = 8,
	ATA_ACPI_FILTER_FPDMA_AA = 16,
	ATA_ACPI_FILTER_DEFAULT = 7,
};

enum ata_xfer_mask {
	ATA_MASK_PIO = 127,
	ATA_MASK_MWDMA = 3968,
	ATA_MASK_UDMA = 1044480,
};

enum ata_completion_errors {
	AC_ERR_OK = 0,
	AC_ERR_DEV = 1,
	AC_ERR_HSM = 2,
	AC_ERR_TIMEOUT = 4,
	AC_ERR_MEDIA = 8,
	AC_ERR_ATA_BUS = 16,
	AC_ERR_HOST_BUS = 32,
	AC_ERR_SYSTEM = 64,
	AC_ERR_INVALID = 128,
	AC_ERR_OTHER = 256,
	AC_ERR_NODEV_HINT = 512,
	AC_ERR_NCQ = 1024,
};

enum ata_lpm_policy {
	ATA_LPM_UNKNOWN = 0,
	ATA_LPM_MAX_POWER = 1,
	ATA_LPM_MED_POWER = 2,
	ATA_LPM_MED_POWER_WITH_DIPM = 3,
	ATA_LPM_MIN_POWER_WITH_PARTIAL = 4,
	ATA_LPM_MIN_POWER = 5,
};

struct ata_queued_cmd;

typedef void (*ata_qc_cb_t)(struct ata_queued_cmd *);

struct ata_taskfile {
	long unsigned int flags;
	u8 protocol;
	u8 ctl;
	u8 hob_feature;
	u8 hob_nsect;
	u8 hob_lbal;
	u8 hob_lbam;
	u8 hob_lbah;
	u8 feature;
	u8 nsect;
	u8 lbal;
	u8 lbam;
	u8 lbah;
	u8 device;
	u8 command;
	u32 auxiliary;
};

struct ata_port;

struct ata_device;

struct ata_queued_cmd {
	struct ata_port *ap;
	struct ata_device *dev;
	struct scsi_cmnd___7 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___7 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link;

typedef int (*ata_prereset_fn_t)(struct ata_link *, long unsigned int);

struct ata_eh_info {
	struct ata_device *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context {
	struct ata_eh_info i;
	int tries[2];
	int cmd_timeout_idx[14];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_ering_entry {
	unsigned int eflags;
	unsigned int err_mask;
	u64 timestamp;
};

struct ata_ering {
	int cursor;
	struct ata_ering_entry ring[32];
};

struct ata_device {
	struct ata_link *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___7 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	void *zpodd;
	struct device___195 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link {
	struct ata_port *ap;
	int pmp;
	struct device___195 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info eh_info;
	struct ata_eh_context eh_context;
	long: 64;
	struct ata_device device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t)(struct ata_link *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t)(struct ata_link *, unsigned int *);

enum sw_activity {
	OFF___2 = 0,
	BLINK_ON = 1,
	BLINK_OFF = 2,
};

struct ata_ioports {
	void *cmd_addr;
	void *data_addr;
	void *error_addr;
	void *feature_addr;
	void *nsect_addr;
	void *lbal_addr;
	void *lbam_addr;
	void *lbah_addr;
	void *device_addr;
	void *status_addr;
	void *command_addr;
	void *altstatus_addr;
	void *ctl_addr;
	void *bmdma_addr;
	void *scr_addr;
};

struct ata_port_operations;

struct ata_host {
	spinlock_t lock;
	struct device___195 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___224 *eh_owner;
	struct ata_port *simplex_claimed;
	struct ata_port *ports[0];
};

struct ata_port_operations {
	int (*qc_defer)(struct ata_queued_cmd *);
	int (*check_atapi_dma)(struct ata_queued_cmd *);
	enum ata_completion_errors (*qc_prep)(struct ata_queued_cmd *);
	unsigned int (*qc_issue)(struct ata_queued_cmd *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd *);
	int (*cable_detect)(struct ata_port *);
	long unsigned int (*mode_filter)(struct ata_device *, long unsigned int);
	void (*set_piomode)(struct ata_port *, struct ata_device *);
	void (*set_dmamode)(struct ata_port *, struct ata_device *);
	int (*set_mode)(struct ata_link *, struct ata_device **);
	unsigned int (*read_id)(struct ata_device *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device *);
	void (*freeze)(struct ata_port *);
	void (*thaw)(struct ata_port *);
	ata_prereset_fn_t prereset;
	ata_reset_fn_t softreset;
	ata_reset_fn_t hardreset;
	ata_postreset_fn_t postreset;
	ata_prereset_fn_t pmp_prereset;
	ata_reset_fn_t pmp_softreset;
	ata_reset_fn_t pmp_hardreset;
	ata_postreset_fn_t pmp_postreset;
	void (*error_handler)(struct ata_port *);
	void (*lost_interrupt)(struct ata_port *);
	void (*post_internal_cmd)(struct ata_queued_cmd *);
	void (*sched_eh)(struct ata_port *);
	void (*end_eh)(struct ata_port *);
	int (*scr_read)(struct ata_link *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port *);
	void (*pmp_detach)(struct ata_port *);
	int (*set_lpm)(struct ata_link *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port *, pm_message_t);
	int (*port_resume)(struct ata_port *);
	int (*port_start)(struct ata_port *);
	void (*port_stop)(struct ata_port *);
	void (*host_stop)(struct ata_host *);
	void (*sff_dev_select)(struct ata_port *, unsigned int);
	void (*sff_set_devctl)(struct ata_port *, u8);
	u8 (*sff_check_status)(struct ata_port *);
	u8 (*sff_check_altstatus)(struct ata_port *);
	void (*sff_tf_load)(struct ata_port *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port *);
	bool (*sff_irq_check)(struct ata_port *);
	void (*sff_irq_clear)(struct ata_port *);
	void (*sff_drain_fifo)(struct ata_queued_cmd *);
	void (*bmdma_setup)(struct ata_queued_cmd *);
	void (*bmdma_start)(struct ata_queued_cmd *);
	void (*bmdma_stop)(struct ata_queued_cmd *);
	u8 (*bmdma_status)(struct ata_port *);
	ssize_t (*em_show)(struct ata_port *, char *);
	ssize_t (*em_store)(struct ata_port *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device *, char *);
	ssize_t (*sw_activity_store)(struct ata_device *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port *, u32, ssize_t);
	void (*phy_reset)(struct ata_port *);
	void (*eng_timeout)(struct ata_port *);
	const struct ata_port_operations *inherits;
};

struct ata_port_stats {
	long unsigned int unhandled_irq;
	long unsigned int idle_irq;
	long unsigned int rw_reqbuf;
};

struct ata_acpi_drive {
	u32 pio;
	u32 dma;
};

struct ata_acpi_gtm {
	struct ata_acpi_drive drive[2];
	u32 flags;
};

struct ata_port {
	struct Scsi_Host___7 *scsi_host;
	struct ata_port_operations *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	struct ata_link link;
	struct ata_link *slave_link;
	int nr_pmp_links;
	struct ata_link *pmp_link;
	struct ata_link *excl_link;
	struct ata_port_stats stats;
	struct ata_host *host;
	struct device___195 *dev;
	struct device___195 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	async_cookie_t cookie;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations *port_ops;
	void *private_data;
};

struct ata_timing {
	short unsigned int mode;
	short unsigned int setup;
	short unsigned int act8b;
	short unsigned int rec8b;
	short unsigned int cyc8b;
	short unsigned int active;
	short unsigned int recover;
	short unsigned int dmack_hold;
	short unsigned int cycle;
	short unsigned int udma;
};

struct pci_bits {
	unsigned int reg;
	unsigned int width;
	long unsigned int mask;
	long unsigned int val;
};

enum ata_link_iter_mode {
	ATA_LITER_EDGE = 0,
	ATA_LITER_HOST_FIRST = 1,
	ATA_LITER_PMP_FIRST = 2,
};

enum ata_dev_iter_mode {
	ATA_DITER_ENABLED = 0,
	ATA_DITER_ENABLED_REVERSE = 1,
	ATA_DITER_ALL = 2,
	ATA_DITER_ALL_REVERSE = 3,
};

struct platform_device___34 {
	const char *name;
	int id;
	bool id_auto;
	struct device___195 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct perf_cpu_context___79;

struct perf_output_handle___79;

struct pmu___79 {
	struct list_head entry;
	struct module___201 *module;
	struct device___195 *dev;
	const struct attribute_group___205 **attr_groups;
	const struct attribute_group___205 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___79 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___79 *);
	void (*pmu_disable)(struct pmu___79 *);
	int (*event_init)(struct perf_event___79 *);
	void (*event_mapped)(struct perf_event___79 *, struct mm_struct___223 *);
	void (*event_unmapped)(struct perf_event___79 *, struct mm_struct___223 *);
	int (*add)(struct perf_event___79 *, int);
	void (*del)(struct perf_event___79 *, int);
	void (*start)(struct perf_event___79 *, int);
	void (*stop)(struct perf_event___79 *, int);
	void (*read)(struct perf_event___79 *);
	void (*start_txn)(struct pmu___79 *, unsigned int);
	int (*commit_txn)(struct pmu___79 *);
	void (*cancel_txn)(struct pmu___79 *);
	int (*event_idx)(struct perf_event___79 *);
	void (*sched_task)(struct perf_event_context___79 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___79 *, struct perf_event_context___79 *);
	void * (*setup_aux)(struct perf_event___79 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___79 *, struct perf_output_handle___79 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___79 *);
	int (*aux_output_match)(struct perf_event___79 *);
	int (*filter_match)(struct perf_event___79 *);
	int (*check_period)(struct perf_event___79 *, u64);
};

struct perf_cpu_context___79 {
	struct perf_event_context___79 ctx;
	struct perf_event_context___79 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___79 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___79 **heap;
	struct perf_event___79 *heap_default[2];
};

struct perf_output_handle___79 {
	struct perf_event___79 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___79 {
	struct cgroup_subsys_state___148 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___73 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___73 *);
	};
};

struct trace_event_class___73 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___73 *, enum trace_reg, void *);
	struct trace_event_fields___73 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___73 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___73 *);
};

struct trace_event_file___32;

struct trace_event_buffer___31 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___32 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___32 {
	struct list_head list;
	struct trace_event_call___73 *event_call;
	struct event_filter *filter;
	struct dentry___217 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_ata_qc_issue {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int tag;
	unsigned char cmd;
	unsigned char dev;
	unsigned char lbal;
	unsigned char lbam;
	unsigned char lbah;
	unsigned char nsect;
	unsigned char feature;
	unsigned char hob_lbal;
	unsigned char hob_lbam;
	unsigned char hob_lbah;
	unsigned char hob_nsect;
	unsigned char hob_feature;
	unsigned char ctl;
	unsigned char proto;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ata_qc_complete_template {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int tag;
	unsigned char status;
	unsigned char dev;
	unsigned char lbal;
	unsigned char lbam;
	unsigned char lbah;
	unsigned char nsect;
	unsigned char error;
	unsigned char hob_lbal;
	unsigned char hob_lbam;
	unsigned char hob_lbah;
	unsigned char hob_nsect;
	unsigned char hob_feature;
	unsigned char ctl;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_raw_ata_eh_link_autopsy {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int eh_action;
	unsigned int eh_err_mask;
	char __data[0];
};

struct trace_event_raw_ata_eh_link_autopsy_qc {
	struct trace_entry ent;
	unsigned int ata_port;
	unsigned int ata_dev;
	unsigned int tag;
	unsigned int qc_flags;
	unsigned int eh_err_mask;
	char __data[0];
};

struct trace_event_data_offsets_ata_qc_issue {};

struct trace_event_data_offsets_ata_qc_complete_template {};

struct trace_event_data_offsets_ata_eh_link_autopsy {};

struct trace_event_data_offsets_ata_eh_link_autopsy_qc {};

typedef void (*btf_trace_ata_qc_issue)(void *, struct ata_queued_cmd *);

typedef void (*btf_trace_ata_qc_complete_internal)(void *, struct ata_queued_cmd *);

typedef void (*btf_trace_ata_qc_complete_failed)(void *, struct ata_queued_cmd *);

typedef void (*btf_trace_ata_qc_complete_done)(void *, struct ata_queued_cmd *);

typedef void (*btf_trace_ata_eh_link_autopsy)(void *, struct ata_device *, unsigned int, unsigned int);

typedef void (*btf_trace_ata_eh_link_autopsy_qc)(void *, struct ata_queued_cmd *);

enum {
	ATA_READID_POSTRESET = 1,
	ATA_DNXFER_PIO = 0,
	ATA_DNXFER_DMA = 1,
	ATA_DNXFER_40C = 2,
	ATA_DNXFER_FORCE_PIO = 3,
	ATA_DNXFER_FORCE_PIO0 = 4,
	ATA_DNXFER_QUIET = 2147483648,
};

struct ata_force_param {
	const char *name;
	u8 cbl;
	u8 spd_limit;
	long unsigned int xfer_mask;
	unsigned int horkage_on;
	unsigned int horkage_off;
	u16 lflags;
};

struct ata_force_ent {
	int port;
	int device;
	struct ata_force_param param;
};

struct ata_xfer_ent {
	int shift;
	int bits;
	u8 base;
};

struct ata_blacklist_entry {
	const char *model_num;
	const char *model_rev;
	long unsigned int horkage;
};

struct dentry___218;

struct super_block___218;

struct module___202;

struct file_system_type___218 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___218 * (*mount)(struct file_system_type___218 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___218 *);
	struct module___202 *owner;
	struct file_system_type___218 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___218;

struct kiocb___218;

struct iov_iter___138;

struct poll_table_struct___143;

struct vm_area_struct___223;

struct inode___218;

struct file_lock___218;

struct page___223;

struct seq_file___193;

struct file_operations___219 {
	struct module___202 *owner;
	loff_t (*llseek)(struct file___218 *, loff_t, int);
	ssize_t (*read)(struct file___218 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___218 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___218 *, struct iov_iter___138 *);
	ssize_t (*write_iter)(struct kiocb___218 *, struct iov_iter___138 *);
	int (*iopoll)(struct kiocb___218 *, bool);
	int (*iterate)(struct file___218 *, struct dir_context *);
	int (*iterate_shared)(struct file___218 *, struct dir_context *);
	__poll_t (*poll)(struct file___218 *, struct poll_table_struct___143 *);
	long int (*unlocked_ioctl)(struct file___218 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___218 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___218 *, struct vm_area_struct___223 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___218 *, struct file___218 *);
	int (*flush)(struct file___218 *, fl_owner_t);
	int (*release)(struct inode___218 *, struct file___218 *);
	int (*fsync)(struct file___218 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___218 *, int);
	int (*lock)(struct file___218 *, int, struct file_lock___218 *);
	ssize_t (*sendpage)(struct file___218 *, struct page___223 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___218 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___218 *, long unsigned int);
	int (*flock)(struct file___218 *, int, struct file_lock___218 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___218 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___218 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___218 *, long int, struct file_lock___218 **, void **);
	long int (*fallocate)(struct file___218 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___193 *, struct file___218 *);
	ssize_t (*copy_file_range)(struct file___218 *, loff_t, struct file___218 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___218 *, loff_t, struct file___218 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___218 *, loff_t, loff_t, int);
};

struct vmacache___223 {
	u64 seqnum;
	struct vm_area_struct___223 *vmas[4];
};

struct page_frag___223 {
	struct page___223 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___224;

struct pid___195;

struct nsproxy___204;

struct signal_struct___219;

struct bio_list___114;

struct backing_dev_info___104;

struct io_context___114;

struct css_set___149;

struct mem_cgroup___95;

struct request_queue___114;

struct vm_struct___201;

struct task_struct___225 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___225 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___224 *mm;
	struct mm_struct___224 *active_mm;
	struct vmacache___223 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___225 *real_parent;
	struct task_struct___225 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___225 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___195 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___204 *nsproxy;
	struct signal_struct___219 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___225 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___114 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___104 *backing_dev_info;
	struct io_context___114 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___149 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___223 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___95 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___95 *active_memcg;
	struct request_queue___114 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___225 *oom_reaper_list;
	struct vm_struct___201 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___79 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___206;

struct kobj_type___206;

struct kernfs_node___206;

struct kobject___206 {
	const char *name;
	struct list_head entry;
	struct kobject___206 *parent;
	struct kset___206 *kset;
	struct kobj_type___206 *ktype;
	struct kernfs_node___206 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___203 {
	struct kobject___206 kobj;
	struct module___202 *mod;
	struct kobject___206 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___202 {
	struct module___202 *mod;
	struct latch_tree_node node;
};

struct module_layout___202 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___202 mtn;
};

struct module_attribute___202;

struct kernel_param___202;

struct module___202 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___203 mkobj;
	struct module_attribute___202 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___206 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___202 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___202 core_layout;
	struct module_layout___202 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___195;

struct upid___195 {
	int nr;
	struct pid_namespace___195 *ns;
};

struct pid_namespace___195 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___225 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___195 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___195 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___195 numbers[1];
};

typedef struct page___223 *pgtable_t___223;

struct address_space___218;

struct dev_pagemap___213;

struct page___223 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___218 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___223 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___223 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___224 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___213 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___213;

struct vm_area_struct___223 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___223 *vm_next;
	struct vm_area_struct___223 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___224 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___213 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___218 *vm_file;
	struct file___218 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___219 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___225 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___225 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___195 *pids[4];
	struct pid___195 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___224 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___223;

struct mm_struct___224 {
	struct {
		struct vm_area_struct___223 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___218 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___223 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___225 *owner;
		struct user_namespace___14 *user_ns;
		struct file___218 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___149;

struct nsproxy___204 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___195 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___149 *cgroup_ns;
};

struct bio___114;

struct bio_list___114 {
	struct bio___114 *head;
	struct bio___114 *tail;
};

struct cgroup_subsys_state___149;

struct bdi_writeback___104 {
	struct backing_dev_info___104 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___149 *memcg_css;
	struct cgroup_subsys_state___149 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___196;

struct backing_dev_info___104 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___104 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___196 *dev;
	char dev_name[64];
	struct device___196 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___218 *debug_dir;
};

struct io_cq___114;

struct io_context___114 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___114 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___149;

struct css_set___149 {
	struct cgroup_subsys_state___149 *subsys[14];
	refcount_t refcount;
	struct css_set___149 *dom_cset;
	struct cgroup___149 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___149 *mg_src_cgrp;
	struct cgroup___149 *mg_dst_cgrp;
	struct css_set___149 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___149;

struct cgroup_subsys_state___149 {
	struct cgroup___149 *cgroup;
	struct cgroup_subsys___149 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___149 *parent;
};

struct cgroup_file___149 {
	struct kernfs_node___206 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___95;

struct mem_cgroup_per_node___95;

struct mem_cgroup___95 {
	struct cgroup_subsys_state___149 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___149 events_file;
	struct cgroup_file___149 events_local_file;
	struct cgroup_file___149 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___95 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___225 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___95 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___114;

struct blk_integrity___114 {
	const struct blk_integrity_profile___114 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___114 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___114 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___114;

struct elevator_queue___114;

struct blk_mq_ops___111;

struct blk_mq_hw_ctx___111;

struct gendisk___117;

struct blkcg_gq___106;

struct blk_mq_tag_set___111;

struct request_queue___114 {
	struct request___114 *last_merge;
	struct elevator_queue___114 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___111 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___111 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___117 *disk;
	struct kobject___206 kobj;
	struct kobject___206 *mq_kobj;
	struct blk_integrity___114 integrity;
	struct device___196 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___106 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___111 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___114 bio_split;
	struct dentry___218 *debugfs_dir;
	struct dentry___218 *sched_debugfs_dir;
	struct dentry___218 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___201 {
	struct vm_struct___201 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___223 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___135 {
	struct page___223 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___138 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___135 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct wait_page_queue___105;

struct kiocb___218 {
	struct file___218 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___218 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct dentry_operations___218;

struct dentry___218 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___218 *d_parent;
	struct qstr d_name;
	struct inode___218 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___218 *d_op;
	struct super_block___218 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___218;

struct address_space___218 {
	struct inode___218 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___218 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___218;

struct cdev___56;

struct inode___218 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___218 *i_op;
	struct super_block___218 *i_sb;
	struct address_space___218 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___104 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___219 *i_fop;
		void (*free_inode)(struct inode___218 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___218 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___56 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___218;

struct path___218;

struct dentry_operations___218 {
	int (*d_revalidate)(struct dentry___218 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___218 *, unsigned int);
	int (*d_hash)(const struct dentry___218 *, struct qstr *);
	int (*d_compare)(const struct dentry___218 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___218 *);
	int (*d_init)(struct dentry___218 *);
	void (*d_release)(struct dentry___218 *);
	void (*d_prune)(struct dentry___218 *);
	void (*d_iput)(struct dentry___218 *, struct inode___218 *);
	char * (*d_dname)(struct dentry___218 *, char *, int);
	struct vfsmount___218 * (*d_automount)(struct path___218 *);
	int (*d_manage)(const struct path___218 *, bool);
	struct dentry___218 * (*d_real)(struct dentry___218 *, const struct inode___218 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___218;

struct mem_dqinfo___218 {
	struct quota_format_type___218 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___218;

struct quota_info___218 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___218 *files[3];
	struct mem_dqinfo___218 info[3];
	const struct quota_format_ops___218 *ops[3];
};

struct rcuwait___219 {
	struct task_struct___225 *task;
};

struct percpu_rw_semaphore___219 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___219 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___218 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___219 rw_sem[3];
};

struct shrink_control___95;

struct shrinker___95 {
	long unsigned int (*count_objects)(struct shrinker___95 *, struct shrink_control___95 *);
	long unsigned int (*scan_objects)(struct shrinker___95 *, struct shrink_control___95 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___218;

struct dquot_operations___218;

struct quotactl_ops___218;

struct block_device___117;

struct super_block___218 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___218 *s_type;
	const struct super_operations___218 *s_op;
	const struct dquot_operations___218 *dq_op;
	const struct quotactl_ops___218 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___218 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___117 *s_bdev;
	struct backing_dev_info___104 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___218 s_dquot;
	struct sb_writers___218 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___218 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___218 {
	struct dentry___218 *mnt_root;
	struct super_block___218 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___218 {
	struct vfsmount___218 *mnt;
	struct dentry___218 *dentry;
};

struct shrink_control___95 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___95 *memcg;
};

struct dev_pagemap_ops___213;

struct dev_pagemap___213 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___213 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___195 {
	rwlock_t lock;
	struct pid___195 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___218 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___218 f_path;
	struct inode___218 *f_inode;
	const struct file_operations___219 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___195 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___218 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___213;

struct vm_operations_struct___213 {
	void (*open)(struct vm_area_struct___223 *);
	void (*close)(struct vm_area_struct___223 *);
	int (*may_split)(struct vm_area_struct___223 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___223 *);
	int (*mprotect)(struct vm_area_struct___223 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___213 *);
	vm_fault_t (*huge_fault)(struct vm_fault___213 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___213 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___223 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___213 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___213 *);
	int (*access)(struct vm_area_struct___223 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___223 *);
	int (*set_policy)(struct vm_area_struct___223 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___223 *, long unsigned int);
	struct page___223 * (*find_special_page)(struct vm_area_struct___223 *, long unsigned int);
};

struct core_thread___223 {
	struct task_struct___225 *task;
	struct core_thread___223 *next;
};

struct core_state___223 {
	atomic_t nr_threads;
	struct core_thread___223 dumper;
	struct completion startup;
};

struct vm_fault___213 {
	const struct {
		struct vm_area_struct___223 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___223 *cow_page;
	struct page___223 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___223 prealloc_pte;
};

struct pglist_data___103;

struct lruvec___103 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___103 *pgdat;
};

struct zone___103 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___103 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___103 {
	struct zone___103 *zone;
	int zone_idx;
};

struct zonelist___103 {
	struct zoneref___103 _zonerefs[321];
};

struct pglist_data___103 {
	struct zone___103 node_zones[5];
	struct zonelist___103 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___225 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___225 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___103 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___149 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___225 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___149;

struct cgroup_rstat_cpu___149;

struct cgroup___149 {
	struct cgroup_subsys_state___149 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___206 *kn;
	struct cgroup_file___149 procs_file;
	struct cgroup_file___149 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___149 *subsys[14];
	struct cgroup_root___149 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___149 *dom_cgrp;
	struct cgroup___149 *old_dom_cgrp;
	struct cgroup_rstat_cpu___149 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___149 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___114 {
	struct request_queue___114 *q;
	struct io_context___114 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___218 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___218 *ia_file;
};

struct dquot___218 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___218 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___218 {
	int qf_fmt_id;
	const struct quota_format_ops___218 *qf_ops;
	struct module___202 *qf_owner;
	struct quota_format_type___218 *qf_next;
};

struct quota_format_ops___218 {
	int (*check_quota_file)(struct super_block___218 *, int);
	int (*read_file_info)(struct super_block___218 *, int);
	int (*write_file_info)(struct super_block___218 *, int);
	int (*free_file_info)(struct super_block___218 *, int);
	int (*read_dqblk)(struct dquot___218 *);
	int (*commit_dqblk)(struct dquot___218 *);
	int (*release_dqblk)(struct dquot___218 *);
	int (*get_next_id)(struct super_block___218 *, struct kqid *);
};

struct dquot_operations___218 {
	int (*write_dquot)(struct dquot___218 *);
	struct dquot___218 * (*alloc_dquot)(struct super_block___218 *, int);
	void (*destroy_dquot)(struct dquot___218 *);
	int (*acquire_dquot)(struct dquot___218 *);
	int (*release_dquot)(struct dquot___218 *);
	int (*mark_dirty)(struct dquot___218 *);
	int (*write_info)(struct super_block___218 *, int);
	qsize_t * (*get_reserved_space)(struct inode___218 *);
	int (*get_projid)(struct inode___218 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___218 *, qsize_t *);
	int (*get_next_id)(struct super_block___218 *, struct kqid *);
};

struct quotactl_ops___218 {
	int (*quota_on)(struct super_block___218 *, int, int, const struct path___218 *);
	int (*quota_off)(struct super_block___218 *, int);
	int (*quota_enable)(struct super_block___218 *, unsigned int);
	int (*quota_disable)(struct super_block___218 *, unsigned int);
	int (*quota_sync)(struct super_block___218 *, int);
	int (*set_info)(struct super_block___218 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___218 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___218 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___218 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___218 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___218 *, unsigned int);
};

struct wait_page_queue___105 {
	struct page___223 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___104;

struct readahead_control___105;

struct swap_info_struct___63;

struct address_space_operations___218 {
	int (*writepage)(struct page___223 *, struct writeback_control___104 *);
	int (*readpage)(struct file___218 *, struct page___223 *);
	int (*writepages)(struct address_space___218 *, struct writeback_control___104 *);
	int (*set_page_dirty)(struct page___223 *);
	int (*readpages)(struct file___218 *, struct address_space___218 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___105 *);
	int (*write_begin)(struct file___218 *, struct address_space___218 *, loff_t, unsigned int, unsigned int, struct page___223 **, void **);
	int (*write_end)(struct file___218 *, struct address_space___218 *, loff_t, unsigned int, unsigned int, struct page___223 *, void *);
	sector_t (*bmap)(struct address_space___218 *, sector_t);
	void (*invalidatepage)(struct page___223 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___223 *, gfp_t);
	void (*freepage)(struct page___223 *);
	ssize_t (*direct_IO)(struct kiocb___218 *, struct iov_iter___138 *);
	int (*migratepage)(struct address_space___218 *, struct page___223 *, struct page___223 *, enum migrate_mode);
	bool (*isolate_page)(struct page___223 *, isolate_mode_t);
	void (*putback_page)(struct page___223 *);
	int (*launder_page)(struct page___223 *);
	int (*is_partially_uptodate)(struct page___223 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___223 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___218 *, struct page___223 *);
	int (*swap_activate)(struct swap_info_struct___63 *, struct file___218 *, sector_t *);
	void (*swap_deactivate)(struct file___218 *);
};

struct writeback_control___104 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___104 *wb;
	struct inode___218 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___105 {
	struct file___218 *file;
	struct address_space___218 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct swap_info_struct___63 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___117 *bdev;
	struct file___218 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___56 {
	struct kobject___206 kobj;
	struct module___202 *owner;
	const struct file_operations___219 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___218 {
	struct dentry___218 * (*lookup)(struct inode___218 *, struct dentry___218 *, unsigned int);
	const char * (*get_link)(struct dentry___218 *, struct inode___218 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___218 *, int);
	struct posix_acl * (*get_acl)(struct inode___218 *, int, bool);
	int (*readlink)(struct dentry___218 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___218 *, struct dentry___218 *, umode_t, bool);
	int (*link)(struct dentry___218 *, struct inode___218 *, struct dentry___218 *);
	int (*unlink)(struct inode___218 *, struct dentry___218 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___218 *, struct dentry___218 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___218 *, struct dentry___218 *, umode_t);
	int (*rmdir)(struct inode___218 *, struct dentry___218 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___218 *, struct dentry___218 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___218 *, struct dentry___218 *, struct inode___218 *, struct dentry___218 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___218 *, struct iattr___218 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___218 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___218 *, char *, size_t);
	int (*fiemap)(struct inode___218 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___218 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___218 *, struct dentry___218 *, struct file___218 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___218 *, struct dentry___218 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___218 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___218 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___218 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___218 {
	void (*fl_copy_lock)(struct file_lock___218 *, struct file_lock___218 *);
	void (*fl_release_private)(struct file_lock___218 *);
};

struct fasync_struct___218;

struct lock_manager_operations___218;

struct file_lock___218 {
	struct file_lock___218 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___218 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___218 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___218 *fl_ops;
	const struct lock_manager_operations___218 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___218 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___218 *);
	int (*lm_grant)(struct file_lock___218 *, int);
	bool (*lm_break)(struct file_lock___218 *);
	int (*lm_change)(struct file_lock___218 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___218 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___218 *);
};

struct fasync_struct___218 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___218 *fa_next;
	struct file___218 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___218 {
	struct inode___218 * (*alloc_inode)(struct super_block___218 *);
	void (*destroy_inode)(struct inode___218 *);
	void (*free_inode)(struct inode___218 *);
	void (*dirty_inode)(struct inode___218 *, int);
	int (*write_inode)(struct inode___218 *, struct writeback_control___104 *);
	int (*drop_inode)(struct inode___218 *);
	void (*evict_inode)(struct inode___218 *);
	void (*put_super)(struct super_block___218 *);
	int (*sync_fs)(struct super_block___218 *, int);
	int (*freeze_super)(struct super_block___218 *);
	int (*freeze_fs)(struct super_block___218 *);
	int (*thaw_super)(struct super_block___218 *);
	int (*unfreeze_fs)(struct super_block___218 *);
	int (*statfs)(struct dentry___218 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___218 *, int *, char *);
	void (*umount_begin)(struct super_block___218 *);
	int (*show_options)(struct seq_file___193 *, struct dentry___218 *);
	int (*show_devname)(struct seq_file___193 *, struct dentry___218 *);
	int (*show_path)(struct seq_file___193 *, struct dentry___218 *);
	int (*show_stats)(struct seq_file___193 *, struct dentry___218 *);
	ssize_t (*quota_read)(struct super_block___218 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___218 *, int, const char *, size_t, loff_t);
	struct dquot___218 ** (*get_dquots)(struct inode___218 *);
	long int (*nr_cached_objects)(struct super_block___218 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___218 *, struct shrink_control___95 *);
	struct file___218 * (*real_loop)(struct file___218 *);
};

struct wakeup_source___196;

struct dev_pm_info___196 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___196 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___196 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___196;

struct bus_type___196;

struct device_driver___196;

struct dev_pm_domain___196;

struct irq_domain___51;

struct device_node___84;

struct fwnode_handle___192;

struct class___196;

struct attribute_group___206;

struct device___196 {
	struct kobject___206 kobj;
	struct device___196 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___196 *type;
	struct bus_type___196 *bus;
	struct device_driver___196 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___196 power;
	struct dev_pm_domain___196 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___51 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___84 *of_node;
	struct fwnode_handle___192 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___196 *class;
	const struct attribute_group___206 **groups;
	void (*release)(struct device___196 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___117 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___218 *bd_inode;
	struct super_block___218 *bd_super;
	void *bd_claiming;
	struct device___196 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___206 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___117 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___218 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___150)(struct file___218 *, wait_queue_head_t *, struct poll_table_struct___143 *);

struct poll_table_struct___143 {
	poll_queue_proc___150 _qproc;
	__poll_t _key;
};

struct seq_operations___193;

struct seq_file___193 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___193 *op;
	int poll_event;
	const struct file___218 *file;
	void *private;
};

typedef void bio_end_io_t___114(struct bio___114 *);

struct bio_integrity_payload___114;

struct bio___114 {
	struct bio___114 *bi_next;
	struct block_device___117 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___114 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___106 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___114 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___135 *bi_io_vec;
	struct bio_set___114 *bi_pool;
	struct bio_vec___135 bi_inline_vecs[0];
};

struct dev_pagemap_ops___213 {
	void (*page_free)(struct page___223 *);
	void (*kill)(struct dev_pagemap___213 *);
	void (*cleanup)(struct dev_pagemap___213 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___213 *);
};

struct irq_desc___53;

typedef void (*irq_flow_handler_t___53)(struct irq_desc___53 *);

struct irq_chip___53;

struct irq_data___53 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___53 *chip;
	struct irq_domain___51 *domain;
	struct irq_data___53 *parent_data;
	void *chip_data;
};

struct irqaction___35;

struct irq_desc___53 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___53 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___53 handle_irq;
	struct irqaction___35 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___206 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___202 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___192;

struct fwnode_handle___192 {
	struct fwnode_handle___192 *secondary;
	const struct fwnode_operations___192 *ops;
	struct device___196 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___192;

struct fwnode_endpoint___192;

struct fwnode_operations___192 {
	struct fwnode_handle___192 * (*get)(struct fwnode_handle___192 *);
	void (*put)(struct fwnode_handle___192 *);
	bool (*device_is_available)(const struct fwnode_handle___192 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___192 *, const struct device___196 *);
	bool (*property_present)(const struct fwnode_handle___192 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___192 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___192 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___192 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*get_parent)(const struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*get_next_child_node)(const struct fwnode_handle___192 *, struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*get_named_child_node)(const struct fwnode_handle___192 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___192 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___192 *);
	struct fwnode_handle___192 * (*graph_get_next_endpoint)(const struct fwnode_handle___192 *, struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*graph_get_remote_endpoint)(const struct fwnode_handle___192 *);
	struct fwnode_handle___192 * (*graph_get_port_parent)(struct fwnode_handle___192 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___192 *, struct fwnode_endpoint___192 *);
	int (*add_links)(struct fwnode_handle___192 *);
};

struct fwnode_endpoint___192 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___192 *local_fwnode;
};

struct fwnode_reference_args___192 {
	struct fwnode_handle___192 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___53 {
	struct device___196 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___53 *);
	void (*irq_shutdown)(struct irq_data___53 *);
	void (*irq_enable)(struct irq_data___53 *);
	void (*irq_disable)(struct irq_data___53 *);
	void (*irq_ack)(struct irq_data___53 *);
	void (*irq_mask)(struct irq_data___53 *);
	void (*irq_mask_ack)(struct irq_data___53 *);
	void (*irq_unmask)(struct irq_data___53 *);
	void (*irq_eoi)(struct irq_data___53 *);
	int (*irq_set_affinity)(struct irq_data___53 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___53 *);
	int (*irq_set_type)(struct irq_data___53 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___53 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___53 *);
	void (*irq_bus_sync_unlock)(struct irq_data___53 *);
	void (*irq_cpu_online)(struct irq_data___53 *);
	void (*irq_cpu_offline)(struct irq_data___53 *);
	void (*irq_suspend)(struct irq_data___53 *);
	void (*irq_resume)(struct irq_data___53 *);
	void (*irq_pm_shutdown)(struct irq_data___53 *);
	void (*irq_calc_mask)(struct irq_data___53 *);
	void (*irq_print_chip)(struct irq_data___53 *, struct seq_file___193 *);
	int (*irq_request_resources)(struct irq_data___53 *);
	void (*irq_release_resources)(struct irq_data___53 *);
	void (*irq_compose_msi_msg)(struct irq_data___53 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___53 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___53 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___53 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___53 *, void *);
	void (*ipi_send_single)(struct irq_data___53 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___53 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___53 *);
	void (*irq_nmi_teardown)(struct irq_data___53 *);
	long unsigned int flags;
};

struct irq_domain_ops___51;

struct irq_domain_chip_generic___51;

struct irq_domain___51 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___51 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___192 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___51 *gc;
	struct irq_domain___51 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___53 *revmap[0];
};

struct kernfs_root___206;

struct kernfs_elem_dir___206 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___206 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___206;

struct kernfs_root___206 {
	struct kernfs_node___206 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___206 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___206 {
	struct kernfs_node___206 *target_kn;
};

struct kernfs_ops___206;

struct kernfs_elem_attr___206 {
	const struct kernfs_ops___206 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___206 *notify_next;
};

struct kernfs_node___206 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___206 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___206 dir;
		struct kernfs_elem_symlink___206 symlink;
		struct kernfs_elem_attr___206 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___206;

struct kernfs_ops___206 {
	int (*open)(struct kernfs_open_file___206 *);
	void (*release)(struct kernfs_open_file___206 *);
	int (*seq_show)(struct seq_file___193 *, void *);
	void * (*seq_start)(struct seq_file___193 *, loff_t *);
	void * (*seq_next)(struct seq_file___193 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___193 *, void *);
	ssize_t (*read)(struct kernfs_open_file___206 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___206 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___206 *, struct poll_table_struct___143 *);
	int (*mmap)(struct kernfs_open_file___206 *, struct vm_area_struct___223 *);
};

struct kernfs_syscall_ops___206 {
	int (*show_options)(struct seq_file___193 *, struct kernfs_root___206 *);
	int (*mkdir)(struct kernfs_node___206 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___206 *);
	int (*rename)(struct kernfs_node___206 *, struct kernfs_node___206 *, const char *);
	int (*show_path)(struct seq_file___193 *, struct kernfs_node___206 *, struct kernfs_root___206 *);
};

struct kernfs_open_file___206 {
	struct kernfs_node___206 *kn;
	struct file___218 *file;
	struct seq_file___193 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___213 *vm_ops;
};

struct bin_attribute___206;

struct attribute_group___206 {
	const char *name;
	umode_t (*is_visible)(struct kobject___206 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___206 *, struct bin_attribute___206 *, int);
	struct attribute **attrs;
	struct bin_attribute___206 **bin_attrs;
};

struct bin_attribute___206 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___218 * (*f_mapping)();
	ssize_t (*read)(struct file___218 *, struct kobject___206 *, struct bin_attribute___206 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___218 *, struct kobject___206 *, struct bin_attribute___206 *, char *, loff_t, size_t);
	int (*mmap)(struct file___218 *, struct kobject___206 *, struct bin_attribute___206 *, struct vm_area_struct___223 *);
};

struct sysfs_ops___206 {
	ssize_t (*show)(struct kobject___206 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___206 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___206;

struct kset___206 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___206 kobj;
	const struct kset_uevent_ops___206 *uevent_ops;
};

struct kobj_type___206 {
	void (*release)(struct kobject___206 *);
	const struct sysfs_ops___206 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___206 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___206 *);
	const void * (*namespace)(struct kobject___206 *);
	void (*get_ownership)(struct kobject___206 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___206 {
	int (* const filter)(struct kset___206 *, struct kobject___206 *);
	const char * (* const name)(struct kset___206 *, struct kobject___206 *);
	int (* const uevent)(struct kset___206 *, struct kobject___206 *, struct kobj_uevent_env *);
};

struct irqaction___35 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___35 *next;
	irq_handler_t thread_fn;
	struct task_struct___225 *thread;
	struct irqaction___35 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___51 {
	struct irq_chip___53 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___53 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___51 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___51 *);
	void (*resume)(struct irq_chip_generic___51 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___51 *domain;
	struct list_head list;
	struct irq_chip_type___51 chip_types[0];
};

struct irq_domain_chip_generic___51 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___51 *gc[0];
};

struct kernel_param_ops___202 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___202 *);
	int (*get)(char *, const struct kernel_param___202 *);
	void (*free)(void *);
};

struct kparam_array___202;

struct kernel_param___202 {
	const char *name;
	struct module___202 *mod;
	const struct kernel_param_ops___202 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___202 *arr;
	};
};

struct kparam_array___202 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___202 *ops;
	void *elem;
};

struct module_attribute___202 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___202 *, struct module_kobject___203 *, char *);
	ssize_t (*store)(struct module_attribute___202 *, struct module_kobject___203 *, const char *, size_t);
	void (*setup)(struct module___202 *, const char *);
	int (*test)(struct module___202 *);
	void (*free)(struct module___202 *);
};

struct cgroup_namespace___149 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___149 *root_cset;
};

struct dev_pm_ops___196 {
	int (*prepare)(struct device___196 *);
	void (*complete)(struct device___196 *);
	int (*suspend)(struct device___196 *);
	int (*resume)(struct device___196 *);
	int (*freeze)(struct device___196 *);
	int (*thaw)(struct device___196 *);
	int (*poweroff)(struct device___196 *);
	int (*restore)(struct device___196 *);
	int (*suspend_late)(struct device___196 *);
	int (*resume_early)(struct device___196 *);
	int (*freeze_late)(struct device___196 *);
	int (*thaw_early)(struct device___196 *);
	int (*poweroff_late)(struct device___196 *);
	int (*restore_early)(struct device___196 *);
	int (*suspend_noirq)(struct device___196 *);
	int (*resume_noirq)(struct device___196 *);
	int (*freeze_noirq)(struct device___196 *);
	int (*thaw_noirq)(struct device___196 *);
	int (*poweroff_noirq)(struct device___196 *);
	int (*restore_noirq)(struct device___196 *);
	int (*runtime_suspend)(struct device___196 *);
	int (*runtime_resume)(struct device___196 *);
	int (*runtime_idle)(struct device___196 *);
};

struct wakeup_source___196 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___196 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___196 {
	struct dev_pm_ops___196 ops;
	int (*start)(struct device___196 *);
	void (*detach)(struct device___196 *, bool);
	int (*activate)(struct device___196 *);
	void (*sync)(struct device___196 *);
	void (*dismiss)(struct device___196 *);
};

struct bus_type___196 {
	const char *name;
	const char *dev_name;
	struct device___196 *dev_root;
	const struct attribute_group___206 **bus_groups;
	const struct attribute_group___206 **dev_groups;
	const struct attribute_group___206 **drv_groups;
	int (*match)(struct device___196 *, struct device_driver___196 *);
	int (*uevent)(struct device___196 *, struct kobj_uevent_env *);
	int (*probe)(struct device___196 *);
	void (*sync_state)(struct device___196 *);
	void (*remove)(struct device___196 *);
	void (*shutdown)(struct device___196 *);
	int (*online)(struct device___196 *);
	int (*offline)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	int (*num_vf)(struct device___196 *);
	int (*dma_configure)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___196 {
	const char *name;
	struct bus_type___196 *bus;
	struct module___202 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___196 *);
	void (*sync_state)(struct device___196 *);
	int (*remove)(struct device___196 *);
	void (*shutdown)(struct device___196 *);
	int (*suspend)(struct device___196 *, pm_message_t);
	int (*resume)(struct device___196 *);
	const struct attribute_group___206 **groups;
	const struct attribute_group___206 **dev_groups;
	const struct dev_pm_ops___196 *pm;
	void (*coredump)(struct device___196 *);
	struct driver_private *p;
};

struct device_type___196 {
	const char *name;
	const struct attribute_group___206 **groups;
	int (*uevent)(struct device___196 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___196 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___196 *);
	const struct dev_pm_ops___196 *pm;
};

struct class___196 {
	const char *name;
	struct module___202 *owner;
	const struct attribute_group___206 **class_groups;
	const struct attribute_group___206 **dev_groups;
	struct kobject___206 *dev_kobj;
	int (*dev_uevent)(struct device___196 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___196 *, umode_t *);
	void (*class_release)(struct class___196 *);
	void (*dev_release)(struct device___196 *);
	int (*shutdown_pre)(struct device___196 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___196 *);
	void (*get_ownership)(struct device___196 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___196 *pm;
	struct subsys_private *p;
};

struct device_attribute___31 {
	struct attribute attr;
	ssize_t (*show)(struct device___196 *, struct device_attribute___31 *, char *);
	ssize_t (*store)(struct device___196 *, struct device_attribute___31 *, const char *, size_t);
};

struct property___61;

struct device_node___84 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___192 fwnode;
	struct property___61 *properties;
	struct property___61 *deadprops;
	struct device_node___84 *parent;
	struct device_node___84 *child;
	struct device_node___84 *sibling;
	struct kobject___206 kobj;
	long unsigned int _flags;
	void *data;
};

struct block_device_operations___114;

struct cdrom_device_info___4;

struct gendisk___117 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___117 *part0;
	const struct block_device_operations___114 *fops;
	struct request_queue___114 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___104 *bdi;
	struct kobject___206 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___206 integrity_kobj;
	struct cdrom_device_info___4 *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___114 {
	struct bio___114 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___135 *bip_vec;
	struct bio_vec___135 bip_inline_vecs[0];
};

struct blkcg___106;

struct blkg_policy_data___106;

struct blkcg_gq___106 {
	struct request_queue___114 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___106 *blkcg;
	struct blkcg_gq___106 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___106 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___114 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___114(struct request___114 *);

typedef void integrity_complete_fn___114(struct request___114 *, unsigned int);

struct blk_integrity_profile___114 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___114 *prepare_fn;
	integrity_complete_fn___114 *complete_fn;
	const char *name;
};

struct block_device_operations___114 {
	blk_qc_t (*submit_bio)(struct bio___114 *);
	int (*open)(struct block_device___117 *, fmode_t);
	void (*release)(struct gendisk___117 *, fmode_t);
	int (*rw_page)(struct block_device___117 *, sector_t, struct page___223 *, unsigned int);
	int (*ioctl)(struct block_device___117 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___117 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___117 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___117 *);
	int (*getgeo)(struct block_device___117 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___117 *, bool);
	void (*swap_slot_free_notify)(struct block_device___117 *, long unsigned int);
	int (*report_zones)(struct gendisk___117 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___117 *, umode_t *);
	struct module___202 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___117 *, sector_t *);
};

struct cdrom_device_ops___4;

struct cdrom_device_info___4 {
	const struct cdrom_device_ops___4 *ops;
	struct list_head list;
	struct gendisk___117 *disk;
	void *handle;
	int mask;
	int speed;
	int capacity;
	unsigned int options: 30;
	unsigned int mc_flags: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int vfs_events;
	unsigned int ioctl_events;
	int use_count;
	char name[20];
	__u8 sanyo_slot: 2;
	__u8 keeplocked: 1;
	__u8 reserved: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int cdda_method;
	__u8 last_sense;
	__u8 media_written;
	short unsigned int mmc3_profile;
	int for_data;
	int (*exit)(struct cdrom_device_info___4 *);
	int mrw_mode_page;
};

struct sg_mapping_iter___2 {
	struct page___223 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

typedef void rq_end_io_fn___114(struct request___114 *, blk_status_t);

struct request___114 {
	struct request_queue___114 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___111 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___114 *bio;
	struct bio___114 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___135 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___114 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___114 *saved_end_io;
		} flush;
	};
	struct gendisk___117 *rq_disk;
	struct block_device___117 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___114 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___111 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___114 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___206 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___218 *debugfs_dir;
	struct dentry___218 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___114;

struct elevator_mq_ops___114 {
	int (*init_sched)(struct request_queue___114 *, struct elevator_type___114 *);
	void (*exit_sched)(struct elevator_queue___114 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___111 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___111 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___111 *);
	bool (*allow_merge)(struct request_queue___114 *, struct request___114 *, struct bio___114 *);
	bool (*bio_merge)(struct request_queue___114 *, struct bio___114 *, unsigned int);
	int (*request_merge)(struct request_queue___114 *, struct request___114 **, struct bio___114 *);
	void (*request_merged)(struct request_queue___114 *, struct request___114 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___114 *, struct request___114 *, struct request___114 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___114 *);
	void (*finish_request)(struct request___114 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___111 *, struct list_head *, bool);
	struct request___114 * (*dispatch_request)(struct blk_mq_hw_ctx___111 *);
	bool (*has_work)(struct blk_mq_hw_ctx___111 *);
	void (*completed_request)(struct request___114 *, u64);
	void (*requeue_request)(struct request___114 *);
	struct request___114 * (*former_request)(struct request_queue___114 *, struct request___114 *);
	struct request___114 * (*next_request)(struct request_queue___114 *, struct request___114 *);
	void (*init_icq)(struct io_cq___114 *);
	void (*exit_icq)(struct io_cq___114 *);
};

struct elv_fs_entry___114;

struct elevator_type___114 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___114 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___114 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___202 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___114 {
	struct elevator_type___114 *type;
	void *elevator_data;
	struct kobject___206 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___114 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___114 *, char *);
	ssize_t (*store)(struct elevator_queue___114 *, const char *, size_t);
};

struct blk_mq_queue_data___111;

struct blk_mq_ops___111 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___111 *, const struct blk_mq_queue_data___111 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___111 *);
	int (*get_budget)(struct request_queue___114 *);
	void (*put_budget)(struct request_queue___114 *, int);
	void (*set_rq_budget_token)(struct request___114 *, int);
	int (*get_rq_budget_token)(struct request___114 *);
	enum blk_eh_timer_return (*timeout)(struct request___114 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___111 *);
	void (*complete)(struct request___114 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___111 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___111 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___111 *, struct request___114 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___111 *, struct request___114 *, unsigned int);
	void (*initialize_rq_fn)(struct request___114 *);
	void (*cleanup_rq)(struct request___114 *);
	bool (*busy)(struct request_queue___114 *);
	int (*map_queues)(struct blk_mq_tag_set___111 *);
	void (*show_rq)(struct seq_file___193 *, struct request___114 *);
};

struct blk_mq_tag_set___111 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___111 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___193 {
	void * (*start)(struct seq_file___193 *, loff_t *);
	void (*stop)(struct seq_file___193 *, void *);
	void * (*next)(struct seq_file___193 *, void *, loff_t *);
	int (*show)(struct seq_file___193 *, void *);
};

struct blk_mq_queue_data___111 {
	struct request___114 *rq;
	bool last;
};

struct Scsi_Host___8;

struct scsi_cmnd___8;

struct scsi_device___8;

struct scsi_target___8;

struct scsi_host_template___8 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___8 *, struct scsi_cmnd___8 *);
	void (*commit_rqs)(struct Scsi_Host___8 *, u16);
	struct module___202 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___8 *);
	int (*ioctl)(struct scsi_device___8 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___8 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___8 *, struct scsi_cmnd___8 *);
	int (*exit_cmd_priv)(struct Scsi_Host___8 *, struct scsi_cmnd___8 *);
	int (*eh_abort_handler)(struct scsi_cmnd___8 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___8 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___8 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___8 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___8 *);
	int (*slave_alloc)(struct scsi_device___8 *);
	int (*slave_configure)(struct scsi_device___8 *);
	void (*slave_destroy)(struct scsi_device___8 *);
	int (*target_alloc)(struct scsi_target___8 *);
	void (*target_destroy)(struct scsi_target___8 *);
	int (*scan_finished)(struct Scsi_Host___8 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___8 *);
	int (*change_queue_depth)(struct scsi_device___8 *, int);
	int (*map_queues)(struct Scsi_Host___8 *);
	int (*mq_poll)(struct Scsi_Host___8 *, unsigned int);
	bool (*dma_need_drain)(struct request___114 *);
	int (*bios_param)(struct scsi_device___8 *, struct block_device___117 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___8 *);
	int (*show_info)(struct seq_file___193 *, struct Scsi_Host___8 *);
	int (*write_info)(struct Scsi_Host___8 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___8 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___8 *);
	int (*host_reset)(struct Scsi_Host___8 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___31 **shost_attrs;
	struct device_attribute___31 **sdev_attrs;
	const struct attribute_group___206 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct scsi_transport_template___2;

struct Scsi_Host___8 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___225 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___8 *hostt;
	struct scsi_transport_template___2 *transportt;
	struct blk_mq_tag_set___111 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___196 shost_gendev;
	struct device___196 shost_dev;
	void *shost_data;
	struct device___196 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_cmnd___8 {
	struct scsi_request req;
	struct scsi_device___8 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___8 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

struct scsi_device___8 {
	struct Scsi_Host___8 *host;
	struct request_queue___114 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___8 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___196 sdev_gendev;
	struct device___196 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___225 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_target___8 {
	struct scsi_device___8 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___196 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct attribute_container___4 {
	struct list_head node;
	struct klist containers;
	struct class___196 *class;
	const struct attribute_group___206 *grp;
	struct device_attribute___31 **attrs;
	int (*match)(struct attribute_container___4 *, struct device___196 *);
	long unsigned int flags;
};

struct transport_container___3 {
	struct attribute_container___4 ac;
	const struct attribute_group___206 *statistics;
};

struct scsi_transport_template___2 {
	struct transport_container___3 host_attrs;
	struct transport_container___3 target_attrs;
	struct transport_container___3 device_attrs;
	int (*user_scan)(struct Scsi_Host___8 *, uint, uint, u64);
	int device_size;
	int device_private_offset;
	int target_size;
	int target_private_offset;
	int host_size;
	unsigned int create_work_queue: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void (*eh_strategy_handler)(struct Scsi_Host___8 *);
};

struct property___61 {
	char *name;
	int length;
	void *value;
	struct property___61 *next;
	long unsigned int _flags;
	struct bin_attribute___206 attr;
};

struct irq_fwspec___49 {
	struct fwnode_handle___192 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___51 {
	int (*match)(struct irq_domain___51 *, struct device_node___84 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___51 *, struct irq_fwspec___49 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___51 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___51 *, unsigned int);
	int (*xlate)(struct irq_domain___51 *, struct device_node___84 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___51 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___51 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___51 *, struct irq_data___53 *, bool);
	void (*deactivate)(struct irq_domain___51 *, struct irq_data___53 *);
	int (*translate)(struct irq_domain___51 *, struct irq_fwspec___49 *, long unsigned int *, unsigned int *);
};

struct cdrom_device_ops___4 {
	int (*open)(struct cdrom_device_info___4 *, int);
	void (*release)(struct cdrom_device_info___4 *);
	int (*drive_status)(struct cdrom_device_info___4 *, int);
	unsigned int (*check_events)(struct cdrom_device_info___4 *, unsigned int, int);
	int (*tray_move)(struct cdrom_device_info___4 *, int);
	int (*lock_door)(struct cdrom_device_info___4 *, int);
	int (*select_speed)(struct cdrom_device_info___4 *, int);
	int (*select_disc)(struct cdrom_device_info___4 *, int);
	int (*get_last_session)(struct cdrom_device_info___4 *, struct cdrom_multisession *);
	int (*get_mcn)(struct cdrom_device_info___4 *, struct cdrom_mcn *);
	int (*reset)(struct cdrom_device_info___4 *);
	int (*audio_ioctl)(struct cdrom_device_info___4 *, unsigned int, void *);
	int (*generic_packet)(struct cdrom_device_info___4 *, struct packet_command *);
	int (*read_cdda_bpc)(struct cdrom_device_info___4 *, void *, u32, u32, u8 *);
	const int capability;
};

struct ata_queued_cmd___2;

typedef void (*ata_qc_cb_t___2)(struct ata_queued_cmd___2 *);

struct ata_port___2;

struct ata_device___2;

struct ata_queued_cmd___2 {
	struct ata_port___2 *ap;
	struct ata_device___2 *dev;
	struct scsi_cmnd___8 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___8 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___2 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___2;

typedef int (*ata_prereset_fn_t___2)(struct ata_link___2 *, long unsigned int);

struct ata_eh_info___2 {
	struct ata_device___2 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___2 {
	struct ata_eh_info___2 i;
	int tries[2];
	int cmd_timeout_idx[14];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___2 {
	struct ata_link___2 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___8 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	void *zpodd;
	struct device___196 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___2 {
	struct ata_port___2 *ap;
	int pmp;
	struct device___196 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___2 eh_info;
	struct ata_eh_context___2 eh_context;
	long: 64;
	struct ata_device___2 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___2)(struct ata_link___2 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___2)(struct ata_link___2 *, unsigned int *);

struct ata_port_operations___2;

struct ata_host___2 {
	spinlock_t lock;
	struct device___196 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___2 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___225 *eh_owner;
	struct ata_port___2 *simplex_claimed;
	struct ata_port___2 *ports[0];
};

struct ata_port_operations___2 {
	int (*qc_defer)(struct ata_queued_cmd___2 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___2 *);
	enum ata_completion_errors (*qc_prep)(struct ata_queued_cmd___2 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___2 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___2 *);
	int (*cable_detect)(struct ata_port___2 *);
	long unsigned int (*mode_filter)(struct ata_device___2 *, long unsigned int);
	void (*set_piomode)(struct ata_port___2 *, struct ata_device___2 *);
	void (*set_dmamode)(struct ata_port___2 *, struct ata_device___2 *);
	int (*set_mode)(struct ata_link___2 *, struct ata_device___2 **);
	unsigned int (*read_id)(struct ata_device___2 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___2 *);
	void (*freeze)(struct ata_port___2 *);
	void (*thaw)(struct ata_port___2 *);
	ata_prereset_fn_t___2 prereset;
	ata_reset_fn_t___2 softreset;
	ata_reset_fn_t___2 hardreset;
	ata_postreset_fn_t___2 postreset;
	ata_prereset_fn_t___2 pmp_prereset;
	ata_reset_fn_t___2 pmp_softreset;
	ata_reset_fn_t___2 pmp_hardreset;
	ata_postreset_fn_t___2 pmp_postreset;
	void (*error_handler)(struct ata_port___2 *);
	void (*lost_interrupt)(struct ata_port___2 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___2 *);
	void (*sched_eh)(struct ata_port___2 *);
	void (*end_eh)(struct ata_port___2 *);
	int (*scr_read)(struct ata_link___2 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___2 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___2 *);
	void (*pmp_detach)(struct ata_port___2 *);
	int (*set_lpm)(struct ata_link___2 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___2 *, pm_message_t);
	int (*port_resume)(struct ata_port___2 *);
	int (*port_start)(struct ata_port___2 *);
	void (*port_stop)(struct ata_port___2 *);
	void (*host_stop)(struct ata_host___2 *);
	void (*sff_dev_select)(struct ata_port___2 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___2 *, u8);
	u8 (*sff_check_status)(struct ata_port___2 *);
	u8 (*sff_check_altstatus)(struct ata_port___2 *);
	void (*sff_tf_load)(struct ata_port___2 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___2 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___2 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___2 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___2 *);
	bool (*sff_irq_check)(struct ata_port___2 *);
	void (*sff_irq_clear)(struct ata_port___2 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___2 *);
	void (*bmdma_setup)(struct ata_queued_cmd___2 *);
	void (*bmdma_start)(struct ata_queued_cmd___2 *);
	void (*bmdma_stop)(struct ata_queued_cmd___2 *);
	u8 (*bmdma_status)(struct ata_port___2 *);
	ssize_t (*em_show)(struct ata_port___2 *, char *);
	ssize_t (*em_store)(struct ata_port___2 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___2 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___2 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___2 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___2 *);
	void (*eng_timeout)(struct ata_port___2 *);
	const struct ata_port_operations___2 *inherits;
};

struct ata_port___2 {
	struct Scsi_Host___8 *scsi_host;
	struct ata_port_operations___2 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___2 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___2 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	struct ata_link___2 link;
	struct ata_link___2 *slave_link;
	int nr_pmp_links;
	struct ata_link___2 *pmp_link;
	struct ata_link___2 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___2 *host;
	struct device___196 *dev;
	struct device___196 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	async_cookie_t cookie;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct cftype___149;

struct cgroup_subsys___149 {
	struct cgroup_subsys_state___149 * (*css_alloc)(struct cgroup_subsys_state___149 *);
	int (*css_online)(struct cgroup_subsys_state___149 *);
	void (*css_offline)(struct cgroup_subsys_state___149 *);
	void (*css_released)(struct cgroup_subsys_state___149 *);
	void (*css_free)(struct cgroup_subsys_state___149 *);
	void (*css_reset)(struct cgroup_subsys_state___149 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___149 *, int);
	int (*css_extra_stat_show)(struct seq_file___193 *, struct cgroup_subsys_state___149 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___225 *, struct css_set___149 *);
	void (*cancel_fork)(struct task_struct___225 *, struct css_set___149 *);
	void (*fork)(struct task_struct___225 *);
	void (*exit)(struct task_struct___225 *);
	void (*release)(struct task_struct___225 *);
	void (*bind)(struct cgroup_subsys_state___149 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___149 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___149 *dfl_cftypes;
	struct cftype___149 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___149 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___149 *updated_children;
	struct cgroup___149 *updated_next;
};

struct cgroup_root___149 {
	struct kernfs_root___206 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___149 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___149 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___149 *ss;
	struct list_head node;
	struct kernfs_ops___206 *kf_ops;
	int (*open)(struct kernfs_open_file___206 *);
	void (*release)(struct kernfs_open_file___206 *);
	u64 (*read_u64)(struct cgroup_subsys_state___149 *, struct cftype___149 *);
	s64 (*read_s64)(struct cgroup_subsys_state___149 *, struct cftype___149 *);
	int (*seq_show)(struct seq_file___193 *, void *);
	void * (*seq_start)(struct seq_file___193 *, loff_t *);
	void * (*seq_next)(struct seq_file___193 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___193 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___149 *, struct cftype___149 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___149 *, struct cftype___149 *, s64);
	ssize_t (*write)(struct kernfs_open_file___206 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___206 *, struct poll_table_struct___143 *);
};

struct blkcg_policy_data___106;

struct blkcg___106 {
	struct cgroup_subsys_state___149 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___106 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___106 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___106 {
	struct blkcg___106 *blkcg;
	int plid;
};

struct blkg_policy_data___106 {
	struct blkcg_gq___106 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___95 {
	struct mem_cgroup___95 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___95 {
	struct lruvec___103 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___95 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___95 *memcg;
};

struct obj_cgroup___95 {
	struct percpu_ref refcnt;
	struct mem_cgroup___95 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

typedef unsigned int (*ata_xlat_func_t)(struct ata_queued_cmd___2 *);

struct ata_scsi_args {
	struct ata_device___2 *dev;
	u16 *id;
	struct scsi_cmnd___8 *cmd;
};

struct pci_bus___18;

struct pci_slot___18 {
	struct pci_bus___18 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___206 kobj;
};

struct pci_dev___18;

struct pci_ops___18;

struct pci_bus___18 {
	struct list_head node;
	struct pci_bus___18 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___18 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___18 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___196 *bridge;
	struct device___196 dev;
	struct bin_attribute___206 *legacy_io;
	struct bin_attribute___206 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___18;

struct pci_dev___18 {
	struct list_head bus_list;
	struct pci_bus___18 *bus;
	struct pci_bus___18 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___18 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___18 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___18 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___196 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___206 *res_attr[17];
	struct bin_attribute___206 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___206 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___18 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___18;

struct pci_driver___18 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___18 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___18 *);
	int (*suspend)(struct pci_dev___18 *, pm_message_t);
	int (*resume)(struct pci_dev___18 *);
	void (*shutdown)(struct pci_dev___18 *);
	int (*sriov_configure)(struct pci_dev___18 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___18 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___18 *);
	const struct pci_error_handlers___18 *err_handler;
	const struct attribute_group___206 **groups;
	const struct attribute_group___206 **dev_groups;
	struct device_driver___196 driver;
	struct pci_dynids dynids;
};

struct pci_ops___18 {
	int (*add_bus)(struct pci_bus___18 *);
	void (*remove_bus)(struct pci_bus___18 *);
	void * (*map_bus)(struct pci_bus___18 *, unsigned int, int);
	int (*read)(struct pci_bus___18 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___18 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___18 {
	pci_ers_result_t (*error_detected)(struct pci_dev___18 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___18 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___18 *);
	void (*reset_prepare)(struct pci_dev___18 *);
	void (*reset_done)(struct pci_dev___18 *);
	void (*resume)(struct pci_dev___18 *);
};

enum ata_lpm_hints {
	ATA_LPM_EMPTY = 1,
	ATA_LPM_HIPM = 2,
	ATA_LPM_WAKE_ONLY = 4,
};

enum {
	ATA_EH_SPDN_NCQ_OFF = 1,
	ATA_EH_SPDN_SPEED_DOWN = 2,
	ATA_EH_SPDN_FALLBACK_TO_PIO = 4,
	ATA_EH_SPDN_KEEP_ERRORS = 8,
	ATA_EFLAG_IS_IO = 1,
	ATA_EFLAG_DUBIOUS_XFER = 2,
	ATA_EFLAG_OLD_ER = 2147483648,
	ATA_ECAT_NONE = 0,
	ATA_ECAT_ATA_BUS = 1,
	ATA_ECAT_TOUT_HSM = 2,
	ATA_ECAT_UNK_DEV = 3,
	ATA_ECAT_DUBIOUS_NONE = 4,
	ATA_ECAT_DUBIOUS_ATA_BUS = 5,
	ATA_ECAT_DUBIOUS_TOUT_HSM = 6,
	ATA_ECAT_DUBIOUS_UNK_DEV = 7,
	ATA_ECAT_NR = 8,
	ATA_EH_CMD_DFL_TIMEOUT = 5000,
	ATA_EH_RESET_COOL_DOWN = 5000,
	ATA_EH_PRERESET_TIMEOUT = 10000,
	ATA_EH_FASTDRAIN_INTERVAL = 3000,
	ATA_EH_UA_TRIES = 5,
	ATA_EH_PROBE_TRIAL_INTERVAL = 60000,
	ATA_EH_PROBE_TRIALS = 2,
};

struct ata_eh_cmd_timeout_ent {
	const u8 *commands;
	const long unsigned int *timeouts;
};

struct speed_down_verdict_arg {
	u64 since;
	int xfer_ok;
	int nr_errors[8];
};

struct transport_class___2 {
	struct class___196 class;
	int (*setup)(struct transport_container___3 *, struct device___196 *, struct device___196 *);
	int (*configure)(struct transport_container___3 *, struct device___196 *, struct device___196 *);
	int (*remove)(struct transport_container___3 *, struct device___196 *, struct device___196 *);
};

struct ata_internal {
	struct scsi_transport_template___2 t;
	struct device_attribute___31 private_port_attrs[3];
	struct device_attribute___31 private_link_attrs[3];
	struct device_attribute___31 private_dev_attrs[9];
	struct transport_container___3 link_attr_cont;
	struct transport_container___3 dev_attr_cont;
	struct device_attribute___31 *link_attrs[4];
	struct device_attribute___31 *port_attrs[4];
	struct device_attribute___31 *dev_attrs[10];
};

struct ata_show_ering_arg {
	char *buf;
	int written;
};

struct ata_port_info___2 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___2 *port_ops;
	void *private_data;
};

enum hsm_task_states {
	HSM_ST_IDLE = 0,
	HSM_ST_FIRST = 1,
	HSM_ST = 2,
	HSM_ST_LAST = 3,
	HSM_ST_ERR = 4,
};

struct acpi_device___15;

struct acpi_hotplug_profile___15 {
	struct kobject___206 kobj;
	int (*scan_dependent)(struct acpi_device___15 *);
	void (*notify_online)(struct acpi_device___15 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___15 {
	void (*func)(struct acpi_device_wakeup_context___15 *);
	struct device___196 *dev;
};

struct acpi_device_wakeup___15 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___15 context;
	struct wakeup_source___196 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___15;

struct acpi_hotplug_context___15;

struct acpi_driver___15;

struct acpi_device___15 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___192 fwnode;
	struct acpi_device___15 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___15 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___15 *handler;
	struct acpi_hotplug_context___15 *hp;
	struct acpi_driver___15 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___196 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___15 *);
};

struct acpi_scan_handler___15 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___15 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___15 *);
	void (*bind)(struct device___196 *);
	void (*unbind)(struct device___196 *);
	struct acpi_hotplug_profile___15 hotplug;
};

struct acpi_hotplug_context___15 {
	struct acpi_device___15 *self;
	int (*notify)(struct acpi_device___15 *, u32);
	void (*uevent)(struct acpi_device___15 *, u32);
	void (*fixup)(struct acpi_device___15 *);
};

typedef int (*acpi_op_add___15)(struct acpi_device___15 *);

typedef int (*acpi_op_remove___15)(struct acpi_device___15 *);

typedef void (*acpi_op_notify___15)(struct acpi_device___15 *, u32);

struct acpi_device_ops___15 {
	acpi_op_add___15 add;
	acpi_op_remove___15 remove;
	acpi_op_notify___15 notify;
};

struct acpi_driver___15 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___15 ops;
	struct device_driver___196 drv;
	struct module___202 *owner;
};

struct ata_acpi_gtf {
	u8 tf[7];
};

struct ata_acpi_hotplug_context {
	struct acpi_hotplug_context___15 hp;
	union {
		struct ata_port___2 *ap;
		struct ata_device___2 *dev;
	} data;
};

struct dentry___219;

struct super_block___219;

struct module___203;

struct file_system_type___219 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___219 * (*mount)(struct file_system_type___219 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___219 *);
	struct module___203 *owner;
	struct file_system_type___219 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___219;

struct kiocb___219;

struct iov_iter___139;

struct poll_table_struct___144;

struct vm_area_struct___224;

struct inode___219;

struct file_lock___219;

struct page___224;

struct seq_file___194;

struct file_operations___220 {
	struct module___203 *owner;
	loff_t (*llseek)(struct file___219 *, loff_t, int);
	ssize_t (*read)(struct file___219 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___219 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___219 *, struct iov_iter___139 *);
	ssize_t (*write_iter)(struct kiocb___219 *, struct iov_iter___139 *);
	int (*iopoll)(struct kiocb___219 *, bool);
	int (*iterate)(struct file___219 *, struct dir_context *);
	int (*iterate_shared)(struct file___219 *, struct dir_context *);
	__poll_t (*poll)(struct file___219 *, struct poll_table_struct___144 *);
	long int (*unlocked_ioctl)(struct file___219 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___219 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___219 *, struct vm_area_struct___224 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___219 *, struct file___219 *);
	int (*flush)(struct file___219 *, fl_owner_t);
	int (*release)(struct inode___219 *, struct file___219 *);
	int (*fsync)(struct file___219 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___219 *, int);
	int (*lock)(struct file___219 *, int, struct file_lock___219 *);
	ssize_t (*sendpage)(struct file___219 *, struct page___224 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___219 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___219 *, long unsigned int);
	int (*flock)(struct file___219 *, int, struct file_lock___219 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___219 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___219 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___219 *, long int, struct file_lock___219 **, void **);
	long int (*fallocate)(struct file___219 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___194 *, struct file___219 *);
	ssize_t (*copy_file_range)(struct file___219 *, loff_t, struct file___219 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___219 *, loff_t, struct file___219 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___219 *, loff_t, loff_t, int);
};

struct vmacache___224 {
	u64 seqnum;
	struct vm_area_struct___224 *vmas[4];
};

struct page_frag___224 {
	struct page___224 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___225;

struct pid___196;

struct nsproxy___205;

struct signal_struct___220;

struct bio_list___115;

struct io_context___115;

struct request_queue___115;

struct vm_struct___202;

struct task_struct___226 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___226 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___225 *mm;
	struct mm_struct___225 *active_mm;
	struct vmacache___224 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___226 *real_parent;
	struct task_struct___226 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___226 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___196 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___205 *nsproxy;
	struct signal_struct___220 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___226 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___115 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___115 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___224 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___115 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___226 *oom_reaper_list;
	struct vm_struct___202 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___79 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___207;

struct kobj_type___207;

struct kernfs_node___207;

struct kobject___207 {
	const char *name;
	struct list_head entry;
	struct kobject___207 *parent;
	struct kset___207 *kset;
	struct kobj_type___207 *ktype;
	struct kernfs_node___207 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___204 {
	struct kobject___207 kobj;
	struct module___203 *mod;
	struct kobject___207 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___203 {
	struct module___203 *mod;
	struct latch_tree_node node;
};

struct module_layout___203 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___203 mtn;
};

struct module_attribute___203;

struct kernel_param___203;

struct module___203 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___204 mkobj;
	struct module_attribute___203 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___207 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___203 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___203 core_layout;
	struct module_layout___203 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___196;

struct upid___196 {
	int nr;
	struct pid_namespace___196 *ns;
};

struct pid_namespace___196 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___226 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___196 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___196 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___196 numbers[1];
};

typedef struct page___224 *pgtable_t___224;

struct address_space___219;

struct dev_pagemap___214;

struct page___224 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___219 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___31 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___224 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___224 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___225 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___214 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___214;

struct vm_area_struct___224 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___224 *vm_next;
	struct vm_area_struct___224 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___225 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___214 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___219 *vm_file;
	struct file___219 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___220 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___226 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___226 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___196 *pids[4];
	struct pid___196 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___225 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___224;

struct mm_struct___225 {
	struct {
		struct vm_area_struct___224 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___219 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___224 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___226 *owner;
		struct user_namespace *user_ns;
		struct file___219 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___205 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___196 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___115;

struct bio_list___115 {
	struct bio___115 *head;
	struct bio___115 *tail;
};

struct io_cq___115;

struct io_context___115 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___115 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___115;

struct blk_integrity___115 {
	const struct blk_integrity_profile___115 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___115 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___115 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___115;

struct elevator_queue___115;

struct blk_mq_ops___112;

struct blk_mq_hw_ctx___112;

struct gendisk___118;

struct device___197;

struct blk_mq_tag_set___112;

struct request_queue___115 {
	struct request___115 *last_merge;
	struct elevator_queue___115 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___112 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___112 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___118 *disk;
	struct kobject___207 kobj;
	struct kobject___207 *mq_kobj;
	struct blk_integrity___115 integrity;
	struct device___197 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___112 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___115 bio_split;
	struct dentry___219 *debugfs_dir;
	struct dentry___219 *sched_debugfs_dir;
	struct dentry___219 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___202 {
	struct vm_struct___202 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___224 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct irq_desc___54;

typedef void (*irq_flow_handler_t___54)(struct irq_desc___54 *);

struct irq_chip___54;

struct irq_domain___52;

struct irq_data___54 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___54 *chip;
	struct irq_domain___52 *domain;
	struct irq_data___54 *parent_data;
	void *chip_data;
};

struct irqaction___36;

struct irq_desc___54 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___54 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___54 handle_irq;
	struct irqaction___36 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___207 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___203 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct address_space_operations___219;

struct address_space___219 {
	struct inode___219 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___219 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___214;

struct dev_pagemap___214 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___214 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___219;

struct path___219 {
	struct vfsmount___219 *mnt;
	struct dentry___219 *dentry;
};

struct fown_struct___196 {
	rwlock_t lock;
	struct pid___196 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___219 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___219 f_path;
	struct inode___219 *f_inode;
	const struct file_operations___220 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___196 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___219 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___214;

struct vm_operations_struct___214 {
	void (*open)(struct vm_area_struct___224 *);
	void (*close)(struct vm_area_struct___224 *);
	int (*may_split)(struct vm_area_struct___224 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___224 *);
	int (*mprotect)(struct vm_area_struct___224 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___214 *);
	vm_fault_t (*huge_fault)(struct vm_fault___214 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___214 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___224 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___214 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___214 *);
	int (*access)(struct vm_area_struct___224 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___224 *);
	int (*set_policy)(struct vm_area_struct___224 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___224 *, long unsigned int);
	struct page___224 * (*find_special_page)(struct vm_area_struct___224 *, long unsigned int);
};

struct core_thread___224 {
	struct task_struct___226 *task;
	struct core_thread___224 *next;
};

struct core_state___224 {
	atomic_t nr_threads;
	struct core_thread___224 dumper;
	struct completion startup;
};

struct vm_fault___214 {
	const struct {
		struct vm_area_struct___224 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___224 *cow_page;
	struct page___224 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___224 prealloc_pte;
};

struct fwnode_operations___193;

struct fwnode_handle___193 {
	struct fwnode_handle___193 *secondary;
	const struct fwnode_operations___193 *ops;
	struct device___197 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___193;

struct fwnode_endpoint___193;

struct fwnode_operations___193 {
	struct fwnode_handle___193 * (*get)(struct fwnode_handle___193 *);
	void (*put)(struct fwnode_handle___193 *);
	bool (*device_is_available)(const struct fwnode_handle___193 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___193 *, const struct device___197 *);
	bool (*property_present)(const struct fwnode_handle___193 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___193 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___193 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___193 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*get_parent)(const struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*get_next_child_node)(const struct fwnode_handle___193 *, struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*get_named_child_node)(const struct fwnode_handle___193 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___193 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___193 *);
	struct fwnode_handle___193 * (*graph_get_next_endpoint)(const struct fwnode_handle___193 *, struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*graph_get_remote_endpoint)(const struct fwnode_handle___193 *);
	struct fwnode_handle___193 * (*graph_get_port_parent)(struct fwnode_handle___193 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___193 *, struct fwnode_endpoint___193 *);
	int (*add_links)(struct fwnode_handle___193 *);
};

struct wakeup_source___197;

struct dev_pm_qos___24;

struct dev_pm_info___197 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___197 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data *subsys_data;
	void (*set_latency_tolerance)(struct device___197 *, s32);
	struct dev_pm_qos___24 *qos;
};

struct device_type___197;

struct bus_type___197;

struct device_driver___197;

struct dev_pm_domain___197;

struct device_node___85;

struct class___197;

struct attribute_group___207;

struct device___197 {
	struct kobject___207 kobj;
	struct device___197 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___197 *type;
	struct bus_type___197 *bus;
	struct device_driver___197 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___197 power;
	struct dev_pm_domain___197 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___52 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___85 *of_node;
	struct fwnode_handle___193 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___197 *class;
	const struct attribute_group___207 **groups;
	void (*release)(struct device___197 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___193 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___193 *local_fwnode;
};

struct fwnode_reference_args___193 {
	struct fwnode_handle___193 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___54 {
	struct device___197 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___54 *);
	void (*irq_shutdown)(struct irq_data___54 *);
	void (*irq_enable)(struct irq_data___54 *);
	void (*irq_disable)(struct irq_data___54 *);
	void (*irq_ack)(struct irq_data___54 *);
	void (*irq_mask)(struct irq_data___54 *);
	void (*irq_mask_ack)(struct irq_data___54 *);
	void (*irq_unmask)(struct irq_data___54 *);
	void (*irq_eoi)(struct irq_data___54 *);
	int (*irq_set_affinity)(struct irq_data___54 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___54 *);
	int (*irq_set_type)(struct irq_data___54 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___54 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___54 *);
	void (*irq_bus_sync_unlock)(struct irq_data___54 *);
	void (*irq_cpu_online)(struct irq_data___54 *);
	void (*irq_cpu_offline)(struct irq_data___54 *);
	void (*irq_suspend)(struct irq_data___54 *);
	void (*irq_resume)(struct irq_data___54 *);
	void (*irq_pm_shutdown)(struct irq_data___54 *);
	void (*irq_calc_mask)(struct irq_data___54 *);
	void (*irq_print_chip)(struct irq_data___54 *, struct seq_file___194 *);
	int (*irq_request_resources)(struct irq_data___54 *);
	void (*irq_release_resources)(struct irq_data___54 *);
	void (*irq_compose_msi_msg)(struct irq_data___54 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___54 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___54 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___54 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___54 *, void *);
	void (*ipi_send_single)(struct irq_data___54 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___54 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___54 *);
	void (*irq_nmi_teardown)(struct irq_data___54 *);
	long unsigned int flags;
};

struct irq_domain_ops___52;

struct irq_domain_chip_generic___52;

struct irq_domain___52 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___52 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___193 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___52 *gc;
	struct irq_domain___52 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___54 *revmap[0];
};

struct seq_operations___194;

struct seq_file___194 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___194 *op;
	int poll_event;
	const struct file___219 *file;
	void *private;
};

struct kernfs_root___207;

struct kernfs_elem_dir___207 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___207 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___207;

struct kernfs_root___207 {
	struct kernfs_node___207 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___207 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___207 {
	struct kernfs_node___207 *target_kn;
};

struct kernfs_ops___207;

struct kernfs_elem_attr___207 {
	const struct kernfs_ops___207 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___207 *notify_next;
};

struct kernfs_node___207 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___207 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___207 dir;
		struct kernfs_elem_symlink___207 symlink;
		struct kernfs_elem_attr___207 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___207;

struct kernfs_ops___207 {
	int (*open)(struct kernfs_open_file___207 *);
	void (*release)(struct kernfs_open_file___207 *);
	int (*seq_show)(struct seq_file___194 *, void *);
	void * (*seq_start)(struct seq_file___194 *, loff_t *);
	void * (*seq_next)(struct seq_file___194 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___194 *, void *);
	ssize_t (*read)(struct kernfs_open_file___207 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___207 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___207 *, struct poll_table_struct___144 *);
	int (*mmap)(struct kernfs_open_file___207 *, struct vm_area_struct___224 *);
};

struct kernfs_syscall_ops___207 {
	int (*show_options)(struct seq_file___194 *, struct kernfs_root___207 *);
	int (*mkdir)(struct kernfs_node___207 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___207 *);
	int (*rename)(struct kernfs_node___207 *, struct kernfs_node___207 *, const char *);
	int (*show_path)(struct seq_file___194 *, struct kernfs_node___207 *, struct kernfs_root___207 *);
};

struct kernfs_open_file___207 {
	struct kernfs_node___207 *kn;
	struct file___219 *file;
	struct seq_file___194 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___214 *vm_ops;
};

typedef void (*poll_queue_proc___151)(struct file___219 *, wait_queue_head_t *, struct poll_table_struct___144 *);

struct poll_table_struct___144 {
	poll_queue_proc___151 _qproc;
	__poll_t _key;
};

struct bin_attribute___207;

struct attribute_group___207 {
	const char *name;
	umode_t (*is_visible)(struct kobject___207 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___207 *, struct bin_attribute___207 *, int);
	struct attribute **attrs;
	struct bin_attribute___207 **bin_attrs;
};

struct bin_attribute___207 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___219 * (*f_mapping)();
	ssize_t (*read)(struct file___219 *, struct kobject___207 *, struct bin_attribute___207 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___219 *, struct kobject___207 *, struct bin_attribute___207 *, char *, loff_t, size_t);
	int (*mmap)(struct file___219 *, struct kobject___207 *, struct bin_attribute___207 *, struct vm_area_struct___224 *);
};

struct sysfs_ops___207 {
	ssize_t (*show)(struct kobject___207 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___207 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___207;

struct kset___207 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___207 kobj;
	const struct kset_uevent_ops___207 *uevent_ops;
};

struct kobj_type___207 {
	void (*release)(struct kobject___207 *);
	const struct sysfs_ops___207 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___207 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___207 *);
	const void * (*namespace)(struct kobject___207 *);
	void (*get_ownership)(struct kobject___207 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___207 {
	int (* const filter)(struct kset___207 *, struct kobject___207 *);
	const char * (* const name)(struct kset___207 *, struct kobject___207 *);
	int (* const uevent)(struct kset___207 *, struct kobject___207 *, struct kobj_uevent_env *);
};

struct irqaction___36 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___36 *next;
	irq_handler_t thread_fn;
	struct task_struct___226 *thread;
	struct irqaction___36 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___52 {
	struct irq_chip___54 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___54 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___52 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___52 *);
	void (*resume)(struct irq_chip_generic___52 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___52 *domain;
	struct list_head list;
	struct irq_chip_type___52 chip_types[0];
};

struct irq_domain_chip_generic___52 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___52 *gc[0];
};

struct dev_pm_ops___197 {
	int (*prepare)(struct device___197 *);
	void (*complete)(struct device___197 *);
	int (*suspend)(struct device___197 *);
	int (*resume)(struct device___197 *);
	int (*freeze)(struct device___197 *);
	int (*thaw)(struct device___197 *);
	int (*poweroff)(struct device___197 *);
	int (*restore)(struct device___197 *);
	int (*suspend_late)(struct device___197 *);
	int (*resume_early)(struct device___197 *);
	int (*freeze_late)(struct device___197 *);
	int (*thaw_early)(struct device___197 *);
	int (*poweroff_late)(struct device___197 *);
	int (*restore_early)(struct device___197 *);
	int (*suspend_noirq)(struct device___197 *);
	int (*resume_noirq)(struct device___197 *);
	int (*freeze_noirq)(struct device___197 *);
	int (*thaw_noirq)(struct device___197 *);
	int (*poweroff_noirq)(struct device___197 *);
	int (*restore_noirq)(struct device___197 *);
	int (*runtime_suspend)(struct device___197 *);
	int (*runtime_resume)(struct device___197 *);
	int (*runtime_idle)(struct device___197 *);
};

struct wakeup_source___197 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___197 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___24;

struct dev_pm_qos___24 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___24 *resume_latency_req;
	struct dev_pm_qos_request___24 *latency_tolerance_req;
	struct dev_pm_qos_request___24 *flags_req;
};

struct dev_pm_domain___197 {
	struct dev_pm_ops___197 ops;
	int (*start)(struct device___197 *);
	void (*detach)(struct device___197 *, bool);
	int (*activate)(struct device___197 *);
	void (*sync)(struct device___197 *);
	void (*dismiss)(struct device___197 *);
};

struct bus_type___197 {
	const char *name;
	const char *dev_name;
	struct device___197 *dev_root;
	const struct attribute_group___207 **bus_groups;
	const struct attribute_group___207 **dev_groups;
	const struct attribute_group___207 **drv_groups;
	int (*match)(struct device___197 *, struct device_driver___197 *);
	int (*uevent)(struct device___197 *, struct kobj_uevent_env *);
	int (*probe)(struct device___197 *);
	void (*sync_state)(struct device___197 *);
	void (*remove)(struct device___197 *);
	void (*shutdown)(struct device___197 *);
	int (*online)(struct device___197 *);
	int (*offline)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	int (*num_vf)(struct device___197 *);
	int (*dma_configure)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___197 {
	const char *name;
	struct bus_type___197 *bus;
	struct module___203 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___197 *);
	void (*sync_state)(struct device___197 *);
	int (*remove)(struct device___197 *);
	void (*shutdown)(struct device___197 *);
	int (*suspend)(struct device___197 *, pm_message_t);
	int (*resume)(struct device___197 *);
	const struct attribute_group___207 **groups;
	const struct attribute_group___207 **dev_groups;
	const struct dev_pm_ops___197 *pm;
	void (*coredump)(struct device___197 *);
	struct driver_private *p;
};

struct device_type___197 {
	const char *name;
	const struct attribute_group___207 **groups;
	int (*uevent)(struct device___197 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___197 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___197 *);
	const struct dev_pm_ops___197 *pm;
};

struct class___197 {
	const char *name;
	struct module___203 *owner;
	const struct attribute_group___207 **class_groups;
	const struct attribute_group___207 **dev_groups;
	struct kobject___207 *dev_kobj;
	int (*dev_uevent)(struct device___197 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___197 *, umode_t *);
	void (*class_release)(struct class___197 *);
	void (*dev_release)(struct device___197 *);
	int (*shutdown_pre)(struct device___197 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___197 *);
	void (*get_ownership)(struct device___197 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___197 *pm;
	struct subsys_private *p;
};

struct device_attribute___32 {
	struct attribute attr;
	ssize_t (*show)(struct device___197 *, struct device_attribute___32 *, char *);
	ssize_t (*store)(struct device___197 *, struct device_attribute___32 *, const char *, size_t);
};

struct property___62;

struct device_node___85 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___193 fwnode;
	struct property___62 *properties;
	struct property___62 *deadprops;
	struct device_node___85 *parent;
	struct device_node___85 *child;
	struct device_node___85 *sibling;
	struct kobject___207 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___214 {
	void (*page_free)(struct page___224 *);
	void (*kill)(struct dev_pagemap___214 *);
	void (*cleanup)(struct dev_pagemap___214 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___214 *);
};

struct dentry_operations___219;

struct dentry___219 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___219 *d_parent;
	struct qstr d_name;
	struct inode___219 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___219 *d_op;
	struct super_block___219 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___219;

struct cdev___57;

struct inode___219 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___219 *i_op;
	struct super_block___219 *i_sb;
	struct address_space___219 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___220 *i_fop;
		void (*free_inode)(struct inode___219 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___219 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___57 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___219 {
	int (*d_revalidate)(struct dentry___219 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___219 *, unsigned int);
	int (*d_hash)(const struct dentry___219 *, struct qstr *);
	int (*d_compare)(const struct dentry___219 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___219 *);
	int (*d_init)(struct dentry___219 *);
	void (*d_release)(struct dentry___219 *);
	void (*d_prune)(struct dentry___219 *);
	void (*d_iput)(struct dentry___219 *, struct inode___219 *);
	char * (*d_dname)(struct dentry___219 *, char *, int);
	struct vfsmount___219 * (*d_automount)(struct path___219 *);
	int (*d_manage)(const struct path___219 *, bool);
	struct dentry___219 * (*d_real)(struct dentry___219 *, const struct inode___219 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___219;

struct mem_dqinfo___219 {
	struct quota_format_type___219 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___219;

struct quota_info___219 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___219 *files[3];
	struct mem_dqinfo___219 info[3];
	const struct quota_format_ops___219 *ops[3];
};

struct rcuwait___220 {
	struct task_struct___226 *task;
};

struct percpu_rw_semaphore___220 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___220 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___219 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___220 rw_sem[3];
};

struct super_operations___219;

struct dquot_operations___219;

struct quotactl_ops___219;

struct block_device___118;

struct super_block___219 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___219 *s_type;
	const struct super_operations___219 *s_op;
	const struct dquot_operations___219 *dq_op;
	const struct quotactl_ops___219 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___219 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___118 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___219 s_dquot;
	struct sb_writers___219 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___219 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___219 {
	struct dentry___219 *mnt_root;
	struct super_block___219 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___115 {
	struct request_queue___115 *q;
	struct io_context___115 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___219 {
	struct file___219 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___219 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___219 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___219 *ia_file;
};

struct dquot___219 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___219 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___219 {
	int qf_fmt_id;
	const struct quota_format_ops___219 *qf_ops;
	struct module___203 *qf_owner;
	struct quota_format_type___219 *qf_next;
};

struct quota_format_ops___219 {
	int (*check_quota_file)(struct super_block___219 *, int);
	int (*read_file_info)(struct super_block___219 *, int);
	int (*write_file_info)(struct super_block___219 *, int);
	int (*free_file_info)(struct super_block___219 *, int);
	int (*read_dqblk)(struct dquot___219 *);
	int (*commit_dqblk)(struct dquot___219 *);
	int (*release_dqblk)(struct dquot___219 *);
	int (*get_next_id)(struct super_block___219 *, struct kqid *);
};

struct dquot_operations___219 {
	int (*write_dquot)(struct dquot___219 *);
	struct dquot___219 * (*alloc_dquot)(struct super_block___219 *, int);
	void (*destroy_dquot)(struct dquot___219 *);
	int (*acquire_dquot)(struct dquot___219 *);
	int (*release_dquot)(struct dquot___219 *);
	int (*mark_dirty)(struct dquot___219 *);
	int (*write_info)(struct super_block___219 *, int);
	qsize_t * (*get_reserved_space)(struct inode___219 *);
	int (*get_projid)(struct inode___219 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___219 *, qsize_t *);
	int (*get_next_id)(struct super_block___219 *, struct kqid *);
};

struct quotactl_ops___219 {
	int (*quota_on)(struct super_block___219 *, int, int, const struct path___219 *);
	int (*quota_off)(struct super_block___219 *, int);
	int (*quota_enable)(struct super_block___219 *, unsigned int);
	int (*quota_disable)(struct super_block___219 *, unsigned int);
	int (*quota_sync)(struct super_block___219 *, int);
	int (*set_info)(struct super_block___219 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___219 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___219 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___219 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___219 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___219 *, unsigned int);
};

struct address_space_operations___219 {
	int (*writepage)(struct page___224 *, struct writeback_control___3 *);
	int (*readpage)(struct file___219 *, struct page___224 *);
	int (*writepages)(struct address_space___219 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___224 *);
	int (*readpages)(struct file___219 *, struct address_space___219 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___219 *, struct address_space___219 *, loff_t, unsigned int, unsigned int, struct page___224 **, void **);
	int (*write_end)(struct file___219 *, struct address_space___219 *, loff_t, unsigned int, unsigned int, struct page___224 *, void *);
	sector_t (*bmap)(struct address_space___219 *, sector_t);
	void (*invalidatepage)(struct page___224 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___224 *, gfp_t);
	void (*freepage)(struct page___224 *);
	ssize_t (*direct_IO)(struct kiocb___219 *, struct iov_iter___139 *);
	int (*migratepage)(struct address_space___219 *, struct page___224 *, struct page___224 *, enum migrate_mode);
	bool (*isolate_page)(struct page___224 *, isolate_mode_t);
	void (*putback_page)(struct page___224 *);
	int (*launder_page)(struct page___224 *);
	int (*is_partially_uptodate)(struct page___224 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___224 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___219 *, struct page___224 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___219 *, sector_t *);
	void (*swap_deactivate)(struct file___219 *);
};

struct bio_vec___136;

struct iov_iter___139 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___136 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___57 {
	struct kobject___207 kobj;
	struct module___203 *owner;
	const struct file_operations___220 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___219 {
	struct dentry___219 * (*lookup)(struct inode___219 *, struct dentry___219 *, unsigned int);
	const char * (*get_link)(struct dentry___219 *, struct inode___219 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___219 *, int);
	struct posix_acl * (*get_acl)(struct inode___219 *, int, bool);
	int (*readlink)(struct dentry___219 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___219 *, struct dentry___219 *, umode_t, bool);
	int (*link)(struct dentry___219 *, struct inode___219 *, struct dentry___219 *);
	int (*unlink)(struct inode___219 *, struct dentry___219 *);
	int (*symlink)(struct user_namespace *, struct inode___219 *, struct dentry___219 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___219 *, struct dentry___219 *, umode_t);
	int (*rmdir)(struct inode___219 *, struct dentry___219 *);
	int (*mknod)(struct user_namespace *, struct inode___219 *, struct dentry___219 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___219 *, struct dentry___219 *, struct inode___219 *, struct dentry___219 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___219 *, struct iattr___219 *);
	int (*getattr)(struct user_namespace *, const struct path___219 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___219 *, char *, size_t);
	int (*fiemap)(struct inode___219 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___219 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___219 *, struct dentry___219 *, struct file___219 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___219 *, struct dentry___219 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___219 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___219 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___219 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___219 {
	void (*fl_copy_lock)(struct file_lock___219 *, struct file_lock___219 *);
	void (*fl_release_private)(struct file_lock___219 *);
};

struct fasync_struct___219;

struct lock_manager_operations___219;

struct file_lock___219 {
	struct file_lock___219 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___219 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___219 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___219 *fl_ops;
	const struct lock_manager_operations___219 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___219 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___219 *);
	int (*lm_grant)(struct file_lock___219 *, int);
	bool (*lm_break)(struct file_lock___219 *);
	int (*lm_change)(struct file_lock___219 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___219 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___219 *);
};

struct fasync_struct___219 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___219 *fa_next;
	struct file___219 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___219 {
	struct inode___219 * (*alloc_inode)(struct super_block___219 *);
	void (*destroy_inode)(struct inode___219 *);
	void (*free_inode)(struct inode___219 *);
	void (*dirty_inode)(struct inode___219 *, int);
	int (*write_inode)(struct inode___219 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___219 *);
	void (*evict_inode)(struct inode___219 *);
	void (*put_super)(struct super_block___219 *);
	int (*sync_fs)(struct super_block___219 *, int);
	int (*freeze_super)(struct super_block___219 *);
	int (*freeze_fs)(struct super_block___219 *);
	int (*thaw_super)(struct super_block___219 *);
	int (*unfreeze_fs)(struct super_block___219 *);
	int (*statfs)(struct dentry___219 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___219 *, int *, char *);
	void (*umount_begin)(struct super_block___219 *);
	int (*show_options)(struct seq_file___194 *, struct dentry___219 *);
	int (*show_devname)(struct seq_file___194 *, struct dentry___219 *);
	int (*show_path)(struct seq_file___194 *, struct dentry___219 *);
	int (*show_stats)(struct seq_file___194 *, struct dentry___219 *);
	ssize_t (*quota_read)(struct super_block___219 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___219 *, int, const char *, size_t, loff_t);
	struct dquot___219 ** (*get_dquots)(struct inode___219 *);
	long int (*nr_cached_objects)(struct super_block___219 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___219 *, struct shrink_control___95 *);
	struct file___219 * (*real_loop)(struct file___219 *);
};

struct block_device___118 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___219 *bd_inode;
	struct super_block___219 *bd_super;
	void *bd_claiming;
	struct device___197 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___207 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___118 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___219 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___115(struct bio___115 *);

struct bio_vec___136 {
	struct page___224 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___115;

struct bio___115 {
	struct bio___115 *bi_next;
	struct block_device___118 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___115 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___115 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___136 *bi_io_vec;
	struct bio_set___115 *bi_pool;
	struct bio_vec___136 bi_inline_vecs[0];
};

struct seq_operations___194 {
	void * (*start)(struct seq_file___194 *, loff_t *);
	void (*stop)(struct seq_file___194 *, void *);
	void * (*next)(struct seq_file___194 *, void *, loff_t *);
	int (*show)(struct seq_file___194 *, void *);
};

struct kernel_param_ops___203 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___203 *);
	int (*get)(char *, const struct kernel_param___203 *);
	void (*free)(void *);
};

struct kparam_array___203;

struct kernel_param___203 {
	const char *name;
	struct module___203 *mod;
	const struct kernel_param_ops___203 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___203 *arr;
	};
};

struct kparam_array___203 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___203 *ops;
	void *elem;
};

struct module_attribute___203 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___203 *, struct module_kobject___204 *, char *);
	ssize_t (*store)(struct module_attribute___203 *, struct module_kobject___204 *, const char *, size_t);
	void (*setup)(struct module___203 *, const char *);
	int (*test)(struct module___203 *);
	void (*free)(struct module___203 *);
};

struct block_device_operations___115;

struct cdrom_device_info___5;

struct gendisk___118 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___118 *part0;
	const struct block_device_operations___115 *fops;
	struct request_queue___115 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___207 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___207 integrity_kobj;
	struct cdrom_device_info___5 *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___115 {
	struct bio___115 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___136 *bip_vec;
	struct bio_vec___136 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___115(struct request___115 *);

typedef void integrity_complete_fn___115(struct request___115 *, unsigned int);

struct blk_integrity_profile___115 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___115 *prepare_fn;
	integrity_complete_fn___115 *complete_fn;
	const char *name;
};

struct block_device_operations___115 {
	blk_qc_t (*submit_bio)(struct bio___115 *);
	int (*open)(struct block_device___118 *, fmode_t);
	void (*release)(struct gendisk___118 *, fmode_t);
	int (*rw_page)(struct block_device___118 *, sector_t, struct page___224 *, unsigned int);
	int (*ioctl)(struct block_device___118 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___118 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___118 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___118 *);
	int (*getgeo)(struct block_device___118 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___118 *, bool);
	void (*swap_slot_free_notify)(struct block_device___118 *, long unsigned int);
	int (*report_zones)(struct gendisk___118 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___118 *, umode_t *);
	struct module___203 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___118 *, sector_t *);
};

struct cdrom_device_ops___5;

struct cdrom_device_info___5 {
	const struct cdrom_device_ops___5 *ops;
	struct list_head list;
	struct gendisk___118 *disk;
	void *handle;
	int mask;
	int speed;
	int capacity;
	unsigned int options: 30;
	unsigned int mc_flags: 2;
	long: 62;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int vfs_events;
	unsigned int ioctl_events;
	int use_count;
	char name[20];
	__u8 sanyo_slot: 2;
	__u8 keeplocked: 1;
	__u8 reserved: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int cdda_method;
	__u8 last_sense;
	__u8 media_written;
	short unsigned int mmc3_profile;
	int for_data;
	int (*exit)(struct cdrom_device_info___5 *);
	int mrw_mode_page;
};

typedef void rq_end_io_fn___115(struct request___115 *, blk_status_t);

struct request___115 {
	struct request_queue___115 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___112 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___115 *bio;
	struct bio___115 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___136 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___115 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___115 *saved_end_io;
		} flush;
	};
	struct gendisk___118 *rq_disk;
	struct block_device___118 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___115 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___112 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___115 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___207 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___219 *debugfs_dir;
	struct dentry___219 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___115;

struct elevator_mq_ops___115 {
	int (*init_sched)(struct request_queue___115 *, struct elevator_type___115 *);
	void (*exit_sched)(struct elevator_queue___115 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___112 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___112 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___112 *);
	bool (*allow_merge)(struct request_queue___115 *, struct request___115 *, struct bio___115 *);
	bool (*bio_merge)(struct request_queue___115 *, struct bio___115 *, unsigned int);
	int (*request_merge)(struct request_queue___115 *, struct request___115 **, struct bio___115 *);
	void (*request_merged)(struct request_queue___115 *, struct request___115 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___115 *, struct request___115 *, struct request___115 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___115 *);
	void (*finish_request)(struct request___115 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___112 *, struct list_head *, bool);
	struct request___115 * (*dispatch_request)(struct blk_mq_hw_ctx___112 *);
	bool (*has_work)(struct blk_mq_hw_ctx___112 *);
	void (*completed_request)(struct request___115 *, u64);
	void (*requeue_request)(struct request___115 *);
	struct request___115 * (*former_request)(struct request_queue___115 *, struct request___115 *);
	struct request___115 * (*next_request)(struct request_queue___115 *, struct request___115 *);
	void (*init_icq)(struct io_cq___115 *);
	void (*exit_icq)(struct io_cq___115 *);
};

struct elv_fs_entry___115;

struct elevator_type___115 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___115 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___115 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___203 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___115 {
	struct elevator_type___115 *type;
	void *elevator_data;
	struct kobject___207 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___115 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___115 *, char *);
	ssize_t (*store)(struct elevator_queue___115 *, const char *, size_t);
};

struct blk_mq_queue_data___112;

struct blk_mq_ops___112 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___112 *, const struct blk_mq_queue_data___112 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___112 *);
	int (*get_budget)(struct request_queue___115 *);
	void (*put_budget)(struct request_queue___115 *, int);
	void (*set_rq_budget_token)(struct request___115 *, int);
	int (*get_rq_budget_token)(struct request___115 *);
	enum blk_eh_timer_return (*timeout)(struct request___115 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___112 *);
	void (*complete)(struct request___115 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___112 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___112 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___112 *, struct request___115 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___112 *, struct request___115 *, unsigned int);
	void (*initialize_rq_fn)(struct request___115 *);
	void (*cleanup_rq)(struct request___115 *);
	bool (*busy)(struct request_queue___115 *);
	int (*map_queues)(struct blk_mq_tag_set___112 *);
	void (*show_rq)(struct seq_file___194 *, struct request___115 *);
};

struct blk_mq_tag_set___112 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___112 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___112 {
	struct request___115 *rq;
	bool last;
};

struct Scsi_Host___9;

struct scsi_device___9;

struct scsi_target___9;

struct scsi_host_template___9 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___9 *, struct scsi_cmnd___2 *);
	void (*commit_rqs)(struct Scsi_Host___9 *, u16);
	struct module___203 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___9 *);
	int (*ioctl)(struct scsi_device___9 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___9 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___9 *, struct scsi_cmnd___2 *);
	int (*exit_cmd_priv)(struct Scsi_Host___9 *, struct scsi_cmnd___2 *);
	int (*eh_abort_handler)(struct scsi_cmnd___2 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___2 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___2 *);
	int (*slave_alloc)(struct scsi_device___9 *);
	int (*slave_configure)(struct scsi_device___9 *);
	void (*slave_destroy)(struct scsi_device___9 *);
	int (*target_alloc)(struct scsi_target___9 *);
	void (*target_destroy)(struct scsi_target___9 *);
	int (*scan_finished)(struct Scsi_Host___9 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___9 *);
	int (*change_queue_depth)(struct scsi_device___9 *, int);
	int (*map_queues)(struct Scsi_Host___9 *);
	int (*mq_poll)(struct Scsi_Host___9 *, unsigned int);
	bool (*dma_need_drain)(struct request___115 *);
	int (*bios_param)(struct scsi_device___9 *, struct block_device___118 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___9 *);
	int (*show_info)(struct seq_file___194 *, struct Scsi_Host___9 *);
	int (*write_info)(struct Scsi_Host___9 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___2 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___2 *);
	int (*host_reset)(struct Scsi_Host___9 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___32 **shost_attrs;
	struct device_attribute___32 **sdev_attrs;
	const struct attribute_group___207 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct Scsi_Host___9 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___226 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___9 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___112 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___197 shost_gendev;
	struct device___197 shost_dev;
	void *shost_data;
	struct device___197 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_device___9 {
	struct Scsi_Host___9 *host;
	struct request_queue___115 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___9 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr: 1;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___197 sdev_gendev;
	struct device___197 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___226 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_target___9 {
	struct scsi_device___9 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___197 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct property___62 {
	char *name;
	int length;
	void *value;
	struct property___62 *next;
	long unsigned int _flags;
	struct bin_attribute___207 attr;
};

struct irq_fwspec___50 {
	struct fwnode_handle___193 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___52 {
	int (*match)(struct irq_domain___52 *, struct device_node___85 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___52 *, struct irq_fwspec___50 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___52 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___52 *, unsigned int);
	int (*xlate)(struct irq_domain___52 *, struct device_node___85 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___52 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___52 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___52 *, struct irq_data___54 *, bool);
	void (*deactivate)(struct irq_domain___52 *, struct irq_data___54 *);
	int (*translate)(struct irq_domain___52 *, struct irq_fwspec___50 *, long unsigned int *, unsigned int *);
};

struct acpi_device___16;

struct acpi_hotplug_profile___16 {
	struct kobject___207 kobj;
	int (*scan_dependent)(struct acpi_device___16 *);
	void (*notify_online)(struct acpi_device___16 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___16 {
	void (*func)(struct acpi_device_wakeup_context___16 *);
	struct device___197 *dev;
};

struct acpi_device_wakeup___16 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___16 context;
	struct wakeup_source___197 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___16;

struct acpi_hotplug_context___16;

struct acpi_driver___16;

struct acpi_device___16 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___193 fwnode;
	struct acpi_device___16 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___16 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___16 *handler;
	struct acpi_hotplug_context___16 *hp;
	struct acpi_driver___16 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___197 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___16 *);
};

struct acpi_scan_handler___16 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___16 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___16 *);
	void (*bind)(struct device___197 *);
	void (*unbind)(struct device___197 *);
	struct acpi_hotplug_profile___16 hotplug;
};

struct acpi_hotplug_context___16 {
	struct acpi_device___16 *self;
	int (*notify)(struct acpi_device___16 *, u32);
	void (*uevent)(struct acpi_device___16 *, u32);
	void (*fixup)(struct acpi_device___16 *);
};

typedef int (*acpi_op_add___16)(struct acpi_device___16 *);

typedef int (*acpi_op_remove___16)(struct acpi_device___16 *);

typedef void (*acpi_op_notify___16)(struct acpi_device___16 *, u32);

struct acpi_device_ops___16 {
	acpi_op_add___16 add;
	acpi_op_remove___16 remove;
	acpi_op_notify___16 notify;
};

struct acpi_driver___16 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___16 ops;
	struct device_driver___197 drv;
	struct module___203 *owner;
};

struct rm_feature_desc {
	__be16 feature_code;
	__u8 curr: 1;
	__u8 persistent: 1;
	__u8 feature_version: 4;
	__u8 reserved1: 2;
	int: 22;
	__u8 add_len;
	__u8 lock: 1;
	__u8 dbml: 1;
	__u8 pvnt_jmpr: 1;
	__u8 eject: 1;
	__u8 load: 1;
	__u8 mech_type: 3;
	long: 37;
	__u8 reserved2;
	__u8 reserved3;
	__u8 reserved4;
};

struct cdrom_device_ops___5 {
	int (*open)(struct cdrom_device_info___5 *, int);
	void (*release)(struct cdrom_device_info___5 *);
	int (*drive_status)(struct cdrom_device_info___5 *, int);
	unsigned int (*check_events)(struct cdrom_device_info___5 *, unsigned int, int);
	int (*tray_move)(struct cdrom_device_info___5 *, int);
	int (*lock_door)(struct cdrom_device_info___5 *, int);
	int (*select_speed)(struct cdrom_device_info___5 *, int);
	int (*select_disc)(struct cdrom_device_info___5 *, int);
	int (*get_last_session)(struct cdrom_device_info___5 *, struct cdrom_multisession *);
	int (*get_mcn)(struct cdrom_device_info___5 *, struct cdrom_mcn *);
	int (*reset)(struct cdrom_device_info___5 *);
	int (*audio_ioctl)(struct cdrom_device_info___5 *, unsigned int, void *);
	int (*generic_packet)(struct cdrom_device_info___5 *, struct packet_command *);
	int (*read_cdda_bpc)(struct cdrom_device_info___5 *, void *, u32, u32, u8 *);
	const int capability;
};

struct ata_queued_cmd___3;

typedef void (*ata_qc_cb_t___3)(struct ata_queued_cmd___3 *);

struct ata_port___3;

struct ata_device___3;

struct ata_queued_cmd___3 {
	struct ata_port___3 *ap;
	struct ata_device___3 *dev;
	struct scsi_cmnd___2 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___2 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___3 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___3;

typedef int (*ata_prereset_fn_t___3)(struct ata_link___3 *, long unsigned int);

struct ata_eh_info___3 {
	struct ata_device___3 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___3 {
	struct ata_eh_info___3 i;
	int tries[2];
	int cmd_timeout_idx[14];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___3 {
	struct ata_link___3 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___9 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	void *zpodd;
	struct device___197 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___3 {
	struct ata_port___3 *ap;
	int pmp;
	struct device___197 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___3 eh_info;
	struct ata_eh_context___3 eh_context;
	long: 64;
	struct ata_device___3 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___3)(struct ata_link___3 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___3)(struct ata_link___3 *, unsigned int *);

struct ata_port_operations___3;

struct ata_host___3 {
	spinlock_t lock;
	struct device___197 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___3 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___226 *eh_owner;
	struct ata_port___3 *simplex_claimed;
	struct ata_port___3 *ports[0];
};

struct ata_port_operations___3 {
	int (*qc_defer)(struct ata_queued_cmd___3 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___3 *);
	enum ata_completion_errors (*qc_prep)(struct ata_queued_cmd___3 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___3 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___3 *);
	int (*cable_detect)(struct ata_port___3 *);
	long unsigned int (*mode_filter)(struct ata_device___3 *, long unsigned int);
	void (*set_piomode)(struct ata_port___3 *, struct ata_device___3 *);
	void (*set_dmamode)(struct ata_port___3 *, struct ata_device___3 *);
	int (*set_mode)(struct ata_link___3 *, struct ata_device___3 **);
	unsigned int (*read_id)(struct ata_device___3 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___3 *);
	void (*freeze)(struct ata_port___3 *);
	void (*thaw)(struct ata_port___3 *);
	ata_prereset_fn_t___3 prereset;
	ata_reset_fn_t___3 softreset;
	ata_reset_fn_t___3 hardreset;
	ata_postreset_fn_t___3 postreset;
	ata_prereset_fn_t___3 pmp_prereset;
	ata_reset_fn_t___3 pmp_softreset;
	ata_reset_fn_t___3 pmp_hardreset;
	ata_postreset_fn_t___3 pmp_postreset;
	void (*error_handler)(struct ata_port___3 *);
	void (*lost_interrupt)(struct ata_port___3 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___3 *);
	void (*sched_eh)(struct ata_port___3 *);
	void (*end_eh)(struct ata_port___3 *);
	int (*scr_read)(struct ata_link___3 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___3 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___3 *);
	void (*pmp_detach)(struct ata_port___3 *);
	int (*set_lpm)(struct ata_link___3 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___3 *, pm_message_t);
	int (*port_resume)(struct ata_port___3 *);
	int (*port_start)(struct ata_port___3 *);
	void (*port_stop)(struct ata_port___3 *);
	void (*host_stop)(struct ata_host___3 *);
	void (*sff_dev_select)(struct ata_port___3 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___3 *, u8);
	u8 (*sff_check_status)(struct ata_port___3 *);
	u8 (*sff_check_altstatus)(struct ata_port___3 *);
	void (*sff_tf_load)(struct ata_port___3 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___3 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___3 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___3 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___3 *);
	bool (*sff_irq_check)(struct ata_port___3 *);
	void (*sff_irq_clear)(struct ata_port___3 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___3 *);
	void (*bmdma_setup)(struct ata_queued_cmd___3 *);
	void (*bmdma_start)(struct ata_queued_cmd___3 *);
	void (*bmdma_stop)(struct ata_queued_cmd___3 *);
	u8 (*bmdma_status)(struct ata_port___3 *);
	ssize_t (*em_show)(struct ata_port___3 *, char *);
	ssize_t (*em_store)(struct ata_port___3 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___3 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___3 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___3 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___3 *);
	void (*eng_timeout)(struct ata_port___3 *);
	const struct ata_port_operations___3 *inherits;
};

struct ata_port___3 {
	struct Scsi_Host___9 *scsi_host;
	struct ata_port_operations___3 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___3 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___3 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	struct ata_link___3 link;
	struct ata_link___3 *slave_link;
	int nr_pmp_links;
	struct ata_link___3 *pmp_link;
	struct ata_link___3 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___3 *host;
	struct device___197 *dev;
	struct device___197 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	async_cookie_t cookie;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct dev_pm_qos_request___24 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___197 *dev;
};

enum odd_mech_type {
	ODD_MECH_TYPE_SLOT = 0,
	ODD_MECH_TYPE_DRAWER = 1,
	ODD_MECH_TYPE_UNSUPPORTED = 2,
};

struct zpodd {
	enum odd_mech_type mech_type;
	struct ata_device___3 *dev;
	bool from_notify;
	bool zp_ready;
	long unsigned int last_ready;
	bool zp_sampled;
	bool powered_off;
};

struct platform_device___35 {
	const char *name;
	int id;
	bool id_auto;
	struct device___196 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___29 {
	int (*probe)(struct platform_device___35 *);
	int (*remove)(struct platform_device___35 *);
	void (*shutdown)(struct platform_device___35 *);
	int (*suspend)(struct platform_device___35 *, pm_message_t);
	int (*resume)(struct platform_device___35 *);
	struct device_driver___196 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct sensor_device_attribute {
	struct device_attribute___31 dev_attr;
	int index;
};

struct thermal_zone_device_ops___2 {
	int (*bind)(struct thermal_zone_device *, struct thermal_cooling_device___3 *);
	int (*unbind)(struct thermal_zone_device *, struct thermal_cooling_device___3 *);
	int (*get_temp)(struct thermal_zone_device *, int *);
	int (*set_trips)(struct thermal_zone_device *, int, int);
	int (*change_mode)(struct thermal_zone_device *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device *, int *);
	int (*set_emul_temp)(struct thermal_zone_device *, int);
	int (*get_trend)(struct thermal_zone_device *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device *);
	void (*critical)(struct thermal_zone_device *);
};

struct thermal_zone_params___2;

struct thermal_governor___2;

struct thermal_zone_device {
	int id;
	char type[20];
	struct device___196 device;
	struct attribute_group___206 trips_attribute_group;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___2 *ops;
	struct thermal_zone_params___2 *tzp;
	struct thermal_governor___2 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___3;

struct thermal_cooling_device___3 {
	int id;
	char *type;
	struct device___196 device;
	struct device_node___84 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___3 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___3 {
	int (*get_max_state)(struct thermal_cooling_device___3 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___3 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___3 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___3 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___3 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___3 *, u32, long unsigned int *);
};

struct thermal_bind_params___2;

struct thermal_zone_params___2 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___2 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___2 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device *);
	void (*unbind_from_tz)(struct thermal_zone_device *);
	int (*throttle)(struct thermal_zone_device *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___2 {
	struct thermal_cooling_device___3 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device *, struct thermal_cooling_device___3 *);
};

struct thermal_zone_of_device_ops {
	int (*get_temp)(void *, int *);
	int (*get_trend)(void *, int, enum thermal_trend *);
	int (*set_trips)(void *, int, int);
	int (*set_emul_temp)(void *, int);
	int (*set_trip_temp)(void *, int, int);
};

struct phy___8;

struct phy_ops___7 {
	int (*init)(struct phy___8 *);
	int (*exit)(struct phy___8 *);
	int (*power_on)(struct phy___8 *);
	int (*power_off)(struct phy___8 *);
	int (*set_mode)(struct phy___8 *, enum phy_mode, int);
	int (*set_media)(struct phy___8 *, enum phy_media);
	int (*set_speed)(struct phy___8 *, int);
	int (*configure)(struct phy___8 *, union phy_configure_opts *);
	int (*validate)(struct phy___8 *, enum phy_mode, int, union phy_configure_opts *);
	int (*reset)(struct phy___8 *);
	int (*calibrate)(struct phy___8 *);
	void (*release)(struct phy___8 *);
	struct module___202 *owner;
};

struct phy___8 {
	struct device___196 dev;
	int id;
	const struct phy_ops___7 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

enum {
	AHCI_MAX_PORTS = 32,
	AHCI_MAX_CLKS = 5,
	AHCI_MAX_SG = 168,
	AHCI_DMA_BOUNDARY = 4294967295,
	AHCI_MAX_CMDS = 32,
	AHCI_CMD_SZ = 32,
	AHCI_CMD_SLOT_SZ = 1024,
	AHCI_RX_FIS_SZ = 256,
	AHCI_CMD_TBL_CDB = 64,
	AHCI_CMD_TBL_HDR_SZ = 128,
	AHCI_CMD_TBL_SZ = 2816,
	AHCI_CMD_TBL_AR_SZ = 90112,
	AHCI_PORT_PRIV_DMA_SZ = 91392,
	AHCI_PORT_PRIV_FBS_DMA_SZ = 95232,
	AHCI_IRQ_ON_SG = 2147483648,
	AHCI_CMD_ATAPI = 32,
	AHCI_CMD_WRITE = 64,
	AHCI_CMD_PREFETCH = 128,
	AHCI_CMD_RESET = 256,
	AHCI_CMD_CLR_BUSY = 1024,
	RX_FIS_PIO_SETUP = 32,
	RX_FIS_D2H_REG = 64,
	RX_FIS_SDB = 88,
	RX_FIS_UNK = 96,
	HOST_CAP = 0,
	HOST_CTL = 4,
	HOST_IRQ_STAT = 8,
	HOST_PORTS_IMPL = 12,
	HOST_VERSION = 16,
	HOST_EM_LOC = 28,
	HOST_EM_CTL = 32,
	HOST_CAP2 = 36,
	HOST_RESET = 1,
	HOST_IRQ_EN = 2,
	HOST_MRSM = 4,
	HOST_AHCI_EN = 2147483648,
	HOST_CAP_SXS = 32,
	HOST_CAP_EMS = 64,
	HOST_CAP_CCC = 128,
	HOST_CAP_PART = 8192,
	HOST_CAP_SSC = 16384,
	HOST_CAP_PIO_MULTI = 32768,
	HOST_CAP_FBS = 65536,
	HOST_CAP_PMP = 131072,
	HOST_CAP_ONLY = 262144,
	HOST_CAP_CLO = 16777216,
	HOST_CAP_LED = 33554432,
	HOST_CAP_ALPM = 67108864,
	HOST_CAP_SSS = 134217728,
	HOST_CAP_MPS = 268435456,
	HOST_CAP_SNTF = 536870912,
	HOST_CAP_NCQ = 1073741824,
	HOST_CAP_64 = 2147483648,
	HOST_CAP2_BOH = 1,
	HOST_CAP2_NVMHCI = 2,
	HOST_CAP2_APST = 4,
	HOST_CAP2_SDS = 8,
	HOST_CAP2_SADM = 16,
	HOST_CAP2_DESO = 32,
	PORT_LST_ADDR = 0,
	PORT_LST_ADDR_HI = 4,
	PORT_FIS_ADDR = 8,
	PORT_FIS_ADDR_HI = 12,
	PORT_IRQ_STAT = 16,
	PORT_IRQ_MASK = 20,
	PORT_CMD = 24,
	PORT_TFDATA = 32,
	PORT_SIG = 36,
	PORT_CMD_ISSUE = 56,
	PORT_SCR_STAT = 40,
	PORT_SCR_CTL = 44,
	PORT_SCR_ERR = 48,
	PORT_SCR_ACT = 52,
	PORT_SCR_NTF = 60,
	PORT_FBS = 64,
	PORT_DEVSLP = 68,
	PORT_IRQ_COLD_PRES = 2147483648,
	PORT_IRQ_TF_ERR = 1073741824,
	PORT_IRQ_HBUS_ERR = 536870912,
	PORT_IRQ_HBUS_DATA_ERR = 268435456,
	PORT_IRQ_IF_ERR = 134217728,
	PORT_IRQ_IF_NONFATAL = 67108864,
	PORT_IRQ_OVERFLOW = 16777216,
	PORT_IRQ_BAD_PMP = 8388608,
	PORT_IRQ_PHYRDY = 4194304,
	PORT_IRQ_DEV_ILCK = 128,
	PORT_IRQ_CONNECT = 64,
	PORT_IRQ_SG_DONE = 32,
	PORT_IRQ_UNK_FIS = 16,
	PORT_IRQ_SDB_FIS = 8,
	PORT_IRQ_DMAS_FIS = 4,
	PORT_IRQ_PIOS_FIS = 2,
	PORT_IRQ_D2H_REG_FIS = 1,
	PORT_IRQ_FREEZE = 683671632,
	PORT_IRQ_ERROR = 2025848912,
	DEF_PORT_IRQ = 2025848959,
	PORT_CMD_ASP = 134217728,
	PORT_CMD_ALPE = 67108864,
	PORT_CMD_ATAPI = 16777216,
	PORT_CMD_FBSCP = 4194304,
	PORT_CMD_ESP = 2097152,
	PORT_CMD_HPCP = 262144,
	PORT_CMD_PMP = 131072,
	PORT_CMD_LIST_ON = 32768,
	PORT_CMD_FIS_ON = 16384,
	PORT_CMD_FIS_RX = 16,
	PORT_CMD_CLO = 8,
	PORT_CMD_POWER_ON = 4,
	PORT_CMD_SPIN_UP = 2,
	PORT_CMD_START = 1,
	PORT_CMD_ICC_MASK = 4026531840,
	PORT_CMD_ICC_ACTIVE = 268435456,
	PORT_CMD_ICC_PARTIAL = 536870912,
	PORT_CMD_ICC_SLUMBER = 1610612736,
	PORT_FBS_DWE_OFFSET = 16,
	PORT_FBS_ADO_OFFSET = 12,
	PORT_FBS_DEV_OFFSET = 8,
	PORT_FBS_DEV_MASK = 3840,
	PORT_FBS_SDE = 4,
	PORT_FBS_DEC = 2,
	PORT_FBS_EN = 1,
	PORT_DEVSLP_DM_OFFSET = 25,
	PORT_DEVSLP_DM_MASK = 503316480,
	PORT_DEVSLP_DITO_OFFSET = 15,
	PORT_DEVSLP_MDAT_OFFSET = 10,
	PORT_DEVSLP_DETO_OFFSET = 2,
	PORT_DEVSLP_DSP = 2,
	PORT_DEVSLP_ADSE = 1,
	AHCI_HFLAG_NO_NCQ = 1,
	AHCI_HFLAG_IGN_IRQ_IF_ERR = 2,
	AHCI_HFLAG_IGN_SERR_INTERNAL = 4,
	AHCI_HFLAG_32BIT_ONLY = 8,
	AHCI_HFLAG_MV_PATA = 16,
	AHCI_HFLAG_NO_MSI = 32,
	AHCI_HFLAG_NO_PMP = 64,
	AHCI_HFLAG_SECT255 = 256,
	AHCI_HFLAG_YES_NCQ = 512,
	AHCI_HFLAG_NO_SUSPEND = 1024,
	AHCI_HFLAG_SRST_TOUT_IS_OFFLINE = 2048,
	AHCI_HFLAG_NO_SNTF = 4096,
	AHCI_HFLAG_NO_FPDMA_AA = 8192,
	AHCI_HFLAG_YES_FBS = 16384,
	AHCI_HFLAG_DELAY_ENGINE = 32768,
	AHCI_HFLAG_NO_DEVSLP = 131072,
	AHCI_HFLAG_NO_FBS = 262144,
	AHCI_HFLAG_MULTI_MSI = 1048576,
	AHCI_HFLAG_WAKE_BEFORE_STOP = 4194304,
	AHCI_HFLAG_YES_ALPM = 8388608,
	AHCI_HFLAG_NO_WRITE_TO_RO = 16777216,
	AHCI_HFLAG_IS_MOBILE = 33554432,
	AHCI_HFLAG_SUSPEND_PHYS = 67108864,
	AHCI_HFLAG_IGN_NOTSUPP_POWER_ON = 134217728,
	AHCI_HFLAG_NO_SXS = 268435456,
	AHCI_FLAG_COMMON = 393346,
	ICH_MAP = 144,
	PCS_6 = 146,
	PCS_7 = 148,
	EM_MAX_SLOTS = 8,
	EM_MAX_RETRY = 5,
	EM_CTL_RST = 512,
	EM_CTL_TM = 256,
	EM_CTL_MR = 1,
	EM_CTL_ALHD = 67108864,
	EM_CTL_XMT = 33554432,
	EM_CTL_SMB = 16777216,
	EM_CTL_SGPIO = 524288,
	EM_CTL_SES = 262144,
	EM_CTL_SAFTE = 131072,
	EM_CTL_LED = 65536,
	EM_MSG_TYPE_LED = 1,
	EM_MSG_TYPE_SAFTE = 2,
	EM_MSG_TYPE_SES2 = 4,
	EM_MSG_TYPE_SGPIO = 8,
};

struct ahci_host_priv {
	unsigned int flags;
	u32 force_port_map;
	u32 mask_port_map;
	void *mmio;
	u32 cap;
	u32 cap2;
	u32 version;
	u32 port_map;
	u32 saved_cap;
	u32 saved_cap2;
	u32 saved_port_map;
	u32 em_loc;
	u32 em_buf_sz;
	u32 em_msg_type;
	u32 remapped_nvme;
	bool got_runtime_pm;
	struct clk *clks[5];
	struct reset_control *rsts;
	struct regulator **target_pwrs;
	struct regulator *ahci_regulator;
	struct regulator *phy_regulator;
	struct phy___8 **phys;
	unsigned int nports;
	void *plat_data;
	unsigned int irq;
	void (*start_engine)(struct ata_port___2 *);
	int (*stop_engine)(struct ata_port___2 *);
	irqreturn_t (*irq_handler)(int, void *);
	int (*get_irq_vector)(struct ata_host___2 *, int);
};

enum {
	IMX_TIMER1MS = 224,
	IMX_P0PHYCR = 376,
	IMX_P0PHYCR_TEST_PDDQ = 1048576,
	IMX_P0PHYCR_CR_READ = 524288,
	IMX_P0PHYCR_CR_WRITE = 262144,
	IMX_P0PHYCR_CR_CAP_DATA = 131072,
	IMX_P0PHYCR_CR_CAP_ADDR = 65536,
	IMX_P0PHYSR = 380,
	IMX_P0PHYSR_CR_ACK = 262144,
	IMX_P0PHYSR_CR_DATA_OUT = 65535,
	IMX_LANE0_OUT_STAT = 8195,
	IMX_LANE0_OUT_STAT_RX_PLL_STATE = 2,
	IMX_CLOCK_RESET = 32575,
	IMX_CLOCK_RESET_RESET = 1,
	IMX8QM_SATA_PHY_RX_IMPED_RATIO_OFFSET = 3,
	IMX8QM_SATA_PHY_TX_IMPED_RATIO_OFFSET = 9,
	IMX8QM_SATA_PHY_IMPED_RATIO_85OHM = 108,
	IMX8QM_LPCG_PHYX2_OFFSET = 0,
	IMX8QM_CSR_PHYX2_OFFSET = 589824,
	IMX8QM_CSR_PHYX1_OFFSET = 655360,
	IMX8QM_CSR_PHYX_STTS0_OFFSET = 4,
	IMX8QM_CSR_PCIEA_OFFSET = 720896,
	IMX8QM_CSR_PCIEB_OFFSET = 786432,
	IMX8QM_CSR_SATA_OFFSET = 851968,
	IMX8QM_CSR_PCIE_CTRL2_OFFSET = 8,
	IMX8QM_CSR_MISC_OFFSET = 917504,
	IMX8QM_LPCG_PHYX2_PCLK0_MASK = 196608,
	IMX8QM_LPCG_PHYX2_PCLK1_MASK = 3145728,
	IMX8QM_PHY_APB_RSTN_0 = 1,
	IMX8QM_PHY_MODE_SATA = 524288,
	IMX8QM_PHY_MODE_MASK = 1966080,
	IMX8QM_PHY_PIPE_RSTN_0 = 16777216,
	IMX8QM_PHY_PIPE_RSTN_OVERRIDE_0 = 33554432,
	IMX8QM_PHY_PIPE_RSTN_1 = 67108864,
	IMX8QM_PHY_PIPE_RSTN_OVERRIDE_1 = 134217728,
	IMX8QM_STTS0_LANE0_TX_PLL_LOCK = 16,
	IMX8QM_MISC_IOB_RXENA = 1,
	IMX8QM_MISC_IOB_TXENA = 2,
	IMX8QM_MISC_PHYX1_EPCS_SEL = 4096,
	IMX8QM_MISC_CLKREQN_OUT_OVERRIDE_1 = 16777216,
	IMX8QM_MISC_CLKREQN_OUT_OVERRIDE_0 = 33554432,
	IMX8QM_MISC_CLKREQN_IN_OVERRIDE_1 = 268435456,
	IMX8QM_MISC_CLKREQN_IN_OVERRIDE_0 = 536870912,
	IMX8QM_SATA_CTRL_RESET_N = 4096,
	IMX8QM_SATA_CTRL_EPCS_PHYRESET_N = 128,
	IMX8QM_CTRL_BUTTON_RST_N = 2097152,
	IMX8QM_CTRL_POWER_UP_RST_N = 8388608,
	IMX8QM_CTRL_LTSSM_ENABLE = 16,
};

enum ahci_imx_type {
	AHCI_IMX53 = 0,
	AHCI_IMX6Q = 1,
	AHCI_IMX6QP = 2,
	AHCI_IMX8QM = 3,
};

struct imx_ahci_priv {
	struct platform_device___35 *ahci_pdev;
	enum ahci_imx_type type;
	struct clk *sata_clk;
	struct clk *sata_ref_clk;
	struct clk *ahb_clk;
	struct clk *epcs_tx_clk;
	struct clk *epcs_rx_clk;
	struct clk *phy_apbclk;
	struct clk *phy_pclk0;
	struct clk *phy_pclk1;
	void *phy_base;
	struct gpio_desc *clkreq_gpiod;
	struct regmap *gpr;
	bool no_device;
	bool first_time;
	u32 phy_params;
	u32 imped_ratio;
};

enum {
	SATA_PHY_CR_CLOCK_CRCMP_LT_LIMIT = 1,
	SATA_PHY_CR_CLOCK_DAC_CTL = 8,
	SATA_PHY_CR_CLOCK_RTUNE_CTL = 9,
	SATA_PHY_CR_CLOCK_ADC_OUT = 10,
	SATA_PHY_CR_CLOCK_MPLL_TST = 23,
};

struct reg_value {
	u32 of_value;
	u32 reg_value;
};

struct reg_property {
	const char *name;
	const struct reg_value *values;
	size_t num_values;
	u32 def_value;
	u32 set_value;
};

struct Scsi_Host___10;

struct scsi_cmnd___9;

struct scsi_device___10;

struct scsi_target___10;

struct scsi_host_template___10 {
	unsigned int cmd_size;
	int (*queuecommand)(struct Scsi_Host___10 *, struct scsi_cmnd___9 *);
	void (*commit_rqs)(struct Scsi_Host___10 *, u16);
	struct module___202 *module;
	const char *name;
	const char * (*info)(struct Scsi_Host___10 *);
	int (*ioctl)(struct scsi_device___10 *, unsigned int, void *);
	int (*compat_ioctl)(struct scsi_device___10 *, unsigned int, void *);
	int (*init_cmd_priv)(struct Scsi_Host___10 *, struct scsi_cmnd___9 *);
	int (*exit_cmd_priv)(struct Scsi_Host___10 *, struct scsi_cmnd___9 *);
	int (*eh_abort_handler)(struct scsi_cmnd___9 *);
	int (*eh_device_reset_handler)(struct scsi_cmnd___9 *);
	int (*eh_target_reset_handler)(struct scsi_cmnd___9 *);
	int (*eh_bus_reset_handler)(struct scsi_cmnd___9 *);
	int (*eh_host_reset_handler)(struct scsi_cmnd___9 *);
	int (*slave_alloc)(struct scsi_device___10 *);
	int (*slave_configure)(struct scsi_device___10 *);
	void (*slave_destroy)(struct scsi_device___10 *);
	int (*target_alloc)(struct scsi_target___10 *);
	void (*target_destroy)(struct scsi_target___10 *);
	int (*scan_finished)(struct Scsi_Host___10 *, long unsigned int);
	void (*scan_start)(struct Scsi_Host___10 *);
	int (*change_queue_depth)(struct scsi_device___10 *, int);
	int (*map_queues)(struct Scsi_Host___10 *);
	int (*mq_poll)(struct Scsi_Host___10 *, unsigned int);
	bool (*dma_need_drain)(struct request___114 *);
	int (*bios_param)(struct scsi_device___10 *, struct block_device___117 *, sector_t, int *);
	void (*unlock_native_capacity)(struct scsi_device___10 *);
	int (*show_info)(struct seq_file___193 *, struct Scsi_Host___10 *);
	int (*write_info)(struct Scsi_Host___10 *, char *, int);
	enum blk_eh_timer_return (*eh_timed_out)(struct scsi_cmnd___9 *);
	bool (*eh_should_retry_cmd)(struct scsi_cmnd___9 *);
	int (*host_reset)(struct Scsi_Host___10 *, int);
	const char *proc_name;
	struct proc_dir_entry *proc_dir;
	int can_queue;
	int this_id;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	short int cmd_per_lun;
	unsigned char present;
	int tag_alloc_policy;
	unsigned int track_queue_depth: 1;
	unsigned int supported_mode: 2;
	unsigned int emulated: 1;
	unsigned int skip_settle_delay: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int max_host_blocked;
	struct device_attribute___31 **shost_attrs;
	struct device_attribute___31 **sdev_attrs;
	const struct attribute_group___206 **sdev_groups;
	u64 vendor_id;
	struct scsi_host_cmd_pool *cmd_pool;
	int rpm_autosuspend_delay;
};

struct Scsi_Host___10 {
	struct list_head __devices;
	struct list_head __targets;
	struct list_head starved_list;
	spinlock_t default_lock;
	spinlock_t *host_lock;
	struct mutex scan_mutex;
	struct list_head eh_abort_list;
	struct list_head eh_cmd_q;
	struct task_struct___225 *ehandler;
	struct completion *eh_action;
	wait_queue_head_t host_wait;
	struct scsi_host_template___10 *hostt;
	struct scsi_transport_template *transportt;
	struct blk_mq_tag_set___111 tag_set;
	atomic_t host_blocked;
	unsigned int host_failed;
	unsigned int host_eh_scheduled;
	unsigned int host_no;
	int eh_deadline;
	long unsigned int last_reset;
	unsigned int max_channel;
	unsigned int max_id;
	u64 max_lun;
	unsigned int unique_id;
	short unsigned int max_cmd_len;
	int this_id;
	int can_queue;
	short int cmd_per_lun;
	short unsigned int sg_tablesize;
	short unsigned int sg_prot_tablesize;
	unsigned int max_sectors;
	unsigned int max_segment_size;
	long unsigned int dma_boundary;
	long unsigned int virt_boundary_mask;
	unsigned int nr_hw_queues;
	unsigned int nr_maps;
	unsigned int active_mode: 2;
	unsigned int host_self_blocked: 1;
	unsigned int reverse_ordering: 1;
	unsigned int tmf_in_progress: 1;
	unsigned int async_scan: 1;
	unsigned int eh_noresume: 1;
	unsigned int no_write_same: 1;
	unsigned int host_tagset: 1;
	unsigned int short_inquiry: 1;
	unsigned int no_scsi2_lun_in_cdb: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	char work_q_name[20];
	struct workqueue_struct *work_q;
	struct workqueue_struct *tmf_work_q;
	unsigned int max_host_blocked;
	unsigned int prot_capabilities;
	unsigned char prot_guard_type;
	long unsigned int base;
	long unsigned int io_port;
	unsigned char n_io_port;
	unsigned char dma_channel;
	unsigned int irq;
	enum scsi_host_state shost_state;
	struct device___196 shost_gendev;
	struct device___196 shost_dev;
	void *shost_data;
	struct device___196 *dma_dev;
	long unsigned int hostdata[0];
};

struct scsi_cmnd___9 {
	struct scsi_request req;
	struct scsi_device___10 *device;
	struct list_head eh_entry;
	struct delayed_work abort_work;
	struct callback_head rcu;
	int eh_eflags;
	int budget_token;
	long unsigned int jiffies_at_alloc;
	int retries;
	int allowed;
	unsigned char prot_op;
	unsigned char prot_type;
	unsigned char prot_flags;
	short unsigned int cmd_len;
	enum dma_data_direction sc_data_direction;
	unsigned char *cmnd;
	struct scsi_data_buffer sdb;
	struct scsi_data_buffer *prot_sdb;
	unsigned int underflow;
	unsigned int transfersize;
	unsigned char *sense_buffer;
	void (*scsi_done)(struct scsi_cmnd___9 *);
	struct scsi_pointer SCp;
	unsigned char *host_scribble;
	int result;
	int flags;
	long unsigned int state;
	unsigned int extra_len;
};

struct scsi_device___10 {
	struct Scsi_Host___10 *host;
	struct request_queue___114 *request_queue;
	struct list_head siblings;
	struct list_head same_target_siblings;
	struct sbitmap budget_map;
	atomic_t device_blocked;
	atomic_t restarts;
	spinlock_t list_lock;
	struct list_head starved_entry;
	short unsigned int queue_depth;
	short unsigned int max_queue_depth;
	short unsigned int last_queue_full_depth;
	short unsigned int last_queue_full_count;
	long unsigned int last_queue_full_time;
	long unsigned int queue_ramp_up_period;
	long unsigned int last_queue_ramp_up;
	unsigned int id;
	unsigned int channel;
	u64 lun;
	unsigned int manufacturer;
	unsigned int sector_size;
	void *hostdata;
	unsigned char type;
	char scsi_level;
	char inq_periph_qual;
	struct mutex inquiry_mutex;
	unsigned char inquiry_len;
	unsigned char *inquiry;
	const char *vendor;
	const char *model;
	const char *rev;
	struct scsi_vpd *vpd_pg0;
	struct scsi_vpd *vpd_pg83;
	struct scsi_vpd *vpd_pg80;
	struct scsi_vpd *vpd_pg89;
	struct scsi_target___10 *sdev_target;
	blist_flags_t sdev_bflags;
	unsigned int eh_timeout;
	unsigned int removable: 1;
	unsigned int changed: 1;
	unsigned int busy: 1;
	unsigned int lockable: 1;
	unsigned int locked: 1;
	unsigned int borken: 1;
	unsigned int disconnect: 1;
	unsigned int soft_reset: 1;
	unsigned int sdtr: 1;
	unsigned int wdtr: 1;
	unsigned int ppr;
	unsigned int tagged_supported: 1;
	unsigned int simple_tags: 1;
	unsigned int was_reset: 1;
	unsigned int expecting_cc_ua: 1;
	unsigned int use_10_for_rw: 1;
	unsigned int use_10_for_ms: 1;
	unsigned int set_dbd_for_ms: 1;
	unsigned int no_report_opcodes: 1;
	unsigned int no_write_same: 1;
	unsigned int use_16_for_rw: 1;
	unsigned int skip_ms_page_8: 1;
	unsigned int skip_ms_page_3f: 1;
	unsigned int skip_vpd_pages: 1;
	unsigned int try_vpd_pages: 1;
	unsigned int use_192_bytes_for_3f: 1;
	unsigned int no_start_on_add: 1;
	unsigned int allow_restart: 1;
	unsigned int manage_start_stop: 1;
	unsigned int start_stop_pwr_cond: 1;
	unsigned int no_uld_attach: 1;
	unsigned int select_no_atn: 1;
	unsigned int fix_capacity: 1;
	unsigned int guess_capacity: 1;
	unsigned int retry_hwerror: 1;
	unsigned int last_sector_bug: 1;
	unsigned int no_read_disc_info: 1;
	unsigned int no_read_capacity_16: 1;
	unsigned int try_rc_10_first: 1;
	unsigned int security_supported: 1;
	unsigned int is_visible: 1;
	unsigned int wce_default_on: 1;
	unsigned int no_dif: 1;
	unsigned int broken_fua: 1;
	unsigned int lun_in_cdb: 1;
	unsigned int unmap_limit_for_ws: 1;
	unsigned int rpm_autosuspend: 1;
	unsigned int ignore_media_change: 1;
	unsigned int silence_suspend: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool offline_already;
	atomic_t disk_events_disable_depth;
	long unsigned int supported_events[1];
	long unsigned int pending_events[1];
	struct list_head event_list;
	struct work_struct event_work;
	unsigned int max_device_blocked;
	atomic_t iorequest_cnt;
	atomic_t iodone_cnt;
	atomic_t ioerr_cnt;
	struct device___196 sdev_gendev;
	struct device___196 sdev_dev;
	struct execute_work ew;
	struct work_struct requeue_work;
	struct scsi_device_handler *handler;
	void *handler_data;
	size_t dma_drain_len;
	void *dma_drain_buf;
	unsigned int sg_timeout;
	unsigned int sg_reserved_size;
	struct bsg_device___2 *bsg_dev;
	unsigned char access_state;
	struct mutex state_mutex;
	enum scsi_device_state sdev_state;
	struct task_struct___225 *quiesced_by;
	long unsigned int sdev_data[0];
};

struct scsi_target___10 {
	struct scsi_device___10 *starget_sdev_user;
	struct list_head siblings;
	struct list_head devices;
	struct device___196 dev;
	struct kref reap_ref;
	unsigned int channel;
	unsigned int id;
	unsigned int create: 1;
	unsigned int single_lun: 1;
	unsigned int pdt_1f_for_no_lun: 1;
	unsigned int no_report_luns: 1;
	unsigned int expecting_lun_change: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t target_busy;
	atomic_t target_blocked;
	unsigned int can_queue;
	unsigned int max_target_blocked;
	char scsi_level;
	enum scsi_target_state state;
	void *hostdata;
	long unsigned int starget_data[0];
};

struct ata_queued_cmd___4;

typedef void (*ata_qc_cb_t___4)(struct ata_queued_cmd___4 *);

struct ata_port___4;

struct ata_device___4;

struct ata_queued_cmd___4 {
	struct ata_port___4 *ap;
	struct ata_device___4 *dev;
	struct scsi_cmnd___9 *scsicmd;
	void (*scsidone)(struct scsi_cmnd___9 *);
	struct ata_taskfile tf;
	u8 cdb[16];
	long unsigned int flags;
	unsigned int tag;
	unsigned int hw_tag;
	unsigned int n_elem;
	unsigned int orig_n_elem;
	int dma_dir;
	unsigned int sect_size;
	unsigned int nbytes;
	unsigned int extrabytes;
	unsigned int curbytes;
	struct scatterlist sgent;
	struct scatterlist *sg;
	struct scatterlist *cursg;
	unsigned int cursg_ofs;
	unsigned int err_mask;
	struct ata_taskfile result_tf;
	ata_qc_cb_t___4 complete_fn;
	void *private_data;
	void *lldd_task;
};

struct ata_link___4;

typedef int (*ata_prereset_fn_t___4)(struct ata_link___4 *, long unsigned int);

struct ata_eh_info___4 {
	struct ata_device___4 *dev;
	u32 serror;
	unsigned int err_mask;
	unsigned int action;
	unsigned int dev_action[2];
	unsigned int flags;
	unsigned int probe_mask;
	char desc[80];
	int desc_len;
};

struct ata_eh_context___4 {
	struct ata_eh_info___4 i;
	int tries[2];
	int cmd_timeout_idx[14];
	unsigned int classes[2];
	unsigned int did_probe_mask;
	unsigned int unloaded_mask;
	unsigned int saved_ncq_enabled;
	u8 saved_xfer_mode[2];
	long unsigned int last_reset;
};

struct ata_device___4 {
	struct ata_link___4 *link;
	unsigned int devno;
	unsigned int horkage;
	long unsigned int flags;
	struct scsi_device___10 *sdev;
	void *private_data;
	union acpi_object *gtf_cache;
	unsigned int gtf_filter;
	void *zpodd;
	struct device___196 tdev;
	u64 n_sectors;
	u64 n_native_sectors;
	unsigned int class;
	long unsigned int unpark_deadline;
	u8 pio_mode;
	u8 dma_mode;
	u8 xfer_mode;
	unsigned int xfer_shift;
	unsigned int multi_count;
	unsigned int max_sectors;
	unsigned int cdb_len;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	u16 cylinders;
	u16 heads;
	u16 sectors;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	union {
		u16 id[256];
		u32 gscr[128];
	};
	u8 devslp_timing[8];
	u8 ncq_send_recv_cmds[20];
	u8 ncq_non_data_cmds[64];
	u32 zac_zoned_cap;
	u32 zac_zones_optimal_open;
	u32 zac_zones_optimal_nonseq;
	u32 zac_zones_max_open;
	int spdn_cnt;
	struct ata_ering ering;
	long: 64;
};

struct ata_link___4 {
	struct ata_port___4 *ap;
	int pmp;
	struct device___196 tdev;
	unsigned int active_tag;
	u32 sactive;
	unsigned int flags;
	u32 saved_scontrol;
	unsigned int hw_sata_spd_limit;
	unsigned int sata_spd_limit;
	unsigned int sata_spd;
	enum ata_lpm_policy lpm_policy;
	struct ata_eh_info___4 eh_info;
	struct ata_eh_context___4 eh_context;
	long: 64;
	struct ata_device___4 device[2];
	long unsigned int last_lpm_change;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*ata_reset_fn_t___4)(struct ata_link___4 *, unsigned int *, long unsigned int);

typedef void (*ata_postreset_fn_t___4)(struct ata_link___4 *, unsigned int *);

struct ata_port_operations___4;

struct ata_host___4 {
	spinlock_t lock;
	struct device___196 *dev;
	void * const *iomap;
	unsigned int n_ports;
	unsigned int n_tags;
	void *private_data;
	struct ata_port_operations___4 *ops;
	long unsigned int flags;
	struct kref kref;
	struct mutex eh_mutex;
	struct task_struct___225 *eh_owner;
	struct ata_port___4 *simplex_claimed;
	struct ata_port___4 *ports[0];
};

struct ata_port_operations___4 {
	int (*qc_defer)(struct ata_queued_cmd___4 *);
	int (*check_atapi_dma)(struct ata_queued_cmd___4 *);
	enum ata_completion_errors (*qc_prep)(struct ata_queued_cmd___4 *);
	unsigned int (*qc_issue)(struct ata_queued_cmd___4 *);
	bool (*qc_fill_rtf)(struct ata_queued_cmd___4 *);
	int (*cable_detect)(struct ata_port___4 *);
	long unsigned int (*mode_filter)(struct ata_device___4 *, long unsigned int);
	void (*set_piomode)(struct ata_port___4 *, struct ata_device___4 *);
	void (*set_dmamode)(struct ata_port___4 *, struct ata_device___4 *);
	int (*set_mode)(struct ata_link___4 *, struct ata_device___4 **);
	unsigned int (*read_id)(struct ata_device___4 *, struct ata_taskfile *, u16 *);
	void (*dev_config)(struct ata_device___4 *);
	void (*freeze)(struct ata_port___4 *);
	void (*thaw)(struct ata_port___4 *);
	ata_prereset_fn_t___4 prereset;
	ata_reset_fn_t___4 softreset;
	ata_reset_fn_t___4 hardreset;
	ata_postreset_fn_t___4 postreset;
	ata_prereset_fn_t___4 pmp_prereset;
	ata_reset_fn_t___4 pmp_softreset;
	ata_reset_fn_t___4 pmp_hardreset;
	ata_postreset_fn_t___4 pmp_postreset;
	void (*error_handler)(struct ata_port___4 *);
	void (*lost_interrupt)(struct ata_port___4 *);
	void (*post_internal_cmd)(struct ata_queued_cmd___4 *);
	void (*sched_eh)(struct ata_port___4 *);
	void (*end_eh)(struct ata_port___4 *);
	int (*scr_read)(struct ata_link___4 *, unsigned int, u32 *);
	int (*scr_write)(struct ata_link___4 *, unsigned int, u32);
	void (*pmp_attach)(struct ata_port___4 *);
	void (*pmp_detach)(struct ata_port___4 *);
	int (*set_lpm)(struct ata_link___4 *, enum ata_lpm_policy, unsigned int);
	int (*port_suspend)(struct ata_port___4 *, pm_message_t);
	int (*port_resume)(struct ata_port___4 *);
	int (*port_start)(struct ata_port___4 *);
	void (*port_stop)(struct ata_port___4 *);
	void (*host_stop)(struct ata_host___4 *);
	void (*sff_dev_select)(struct ata_port___4 *, unsigned int);
	void (*sff_set_devctl)(struct ata_port___4 *, u8);
	u8 (*sff_check_status)(struct ata_port___4 *);
	u8 (*sff_check_altstatus)(struct ata_port___4 *);
	void (*sff_tf_load)(struct ata_port___4 *, const struct ata_taskfile *);
	void (*sff_tf_read)(struct ata_port___4 *, struct ata_taskfile *);
	void (*sff_exec_command)(struct ata_port___4 *, const struct ata_taskfile *);
	unsigned int (*sff_data_xfer)(struct ata_queued_cmd___4 *, unsigned char *, unsigned int, int);
	void (*sff_irq_on)(struct ata_port___4 *);
	bool (*sff_irq_check)(struct ata_port___4 *);
	void (*sff_irq_clear)(struct ata_port___4 *);
	void (*sff_drain_fifo)(struct ata_queued_cmd___4 *);
	void (*bmdma_setup)(struct ata_queued_cmd___4 *);
	void (*bmdma_start)(struct ata_queued_cmd___4 *);
	void (*bmdma_stop)(struct ata_queued_cmd___4 *);
	u8 (*bmdma_status)(struct ata_port___4 *);
	ssize_t (*em_show)(struct ata_port___4 *, char *);
	ssize_t (*em_store)(struct ata_port___4 *, const char *, size_t);
	ssize_t (*sw_activity_show)(struct ata_device___4 *, char *);
	ssize_t (*sw_activity_store)(struct ata_device___4 *, enum sw_activity);
	ssize_t (*transmit_led_message)(struct ata_port___4 *, u32, ssize_t);
	void (*phy_reset)(struct ata_port___4 *);
	void (*eng_timeout)(struct ata_port___4 *);
	const struct ata_port_operations___4 *inherits;
};

struct ata_port___4 {
	struct Scsi_Host___10 *scsi_host;
	struct ata_port_operations___4 *ops;
	spinlock_t *lock;
	long unsigned int flags;
	unsigned int pflags;
	unsigned int print_id;
	unsigned int local_port_no;
	unsigned int port_no;
	struct ata_ioports ioaddr;
	u8 ctl;
	u8 last_ctl;
	struct ata_link___4 *sff_pio_task_link;
	struct delayed_work sff_pio_task;
	struct ata_bmdma_prd *bmdma_prd;
	dma_addr_t bmdma_prd_dma;
	unsigned int pio_mask;
	unsigned int mwdma_mask;
	unsigned int udma_mask;
	unsigned int cbl;
	struct ata_queued_cmd___4 qcmd[33];
	long unsigned int sas_tag_allocated;
	u64 qc_active;
	int nr_active_links;
	unsigned int sas_last_tag;
	long: 64;
	struct ata_link___4 link;
	struct ata_link___4 *slave_link;
	int nr_pmp_links;
	struct ata_link___4 *pmp_link;
	struct ata_link___4 *excl_link;
	struct ata_port_stats stats;
	struct ata_host___4 *host;
	struct device___196 *dev;
	struct device___196 tdev;
	struct mutex scsi_scan_mutex;
	struct delayed_work hotplug_task;
	struct work_struct scsi_rescan_task;
	unsigned int hsm_task_state;
	u32 msg_enable;
	struct list_head eh_done_q;
	wait_queue_head_t eh_wait_q;
	int eh_tries;
	struct completion park_req_pending;
	pm_message_t pm_mesg;
	enum ata_lpm_policy target_lpm_policy;
	struct timer_list fastdrain_timer;
	long unsigned int fastdrain_cnt;
	async_cookie_t cookie;
	int em_message_type;
	void *private_data;
	struct ata_acpi_gtm __acpi_init_gtm;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sector_buf[512];
};

struct ata_port_info___3 {
	long unsigned int flags;
	long unsigned int link_flags;
	long unsigned int pio_mask;
	long unsigned int mwdma_mask;
	long unsigned int udma_mask;
	struct ata_port_operations___4 *port_ops;
	void *private_data;
};

struct phy_configure_opts_dp___3 {
	unsigned int link_rate;
	unsigned int lanes;
	unsigned int voltage[4];
	unsigned int pre[4];
	u8 ssc;
	u8 set_rate: 1;
	u8 set_lanes: 1;
	u8 set_voltages: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

union phy_configure_opts___3 {
	struct phy_configure_opts_mipi_dphy mipi_dphy;
	struct phy_configure_opts_dp___3 dp;
};

struct phy___9;

struct phy_ops___8 {
	int (*init)(struct phy___9 *);
	int (*exit)(struct phy___9 *);
	int (*power_on)(struct phy___9 *);
	int (*power_off)(struct phy___9 *);
	int (*set_mode)(struct phy___9 *, enum phy_mode, int);
	int (*set_media)(struct phy___9 *, enum phy_media);
	int (*set_speed)(struct phy___9 *, int);
	int (*configure)(struct phy___9 *, union phy_configure_opts___3 *);
	int (*validate)(struct phy___9 *, enum phy_mode, int, union phy_configure_opts___3 *);
	int (*reset)(struct phy___9 *);
	int (*calibrate)(struct phy___9 *);
	void (*release)(struct phy___9 *);
	struct module___202 *owner;
};

struct phy___9 {
	struct device___196 dev;
	int id;
	const struct phy_ops___8 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct ahci_cmd_hdr {
	__le32 opts;
	__le32 status;
	__le32 tbl_addr;
	__le32 tbl_addr_hi;
	__le32 reserved[4];
};

struct ahci_sg {
	__le32 addr;
	__le32 addr_hi;
	__le32 reserved;
	__le32 flags_size;
};

struct ahci_em_priv {
	enum sw_activity blink_policy;
	struct timer_list timer;
	long unsigned int saved_activity;
	long unsigned int activity;
	long unsigned int led_state;
	struct ata_link___4 *link;
};

struct ahci_port_priv {
	struct ata_link___4 *active_link;
	struct ahci_cmd_hdr *cmd_slot;
	dma_addr_t cmd_slot_dma;
	void *cmd_tbl;
	dma_addr_t cmd_tbl_dma;
	void *rx_fis;
	dma_addr_t rx_fis_dma;
	unsigned int ncq_saw_d2h: 1;
	unsigned int ncq_saw_dmas: 1;
	unsigned int ncq_saw_sdb: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t lock;
	u32 intr_mask;
	bool fbs_supported;
	bool fbs_enabled;
	int fbs_last_dev;
	struct ahci_em_priv em_priv[8];
	char *irq_desc;
};

struct ahci_host_priv___2 {
	unsigned int flags;
	u32 force_port_map;
	u32 mask_port_map;
	void *mmio;
	u32 cap;
	u32 cap2;
	u32 version;
	u32 port_map;
	u32 saved_cap;
	u32 saved_cap2;
	u32 saved_port_map;
	u32 em_loc;
	u32 em_buf_sz;
	u32 em_msg_type;
	u32 remapped_nvme;
	bool got_runtime_pm;
	struct clk *clks[5];
	struct reset_control *rsts;
	struct regulator **target_pwrs;
	struct regulator *ahci_regulator;
	struct regulator *phy_regulator;
	struct phy___9 **phys;
	unsigned int nports;
	void *plat_data;
	unsigned int irq;
	void (*start_engine)(struct ata_port___4 *);
	int (*stop_engine)(struct ata_port___4 *);
	irqreturn_t (*irq_handler)(int, void *);
	int (*get_irq_vector)(struct ata_host___4 *, int);
};

typedef void (*dr_release_t___28)(struct device___196 *, void *);

struct mipi_dsi_msg {
	u8 channel;
	u8 type;
	u16 flags;
	size_t tx_len;
	const void *tx_buf;
	size_t rx_len;
	void *rx_buf;
};

struct mipi_dsi_packet {
	size_t size;
	u8 header[4];
	size_t payload_length;
	const u8 *payload;
};

struct mipi_dsi_host;

struct mipi_dsi_device;

struct mipi_dsi_host_ops {
	int (*attach)(struct mipi_dsi_host *, struct mipi_dsi_device *);
	int (*detach)(struct mipi_dsi_host *, struct mipi_dsi_device *);
	ssize_t (*transfer)(struct mipi_dsi_host *, const struct mipi_dsi_msg *);
};

struct mipi_dsi_host {
	struct device___15 *dev;
	const struct mipi_dsi_host_ops *ops;
	struct list_head list;
};

enum mipi_dsi_pixel_format {
	MIPI_DSI_FMT_RGB888 = 0,
	MIPI_DSI_FMT_RGB666 = 1,
	MIPI_DSI_FMT_RGB666_PACKED = 2,
	MIPI_DSI_FMT_RGB565 = 3,
};

struct mipi_dsi_device {
	struct mipi_dsi_host *host;
	struct device___15 dev;
	char name[20];
	unsigned int channel;
	unsigned int lanes;
	enum mipi_dsi_pixel_format format;
	long unsigned int mode_flags;
	long unsigned int hs_rate;
	long unsigned int lp_rate;
};

struct mipi_dsi_device_info {
	char type[20];
	u32 channel;
	struct device_node___10 *node;
};

enum mipi_dsi_dcs_tear_mode {
	MIPI_DSI_DCS_TEAR_MODE_VBLANK = 0,
	MIPI_DSI_DCS_TEAR_MODE_VHBLANK = 1,
};

struct mipi_dsi_driver {
	struct device_driver___15 driver;
	int (*probe)(struct mipi_dsi_device *);
	int (*remove)(struct mipi_dsi_device *);
	void (*shutdown)(struct mipi_dsi_device *);
};

struct drm_dsc_picture_parameter_set {
	u8 dsc_version;
	u8 pps_identifier;
	u8 pps_reserved;
	u8 pps_3;
	u8 pps_4;
	u8 bits_per_pixel_low;
	__be16 pic_height;
	__be16 pic_width;
	__be16 slice_height;
	__be16 slice_width;
	__be16 chunk_size;
	u8 initial_xmit_delay_high;
	u8 initial_xmit_delay_low;
	__be16 initial_dec_delay;
	u8 pps20_reserved;
	u8 initial_scale_value;
	__be16 scale_increment_interval;
	u8 scale_decrement_interval_high;
	u8 scale_decrement_interval_low;
	u8 pps26_reserved;
	u8 first_line_bpg_offset;
	__be16 nfl_bpg_offset;
	__be16 slice_bpg_offset;
	__be16 initial_offset;
	__be16 final_offset;
	u8 flatness_min_qp;
	u8 flatness_max_qp;
	__be16 rc_model_size;
	u8 rc_edge_factor;
	u8 rc_quant_incr_limit0;
	u8 rc_quant_incr_limit1;
	u8 rc_tgt_offset;
	u8 rc_buf_thresh[14];
	__be16 rc_range_parameters[15];
	u8 native_422_420;
	u8 second_line_bpg_offset;
	__be16 nsl_bpg_offset;
	__be16 second_line_offset_adj;
	u32 pps_long_94_reserved;
	u32 pps_long_98_reserved;
	u32 pps_long_102_reserved;
	u32 pps_long_106_reserved;
	u32 pps_long_110_reserved;
	u32 pps_long_114_reserved;
	u32 pps_long_118_reserved;
	u32 pps_long_122_reserved;
	__be16 pps_short_126_reserved;
} __attribute__((packed));

enum {
	MIPI_DSI_V_SYNC_START = 1,
	MIPI_DSI_V_SYNC_END = 17,
	MIPI_DSI_H_SYNC_START = 33,
	MIPI_DSI_H_SYNC_END = 49,
	MIPI_DSI_COMPRESSION_MODE = 7,
	MIPI_DSI_END_OF_TRANSMISSION = 8,
	MIPI_DSI_COLOR_MODE_OFF = 2,
	MIPI_DSI_COLOR_MODE_ON = 18,
	MIPI_DSI_SHUTDOWN_PERIPHERAL = 34,
	MIPI_DSI_TURN_ON_PERIPHERAL = 50,
	MIPI_DSI_GENERIC_SHORT_WRITE_0_PARAM = 3,
	MIPI_DSI_GENERIC_SHORT_WRITE_1_PARAM = 19,
	MIPI_DSI_GENERIC_SHORT_WRITE_2_PARAM = 35,
	MIPI_DSI_GENERIC_READ_REQUEST_0_PARAM = 4,
	MIPI_DSI_GENERIC_READ_REQUEST_1_PARAM = 20,
	MIPI_DSI_GENERIC_READ_REQUEST_2_PARAM = 36,
	MIPI_DSI_DCS_SHORT_WRITE = 5,
	MIPI_DSI_DCS_SHORT_WRITE_PARAM = 21,
	MIPI_DSI_DCS_READ = 6,
	MIPI_DSI_EXECUTE_QUEUE = 22,
	MIPI_DSI_SET_MAXIMUM_RETURN_PACKET_SIZE = 55,
	MIPI_DSI_NULL_PACKET = 9,
	MIPI_DSI_BLANKING_PACKET = 25,
	MIPI_DSI_GENERIC_LONG_WRITE = 41,
	MIPI_DSI_DCS_LONG_WRITE = 57,
	MIPI_DSI_PICTURE_PARAMETER_SET = 10,
	MIPI_DSI_COMPRESSED_PIXEL_STREAM = 11,
	MIPI_DSI_LOOSELY_PACKED_PIXEL_STREAM_YCBCR20 = 12,
	MIPI_DSI_PACKED_PIXEL_STREAM_YCBCR24 = 28,
	MIPI_DSI_PACKED_PIXEL_STREAM_YCBCR16 = 44,
	MIPI_DSI_PACKED_PIXEL_STREAM_30 = 13,
	MIPI_DSI_PACKED_PIXEL_STREAM_36 = 29,
	MIPI_DSI_PACKED_PIXEL_STREAM_YCBCR12 = 61,
	MIPI_DSI_PACKED_PIXEL_STREAM_16 = 14,
	MIPI_DSI_PACKED_PIXEL_STREAM_18 = 30,
	MIPI_DSI_PIXEL_STREAM_3BYTE_18 = 46,
	MIPI_DSI_PACKED_PIXEL_STREAM_24 = 62,
};

enum {
	MIPI_DCS_NOP = 0,
	MIPI_DCS_SOFT_RESET = 1,
	MIPI_DCS_GET_COMPRESSION_MODE = 3,
	MIPI_DCS_GET_DISPLAY_ID = 4,
	MIPI_DCS_GET_ERROR_COUNT_ON_DSI = 5,
	MIPI_DCS_GET_RED_CHANNEL = 6,
	MIPI_DCS_GET_GREEN_CHANNEL = 7,
	MIPI_DCS_GET_BLUE_CHANNEL = 8,
	MIPI_DCS_GET_DISPLAY_STATUS = 9,
	MIPI_DCS_GET_POWER_MODE = 10,
	MIPI_DCS_GET_ADDRESS_MODE = 11,
	MIPI_DCS_GET_PIXEL_FORMAT = 12,
	MIPI_DCS_GET_DISPLAY_MODE = 13,
	MIPI_DCS_GET_SIGNAL_MODE = 14,
	MIPI_DCS_GET_DIAGNOSTIC_RESULT = 15,
	MIPI_DCS_ENTER_SLEEP_MODE = 16,
	MIPI_DCS_EXIT_SLEEP_MODE = 17,
	MIPI_DCS_ENTER_PARTIAL_MODE = 18,
	MIPI_DCS_ENTER_NORMAL_MODE = 19,
	MIPI_DCS_GET_IMAGE_CHECKSUM_RGB = 20,
	MIPI_DCS_GET_IMAGE_CHECKSUM_CT = 21,
	MIPI_DCS_EXIT_INVERT_MODE = 32,
	MIPI_DCS_ENTER_INVERT_MODE = 33,
	MIPI_DCS_SET_GAMMA_CURVE = 38,
	MIPI_DCS_SET_DISPLAY_OFF = 40,
	MIPI_DCS_SET_DISPLAY_ON = 41,
	MIPI_DCS_SET_COLUMN_ADDRESS = 42,
	MIPI_DCS_SET_PAGE_ADDRESS = 43,
	MIPI_DCS_WRITE_MEMORY_START = 44,
	MIPI_DCS_WRITE_LUT = 45,
	MIPI_DCS_READ_MEMORY_START = 46,
	MIPI_DCS_SET_PARTIAL_ROWS = 48,
	MIPI_DCS_SET_PARTIAL_COLUMNS = 49,
	MIPI_DCS_SET_SCROLL_AREA = 51,
	MIPI_DCS_SET_TEAR_OFF = 52,
	MIPI_DCS_SET_TEAR_ON = 53,
	MIPI_DCS_SET_ADDRESS_MODE = 54,
	MIPI_DCS_SET_SCROLL_START = 55,
	MIPI_DCS_EXIT_IDLE_MODE = 56,
	MIPI_DCS_ENTER_IDLE_MODE = 57,
	MIPI_DCS_SET_PIXEL_FORMAT = 58,
	MIPI_DCS_WRITE_MEMORY_CONTINUE = 60,
	MIPI_DCS_SET_3D_CONTROL = 61,
	MIPI_DCS_READ_MEMORY_CONTINUE = 62,
	MIPI_DCS_GET_3D_CONTROL = 63,
	MIPI_DCS_SET_VSYNC_TIMING = 64,
	MIPI_DCS_SET_TEAR_SCANLINE = 68,
	MIPI_DCS_GET_SCANLINE = 69,
	MIPI_DCS_SET_DISPLAY_BRIGHTNESS = 81,
	MIPI_DCS_GET_DISPLAY_BRIGHTNESS = 82,
	MIPI_DCS_WRITE_CONTROL_DISPLAY = 83,
	MIPI_DCS_GET_CONTROL_DISPLAY = 84,
	MIPI_DCS_WRITE_POWER_SAVE = 85,
	MIPI_DCS_GET_POWER_SAVE = 86,
	MIPI_DCS_SET_CABC_MIN_BRIGHTNESS = 94,
	MIPI_DCS_GET_CABC_MIN_BRIGHTNESS = 95,
	MIPI_DCS_READ_DDB_START = 161,
	MIPI_DCS_READ_PPS_START = 162,
	MIPI_DCS_READ_DDB_CONTINUE = 168,
	MIPI_DCS_READ_PPS_CONTINUE = 169,
};

struct drm_dmi_panel_orientation_data {
	int width;
	int height;
	const char * const *bios_dates;
	int orientation;
};

typedef struct poll_table_struct___144 poll_table___39;

struct vga_device {
	struct list_head list;
	struct pci_dev___18 *pdev;
	unsigned int decodes;
	unsigned int owns;
	unsigned int locks;
	unsigned int io_lock_cnt;
	unsigned int mem_lock_cnt;
	unsigned int io_norm_cnt;
	unsigned int mem_norm_cnt;
	bool bridge_has_one_vga;
	unsigned int (*set_decode)(struct pci_dev___18 *, bool);
};

struct vga_arb_user_card {
	struct pci_dev___18 *pdev;
	unsigned int mem_cnt;
	unsigned int io_cnt;
};

struct vga_arb_private {
	struct list_head list;
	struct pci_dev___18 *target;
	struct vga_arb_user_card cards[16];
	spinlock_t lock;
};

struct dentry___220;

struct super_block___220;

struct module___204;

struct file_system_type___220 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___220 * (*mount)(struct file_system_type___220 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___220 *);
	struct module___204 *owner;
	struct file_system_type___220 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___220;

struct kiocb___220;

struct iov_iter___140;

struct poll_table_struct___145;

struct vm_area_struct___225;

struct inode___220;

struct file_lock___220;

struct page___225;

struct pipe_inode_info___70;

struct seq_file___195;

struct file_operations___221 {
	struct module___204 *owner;
	loff_t (*llseek)(struct file___220 *, loff_t, int);
	ssize_t (*read)(struct file___220 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___220 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___220 *, struct iov_iter___140 *);
	ssize_t (*write_iter)(struct kiocb___220 *, struct iov_iter___140 *);
	int (*iopoll)(struct kiocb___220 *, bool);
	int (*iterate)(struct file___220 *, struct dir_context *);
	int (*iterate_shared)(struct file___220 *, struct dir_context *);
	__poll_t (*poll)(struct file___220 *, struct poll_table_struct___145 *);
	long int (*unlocked_ioctl)(struct file___220 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___220 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___220 *, struct vm_area_struct___225 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___220 *, struct file___220 *);
	int (*flush)(struct file___220 *, fl_owner_t);
	int (*release)(struct inode___220 *, struct file___220 *);
	int (*fsync)(struct file___220 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___220 *, int);
	int (*lock)(struct file___220 *, int, struct file_lock___220 *);
	ssize_t (*sendpage)(struct file___220 *, struct page___225 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___220 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___220 *, long unsigned int);
	int (*flock)(struct file___220 *, int, struct file_lock___220 *);
	ssize_t (*splice_write)(struct pipe_inode_info___70 *, struct file___220 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___220 *, loff_t *, struct pipe_inode_info___70 *, size_t, unsigned int);
	int (*setlease)(struct file___220 *, long int, struct file_lock___220 **, void **);
	long int (*fallocate)(struct file___220 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___195 *, struct file___220 *);
	ssize_t (*copy_file_range)(struct file___220 *, loff_t, struct file___220 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___220 *, loff_t, struct file___220 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___220 *, loff_t, loff_t, int);
};

struct vmacache___225 {
	u64 seqnum;
	struct vm_area_struct___225 *vmas[4];
};

struct page_frag___225 {
	struct page___225 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___80;

struct debug_info___80 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___80 *hbp_break[16];
	struct perf_event___80 *hbp_watch[16];
};

struct thread_struct___80 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___80 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___226;

struct pid___197;

struct nsproxy___206;

struct signal_struct___221;

struct css_set___150;

struct perf_event_context___80;

struct vm_struct___203;

struct task_struct___227 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___227 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___226 *mm;
	struct mm_struct___226 *active_mm;
	struct vmacache___225 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___227 *real_parent;
	struct task_struct___227 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___227 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___197 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___206 *nsproxy;
	struct signal_struct___221 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___227 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___115 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___150 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___80 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___70 *splice_pipe;
	struct page_frag___225 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___227 *oom_reaper_list;
	struct vm_struct___203 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___80 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___208;

struct kobj_type___208;

struct kernfs_node___208;

struct kobject___208 {
	const char *name;
	struct list_head entry;
	struct kobject___208 *parent;
	struct kset___208 *kset;
	struct kobj_type___208 *ktype;
	struct kernfs_node___208 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___205 {
	struct kobject___208 kobj;
	struct module___204 *mod;
	struct kobject___208 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___204 {
	struct module___204 *mod;
	struct latch_tree_node node;
};

struct module_layout___204 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___204 mtn;
};

struct module_attribute___204;

struct kernel_param___204;

struct trace_event_call___74;

struct module___204 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___205 mkobj;
	struct module_attribute___204 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___208 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___204 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___204 core_layout;
	struct module_layout___204 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___74 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___80 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___227 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___80)(struct perf_event___80 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___80;

struct fasync_struct___220;

struct pid_namespace___197;

struct perf_cgroup___80;

struct perf_event___80 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___80 *group_leader;
	struct pmu___80 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___80 hw;
	struct perf_event_context___80 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___80 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___227 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___220 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___80 *aux_event;
	void (*destroy)(struct perf_event___80 *);
	struct callback_head callback_head;
	struct pid_namespace___197 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___80 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___80 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___74 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___80 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___197 {
	int nr;
	struct pid_namespace___197 *ns;
};

struct pid_namespace___197 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___227 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___197 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___197 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___197 numbers[1];
};

typedef struct page___225 *pgtable_t___225;

struct address_space___220;

struct page_pool___58;

struct dev_pagemap___215;

struct page___225 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___220 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___58 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___225 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___225 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___226 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___215 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___215;

struct vm_area_struct___225 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___225 *vm_next;
	struct vm_area_struct___225 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___226 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___215 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___220 *vm_file;
	struct file___220 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___221 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___227 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___227 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___197 *pids[4];
	struct pid___197 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___226 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___225;

struct mm_struct___226 {
	struct {
		struct vm_area_struct___225 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___220 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___225 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___227 *owner;
		struct user_namespace___14 *user_ns;
		struct file___220 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___150;

struct nsproxy___206 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___197 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___150 *cgroup_ns;
};

struct cgroup_subsys_state___150;

struct cgroup___150;

struct css_set___150 {
	struct cgroup_subsys_state___150 *subsys[14];
	refcount_t refcount;
	struct css_set___150 *dom_cset;
	struct cgroup___150 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___150 *mg_src_cgrp;
	struct cgroup___150 *mg_dst_cgrp;
	struct css_set___150 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___80 {
	struct pmu___80 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___227 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___80 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___70;

struct pipe_inode_info___70 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___225 *tmp_page;
	struct fasync_struct___220 *fasync_readers;
	struct fasync_struct___220 *fasync_writers;
	struct pipe_buffer___70 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___203 {
	struct vm_struct___203 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___225 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___220;

struct address_space___220 {
	struct inode___220 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___220 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___198;

struct page_pool_params___58 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___198 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___58 {
	u32 count;
	struct page___225 *cache[128];
};

struct page_pool___58 {
	struct page_pool_params___58 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___225 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___58 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___215;

struct dev_pagemap___215 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___215 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___220;

struct path___220 {
	struct vfsmount___220 *mnt;
	struct dentry___220 *dentry;
};

struct fown_struct___197 {
	rwlock_t lock;
	struct pid___197 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___220 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___220 f_path;
	struct inode___220 *f_inode;
	const struct file_operations___221 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___197 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___220 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___215;

struct vm_operations_struct___215 {
	void (*open)(struct vm_area_struct___225 *);
	void (*close)(struct vm_area_struct___225 *);
	int (*may_split)(struct vm_area_struct___225 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___225 *);
	int (*mprotect)(struct vm_area_struct___225 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___215 *);
	vm_fault_t (*huge_fault)(struct vm_fault___215 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___215 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___225 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___215 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___215 *);
	int (*access)(struct vm_area_struct___225 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___225 *);
	int (*set_policy)(struct vm_area_struct___225 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___225 *, long unsigned int);
	struct page___225 * (*find_special_page)(struct vm_area_struct___225 *, long unsigned int);
};

struct core_thread___225 {
	struct task_struct___227 *task;
	struct core_thread___225 *next;
};

struct core_state___225 {
	atomic_t nr_threads;
	struct core_thread___225 dumper;
	struct completion startup;
};

struct vm_fault___215 {
	const struct {
		struct vm_area_struct___225 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___225 *cow_page;
	struct page___225 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___225 prealloc_pte;
};

struct kernfs_root___208;

struct kernfs_elem_dir___208 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___208 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___208;

struct kernfs_root___208 {
	struct kernfs_node___208 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___208 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___208 {
	struct kernfs_node___208 *target_kn;
};

struct kernfs_ops___208;

struct kernfs_elem_attr___208 {
	const struct kernfs_ops___208 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___208 *notify_next;
};

struct kernfs_node___208 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___208 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___208 dir;
		struct kernfs_elem_symlink___208 symlink;
		struct kernfs_elem_attr___208 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___208;

struct kernfs_ops___208 {
	int (*open)(struct kernfs_open_file___208 *);
	void (*release)(struct kernfs_open_file___208 *);
	int (*seq_show)(struct seq_file___195 *, void *);
	void * (*seq_start)(struct seq_file___195 *, loff_t *);
	void * (*seq_next)(struct seq_file___195 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___195 *, void *);
	ssize_t (*read)(struct kernfs_open_file___208 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___208 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___208 *, struct poll_table_struct___145 *);
	int (*mmap)(struct kernfs_open_file___208 *, struct vm_area_struct___225 *);
};

struct kernfs_syscall_ops___208 {
	int (*show_options)(struct seq_file___195 *, struct kernfs_root___208 *);
	int (*mkdir)(struct kernfs_node___208 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___208 *);
	int (*rename)(struct kernfs_node___208 *, struct kernfs_node___208 *, const char *);
	int (*show_path)(struct seq_file___195 *, struct kernfs_node___208 *, struct kernfs_root___208 *);
};

struct seq_operations___195;

struct seq_file___195 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___195 *op;
	int poll_event;
	const struct file___220 *file;
	void *private;
};

struct kernfs_open_file___208 {
	struct kernfs_node___208 *kn;
	struct file___220 *file;
	struct seq_file___195 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___215 *vm_ops;
};

typedef void (*poll_queue_proc___152)(struct file___220 *, wait_queue_head_t *, struct poll_table_struct___145 *);

struct poll_table_struct___145 {
	poll_queue_proc___152 _qproc;
	__poll_t _key;
};

struct bin_attribute___208;

struct attribute_group___208 {
	const char *name;
	umode_t (*is_visible)(struct kobject___208 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___208 *, struct bin_attribute___208 *, int);
	struct attribute **attrs;
	struct bin_attribute___208 **bin_attrs;
};

struct bin_attribute___208 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___220 * (*f_mapping)();
	ssize_t (*read)(struct file___220 *, struct kobject___208 *, struct bin_attribute___208 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___220 *, struct kobject___208 *, struct bin_attribute___208 *, char *, loff_t, size_t);
	int (*mmap)(struct file___220 *, struct kobject___208 *, struct bin_attribute___208 *, struct vm_area_struct___225 *);
};

struct sysfs_ops___208 {
	ssize_t (*show)(struct kobject___208 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___208 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___208;

struct kset___208 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___208 kobj;
	const struct kset_uevent_ops___208 *uevent_ops;
};

struct kobj_type___208 {
	void (*release)(struct kobject___208 *);
	const struct sysfs_ops___208 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___208 **default_groups;
	const struct kobj_ns_type_operations___13 * (*child_ns_type)(struct kobject___208 *);
	const void * (*namespace)(struct kobject___208 *);
	void (*get_ownership)(struct kobject___208 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___208 {
	int (* const filter)(struct kset___208 *, struct kobject___208 *);
	const char * (* const name)(struct kset___208 *, struct kobject___208 *);
	int (* const uevent)(struct kset___208 *, struct kobject___208 *, struct kobj_uevent_env *);
};

struct wakeup_source___198;

struct pm_subsys_data___11;

struct dev_pm_info___198 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___198 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___198 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___198;

struct bus_type___198;

struct device_driver___198;

struct dev_pm_domain___198;

struct irq_domain___53;

struct device_node___86;

struct fwnode_handle___194;

struct class___198;

struct device___198 {
	struct kobject___208 kobj;
	struct device___198 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___198 *type;
	struct bus_type___198 *bus;
	struct device_driver___198 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___198 power;
	struct dev_pm_domain___198 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___53 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___86 *of_node;
	struct fwnode_handle___194 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___198 *class;
	const struct attribute_group___208 **groups;
	void (*release)(struct device___198 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___198 {
	int (*prepare)(struct device___198 *);
	void (*complete)(struct device___198 *);
	int (*suspend)(struct device___198 *);
	int (*resume)(struct device___198 *);
	int (*freeze)(struct device___198 *);
	int (*thaw)(struct device___198 *);
	int (*poweroff)(struct device___198 *);
	int (*restore)(struct device___198 *);
	int (*suspend_late)(struct device___198 *);
	int (*resume_early)(struct device___198 *);
	int (*freeze_late)(struct device___198 *);
	int (*thaw_early)(struct device___198 *);
	int (*poweroff_late)(struct device___198 *);
	int (*restore_early)(struct device___198 *);
	int (*suspend_noirq)(struct device___198 *);
	int (*resume_noirq)(struct device___198 *);
	int (*freeze_noirq)(struct device___198 *);
	int (*thaw_noirq)(struct device___198 *);
	int (*poweroff_noirq)(struct device___198 *);
	int (*restore_noirq)(struct device___198 *);
	int (*runtime_suspend)(struct device___198 *);
	int (*runtime_resume)(struct device___198 *);
	int (*runtime_idle)(struct device___198 *);
};

struct pm_domain_data___11;

struct pm_subsys_data___11 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___11 *domain_data;
};

struct pm_domain_data___11 {
	struct list_head list_node;
	struct device___198 *dev;
};

struct wakeup_source___198 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___198 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___198 {
	struct dev_pm_ops___198 ops;
	int (*start)(struct device___198 *);
	void (*detach)(struct device___198 *, bool);
	int (*activate)(struct device___198 *);
	void (*sync)(struct device___198 *);
	void (*dismiss)(struct device___198 *);
};

struct bus_type___198 {
	const char *name;
	const char *dev_name;
	struct device___198 *dev_root;
	const struct attribute_group___208 **bus_groups;
	const struct attribute_group___208 **dev_groups;
	const struct attribute_group___208 **drv_groups;
	int (*match)(struct device___198 *, struct device_driver___198 *);
	int (*uevent)(struct device___198 *, struct kobj_uevent_env *);
	int (*probe)(struct device___198 *);
	void (*sync_state)(struct device___198 *);
	void (*remove)(struct device___198 *);
	void (*shutdown)(struct device___198 *);
	int (*online)(struct device___198 *);
	int (*offline)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	int (*num_vf)(struct device___198 *);
	int (*dma_configure)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___198 {
	const char *name;
	struct bus_type___198 *bus;
	struct module___204 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___198 *);
	void (*sync_state)(struct device___198 *);
	int (*remove)(struct device___198 *);
	void (*shutdown)(struct device___198 *);
	int (*suspend)(struct device___198 *, pm_message_t);
	int (*resume)(struct device___198 *);
	const struct attribute_group___208 **groups;
	const struct attribute_group___208 **dev_groups;
	const struct dev_pm_ops___198 *pm;
	void (*coredump)(struct device___198 *);
	struct driver_private *p;
};

struct device_type___198 {
	const char *name;
	const struct attribute_group___208 **groups;
	int (*uevent)(struct device___198 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___198 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___198 *);
	const struct dev_pm_ops___198 *pm;
};

struct class___198 {
	const char *name;
	struct module___204 *owner;
	const struct attribute_group___208 **class_groups;
	const struct attribute_group___208 **dev_groups;
	struct kobject___208 *dev_kobj;
	int (*dev_uevent)(struct device___198 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___198 *, umode_t *);
	void (*class_release)(struct class___198 *);
	void (*dev_release)(struct device___198 *);
	int (*shutdown_pre)(struct device___198 *);
	const struct kobj_ns_type_operations___13 *ns_type;
	const void * (*namespace)(struct device___198 *);
	void (*get_ownership)(struct device___198 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___198 *pm;
	struct subsys_private *p;
};

struct device_attribute___33 {
	struct attribute attr;
	ssize_t (*show)(struct device___198 *, struct device_attribute___33 *, char *);
	ssize_t (*store)(struct device___198 *, struct device_attribute___33 *, const char *, size_t);
};

typedef void (*dr_release_t___29)(struct device___198 *, void *);

struct irq_domain_ops___53;

struct irq_domain_chip_generic___53;

struct irq_data___55;

struct irq_domain___53 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___53 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___194 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___53 *gc;
	struct irq_domain___53 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___55 *revmap[0];
};

struct fwnode_operations___194;

struct fwnode_handle___194 {
	struct fwnode_handle___194 *secondary;
	const struct fwnode_operations___194 *ops;
	struct device___198 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___63;

struct device_node___86 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___194 fwnode;
	struct property___63 *properties;
	struct property___63 *deadprops;
	struct device_node___86 *parent;
	struct device_node___86 *child;
	struct device_node___86 *sibling;
	struct kobject___208 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___215 {
	void (*page_free)(struct page___225 *);
	void (*kill)(struct dev_pagemap___215 *);
	void (*cleanup)(struct dev_pagemap___215 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___215 *);
};

struct dentry_operations___220;

struct dentry___220 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___220 *d_parent;
	struct qstr d_name;
	struct inode___220 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___220 *d_op;
	struct super_block___220 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___220;

struct cdev___58;

struct inode___220 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___220 *i_op;
	struct super_block___220 *i_sb;
	struct address_space___220 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___221 *i_fop;
		void (*free_inode)(struct inode___220 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___220 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___70 *i_pipe;
		struct cdev___58 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___220 {
	int (*d_revalidate)(struct dentry___220 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___220 *, unsigned int);
	int (*d_hash)(const struct dentry___220 *, struct qstr *);
	int (*d_compare)(const struct dentry___220 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___220 *);
	int (*d_init)(struct dentry___220 *);
	void (*d_release)(struct dentry___220 *);
	void (*d_prune)(struct dentry___220 *);
	void (*d_iput)(struct dentry___220 *, struct inode___220 *);
	char * (*d_dname)(struct dentry___220 *, char *, int);
	struct vfsmount___220 * (*d_automount)(struct path___220 *);
	int (*d_manage)(const struct path___220 *, bool);
	struct dentry___220 * (*d_real)(struct dentry___220 *, const struct inode___220 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___220;

struct mem_dqinfo___220 {
	struct quota_format_type___220 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___220;

struct quota_info___220 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___220 *files[3];
	struct mem_dqinfo___220 info[3];
	const struct quota_format_ops___220 *ops[3];
};

struct rcuwait___221 {
	struct task_struct___227 *task;
};

struct percpu_rw_semaphore___221 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___221 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___220 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___221 rw_sem[3];
};

struct super_operations___220;

struct dquot_operations___220;

struct quotactl_ops___220;

struct super_block___220 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___220 *s_type;
	const struct super_operations___220 *s_op;
	const struct dquot_operations___220 *dq_op;
	const struct quotactl_ops___220 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___220 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___220 s_dquot;
	struct sb_writers___220 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___220 *s_d_op;
	int cleancache_poolid;
	struct shrinker___95 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___220 {
	struct dentry___220 *mnt_root;
	struct super_block___220 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct cgroup_subsys___150;

struct cgroup_subsys_state___150 {
	struct cgroup___150 *cgroup;
	struct cgroup_subsys___150 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___150 *parent;
};

struct cgroup_file___150 {
	struct kernfs_node___208 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___150 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___227 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___150;

struct cgroup_rstat_cpu___150;

struct cgroup___150 {
	struct cgroup_subsys_state___150 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___208 *kn;
	struct cgroup_file___150 procs_file;
	struct cgroup_file___150 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___150 *subsys[14];
	struct cgroup_root___150 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___150 *dom_cgrp;
	struct cgroup___150 *old_dom_cgrp;
	struct cgroup_rstat_cpu___150 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___150 psi;
	struct cgroup_bpf___20 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___220 {
	struct file___220 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___220 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___220 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___220 *ia_file;
};

struct dquot___220 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___220 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___220 {
	int qf_fmt_id;
	const struct quota_format_ops___220 *qf_ops;
	struct module___204 *qf_owner;
	struct quota_format_type___220 *qf_next;
};

struct quota_format_ops___220 {
	int (*check_quota_file)(struct super_block___220 *, int);
	int (*read_file_info)(struct super_block___220 *, int);
	int (*write_file_info)(struct super_block___220 *, int);
	int (*free_file_info)(struct super_block___220 *, int);
	int (*read_dqblk)(struct dquot___220 *);
	int (*commit_dqblk)(struct dquot___220 *);
	int (*release_dqblk)(struct dquot___220 *);
	int (*get_next_id)(struct super_block___220 *, struct kqid *);
};

struct dquot_operations___220 {
	int (*write_dquot)(struct dquot___220 *);
	struct dquot___220 * (*alloc_dquot)(struct super_block___220 *, int);
	void (*destroy_dquot)(struct dquot___220 *);
	int (*acquire_dquot)(struct dquot___220 *);
	int (*release_dquot)(struct dquot___220 *);
	int (*mark_dirty)(struct dquot___220 *);
	int (*write_info)(struct super_block___220 *, int);
	qsize_t * (*get_reserved_space)(struct inode___220 *);
	int (*get_projid)(struct inode___220 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___220 *, qsize_t *);
	int (*get_next_id)(struct super_block___220 *, struct kqid *);
};

struct quotactl_ops___220 {
	int (*quota_on)(struct super_block___220 *, int, int, const struct path___220 *);
	int (*quota_off)(struct super_block___220 *, int);
	int (*quota_enable)(struct super_block___220 *, unsigned int);
	int (*quota_disable)(struct super_block___220 *, unsigned int);
	int (*quota_sync)(struct super_block___220 *, int);
	int (*set_info)(struct super_block___220 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___220 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___220 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___220 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___220 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___220 *, unsigned int);
};

struct address_space_operations___220 {
	int (*writepage)(struct page___225 *, struct writeback_control___3 *);
	int (*readpage)(struct file___220 *, struct page___225 *);
	int (*writepages)(struct address_space___220 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___225 *);
	int (*readpages)(struct file___220 *, struct address_space___220 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___220 *, struct address_space___220 *, loff_t, unsigned int, unsigned int, struct page___225 **, void **);
	int (*write_end)(struct file___220 *, struct address_space___220 *, loff_t, unsigned int, unsigned int, struct page___225 *, void *);
	sector_t (*bmap)(struct address_space___220 *, sector_t);
	void (*invalidatepage)(struct page___225 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___225 *, gfp_t);
	void (*freepage)(struct page___225 *);
	ssize_t (*direct_IO)(struct kiocb___220 *, struct iov_iter___140 *);
	int (*migratepage)(struct address_space___220 *, struct page___225 *, struct page___225 *, enum migrate_mode);
	bool (*isolate_page)(struct page___225 *, isolate_mode_t);
	void (*putback_page)(struct page___225 *);
	int (*launder_page)(struct page___225 *);
	int (*is_partially_uptodate)(struct page___225 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___225 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___220 *, struct page___225 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___220 *, sector_t *);
	void (*swap_deactivate)(struct file___220 *);
};

struct bio_vec___137;

struct iov_iter___140 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___137 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___70 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___58 {
	struct kobject___208 kobj;
	struct module___204 *owner;
	const struct file_operations___221 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___220 {
	struct dentry___220 * (*lookup)(struct inode___220 *, struct dentry___220 *, unsigned int);
	const char * (*get_link)(struct dentry___220 *, struct inode___220 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___220 *, int);
	struct posix_acl * (*get_acl)(struct inode___220 *, int, bool);
	int (*readlink)(struct dentry___220 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___220 *, struct dentry___220 *, umode_t, bool);
	int (*link)(struct dentry___220 *, struct inode___220 *, struct dentry___220 *);
	int (*unlink)(struct inode___220 *, struct dentry___220 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___220 *, struct dentry___220 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___220 *, struct dentry___220 *, umode_t);
	int (*rmdir)(struct inode___220 *, struct dentry___220 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___220 *, struct dentry___220 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___220 *, struct dentry___220 *, struct inode___220 *, struct dentry___220 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___220 *, struct iattr___220 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___220 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___220 *, char *, size_t);
	int (*fiemap)(struct inode___220 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___220 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___220 *, struct dentry___220 *, struct file___220 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___220 *, struct dentry___220 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___220 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___220 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___220 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___220 {
	void (*fl_copy_lock)(struct file_lock___220 *, struct file_lock___220 *);
	void (*fl_release_private)(struct file_lock___220 *);
};

struct lock_manager_operations___220;

struct file_lock___220 {
	struct file_lock___220 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___220 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___220 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___220 *fl_ops;
	const struct lock_manager_operations___220 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___220 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___220 *);
	int (*lm_grant)(struct file_lock___220 *, int);
	bool (*lm_break)(struct file_lock___220 *);
	int (*lm_change)(struct file_lock___220 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___220 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___220 *);
};

struct fasync_struct___220 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___220 *fa_next;
	struct file___220 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___220 {
	struct inode___220 * (*alloc_inode)(struct super_block___220 *);
	void (*destroy_inode)(struct inode___220 *);
	void (*free_inode)(struct inode___220 *);
	void (*dirty_inode)(struct inode___220 *, int);
	int (*write_inode)(struct inode___220 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___220 *);
	void (*evict_inode)(struct inode___220 *);
	void (*put_super)(struct super_block___220 *);
	int (*sync_fs)(struct super_block___220 *, int);
	int (*freeze_super)(struct super_block___220 *);
	int (*freeze_fs)(struct super_block___220 *);
	int (*thaw_super)(struct super_block___220 *);
	int (*unfreeze_fs)(struct super_block___220 *);
	int (*statfs)(struct dentry___220 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___220 *, int *, char *);
	void (*umount_begin)(struct super_block___220 *);
	int (*show_options)(struct seq_file___195 *, struct dentry___220 *);
	int (*show_devname)(struct seq_file___195 *, struct dentry___220 *);
	int (*show_path)(struct seq_file___195 *, struct dentry___220 *);
	int (*show_stats)(struct seq_file___195 *, struct dentry___220 *);
	ssize_t (*quota_read)(struct super_block___220 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___220 *, int, const char *, size_t, loff_t);
	struct dquot___220 ** (*get_dquots)(struct inode___220 *);
	long int (*nr_cached_objects)(struct super_block___220 *, struct shrink_control___95 *);
	long int (*free_cached_objects)(struct super_block___220 *, struct shrink_control___95 *);
	struct file___220 * (*real_loop)(struct file___220 *);
};

struct fwnode_reference_args___194;

struct fwnode_endpoint___194;

struct fwnode_operations___194 {
	struct fwnode_handle___194 * (*get)(struct fwnode_handle___194 *);
	void (*put)(struct fwnode_handle___194 *);
	bool (*device_is_available)(const struct fwnode_handle___194 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___194 *, const struct device___198 *);
	bool (*property_present)(const struct fwnode_handle___194 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___194 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___194 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___194 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*get_parent)(const struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*get_next_child_node)(const struct fwnode_handle___194 *, struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*get_named_child_node)(const struct fwnode_handle___194 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___194 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___194 *);
	struct fwnode_handle___194 * (*graph_get_next_endpoint)(const struct fwnode_handle___194 *, struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*graph_get_remote_endpoint)(const struct fwnode_handle___194 *);
	struct fwnode_handle___194 * (*graph_get_port_parent)(struct fwnode_handle___194 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___194 *, struct fwnode_endpoint___194 *);
	int (*add_links)(struct fwnode_handle___194 *);
};

struct fwnode_endpoint___194 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___194 *local_fwnode;
};

struct fwnode_reference_args___194 {
	struct fwnode_handle___194 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct bio_vec___137 {
	struct page___225 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct dma_router___7 {
	struct device___198 *dev;
	void (*route_free)(struct device___198 *, void *);
};

struct dma_device___7;

struct dma_chan_dev___7;

struct dma_chan___8 {
	struct dma_device___7 *device;
	struct device___198 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___7 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___7 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___7)(struct dma_chan___8 *, void *);

struct dma_filter___7 {
	dma_filter_fn___7 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___7;

struct dma_device___7 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___7 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___198 *dev;
	struct module___204 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___8 *);
	int (*device_router_config)(struct dma_chan___8 *);
	void (*device_free_chan_resources)(struct dma_chan___8 *);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memcpy)(struct dma_chan___8 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_xor)(struct dma_chan___8 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_xor_val)(struct dma_chan___8 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_pq)(struct dma_chan___8 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_pq_val)(struct dma_chan___8 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memset)(struct dma_chan___8 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_memset_sg)(struct dma_chan___8 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_interrupt)(struct dma_chan___8 *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_slave_sg)(struct dma_chan___8 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_cyclic)(struct dma_chan___8 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_interleaved_dma)(struct dma_chan___8 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___7 * (*device_prep_dma_imm_data)(struct dma_chan___8 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___8 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___8 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___8 *);
	int (*device_resume)(struct dma_chan___8 *);
	int (*device_terminate_all)(struct dma_chan___8 *);
	void (*device_synchronize)(struct dma_chan___8 *);
	enum dma_status (*device_tx_status)(struct dma_chan___8 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___8 *);
	void (*device_release)(struct dma_device___7 *);
	void (*dbg_summary_show)(struct seq_file___195 *, struct dma_device___7 *);
	struct dentry___220 *dbg_dev_root;
};

struct dma_chan_dev___7 {
	struct dma_chan___8 *chan;
	struct device___198 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___7 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___198 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___7 {
	int (*attach)(struct dma_async_tx_descriptor___7 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___7 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___7 *, size_t);
};

struct dma_async_tx_descriptor___7 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___8 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___7 *);
	int (*desc_free)(struct dma_async_tx_descriptor___7 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___7 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___7 *metadata_ops;
	struct dma_async_tx_descriptor___7 *next;
	struct dma_async_tx_descriptor___7 *parent;
	spinlock_t lock;
};

struct property___63 {
	char *name;
	int length;
	void *value;
	struct property___63 *next;
	long unsigned int _flags;
	struct bin_attribute___208 attr;
};

struct of_reconfig_data___2 {
	struct device_node___86 *dn;
	struct property___63 *prop;
	struct property___63 *old_prop;
};

struct irq_desc___55;

typedef void (*irq_flow_handler_t___55)(struct irq_desc___55 *);

struct irq_chip___55;

struct irq_data___55 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___55 *chip;
	struct irq_domain___53 *domain;
	struct irq_data___55 *parent_data;
	void *chip_data;
};

struct irqaction___37;

struct irq_desc___55 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___55 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___55 handle_irq;
	struct irqaction___37 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___208 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___204 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___55 {
	struct device___198 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___55 *);
	void (*irq_shutdown)(struct irq_data___55 *);
	void (*irq_enable)(struct irq_data___55 *);
	void (*irq_disable)(struct irq_data___55 *);
	void (*irq_ack)(struct irq_data___55 *);
	void (*irq_mask)(struct irq_data___55 *);
	void (*irq_mask_ack)(struct irq_data___55 *);
	void (*irq_unmask)(struct irq_data___55 *);
	void (*irq_eoi)(struct irq_data___55 *);
	int (*irq_set_affinity)(struct irq_data___55 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___55 *);
	int (*irq_set_type)(struct irq_data___55 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___55 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___55 *);
	void (*irq_bus_sync_unlock)(struct irq_data___55 *);
	void (*irq_cpu_online)(struct irq_data___55 *);
	void (*irq_cpu_offline)(struct irq_data___55 *);
	void (*irq_suspend)(struct irq_data___55 *);
	void (*irq_resume)(struct irq_data___55 *);
	void (*irq_pm_shutdown)(struct irq_data___55 *);
	void (*irq_calc_mask)(struct irq_data___55 *);
	void (*irq_print_chip)(struct irq_data___55 *, struct seq_file___195 *);
	int (*irq_request_resources)(struct irq_data___55 *);
	void (*irq_release_resources)(struct irq_data___55 *);
	void (*irq_compose_msi_msg)(struct irq_data___55 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___55 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___55 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___55 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___55 *, void *);
	void (*ipi_send_single)(struct irq_data___55 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___55 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___55 *);
	void (*irq_nmi_teardown)(struct irq_data___55 *);
	long unsigned int flags;
};

struct irqaction___37 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___37 *next;
	irq_handler_t thread_fn;
	struct task_struct___227 *thread;
	struct irqaction___37 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___53 {
	struct irq_chip___55 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___55 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___53 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___53 *);
	void (*resume)(struct irq_chip_generic___53 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___53 *domain;
	struct list_head list;
	struct irq_chip_type___53 chip_types[0];
};

struct irq_domain_chip_generic___53 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___53 *gc[0];
};

struct irq_fwspec___51 {
	struct fwnode_handle___194 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___53 {
	int (*match)(struct irq_domain___53 *, struct device_node___86 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___53 *, struct irq_fwspec___51 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___53 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___53 *, unsigned int);
	int (*xlate)(struct irq_domain___53 *, struct device_node___86 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___53 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___53 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___53 *, struct irq_data___55 *, bool);
	void (*deactivate)(struct irq_domain___53 *, struct irq_data___55 *);
	int (*translate)(struct irq_domain___53 *, struct irq_fwspec___51 *, long unsigned int *, unsigned int *);
};

struct kthread_work___6;

typedef void (*kthread_work_func_t___6)(struct kthread_work___6 *);

struct kthread_worker___6;

struct kthread_work___6 {
	struct list_head node;
	kthread_work_func_t___6 func;
	struct kthread_worker___6 *worker;
	int canceling;
};

struct kthread_worker___6 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___227 *task;
	struct kthread_work___6 *current_work;
};

struct kernel_param_ops___204 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___204 *);
	int (*get)(char *, const struct kernel_param___204 *);
	void (*free)(void *);
};

struct kparam_array___204;

struct kernel_param___204 {
	const char *name;
	struct module___204 *mod;
	const struct kernel_param_ops___204 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___204 *arr;
	};
};

struct kparam_array___204 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___204 *ops;
	void *elem;
};

struct module_attribute___204 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___204 *, struct module_kobject___205 *, char *);
	ssize_t (*store)(struct module_attribute___204 *, struct module_kobject___205 *, const char *, size_t);
	void (*setup)(struct module___204 *, const char *);
	int (*test)(struct module___204 *);
	void (*free)(struct module___204 *);
};

struct trace_event_class___74;

struct trace_event_call___74 {
	struct list_head list;
	struct trace_event_class___74 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___20 *prog_array;
	int (*perf_perm)(struct trace_event_call___74 *, struct perf_event___80 *);
};

struct cgroup_namespace___150 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___150 *root_cset;
};

struct pipe_buf_operations___70;

struct pipe_buffer___70 {
	struct page___225 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___70 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___70 {
	int (*confirm)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
	void (*release)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
	bool (*try_steal)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
	bool (*get)(struct pipe_inode_info___70 *, struct pipe_buffer___70 *);
};

struct acpi_device___17;

struct acpi_hotplug_profile___17 {
	struct kobject___208 kobj;
	int (*scan_dependent)(struct acpi_device___17 *);
	void (*notify_online)(struct acpi_device___17 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___17 {
	void (*func)(struct acpi_device_wakeup_context___17 *);
	struct device___198 *dev;
};

struct acpi_device_wakeup___17 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___17 context;
	struct wakeup_source___198 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___17;

struct acpi_hotplug_context___17;

struct acpi_driver___17;

struct acpi_device___17 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___194 fwnode;
	struct acpi_device___17 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___17 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___17 *handler;
	struct acpi_hotplug_context___17 *hp;
	struct acpi_driver___17 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___198 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___17 *);
};

struct acpi_scan_handler___17 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___17 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___17 *);
	void (*bind)(struct device___198 *);
	void (*unbind)(struct device___198 *);
	struct acpi_hotplug_profile___17 hotplug;
};

struct acpi_hotplug_context___17 {
	struct acpi_device___17 *self;
	int (*notify)(struct acpi_device___17 *, u32);
	void (*uevent)(struct acpi_device___17 *, u32);
	void (*fixup)(struct acpi_device___17 *);
};

typedef int (*acpi_op_add___17)(struct acpi_device___17 *);

typedef int (*acpi_op_remove___17)(struct acpi_device___17 *);

typedef void (*acpi_op_notify___17)(struct acpi_device___17 *, u32);

struct acpi_device_ops___17 {
	acpi_op_add___17 add;
	acpi_op_remove___17 remove;
	acpi_op_notify___17 notify;
};

struct acpi_driver___17 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___17 ops;
	struct device_driver___198 drv;
	struct module___204 *owner;
};

struct seq_operations___195 {
	void * (*start)(struct seq_file___195 *, loff_t *);
	void (*stop)(struct seq_file___195 *, void *);
	void * (*next)(struct seq_file___195 *, void *, loff_t *);
	int (*show)(struct seq_file___195 *, void *);
};

struct spi_controller___3;

struct spi_device___3 {
	struct device___198 dev;
	struct spi_controller___3 *controller;
	struct spi_controller___3 *master;
	u32 max_speed_hz;
	u8 chip_select;
	u8 bits_per_word;
	bool rt;
	u32 mode;
	int irq;
	void *controller_state;
	void *controller_data;
	char modalias[32];
	const char *driver_override;
	int cs_gpio;
	struct gpio_desc *cs_gpiod;
	struct spi_delay word_delay;
	struct spi_delay cs_setup;
	struct spi_delay cs_hold;
	struct spi_delay cs_inactive;
	struct spi_statistics statistics;
};

struct spi_message___3;

struct spi_controller_mem_ops___2;

struct spi_controller___3 {
	struct device___198 dev;
	struct list_head list;
	s16 bus_num;
	u16 num_chipselect;
	u16 dma_alignment;
	u32 mode_bits;
	u32 buswidth_override_bits;
	u32 bits_per_word_mask;
	u32 min_speed_hz;
	u32 max_speed_hz;
	u16 flags;
	bool devm_allocated;
	bool slave;
	size_t (*max_transfer_size)(struct spi_device___3 *);
	size_t (*max_message_size)(struct spi_device___3 *);
	struct mutex io_mutex;
	struct mutex add_lock;
	spinlock_t bus_lock_spinlock;
	struct mutex bus_lock_mutex;
	bool bus_lock_flag;
	int (*setup)(struct spi_device___3 *);
	int (*set_cs_timing)(struct spi_device___3 *);
	int (*transfer)(struct spi_device___3 *, struct spi_message___3 *);
	void (*cleanup)(struct spi_device___3 *);
	bool (*can_dma)(struct spi_controller___3 *, struct spi_device___3 *, struct spi_transfer *);
	struct device___198 *dma_map_dev;
	bool queued;
	struct kthread_worker___6 *kworker;
	struct kthread_work___6 pump_messages;
	spinlock_t queue_lock;
	struct list_head queue;
	struct spi_message___3 *cur_msg;
	bool idling;
	bool busy;
	bool running;
	bool rt;
	bool auto_runtime_pm;
	bool cur_msg_prepared;
	bool cur_msg_mapped;
	bool last_cs_enable;
	bool last_cs_mode_high;
	bool fallback;
	struct completion xfer_completion;
	size_t max_dma_len;
	int (*prepare_transfer_hardware)(struct spi_controller___3 *);
	int (*transfer_one_message)(struct spi_controller___3 *, struct spi_message___3 *);
	int (*unprepare_transfer_hardware)(struct spi_controller___3 *);
	int (*prepare_message)(struct spi_controller___3 *, struct spi_message___3 *);
	int (*unprepare_message)(struct spi_controller___3 *, struct spi_message___3 *);
	int (*slave_abort)(struct spi_controller___3 *);
	void (*set_cs)(struct spi_device___3 *, bool);
	int (*transfer_one)(struct spi_controller___3 *, struct spi_device___3 *, struct spi_transfer *);
	void (*handle_err)(struct spi_controller___3 *, struct spi_message___3 *);
	const struct spi_controller_mem_ops___2 *mem_ops;
	int *cs_gpios;
	struct gpio_desc **cs_gpiods;
	bool use_gpio_descriptors;
	s8 unused_native_cs;
	s8 max_native_cs;
	struct spi_statistics statistics;
	struct dma_chan___8 *dma_tx;
	struct dma_chan___8 *dma_rx;
	void *dummy_rx;
	void *dummy_tx;
	int (*fw_translate_cs)(struct spi_controller___3 *, unsigned int);
	bool ptp_sts_supported;
	long unsigned int irq_flags;
};

struct spi_driver___3 {
	const struct spi_device_id *id_table;
	int (*probe)(struct spi_device___3 *);
	int (*remove)(struct spi_device___3 *);
	void (*shutdown)(struct spi_device___3 *);
	struct device_driver___198 driver;
};

struct spi_message___3 {
	struct list_head transfers;
	struct spi_device___3 *spi;
	unsigned int is_dma_mapped: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	void (*complete)(void *);
	void *context;
	unsigned int frame_length;
	unsigned int actual_length;
	int status;
	struct list_head queue;
	void *state;
	struct list_head resources;
};

struct spi_mem___2;

struct spi_mem_op___2;

struct spi_mem_dirmap_desc___2;

struct spi_controller_mem_ops___2 {
	int (*adjust_op_size)(struct spi_mem___2 *, struct spi_mem_op___2 *);
	bool (*supports_op)(struct spi_mem___2 *, const struct spi_mem_op___2 *);
	int (*exec_op)(struct spi_mem___2 *, const struct spi_mem_op___2 *);
	const char * (*get_name)(struct spi_mem___2 *);
	int (*dirmap_create)(struct spi_mem_dirmap_desc___2 *);
	void (*dirmap_destroy)(struct spi_mem_dirmap_desc___2 *);
	ssize_t (*dirmap_read)(struct spi_mem_dirmap_desc___2 *, u64, size_t, void *);
	ssize_t (*dirmap_write)(struct spi_mem_dirmap_desc___2 *, u64, size_t, const void *);
	int (*poll_status)(struct spi_mem___2 *, const struct spi_mem_op___2 *, u16, u16, long unsigned int, long unsigned int, long unsigned int);
};

typedef void (*spi_res_release_t)(struct spi_controller___3 *, struct spi_message___3 *, void *);

struct spi_res {
	struct list_head entry;
	spi_res_release_t release;
	long long unsigned int data[0];
};

struct spi_replaced_transfers;

typedef void (*spi_replaced_release_t)(struct spi_controller___3 *, struct spi_message___3 *, struct spi_replaced_transfers *);

struct spi_replaced_transfers {
	spi_replaced_release_t release;
	void *extradata;
	struct list_head replaced_transfers;
	struct list_head *replaced_after;
	size_t inserted;
	struct spi_transfer inserted_transfers[0];
};

struct spi_board_info {
	char modalias[32];
	const void *platform_data;
	const struct software_node *swnode;
	void *controller_data;
	int irq;
	u32 max_speed_hz;
	u16 bus_num;
	u16 chip_select;
	u32 mode;
};

enum spi_mem_data_dir {
	SPI_MEM_NO_DATA = 0,
	SPI_MEM_DATA_IN = 1,
	SPI_MEM_DATA_OUT = 2,
};

struct spi_mem_op___2 {
	struct {
		u8 nbytes;
		u8 buswidth;
		u8 dtr: 1;
		int: 31;
		u16 opcode;
	} cmd;
	struct {
		u8 nbytes;
		u8 buswidth;
		u8 dtr: 1;
		u64 val;
	} addr;
	struct {
		u8 nbytes;
		u8 buswidth;
		u8 dtr: 1;
		int: 23;
	} dummy;
	struct {
		u8 buswidth;
		u8 dtr: 1;
		enum spi_mem_data_dir dir;
		unsigned int nbytes;
		union {
			void *in;
			const void *out;
		} buf;
	} data;
};

struct spi_mem_dirmap_info {
	struct spi_mem_op___2 op_tmpl;
	u64 offset;
	u64 length;
};

struct spi_mem_dirmap_desc___2 {
	struct spi_mem___2 *mem;
	struct spi_mem_dirmap_info info;
	unsigned int nodirmap;
	void *priv;
};

struct spi_mem___2 {
	struct spi_device___3 *spi;
	void *drvpriv;
	const char *name;
};

struct cftype___150;

struct cgroup_subsys___150 {
	struct cgroup_subsys_state___150 * (*css_alloc)(struct cgroup_subsys_state___150 *);
	int (*css_online)(struct cgroup_subsys_state___150 *);
	void (*css_offline)(struct cgroup_subsys_state___150 *);
	void (*css_released)(struct cgroup_subsys_state___150 *);
	void (*css_free)(struct cgroup_subsys_state___150 *);
	void (*css_reset)(struct cgroup_subsys_state___150 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___150 *, int);
	int (*css_extra_stat_show)(struct seq_file___195 *, struct cgroup_subsys_state___150 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___227 *, struct css_set___150 *);
	void (*cancel_fork)(struct task_struct___227 *, struct css_set___150 *);
	void (*fork)(struct task_struct___227 *);
	void (*exit)(struct task_struct___227 *);
	void (*release)(struct task_struct___227 *);
	void (*bind)(struct cgroup_subsys_state___150 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___150 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___150 *dfl_cftypes;
	struct cftype___150 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___150 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___150 *updated_children;
	struct cgroup___150 *updated_next;
};

struct cgroup_root___150 {
	struct kernfs_root___208 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___150 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___150 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___150 *ss;
	struct list_head node;
	struct kernfs_ops___208 *kf_ops;
	int (*open)(struct kernfs_open_file___208 *);
	void (*release)(struct kernfs_open_file___208 *);
	u64 (*read_u64)(struct cgroup_subsys_state___150 *, struct cftype___150 *);
	s64 (*read_s64)(struct cgroup_subsys_state___150 *, struct cftype___150 *);
	int (*seq_show)(struct seq_file___195 *, void *);
	void * (*seq_start)(struct seq_file___195 *, loff_t *);
	void * (*seq_next)(struct seq_file___195 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___195 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___150 *, struct cftype___150 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___150 *, struct cftype___150 *, s64);
	ssize_t (*write)(struct kernfs_open_file___208 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___208 *, struct poll_table_struct___145 *);
};

struct perf_cpu_context___80;

struct perf_output_handle___80;

struct pmu___80 {
	struct list_head entry;
	struct module___204 *module;
	struct device___198 *dev;
	const struct attribute_group___208 **attr_groups;
	const struct attribute_group___208 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___80 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___80 *);
	void (*pmu_disable)(struct pmu___80 *);
	int (*event_init)(struct perf_event___80 *);
	void (*event_mapped)(struct perf_event___80 *, struct mm_struct___226 *);
	void (*event_unmapped)(struct perf_event___80 *, struct mm_struct___226 *);
	int (*add)(struct perf_event___80 *, int);
	void (*del)(struct perf_event___80 *, int);
	void (*start)(struct perf_event___80 *, int);
	void (*stop)(struct perf_event___80 *, int);
	void (*read)(struct perf_event___80 *);
	void (*start_txn)(struct pmu___80 *, unsigned int);
	int (*commit_txn)(struct pmu___80 *);
	void (*cancel_txn)(struct pmu___80 *);
	int (*event_idx)(struct perf_event___80 *);
	void (*sched_task)(struct perf_event_context___80 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___80 *, struct perf_event_context___80 *);
	void * (*setup_aux)(struct perf_event___80 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___80 *, struct perf_output_handle___80 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___80 *);
	int (*aux_output_match)(struct perf_event___80 *);
	int (*filter_match)(struct perf_event___80 *);
	int (*check_period)(struct perf_event___80 *, u64);
};

struct perf_cpu_context___80 {
	struct perf_event_context___80 ctx;
	struct perf_event_context___80 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___80 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___80 **heap;
	struct perf_event___80 *heap_default[2];
};

struct perf_output_handle___80 {
	struct perf_event___80 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___80 {
	struct cgroup_subsys_state___150 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___74 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___74 *);
	};
};

struct trace_event_class___74 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___74 *, enum trace_reg, void *);
	struct trace_event_fields___74 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___74 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___74 *);
};

struct trace_event_file___33;

struct trace_event_buffer___32 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___33 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___33 {
	struct list_head list;
	struct trace_event_call___74 *event_call;
	struct event_filter *filter;
	struct dentry___220 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_spi_controller {
	struct trace_entry ent;
	int bus_num;
	char __data[0];
};

struct trace_event_raw_spi_setup {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	long unsigned int mode;
	unsigned int bits_per_word;
	unsigned int max_speed_hz;
	int status;
	char __data[0];
};

struct trace_event_raw_spi_set_cs {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	long unsigned int mode;
	bool enable;
	char __data[0];
};

struct trace_event_raw_spi_message {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	struct spi_message___3 *msg;
	char __data[0];
};

struct trace_event_raw_spi_message_done {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	struct spi_message___3 *msg;
	unsigned int frame;
	unsigned int actual;
	char __data[0];
};

struct trace_event_raw_spi_transfer {
	struct trace_entry ent;
	int bus_num;
	int chip_select;
	struct spi_transfer *xfer;
	int len;
	u32 __data_loc_rx_buf;
	u32 __data_loc_tx_buf;
	char __data[0];
};

struct trace_event_data_offsets_spi_controller {};

struct trace_event_data_offsets_spi_setup {};

struct trace_event_data_offsets_spi_set_cs {};

struct trace_event_data_offsets_spi_message {};

struct trace_event_data_offsets_spi_message_done {};

struct trace_event_data_offsets_spi_transfer {
	u32 rx_buf;
	u32 tx_buf;
};

typedef void (*btf_trace_spi_controller_idle)(void *, struct spi_controller___3 *);

typedef void (*btf_trace_spi_controller_busy)(void *, struct spi_controller___3 *);

typedef void (*btf_trace_spi_setup)(void *, struct spi_device___3 *, int);

typedef void (*btf_trace_spi_set_cs)(void *, struct spi_device___3 *, bool);

typedef void (*btf_trace_spi_message_submit)(void *, struct spi_message___3 *);

typedef void (*btf_trace_spi_message_start)(void *, struct spi_message___3 *);

typedef void (*btf_trace_spi_message_done)(void *, struct spi_message___3 *);

typedef void (*btf_trace_spi_transfer_start)(void *, struct spi_message___3 *, struct spi_transfer *);

typedef void (*btf_trace_spi_transfer_stop)(void *, struct spi_message___3 *, struct spi_transfer *);

struct boardinfo {
	struct list_head list;
	struct spi_board_info board_info;
};

struct acpi_spi_lookup {
	struct spi_controller___3 *ctlr;
	u32 max_speed_hz;
	u32 mode;
	int irq;
	u8 bits_per_word;
	u8 chip_select;
	int n;
	int index;
};

struct dma_router___8 {
	struct device___190 *dev;
	void (*route_free)(struct device___190 *, void *);
};

struct dma_device___8;

struct dma_chan_dev___8;

struct dma_chan___6 {
	struct dma_device___8 *device;
	struct device___190 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___8 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___8 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___8)(struct dma_chan___6 *, void *);

struct dma_filter___8 {
	dma_filter_fn___8 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___8;

struct dma_device___8 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___8 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___190 *dev;
	struct module___196 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___6 *);
	int (*device_router_config)(struct dma_chan___6 *);
	void (*device_free_chan_resources)(struct dma_chan___6 *);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memcpy)(struct dma_chan___6 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_xor)(struct dma_chan___6 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_xor_val)(struct dma_chan___6 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_pq)(struct dma_chan___6 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_pq_val)(struct dma_chan___6 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memset)(struct dma_chan___6 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_memset_sg)(struct dma_chan___6 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_interrupt)(struct dma_chan___6 *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_slave_sg)(struct dma_chan___6 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_cyclic)(struct dma_chan___6 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_interleaved_dma)(struct dma_chan___6 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___8 * (*device_prep_dma_imm_data)(struct dma_chan___6 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___6 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___6 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___6 *);
	int (*device_resume)(struct dma_chan___6 *);
	int (*device_terminate_all)(struct dma_chan___6 *);
	void (*device_synchronize)(struct dma_chan___6 *);
	enum dma_status (*device_tx_status)(struct dma_chan___6 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___6 *);
	void (*device_release)(struct dma_device___8 *);
	void (*dbg_summary_show)(struct seq_file___187 *, struct dma_device___8 *);
	struct dentry___212 *dbg_dev_root;
};

struct dma_chan_dev___8 {
	struct dma_chan___6 *chan;
	struct device___190 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___8 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___190 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___8 {
	int (*attach)(struct dma_async_tx_descriptor___8 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___8 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___8 *, size_t);
};

struct dma_async_tx_descriptor___8 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___6 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___8 *);
	int (*desc_free)(struct dma_async_tx_descriptor___8 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___8 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___8 *metadata_ops;
	struct dma_async_tx_descriptor___8 *next;
	struct dma_async_tx_descriptor___8 *parent;
	spinlock_t lock;
};

struct spi_mem_op {
	struct {
		u8 nbytes;
		u8 buswidth;
		u8 dtr;
		int: 24;
		u16 opcode;
	} cmd;
	struct {
		u8 nbytes;
		u8 buswidth;
		u8 dtr;
		u64 val;
	} addr;
	struct {
		u8 nbytes;
		u8 buswidth;
		u8 dtr;
		short: 16;
	} dummy;
	struct {
		u8 buswidth;
		u8 dtr;
		enum spi_mem_data_dir dir;
		unsigned int nbytes;
		union {
			void *in;
			const void *out;
		} buf;
	} data;
};

struct spi_mem_dirmap_info___2 {
	struct spi_mem_op op_tmpl;
	u64 offset;
	u64 length;
};

struct spi_mem_dirmap_desc {
	struct spi_mem *mem;
	struct spi_mem_dirmap_info___2 info;
	unsigned int nodirmap;
	void *priv;
};

struct spi_mem {
	struct spi_device___2 *spi;
	void *drvpriv;
	const char *name;
};

struct spi_mem_driver {
	struct spi_driver___2 spidrv;
	int (*probe)(struct spi_mem *);
	int (*remove)(struct spi_mem *);
	void (*shutdown)(struct spi_mem *);
};

struct fsl_spi_platform_data {
	u32 initial_spmode;
	s16 bus_num;
	unsigned int flags;
	u16 max_chipselect;
	void (*cs_control)(struct spi_device___2 *, bool);
	u32 sysclk;
};

struct spi_pram;

struct mpc8xxx_spi {
	struct device___190 *dev;
	void *reg_base;
	const void *tx;
	void *rx;
	int subblock;
	struct spi_pram *pram;
	struct spi_transfer *xfer_in_progress;
	dma_addr_t tx_dma;
	dma_addr_t rx_dma;
	bool map_tx_dma;
	bool map_rx_dma;
	dma_addr_t dma_dummy_tx;
	dma_addr_t dma_dummy_rx;
	void (*get_rx)(u32, struct mpc8xxx_spi *);
	u32 (*get_tx)(struct mpc8xxx_spi *);
	unsigned int count;
	unsigned int irq;
	unsigned int nsecs;
	u32 spibrg;
	u32 rx_shift;
	u32 tx_shift;
	unsigned int flags;
	int type;
	int native_chipselects;
	u8 max_bits_per_word;
	void (*set_shifts)(u32 *, u32 *, int, int);
	struct completion done;
};

struct mpc8xxx_spi_probe_info {
	struct fsl_spi_platform_data pdata;
	__be32 *immr_spi_cs;
};

struct fsl_spi_platform_data___2 {
	u32 initial_spmode;
	s16 bus_num;
	unsigned int flags;
	u16 max_chipselect;
	void (*cs_control)(struct spi_device___3 *, bool);
	u32 sysclk;
};

struct platform_driver___30 {
	int (*probe)(struct platform_device___30 *);
	int (*remove)(struct platform_device___30 *);
	void (*shutdown)(struct platform_device___30 *);
	int (*suspend)(struct platform_device___30 *, pm_message_t);
	int (*resume)(struct platform_device___30 *);
	struct device_driver___198 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct mpc8xxx_spi___2 {
	struct device___198 *dev;
	void *reg_base;
	const void *tx;
	void *rx;
	int subblock;
	struct spi_pram *pram;
	struct spi_transfer *xfer_in_progress;
	dma_addr_t tx_dma;
	dma_addr_t rx_dma;
	bool map_tx_dma;
	bool map_rx_dma;
	dma_addr_t dma_dummy_tx;
	dma_addr_t dma_dummy_rx;
	void (*get_rx)(u32, struct mpc8xxx_spi___2 *);
	u32 (*get_tx)(struct mpc8xxx_spi___2 *);
	unsigned int count;
	unsigned int irq;
	unsigned int nsecs;
	u32 spibrg;
	u32 rx_shift;
	u32 tx_shift;
	unsigned int flags;
	int type;
	int native_chipselects;
	u8 max_bits_per_word;
	void (*set_shifts)(u32 *, u32 *, int, int);
	struct completion done;
};

struct spi_mpc8xxx_cs {
	void (*get_rx)(u32, struct mpc8xxx_spi___2 *);
	u32 (*get_tx)(struct mpc8xxx_spi___2 *);
	u32 rx_shift;
	u32 tx_shift;
	u32 hw_mode;
};

struct mpc8xxx_spi_probe_info___2 {
	struct fsl_spi_platform_data___2 pdata;
	__be32 *immr_spi_cs;
};

struct fsl_spi_reg {
	__be32 cap;
	u8 res1[28];
	__be32 mode;
	__be32 event;
	__be32 mask;
	__be32 command;
	__be32 transmit;
	__be32 receive;
	__be32 slvsel;
};

struct fsl_spi_match_data {
	int type;
};

struct omap2_mcspi_platform_config {
	short unsigned int num_cs;
	unsigned int regs_offset;
	unsigned int pin_dir: 1;
	long: 63;
	long: 64;
	size_t max_xfer_len;
};

struct omap2_mcspi_device_config {
	unsigned int turbo_mode: 1;
	unsigned int cs_per_word: 1;
};

struct omap2_mcspi_dma {
	struct dma_chan___8 *dma_tx;
	struct dma_chan___8 *dma_rx;
	struct completion dma_tx_completion;
	struct completion dma_rx_completion;
	char dma_rx_ch_name[14];
	char dma_tx_ch_name[14];
};

struct omap2_mcspi_regs {
	u32 modulctrl;
	u32 wakeupenable;
	struct list_head cs;
};

struct omap2_mcspi {
	struct completion txdone;
	struct spi_controller___3 *master;
	void *base;
	long unsigned int phys;
	struct omap2_mcspi_dma *dma_channels;
	struct device___198 *dev;
	struct omap2_mcspi_regs ctx;
	int fifo_depth;
	bool slave_aborted;
	unsigned int pin_dir: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	size_t max_xfer_len;
};

struct omap2_mcspi_cs {
	void *base;
	long unsigned int phys;
	int word_len;
	u16 mode;
	struct list_head node;
	u32 chconf0;
	u32 chctrl0;
};

enum netdev_state_t {
	__LINK_STATE_START = 0,
	__LINK_STATE_PRESENT = 1,
	__LINK_STATE_NOCARRIER = 2,
	__LINK_STATE_LINKWATCH_PENDING = 3,
	__LINK_STATE_DORMANT = 4,
	__LINK_STATE_TESTING = 5,
};

struct ethtool_cmd {
	__u32 cmd;
	__u32 supported;
	__u32 advertising;
	__u16 speed;
	__u8 duplex;
	__u8 port;
	__u8 phy_address;
	__u8 transceiver;
	__u8 autoneg;
	__u8 mdio_support;
	__u32 maxtxpkt;
	__u32 maxrxpkt;
	__u16 speed_hi;
	__u8 eth_tp_mdix;
	__u8 eth_tp_mdix_ctrl;
	__u32 lp_advertising;
	__u32 reserved[2];
};

struct mii_ioctl_data {
	__u16 phy_id;
	__u16 reg_num;
	__u16 val_in;
	__u16 val_out;
};

struct mii_if_info {
	int phy_id;
	int advertising;
	int phy_id_mask;
	int reg_num_mask;
	unsigned int full_duplex: 1;
	unsigned int force_media: 1;
	unsigned int supports_gmii: 1;
	long: 63;
	long: 64;
	long: 64;
	struct net_device___4 *dev;
	int (*mdio_read)(struct net_device___4 *, int, int);
	void (*mdio_write)(struct net_device___4 *, int, int, int);
};

struct dentry___221;

struct super_block___221;

struct module___205;

struct file_system_type___221 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___221 * (*mount)(struct file_system_type___221 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___221 *);
	struct module___205 *owner;
	struct file_system_type___221 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___221;

struct kiocb___221;

struct iov_iter___141;

struct poll_table_struct___146;

struct vm_area_struct___226;

struct inode___221;

struct file_lock___221;

struct page___226;

struct pipe_inode_info___71;

struct seq_file___196;

struct file_operations___222 {
	struct module___205 *owner;
	loff_t (*llseek)(struct file___221 *, loff_t, int);
	ssize_t (*read)(struct file___221 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___221 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___221 *, struct iov_iter___141 *);
	ssize_t (*write_iter)(struct kiocb___221 *, struct iov_iter___141 *);
	int (*iopoll)(struct kiocb___221 *, bool);
	int (*iterate)(struct file___221 *, struct dir_context *);
	int (*iterate_shared)(struct file___221 *, struct dir_context *);
	__poll_t (*poll)(struct file___221 *, struct poll_table_struct___146 *);
	long int (*unlocked_ioctl)(struct file___221 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___221 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___221 *, struct vm_area_struct___226 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___221 *, struct file___221 *);
	int (*flush)(struct file___221 *, fl_owner_t);
	int (*release)(struct inode___221 *, struct file___221 *);
	int (*fsync)(struct file___221 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___221 *, int);
	int (*lock)(struct file___221 *, int, struct file_lock___221 *);
	ssize_t (*sendpage)(struct file___221 *, struct page___226 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___221 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___221 *, long unsigned int);
	int (*flock)(struct file___221 *, int, struct file_lock___221 *);
	ssize_t (*splice_write)(struct pipe_inode_info___71 *, struct file___221 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___221 *, loff_t *, struct pipe_inode_info___71 *, size_t, unsigned int);
	int (*setlease)(struct file___221 *, long int, struct file_lock___221 **, void **);
	long int (*fallocate)(struct file___221 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___196 *, struct file___221 *);
	ssize_t (*copy_file_range)(struct file___221 *, loff_t, struct file___221 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___221 *, loff_t, struct file___221 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___221 *, loff_t, loff_t, int);
};

struct vmacache___226 {
	u64 seqnum;
	struct vm_area_struct___226 *vmas[4];
};

struct page_frag___226 {
	struct page___226 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___227;

struct pid___198;

struct nsproxy___207;

struct signal_struct___222;

struct bio_list___116;

struct backing_dev_info___105;

struct io_context___116;

struct css_set___151;

struct mem_cgroup___96;

struct request_queue___116;

struct vm_struct___204;

struct task_struct___228 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___228 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___227 *mm;
	struct mm_struct___227 *active_mm;
	struct vmacache___226 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___228 *real_parent;
	struct task_struct___228 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___228 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___198 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___207 *nsproxy;
	struct signal_struct___222 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___228 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___116 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___105 *backing_dev_info;
	struct io_context___116 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___151 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___71 *splice_pipe;
	struct page_frag___226 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___96 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___96 *active_memcg;
	struct request_queue___116 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___228 *oom_reaper_list;
	struct vm_struct___204 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___80 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___209;

struct kobj_type___209;

struct kernfs_node___209;

struct kobject___209 {
	const char *name;
	struct list_head entry;
	struct kobject___209 *parent;
	struct kset___209 *kset;
	struct kobj_type___209 *ktype;
	struct kernfs_node___209 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___206 {
	struct kobject___209 kobj;
	struct module___205 *mod;
	struct kobject___209 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___205 {
	struct module___205 *mod;
	struct latch_tree_node node;
};

struct module_layout___205 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___205 mtn;
};

struct module_attribute___205;

struct kernel_param___205;

struct module___205 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___206 mkobj;
	struct module_attribute___205 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___209 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___205 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___205 core_layout;
	struct module_layout___205 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___198;

struct upid___198 {
	int nr;
	struct pid_namespace___198 *ns;
};

struct pid_namespace___198 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___228 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___198 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___198 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___198 numbers[1];
};

typedef struct page___226 *pgtable_t___226;

struct address_space___221;

struct page_pool___59;

struct dev_pagemap___216;

struct page___226 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___221 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___59 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___226 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___226 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___227 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___216 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___216;

struct vm_area_struct___226 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___226 *vm_next;
	struct vm_area_struct___226 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___227 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___216 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___221 *vm_file;
	struct file___221 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___222 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___228 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___228 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___198 *pids[4];
	struct pid___198 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___227 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___226;

struct mm_struct___227 {
	struct {
		struct vm_area_struct___226 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___221 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___226 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___228 *owner;
		struct user_namespace___14 *user_ns;
		struct file___221 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___44;

struct cgroup_namespace___151;

struct nsproxy___207 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___198 *pid_ns_for_children;
	struct net___44 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___151 *cgroup_ns;
};

struct bio___116;

struct bio_list___116 {
	struct bio___116 *head;
	struct bio___116 *tail;
};

struct cgroup_subsys_state___151;

struct bdi_writeback___105 {
	struct backing_dev_info___105 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___151 *memcg_css;
	struct cgroup_subsys_state___151 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___199;

struct backing_dev_info___105 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___105 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___199 *dev;
	char dev_name[64];
	struct device___199 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___221 *debug_dir;
};

struct io_cq___116;

struct io_context___116 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___116 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___151;

struct css_set___151 {
	struct cgroup_subsys_state___151 *subsys[14];
	refcount_t refcount;
	struct css_set___151 *dom_cset;
	struct cgroup___151 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___151 *mg_src_cgrp;
	struct cgroup___151 *mg_dst_cgrp;
	struct css_set___151 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___221;

struct pipe_buffer___71;

struct pipe_inode_info___71 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___226 *tmp_page;
	struct fasync_struct___221 *fasync_readers;
	struct fasync_struct___221 *fasync_writers;
	struct pipe_buffer___71 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___151;

struct cgroup_subsys_state___151 {
	struct cgroup___151 *cgroup;
	struct cgroup_subsys___151 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___151 *parent;
};

struct cgroup_file___151 {
	struct kernfs_node___209 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___96;

struct mem_cgroup_per_node___96;

struct mem_cgroup___96 {
	struct cgroup_subsys_state___151 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___151 events_file;
	struct cgroup_file___151 events_local_file;
	struct cgroup_file___151 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___96 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___228 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___96 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___116;

struct blk_integrity___116 {
	const struct blk_integrity_profile___116 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___116 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___116 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___116;

struct elevator_queue___116;

struct blk_mq_ops___113;

struct blk_mq_hw_ctx___113;

struct gendisk___119;

struct blkcg_gq___107;

struct blk_mq_tag_set___113;

struct request_queue___116 {
	struct request___116 *last_merge;
	struct elevator_queue___116 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___113 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___113 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___119 *disk;
	struct kobject___209 kobj;
	struct kobject___209 *mq_kobj;
	struct blk_integrity___116 integrity;
	struct device___199 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___107 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___113 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___116 bio_split;
	struct dentry___221 *debugfs_dir;
	struct dentry___221 *sched_debugfs_dir;
	struct dentry___221 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___204 {
	struct vm_struct___204 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___226 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___221;

struct address_space___221 {
	struct inode___221 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___221 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___59 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___199 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___59 {
	u32 count;
	struct page___226 *cache[128];
};

struct page_pool___59 {
	struct page_pool_params___59 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___226 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___59 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___216;

struct dev_pagemap___216 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___216 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___221;

struct path___221 {
	struct vfsmount___221 *mnt;
	struct dentry___221 *dentry;
};

struct fown_struct___198 {
	rwlock_t lock;
	struct pid___198 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___221 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___221 f_path;
	struct inode___221 *f_inode;
	const struct file_operations___222 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___198 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___221 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___216;

struct vm_operations_struct___216 {
	void (*open)(struct vm_area_struct___226 *);
	void (*close)(struct vm_area_struct___226 *);
	int (*may_split)(struct vm_area_struct___226 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___226 *);
	int (*mprotect)(struct vm_area_struct___226 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___216 *);
	vm_fault_t (*huge_fault)(struct vm_fault___216 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___216 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___226 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___216 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___216 *);
	int (*access)(struct vm_area_struct___226 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___226 *);
	int (*set_policy)(struct vm_area_struct___226 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___226 *, long unsigned int);
	struct page___226 * (*find_special_page)(struct vm_area_struct___226 *, long unsigned int);
};

struct core_thread___226 {
	struct task_struct___228 *task;
	struct core_thread___226 *next;
};

struct core_state___226 {
	atomic_t nr_threads;
	struct core_thread___226 dumper;
	struct completion startup;
};

struct vm_fault___216 {
	const struct {
		struct vm_area_struct___226 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___226 *cow_page;
	struct page___226 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___226 prealloc_pte;
};

struct pglist_data___104;

struct lruvec___104 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___104 *pgdat;
};

struct zone___104 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___104 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___104 {
	struct zone___104 *zone;
	int zone_idx;
};

struct zonelist___104 {
	struct zoneref___104 _zonerefs[321];
};

struct pglist_data___104 {
	struct zone___104 node_zones[5];
	struct zonelist___104 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___228 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___228 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___104 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___221;

struct dentry___221 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___221 *d_parent;
	struct qstr d_name;
	struct inode___221 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___221 *d_op;
	struct super_block___221 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___221;

struct inode___221 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___221 *i_op;
	struct super_block___221 *i_sb;
	struct address_space___221 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___105 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___222 *i_fop;
		void (*free_inode)(struct inode___221 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___221 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___71 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___221 {
	int (*d_revalidate)(struct dentry___221 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___221 *, unsigned int);
	int (*d_hash)(const struct dentry___221 *, struct qstr *);
	int (*d_compare)(const struct dentry___221 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___221 *);
	int (*d_init)(struct dentry___221 *);
	void (*d_release)(struct dentry___221 *);
	void (*d_prune)(struct dentry___221 *);
	void (*d_iput)(struct dentry___221 *, struct inode___221 *);
	char * (*d_dname)(struct dentry___221 *, char *, int);
	struct vfsmount___221 * (*d_automount)(struct path___221 *);
	int (*d_manage)(const struct path___221 *, bool);
	struct dentry___221 * (*d_real)(struct dentry___221 *, const struct inode___221 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___221;

struct mem_dqinfo___221 {
	struct quota_format_type___221 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___221;

struct quota_info___221 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___221 *files[3];
	struct mem_dqinfo___221 info[3];
	const struct quota_format_ops___221 *ops[3];
};

struct rcuwait___222 {
	struct task_struct___228 *task;
};

struct percpu_rw_semaphore___222 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___222 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___221 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___222 rw_sem[3];
};

struct shrink_control___96;

struct shrinker___96 {
	long unsigned int (*count_objects)(struct shrinker___96 *, struct shrink_control___96 *);
	long unsigned int (*scan_objects)(struct shrinker___96 *, struct shrink_control___96 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___221;

struct dquot_operations___221;

struct quotactl_ops___221;

struct block_device___119;

struct super_block___221 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___221 *s_type;
	const struct super_operations___221 *s_op;
	const struct dquot_operations___221 *dq_op;
	const struct quotactl_ops___221 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___221 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___119 *s_bdev;
	struct backing_dev_info___105 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___221 s_dquot;
	struct sb_writers___221 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___221 *s_d_op;
	int cleancache_poolid;
	struct shrinker___96 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___221 {
	struct dentry___221 *mnt_root;
	struct super_block___221 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___96 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___96 *memcg;
};

struct psi_group___151 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___228 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___37;

struct cgroup_bpf___37 {
	struct bpf_prog_array___37 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___37 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___151;

struct cgroup_rstat_cpu___151;

struct cgroup___151 {
	struct cgroup_subsys_state___151 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___209 *kn;
	struct cgroup_file___151 procs_file;
	struct cgroup_file___151 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___151 *subsys[14];
	struct cgroup_root___151 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___151 *dom_cgrp;
	struct cgroup___151 *old_dom_cgrp;
	struct cgroup_rstat_cpu___151 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___151 psi;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___116 {
	struct request_queue___116 *q;
	struct io_context___116 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___221 {
	struct file___221 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___221 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___221 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___221 *ia_file;
};

struct dquot___221 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___221 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___221 {
	int qf_fmt_id;
	const struct quota_format_ops___221 *qf_ops;
	struct module___205 *qf_owner;
	struct quota_format_type___221 *qf_next;
};

struct quota_format_ops___221 {
	int (*check_quota_file)(struct super_block___221 *, int);
	int (*read_file_info)(struct super_block___221 *, int);
	int (*write_file_info)(struct super_block___221 *, int);
	int (*free_file_info)(struct super_block___221 *, int);
	int (*read_dqblk)(struct dquot___221 *);
	int (*commit_dqblk)(struct dquot___221 *);
	int (*release_dqblk)(struct dquot___221 *);
	int (*get_next_id)(struct super_block___221 *, struct kqid *);
};

struct dquot_operations___221 {
	int (*write_dquot)(struct dquot___221 *);
	struct dquot___221 * (*alloc_dquot)(struct super_block___221 *, int);
	void (*destroy_dquot)(struct dquot___221 *);
	int (*acquire_dquot)(struct dquot___221 *);
	int (*release_dquot)(struct dquot___221 *);
	int (*mark_dirty)(struct dquot___221 *);
	int (*write_info)(struct super_block___221 *, int);
	qsize_t * (*get_reserved_space)(struct inode___221 *);
	int (*get_projid)(struct inode___221 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___221 *, qsize_t *);
	int (*get_next_id)(struct super_block___221 *, struct kqid *);
};

struct quotactl_ops___221 {
	int (*quota_on)(struct super_block___221 *, int, int, const struct path___221 *);
	int (*quota_off)(struct super_block___221 *, int);
	int (*quota_enable)(struct super_block___221 *, unsigned int);
	int (*quota_disable)(struct super_block___221 *, unsigned int);
	int (*quota_sync)(struct super_block___221 *, int);
	int (*set_info)(struct super_block___221 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___221 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___221 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___221 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___221 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___221 *, unsigned int);
};

struct writeback_control___105;

struct address_space_operations___221 {
	int (*writepage)(struct page___226 *, struct writeback_control___105 *);
	int (*readpage)(struct file___221 *, struct page___226 *);
	int (*writepages)(struct address_space___221 *, struct writeback_control___105 *);
	int (*set_page_dirty)(struct page___226 *);
	int (*readpages)(struct file___221 *, struct address_space___221 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___221 *, struct address_space___221 *, loff_t, unsigned int, unsigned int, struct page___226 **, void **);
	int (*write_end)(struct file___221 *, struct address_space___221 *, loff_t, unsigned int, unsigned int, struct page___226 *, void *);
	sector_t (*bmap)(struct address_space___221 *, sector_t);
	void (*invalidatepage)(struct page___226 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___226 *, gfp_t);
	void (*freepage)(struct page___226 *);
	ssize_t (*direct_IO)(struct kiocb___221 *, struct iov_iter___141 *);
	int (*migratepage)(struct address_space___221 *, struct page___226 *, struct page___226 *, enum migrate_mode);
	bool (*isolate_page)(struct page___226 *, isolate_mode_t);
	void (*putback_page)(struct page___226 *);
	int (*launder_page)(struct page___226 *);
	int (*is_partially_uptodate)(struct page___226 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___226 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___221 *, struct page___226 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___221 *, sector_t *);
	void (*swap_deactivate)(struct file___221 *);
};

struct writeback_control___105 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___105 *wb;
	struct inode___221 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___138;

struct iov_iter___141 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___138 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___71 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___221 {
	struct dentry___221 * (*lookup)(struct inode___221 *, struct dentry___221 *, unsigned int);
	const char * (*get_link)(struct dentry___221 *, struct inode___221 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___221 *, int);
	struct posix_acl * (*get_acl)(struct inode___221 *, int, bool);
	int (*readlink)(struct dentry___221 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___221 *, struct dentry___221 *, umode_t, bool);
	int (*link)(struct dentry___221 *, struct inode___221 *, struct dentry___221 *);
	int (*unlink)(struct inode___221 *, struct dentry___221 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___221 *, struct dentry___221 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___221 *, struct dentry___221 *, umode_t);
	int (*rmdir)(struct inode___221 *, struct dentry___221 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___221 *, struct dentry___221 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___221 *, struct dentry___221 *, struct inode___221 *, struct dentry___221 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___221 *, struct iattr___221 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___221 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___221 *, char *, size_t);
	int (*fiemap)(struct inode___221 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___221 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___221 *, struct dentry___221 *, struct file___221 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___221 *, struct dentry___221 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___221 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___221 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___221 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___221 {
	void (*fl_copy_lock)(struct file_lock___221 *, struct file_lock___221 *);
	void (*fl_release_private)(struct file_lock___221 *);
};

struct lock_manager_operations___221;

struct file_lock___221 {
	struct file_lock___221 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___221 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___221 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___221 *fl_ops;
	const struct lock_manager_operations___221 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___221 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___221 *);
	int (*lm_grant)(struct file_lock___221 *, int);
	bool (*lm_break)(struct file_lock___221 *);
	int (*lm_change)(struct file_lock___221 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___221 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___221 *);
};

struct fasync_struct___221 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___221 *fa_next;
	struct file___221 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___221 {
	struct inode___221 * (*alloc_inode)(struct super_block___221 *);
	void (*destroy_inode)(struct inode___221 *);
	void (*free_inode)(struct inode___221 *);
	void (*dirty_inode)(struct inode___221 *, int);
	int (*write_inode)(struct inode___221 *, struct writeback_control___105 *);
	int (*drop_inode)(struct inode___221 *);
	void (*evict_inode)(struct inode___221 *);
	void (*put_super)(struct super_block___221 *);
	int (*sync_fs)(struct super_block___221 *, int);
	int (*freeze_super)(struct super_block___221 *);
	int (*freeze_fs)(struct super_block___221 *);
	int (*thaw_super)(struct super_block___221 *);
	int (*unfreeze_fs)(struct super_block___221 *);
	int (*statfs)(struct dentry___221 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___221 *, int *, char *);
	void (*umount_begin)(struct super_block___221 *);
	int (*show_options)(struct seq_file___196 *, struct dentry___221 *);
	int (*show_devname)(struct seq_file___196 *, struct dentry___221 *);
	int (*show_path)(struct seq_file___196 *, struct dentry___221 *);
	int (*show_stats)(struct seq_file___196 *, struct dentry___221 *);
	ssize_t (*quota_read)(struct super_block___221 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___221 *, int, const char *, size_t, loff_t);
	struct dquot___221 ** (*get_dquots)(struct inode___221 *);
	long int (*nr_cached_objects)(struct super_block___221 *, struct shrink_control___96 *);
	long int (*free_cached_objects)(struct super_block___221 *, struct shrink_control___96 *);
	struct file___221 * (*real_loop)(struct file___221 *);
};

struct wakeup_source___199;

struct dev_pm_info___199 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___199 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___199 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___199;

struct bus_type___199;

struct device_driver___199;

struct dev_pm_domain___199;

struct fwnode_handle___195;

struct class___199;

struct attribute_group___209;

struct device___199 {
	struct kobject___209 kobj;
	struct device___199 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___199 *type;
	struct bus_type___199 *bus;
	struct device_driver___199 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___199 power;
	struct dev_pm_domain___199 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___195 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___199 *class;
	const struct attribute_group___209 **groups;
	void (*release)(struct device___199 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___119 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___221 *bd_inode;
	struct super_block___221 *bd_super;
	void *bd_claiming;
	struct device___199 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___209 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___119 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___221 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___153)(struct file___221 *, wait_queue_head_t *, struct poll_table_struct___146 *);

struct poll_table_struct___146 {
	poll_queue_proc___153 _qproc;
	__poll_t _key;
};

struct seq_operations___196;

struct seq_file___196 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___196 *op;
	int poll_event;
	const struct file___221 *file;
	void *private;
};

typedef void bio_end_io_t___116(struct bio___116 *);

struct bio_vec___138 {
	struct page___226 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___116;

struct bio___116 {
	struct bio___116 *bi_next;
	struct block_device___119 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___116 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___107 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___116 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___138 *bi_io_vec;
	struct bio_set___116 *bi_pool;
	struct bio_vec___138 bi_inline_vecs[0];
};

struct kernfs_root___209;

struct kernfs_elem_dir___209 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___209 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___209;

struct kernfs_root___209 {
	struct kernfs_node___209 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___209 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___209 {
	struct kernfs_node___209 *target_kn;
};

struct kernfs_ops___209;

struct kernfs_elem_attr___209 {
	const struct kernfs_ops___209 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___209 *notify_next;
};

struct kernfs_node___209 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___209 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___209 dir;
		struct kernfs_elem_symlink___209 symlink;
		struct kernfs_elem_attr___209 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___209;

struct kernfs_ops___209 {
	int (*open)(struct kernfs_open_file___209 *);
	void (*release)(struct kernfs_open_file___209 *);
	int (*seq_show)(struct seq_file___196 *, void *);
	void * (*seq_start)(struct seq_file___196 *, loff_t *);
	void * (*seq_next)(struct seq_file___196 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___196 *, void *);
	ssize_t (*read)(struct kernfs_open_file___209 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___209 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___209 *, struct poll_table_struct___146 *);
	int (*mmap)(struct kernfs_open_file___209 *, struct vm_area_struct___226 *);
};

struct kernfs_syscall_ops___209 {
	int (*show_options)(struct seq_file___196 *, struct kernfs_root___209 *);
	int (*mkdir)(struct kernfs_node___209 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___209 *);
	int (*rename)(struct kernfs_node___209 *, struct kernfs_node___209 *, const char *);
	int (*show_path)(struct seq_file___196 *, struct kernfs_node___209 *, struct kernfs_root___209 *);
};

struct kernfs_open_file___209 {
	struct kernfs_node___209 *kn;
	struct file___221 *file;
	struct seq_file___196 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___216 *vm_ops;
};

struct sock___31;

struct kobj_ns_type_operations___30 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___31 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___44 *net;
} possible_net_t___39;

struct proto___30;

struct sock_common___30 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___30 *skc_prot;
	possible_net_t___39 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___31 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___40;

struct sk_buff_head___39 {
	struct sk_buff___40 *next;
	struct sk_buff___40 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___30 {
	struct cgroup___151 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___30;

struct socket_wq___31;

struct dst_entry___30;

struct socket___32;

struct net_device___41;

struct sock___31 {
	struct sock_common___30 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___39 sk_error_queue;
	struct sk_buff___40 *sk_rx_skb_cache;
	struct sk_buff_head___39 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___40 *head;
		struct sk_buff___40 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___30 *sk_filter;
	union {
		struct socket_wq___31 *sk_wq;
		struct socket_wq___31 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___30 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___30 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___40 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___40 *sk_tx_skb_cache;
	struct sk_buff_head___39 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___226 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___30 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___198 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___32 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___30 sk_cgrp_data;
	struct mem_cgroup___96 *sk_memcg;
	void (*sk_state_change)(struct sock___31 *);
	void (*sk_data_ready)(struct sock___31 *);
	void (*sk_write_space)(struct sock___31 *);
	void (*sk_error_report)(struct sock___31 *);
	int (*sk_backlog_rcv)(struct sock___31 *, struct sk_buff___40 *);
	struct sk_buff___40 * (*sk_validate_xmit_skb)(struct sock___31 *, struct net_device___41 *, struct sk_buff___40 *);
	void (*sk_destruct)(struct sock___31 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___209;

struct attribute_group___209 {
	const char *name;
	umode_t (*is_visible)(struct kobject___209 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___209 *, struct bin_attribute___209 *, int);
	struct attribute **attrs;
	struct bin_attribute___209 **bin_attrs;
};

struct bin_attribute___209 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___221 * (*f_mapping)();
	ssize_t (*read)(struct file___221 *, struct kobject___209 *, struct bin_attribute___209 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___221 *, struct kobject___209 *, struct bin_attribute___209 *, char *, loff_t, size_t);
	int (*mmap)(struct file___221 *, struct kobject___209 *, struct bin_attribute___209 *, struct vm_area_struct___226 *);
};

struct sysfs_ops___209 {
	ssize_t (*show)(struct kobject___209 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___209 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___209;

struct kset___209 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___209 kobj;
	const struct kset_uevent_ops___209 *uevent_ops;
};

struct kobj_type___209 {
	void (*release)(struct kobject___209 *);
	const struct sysfs_ops___209 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___209 **default_groups;
	const struct kobj_ns_type_operations___30 * (*child_ns_type)(struct kobject___209 *);
	const void * (*namespace)(struct kobject___209 *);
	void (*get_ownership)(struct kobject___209 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___209 {
	int (* const filter)(struct kset___209 *, struct kobject___209 *);
	const char * (* const name)(struct kset___209 *, struct kobject___209 *);
	int (* const uevent)(struct kset___209 *, struct kobject___209 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___205 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___205 *);
	int (*get)(char *, const struct kernel_param___205 *);
	void (*free)(void *);
};

struct kparam_array___205;

struct kernel_param___205 {
	const char *name;
	struct module___205 *mod;
	const struct kernel_param_ops___205 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___205 *arr;
	};
};

struct kparam_array___205 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___205 *ops;
	void *elem;
};

struct module_attribute___205 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___205 *, struct module_kobject___206 *, char *);
	ssize_t (*store)(struct module_attribute___205 *, struct module_kobject___206 *, const char *, size_t);
	void (*setup)(struct module___205 *, const char *);
	int (*test)(struct module___205 *);
	void (*free)(struct module___205 *);
};

struct fwnode_operations___195;

struct fwnode_handle___195 {
	struct fwnode_handle___195 *secondary;
	const struct fwnode_operations___195 *ops;
	struct device___199 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___195;

struct fwnode_endpoint___195;

struct fwnode_operations___195 {
	struct fwnode_handle___195 * (*get)(struct fwnode_handle___195 *);
	void (*put)(struct fwnode_handle___195 *);
	bool (*device_is_available)(const struct fwnode_handle___195 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___195 *, const struct device___199 *);
	bool (*property_present)(const struct fwnode_handle___195 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___195 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___195 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___195 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*get_parent)(const struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*get_next_child_node)(const struct fwnode_handle___195 *, struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*get_named_child_node)(const struct fwnode_handle___195 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___195 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___195 *);
	struct fwnode_handle___195 * (*graph_get_next_endpoint)(const struct fwnode_handle___195 *, struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*graph_get_remote_endpoint)(const struct fwnode_handle___195 *);
	struct fwnode_handle___195 * (*graph_get_port_parent)(struct fwnode_handle___195 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___195 *, struct fwnode_endpoint___195 *);
	int (*add_links)(struct fwnode_handle___195 *);
};

struct fwnode_endpoint___195 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___195 *local_fwnode;
};

struct fwnode_reference_args___195 {
	struct fwnode_handle___195 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msghdr___32 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___141 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___221 *msg_iocb;
};

struct sk_buff___40 {
	union {
		struct {
			struct sk_buff___40 *next;
			struct sk_buff___40 *prev;
			union {
				struct net_device___41 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___31 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___40 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___44;

struct fqdir___44 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___44 *f;
	struct net___44 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___44;

struct inet_frags___44 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___44 *, const void *);
	void (*destructor)(struct inet_frag_queue___44 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct fib_rules_ops___30;

struct fib_notifier_ops___30;

struct netns_ipv4___44 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___30 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___31 *fibnl;
	struct sock___31 **icmp_sk;
	struct sock___31 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___31 **tcp_sk;
	struct fqdir___44 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___30 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___30 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___30 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___30;

struct dst_ops___44 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___44 *);
	struct dst_entry___30 * (*check)(struct dst_entry___30 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___30 *);
	unsigned int (*mtu)(const struct dst_entry___30 *);
	u32 * (*cow_metrics)(struct dst_entry___30 *, long unsigned int);
	void (*destroy)(struct dst_entry___30 *);
	void (*ifdown)(struct dst_entry___30 *, struct net_device___41 *, int);
	struct dst_entry___30 * (*negative_advice)(struct dst_entry___30 *);
	void (*link_failure)(struct sk_buff___40 *);
	void (*update_pmtu)(struct dst_entry___30 *, struct sock___31 *, struct sk_buff___40 *, u32, bool);
	void (*redirect)(struct dst_entry___30 *, struct sock___31 *, struct sk_buff___40 *);
	int (*local_out)(struct net___44 *, struct sock___31 *, struct sk_buff___40 *);
	struct neighbour___30 * (*neigh_lookup)(const struct dst_entry___30 *, struct sk_buff___40 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___30 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___44 {
	struct dst_ops___44 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___44 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___30 *fib6_rules_ops;
	struct sock___31 **icmp_sk;
	struct sock___31 *ndisc_sk;
	struct sock___31 *tcp_sk;
	struct sock___31 *igmp_sk;
	struct sock___31 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___30 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___30 *notifier_ops;
	struct fib_notifier_ops___30 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___44 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___44 *fqdir;
};

struct netns_sctp___30 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___31 *ctl_sock;
	struct sock___31 *udp4_sock;
	struct sock___31 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___37;

struct netns_bpf___37 {
	struct bpf_prog_array___37 *run_array[2];
	struct bpf_prog___37 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___44 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___31 *nlsk;
	struct sock___31 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___44 xfrm4_dst_ops;
	struct dst_ops___44 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___44 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___31 *rtnl;
	struct sock___31 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___41 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___44 ipv4;
	struct netns_ipv6___44 ipv6;
	struct netns_ieee802154_lowpan___44 ieee802154_lowpan;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___39 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___37 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___44 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___31 *crypto_nlsk;
	struct sock___31 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___44 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___40 *fragments_tail;
	struct sk_buff___40 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___44 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___30;

struct fib_lookup_arg___30;

struct fib_rules_ops___30 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___30 *, struct flowi *, int, struct fib_lookup_arg___30 *);
	bool (*suppress)(struct fib_rule___30 *, int, struct fib_lookup_arg___30 *);
	int (*match)(struct fib_rule___30 *, struct flowi *, int);
	int (*configure)(struct fib_rule___30 *, struct sk_buff___40 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___30 *);
	int (*compare)(struct fib_rule___30 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___30 *, struct sk_buff___40 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___30 *);
	void (*flush_cache)(struct fib_rules_ops___30 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___205 *owner;
	struct net___44 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___30 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___44 *);
	int (*fib_dump)(struct net___44 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___205 *owner;
	struct callback_head rcu;
};

struct dst_entry___30 {
	struct net_device___41 *dev;
	struct dst_ops___44 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___40 *);
	int (*output)(struct net___44 *, struct sock___31 *, struct sk_buff___40 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___39(struct sk_buff___40 **);

struct bpf_xdp_entity___37 {
	struct bpf_prog___37 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___39;

struct net_device_ops___39;

struct ethtool_ops___15;

struct l3mdev_ops___30;

struct xfrmdev_ops___39;

struct header_ops___39;

struct netdev_rx_queue___39;

struct mini_Qdisc___37;

struct netdev_queue___39;

struct Qdisc___37;

struct rtnl_link_ops___37;

struct dcbnl_rtnl_ops___39;

struct net_device___41 {
	char name[16];
	struct netdev_name_node___39 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___39 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___15 *ethtool_ops;
	const struct l3mdev_ops___30 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___39 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___39 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___209 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___39 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___37 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___39 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___37 *miniq_ingress;
	struct netdev_queue___39 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___39 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___37 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___37 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___39 = 0,
		NETREG_REGISTERED___39 = 1,
		NETREG_UNREGISTERING___39 = 2,
		NETREG_UNREGISTERED___39 = 3,
		NETREG_RELEASED___39 = 4,
		NETREG_DUMMY___39 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___39 = 0,
		RTNL_LINK_INITIALIZING___39 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___41 *);
	struct netpoll_info *npinfo;
	possible_net_t___39 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___199 dev;
	const struct attribute_group___209 *sysfs_groups[4];
	const struct attribute_group___209 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___37 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___39 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___37 xdp_state[3];
	long: 64;
};

struct neigh_table___30;

struct neigh_parms___30;

struct neigh_ops___30;

struct neighbour___30 {
	struct neighbour___30 *next;
	struct neigh_table___30 *tbl;
	struct neigh_parms___30 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___39 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___30 *, struct sk_buff___40 *);
	const struct neigh_ops___30 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___41 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___37 {
	struct bpf_prog___37 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___37 {
	struct callback_head rcu;
	struct bpf_prog_array_item___37 items[0];
};

struct bpf_prog_aux___42;

struct bpf_prog___37 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___42 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___216 {
	void (*page_free)(struct page___226 *);
	void (*kill)(struct dev_pagemap___216 *);
	void (*cleanup)(struct dev_pagemap___216 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___216 *);
};

struct cgroup_namespace___151 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___151 *root_cset;
};

struct socket_wq___31 {
	wait_queue_head_t wait;
	struct fasync_struct___221 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___31;

struct socket___32 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___221 *file;
	struct sock___31 *sk;
	const struct proto_ops___31 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___31 wq;
};

typedef int (*sk_read_actor_t___30)(read_descriptor_t *, struct sk_buff___40 *, unsigned int, size_t);

struct proto_ops___31 {
	int family;
	struct module___205 *owner;
	int (*release)(struct socket___32 *);
	int (*bind)(struct socket___32 *, struct sockaddr *, int);
	int (*connect)(struct socket___32 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___32 *, struct socket___32 *);
	int (*accept)(struct socket___32 *, struct socket___32 *, int, bool);
	int (*getname)(struct socket___32 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___221 *, struct socket___32 *, struct poll_table_struct___146 *);
	int (*ioctl)(struct socket___32 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___32 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___32 *, void *, bool, bool);
	int (*listen)(struct socket___32 *, int);
	int (*shutdown)(struct socket___32 *, int);
	int (*setsockopt)(struct socket___32 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___32 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___196 *, struct socket___32 *);
	int (*sendmsg)(struct socket___32 *, struct msghdr___32 *, size_t);
	int (*recvmsg)(struct socket___32 *, struct msghdr___32 *, size_t, int);
	int (*mmap)(struct file___221 *, struct socket___32 *, struct vm_area_struct___226 *);
	ssize_t (*sendpage)(struct socket___32 *, struct page___226 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___32 *, loff_t *, struct pipe_inode_info___71 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___31 *, int);
	int (*peek_len)(struct socket___32 *);
	int (*read_sock)(struct sock___31 *, read_descriptor_t *, sk_read_actor_t___30);
	int (*sendpage_locked)(struct sock___31 *, struct page___226 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___31 *, struct msghdr___32 *, size_t);
	int (*set_rcvlowat)(struct sock___31 *, int);
};

struct dev_pm_ops___199 {
	int (*prepare)(struct device___199 *);
	void (*complete)(struct device___199 *);
	int (*suspend)(struct device___199 *);
	int (*resume)(struct device___199 *);
	int (*freeze)(struct device___199 *);
	int (*thaw)(struct device___199 *);
	int (*poweroff)(struct device___199 *);
	int (*restore)(struct device___199 *);
	int (*suspend_late)(struct device___199 *);
	int (*resume_early)(struct device___199 *);
	int (*freeze_late)(struct device___199 *);
	int (*thaw_early)(struct device___199 *);
	int (*poweroff_late)(struct device___199 *);
	int (*restore_early)(struct device___199 *);
	int (*suspend_noirq)(struct device___199 *);
	int (*resume_noirq)(struct device___199 *);
	int (*freeze_noirq)(struct device___199 *);
	int (*thaw_noirq)(struct device___199 *);
	int (*poweroff_noirq)(struct device___199 *);
	int (*restore_noirq)(struct device___199 *);
	int (*runtime_suspend)(struct device___199 *);
	int (*runtime_resume)(struct device___199 *);
	int (*runtime_idle)(struct device___199 *);
};

struct wakeup_source___199 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___199 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___199 {
	struct dev_pm_ops___199 ops;
	int (*start)(struct device___199 *);
	void (*detach)(struct device___199 *, bool);
	int (*activate)(struct device___199 *);
	void (*sync)(struct device___199 *);
	void (*dismiss)(struct device___199 *);
};

struct bus_type___199 {
	const char *name;
	const char *dev_name;
	struct device___199 *dev_root;
	const struct attribute_group___209 **bus_groups;
	const struct attribute_group___209 **dev_groups;
	const struct attribute_group___209 **drv_groups;
	int (*match)(struct device___199 *, struct device_driver___199 *);
	int (*uevent)(struct device___199 *, struct kobj_uevent_env *);
	int (*probe)(struct device___199 *);
	void (*sync_state)(struct device___199 *);
	void (*remove)(struct device___199 *);
	void (*shutdown)(struct device___199 *);
	int (*online)(struct device___199 *);
	int (*offline)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	int (*num_vf)(struct device___199 *);
	int (*dma_configure)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___199 {
	const char *name;
	struct bus_type___199 *bus;
	struct module___205 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___199 *);
	void (*sync_state)(struct device___199 *);
	int (*remove)(struct device___199 *);
	void (*shutdown)(struct device___199 *);
	int (*suspend)(struct device___199 *, pm_message_t);
	int (*resume)(struct device___199 *);
	const struct attribute_group___209 **groups;
	const struct attribute_group___209 **dev_groups;
	const struct dev_pm_ops___199 *pm;
	void (*coredump)(struct device___199 *);
	struct driver_private *p;
};

struct device_type___199 {
	const char *name;
	const struct attribute_group___209 **groups;
	int (*uevent)(struct device___199 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___199 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___199 *);
	const struct dev_pm_ops___199 *pm;
};

struct class___199 {
	const char *name;
	struct module___205 *owner;
	const struct attribute_group___209 **class_groups;
	const struct attribute_group___209 **dev_groups;
	struct kobject___209 *dev_kobj;
	int (*dev_uevent)(struct device___199 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___199 *, umode_t *);
	void (*class_release)(struct class___199 *);
	void (*dev_release)(struct device___199 *);
	int (*shutdown_pre)(struct device___199 *);
	const struct kobj_ns_type_operations___30 *ns_type;
	const void * (*namespace)(struct device___199 *);
	void (*get_ownership)(struct device___199 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___199 *pm;
	struct subsys_private *p;
};

enum {
	NETIF_F_SG_BIT = 0,
	NETIF_F_IP_CSUM_BIT = 1,
	__UNUSED_NETIF_F_1 = 2,
	NETIF_F_HW_CSUM_BIT = 3,
	NETIF_F_IPV6_CSUM_BIT = 4,
	NETIF_F_HIGHDMA_BIT = 5,
	NETIF_F_FRAGLIST_BIT = 6,
	NETIF_F_HW_VLAN_CTAG_TX_BIT = 7,
	NETIF_F_HW_VLAN_CTAG_RX_BIT = 8,
	NETIF_F_HW_VLAN_CTAG_FILTER_BIT = 9,
	NETIF_F_VLAN_CHALLENGED_BIT = 10,
	NETIF_F_GSO_BIT = 11,
	NETIF_F_LLTX_BIT = 12,
	NETIF_F_NETNS_LOCAL_BIT = 13,
	NETIF_F_GRO_BIT = 14,
	NETIF_F_LRO_BIT = 15,
	NETIF_F_GSO_SHIFT = 16,
	NETIF_F_TSO_BIT = 16,
	NETIF_F_GSO_ROBUST_BIT = 17,
	NETIF_F_TSO_ECN_BIT = 18,
	NETIF_F_TSO_MANGLEID_BIT = 19,
	NETIF_F_TSO6_BIT = 20,
	NETIF_F_FSO_BIT = 21,
	NETIF_F_GSO_GRE_BIT = 22,
	NETIF_F_GSO_GRE_CSUM_BIT = 23,
	NETIF_F_GSO_IPXIP4_BIT = 24,
	NETIF_F_GSO_IPXIP6_BIT = 25,
	NETIF_F_GSO_UDP_TUNNEL_BIT = 26,
	NETIF_F_GSO_UDP_TUNNEL_CSUM_BIT = 27,
	NETIF_F_GSO_PARTIAL_BIT = 28,
	NETIF_F_GSO_TUNNEL_REMCSUM_BIT = 29,
	NETIF_F_GSO_SCTP_BIT = 30,
	NETIF_F_GSO_ESP_BIT = 31,
	NETIF_F_GSO_UDP_BIT = 32,
	NETIF_F_GSO_UDP_L4_BIT = 33,
	NETIF_F_GSO_FRAGLIST_BIT = 34,
	NETIF_F_GSO_LAST = 34,
	NETIF_F_FCOE_CRC_BIT = 35,
	NETIF_F_SCTP_CRC_BIT = 36,
	NETIF_F_FCOE_MTU_BIT = 37,
	NETIF_F_NTUPLE_BIT = 38,
	NETIF_F_RXHASH_BIT = 39,
	NETIF_F_RXCSUM_BIT = 40,
	NETIF_F_NOCACHE_COPY_BIT = 41,
	NETIF_F_LOOPBACK_BIT = 42,
	NETIF_F_RXFCS_BIT = 43,
	NETIF_F_RXALL_BIT = 44,
	NETIF_F_HW_VLAN_STAG_TX_BIT = 45,
	NETIF_F_HW_VLAN_STAG_RX_BIT = 46,
	NETIF_F_HW_VLAN_STAG_FILTER_BIT = 47,
	NETIF_F_HW_L2FW_DOFFLOAD_BIT = 48,
	NETIF_F_HW_TC_BIT = 49,
	NETIF_F_HW_ESP_BIT = 50,
	NETIF_F_HW_ESP_TX_CSUM_BIT = 51,
	NETIF_F_RX_UDP_TUNNEL_PORT_BIT = 52,
	NETIF_F_HW_TLS_TX_BIT = 53,
	NETIF_F_HW_TLS_RX_BIT = 54,
	NETIF_F_GRO_HW_BIT = 55,
	NETIF_F_HW_TLS_RECORD_BIT = 56,
	NETIF_F_GRO_FRAGLIST_BIT = 57,
	NETIF_F_HW_MACSEC_BIT = 58,
	NETIF_F_GRO_UDP_FWD_BIT = 59,
	NETIF_F_HW_HSR_TAG_INS_BIT = 60,
	NETIF_F_HW_HSR_TAG_RM_BIT = 61,
	NETIF_F_HW_HSR_FWD_BIT = 62,
	NETIF_F_HW_HSR_DUP_BIT = 63,
	NETDEV_FEATURE_COUNT = 64,
};

struct pipe_buf_operations___71;

struct pipe_buffer___71 {
	struct page___226 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___71 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___71 {
	int (*confirm)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
	void (*release)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
	bool (*try_steal)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
	bool (*get)(struct pipe_inode_info___71 *, struct pipe_buffer___71 *);
};

typedef struct bio_vec___138 skb_frag_t;

struct skb_shared_hwtstamps {
	ktime_t hwtstamp;
};

enum {
	SKBTX_HW_TSTAMP = 1,
	SKBTX_SW_TSTAMP = 2,
	SKBTX_IN_PROGRESS = 4,
	SKBTX_WIFI_STATUS = 16,
	SKBTX_SCHED_TSTAMP = 64,
};

struct skb_shared_info {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___40 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t frags[17];
};

struct seq_operations___196 {
	void * (*start)(struct seq_file___196 *, loff_t *);
	void (*stop)(struct seq_file___196 *, void *);
	void * (*next)(struct seq_file___196 *, void *, loff_t *);
	int (*show)(struct seq_file___196 *, void *);
};

struct pernet_operations___6 {
	struct list_head list;
	int (*init)(struct net___44 *);
	void (*pre_exit)(struct net___44 *);
	void (*exit)(struct net___44 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___39 {
	int (*ieee_getets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___41 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___41 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___41 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___41 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___41 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___41 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___41 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___41 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___41 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___41 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___41 *);
	u8 (*setstate)(struct net_device___41 *, u8);
	void (*getpermhwaddr)(struct net_device___41 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___41 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___41 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___41 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___41 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___41 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___41 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___41 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___41 *, int, u8 *);
	void (*setpfccfg)(struct net_device___41 *, int, u8);
	void (*getpfccfg)(struct net_device___41 *, int, u8 *);
	u8 (*setall)(struct net_device___41 *);
	u8 (*getcap)(struct net_device___41 *, int, u8 *);
	int (*getnumtcs)(struct net_device___41 *, int, u8 *);
	int (*setnumtcs)(struct net_device___41 *, int, u8);
	u8 (*getpfcstate)(struct net_device___41 *);
	void (*setpfcstate)(struct net_device___41 *, u8);
	void (*getbcncfg)(struct net_device___41 *, int, u32 *);
	void (*setbcncfg)(struct net_device___41 *, int, u32);
	void (*getbcnrp)(struct net_device___41 *, int, u8 *);
	void (*setbcnrp)(struct net_device___41 *, int, u8);
	int (*setapp)(struct net_device___41 *, u8, u16, u8);
	int (*getapp)(struct net_device___41 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___41 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___41 *, int, u8);
	u8 (*getdcbx)(struct net_device___41 *);
	u8 (*setdcbx)(struct net_device___41 *, u8);
	int (*peer_getappinfo)(struct net_device___41 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___41 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___41 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___41 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___41 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___41 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___42;

typedef int (*bpf_iter_init_seq_priv_t___41)(void *, struct bpf_iter_aux_info___42 *);

struct bpf_map___42;

struct bpf_iter_aux_info___42 {
	struct bpf_map___42 *map;
};

struct bpf_iter_seq_info___41 {
	const struct seq_operations___196 *seq_ops;
	bpf_iter_init_seq_priv_t___41 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___41 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___42 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___42 *, struct file___221 *);
	void (*map_free)(struct bpf_map___42 *);
	int (*map_get_next_key)(struct bpf_map___42 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___42 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___42 *, void *);
	int (*map_lookup_batch)(struct bpf_map___42 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___42 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___42 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___42 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___42 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___42 *, void *);
	int (*map_update_elem)(struct bpf_map___42 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___42 *, void *);
	int (*map_push_elem)(struct bpf_map___42 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___42 *, void *);
	int (*map_peek_elem)(struct bpf_map___42 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___42 *, struct file___221 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___42 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___42 *, void *, struct seq_file___196 *);
	int (*map_check_btf)(const struct bpf_map___42 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___42 *, struct bpf_prog_aux___42 *);
	void (*map_poke_untrack)(struct bpf_map___42 *, struct bpf_prog_aux___42 *);
	void (*map_poke_run)(struct bpf_map___42 *, u32, struct bpf_prog___37 *, struct bpf_prog___37 *);
	int (*map_direct_value_addr)(const struct bpf_map___42 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___42 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___42 *, struct vm_area_struct___226 *);
	__poll_t (*map_poll)(struct bpf_map___42 *, struct file___221 *, struct poll_table_struct___146 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___42 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___42 *, const struct bpf_map___42 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___42 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___41 *iter_seq_info;
};

struct bpf_map___42 {
	const struct bpf_map_ops___41 *ops;
	struct bpf_map___42 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___96 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___41;

struct bpf_jit_poke_descriptor___41;

struct bpf_prog_ops___37;

struct btf_mod_pair___41;

struct bpf_prog_offload___39;

struct bpf_prog_aux___42 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___37 *dst_prog;
	struct bpf_trampoline___41 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___37 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___41 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___37 *ops;
	struct bpf_map___42 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___41 *used_btfs;
	struct bpf_prog___37 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___42 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___39 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___39;

struct bpf_map_dev_ops___39 {
	int (*map_get_next_key)(struct bpf_offloaded_map___39 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___39 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___39 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___39 *, void *);
};

struct bpf_offloaded_map___39 {
	struct bpf_map___42 map;
	struct net_device___41 *netdev;
	const struct bpf_map_dev_ops___39 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___37 {
	int (*test_run)(struct bpf_prog___37 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___39 {
	struct bpf_prog___37 *prog;
	struct net_device___41 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___41 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___37 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___205 *mod;
};

struct bpf_jit_poke_descriptor___41 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___42 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___41 {
	struct btf *btf;
	struct module___205 *module;
};

struct cftype___151;

struct cgroup_subsys___151 {
	struct cgroup_subsys_state___151 * (*css_alloc)(struct cgroup_subsys_state___151 *);
	int (*css_online)(struct cgroup_subsys_state___151 *);
	void (*css_offline)(struct cgroup_subsys_state___151 *);
	void (*css_released)(struct cgroup_subsys_state___151 *);
	void (*css_free)(struct cgroup_subsys_state___151 *);
	void (*css_reset)(struct cgroup_subsys_state___151 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___151 *, int);
	int (*css_extra_stat_show)(struct seq_file___196 *, struct cgroup_subsys_state___151 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___228 *, struct css_set___151 *);
	void (*cancel_fork)(struct task_struct___228 *, struct css_set___151 *);
	void (*fork)(struct task_struct___228 *);
	void (*exit)(struct task_struct___228 *);
	void (*release)(struct task_struct___228 *);
	void (*bind)(struct cgroup_subsys_state___151 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___151 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___151 *dfl_cftypes;
	struct cftype___151 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___151 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___151 *updated_children;
	struct cgroup___151 *updated_next;
};

struct cgroup_root___151 {
	struct kernfs_root___209 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___151 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___151 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___151 *ss;
	struct list_head node;
	struct kernfs_ops___209 *kf_ops;
	int (*open)(struct kernfs_open_file___209 *);
	void (*release)(struct kernfs_open_file___209 *);
	u64 (*read_u64)(struct cgroup_subsys_state___151 *, struct cftype___151 *);
	s64 (*read_s64)(struct cgroup_subsys_state___151 *, struct cftype___151 *);
	int (*seq_show)(struct seq_file___196 *, void *);
	void * (*seq_start)(struct seq_file___196 *, loff_t *);
	void * (*seq_next)(struct seq_file___196 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___196 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___151 *, struct cftype___151 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___151 *, struct cftype___151 *, s64);
	ssize_t (*write)(struct kernfs_open_file___209 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___209 *, struct poll_table_struct___146 *);
};

struct xdp_rxq_info___39 {
	struct net_device___41 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___39 {
	struct net_device___41 *dev;
};

struct xdp_buff___39 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___39 *rxq;
	struct xdp_txq_info___39 *txq;
	u32 frame_sz;
};

struct xdp_frame___39 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___41 *dev_rx;
};

struct netlink_callback___39 {
	struct sk_buff___40 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___40 *, struct netlink_callback___39 *);
	int (*done)(struct netlink_callback___39 *);
	void *data;
	struct module___205 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___39 {
	int (*create)(struct sk_buff___40 *, struct net_device___41 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___40 *, unsigned char *);
	int (*cache)(const struct neighbour___30 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___41 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___40 *);
};

struct netdev_queue___39 {
	struct net_device___41 *dev;
	struct Qdisc___37 *qdisc;
	struct Qdisc___37 *qdisc_sleeping;
	struct kobject___209 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___41 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___37 {
	struct sk_buff___40 *head;
	struct sk_buff___40 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___37;

struct Qdisc___37 {
	int (*enqueue)(struct sk_buff___40 *, struct Qdisc___37 *, struct sk_buff___40 **);
	struct sk_buff___40 * (*dequeue)(struct Qdisc___37 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___37 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___39 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___39 gso_skb;
	struct qdisc_skb_head___37 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___37 *next_sched;
	struct sk_buff_head___39 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___39 {
	struct xdp_rxq_info___39 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___209 kobj;
	struct net_device___41 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___39 {
	enum net_device_path_type type;
	const struct net_device___41 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___39 = 0,
				DEV_PATH_BR_VLAN_TAG___39 = 1,
				DEV_PATH_BR_VLAN_UNTAG___39 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___39 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___39 {
	const struct net_device___41 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___39 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___37 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___39 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___39 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___40 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___39 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___41 *dev;
	const char *name;
};

struct net_device_ops___39 {
	int (*ndo_init)(struct net_device___41 *);
	void (*ndo_uninit)(struct net_device___41 *);
	int (*ndo_open)(struct net_device___41 *);
	int (*ndo_stop)(struct net_device___41 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___40 *, struct net_device___41 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___40 *, struct net_device___41 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___41 *, struct sk_buff___40 *, struct net_device___41 *);
	void (*ndo_change_rx_flags)(struct net_device___41 *, int);
	void (*ndo_set_rx_mode)(struct net_device___41 *);
	int (*ndo_set_mac_address)(struct net_device___41 *, void *);
	int (*ndo_validate_addr)(struct net_device___41 *);
	int (*ndo_do_ioctl)(struct net_device___41 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___41 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___41 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___41 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___41 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___41 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___41 *, int);
	int (*ndo_neigh_setup)(struct net_device___41 *, struct neigh_parms___30 *);
	void (*ndo_tx_timeout)(struct net_device___41 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___41 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___41 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___41 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___41 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___41 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___41 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___41 *);
	int (*ndo_netpoll_setup)(struct net_device___41 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___41 *);
	int (*ndo_set_vf_mac)(struct net_device___41 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___41 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___41 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___41 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___41 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___41 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___41 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___41 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___41 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___41 *, int, struct sk_buff___40 *);
	int (*ndo_get_vf_guid)(struct net_device___41 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___41 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___41 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___41 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___41 *);
	int (*ndo_fcoe_disable)(struct net_device___41 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___41 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___41 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___41 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___41 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___41 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___41 *, const struct sk_buff___40 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___41 *, struct net_device___41 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___41 *, struct net_device___41 *);
	struct net_device___41 * (*ndo_get_xmit_slave)(struct net_device___41 *, struct sk_buff___40 *, bool);
	struct net_device___41 * (*ndo_sk_get_lower_dev)(struct net_device___41 *, struct sock___31 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___41 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___41 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___41 *, struct neighbour___30 *);
	void (*ndo_neigh_destroy)(struct net_device___41 *, struct neighbour___30 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___40 *, struct netlink_callback___39 *, struct net_device___41 *, struct net_device___41 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___40 *, struct nlattr **, struct net_device___41 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___41 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___40 *, u32, u32, struct net_device___41 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___41 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___41 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___41 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___41 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___41 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___41 *, struct net_device___41 *);
	void (*ndo_dfwd_del_station)(struct net_device___41 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___41 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___41 *);
	int (*ndo_change_proto_down)(struct net_device___41 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___41 *, struct sk_buff___40 *);
	void (*ndo_set_rx_headroom)(struct net_device___41 *, int);
	int (*ndo_bpf)(struct net_device___41 *, struct netdev_bpf___39 *);
	int (*ndo_xdp_xmit)(struct net_device___41 *, int, struct xdp_frame___39 **, u32);
	struct net_device___41 * (*ndo_xdp_get_xmit_slave)(struct net_device___41 *, struct xdp_buff___39 *);
	int (*ndo_xsk_wakeup)(struct net_device___41 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___41 *);
	int (*ndo_tunnel_ctl)(struct net_device___41 *, struct ip_tunnel_parm *, int);
	struct net_device___41 * (*ndo_get_peer_dev)(struct net_device___41 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___39 *, struct net_device_path___39 *);
};

struct neigh_parms___30 {
	possible_net_t___39 net;
	struct net_device___41 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___30 *);
	struct neigh_table___30 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___15 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___41 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___41 *);
	void (*get_regs)(struct net_device___41 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___41 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___41 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___41 *);
	void (*set_msglevel)(struct net_device___41 *, u32);
	int (*nway_reset)(struct net_device___41 *);
	u32 (*get_link)(struct net_device___41 *);
	int (*get_link_ext_state)(struct net_device___41 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___41 *);
	int (*get_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___41 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___41 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___41 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___41 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___41 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___41 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___41 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___41 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___41 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___41 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___41 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___41 *);
	void (*complete)(struct net_device___41 *);
	u32 (*get_priv_flags)(struct net_device___41 *);
	int (*set_priv_flags)(struct net_device___41 *, u32);
	int (*get_sset_count)(struct net_device___41 *, int);
	int (*get_rxnfc)(struct net_device___41 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___41 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___41 *, struct ethtool_flash *);
	int (*reset)(struct net_device___41 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___41 *);
	u32 (*get_rxfh_indir_size)(struct net_device___41 *);
	int (*get_rxfh)(struct net_device___41 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___41 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___41 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___41 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___41 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___41 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___41 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___41 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___41 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___41 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___41 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___41 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___41 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___41 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___41 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___41 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___41 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___41 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___41 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___41 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___41 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___41 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___41 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___41 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___41 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___41 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___41 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___41 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___41 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___41 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___41 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___30 {
	u32 (*l3mdev_fib_table)(const struct net_device___41 *);
	struct sk_buff___40 * (*l3mdev_l3_rcv)(struct net_device___41 *, struct sk_buff___40 *, u16);
	struct sk_buff___40 * (*l3mdev_l3_out)(struct net_device___41 *, struct sock___31 *, struct sk_buff___40 *, u16);
	struct dst_entry___30 * (*l3mdev_link_scope_lookup)(const struct net_device___41 *, struct flowi6 *);
};

struct tcf_proto___37;

struct tcf_block___37;

struct mini_Qdisc___37 {
	struct tcf_proto___37 *filter_list;
	struct tcf_block___37 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___37 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___41 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___41 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___44 *, struct net_device___41 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___41 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___41 *, struct list_head *);
	size_t (*get_size)(const struct net_device___41 *);
	int (*fill_info)(struct sk_buff___40 *, const struct net_device___41 *);
	size_t (*get_xstats_size)(const struct net_device___41 *);
	int (*fill_xstats)(struct sk_buff___40 *, const struct net_device___41 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___41 *, struct net_device___41 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___41 *, const struct net_device___41 *);
	int (*fill_slave_info)(struct sk_buff___40 *, const struct net_device___41 *, const struct net_device___41 *);
	struct net___44 * (*get_link_net)(const struct net_device___41 *);
	size_t (*get_linkxstats_size)(const struct net_device___41 *, int);
	int (*fill_linkxstats)(struct sk_buff___40 *, const struct net_device___41 *, int *, int);
};

struct block_device_operations___116;

struct gendisk___119 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___119 *part0;
	const struct block_device_operations___116 *fops;
	struct request_queue___116 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___105 *bdi;
	struct kobject___209 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___209 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___116 {
	struct bio___116 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___138 *bip_vec;
	struct bio_vec___138 bip_inline_vecs[0];
};

struct blkcg___107;

struct blkg_policy_data___107;

struct blkcg_gq___107 {
	struct request_queue___116 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___107 *blkcg;
	struct blkcg_gq___107 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___107 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___116 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___116(struct request___116 *);

typedef void integrity_complete_fn___116(struct request___116 *, unsigned int);

struct blk_integrity_profile___116 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___116 *prepare_fn;
	integrity_complete_fn___116 *complete_fn;
	const char *name;
};

struct block_device_operations___116 {
	blk_qc_t (*submit_bio)(struct bio___116 *);
	int (*open)(struct block_device___119 *, fmode_t);
	void (*release)(struct gendisk___119 *, fmode_t);
	int (*rw_page)(struct block_device___119 *, sector_t, struct page___226 *, unsigned int);
	int (*ioctl)(struct block_device___119 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___119 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___119 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___119 *);
	int (*getgeo)(struct block_device___119 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___119 *, bool);
	void (*swap_slot_free_notify)(struct block_device___119 *, long unsigned int);
	int (*report_zones)(struct gendisk___119 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___119 *, umode_t *);
	struct module___205 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___119 *, sector_t *);
};

typedef void rq_end_io_fn___116(struct request___116 *, blk_status_t);

struct request___116 {
	struct request_queue___116 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___113 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___116 *bio;
	struct bio___116 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___138 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___116 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___116 *saved_end_io;
		} flush;
	};
	struct gendisk___119 *rq_disk;
	struct block_device___119 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___116 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___113 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___116 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___209 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___221 *debugfs_dir;
	struct dentry___221 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___116;

struct elevator_mq_ops___116 {
	int (*init_sched)(struct request_queue___116 *, struct elevator_type___116 *);
	void (*exit_sched)(struct elevator_queue___116 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___113 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___113 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___113 *);
	bool (*allow_merge)(struct request_queue___116 *, struct request___116 *, struct bio___116 *);
	bool (*bio_merge)(struct request_queue___116 *, struct bio___116 *, unsigned int);
	int (*request_merge)(struct request_queue___116 *, struct request___116 **, struct bio___116 *);
	void (*request_merged)(struct request_queue___116 *, struct request___116 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___116 *, struct request___116 *, struct request___116 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___116 *);
	void (*finish_request)(struct request___116 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___113 *, struct list_head *, bool);
	struct request___116 * (*dispatch_request)(struct blk_mq_hw_ctx___113 *);
	bool (*has_work)(struct blk_mq_hw_ctx___113 *);
	void (*completed_request)(struct request___116 *, u64);
	void (*requeue_request)(struct request___116 *);
	struct request___116 * (*former_request)(struct request_queue___116 *, struct request___116 *);
	struct request___116 * (*next_request)(struct request_queue___116 *, struct request___116 *);
	void (*init_icq)(struct io_cq___116 *);
	void (*exit_icq)(struct io_cq___116 *);
};

struct elv_fs_entry___116;

struct elevator_type___116 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___116 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___116 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___205 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___116 {
	struct elevator_type___116 *type;
	void *elevator_data;
	struct kobject___209 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___116 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___116 *, char *);
	ssize_t (*store)(struct elevator_queue___116 *, const char *, size_t);
};

struct blk_mq_queue_data___113;

struct blk_mq_ops___113 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___113 *, const struct blk_mq_queue_data___113 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___113 *);
	int (*get_budget)(struct request_queue___116 *);
	void (*put_budget)(struct request_queue___116 *, int);
	void (*set_rq_budget_token)(struct request___116 *, int);
	int (*get_rq_budget_token)(struct request___116 *);
	enum blk_eh_timer_return (*timeout)(struct request___116 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___113 *);
	void (*complete)(struct request___116 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___113 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___113 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___113 *, struct request___116 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___113 *, struct request___116 *, unsigned int);
	void (*initialize_rq_fn)(struct request___116 *);
	void (*cleanup_rq)(struct request___116 *);
	bool (*busy)(struct request_queue___116 *);
	int (*map_queues)(struct blk_mq_tag_set___113 *);
	void (*show_rq)(struct seq_file___196 *, struct request___116 *);
};

struct blk_mq_tag_set___113 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___113 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___113 {
	struct request___116 *rq;
	bool last;
};

struct blkcg_policy_data___107;

struct blkcg___107 {
	struct cgroup_subsys_state___151 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___107 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___107 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___107 {
	struct blkcg___107 *blkcg;
	int plid;
};

struct blkg_policy_data___107 {
	struct blkcg_gq___107 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___96 {
	struct mem_cgroup___96 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___96 {
	struct lruvec___104 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___96 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___96 *memcg;
};

struct obj_cgroup___96 {
	struct percpu_ref refcnt;
	struct mem_cgroup___96 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___37 {
	spinlock_t *lock;
	struct sk_buff___40 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___37;

struct Qdisc_ops___37 {
	struct Qdisc_ops___37 *next;
	const struct Qdisc_class_ops___37 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___40 *, struct Qdisc___37 *, struct sk_buff___40 **);
	struct sk_buff___40 * (*dequeue)(struct Qdisc___37 *);
	struct sk_buff___40 * (*peek)(struct Qdisc___37 *);
	int (*init)(struct Qdisc___37 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___37 *);
	void (*destroy)(struct Qdisc___37 *);
	int (*change)(struct Qdisc___37 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___37 *);
	int (*change_tx_queue_len)(struct Qdisc___37 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___37 *, unsigned int);
	int (*dump)(struct Qdisc___37 *, struct sk_buff___40 *);
	int (*dump_stats)(struct Qdisc___37 *, struct gnet_dump___37 *);
	void (*ingress_block_set)(struct Qdisc___37 *, u32);
	void (*egress_block_set)(struct Qdisc___37 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___37 *);
	u32 (*egress_block_get)(struct Qdisc___37 *);
	struct module___205 *owner;
};

struct Qdisc_class_ops___37 {
	unsigned int flags;
	struct netdev_queue___39 * (*select_queue)(struct Qdisc___37 *, struct tcmsg *);
	int (*graft)(struct Qdisc___37 *, long unsigned int, struct Qdisc___37 *, struct Qdisc___37 **, struct netlink_ext_ack *);
	struct Qdisc___37 * (*leaf)(struct Qdisc___37 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___37 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___37 *, u32);
	int (*change)(struct Qdisc___37 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___37 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___37 *, struct qdisc_walker *);
	struct tcf_block___37 * (*tcf_block)(struct Qdisc___37 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___37 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___37 *, long unsigned int);
	int (*dump)(struct Qdisc___37 *, long unsigned int, struct sk_buff___40 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___37 *, long unsigned int, struct gnet_dump___37 *);
};

struct tcf_chain___37;

struct tcf_block___37 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___44 *net;
	struct Qdisc___37 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___37 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___37;

struct tcf_proto_ops___37;

struct tcf_proto___37 {
	struct tcf_proto___37 *next;
	void *root;
	int (*classify)(struct sk_buff___40 *, const struct tcf_proto___37 *, struct tcf_result___37 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___37 *ops;
	struct tcf_chain___37 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___37 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___37 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___37 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___40 *, const struct tcf_proto___37 *, struct tcf_result___37 *);
	int (*init)(struct tcf_proto___37 *);
	void (*destroy)(struct tcf_proto___37 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___37 *, u32);
	void (*put)(struct tcf_proto___37 *, void *);
	int (*change)(struct net___44 *, struct sk_buff___40 *, struct tcf_proto___37 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___37 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___37 *);
	void (*walk)(struct tcf_proto___37 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___37 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___37 *, void *);
	void (*hw_del)(struct tcf_proto___37 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___44 *, struct tcf_chain___37 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___44 *, struct tcf_proto___37 *, void *, struct sk_buff___40 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___44 *, struct tcf_proto___37 *, void *, struct sk_buff___40 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___40 *, struct net___44 *, void *);
	struct module___205 *owner;
	int flags;
};

struct tcf_chain___37 {
	struct mutex filter_chain_lock;
	struct tcf_proto___37 *filter_chain;
	struct list_head list;
	struct tcf_block___37 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___37 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___30 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___37 *prog;
};

struct pneigh_entry___30;

struct neigh_hash_table___30;

struct neigh_table___30 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___41 *, __u32 *);
	bool (*key_eq)(const struct neighbour___30 *, const void *);
	int (*constructor)(struct neighbour___30 *);
	int (*pconstructor)(struct pneigh_entry___30 *);
	void (*pdestructor)(struct pneigh_entry___30 *);
	void (*proxy_redo)(struct sk_buff___40 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___41 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___30 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___39 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___30 *nht;
	struct pneigh_entry___30 **phash_buckets;
};

struct neigh_ops___30 {
	int family;
	void (*solicit)(struct neighbour___30 *, struct sk_buff___40 *);
	void (*error_report)(struct neighbour___30 *, struct sk_buff___40 *);
	int (*output)(struct neighbour___30 *, struct sk_buff___40 *);
	int (*connected_output)(struct neighbour___30 *, struct sk_buff___40 *);
};

struct pneigh_entry___30 {
	struct pneigh_entry___30 *next;
	possible_net_t___39 net;
	struct net_device___41 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___30 {
	struct neighbour___30 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___30 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___30 *ctarget;
	struct net___44 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___30 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___30 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___20;

struct timewait_sock_ops___20;

struct proto___30 {
	void (*close)(struct sock___31 *, long int);
	int (*pre_connect)(struct sock___31 *, struct sockaddr *, int);
	int (*connect)(struct sock___31 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___31 *, int);
	struct sock___31 * (*accept)(struct sock___31 *, int, int *, bool);
	int (*ioctl)(struct sock___31 *, int, long unsigned int);
	int (*init)(struct sock___31 *);
	void (*destroy)(struct sock___31 *);
	void (*shutdown)(struct sock___31 *, int);
	int (*setsockopt)(struct sock___31 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___31 *, int, int, char *, int *);
	void (*keepalive)(struct sock___31 *, int);
	int (*compat_ioctl)(struct sock___31 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___31 *, struct msghdr___32 *, size_t);
	int (*recvmsg)(struct sock___31 *, struct msghdr___32 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___31 *, struct page___226 *, int, size_t, int);
	int (*bind)(struct sock___31 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___31 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___31 *, struct sk_buff___40 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___31 *);
	int (*hash)(struct sock___31 *);
	void (*unhash)(struct sock___31 *);
	void (*rehash)(struct sock___31 *);
	int (*get_port)(struct sock___31 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___31 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___31 *, int);
	bool (*sock_is_readable)(struct sock___31 *);
	void (*enter_memory_pressure)(struct sock___31 *);
	void (*leave_memory_pressure)(struct sock___31 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___20 *rsk_prot;
	struct timewait_sock_ops___20 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___205 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___31 *, int);
};

struct request_sock___21;

struct request_sock_ops___20 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___31 *, struct request_sock___21 *);
	void (*send_ack)(const struct sock___31 *, struct sk_buff___40 *, struct request_sock___21 *);
	void (*send_reset)(const struct sock___31 *, struct sk_buff___40 *);
	void (*destructor)(struct request_sock___21 *);
	void (*syn_ack_timeout)(const struct request_sock___21 *);
};

struct timewait_sock_ops___20 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___31 *, struct sock___31 *, void *);
	void (*twsk_destructor)(struct sock___31 *);
};

struct request_sock___21 {
	struct sock_common___30 __req_common;
	struct request_sock___21 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___20 *rsk_ops;
	struct sock___31 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct mdio_board_info {
	const char *bus_id;
	char modalias[32];
	int mdio_addr;
	const void *platform_data;
};

struct mdio_board_entry {
	struct list_head list;
	struct mdio_board_info board_info;
};

typedef void (*dr_release_t___30)(struct device___141 *, void *);

typedef int (*dr_match_t___22)(struct device___141 *, void *, void *);

struct mdiobus_devres {
	struct mii_bus *mii;
};

struct mii_bus___3;

struct mdio_device___3 {
	struct device___112 dev;
	struct mii_bus___3 *bus;
	char modalias[32];
	int (*bus_match)(struct device___112 *, struct device_driver___112 *);
	void (*device_free)(struct mdio_device___3 *);
	void (*device_remove)(struct mdio_device___3 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___2;

struct phy_led_trigger___2;

struct mii_timestamper___2;

struct phy_device {
	struct mdio_device___3 mdio;
	struct phy_driver___2 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger___2 *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger___2 *last_triggered;
	struct phy_led_trigger___2 *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___26 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___3 *attached_dev;
	struct mii_timestamper___2 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device *, bool);
	void (*adjust_link)(struct net_device___3 *);
	const struct macsec_ops *macsec_ops;
};

enum {
	ETHTOOL_MSG_KERNEL_NONE = 0,
	ETHTOOL_MSG_STRSET_GET_REPLY = 1,
	ETHTOOL_MSG_LINKINFO_GET_REPLY = 2,
	ETHTOOL_MSG_LINKINFO_NTF = 3,
	ETHTOOL_MSG_LINKMODES_GET_REPLY = 4,
	ETHTOOL_MSG_LINKMODES_NTF = 5,
	ETHTOOL_MSG_LINKSTATE_GET_REPLY = 6,
	ETHTOOL_MSG_DEBUG_GET_REPLY = 7,
	ETHTOOL_MSG_DEBUG_NTF = 8,
	ETHTOOL_MSG_WOL_GET_REPLY = 9,
	ETHTOOL_MSG_WOL_NTF = 10,
	ETHTOOL_MSG_FEATURES_GET_REPLY = 11,
	ETHTOOL_MSG_FEATURES_SET_REPLY = 12,
	ETHTOOL_MSG_FEATURES_NTF = 13,
	ETHTOOL_MSG_PRIVFLAGS_GET_REPLY = 14,
	ETHTOOL_MSG_PRIVFLAGS_NTF = 15,
	ETHTOOL_MSG_RINGS_GET_REPLY = 16,
	ETHTOOL_MSG_RINGS_NTF = 17,
	ETHTOOL_MSG_CHANNELS_GET_REPLY = 18,
	ETHTOOL_MSG_CHANNELS_NTF = 19,
	ETHTOOL_MSG_COALESCE_GET_REPLY = 20,
	ETHTOOL_MSG_COALESCE_NTF = 21,
	ETHTOOL_MSG_PAUSE_GET_REPLY = 22,
	ETHTOOL_MSG_PAUSE_NTF = 23,
	ETHTOOL_MSG_EEE_GET_REPLY = 24,
	ETHTOOL_MSG_EEE_NTF = 25,
	ETHTOOL_MSG_TSINFO_GET_REPLY = 26,
	ETHTOOL_MSG_CABLE_TEST_NTF = 27,
	ETHTOOL_MSG_CABLE_TEST_TDR_NTF = 28,
	ETHTOOL_MSG_TUNNEL_INFO_GET_REPLY = 29,
	ETHTOOL_MSG_FEC_GET_REPLY = 30,
	ETHTOOL_MSG_FEC_NTF = 31,
	ETHTOOL_MSG_MODULE_EEPROM_GET_REPLY = 32,
	ETHTOOL_MSG_STATS_GET_REPLY = 33,
	ETHTOOL_MSG_PHC_VCLOCKS_GET_REPLY = 34,
	__ETHTOOL_MSG_KERNEL_CNT = 35,
	ETHTOOL_MSG_KERNEL_MAX = 34,
};

enum {
	ETHTOOL_A_STATS_UNSPEC = 0,
	ETHTOOL_A_STATS_PAD = 1,
	ETHTOOL_A_STATS_HEADER = 2,
	ETHTOOL_A_STATS_GROUPS = 3,
	ETHTOOL_A_STATS_GRP = 4,
	__ETHTOOL_A_STATS_CNT = 5,
	ETHTOOL_A_STATS_MAX = 4,
};

struct mii_bus___3 {
	struct module___141 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___3 *, int, int);
	int (*write)(struct mii_bus___3 *, int, int, u16);
	int (*reset)(struct mii_bus___3 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___112 *parent;
	enum {
		MDIOBUS_ALLOCATED___3 = 1,
		MDIOBUS_REGISTERED___3 = 2,
		MDIOBUS_UNREGISTERED___3 = 3,
		MDIOBUS_RELEASED___3 = 4,
	} state;
	struct device___112 dev;
	struct mdio_device___3 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___3 = 0,
		MDIOBUS_C22___3 = 1,
		MDIOBUS_C45___3 = 2,
		MDIOBUS_C22_C45___3 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___3 {
	struct device_driver___112 driver;
	int flags;
};

struct mii_timestamper___2 {
	bool (*rxtstamp)(struct mii_timestamper___2 *, struct sk_buff___26 *, int);
	void (*txtstamp)(struct mii_timestamper___2 *, struct sk_buff___26 *, int);
	int (*hwtstamp)(struct mii_timestamper___2 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___2 *, struct phy_device *);
	int (*ts_info)(struct mii_timestamper___2 *, struct ethtool_ts_info *);
	struct device___112 *device;
};

struct phy_driver___2 {
	struct mdio_driver_common___3 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device *);
	int (*config_init)(struct phy_device *);
	int (*probe)(struct phy_device *);
	int (*get_features)(struct phy_device *);
	int (*suspend)(struct phy_device *);
	int (*resume)(struct phy_device *);
	int (*config_aneg)(struct phy_device *);
	int (*aneg_done)(struct phy_device *);
	int (*read_status)(struct phy_device *);
	int (*config_intr)(struct phy_device *);
	irqreturn_t (*handle_interrupt)(struct phy_device *);
	void (*remove)(struct phy_device *);
	int (*match_phy_device)(struct phy_device *);
	int (*set_wol)(struct phy_device *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device *);
	int (*read_mmd)(struct phy_device *, int, u16);
	int (*write_mmd)(struct phy_device *, int, u16, u16);
	int (*read_page)(struct phy_device *);
	int (*write_page)(struct phy_device *, int);
	int (*module_info)(struct phy_device *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device *);
	int (*cable_test_tdr_start)(struct phy_device *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device *, bool *);
	int (*get_sset_count)(struct phy_device *);
	void (*get_strings)(struct phy_device *, u8 *);
	void (*get_stats)(struct phy_device *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device *, bool);
	int (*get_sqi)(struct phy_device *);
	int (*get_sqi_max)(struct phy_device *);
};

struct led_classdev___4;

struct led_trigger___4 {
	const char *name;
	int (*activate)(struct led_classdev___4 *);
	void (*deactivate)(struct led_classdev___4 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___143 **groups;
};

struct phy_led_trigger___2 {
	struct led_trigger___4 trigger;
	char name[76];
	unsigned int speed;
};

struct phy_setting {
	u32 speed;
	u8 duplex;
	u8 bit;
};

struct led_classdev___4 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___4 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___4 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___4 *);
	int (*blink_set)(struct led_classdev___4 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___4 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___4 *);
	struct device___112 *dev;
	const struct attribute_group___143 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___4 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___4 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___143 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct irq_desc___56;

typedef void (*irq_flow_handler_t___56)(struct irq_desc___56 *);

struct irq_chip___56;

struct irq_domain___54;

struct irq_data___56 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___56 *chip;
	struct irq_domain___54 *domain;
	struct irq_data___56 *parent_data;
	void *chip_data;
};

struct kset___210;

struct kobj_type___210;

struct kernfs_node___210;

struct kobject___210 {
	const char *name;
	struct list_head entry;
	struct kobject___210 *parent;
	struct kset___210 *kset;
	struct kobj_type___210 *ktype;
	struct kernfs_node___210 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___38;

struct module___206;

struct irq_desc___56 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___56 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___56 handle_irq;
	struct irqaction___38 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___210 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___206 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___222;

struct super_block___222;

struct file_system_type___222 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___222 * (*mount)(struct file_system_type___222 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___222 *);
	struct module___206 *owner;
	struct file_system_type___222 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___222;

struct kiocb___222;

struct iov_iter___142;

struct poll_table_struct___147;

struct vm_area_struct___227;

struct inode___222;

struct file_lock___222;

struct page___227;

struct pipe_inode_info___72;

struct seq_file___197;

struct file_operations___223 {
	struct module___206 *owner;
	loff_t (*llseek)(struct file___222 *, loff_t, int);
	ssize_t (*read)(struct file___222 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___222 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___222 *, struct iov_iter___142 *);
	ssize_t (*write_iter)(struct kiocb___222 *, struct iov_iter___142 *);
	int (*iopoll)(struct kiocb___222 *, bool);
	int (*iterate)(struct file___222 *, struct dir_context *);
	int (*iterate_shared)(struct file___222 *, struct dir_context *);
	__poll_t (*poll)(struct file___222 *, struct poll_table_struct___147 *);
	long int (*unlocked_ioctl)(struct file___222 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___222 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___222 *, struct vm_area_struct___227 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___222 *, struct file___222 *);
	int (*flush)(struct file___222 *, fl_owner_t);
	int (*release)(struct inode___222 *, struct file___222 *);
	int (*fsync)(struct file___222 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___222 *, int);
	int (*lock)(struct file___222 *, int, struct file_lock___222 *);
	ssize_t (*sendpage)(struct file___222 *, struct page___227 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___222 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___222 *, long unsigned int);
	int (*flock)(struct file___222 *, int, struct file_lock___222 *);
	ssize_t (*splice_write)(struct pipe_inode_info___72 *, struct file___222 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___222 *, loff_t *, struct pipe_inode_info___72 *, size_t, unsigned int);
	int (*setlease)(struct file___222 *, long int, struct file_lock___222 **, void **);
	long int (*fallocate)(struct file___222 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___197 *, struct file___222 *);
	ssize_t (*copy_file_range)(struct file___222 *, loff_t, struct file___222 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___222 *, loff_t, struct file___222 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___222 *, loff_t, loff_t, int);
};

struct vmacache___227 {
	u64 seqnum;
	struct vm_area_struct___227 *vmas[4];
};

struct page_frag___227 {
	struct page___227 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___228;

struct pid___199;

struct nsproxy___208;

struct signal_struct___223;

struct css_set___152;

struct vm_struct___205;

struct task_struct___229 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___229 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___228 *mm;
	struct mm_struct___228 *active_mm;
	struct vmacache___227 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___229 *real_parent;
	struct task_struct___229 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___229 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___199 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___208 *nsproxy;
	struct signal_struct___223 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___229 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___116 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___152 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___72 *splice_pipe;
	struct page_frag___227 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___229 *oom_reaper_list;
	struct vm_struct___205 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___80 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___207 {
	struct kobject___210 kobj;
	struct module___206 *mod;
	struct kobject___210 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___206 {
	struct module___206 *mod;
	struct latch_tree_node node;
};

struct module_layout___206 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___206 mtn;
};

struct module_attribute___206;

struct kernel_param___206;

struct module___206 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___207 mkobj;
	struct module_attribute___206 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___210 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___206 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___206 core_layout;
	struct module_layout___206 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___227 *pgtable_t___227;

struct address_space___222;

struct page_pool___60;

struct dev_pagemap___217;

struct page___227 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___222 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___60 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___227 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___227 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___228 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___217 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___217;

struct vm_area_struct___227 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___227 *vm_next;
	struct vm_area_struct___227 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___228 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___217 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___222 *vm_file;
	struct file___222 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___227;

struct mm_struct___228 {
	struct {
		struct vm_area_struct___227 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___222 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___227 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___229 *owner;
		struct user_namespace___14 *user_ns;
		struct file___222 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___222;

struct address_space___222 {
	struct inode___222 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___222 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___200;

struct page_pool_params___60 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___200 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___60 {
	u32 count;
	struct page___227 *cache[128];
};

struct page_pool___60 {
	struct page_pool_params___60 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___227 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___60 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___217;

struct dev_pagemap___217 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___217 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___222;

struct path___222 {
	struct vfsmount___222 *mnt;
	struct dentry___222 *dentry;
};

struct fown_struct___199 {
	rwlock_t lock;
	struct pid___199 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___222 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___222 f_path;
	struct inode___222 *f_inode;
	const struct file_operations___223 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___199 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___222 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___217;

struct vm_operations_struct___217 {
	void (*open)(struct vm_area_struct___227 *);
	void (*close)(struct vm_area_struct___227 *);
	int (*may_split)(struct vm_area_struct___227 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___227 *);
	int (*mprotect)(struct vm_area_struct___227 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___217 *);
	vm_fault_t (*huge_fault)(struct vm_fault___217 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___217 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___227 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___217 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___217 *);
	int (*access)(struct vm_area_struct___227 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___227 *);
	int (*set_policy)(struct vm_area_struct___227 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___227 *, long unsigned int);
	struct page___227 * (*find_special_page)(struct vm_area_struct___227 *, long unsigned int);
};

struct core_thread___227 {
	struct task_struct___229 *task;
	struct core_thread___227 *next;
};

struct core_state___227 {
	atomic_t nr_threads;
	struct core_thread___227 dumper;
	struct completion startup;
};

struct vm_fault___217 {
	const struct {
		struct vm_area_struct___227 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___227 *cow_page;
	struct page___227 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___227 prealloc_pte;
};

struct kernfs_root___210;

struct kernfs_elem_dir___210 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___210 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___210;

struct kernfs_root___210 {
	struct kernfs_node___210 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___210 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___210 {
	struct kernfs_node___210 *target_kn;
};

struct kernfs_ops___210;

struct kernfs_elem_attr___210 {
	const struct kernfs_ops___210 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___210 *notify_next;
};

struct kernfs_node___210 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___210 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___210 dir;
		struct kernfs_elem_symlink___210 symlink;
		struct kernfs_elem_attr___210 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___210;

struct kernfs_ops___210 {
	int (*open)(struct kernfs_open_file___210 *);
	void (*release)(struct kernfs_open_file___210 *);
	int (*seq_show)(struct seq_file___197 *, void *);
	void * (*seq_start)(struct seq_file___197 *, loff_t *);
	void * (*seq_next)(struct seq_file___197 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___197 *, void *);
	ssize_t (*read)(struct kernfs_open_file___210 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___210 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___210 *, struct poll_table_struct___147 *);
	int (*mmap)(struct kernfs_open_file___210 *, struct vm_area_struct___227 *);
};

struct kernfs_syscall_ops___210 {
	int (*show_options)(struct seq_file___197 *, struct kernfs_root___210 *);
	int (*mkdir)(struct kernfs_node___210 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___210 *);
	int (*rename)(struct kernfs_node___210 *, struct kernfs_node___210 *, const char *);
	int (*show_path)(struct seq_file___197 *, struct kernfs_node___210 *, struct kernfs_root___210 *);
};

struct seq_operations___197;

struct seq_file___197 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___197 *op;
	int poll_event;
	const struct file___222 *file;
	void *private;
};

struct kernfs_open_file___210 {
	struct kernfs_node___210 *kn;
	struct file___222 *file;
	struct seq_file___197 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___217 *vm_ops;
};

typedef void (*poll_queue_proc___154)(struct file___222 *, wait_queue_head_t *, struct poll_table_struct___147 *);

struct poll_table_struct___147 {
	poll_queue_proc___154 _qproc;
	__poll_t _key;
};

struct pid_namespace___199;

struct upid___199 {
	int nr;
	struct pid_namespace___199 *ns;
};

struct pid_namespace___199 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___229 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___199 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___199 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___199 numbers[1];
};

struct signal_struct___223 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___229 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___229 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___199 *pids[4];
	struct pid___199 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___228 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___45;

struct cgroup_namespace___152;

struct nsproxy___208 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___199 *pid_ns_for_children;
	struct net___45 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___152 *cgroup_ns;
};

struct cgroup_subsys_state___152;

struct cgroup___152;

struct css_set___152 {
	struct cgroup_subsys_state___152 *subsys[14];
	refcount_t refcount;
	struct css_set___152 *dom_cset;
	struct cgroup___152 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___152 *mg_src_cgrp;
	struct cgroup___152 *mg_dst_cgrp;
	struct css_set___152 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___222;

struct pipe_buffer___72;

struct pipe_inode_info___72 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___227 *tmp_page;
	struct fasync_struct___222 *fasync_readers;
	struct fasync_struct___222 *fasync_writers;
	struct pipe_buffer___72 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___205 {
	struct vm_struct___205 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___227 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___210;

struct attribute_group___210 {
	const char *name;
	umode_t (*is_visible)(struct kobject___210 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___210 *, struct bin_attribute___210 *, int);
	struct attribute **attrs;
	struct bin_attribute___210 **bin_attrs;
};

struct bin_attribute___210 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___222 * (*f_mapping)();
	ssize_t (*read)(struct file___222 *, struct kobject___210 *, struct bin_attribute___210 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___222 *, struct kobject___210 *, struct bin_attribute___210 *, char *, loff_t, size_t);
	int (*mmap)(struct file___222 *, struct kobject___210 *, struct bin_attribute___210 *, struct vm_area_struct___227 *);
};

struct sysfs_ops___210 {
	ssize_t (*show)(struct kobject___210 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___210 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___210;

struct kset___210 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___210 kobj;
	const struct kset_uevent_ops___210 *uevent_ops;
};

struct kobj_type___210 {
	void (*release)(struct kobject___210 *);
	const struct sysfs_ops___210 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___210 **default_groups;
	const struct kobj_ns_type_operations___30 * (*child_ns_type)(struct kobject___210 *);
	const void * (*namespace)(struct kobject___210 *);
	void (*get_ownership)(struct kobject___210 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___210 {
	int (* const filter)(struct kset___210 *, struct kobject___210 *);
	const char * (* const name)(struct kset___210 *, struct kobject___210 *);
	int (* const uevent)(struct kset___210 *, struct kobject___210 *, struct kobj_uevent_env *);
};

struct fwnode_operations___196;

struct fwnode_handle___196 {
	struct fwnode_handle___196 *secondary;
	const struct fwnode_operations___196 *ops;
	struct device___200 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___196;

struct fwnode_endpoint___196;

struct fwnode_operations___196 {
	struct fwnode_handle___196 * (*get)(struct fwnode_handle___196 *);
	void (*put)(struct fwnode_handle___196 *);
	bool (*device_is_available)(const struct fwnode_handle___196 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___196 *, const struct device___200 *);
	bool (*property_present)(const struct fwnode_handle___196 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___196 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___196 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___196 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*get_parent)(const struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*get_next_child_node)(const struct fwnode_handle___196 *, struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*get_named_child_node)(const struct fwnode_handle___196 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___196 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___196 *);
	struct fwnode_handle___196 * (*graph_get_next_endpoint)(const struct fwnode_handle___196 *, struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*graph_get_remote_endpoint)(const struct fwnode_handle___196 *);
	struct fwnode_handle___196 * (*graph_get_port_parent)(struct fwnode_handle___196 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___196 *, struct fwnode_endpoint___196 *);
	int (*add_links)(struct fwnode_handle___196 *);
};

struct wakeup_source___200;

struct dev_pm_info___200 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___200 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___200 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___200;

struct bus_type___200;

struct device_driver___200;

struct dev_pm_domain___200;

struct device_node___87;

struct class___200;

struct device___200 {
	struct kobject___210 kobj;
	struct device___200 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___200 *type;
	struct bus_type___200 *bus;
	struct device_driver___200 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___200 power;
	struct dev_pm_domain___200 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___54 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___87 *of_node;
	struct fwnode_handle___196 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___200 *class;
	const struct attribute_group___210 **groups;
	void (*release)(struct device___200 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___196 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___196 *local_fwnode;
};

struct fwnode_reference_args___196 {
	struct fwnode_handle___196 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___64 {
	char *name;
	int length;
	void *value;
	struct property___64 *next;
	long unsigned int _flags;
	struct bin_attribute___210 attr;
};

struct device_node___87 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___196 fwnode;
	struct property___64 *properties;
	struct property___64 *deadprops;
	struct device_node___87 *parent;
	struct device_node___87 *child;
	struct device_node___87 *sibling;
	struct kobject___210 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___52 {
	struct fwnode_handle___196 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___54 {
	int (*match)(struct irq_domain___54 *, struct device_node___87 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___54 *, struct irq_fwspec___52 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___54 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___54 *, unsigned int);
	int (*xlate)(struct irq_domain___54 *, struct device_node___87 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___54 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___54 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___54 *, struct irq_data___56 *, bool);
	void (*deactivate)(struct irq_domain___54 *, struct irq_data___56 *);
	int (*translate)(struct irq_domain___54 *, struct irq_fwspec___52 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___54;

struct irq_domain___54 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___54 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___196 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___54 *gc;
	struct irq_domain___54 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___56 *revmap[0];
};

struct irq_chip_generic___54;

struct irq_domain_chip_generic___54 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___54 *gc[0];
};

struct dev_pm_ops___200 {
	int (*prepare)(struct device___200 *);
	void (*complete)(struct device___200 *);
	int (*suspend)(struct device___200 *);
	int (*resume)(struct device___200 *);
	int (*freeze)(struct device___200 *);
	int (*thaw)(struct device___200 *);
	int (*poweroff)(struct device___200 *);
	int (*restore)(struct device___200 *);
	int (*suspend_late)(struct device___200 *);
	int (*resume_early)(struct device___200 *);
	int (*freeze_late)(struct device___200 *);
	int (*thaw_early)(struct device___200 *);
	int (*poweroff_late)(struct device___200 *);
	int (*restore_early)(struct device___200 *);
	int (*suspend_noirq)(struct device___200 *);
	int (*resume_noirq)(struct device___200 *);
	int (*freeze_noirq)(struct device___200 *);
	int (*thaw_noirq)(struct device___200 *);
	int (*poweroff_noirq)(struct device___200 *);
	int (*restore_noirq)(struct device___200 *);
	int (*runtime_suspend)(struct device___200 *);
	int (*runtime_resume)(struct device___200 *);
	int (*runtime_idle)(struct device___200 *);
};

struct wakeup_source___200 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___200 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___200 {
	struct dev_pm_ops___200 ops;
	int (*start)(struct device___200 *);
	void (*detach)(struct device___200 *, bool);
	int (*activate)(struct device___200 *);
	void (*sync)(struct device___200 *);
	void (*dismiss)(struct device___200 *);
};

struct bus_type___200 {
	const char *name;
	const char *dev_name;
	struct device___200 *dev_root;
	const struct attribute_group___210 **bus_groups;
	const struct attribute_group___210 **dev_groups;
	const struct attribute_group___210 **drv_groups;
	int (*match)(struct device___200 *, struct device_driver___200 *);
	int (*uevent)(struct device___200 *, struct kobj_uevent_env *);
	int (*probe)(struct device___200 *);
	void (*sync_state)(struct device___200 *);
	void (*remove)(struct device___200 *);
	void (*shutdown)(struct device___200 *);
	int (*online)(struct device___200 *);
	int (*offline)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	int (*num_vf)(struct device___200 *);
	int (*dma_configure)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___200 {
	const char *name;
	struct bus_type___200 *bus;
	struct module___206 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___200 *);
	void (*sync_state)(struct device___200 *);
	int (*remove)(struct device___200 *);
	void (*shutdown)(struct device___200 *);
	int (*suspend)(struct device___200 *, pm_message_t);
	int (*resume)(struct device___200 *);
	const struct attribute_group___210 **groups;
	const struct attribute_group___210 **dev_groups;
	const struct dev_pm_ops___200 *pm;
	void (*coredump)(struct device___200 *);
	struct driver_private *p;
};

struct device_type___200 {
	const char *name;
	const struct attribute_group___210 **groups;
	int (*uevent)(struct device___200 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___200 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___200 *);
	const struct dev_pm_ops___200 *pm;
};

struct class___200 {
	const char *name;
	struct module___206 *owner;
	const struct attribute_group___210 **class_groups;
	const struct attribute_group___210 **dev_groups;
	struct kobject___210 *dev_kobj;
	int (*dev_uevent)(struct device___200 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___200 *, umode_t *);
	void (*class_release)(struct class___200 *);
	void (*dev_release)(struct device___200 *);
	int (*shutdown_pre)(struct device___200 *);
	const struct kobj_ns_type_operations___30 *ns_type;
	const void * (*namespace)(struct device___200 *);
	void (*get_ownership)(struct device___200 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___200 *pm;
	struct subsys_private *p;
};

struct device_attribute___34 {
	struct attribute attr;
	ssize_t (*show)(struct device___200 *, struct device_attribute___34 *, char *);
	ssize_t (*store)(struct device___200 *, struct device_attribute___34 *, const char *, size_t);
};

typedef void (*dr_release_t___31)(struct device___200 *, void *);

struct dentry_operations___222;

struct dentry___222 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___222 *d_parent;
	struct qstr d_name;
	struct inode___222 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___222 *d_op;
	struct super_block___222 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___222;

struct cdev___59;

struct inode___222 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___222 *i_op;
	struct super_block___222 *i_sb;
	struct address_space___222 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___223 *i_fop;
		void (*free_inode)(struct inode___222 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___222 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___72 *i_pipe;
		struct cdev___59 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___222 {
	int (*d_revalidate)(struct dentry___222 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___222 *, unsigned int);
	int (*d_hash)(const struct dentry___222 *, struct qstr *);
	int (*d_compare)(const struct dentry___222 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___222 *);
	int (*d_init)(struct dentry___222 *);
	void (*d_release)(struct dentry___222 *);
	void (*d_prune)(struct dentry___222 *);
	void (*d_iput)(struct dentry___222 *, struct inode___222 *);
	char * (*d_dname)(struct dentry___222 *, char *, int);
	struct vfsmount___222 * (*d_automount)(struct path___222 *);
	int (*d_manage)(const struct path___222 *, bool);
	struct dentry___222 * (*d_real)(struct dentry___222 *, const struct inode___222 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___222;

struct mem_dqinfo___222 {
	struct quota_format_type___222 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___222;

struct quota_info___222 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___222 *files[3];
	struct mem_dqinfo___222 info[3];
	const struct quota_format_ops___222 *ops[3];
};

struct rcuwait___223 {
	struct task_struct___229 *task;
};

struct percpu_rw_semaphore___223 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___223 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___222 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___223 rw_sem[3];
};

struct super_operations___222;

struct dquot_operations___222;

struct quotactl_ops___222;

struct super_block___222 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___222 *s_type;
	const struct super_operations___222 *s_op;
	const struct dquot_operations___222 *dq_op;
	const struct quotactl_ops___222 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___222 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___222 s_dquot;
	struct sb_writers___222 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___222 *s_d_op;
	int cleancache_poolid;
	struct shrinker___96 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___222 {
	struct dentry___222 *mnt_root;
	struct super_block___222 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct cgroup_subsys___152;

struct cgroup_subsys_state___152 {
	struct cgroup___152 *cgroup;
	struct cgroup_subsys___152 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___152 *parent;
};

struct cgroup_file___152 {
	struct kernfs_node___210 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___152 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___229 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___152;

struct cgroup_rstat_cpu___152;

struct cgroup___152 {
	struct cgroup_subsys_state___152 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___210 *kn;
	struct cgroup_file___152 procs_file;
	struct cgroup_file___152 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___152 *subsys[14];
	struct cgroup_root___152 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___152 *dom_cgrp;
	struct cgroup___152 *old_dom_cgrp;
	struct cgroup_rstat_cpu___152 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___152 psi;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___222 {
	struct file___222 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___222 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___222 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___222 *ia_file;
};

struct dquot___222 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___222 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___222 {
	int qf_fmt_id;
	const struct quota_format_ops___222 *qf_ops;
	struct module___206 *qf_owner;
	struct quota_format_type___222 *qf_next;
};

struct quota_format_ops___222 {
	int (*check_quota_file)(struct super_block___222 *, int);
	int (*read_file_info)(struct super_block___222 *, int);
	int (*write_file_info)(struct super_block___222 *, int);
	int (*free_file_info)(struct super_block___222 *, int);
	int (*read_dqblk)(struct dquot___222 *);
	int (*commit_dqblk)(struct dquot___222 *);
	int (*release_dqblk)(struct dquot___222 *);
	int (*get_next_id)(struct super_block___222 *, struct kqid *);
};

struct dquot_operations___222 {
	int (*write_dquot)(struct dquot___222 *);
	struct dquot___222 * (*alloc_dquot)(struct super_block___222 *, int);
	void (*destroy_dquot)(struct dquot___222 *);
	int (*acquire_dquot)(struct dquot___222 *);
	int (*release_dquot)(struct dquot___222 *);
	int (*mark_dirty)(struct dquot___222 *);
	int (*write_info)(struct super_block___222 *, int);
	qsize_t * (*get_reserved_space)(struct inode___222 *);
	int (*get_projid)(struct inode___222 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___222 *, qsize_t *);
	int (*get_next_id)(struct super_block___222 *, struct kqid *);
};

struct quotactl_ops___222 {
	int (*quota_on)(struct super_block___222 *, int, int, const struct path___222 *);
	int (*quota_off)(struct super_block___222 *, int);
	int (*quota_enable)(struct super_block___222 *, unsigned int);
	int (*quota_disable)(struct super_block___222 *, unsigned int);
	int (*quota_sync)(struct super_block___222 *, int);
	int (*set_info)(struct super_block___222 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___222 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___222 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___222 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___222 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___222 *, unsigned int);
};

struct address_space_operations___222 {
	int (*writepage)(struct page___227 *, struct writeback_control___3 *);
	int (*readpage)(struct file___222 *, struct page___227 *);
	int (*writepages)(struct address_space___222 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___227 *);
	int (*readpages)(struct file___222 *, struct address_space___222 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___222 *, struct address_space___222 *, loff_t, unsigned int, unsigned int, struct page___227 **, void **);
	int (*write_end)(struct file___222 *, struct address_space___222 *, loff_t, unsigned int, unsigned int, struct page___227 *, void *);
	sector_t (*bmap)(struct address_space___222 *, sector_t);
	void (*invalidatepage)(struct page___227 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___227 *, gfp_t);
	void (*freepage)(struct page___227 *);
	ssize_t (*direct_IO)(struct kiocb___222 *, struct iov_iter___142 *);
	int (*migratepage)(struct address_space___222 *, struct page___227 *, struct page___227 *, enum migrate_mode);
	bool (*isolate_page)(struct page___227 *, isolate_mode_t);
	void (*putback_page)(struct page___227 *);
	int (*launder_page)(struct page___227 *);
	int (*is_partially_uptodate)(struct page___227 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___227 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___222 *, struct page___227 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___222 *, sector_t *);
	void (*swap_deactivate)(struct file___222 *);
};

struct bio_vec___139;

struct iov_iter___142 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___139 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___72 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___59 {
	struct kobject___210 kobj;
	struct module___206 *owner;
	const struct file_operations___223 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___222 {
	struct dentry___222 * (*lookup)(struct inode___222 *, struct dentry___222 *, unsigned int);
	const char * (*get_link)(struct dentry___222 *, struct inode___222 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___222 *, int);
	struct posix_acl * (*get_acl)(struct inode___222 *, int, bool);
	int (*readlink)(struct dentry___222 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___222 *, struct dentry___222 *, umode_t, bool);
	int (*link)(struct dentry___222 *, struct inode___222 *, struct dentry___222 *);
	int (*unlink)(struct inode___222 *, struct dentry___222 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___222 *, struct dentry___222 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___222 *, struct dentry___222 *, umode_t);
	int (*rmdir)(struct inode___222 *, struct dentry___222 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___222 *, struct dentry___222 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___222 *, struct dentry___222 *, struct inode___222 *, struct dentry___222 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___222 *, struct iattr___222 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___222 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___222 *, char *, size_t);
	int (*fiemap)(struct inode___222 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___222 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___222 *, struct dentry___222 *, struct file___222 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___222 *, struct dentry___222 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___222 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___222 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___222 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___222 {
	void (*fl_copy_lock)(struct file_lock___222 *, struct file_lock___222 *);
	void (*fl_release_private)(struct file_lock___222 *);
};

struct lock_manager_operations___222;

struct file_lock___222 {
	struct file_lock___222 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___222 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___222 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___222 *fl_ops;
	const struct lock_manager_operations___222 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___222 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___222 *);
	int (*lm_grant)(struct file_lock___222 *, int);
	bool (*lm_break)(struct file_lock___222 *);
	int (*lm_change)(struct file_lock___222 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___222 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___222 *);
};

struct fasync_struct___222 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___222 *fa_next;
	struct file___222 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___222 {
	struct inode___222 * (*alloc_inode)(struct super_block___222 *);
	void (*destroy_inode)(struct inode___222 *);
	void (*free_inode)(struct inode___222 *);
	void (*dirty_inode)(struct inode___222 *, int);
	int (*write_inode)(struct inode___222 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___222 *);
	void (*evict_inode)(struct inode___222 *);
	void (*put_super)(struct super_block___222 *);
	int (*sync_fs)(struct super_block___222 *, int);
	int (*freeze_super)(struct super_block___222 *);
	int (*freeze_fs)(struct super_block___222 *);
	int (*thaw_super)(struct super_block___222 *);
	int (*unfreeze_fs)(struct super_block___222 *);
	int (*statfs)(struct dentry___222 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___222 *, int *, char *);
	void (*umount_begin)(struct super_block___222 *);
	int (*show_options)(struct seq_file___197 *, struct dentry___222 *);
	int (*show_devname)(struct seq_file___197 *, struct dentry___222 *);
	int (*show_path)(struct seq_file___197 *, struct dentry___222 *);
	int (*show_stats)(struct seq_file___197 *, struct dentry___222 *);
	ssize_t (*quota_read)(struct super_block___222 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___222 *, int, const char *, size_t, loff_t);
	struct dquot___222 ** (*get_dquots)(struct inode___222 *);
	long int (*nr_cached_objects)(struct super_block___222 *, struct shrink_control___96 *);
	long int (*free_cached_objects)(struct super_block___222 *, struct shrink_control___96 *);
	struct file___222 * (*real_loop)(struct file___222 *);
};

struct kernel_param_ops___206 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___206 *);
	int (*get)(char *, const struct kernel_param___206 *);
	void (*free)(void *);
};

struct kparam_array___206;

struct kernel_param___206 {
	const char *name;
	struct module___206 *mod;
	const struct kernel_param_ops___206 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___206 *arr;
	};
};

struct kparam_array___206 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___206 *ops;
	void *elem;
};

struct module_attribute___206 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___206 *, struct module_kobject___207 *, char *);
	ssize_t (*store)(struct module_attribute___206 *, struct module_kobject___207 *, const char *, size_t);
	void (*setup)(struct module___206 *, const char *);
	int (*test)(struct module___206 *);
	void (*free)(struct module___206 *);
};

struct irq_chip___56 {
	struct device___200 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___56 *);
	void (*irq_shutdown)(struct irq_data___56 *);
	void (*irq_enable)(struct irq_data___56 *);
	void (*irq_disable)(struct irq_data___56 *);
	void (*irq_ack)(struct irq_data___56 *);
	void (*irq_mask)(struct irq_data___56 *);
	void (*irq_mask_ack)(struct irq_data___56 *);
	void (*irq_unmask)(struct irq_data___56 *);
	void (*irq_eoi)(struct irq_data___56 *);
	int (*irq_set_affinity)(struct irq_data___56 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___56 *);
	int (*irq_set_type)(struct irq_data___56 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___56 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___56 *);
	void (*irq_bus_sync_unlock)(struct irq_data___56 *);
	void (*irq_cpu_online)(struct irq_data___56 *);
	void (*irq_cpu_offline)(struct irq_data___56 *);
	void (*irq_suspend)(struct irq_data___56 *);
	void (*irq_resume)(struct irq_data___56 *);
	void (*irq_pm_shutdown)(struct irq_data___56 *);
	void (*irq_calc_mask)(struct irq_data___56 *);
	void (*irq_print_chip)(struct irq_data___56 *, struct seq_file___197 *);
	int (*irq_request_resources)(struct irq_data___56 *);
	void (*irq_release_resources)(struct irq_data___56 *);
	void (*irq_compose_msi_msg)(struct irq_data___56 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___56 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___56 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___56 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___56 *, void *);
	void (*ipi_send_single)(struct irq_data___56 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___56 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___56 *);
	void (*irq_nmi_teardown)(struct irq_data___56 *);
	long unsigned int flags;
};

struct irqaction___38 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___38 *next;
	irq_handler_t thread_fn;
	struct task_struct___229 *thread;
	struct irqaction___38 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___54 {
	struct irq_chip___56 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___56 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___54 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___54 *);
	void (*resume)(struct irq_chip_generic___54 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___54 *domain;
	struct list_head list;
	struct irq_chip_type___54 chip_types[0];
};

struct seq_operations___197 {
	void * (*start)(struct seq_file___197 *, loff_t *);
	void (*stop)(struct seq_file___197 *, void *);
	void * (*next)(struct seq_file___197 *, void *, loff_t *);
	int (*show)(struct seq_file___197 *, void *);
};

struct dev_pagemap_ops___217 {
	void (*page_free)(struct page___227 *);
	void (*kill)(struct dev_pagemap___217 *);
	void (*cleanup)(struct dev_pagemap___217 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___217 *);
};

struct fqdir___45;

struct netns_ipv4___45 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___45 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___42;

struct sk_buff___41;

struct dst_ops___45 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___45 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___42 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___41 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___41 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___41 *);
	int (*local_out)(struct net___45 *, struct sock *, struct sk_buff___41 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___41 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___45 {
	struct dst_ops___45 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___45 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___45 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___45 *fqdir;
};

struct sk_buff_head___40 {
	struct sk_buff___41 *next;
	struct sk_buff___41 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___45 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___45 xfrm4_dst_ops;
	struct dst_ops___45 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___45 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___42 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___45 ipv4;
	struct netns_ipv6___45 ipv6;
	struct netns_ieee802154_lowpan___45 ieee802154_lowpan;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___40 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___37 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___45 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___152 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___152 *root_cset;
};

struct bio_vec___139 {
	struct page___227 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct sk_buff___41 {
	union {
		struct {
			struct sk_buff___41 *next;
			struct sk_buff___41 *prev;
			union {
				struct net_device___42 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___31 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___41 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct pipe_buf_operations___72;

struct pipe_buffer___72 {
	struct page___227 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___72 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___72 {
	int (*confirm)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
	void (*release)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
	bool (*try_steal)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
	bool (*get)(struct pipe_inode_info___72 *, struct pipe_buffer___72 *);
};

typedef rx_handler_result_t rx_handler_func_t___40(struct sk_buff___41 **);

typedef struct {
	struct net___45 *net;
} possible_net_t___40;

struct netdev_name_node___40;

struct net_device_ops___40;

struct ethtool_ops___16;

struct xfrmdev_ops___40;

struct header_ops___40;

struct netdev_rx_queue___40;

struct netdev_queue___40;

struct dcbnl_rtnl_ops___40;

struct phy_device___3;

struct net_device___42 {
	char name[16];
	struct netdev_name_node___40 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___40 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___16 *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___40 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___40 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___210 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___40 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___40 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___40 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___40 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___40 = 0,
		NETREG_REGISTERED___40 = 1,
		NETREG_UNREGISTERING___40 = 2,
		NETREG_UNREGISTERED___40 = 3,
		NETREG_RELEASED___40 = 4,
		NETREG_DUMMY___40 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___40 = 0,
		RTNL_LINK_INITIALIZING___40 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___42 *);
	struct netpoll_info *npinfo;
	possible_net_t___40 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___200 dev;
	const struct attribute_group___210 *sysfs_groups[4];
	const struct attribute_group___210 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___40 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___3 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___37 xdp_state[3];
	long: 64;
};

struct inet_frags___45;

struct fqdir___45 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___45 *f;
	struct net___45 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___45;

struct inet_frags___45 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___45 *, const void *);
	void (*destructor)(struct inet_frag_queue___45 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___45 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___41 *fragments_tail;
	struct sk_buff___41 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___45 *fqdir;
	struct callback_head rcu;
};

struct dcbnl_rtnl_ops___40 {
	int (*ieee_getets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___42 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___42 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___42 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___42 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___42 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___42 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___42 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___42 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___42 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___42 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___42 *);
	u8 (*setstate)(struct net_device___42 *, u8);
	void (*getpermhwaddr)(struct net_device___42 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___42 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___42 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___42 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___42 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___42 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___42 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___42 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___42 *, int, u8 *);
	void (*setpfccfg)(struct net_device___42 *, int, u8);
	void (*getpfccfg)(struct net_device___42 *, int, u8 *);
	u8 (*setall)(struct net_device___42 *);
	u8 (*getcap)(struct net_device___42 *, int, u8 *);
	int (*getnumtcs)(struct net_device___42 *, int, u8 *);
	int (*setnumtcs)(struct net_device___42 *, int, u8);
	u8 (*getpfcstate)(struct net_device___42 *);
	void (*setpfcstate)(struct net_device___42 *, u8);
	void (*getbcncfg)(struct net_device___42 *, int, u32 *);
	void (*setbcncfg)(struct net_device___42 *, int, u32);
	void (*getbcnrp)(struct net_device___42 *, int, u8 *);
	void (*setbcnrp)(struct net_device___42 *, int, u8);
	int (*setapp)(struct net_device___42 *, u8, u16, u8);
	int (*getapp)(struct net_device___42 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___42 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___42 *, int, u8);
	u8 (*getdcbx)(struct net_device___42 *);
	u8 (*setdcbx)(struct net_device___42 *, u8);
	int (*peer_getappinfo)(struct net_device___42 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___42 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___42 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___42 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___42 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___42 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___43;

typedef int (*bpf_iter_init_seq_priv_t___42)(void *, struct bpf_iter_aux_info___43 *);

struct bpf_map___43;

struct bpf_iter_aux_info___43 {
	struct bpf_map___43 *map;
};

struct bpf_iter_seq_info___42 {
	const struct seq_operations___197 *seq_ops;
	bpf_iter_init_seq_priv_t___42 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___43;

struct bpf_map_ops___42 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___43 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___43 *, struct file___222 *);
	void (*map_free)(struct bpf_map___43 *);
	int (*map_get_next_key)(struct bpf_map___43 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___43 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___43 *, void *);
	int (*map_lookup_batch)(struct bpf_map___43 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___43 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___43 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___43 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___43 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___43 *, void *);
	int (*map_update_elem)(struct bpf_map___43 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___43 *, void *);
	int (*map_push_elem)(struct bpf_map___43 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___43 *, void *);
	int (*map_peek_elem)(struct bpf_map___43 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___43 *, struct file___222 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___43 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___43 *, void *, struct seq_file___197 *);
	int (*map_check_btf)(const struct bpf_map___43 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___43 *, struct bpf_prog_aux___43 *);
	void (*map_poke_untrack)(struct bpf_map___43 *, struct bpf_prog_aux___43 *);
	void (*map_poke_run)(struct bpf_map___43 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___43 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___43 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___43 *, struct vm_area_struct___227 *);
	__poll_t (*map_poll)(struct bpf_map___43 *, struct file___222 *, struct poll_table_struct___147 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___43 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___43 *, const struct bpf_map___43 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___43 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___42 *iter_seq_info;
};

struct bpf_map___43 {
	const struct bpf_map_ops___42 *ops;
	struct bpf_map___43 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___42;

struct bpf_jit_poke_descriptor___42;

struct btf_mod_pair___42;

struct bpf_prog_offload___40;

struct bpf_prog_aux___43 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___42 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___42 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___37 *ops;
	struct bpf_map___43 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___42 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___43 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___40 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___40;

struct bpf_map_dev_ops___40 {
	int (*map_get_next_key)(struct bpf_offloaded_map___40 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___40 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___40 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___40 *, void *);
};

struct bpf_offloaded_map___40 {
	struct bpf_map___43 map;
	struct net_device___42 *netdev;
	const struct bpf_map_dev_ops___40 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___40 {
	struct bpf_prog *prog;
	struct net_device___42 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___42 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___206 *mod;
};

struct bpf_jit_poke_descriptor___42 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___43 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___42 {
	struct btf *btf;
	struct module___206 *module;
};

struct cftype___152;

struct cgroup_subsys___152 {
	struct cgroup_subsys_state___152 * (*css_alloc)(struct cgroup_subsys_state___152 *);
	int (*css_online)(struct cgroup_subsys_state___152 *);
	void (*css_offline)(struct cgroup_subsys_state___152 *);
	void (*css_released)(struct cgroup_subsys_state___152 *);
	void (*css_free)(struct cgroup_subsys_state___152 *);
	void (*css_reset)(struct cgroup_subsys_state___152 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___152 *, int);
	int (*css_extra_stat_show)(struct seq_file___197 *, struct cgroup_subsys_state___152 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___229 *, struct css_set___152 *);
	void (*cancel_fork)(struct task_struct___229 *, struct css_set___152 *);
	void (*fork)(struct task_struct___229 *);
	void (*exit)(struct task_struct___229 *);
	void (*release)(struct task_struct___229 *);
	void (*bind)(struct cgroup_subsys_state___152 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___152 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___152 *dfl_cftypes;
	struct cftype___152 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___152 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___152 *updated_children;
	struct cgroup___152 *updated_next;
};

struct cgroup_root___152 {
	struct kernfs_root___210 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___152 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___152 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___152 *ss;
	struct list_head node;
	struct kernfs_ops___210 *kf_ops;
	int (*open)(struct kernfs_open_file___210 *);
	void (*release)(struct kernfs_open_file___210 *);
	u64 (*read_u64)(struct cgroup_subsys_state___152 *, struct cftype___152 *);
	s64 (*read_s64)(struct cgroup_subsys_state___152 *, struct cftype___152 *);
	int (*seq_show)(struct seq_file___197 *, void *);
	void * (*seq_start)(struct seq_file___197 *, loff_t *);
	void * (*seq_next)(struct seq_file___197 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___197 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___152 *, struct cftype___152 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___152 *, struct cftype___152 *, s64);
	ssize_t (*write)(struct kernfs_open_file___210 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___210 *, struct poll_table_struct___147 *);
};

struct xdp_rxq_info___40 {
	struct net_device___42 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___40 {
	struct net_device___42 *dev;
};

struct xdp_buff___40 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___40 *rxq;
	struct xdp_txq_info___40 *txq;
	u32 frame_sz;
};

struct xdp_frame___40 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___42 *dev_rx;
};

struct netlink_callback___40 {
	struct sk_buff___41 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___41 *, struct netlink_callback___40 *);
	int (*done)(struct netlink_callback___40 *);
	void *data;
	struct module___206 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___40 {
	int (*create)(struct sk_buff___41 *, struct net_device___42 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___41 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___42 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___41 *);
};

struct netdev_queue___40 {
	struct net_device___42 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___210 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___42 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___40 {
	struct xdp_rxq_info___40 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___210 kobj;
	struct net_device___42 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___40 {
	enum net_device_path_type type;
	const struct net_device___42 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___40 = 0,
				DEV_PATH_BR_VLAN_TAG___40 = 1,
				DEV_PATH_BR_VLAN_UNTAG___40 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___40 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___40 {
	const struct net_device___42 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___40 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___37 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___40 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___40 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___41 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___40 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___42 *dev;
	const char *name;
};

struct net_device_ops___40 {
	int (*ndo_init)(struct net_device___42 *);
	void (*ndo_uninit)(struct net_device___42 *);
	int (*ndo_open)(struct net_device___42 *);
	int (*ndo_stop)(struct net_device___42 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___41 *, struct net_device___42 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___41 *, struct net_device___42 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___42 *, struct sk_buff___41 *, struct net_device___42 *);
	void (*ndo_change_rx_flags)(struct net_device___42 *, int);
	void (*ndo_set_rx_mode)(struct net_device___42 *);
	int (*ndo_set_mac_address)(struct net_device___42 *, void *);
	int (*ndo_validate_addr)(struct net_device___42 *);
	int (*ndo_do_ioctl)(struct net_device___42 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___42 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___42 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___42 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___42 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___42 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___42 *, int);
	int (*ndo_neigh_setup)(struct net_device___42 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___42 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___42 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___42 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___42 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___42 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___42 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___42 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___42 *);
	int (*ndo_netpoll_setup)(struct net_device___42 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___42 *);
	int (*ndo_set_vf_mac)(struct net_device___42 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___42 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___42 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___42 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___42 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___42 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___42 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___42 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___42 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___42 *, int, struct sk_buff___41 *);
	int (*ndo_get_vf_guid)(struct net_device___42 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___42 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___42 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___42 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___42 *);
	int (*ndo_fcoe_disable)(struct net_device___42 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___42 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___42 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___42 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___42 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___42 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___42 *, const struct sk_buff___41 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___42 *, struct net_device___42 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___42 *, struct net_device___42 *);
	struct net_device___42 * (*ndo_get_xmit_slave)(struct net_device___42 *, struct sk_buff___41 *, bool);
	struct net_device___42 * (*ndo_sk_get_lower_dev)(struct net_device___42 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___42 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___42 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___42 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___42 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___41 *, struct netlink_callback___40 *, struct net_device___42 *, struct net_device___42 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___41 *, struct nlattr **, struct net_device___42 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___42 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___41 *, u32, u32, struct net_device___42 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___42 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___42 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___42 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___42 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___42 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___42 *, struct net_device___42 *);
	void (*ndo_dfwd_del_station)(struct net_device___42 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___42 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___42 *);
	int (*ndo_change_proto_down)(struct net_device___42 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___42 *, struct sk_buff___41 *);
	void (*ndo_set_rx_headroom)(struct net_device___42 *, int);
	int (*ndo_bpf)(struct net_device___42 *, struct netdev_bpf___40 *);
	int (*ndo_xdp_xmit)(struct net_device___42 *, int, struct xdp_frame___40 **, u32);
	struct net_device___42 * (*ndo_xdp_get_xmit_slave)(struct net_device___42 *, struct xdp_buff___40 *);
	int (*ndo_xsk_wakeup)(struct net_device___42 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___42 *);
	int (*ndo_tunnel_ctl)(struct net_device___42 *, struct ip_tunnel_parm *, int);
	struct net_device___42 * (*ndo_get_peer_dev)(struct net_device___42 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___40 *, struct net_device_path___40 *);
};

struct ethtool_ops___16 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___42 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___42 *);
	void (*get_regs)(struct net_device___42 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___42 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___42 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___42 *);
	void (*set_msglevel)(struct net_device___42 *, u32);
	int (*nway_reset)(struct net_device___42 *);
	u32 (*get_link)(struct net_device___42 *);
	int (*get_link_ext_state)(struct net_device___42 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___42 *);
	int (*get_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___42 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___42 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___42 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___42 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___42 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___42 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___42 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___42 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___42 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___42 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___42 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___42 *);
	void (*complete)(struct net_device___42 *);
	u32 (*get_priv_flags)(struct net_device___42 *);
	int (*set_priv_flags)(struct net_device___42 *, u32);
	int (*get_sset_count)(struct net_device___42 *, int);
	int (*get_rxnfc)(struct net_device___42 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___42 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___42 *, struct ethtool_flash *);
	int (*reset)(struct net_device___42 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___42 *);
	u32 (*get_rxfh_indir_size)(struct net_device___42 *);
	int (*get_rxfh)(struct net_device___42 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___42 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___42 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___42 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___42 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___42 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___42 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___42 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___42 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___42 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___42 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___42 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___42 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___42 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___42 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___42 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___42 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___42 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___42 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___42 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___42 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___42 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___42 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___42 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___42 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___42 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___42 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___42 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___42 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___42 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___42 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct mii_bus___4;

struct mdio_device___4 {
	struct device___200 dev;
	struct mii_bus___4 *bus;
	char modalias[32];
	int (*bus_match)(struct device___200 *, struct device_driver___200 *);
	void (*device_free)(struct mdio_device___4 *);
	void (*device_remove)(struct mdio_device___4 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___3;

struct phy_led_trigger___3;

struct mii_timestamper___3;

struct phy_device___3 {
	struct mdio_device___4 mdio;
	struct phy_driver___3 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger___3 *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger___3 *last_triggered;
	struct phy_led_trigger___3 *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___41 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___42 *attached_dev;
	struct mii_timestamper___3 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___3 *, bool);
	void (*adjust_link)(struct net_device___42 *);
	const struct macsec_ops *macsec_ops;
};

struct ethtool_phy_ops {
	int (*get_sset_count)(struct phy_device___3 *);
	int (*get_strings)(struct phy_device___3 *, u8 *);
	int (*get_stats)(struct phy_device___3 *, struct ethtool_stats *, u64 *);
	int (*start_cable_test)(struct phy_device___3 *, struct netlink_ext_ack *);
	int (*start_cable_test_tdr)(struct phy_device___3 *, struct netlink_ext_ack *, const struct phy_tdr_config *);
};

struct mii_bus___4 {
	struct module___206 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___4 *, int, int);
	int (*write)(struct mii_bus___4 *, int, int, u16);
	int (*reset)(struct mii_bus___4 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___200 *parent;
	enum {
		MDIOBUS_ALLOCATED___4 = 1,
		MDIOBUS_REGISTERED___4 = 2,
		MDIOBUS_UNREGISTERED___4 = 3,
		MDIOBUS_RELEASED___4 = 4,
	} state;
	struct device___200 dev;
	struct mdio_device___4 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___4 = 0,
		MDIOBUS_C22___4 = 1,
		MDIOBUS_C45___4 = 2,
		MDIOBUS_C22_C45___4 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___4 {
	struct device_driver___200 driver;
	int flags;
};

struct mii_timestamper___3 {
	bool (*rxtstamp)(struct mii_timestamper___3 *, struct sk_buff___41 *, int);
	void (*txtstamp)(struct mii_timestamper___3 *, struct sk_buff___41 *, int);
	int (*hwtstamp)(struct mii_timestamper___3 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___3 *, struct phy_device___3 *);
	int (*ts_info)(struct mii_timestamper___3 *, struct ethtool_ts_info *);
	struct device___200 *device;
};

struct phy_driver___3 {
	struct mdio_driver_common___4 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___3 *);
	int (*config_init)(struct phy_device___3 *);
	int (*probe)(struct phy_device___3 *);
	int (*get_features)(struct phy_device___3 *);
	int (*suspend)(struct phy_device___3 *);
	int (*resume)(struct phy_device___3 *);
	int (*config_aneg)(struct phy_device___3 *);
	int (*aneg_done)(struct phy_device___3 *);
	int (*read_status)(struct phy_device___3 *);
	int (*config_intr)(struct phy_device___3 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___3 *);
	void (*remove)(struct phy_device___3 *);
	int (*match_phy_device)(struct phy_device___3 *);
	int (*set_wol)(struct phy_device___3 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___3 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___3 *);
	int (*read_mmd)(struct phy_device___3 *, int, u16);
	int (*write_mmd)(struct phy_device___3 *, int, u16, u16);
	int (*read_page)(struct phy_device___3 *);
	int (*write_page)(struct phy_device___3 *, int);
	int (*module_info)(struct phy_device___3 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___3 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___3 *);
	int (*cable_test_tdr_start)(struct phy_device___3 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___3 *, bool *);
	int (*get_sset_count)(struct phy_device___3 *);
	void (*get_strings)(struct phy_device___3 *, u8 *);
	void (*get_stats)(struct phy_device___3 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___3 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___3 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___3 *, bool);
	int (*get_sqi)(struct phy_device___3 *);
	int (*get_sqi_max)(struct phy_device___3 *);
};

struct led_classdev___5;

struct led_trigger___5 {
	const char *name;
	int (*activate)(struct led_classdev___5 *);
	void (*deactivate)(struct led_classdev___5 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___210 **groups;
};

struct phy_led_trigger___3 {
	struct led_trigger___5 trigger;
	char name[76];
	unsigned int speed;
};

struct phy_fixup {
	struct list_head list;
	char bus_id[64];
	u32 phy_uid;
	u32 phy_uid_mask;
	int (*run)(struct phy_device___3 *);
};

struct led_classdev___5 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___5 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___5 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___5 *);
	int (*blink_set)(struct led_classdev___5 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___5 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___5 *);
	struct device___200 *dev;
	const struct attribute_group___210 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___5 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___5 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___210 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct sfp_eeprom_base {
	u8 phys_id;
	u8 phys_ext_id;
	u8 connector;
	u8 if_1x_copper_passive: 1;
	u8 if_1x_copper_active: 1;
	u8 if_1x_lx: 1;
	u8 if_1x_sx: 1;
	u8 e10g_base_sr: 1;
	u8 e10g_base_lr: 1;
	u8 e10g_base_lrm: 1;
	u8 e10g_base_er: 1;
	u8 sonet_oc3_short_reach: 1;
	u8 sonet_oc3_smf_intermediate_reach: 1;
	u8 sonet_oc3_smf_long_reach: 1;
	u8 unallocated_5_3: 1;
	u8 sonet_oc12_short_reach: 1;
	u8 sonet_oc12_smf_intermediate_reach: 1;
	u8 sonet_oc12_smf_long_reach: 1;
	u8 unallocated_5_7: 1;
	u8 sonet_oc48_short_reach: 1;
	u8 sonet_oc48_intermediate_reach: 1;
	u8 sonet_oc48_long_reach: 1;
	u8 sonet_reach_bit2: 1;
	u8 sonet_reach_bit1: 1;
	u8 sonet_oc192_short_reach: 1;
	u8 escon_smf_1310_laser: 1;
	u8 escon_mmf_1310_led: 1;
	u8 e1000_base_sx: 1;
	u8 e1000_base_lx: 1;
	u8 e1000_base_cx: 1;
	u8 e1000_base_t: 1;
	u8 e100_base_lx: 1;
	u8 e100_base_fx: 1;
	u8 e_base_bx10: 1;
	u8 e_base_px: 1;
	u8 fc_tech_electrical_inter_enclosure: 1;
	u8 fc_tech_lc: 1;
	u8 fc_tech_sa: 1;
	u8 fc_ll_m: 1;
	u8 fc_ll_l: 1;
	u8 fc_ll_i: 1;
	u8 fc_ll_s: 1;
	u8 fc_ll_v: 1;
	u8 unallocated_8_0: 1;
	u8 unallocated_8_1: 1;
	u8 sfp_ct_passive: 1;
	u8 sfp_ct_active: 1;
	u8 fc_tech_ll: 1;
	u8 fc_tech_sl: 1;
	u8 fc_tech_sn: 1;
	u8 fc_tech_electrical_intra_enclosure: 1;
	u8 fc_media_sm: 1;
	u8 unallocated_9_1: 1;
	u8 fc_media_m5: 1;
	u8 fc_media_m6: 1;
	u8 fc_media_tv: 1;
	u8 fc_media_mi: 1;
	u8 fc_media_tp: 1;
	u8 fc_media_tw: 1;
	u8 fc_speed_100: 1;
	u8 unallocated_10_1: 1;
	u8 fc_speed_200: 1;
	u8 fc_speed_3200: 1;
	u8 fc_speed_400: 1;
	u8 fc_speed_1600: 1;
	u8 fc_speed_800: 1;
	u8 fc_speed_1200: 1;
	long: 23;
	long: 64;
	u8 encoding;
	u8 br_nominal;
	u8 rate_id;
	u8 link_len[6];
	char vendor_name[16];
	u8 extended_cc;
	char vendor_oui[3];
	char vendor_pn[16];
	char vendor_rev[4];
	union {
		__be16 optical_wavelength;
		__be16 cable_compliance;
		struct {
			u8 sff8431_app_e: 1;
			u8 fc_pi_4_app_h: 1;
			u8 reserved60_2: 6;
			u8 reserved61: 8;
			char: 8;
		} passive;
		struct {
			u8 sff8431_app_e: 1;
			u8 fc_pi_4_app_h: 1;
			u8 sff8431_lim: 1;
			u8 fc_pi_4_lim: 1;
			u8 reserved60_4: 4;
			u8 reserved61: 8;
			char: 8;
		} active;
	};
	u8 reserved62;
	u8 cc_base;
};

struct sfp_eeprom_ext {
	__be16 options;
	u8 br_max;
	u8 br_min;
	char vendor_sn[16];
	char datecode[8];
	u8 diagmon;
	u8 enhopts;
	u8 sff8472_compliance;
	u8 cc_ext;
};

struct sfp_eeprom_id {
	struct sfp_eeprom_base base;
	struct sfp_eeprom_ext ext;
};

struct sfp_upstream_ops {
	void (*attach)(void *, struct sfp_bus *);
	void (*detach)(void *, struct sfp_bus *);
	int (*module_insert)(void *, const struct sfp_eeprom_id *);
	void (*module_remove)(void *);
	int (*module_start)(void *);
	void (*module_stop)(void *);
	void (*link_down)(void *);
	void (*link_up)(void *);
	int (*connect_phy)(void *, struct phy_device___3 *);
	void (*disconnect_phy)(void *);
};

struct dentry___223;

struct super_block___223;

struct module___207;

struct file_system_type___223 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___223 * (*mount)(struct file_system_type___223 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___223 *);
	struct module___207 *owner;
	struct file_system_type___223 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___223;

struct kiocb___223;

struct iov_iter___143;

struct poll_table_struct___148;

struct vm_area_struct___228;

struct inode___223;

struct file_lock___223;

struct page___228;

struct pipe_inode_info___73;

struct seq_file___198;

struct file_operations___224 {
	struct module___207 *owner;
	loff_t (*llseek)(struct file___223 *, loff_t, int);
	ssize_t (*read)(struct file___223 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___223 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___223 *, struct iov_iter___143 *);
	ssize_t (*write_iter)(struct kiocb___223 *, struct iov_iter___143 *);
	int (*iopoll)(struct kiocb___223 *, bool);
	int (*iterate)(struct file___223 *, struct dir_context *);
	int (*iterate_shared)(struct file___223 *, struct dir_context *);
	__poll_t (*poll)(struct file___223 *, struct poll_table_struct___148 *);
	long int (*unlocked_ioctl)(struct file___223 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___223 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___223 *, struct vm_area_struct___228 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___223 *, struct file___223 *);
	int (*flush)(struct file___223 *, fl_owner_t);
	int (*release)(struct inode___223 *, struct file___223 *);
	int (*fsync)(struct file___223 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___223 *, int);
	int (*lock)(struct file___223 *, int, struct file_lock___223 *);
	ssize_t (*sendpage)(struct file___223 *, struct page___228 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___223 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___223 *, long unsigned int);
	int (*flock)(struct file___223 *, int, struct file_lock___223 *);
	ssize_t (*splice_write)(struct pipe_inode_info___73 *, struct file___223 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___223 *, loff_t *, struct pipe_inode_info___73 *, size_t, unsigned int);
	int (*setlease)(struct file___223 *, long int, struct file_lock___223 **, void **);
	long int (*fallocate)(struct file___223 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___198 *, struct file___223 *);
	ssize_t (*copy_file_range)(struct file___223 *, loff_t, struct file___223 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___223 *, loff_t, struct file___223 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___223 *, loff_t, loff_t, int);
};

struct vmacache___228 {
	u64 seqnum;
	struct vm_area_struct___228 *vmas[4];
};

struct page_frag___228 {
	struct page___228 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___81;

struct debug_info___81 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___81 *hbp_break[16];
	struct perf_event___81 *hbp_watch[16];
};

struct thread_struct___81 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___81 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___229;

struct pid___200;

struct nsproxy___209;

struct signal_struct___224;

struct css_set___153;

struct perf_event_context___81;

struct vm_struct___206;

struct task_struct___230 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___230 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___229 *mm;
	struct mm_struct___229 *active_mm;
	struct vmacache___228 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___230 *real_parent;
	struct task_struct___230 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___230 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___200 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___209 *nsproxy;
	struct signal_struct___224 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___230 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___116 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___153 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___81 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___73 *splice_pipe;
	struct page_frag___228 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___230 *oom_reaper_list;
	struct vm_struct___206 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___211;

struct kobj_type___211;

struct kernfs_node___211;

struct kobject___211 {
	const char *name;
	struct list_head entry;
	struct kobject___211 *parent;
	struct kset___211 *kset;
	struct kobj_type___211 *ktype;
	struct kernfs_node___211 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___208 {
	struct kobject___211 kobj;
	struct module___207 *mod;
	struct kobject___211 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___207 {
	struct module___207 *mod;
	struct latch_tree_node node;
};

struct module_layout___207 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___207 mtn;
};

struct module_attribute___207;

struct kernel_param___207;

struct trace_event_call___75;

struct module___207 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___208 mkobj;
	struct module_attribute___207 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___211 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___207 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___207 core_layout;
	struct module_layout___207 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___75 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___81 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___230 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___81)(struct perf_event___81 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___81;

struct fasync_struct___223;

struct pid_namespace___200;

struct perf_cgroup___81;

struct perf_event___81 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___81 *group_leader;
	struct pmu___81 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___81 hw;
	struct perf_event_context___81 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___81 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___230 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___223 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___81 *aux_event;
	void (*destroy)(struct perf_event___81 *);
	struct callback_head callback_head;
	struct pid_namespace___200 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___81 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___81 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___75 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___81 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___200 {
	int nr;
	struct pid_namespace___200 *ns;
};

struct pid_namespace___200 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___230 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___200 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___200 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___200 numbers[1];
};

typedef struct page___228 *pgtable_t___228;

struct address_space___223;

struct page_pool___61;

struct dev_pagemap___218;

struct page___228 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___223 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___61 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___228 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___228 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___229 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___218 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___218;

struct vm_area_struct___228 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___228 *vm_next;
	struct vm_area_struct___228 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___229 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___218 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___223 *vm_file;
	struct file___223 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___224 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___230 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___230 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___200 *pids[4];
	struct pid___200 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___229 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___228;

struct mm_struct___229 {
	struct {
		struct vm_area_struct___228 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___223 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___228 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___230 *owner;
		struct user_namespace___14 *user_ns;
		struct file___223 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___46;

struct cgroup_namespace___153;

struct nsproxy___209 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___200 *pid_ns_for_children;
	struct net___46 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___153 *cgroup_ns;
};

struct cgroup_subsys_state___153;

struct cgroup___153;

struct css_set___153 {
	struct cgroup_subsys_state___153 *subsys[14];
	refcount_t refcount;
	struct css_set___153 *dom_cset;
	struct cgroup___153 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___153 *mg_src_cgrp;
	struct cgroup___153 *mg_dst_cgrp;
	struct css_set___153 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___81 {
	struct pmu___81 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___230 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___81 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___73;

struct pipe_inode_info___73 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___228 *tmp_page;
	struct fasync_struct___223 *fasync_readers;
	struct fasync_struct___223 *fasync_writers;
	struct pipe_buffer___73 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___206 {
	struct vm_struct___206 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___228 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___223;

struct address_space___223 {
	struct inode___223 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___223 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___201;

struct page_pool_params___61 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___201 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___61 {
	u32 count;
	struct page___228 *cache[128];
};

struct page_pool___61 {
	struct page_pool_params___61 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___228 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___61 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___218;

struct dev_pagemap___218 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___218 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___223;

struct path___223 {
	struct vfsmount___223 *mnt;
	struct dentry___223 *dentry;
};

struct fown_struct___200 {
	rwlock_t lock;
	struct pid___200 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___223 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___223 f_path;
	struct inode___223 *f_inode;
	const struct file_operations___224 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___200 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___223 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___218;

struct vm_operations_struct___218 {
	void (*open)(struct vm_area_struct___228 *);
	void (*close)(struct vm_area_struct___228 *);
	int (*may_split)(struct vm_area_struct___228 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___228 *);
	int (*mprotect)(struct vm_area_struct___228 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___218 *);
	vm_fault_t (*huge_fault)(struct vm_fault___218 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___218 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___228 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___218 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___218 *);
	int (*access)(struct vm_area_struct___228 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___228 *);
	int (*set_policy)(struct vm_area_struct___228 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___228 *, long unsigned int);
	struct page___228 * (*find_special_page)(struct vm_area_struct___228 *, long unsigned int);
};

struct core_thread___228 {
	struct task_struct___230 *task;
	struct core_thread___228 *next;
};

struct core_state___228 {
	atomic_t nr_threads;
	struct core_thread___228 dumper;
	struct completion startup;
};

struct vm_fault___218 {
	const struct {
		struct vm_area_struct___228 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___228 *cow_page;
	struct page___228 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___228 prealloc_pte;
};

struct kernfs_root___211;

struct kernfs_elem_dir___211 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___211 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___211;

struct kernfs_root___211 {
	struct kernfs_node___211 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___211 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___211 {
	struct kernfs_node___211 *target_kn;
};

struct kernfs_ops___211;

struct kernfs_elem_attr___211 {
	const struct kernfs_ops___211 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___211 *notify_next;
};

struct kernfs_node___211 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___211 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___211 dir;
		struct kernfs_elem_symlink___211 symlink;
		struct kernfs_elem_attr___211 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___211;

struct kernfs_ops___211 {
	int (*open)(struct kernfs_open_file___211 *);
	void (*release)(struct kernfs_open_file___211 *);
	int (*seq_show)(struct seq_file___198 *, void *);
	void * (*seq_start)(struct seq_file___198 *, loff_t *);
	void * (*seq_next)(struct seq_file___198 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___198 *, void *);
	ssize_t (*read)(struct kernfs_open_file___211 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___211 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___211 *, struct poll_table_struct___148 *);
	int (*mmap)(struct kernfs_open_file___211 *, struct vm_area_struct___228 *);
};

struct kernfs_syscall_ops___211 {
	int (*show_options)(struct seq_file___198 *, struct kernfs_root___211 *);
	int (*mkdir)(struct kernfs_node___211 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___211 *);
	int (*rename)(struct kernfs_node___211 *, struct kernfs_node___211 *, const char *);
	int (*show_path)(struct seq_file___198 *, struct kernfs_node___211 *, struct kernfs_root___211 *);
};

struct seq_operations___198;

struct seq_file___198 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___198 *op;
	int poll_event;
	const struct file___223 *file;
	void *private;
};

struct kernfs_open_file___211 {
	struct kernfs_node___211 *kn;
	struct file___223 *file;
	struct seq_file___198 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___218 *vm_ops;
};

typedef void (*poll_queue_proc___155)(struct file___223 *, wait_queue_head_t *, struct poll_table_struct___148 *);

struct poll_table_struct___148 {
	poll_queue_proc___155 _qproc;
	__poll_t _key;
};

struct bin_attribute___211;

struct attribute_group___211 {
	const char *name;
	umode_t (*is_visible)(struct kobject___211 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___211 *, struct bin_attribute___211 *, int);
	struct attribute **attrs;
	struct bin_attribute___211 **bin_attrs;
};

struct bin_attribute___211 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___223 * (*f_mapping)();
	ssize_t (*read)(struct file___223 *, struct kobject___211 *, struct bin_attribute___211 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___223 *, struct kobject___211 *, struct bin_attribute___211 *, char *, loff_t, size_t);
	int (*mmap)(struct file___223 *, struct kobject___211 *, struct bin_attribute___211 *, struct vm_area_struct___228 *);
};

struct sysfs_ops___211 {
	ssize_t (*show)(struct kobject___211 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___211 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___211;

struct kset___211 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___211 kobj;
	const struct kset_uevent_ops___211 *uevent_ops;
};

struct kobj_type___211 {
	void (*release)(struct kobject___211 *);
	const struct sysfs_ops___211 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___211 **default_groups;
	const struct kobj_ns_type_operations___30 * (*child_ns_type)(struct kobject___211 *);
	const void * (*namespace)(struct kobject___211 *);
	void (*get_ownership)(struct kobject___211 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___211 {
	int (* const filter)(struct kset___211 *, struct kobject___211 *);
	const char * (* const name)(struct kset___211 *, struct kobject___211 *);
	int (* const uevent)(struct kset___211 *, struct kobject___211 *, struct kobj_uevent_env *);
};

struct wakeup_source___201;

struct dev_pm_info___201 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___201 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___201 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___201;

struct bus_type___201;

struct device_driver___201;

struct dev_pm_domain___201;

struct irq_domain___55;

struct device_node___88;

struct fwnode_handle___197;

struct class___201;

struct device___201 {
	struct kobject___211 kobj;
	struct device___201 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___201 *type;
	struct bus_type___201 *bus;
	struct device_driver___201 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___201 power;
	struct dev_pm_domain___201 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___55 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___88 *of_node;
	struct fwnode_handle___197 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___201 *class;
	const struct attribute_group___211 **groups;
	void (*release)(struct device___201 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___201 {
	int (*prepare)(struct device___201 *);
	void (*complete)(struct device___201 *);
	int (*suspend)(struct device___201 *);
	int (*resume)(struct device___201 *);
	int (*freeze)(struct device___201 *);
	int (*thaw)(struct device___201 *);
	int (*poweroff)(struct device___201 *);
	int (*restore)(struct device___201 *);
	int (*suspend_late)(struct device___201 *);
	int (*resume_early)(struct device___201 *);
	int (*freeze_late)(struct device___201 *);
	int (*thaw_early)(struct device___201 *);
	int (*poweroff_late)(struct device___201 *);
	int (*restore_early)(struct device___201 *);
	int (*suspend_noirq)(struct device___201 *);
	int (*resume_noirq)(struct device___201 *);
	int (*freeze_noirq)(struct device___201 *);
	int (*thaw_noirq)(struct device___201 *);
	int (*poweroff_noirq)(struct device___201 *);
	int (*restore_noirq)(struct device___201 *);
	int (*runtime_suspend)(struct device___201 *);
	int (*runtime_resume)(struct device___201 *);
	int (*runtime_idle)(struct device___201 *);
};

struct wakeup_source___201 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___201 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___201 {
	struct dev_pm_ops___201 ops;
	int (*start)(struct device___201 *);
	void (*detach)(struct device___201 *, bool);
	int (*activate)(struct device___201 *);
	void (*sync)(struct device___201 *);
	void (*dismiss)(struct device___201 *);
};

struct bus_type___201 {
	const char *name;
	const char *dev_name;
	struct device___201 *dev_root;
	const struct attribute_group___211 **bus_groups;
	const struct attribute_group___211 **dev_groups;
	const struct attribute_group___211 **drv_groups;
	int (*match)(struct device___201 *, struct device_driver___201 *);
	int (*uevent)(struct device___201 *, struct kobj_uevent_env *);
	int (*probe)(struct device___201 *);
	void (*sync_state)(struct device___201 *);
	void (*remove)(struct device___201 *);
	void (*shutdown)(struct device___201 *);
	int (*online)(struct device___201 *);
	int (*offline)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	int (*num_vf)(struct device___201 *);
	int (*dma_configure)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___201 {
	const char *name;
	struct bus_type___201 *bus;
	struct module___207 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___201 *);
	void (*sync_state)(struct device___201 *);
	int (*remove)(struct device___201 *);
	void (*shutdown)(struct device___201 *);
	int (*suspend)(struct device___201 *, pm_message_t);
	int (*resume)(struct device___201 *);
	const struct attribute_group___211 **groups;
	const struct attribute_group___211 **dev_groups;
	const struct dev_pm_ops___201 *pm;
	void (*coredump)(struct device___201 *);
	struct driver_private *p;
};

struct device_type___201 {
	const char *name;
	const struct attribute_group___211 **groups;
	int (*uevent)(struct device___201 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___201 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___201 *);
	const struct dev_pm_ops___201 *pm;
};

struct class___201 {
	const char *name;
	struct module___207 *owner;
	const struct attribute_group___211 **class_groups;
	const struct attribute_group___211 **dev_groups;
	struct kobject___211 *dev_kobj;
	int (*dev_uevent)(struct device___201 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___201 *, umode_t *);
	void (*class_release)(struct class___201 *);
	void (*dev_release)(struct device___201 *);
	int (*shutdown_pre)(struct device___201 *);
	const struct kobj_ns_type_operations___30 *ns_type;
	const void * (*namespace)(struct device___201 *);
	void (*get_ownership)(struct device___201 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___201 *pm;
	struct subsys_private *p;
};

struct device_attribute___35 {
	struct attribute attr;
	ssize_t (*show)(struct device___201 *, struct device_attribute___35 *, char *);
	ssize_t (*store)(struct device___201 *, struct device_attribute___35 *, const char *, size_t);
};

struct dev_ext_attribute___3 {
	struct device_attribute___35 attr;
	void *var;
};

struct irq_domain_ops___55;

struct irq_domain_chip_generic___55;

struct irq_data___57;

struct irq_domain___55 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___55 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___197 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___55 *gc;
	struct irq_domain___55 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___57 *revmap[0];
};

struct fwnode_operations___197;

struct fwnode_handle___197 {
	struct fwnode_handle___197 *secondary;
	const struct fwnode_operations___197 *ops;
	struct device___201 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___65;

struct device_node___88 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___197 fwnode;
	struct property___65 *properties;
	struct property___65 *deadprops;
	struct device_node___88 *parent;
	struct device_node___88 *child;
	struct device_node___88 *sibling;
	struct kobject___211 kobj;
	long unsigned int _flags;
	void *data;
};

struct dentry_operations___223;

struct dentry___223 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___223 *d_parent;
	struct qstr d_name;
	struct inode___223 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___223 *d_op;
	struct super_block___223 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___223;

struct inode___223 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___223 *i_op;
	struct super_block___223 *i_sb;
	struct address_space___223 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___224 *i_fop;
		void (*free_inode)(struct inode___223 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___223 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___73 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___223 {
	int (*d_revalidate)(struct dentry___223 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___223 *, unsigned int);
	int (*d_hash)(const struct dentry___223 *, struct qstr *);
	int (*d_compare)(const struct dentry___223 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___223 *);
	int (*d_init)(struct dentry___223 *);
	void (*d_release)(struct dentry___223 *);
	void (*d_prune)(struct dentry___223 *);
	void (*d_iput)(struct dentry___223 *, struct inode___223 *);
	char * (*d_dname)(struct dentry___223 *, char *, int);
	struct vfsmount___223 * (*d_automount)(struct path___223 *);
	int (*d_manage)(const struct path___223 *, bool);
	struct dentry___223 * (*d_real)(struct dentry___223 *, const struct inode___223 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___223;

struct mem_dqinfo___223 {
	struct quota_format_type___223 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___223;

struct quota_info___223 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___223 *files[3];
	struct mem_dqinfo___223 info[3];
	const struct quota_format_ops___223 *ops[3];
};

struct rcuwait___224 {
	struct task_struct___230 *task;
};

struct percpu_rw_semaphore___224 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___224 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___223 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___224 rw_sem[3];
};

struct super_operations___223;

struct dquot_operations___223;

struct quotactl_ops___223;

struct super_block___223 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___223 *s_type;
	const struct super_operations___223 *s_op;
	const struct dquot_operations___223 *dq_op;
	const struct quotactl_ops___223 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___223 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___223 s_dquot;
	struct sb_writers___223 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___223 *s_d_op;
	int cleancache_poolid;
	struct shrinker___96 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___223 {
	struct dentry___223 *mnt_root;
	struct super_block___223 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct cgroup_subsys___153;

struct cgroup_subsys_state___153 {
	struct cgroup___153 *cgroup;
	struct cgroup_subsys___153 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___153 *parent;
};

struct cgroup_file___153 {
	struct kernfs_node___211 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___153 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___230 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___153;

struct cgroup_rstat_cpu___153;

struct cgroup___153 {
	struct cgroup_subsys_state___153 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___211 *kn;
	struct cgroup_file___153 procs_file;
	struct cgroup_file___153 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___153 *subsys[14];
	struct cgroup_root___153 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___153 *dom_cgrp;
	struct cgroup___153 *old_dom_cgrp;
	struct cgroup_rstat_cpu___153 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___153 psi;
	struct cgroup_bpf___37 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___223 {
	struct file___223 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___223 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___223 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___223 *ia_file;
};

struct dquot___223 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___223 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___223 {
	int qf_fmt_id;
	const struct quota_format_ops___223 *qf_ops;
	struct module___207 *qf_owner;
	struct quota_format_type___223 *qf_next;
};

struct quota_format_ops___223 {
	int (*check_quota_file)(struct super_block___223 *, int);
	int (*read_file_info)(struct super_block___223 *, int);
	int (*write_file_info)(struct super_block___223 *, int);
	int (*free_file_info)(struct super_block___223 *, int);
	int (*read_dqblk)(struct dquot___223 *);
	int (*commit_dqblk)(struct dquot___223 *);
	int (*release_dqblk)(struct dquot___223 *);
	int (*get_next_id)(struct super_block___223 *, struct kqid *);
};

struct dquot_operations___223 {
	int (*write_dquot)(struct dquot___223 *);
	struct dquot___223 * (*alloc_dquot)(struct super_block___223 *, int);
	void (*destroy_dquot)(struct dquot___223 *);
	int (*acquire_dquot)(struct dquot___223 *);
	int (*release_dquot)(struct dquot___223 *);
	int (*mark_dirty)(struct dquot___223 *);
	int (*write_info)(struct super_block___223 *, int);
	qsize_t * (*get_reserved_space)(struct inode___223 *);
	int (*get_projid)(struct inode___223 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___223 *, qsize_t *);
	int (*get_next_id)(struct super_block___223 *, struct kqid *);
};

struct quotactl_ops___223 {
	int (*quota_on)(struct super_block___223 *, int, int, const struct path___223 *);
	int (*quota_off)(struct super_block___223 *, int);
	int (*quota_enable)(struct super_block___223 *, unsigned int);
	int (*quota_disable)(struct super_block___223 *, unsigned int);
	int (*quota_sync)(struct super_block___223 *, int);
	int (*set_info)(struct super_block___223 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___223 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___223 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___223 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___223 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___223 *, unsigned int);
};

struct address_space_operations___223 {
	int (*writepage)(struct page___228 *, struct writeback_control___3 *);
	int (*readpage)(struct file___223 *, struct page___228 *);
	int (*writepages)(struct address_space___223 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___228 *);
	int (*readpages)(struct file___223 *, struct address_space___223 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___223 *, struct address_space___223 *, loff_t, unsigned int, unsigned int, struct page___228 **, void **);
	int (*write_end)(struct file___223 *, struct address_space___223 *, loff_t, unsigned int, unsigned int, struct page___228 *, void *);
	sector_t (*bmap)(struct address_space___223 *, sector_t);
	void (*invalidatepage)(struct page___228 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___228 *, gfp_t);
	void (*freepage)(struct page___228 *);
	ssize_t (*direct_IO)(struct kiocb___223 *, struct iov_iter___143 *);
	int (*migratepage)(struct address_space___223 *, struct page___228 *, struct page___228 *, enum migrate_mode);
	bool (*isolate_page)(struct page___228 *, isolate_mode_t);
	void (*putback_page)(struct page___228 *);
	int (*launder_page)(struct page___228 *);
	int (*is_partially_uptodate)(struct page___228 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___228 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___223 *, struct page___228 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___223 *, sector_t *);
	void (*swap_deactivate)(struct file___223 *);
};

struct bio_vec___140;

struct iov_iter___143 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___140 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___73 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___223 {
	struct dentry___223 * (*lookup)(struct inode___223 *, struct dentry___223 *, unsigned int);
	const char * (*get_link)(struct dentry___223 *, struct inode___223 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___223 *, int);
	struct posix_acl * (*get_acl)(struct inode___223 *, int, bool);
	int (*readlink)(struct dentry___223 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___223 *, struct dentry___223 *, umode_t, bool);
	int (*link)(struct dentry___223 *, struct inode___223 *, struct dentry___223 *);
	int (*unlink)(struct inode___223 *, struct dentry___223 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___223 *, struct dentry___223 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___223 *, struct dentry___223 *, umode_t);
	int (*rmdir)(struct inode___223 *, struct dentry___223 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___223 *, struct dentry___223 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___223 *, struct dentry___223 *, struct inode___223 *, struct dentry___223 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___223 *, struct iattr___223 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___223 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___223 *, char *, size_t);
	int (*fiemap)(struct inode___223 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___223 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___223 *, struct dentry___223 *, struct file___223 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___223 *, struct dentry___223 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___223 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___223 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___223 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___223 {
	void (*fl_copy_lock)(struct file_lock___223 *, struct file_lock___223 *);
	void (*fl_release_private)(struct file_lock___223 *);
};

struct lock_manager_operations___223;

struct file_lock___223 {
	struct file_lock___223 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___223 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___223 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___223 *fl_ops;
	const struct lock_manager_operations___223 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___223 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___223 *);
	int (*lm_grant)(struct file_lock___223 *, int);
	bool (*lm_break)(struct file_lock___223 *);
	int (*lm_change)(struct file_lock___223 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___223 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___223 *);
};

struct fasync_struct___223 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___223 *fa_next;
	struct file___223 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___223 {
	struct inode___223 * (*alloc_inode)(struct super_block___223 *);
	void (*destroy_inode)(struct inode___223 *);
	void (*free_inode)(struct inode___223 *);
	void (*dirty_inode)(struct inode___223 *, int);
	int (*write_inode)(struct inode___223 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___223 *);
	void (*evict_inode)(struct inode___223 *);
	void (*put_super)(struct super_block___223 *);
	int (*sync_fs)(struct super_block___223 *, int);
	int (*freeze_super)(struct super_block___223 *);
	int (*freeze_fs)(struct super_block___223 *);
	int (*thaw_super)(struct super_block___223 *);
	int (*unfreeze_fs)(struct super_block___223 *);
	int (*statfs)(struct dentry___223 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___223 *, int *, char *);
	void (*umount_begin)(struct super_block___223 *);
	int (*show_options)(struct seq_file___198 *, struct dentry___223 *);
	int (*show_devname)(struct seq_file___198 *, struct dentry___223 *);
	int (*show_path)(struct seq_file___198 *, struct dentry___223 *);
	int (*show_stats)(struct seq_file___198 *, struct dentry___223 *);
	ssize_t (*quota_read)(struct super_block___223 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___223 *, int, const char *, size_t, loff_t);
	struct dquot___223 ** (*get_dquots)(struct inode___223 *);
	long int (*nr_cached_objects)(struct super_block___223 *, struct shrink_control___96 *);
	long int (*free_cached_objects)(struct super_block___223 *, struct shrink_control___96 *);
	struct file___223 * (*real_loop)(struct file___223 *);
};

struct dev_pagemap_ops___218 {
	void (*page_free)(struct page___228 *);
	void (*kill)(struct dev_pagemap___218 *);
	void (*cleanup)(struct dev_pagemap___218 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___218 *);
};

struct irq_desc___57;

typedef void (*irq_flow_handler_t___57)(struct irq_desc___57 *);

struct irq_chip___57;

struct irq_data___57 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___57 *chip;
	struct irq_domain___55 *domain;
	struct irq_data___57 *parent_data;
	void *chip_data;
};

struct irqaction___39;

struct irq_desc___57 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___57 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___57 handle_irq;
	struct irqaction___39 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___211 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___207 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___197;

struct fwnode_endpoint___197;

struct fwnode_operations___197 {
	struct fwnode_handle___197 * (*get)(struct fwnode_handle___197 *);
	void (*put)(struct fwnode_handle___197 *);
	bool (*device_is_available)(const struct fwnode_handle___197 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___197 *, const struct device___201 *);
	bool (*property_present)(const struct fwnode_handle___197 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___197 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___197 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___197 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*get_parent)(const struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*get_next_child_node)(const struct fwnode_handle___197 *, struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*get_named_child_node)(const struct fwnode_handle___197 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___197 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___197 *);
	struct fwnode_handle___197 * (*graph_get_next_endpoint)(const struct fwnode_handle___197 *, struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*graph_get_remote_endpoint)(const struct fwnode_handle___197 *);
	struct fwnode_handle___197 * (*graph_get_port_parent)(struct fwnode_handle___197 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___197 *, struct fwnode_endpoint___197 *);
	int (*add_links)(struct fwnode_handle___197 *);
};

struct fwnode_endpoint___197 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___197 *local_fwnode;
};

struct fwnode_reference_args___197 {
	struct fwnode_handle___197 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___57 {
	struct device___201 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___57 *);
	void (*irq_shutdown)(struct irq_data___57 *);
	void (*irq_enable)(struct irq_data___57 *);
	void (*irq_disable)(struct irq_data___57 *);
	void (*irq_ack)(struct irq_data___57 *);
	void (*irq_mask)(struct irq_data___57 *);
	void (*irq_mask_ack)(struct irq_data___57 *);
	void (*irq_unmask)(struct irq_data___57 *);
	void (*irq_eoi)(struct irq_data___57 *);
	int (*irq_set_affinity)(struct irq_data___57 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___57 *);
	int (*irq_set_type)(struct irq_data___57 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___57 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___57 *);
	void (*irq_bus_sync_unlock)(struct irq_data___57 *);
	void (*irq_cpu_online)(struct irq_data___57 *);
	void (*irq_cpu_offline)(struct irq_data___57 *);
	void (*irq_suspend)(struct irq_data___57 *);
	void (*irq_resume)(struct irq_data___57 *);
	void (*irq_pm_shutdown)(struct irq_data___57 *);
	void (*irq_calc_mask)(struct irq_data___57 *);
	void (*irq_print_chip)(struct irq_data___57 *, struct seq_file___198 *);
	int (*irq_request_resources)(struct irq_data___57 *);
	void (*irq_release_resources)(struct irq_data___57 *);
	void (*irq_compose_msi_msg)(struct irq_data___57 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___57 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___57 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___57 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___57 *, void *);
	void (*ipi_send_single)(struct irq_data___57 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___57 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___57 *);
	void (*irq_nmi_teardown)(struct irq_data___57 *);
	long unsigned int flags;
};

struct irqaction___39 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___39 *next;
	irq_handler_t thread_fn;
	struct task_struct___230 *thread;
	struct irqaction___39 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___55 {
	struct irq_chip___57 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___57 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___55 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___55 *);
	void (*resume)(struct irq_chip_generic___55 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___55 *domain;
	struct list_head list;
	struct irq_chip_type___55 chip_types[0];
};

struct irq_domain_chip_generic___55 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___55 *gc[0];
};

struct kernel_param_ops___207 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___207 *);
	int (*get)(char *, const struct kernel_param___207 *);
	void (*free)(void *);
};

struct kparam_array___207;

struct kernel_param___207 {
	const char *name;
	struct module___207 *mod;
	const struct kernel_param_ops___207 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___207 *arr;
	};
};

struct kparam_array___207 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___207 *ops;
	void *elem;
};

struct module_attribute___207 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___207 *, struct module_kobject___208 *, char *);
	ssize_t (*store)(struct module_attribute___207 *, struct module_kobject___208 *, const char *, size_t);
	void (*setup)(struct module___207 *, const char *);
	int (*test)(struct module___207 *);
	void (*free)(struct module___207 *);
};

struct trace_event_class___75;

struct trace_event_call___75 {
	struct list_head list;
	struct trace_event_class___75 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___37 *prog_array;
	int (*perf_perm)(struct trace_event_call___75 *, struct perf_event___81 *);
};

struct fqdir___46;

struct netns_ipv4___46 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___46 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___43;

struct sk_buff___42;

struct dst_ops___46 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___46 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___43 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___42 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___42 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___42 *);
	int (*local_out)(struct net___46 *, struct sock *, struct sk_buff___42 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___42 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___46 {
	struct dst_ops___46 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___46 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___46 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___46 *fqdir;
};

struct sk_buff_head___41 {
	struct sk_buff___42 *next;
	struct sk_buff___42 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___46 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___46 xfrm4_dst_ops;
	struct dst_ops___46 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___46 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___43 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___46 ipv4;
	struct netns_ipv6___46 ipv6;
	struct netns_ieee802154_lowpan___46 ieee802154_lowpan;
	struct netns_sctp___30 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___41 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___37 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___46 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___153 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___153 *root_cset;
};

struct bio_vec___140 {
	struct page___228 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct sk_buff___42 {
	union {
		struct {
			struct sk_buff___42 *next;
			struct sk_buff___42 *prev;
			union {
				struct net_device___43 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___31 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___42 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct pipe_buf_operations___73;

struct pipe_buffer___73 {
	struct page___228 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___73 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___73 {
	int (*confirm)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
	void (*release)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
	bool (*try_steal)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
	bool (*get)(struct pipe_inode_info___73 *, struct pipe_buffer___73 *);
};

typedef rx_handler_result_t rx_handler_func_t___41(struct sk_buff___42 **);

typedef struct {
	struct net___46 *net;
} possible_net_t___41;

struct netdev_name_node___41;

struct net_device_ops___41;

struct ethtool_ops___17;

struct xfrmdev_ops___41;

struct header_ops___41;

struct netdev_rx_queue___41;

struct netdev_queue___41;

struct dcbnl_rtnl_ops___41;

struct phy_device___4;

struct net_device___43 {
	char name[16];
	struct netdev_name_node___41 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___41 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___17 *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___41 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___41 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___211 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___41 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___41 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___41 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___41 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___41 = 0,
		NETREG_REGISTERED___41 = 1,
		NETREG_UNREGISTERING___41 = 2,
		NETREG_UNREGISTERED___41 = 3,
		NETREG_RELEASED___41 = 4,
		NETREG_DUMMY___41 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___41 = 0,
		RTNL_LINK_INITIALIZING___41 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___43 *);
	struct netpoll_info *npinfo;
	possible_net_t___41 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___201 dev;
	const struct attribute_group___211 *sysfs_groups[4];
	const struct attribute_group___211 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___41 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___4 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___37 xdp_state[3];
	long: 64;
};

struct inet_frags___46;

struct fqdir___46 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___46 *f;
	struct net___46 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___46;

struct inet_frags___46 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___46 *, const void *);
	void (*destructor)(struct inet_frag_queue___46 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___46 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___42 *fragments_tail;
	struct sk_buff___42 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___46 *fqdir;
	struct callback_head rcu;
};

struct seq_operations___198 {
	void * (*start)(struct seq_file___198 *, loff_t *);
	void (*stop)(struct seq_file___198 *, void *);
	void * (*next)(struct seq_file___198 *, void *, loff_t *);
	int (*show)(struct seq_file___198 *, void *);
};

struct dcbnl_rtnl_ops___41 {
	int (*ieee_getets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___43 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___43 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___43 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___43 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___43 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___43 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___43 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___43 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___43 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___43 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___43 *);
	u8 (*setstate)(struct net_device___43 *, u8);
	void (*getpermhwaddr)(struct net_device___43 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___43 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___43 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___43 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___43 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___43 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___43 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___43 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___43 *, int, u8 *);
	void (*setpfccfg)(struct net_device___43 *, int, u8);
	void (*getpfccfg)(struct net_device___43 *, int, u8 *);
	u8 (*setall)(struct net_device___43 *);
	u8 (*getcap)(struct net_device___43 *, int, u8 *);
	int (*getnumtcs)(struct net_device___43 *, int, u8 *);
	int (*setnumtcs)(struct net_device___43 *, int, u8);
	u8 (*getpfcstate)(struct net_device___43 *);
	void (*setpfcstate)(struct net_device___43 *, u8);
	void (*getbcncfg)(struct net_device___43 *, int, u32 *);
	void (*setbcncfg)(struct net_device___43 *, int, u32);
	void (*getbcnrp)(struct net_device___43 *, int, u8 *);
	void (*setbcnrp)(struct net_device___43 *, int, u8);
	int (*setapp)(struct net_device___43 *, u8, u16, u8);
	int (*getapp)(struct net_device___43 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___43 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___43 *, int, u8);
	u8 (*getdcbx)(struct net_device___43 *);
	u8 (*setdcbx)(struct net_device___43 *, u8);
	int (*peer_getappinfo)(struct net_device___43 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___43 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___43 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___43 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___43 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___43 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___44;

typedef int (*bpf_iter_init_seq_priv_t___43)(void *, struct bpf_iter_aux_info___44 *);

struct bpf_map___44;

struct bpf_iter_aux_info___44 {
	struct bpf_map___44 *map;
};

struct bpf_iter_seq_info___43 {
	const struct seq_operations___198 *seq_ops;
	bpf_iter_init_seq_priv_t___43 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___44;

struct bpf_map_ops___43 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___44 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___44 *, struct file___223 *);
	void (*map_free)(struct bpf_map___44 *);
	int (*map_get_next_key)(struct bpf_map___44 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___44 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___44 *, void *);
	int (*map_lookup_batch)(struct bpf_map___44 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___44 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___44 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___44 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___44 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___44 *, void *);
	int (*map_update_elem)(struct bpf_map___44 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___44 *, void *);
	int (*map_push_elem)(struct bpf_map___44 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___44 *, void *);
	int (*map_peek_elem)(struct bpf_map___44 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___44 *, struct file___223 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___44 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___44 *, void *, struct seq_file___198 *);
	int (*map_check_btf)(const struct bpf_map___44 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___44 *, struct bpf_prog_aux___44 *);
	void (*map_poke_untrack)(struct bpf_map___44 *, struct bpf_prog_aux___44 *);
	void (*map_poke_run)(struct bpf_map___44 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___44 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___44 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___44 *, struct vm_area_struct___228 *);
	__poll_t (*map_poll)(struct bpf_map___44 *, struct file___223 *, struct poll_table_struct___148 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___44 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___44 *, const struct bpf_map___44 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___44 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___43 *iter_seq_info;
};

struct bpf_map___44 {
	const struct bpf_map_ops___43 *ops;
	struct bpf_map___44 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___43;

struct bpf_jit_poke_descriptor___43;

struct btf_mod_pair___43;

struct bpf_prog_offload___41;

struct bpf_prog_aux___44 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___43 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___43 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___37 *ops;
	struct bpf_map___44 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___43 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___44 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___41 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___41;

struct bpf_map_dev_ops___41 {
	int (*map_get_next_key)(struct bpf_offloaded_map___41 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___41 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___41 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___41 *, void *);
};

struct bpf_offloaded_map___41 {
	struct bpf_map___44 map;
	struct net_device___43 *netdev;
	const struct bpf_map_dev_ops___41 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___41 {
	struct bpf_prog *prog;
	struct net_device___43 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___43 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___207 *mod;
};

struct bpf_jit_poke_descriptor___43 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___44 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___43 {
	struct btf *btf;
	struct module___207 *module;
};

struct cftype___153;

struct cgroup_subsys___153 {
	struct cgroup_subsys_state___153 * (*css_alloc)(struct cgroup_subsys_state___153 *);
	int (*css_online)(struct cgroup_subsys_state___153 *);
	void (*css_offline)(struct cgroup_subsys_state___153 *);
	void (*css_released)(struct cgroup_subsys_state___153 *);
	void (*css_free)(struct cgroup_subsys_state___153 *);
	void (*css_reset)(struct cgroup_subsys_state___153 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___153 *, int);
	int (*css_extra_stat_show)(struct seq_file___198 *, struct cgroup_subsys_state___153 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___230 *, struct css_set___153 *);
	void (*cancel_fork)(struct task_struct___230 *, struct css_set___153 *);
	void (*fork)(struct task_struct___230 *);
	void (*exit)(struct task_struct___230 *);
	void (*release)(struct task_struct___230 *);
	void (*bind)(struct cgroup_subsys_state___153 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___153 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___153 *dfl_cftypes;
	struct cftype___153 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___153 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___153 *updated_children;
	struct cgroup___153 *updated_next;
};

struct cgroup_root___153 {
	struct kernfs_root___211 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___153 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___153 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___153 *ss;
	struct list_head node;
	struct kernfs_ops___211 *kf_ops;
	int (*open)(struct kernfs_open_file___211 *);
	void (*release)(struct kernfs_open_file___211 *);
	u64 (*read_u64)(struct cgroup_subsys_state___153 *, struct cftype___153 *);
	s64 (*read_s64)(struct cgroup_subsys_state___153 *, struct cftype___153 *);
	int (*seq_show)(struct seq_file___198 *, void *);
	void * (*seq_start)(struct seq_file___198 *, loff_t *);
	void * (*seq_next)(struct seq_file___198 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___198 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___153 *, struct cftype___153 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___153 *, struct cftype___153 *, s64);
	ssize_t (*write)(struct kernfs_open_file___211 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___211 *, struct poll_table_struct___148 *);
};

struct xdp_rxq_info___41 {
	struct net_device___43 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___41 {
	struct net_device___43 *dev;
};

struct xdp_buff___41 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___41 *rxq;
	struct xdp_txq_info___41 *txq;
	u32 frame_sz;
};

struct xdp_frame___41 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___43 *dev_rx;
};

struct netlink_callback___41 {
	struct sk_buff___42 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___42 *, struct netlink_callback___41 *);
	int (*done)(struct netlink_callback___41 *);
	void *data;
	struct module___207 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___41 {
	int (*create)(struct sk_buff___42 *, struct net_device___43 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___42 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___43 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___42 *);
};

struct netdev_queue___41 {
	struct net_device___43 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___211 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___43 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___41 {
	struct xdp_rxq_info___41 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___211 kobj;
	struct net_device___43 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___41 {
	enum net_device_path_type type;
	const struct net_device___43 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___41 = 0,
				DEV_PATH_BR_VLAN_TAG___41 = 1,
				DEV_PATH_BR_VLAN_UNTAG___41 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___41 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___41 {
	const struct net_device___43 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___41 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___37 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___41 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___41 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___42 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___41 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___43 *dev;
	const char *name;
};

struct net_device_ops___41 {
	int (*ndo_init)(struct net_device___43 *);
	void (*ndo_uninit)(struct net_device___43 *);
	int (*ndo_open)(struct net_device___43 *);
	int (*ndo_stop)(struct net_device___43 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___42 *, struct net_device___43 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___42 *, struct net_device___43 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___43 *, struct sk_buff___42 *, struct net_device___43 *);
	void (*ndo_change_rx_flags)(struct net_device___43 *, int);
	void (*ndo_set_rx_mode)(struct net_device___43 *);
	int (*ndo_set_mac_address)(struct net_device___43 *, void *);
	int (*ndo_validate_addr)(struct net_device___43 *);
	int (*ndo_do_ioctl)(struct net_device___43 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___43 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___43 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___43 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___43 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___43 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___43 *, int);
	int (*ndo_neigh_setup)(struct net_device___43 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___43 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___43 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___43 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___43 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___43 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___43 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___43 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___43 *);
	int (*ndo_netpoll_setup)(struct net_device___43 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___43 *);
	int (*ndo_set_vf_mac)(struct net_device___43 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___43 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___43 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___43 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___43 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___43 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___43 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___43 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___43 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___43 *, int, struct sk_buff___42 *);
	int (*ndo_get_vf_guid)(struct net_device___43 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___43 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___43 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___43 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___43 *);
	int (*ndo_fcoe_disable)(struct net_device___43 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___43 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___43 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___43 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___43 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___43 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___43 *, const struct sk_buff___42 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___43 *, struct net_device___43 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___43 *, struct net_device___43 *);
	struct net_device___43 * (*ndo_get_xmit_slave)(struct net_device___43 *, struct sk_buff___42 *, bool);
	struct net_device___43 * (*ndo_sk_get_lower_dev)(struct net_device___43 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___43 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___43 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___43 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___43 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___42 *, struct netlink_callback___41 *, struct net_device___43 *, struct net_device___43 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___42 *, struct nlattr **, struct net_device___43 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___43 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___42 *, u32, u32, struct net_device___43 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___43 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___43 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___43 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___43 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___43 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___43 *, struct net_device___43 *);
	void (*ndo_dfwd_del_station)(struct net_device___43 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___43 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___43 *);
	int (*ndo_change_proto_down)(struct net_device___43 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___43 *, struct sk_buff___42 *);
	void (*ndo_set_rx_headroom)(struct net_device___43 *, int);
	int (*ndo_bpf)(struct net_device___43 *, struct netdev_bpf___41 *);
	int (*ndo_xdp_xmit)(struct net_device___43 *, int, struct xdp_frame___41 **, u32);
	struct net_device___43 * (*ndo_xdp_get_xmit_slave)(struct net_device___43 *, struct xdp_buff___41 *);
	int (*ndo_xsk_wakeup)(struct net_device___43 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___43 *);
	int (*ndo_tunnel_ctl)(struct net_device___43 *, struct ip_tunnel_parm *, int);
	struct net_device___43 * (*ndo_get_peer_dev)(struct net_device___43 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___41 *, struct net_device_path___41 *);
};

struct ethtool_ops___17 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___43 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___43 *);
	void (*get_regs)(struct net_device___43 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___43 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___43 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___43 *);
	void (*set_msglevel)(struct net_device___43 *, u32);
	int (*nway_reset)(struct net_device___43 *);
	u32 (*get_link)(struct net_device___43 *);
	int (*get_link_ext_state)(struct net_device___43 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___43 *);
	int (*get_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___43 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___43 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___43 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___43 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___43 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___43 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___43 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___43 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___43 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___43 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___43 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___43 *);
	void (*complete)(struct net_device___43 *);
	u32 (*get_priv_flags)(struct net_device___43 *);
	int (*set_priv_flags)(struct net_device___43 *, u32);
	int (*get_sset_count)(struct net_device___43 *, int);
	int (*get_rxnfc)(struct net_device___43 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___43 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___43 *, struct ethtool_flash *);
	int (*reset)(struct net_device___43 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___43 *);
	u32 (*get_rxfh_indir_size)(struct net_device___43 *);
	int (*get_rxfh)(struct net_device___43 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___43 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___43 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___43 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___43 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___43 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___43 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___43 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___43 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___43 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___43 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___43 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___43 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___43 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___43 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___43 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___43 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___43 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___43 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___43 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___43 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___43 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___43 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___43 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___43 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___43 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___43 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___43 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___43 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___43 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___43 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct mii_bus___5;

struct mdio_device___5 {
	struct device___201 dev;
	struct mii_bus___5 *bus;
	char modalias[32];
	int (*bus_match)(struct device___201 *, struct device_driver___201 *);
	void (*device_free)(struct mdio_device___5 *);
	void (*device_remove)(struct mdio_device___5 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___4;

struct mii_timestamper___4;

struct phy_device___4 {
	struct mdio_device___5 mdio;
	struct phy_driver___4 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___42 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___43 *attached_dev;
	struct mii_timestamper___4 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___4 *, bool);
	void (*adjust_link)(struct net_device___43 *);
	const struct macsec_ops *macsec_ops;
};

struct property___65 {
	char *name;
	int length;
	void *value;
	struct property___65 *next;
	long unsigned int _flags;
	struct bin_attribute___211 attr;
};

struct irq_fwspec___53 {
	struct fwnode_handle___197 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___55 {
	int (*match)(struct irq_domain___55 *, struct device_node___88 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___55 *, struct irq_fwspec___53 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___55 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___55 *, unsigned int);
	int (*xlate)(struct irq_domain___55 *, struct device_node___88 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___55 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___55 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___55 *, struct irq_data___57 *, bool);
	void (*deactivate)(struct irq_domain___55 *, struct irq_data___57 *);
	int (*translate)(struct irq_domain___55 *, struct irq_fwspec___53 *, long unsigned int *, unsigned int *);
};

struct mii_bus___5 {
	struct module___207 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___5 *, int, int);
	int (*write)(struct mii_bus___5 *, int, int, u16);
	int (*reset)(struct mii_bus___5 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___201 *parent;
	enum {
		MDIOBUS_ALLOCATED___5 = 1,
		MDIOBUS_REGISTERED___5 = 2,
		MDIOBUS_UNREGISTERED___5 = 3,
		MDIOBUS_RELEASED___5 = 4,
	} state;
	struct device___201 dev;
	struct mdio_device___5 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___5 = 0,
		MDIOBUS_C22___5 = 1,
		MDIOBUS_C45___5 = 2,
		MDIOBUS_C22_C45___5 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___5 {
	struct device_driver___201 driver;
	int flags;
};

struct mii_timestamper___4 {
	bool (*rxtstamp)(struct mii_timestamper___4 *, struct sk_buff___42 *, int);
	void (*txtstamp)(struct mii_timestamper___4 *, struct sk_buff___42 *, int);
	int (*hwtstamp)(struct mii_timestamper___4 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___4 *, struct phy_device___4 *);
	int (*ts_info)(struct mii_timestamper___4 *, struct ethtool_ts_info *);
	struct device___201 *device;
};

struct phy_driver___4 {
	struct mdio_driver_common___5 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___4 *);
	int (*config_init)(struct phy_device___4 *);
	int (*probe)(struct phy_device___4 *);
	int (*get_features)(struct phy_device___4 *);
	int (*suspend)(struct phy_device___4 *);
	int (*resume)(struct phy_device___4 *);
	int (*config_aneg)(struct phy_device___4 *);
	int (*aneg_done)(struct phy_device___4 *);
	int (*read_status)(struct phy_device___4 *);
	int (*config_intr)(struct phy_device___4 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___4 *);
	void (*remove)(struct phy_device___4 *);
	int (*match_phy_device)(struct phy_device___4 *);
	int (*set_wol)(struct phy_device___4 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___4 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___4 *);
	int (*read_mmd)(struct phy_device___4 *, int, u16);
	int (*write_mmd)(struct phy_device___4 *, int, u16, u16);
	int (*read_page)(struct phy_device___4 *);
	int (*write_page)(struct phy_device___4 *, int);
	int (*module_info)(struct phy_device___4 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___4 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___4 *);
	int (*cable_test_tdr_start)(struct phy_device___4 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___4 *, bool *);
	int (*get_sset_count)(struct phy_device___4 *);
	void (*get_strings)(struct phy_device___4 *, u8 *);
	void (*get_stats)(struct phy_device___4 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___4 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___4 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___4 *, bool);
	int (*get_sqi)(struct phy_device___4 *);
	int (*get_sqi_max)(struct phy_device___4 *);
};

struct perf_cpu_context___81;

struct perf_output_handle___81;

struct pmu___81 {
	struct list_head entry;
	struct module___207 *module;
	struct device___201 *dev;
	const struct attribute_group___211 **attr_groups;
	const struct attribute_group___211 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___81 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___81 *);
	void (*pmu_disable)(struct pmu___81 *);
	int (*event_init)(struct perf_event___81 *);
	void (*event_mapped)(struct perf_event___81 *, struct mm_struct___229 *);
	void (*event_unmapped)(struct perf_event___81 *, struct mm_struct___229 *);
	int (*add)(struct perf_event___81 *, int);
	void (*del)(struct perf_event___81 *, int);
	void (*start)(struct perf_event___81 *, int);
	void (*stop)(struct perf_event___81 *, int);
	void (*read)(struct perf_event___81 *);
	void (*start_txn)(struct pmu___81 *, unsigned int);
	int (*commit_txn)(struct pmu___81 *);
	void (*cancel_txn)(struct pmu___81 *);
	int (*event_idx)(struct perf_event___81 *);
	void (*sched_task)(struct perf_event_context___81 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___81 *, struct perf_event_context___81 *);
	void * (*setup_aux)(struct perf_event___81 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___81 *, struct perf_output_handle___81 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___81 *);
	int (*aux_output_match)(struct perf_event___81 *);
	int (*filter_match)(struct perf_event___81 *);
	int (*check_period)(struct perf_event___81 *, u64);
};

struct perf_cpu_context___81 {
	struct perf_event_context___81 ctx;
	struct perf_event_context___81 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___81 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___81 **heap;
	struct perf_event___81 *heap_default[2];
};

struct perf_output_handle___81 {
	struct perf_event___81 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___81 {
	struct cgroup_subsys_state___153 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___75 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___75 *);
	};
};

struct trace_event_class___75 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___75 *, enum trace_reg, void *);
	struct trace_event_fields___75 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___75 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___75 *);
};

struct trace_event_file___34;

struct trace_event_buffer___33 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___34 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___34 {
	struct list_head list;
	struct trace_event_call___75 *event_call;
	struct event_filter *filter;
	struct dentry___223 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mdio_access {
	struct trace_entry ent;
	char busid[61];
	char read;
	u8 addr;
	u16 val;
	unsigned int regnum;
	char __data[0];
};

struct trace_event_data_offsets_mdio_access {};

typedef void (*btf_trace_mdio_access)(void *, struct mii_bus___5 *, char, u8, unsigned int, u16, int);

struct mdio_bus_stat_attr {
	int addr;
	unsigned int field_offset;
};

struct mii_bus___6;

struct mdio_device___6 {
	struct device___198 dev;
	struct mii_bus___6 *bus;
	char modalias[32];
	int (*bus_match)(struct device___198 *, struct device_driver___198 *);
	void (*device_free)(struct mdio_device___6 *);
	void (*device_remove)(struct mdio_device___6 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct mii_bus___6 {
	struct module___204 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___6 *, int, int);
	int (*write)(struct mii_bus___6 *, int, int, u16);
	int (*reset)(struct mii_bus___6 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___198 *parent;
	enum {
		MDIOBUS_ALLOCATED___6 = 1,
		MDIOBUS_REGISTERED___6 = 2,
		MDIOBUS_UNREGISTERED___6 = 3,
		MDIOBUS_RELEASED___6 = 4,
	} state;
	struct device___198 dev;
	struct mdio_device___6 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___6 = 0,
		MDIOBUS_C22___6 = 1,
		MDIOBUS_C45___6 = 2,
		MDIOBUS_C22_C45___6 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___6 {
	struct device_driver___198 driver;
	int flags;
};

struct mdio_driver___2 {
	struct mdio_driver_common___6 mdiodrv;
	int (*probe)(struct mdio_device___6 *);
	void (*remove)(struct mdio_device___6 *);
	void (*shutdown)(struct mdio_device___6 *);
};

struct fixed_phy_status {
	int link;
	int speed;
	int duplex;
	int pause;
	int asym_pause;
};

struct swmii_regs {
	u16 bmsr;
	u16 lpa;
	u16 lpagb;
	u16 estat;
};

enum {
	SWMII_SPEED_10 = 0,
	SWMII_SPEED_100 = 1,
	SWMII_SPEED_1000 = 2,
	SWMII_DUPLEX_HALF = 0,
	SWMII_DUPLEX_FULL = 1,
};

struct led_trigger___6;

struct led_classdev___6 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___6 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___6 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___6 *);
	int (*blink_set)(struct led_classdev___6 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___6 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___6 *);
	struct device___178 *dev;
	const struct attribute_group___195 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___6 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___6 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___195 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___6 {
	const char *name;
	int (*activate)(struct led_classdev___6 *);
	void (*deactivate)(struct led_classdev___6 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___195 **groups;
};

struct phy_led_trigger {
	struct led_trigger___6 trigger;
	char name[76];
	unsigned int speed;
};

struct mii_timestamping_ctrl {
	struct mii_timestamper * (*probe_channel)(struct device___199 *, unsigned int);
	void (*release_channel)(struct device___199 *, struct mii_timestamper *);
};

struct mii_timestamping_desc {
	struct list_head list;
	struct mii_timestamping_ctrl *ctrl;
	struct device___199 *device;
};

struct sfp;

struct sfp_socket_ops;

struct sfp_quirk;

struct sfp_upstream_ops___2;

struct sfp_bus {
	struct kref kref;
	struct list_head node;
	struct fwnode_handle___176 *fwnode;
	const struct sfp_socket_ops *socket_ops;
	struct device___178 *sfp_dev;
	struct sfp *sfp;
	const struct sfp_quirk *sfp_quirk;
	const struct sfp_upstream_ops___2 *upstream_ops;
	void *upstream;
	struct phy_device___2 *phydev;
	bool registered;
	bool started;
};

enum {
	SFF8024_ID_UNK = 0,
	SFF8024_ID_SFF_8472 = 2,
	SFF8024_ID_SFP = 3,
	SFF8024_ID_DWDM_SFP = 11,
	SFF8024_ID_QSFP_8438 = 12,
	SFF8024_ID_QSFP_8436_8636 = 13,
	SFF8024_ID_QSFP28_8636 = 17,
	SFF8024_ENCODING_UNSPEC = 0,
	SFF8024_ENCODING_8B10B = 1,
	SFF8024_ENCODING_4B5B = 2,
	SFF8024_ENCODING_NRZ = 3,
	SFF8024_ENCODING_8472_MANCHESTER = 4,
	SFF8024_ENCODING_8472_SONET = 5,
	SFF8024_ENCODING_8472_64B66B = 6,
	SFF8024_ENCODING_8436_MANCHESTER = 6,
	SFF8024_ENCODING_8436_SONET = 4,
	SFF8024_ENCODING_8436_64B66B = 5,
	SFF8024_ENCODING_256B257B = 7,
	SFF8024_ENCODING_PAM4 = 8,
	SFF8024_CONNECTOR_UNSPEC = 0,
	SFF8024_CONNECTOR_SC = 1,
	SFF8024_CONNECTOR_FIBERJACK = 6,
	SFF8024_CONNECTOR_LC = 7,
	SFF8024_CONNECTOR_MT_RJ = 8,
	SFF8024_CONNECTOR_MU = 9,
	SFF8024_CONNECTOR_SG = 10,
	SFF8024_CONNECTOR_OPTICAL_PIGTAIL = 11,
	SFF8024_CONNECTOR_MPO_1X12 = 12,
	SFF8024_CONNECTOR_MPO_2X16 = 13,
	SFF8024_CONNECTOR_HSSDC_II = 32,
	SFF8024_CONNECTOR_COPPER_PIGTAIL = 33,
	SFF8024_CONNECTOR_RJ45 = 34,
	SFF8024_CONNECTOR_NOSEPARATE = 35,
	SFF8024_CONNECTOR_MXC_2X16 = 36,
	SFF8024_ECC_UNSPEC = 0,
	SFF8024_ECC_100G_25GAUI_C2M_AOC = 1,
	SFF8024_ECC_100GBASE_SR4_25GBASE_SR = 2,
	SFF8024_ECC_100GBASE_LR4_25GBASE_LR = 3,
	SFF8024_ECC_100GBASE_ER4_25GBASE_ER = 4,
	SFF8024_ECC_100GBASE_SR10 = 5,
	SFF8024_ECC_100GBASE_CR4 = 11,
	SFF8024_ECC_25GBASE_CR_S = 12,
	SFF8024_ECC_25GBASE_CR_N = 13,
	SFF8024_ECC_10GBASE_T_SFI = 22,
	SFF8024_ECC_10GBASE_T_SR = 28,
	SFF8024_ECC_5GBASE_T = 29,
	SFF8024_ECC_2_5GBASE_T = 30,
};

struct sfp_upstream_ops___2 {
	void (*attach)(void *, struct sfp_bus *);
	void (*detach)(void *, struct sfp_bus *);
	int (*module_insert)(void *, const struct sfp_eeprom_id *);
	void (*module_remove)(void *);
	int (*module_start)(void *);
	void (*module_stop)(void *);
	void (*link_down)(void *);
	void (*link_up)(void *);
	int (*connect_phy)(void *, struct phy_device___2 *);
	void (*disconnect_phy)(void *);
};

struct sfp_socket_ops {
	void (*attach)(struct sfp *);
	void (*detach)(struct sfp *);
	void (*start)(struct sfp *);
	void (*stop)(struct sfp *);
	int (*module_info)(struct sfp *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct sfp *, struct ethtool_eeprom *, u8 *);
	int (*module_eeprom_by_page)(struct sfp *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
};

struct sfp_quirk {
	const char *vendor;
	const char *part;
	void (*modes)(const struct sfp_eeprom_id *, long unsigned int *);
};

struct mdio_device_id {
	__u32 phy_id;
	__u32 phy_id_mask;
};

enum {
	MDIO_AN_C22 = 65504,
};

struct platform_device___36 {
	const char *name;
	int id;
	bool id_auto;
	struct device___178 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_device_info___7 {
	struct device___178 *parent;
	struct fwnode_handle___176 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct fixed_mdio_bus {
	struct mii_bus___2 *mii_bus;
	struct list_head phys;
};

struct fixed_phy {
	int addr;
	struct phy_device___2 *phydev;
	struct fixed_phy_status status;
	bool no_carrier;
	int (*link_update)(struct net_device___40 *, struct fixed_phy_status *);
	struct list_head node;
	struct gpio_desc *link_gpiod;
};

struct acpi_device___18;

struct acpi_hotplug_profile___18 {
	struct kobject___200 kobj;
	int (*scan_dependent)(struct acpi_device___18 *);
	void (*notify_online)(struct acpi_device___18 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___18 {
	void (*func)(struct acpi_device_wakeup_context___18 *);
	struct device___190 *dev;
};

struct acpi_device_wakeup___18 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___18 context;
	struct wakeup_source___190 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___18;

struct acpi_hotplug_context___18;

struct acpi_driver___18;

struct acpi_device___18 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___186 fwnode;
	struct acpi_device___18 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___18 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___18 *handler;
	struct acpi_hotplug_context___18 *hp;
	struct acpi_driver___18 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___190 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___18 *);
};

struct acpi_scan_handler___18 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___18 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___18 *);
	void (*bind)(struct device___190 *);
	void (*unbind)(struct device___190 *);
	struct acpi_hotplug_profile___18 hotplug;
};

struct acpi_hotplug_context___18 {
	struct acpi_device___18 *self;
	int (*notify)(struct acpi_device___18 *, u32);
	void (*uevent)(struct acpi_device___18 *, u32);
	void (*fixup)(struct acpi_device___18 *);
};

typedef int (*acpi_op_add___18)(struct acpi_device___18 *);

typedef int (*acpi_op_remove___18)(struct acpi_device___18 *);

typedef void (*acpi_op_notify___18)(struct acpi_device___18 *, u32);

struct acpi_device_ops___18 {
	acpi_op_add___18 add;
	acpi_op_remove___18 remove;
	acpi_op_notify___18 notify;
};

struct acpi_driver___18 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___18 ops;
	struct device_driver___190 drv;
	struct module___196 *owner;
};

struct mii_bus___7;

struct mdio_device___7 {
	struct device___190 dev;
	struct mii_bus___7 *bus;
	char modalias[32];
	int (*bus_match)(struct device___190 *, struct device_driver___190 *);
	void (*device_free)(struct mdio_device___7 *);
	void (*device_remove)(struct mdio_device___7 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct mii_bus___7 {
	struct module___196 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___7 *, int, int);
	int (*write)(struct mii_bus___7 *, int, int, u16);
	int (*reset)(struct mii_bus___7 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___190 *parent;
	enum {
		MDIOBUS_ALLOCATED___7 = 1,
		MDIOBUS_REGISTERED___7 = 2,
		MDIOBUS_UNREGISTERED___7 = 3,
		MDIOBUS_RELEASED___7 = 4,
	} state;
	struct device___190 dev;
	struct mdio_device___7 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___7 = 0,
		MDIOBUS_C22___7 = 1,
		MDIOBUS_C45___7 = 2,
		MDIOBUS_C22_C45___7 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct of_phandle_args___37 {
	struct device_node___87 *np;
	int args_count;
	uint32_t args[16];
};

struct mdio_mux_child_bus;

struct mdio_mux_parent_bus {
	struct mii_bus___7 *mii_bus;
	int current_child;
	int parent_id;
	void *switch_data;
	int (*switch_fn)(int, int, void *);
	struct mdio_mux_child_bus *children;
};

struct mdio_mux_child_bus {
	struct mii_bus___7 *mii_bus;
	struct mdio_mux_parent_bus *parent;
	struct mdio_mux_child_bus *next;
	int bus_number;
};

struct platform_device___37 {
	const char *name;
	int id;
	bool id_auto;
	struct device___141 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___31 {
	int (*probe)(struct platform_device___37 *);
	int (*remove)(struct platform_device___37 *);
	void (*shutdown)(struct platform_device___37 *);
	int (*suspend)(struct platform_device___37 *, pm_message_t);
	int (*resume)(struct platform_device___37 *);
	struct device_driver___141 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct iproc_mdiomux_desc {
	void *mux_handle;
	void *base;
	struct device___141 *dev;
	struct mii_bus___7 *mii_bus;
	struct clk *core_clk;
};

struct dentry___224;

struct super_block___224;

struct module___208;

struct file_system_type___224 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___224 * (*mount)(struct file_system_type___224 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___224 *);
	struct module___208 *owner;
	struct file_system_type___224 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___224;

struct kiocb___224;

struct iov_iter___144;

struct poll_table_struct___149;

struct vm_area_struct___229;

struct inode___224;

struct file_lock___224;

struct page___229;

struct pipe_inode_info___74;

struct seq_file___199;

struct file_operations___225 {
	struct module___208 *owner;
	loff_t (*llseek)(struct file___224 *, loff_t, int);
	ssize_t (*read)(struct file___224 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___224 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___224 *, struct iov_iter___144 *);
	ssize_t (*write_iter)(struct kiocb___224 *, struct iov_iter___144 *);
	int (*iopoll)(struct kiocb___224 *, bool);
	int (*iterate)(struct file___224 *, struct dir_context *);
	int (*iterate_shared)(struct file___224 *, struct dir_context *);
	__poll_t (*poll)(struct file___224 *, struct poll_table_struct___149 *);
	long int (*unlocked_ioctl)(struct file___224 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___224 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___224 *, struct vm_area_struct___229 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___224 *, struct file___224 *);
	int (*flush)(struct file___224 *, fl_owner_t);
	int (*release)(struct inode___224 *, struct file___224 *);
	int (*fsync)(struct file___224 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___224 *, int);
	int (*lock)(struct file___224 *, int, struct file_lock___224 *);
	ssize_t (*sendpage)(struct file___224 *, struct page___229 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___224 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___224 *, long unsigned int);
	int (*flock)(struct file___224 *, int, struct file_lock___224 *);
	ssize_t (*splice_write)(struct pipe_inode_info___74 *, struct file___224 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___224 *, loff_t *, struct pipe_inode_info___74 *, size_t, unsigned int);
	int (*setlease)(struct file___224 *, long int, struct file_lock___224 **, void **);
	long int (*fallocate)(struct file___224 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___199 *, struct file___224 *);
	ssize_t (*copy_file_range)(struct file___224 *, loff_t, struct file___224 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___224 *, loff_t, struct file___224 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___224 *, loff_t, loff_t, int);
};

struct vmacache___229 {
	u64 seqnum;
	struct vm_area_struct___229 *vmas[4];
};

struct page_frag___229 {
	struct page___229 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___230;

struct pid___201;

struct nsproxy___210;

struct signal_struct___225;

struct bio_list___117;

struct backing_dev_info___106;

struct io_context___117;

struct css_set___154;

struct mem_cgroup___97;

struct request_queue___117;

struct vm_struct___207;

struct task_struct___231 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___231 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___230 *mm;
	struct mm_struct___230 *active_mm;
	struct vmacache___229 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___231 *real_parent;
	struct task_struct___231 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___231 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___201 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___210 *nsproxy;
	struct signal_struct___225 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___231 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___117 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___106 *backing_dev_info;
	struct io_context___117 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___154 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___74 *splice_pipe;
	struct page_frag___229 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___97 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___97 *active_memcg;
	struct request_queue___117 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___231 *oom_reaper_list;
	struct vm_struct___207 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___212;

struct kobj_type___212;

struct kernfs_node___212;

struct kobject___212 {
	const char *name;
	struct list_head entry;
	struct kobject___212 *parent;
	struct kset___212 *kset;
	struct kobj_type___212 *ktype;
	struct kernfs_node___212 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___209 {
	struct kobject___212 kobj;
	struct module___208 *mod;
	struct kobject___212 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___208 {
	struct module___208 *mod;
	struct latch_tree_node node;
};

struct module_layout___208 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___208 mtn;
};

struct module_attribute___208;

struct kernel_param___208;

struct module___208 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___209 mkobj;
	struct module_attribute___208 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___212 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___208 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___208 core_layout;
	struct module_layout___208 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___201;

struct upid___201 {
	int nr;
	struct pid_namespace___201 *ns;
};

struct pid_namespace___201 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___231 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___201 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___201 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___201 numbers[1];
};

typedef struct page___229 *pgtable_t___229;

struct address_space___224;

struct page_pool___62;

struct dev_pagemap___219;

struct page___229 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___224 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___62 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___229 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___229 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___230 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___219 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___219;

struct vm_area_struct___229 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___229 *vm_next;
	struct vm_area_struct___229 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___230 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___219 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___224 *vm_file;
	struct file___224 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___225 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___231 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___231 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___201 *pids[4];
	struct pid___201 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___230 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___229;

struct mm_struct___230 {
	struct {
		struct vm_area_struct___229 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___224 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___229 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___231 *owner;
		struct user_namespace___14 *user_ns;
		struct file___224 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___47;

struct cgroup_namespace___154;

struct nsproxy___210 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___201 *pid_ns_for_children;
	struct net___47 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___154 *cgroup_ns;
};

struct bio___117;

struct bio_list___117 {
	struct bio___117 *head;
	struct bio___117 *tail;
};

struct cgroup_subsys_state___154;

struct bdi_writeback___106 {
	struct backing_dev_info___106 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___154 *memcg_css;
	struct cgroup_subsys_state___154 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___202;

struct backing_dev_info___106 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___106 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___202 *dev;
	char dev_name[64];
	struct device___202 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___224 *debug_dir;
};

struct io_cq___117;

struct io_context___117 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___117 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___154;

struct css_set___154 {
	struct cgroup_subsys_state___154 *subsys[14];
	refcount_t refcount;
	struct css_set___154 *dom_cset;
	struct cgroup___154 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___154 *mg_src_cgrp;
	struct cgroup___154 *mg_dst_cgrp;
	struct css_set___154 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___224;

struct pipe_buffer___74;

struct pipe_inode_info___74 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___229 *tmp_page;
	struct fasync_struct___224 *fasync_readers;
	struct fasync_struct___224 *fasync_writers;
	struct pipe_buffer___74 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___154;

struct cgroup_subsys_state___154 {
	struct cgroup___154 *cgroup;
	struct cgroup_subsys___154 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___154 *parent;
};

struct cgroup_file___154 {
	struct kernfs_node___212 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___97;

struct mem_cgroup_per_node___97;

struct mem_cgroup___97 {
	struct cgroup_subsys_state___154 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___154 events_file;
	struct cgroup_file___154 events_local_file;
	struct cgroup_file___154 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___97 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___231 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___97 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___117;

struct blk_integrity___117 {
	const struct blk_integrity_profile___117 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___117 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___117 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___117;

struct elevator_queue___117;

struct blk_mq_ops___114;

struct blk_mq_hw_ctx___114;

struct gendisk___120;

struct blkcg_gq___108;

struct blk_mq_tag_set___114;

struct request_queue___117 {
	struct request___117 *last_merge;
	struct elevator_queue___117 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___114 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___114 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___120 *disk;
	struct kobject___212 kobj;
	struct kobject___212 *mq_kobj;
	struct blk_integrity___117 integrity;
	struct device___202 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___108 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___114 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___117 bio_split;
	struct dentry___224 *debugfs_dir;
	struct dentry___224 *sched_debugfs_dir;
	struct dentry___224 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___207 {
	struct vm_struct___207 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___229 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___224;

struct address_space___224 {
	struct inode___224 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___224 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___62 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___202 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___62 {
	u32 count;
	struct page___229 *cache[128];
};

struct page_pool___62 {
	struct page_pool_params___62 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___229 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___62 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___219;

struct dev_pagemap___219 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___219 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___224;

struct path___224 {
	struct vfsmount___224 *mnt;
	struct dentry___224 *dentry;
};

struct fown_struct___201 {
	rwlock_t lock;
	struct pid___201 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___224 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___224 f_path;
	struct inode___224 *f_inode;
	const struct file_operations___225 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___201 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___224 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___219;

struct vm_operations_struct___219 {
	void (*open)(struct vm_area_struct___229 *);
	void (*close)(struct vm_area_struct___229 *);
	int (*may_split)(struct vm_area_struct___229 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___229 *);
	int (*mprotect)(struct vm_area_struct___229 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___219 *);
	vm_fault_t (*huge_fault)(struct vm_fault___219 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___219 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___229 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___219 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___219 *);
	int (*access)(struct vm_area_struct___229 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___229 *);
	int (*set_policy)(struct vm_area_struct___229 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___229 *, long unsigned int);
	struct page___229 * (*find_special_page)(struct vm_area_struct___229 *, long unsigned int);
};

struct core_thread___229 {
	struct task_struct___231 *task;
	struct core_thread___229 *next;
};

struct core_state___229 {
	atomic_t nr_threads;
	struct core_thread___229 dumper;
	struct completion startup;
};

struct vm_fault___219 {
	const struct {
		struct vm_area_struct___229 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___229 *cow_page;
	struct page___229 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___229 prealloc_pte;
};

struct pglist_data___105;

struct lruvec___105 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___105 *pgdat;
};

struct zone___105 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___105 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___105 {
	struct zone___105 *zone;
	int zone_idx;
};

struct zonelist___105 {
	struct zoneref___105 _zonerefs[321];
};

struct pglist_data___105 {
	struct zone___105 node_zones[5];
	struct zonelist___105 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___231 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___231 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___105 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___224;

struct dentry___224 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___224 *d_parent;
	struct qstr d_name;
	struct inode___224 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___224 *d_op;
	struct super_block___224 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___224;

struct inode___224 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___224 *i_op;
	struct super_block___224 *i_sb;
	struct address_space___224 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___106 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___225 *i_fop;
		void (*free_inode)(struct inode___224 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___224 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___74 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___224 {
	int (*d_revalidate)(struct dentry___224 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___224 *, unsigned int);
	int (*d_hash)(const struct dentry___224 *, struct qstr *);
	int (*d_compare)(const struct dentry___224 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___224 *);
	int (*d_init)(struct dentry___224 *);
	void (*d_release)(struct dentry___224 *);
	void (*d_prune)(struct dentry___224 *);
	void (*d_iput)(struct dentry___224 *, struct inode___224 *);
	char * (*d_dname)(struct dentry___224 *, char *, int);
	struct vfsmount___224 * (*d_automount)(struct path___224 *);
	int (*d_manage)(const struct path___224 *, bool);
	struct dentry___224 * (*d_real)(struct dentry___224 *, const struct inode___224 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___224;

struct mem_dqinfo___224 {
	struct quota_format_type___224 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___224;

struct quota_info___224 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___224 *files[3];
	struct mem_dqinfo___224 info[3];
	const struct quota_format_ops___224 *ops[3];
};

struct rcuwait___225 {
	struct task_struct___231 *task;
};

struct percpu_rw_semaphore___225 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___225 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___224 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___225 rw_sem[3];
};

struct shrink_control___97;

struct shrinker___97 {
	long unsigned int (*count_objects)(struct shrinker___97 *, struct shrink_control___97 *);
	long unsigned int (*scan_objects)(struct shrinker___97 *, struct shrink_control___97 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___224;

struct dquot_operations___224;

struct quotactl_ops___224;

struct block_device___120;

struct super_block___224 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___224 *s_type;
	const struct super_operations___224 *s_op;
	const struct dquot_operations___224 *dq_op;
	const struct quotactl_ops___224 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___224 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___120 *s_bdev;
	struct backing_dev_info___106 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___224 s_dquot;
	struct sb_writers___224 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___224 *s_d_op;
	int cleancache_poolid;
	struct shrinker___97 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___224 {
	struct dentry___224 *mnt_root;
	struct super_block___224 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___97 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___97 *memcg;
};

struct psi_group___154 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___231 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___38;

struct cgroup_bpf___38 {
	struct bpf_prog_array___38 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___38 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___154;

struct cgroup_rstat_cpu___154;

struct cgroup___154 {
	struct cgroup_subsys_state___154 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___212 *kn;
	struct cgroup_file___154 procs_file;
	struct cgroup_file___154 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___154 *subsys[14];
	struct cgroup_root___154 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___154 *dom_cgrp;
	struct cgroup___154 *old_dom_cgrp;
	struct cgroup_rstat_cpu___154 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___154 psi;
	struct cgroup_bpf___38 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___117 {
	struct request_queue___117 *q;
	struct io_context___117 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___224 {
	struct file___224 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___224 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___224 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___224 *ia_file;
};

struct dquot___224 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___224 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___224 {
	int qf_fmt_id;
	const struct quota_format_ops___224 *qf_ops;
	struct module___208 *qf_owner;
	struct quota_format_type___224 *qf_next;
};

struct quota_format_ops___224 {
	int (*check_quota_file)(struct super_block___224 *, int);
	int (*read_file_info)(struct super_block___224 *, int);
	int (*write_file_info)(struct super_block___224 *, int);
	int (*free_file_info)(struct super_block___224 *, int);
	int (*read_dqblk)(struct dquot___224 *);
	int (*commit_dqblk)(struct dquot___224 *);
	int (*release_dqblk)(struct dquot___224 *);
	int (*get_next_id)(struct super_block___224 *, struct kqid *);
};

struct dquot_operations___224 {
	int (*write_dquot)(struct dquot___224 *);
	struct dquot___224 * (*alloc_dquot)(struct super_block___224 *, int);
	void (*destroy_dquot)(struct dquot___224 *);
	int (*acquire_dquot)(struct dquot___224 *);
	int (*release_dquot)(struct dquot___224 *);
	int (*mark_dirty)(struct dquot___224 *);
	int (*write_info)(struct super_block___224 *, int);
	qsize_t * (*get_reserved_space)(struct inode___224 *);
	int (*get_projid)(struct inode___224 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___224 *, qsize_t *);
	int (*get_next_id)(struct super_block___224 *, struct kqid *);
};

struct quotactl_ops___224 {
	int (*quota_on)(struct super_block___224 *, int, int, const struct path___224 *);
	int (*quota_off)(struct super_block___224 *, int);
	int (*quota_enable)(struct super_block___224 *, unsigned int);
	int (*quota_disable)(struct super_block___224 *, unsigned int);
	int (*quota_sync)(struct super_block___224 *, int);
	int (*set_info)(struct super_block___224 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___224 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___224 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___224 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___224 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___224 *, unsigned int);
};

struct writeback_control___106;

struct address_space_operations___224 {
	int (*writepage)(struct page___229 *, struct writeback_control___106 *);
	int (*readpage)(struct file___224 *, struct page___229 *);
	int (*writepages)(struct address_space___224 *, struct writeback_control___106 *);
	int (*set_page_dirty)(struct page___229 *);
	int (*readpages)(struct file___224 *, struct address_space___224 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___224 *, struct address_space___224 *, loff_t, unsigned int, unsigned int, struct page___229 **, void **);
	int (*write_end)(struct file___224 *, struct address_space___224 *, loff_t, unsigned int, unsigned int, struct page___229 *, void *);
	sector_t (*bmap)(struct address_space___224 *, sector_t);
	void (*invalidatepage)(struct page___229 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___229 *, gfp_t);
	void (*freepage)(struct page___229 *);
	ssize_t (*direct_IO)(struct kiocb___224 *, struct iov_iter___144 *);
	int (*migratepage)(struct address_space___224 *, struct page___229 *, struct page___229 *, enum migrate_mode);
	bool (*isolate_page)(struct page___229 *, isolate_mode_t);
	void (*putback_page)(struct page___229 *);
	int (*launder_page)(struct page___229 *);
	int (*is_partially_uptodate)(struct page___229 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___229 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___224 *, struct page___229 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___224 *, sector_t *);
	void (*swap_deactivate)(struct file___224 *);
};

struct writeback_control___106 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___106 *wb;
	struct inode___224 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___141;

struct iov_iter___144 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___141 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___74 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___224 {
	struct dentry___224 * (*lookup)(struct inode___224 *, struct dentry___224 *, unsigned int);
	const char * (*get_link)(struct dentry___224 *, struct inode___224 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___224 *, int);
	struct posix_acl * (*get_acl)(struct inode___224 *, int, bool);
	int (*readlink)(struct dentry___224 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___224 *, struct dentry___224 *, umode_t, bool);
	int (*link)(struct dentry___224 *, struct inode___224 *, struct dentry___224 *);
	int (*unlink)(struct inode___224 *, struct dentry___224 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___224 *, struct dentry___224 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___224 *, struct dentry___224 *, umode_t);
	int (*rmdir)(struct inode___224 *, struct dentry___224 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___224 *, struct dentry___224 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___224 *, struct dentry___224 *, struct inode___224 *, struct dentry___224 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___224 *, struct iattr___224 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___224 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___224 *, char *, size_t);
	int (*fiemap)(struct inode___224 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___224 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___224 *, struct dentry___224 *, struct file___224 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___224 *, struct dentry___224 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___224 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___224 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___224 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___224 {
	void (*fl_copy_lock)(struct file_lock___224 *, struct file_lock___224 *);
	void (*fl_release_private)(struct file_lock___224 *);
};

struct lock_manager_operations___224;

struct file_lock___224 {
	struct file_lock___224 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___224 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___224 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___224 *fl_ops;
	const struct lock_manager_operations___224 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___224 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___224 *);
	int (*lm_grant)(struct file_lock___224 *, int);
	bool (*lm_break)(struct file_lock___224 *);
	int (*lm_change)(struct file_lock___224 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___224 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___224 *);
};

struct fasync_struct___224 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___224 *fa_next;
	struct file___224 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___224 {
	struct inode___224 * (*alloc_inode)(struct super_block___224 *);
	void (*destroy_inode)(struct inode___224 *);
	void (*free_inode)(struct inode___224 *);
	void (*dirty_inode)(struct inode___224 *, int);
	int (*write_inode)(struct inode___224 *, struct writeback_control___106 *);
	int (*drop_inode)(struct inode___224 *);
	void (*evict_inode)(struct inode___224 *);
	void (*put_super)(struct super_block___224 *);
	int (*sync_fs)(struct super_block___224 *, int);
	int (*freeze_super)(struct super_block___224 *);
	int (*freeze_fs)(struct super_block___224 *);
	int (*thaw_super)(struct super_block___224 *);
	int (*unfreeze_fs)(struct super_block___224 *);
	int (*statfs)(struct dentry___224 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___224 *, int *, char *);
	void (*umount_begin)(struct super_block___224 *);
	int (*show_options)(struct seq_file___199 *, struct dentry___224 *);
	int (*show_devname)(struct seq_file___199 *, struct dentry___224 *);
	int (*show_path)(struct seq_file___199 *, struct dentry___224 *);
	int (*show_stats)(struct seq_file___199 *, struct dentry___224 *);
	ssize_t (*quota_read)(struct super_block___224 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___224 *, int, const char *, size_t, loff_t);
	struct dquot___224 ** (*get_dquots)(struct inode___224 *);
	long int (*nr_cached_objects)(struct super_block___224 *, struct shrink_control___97 *);
	long int (*free_cached_objects)(struct super_block___224 *, struct shrink_control___97 *);
	struct file___224 * (*real_loop)(struct file___224 *);
};

struct wakeup_source___202;

struct dev_pm_info___202 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___202 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___202 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___202;

struct bus_type___202;

struct device_driver___202;

struct dev_pm_domain___202;

struct fwnode_handle___198;

struct class___202;

struct attribute_group___212;

struct device___202 {
	struct kobject___212 kobj;
	struct device___202 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___202 *type;
	struct bus_type___202 *bus;
	struct device_driver___202 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___202 power;
	struct dev_pm_domain___202 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___198 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___202 *class;
	const struct attribute_group___212 **groups;
	void (*release)(struct device___202 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___120 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___224 *bd_inode;
	struct super_block___224 *bd_super;
	void *bd_claiming;
	struct device___202 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___212 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___120 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___224 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___156)(struct file___224 *, wait_queue_head_t *, struct poll_table_struct___149 *);

struct poll_table_struct___149 {
	poll_queue_proc___156 _qproc;
	__poll_t _key;
};

struct seq_operations___199;

struct seq_file___199 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___199 *op;
	int poll_event;
	const struct file___224 *file;
	void *private;
};

typedef void bio_end_io_t___117(struct bio___117 *);

struct bio_vec___141 {
	struct page___229 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___117;

struct bio___117 {
	struct bio___117 *bi_next;
	struct block_device___120 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___117 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___108 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___117 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___141 *bi_io_vec;
	struct bio_set___117 *bi_pool;
	struct bio_vec___141 bi_inline_vecs[0];
};

struct kernfs_root___212;

struct kernfs_elem_dir___212 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___212 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___212;

struct kernfs_root___212 {
	struct kernfs_node___212 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___212 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___212 {
	struct kernfs_node___212 *target_kn;
};

struct kernfs_ops___212;

struct kernfs_elem_attr___212 {
	const struct kernfs_ops___212 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___212 *notify_next;
};

struct kernfs_node___212 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___212 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___212 dir;
		struct kernfs_elem_symlink___212 symlink;
		struct kernfs_elem_attr___212 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___212;

struct kernfs_ops___212 {
	int (*open)(struct kernfs_open_file___212 *);
	void (*release)(struct kernfs_open_file___212 *);
	int (*seq_show)(struct seq_file___199 *, void *);
	void * (*seq_start)(struct seq_file___199 *, loff_t *);
	void * (*seq_next)(struct seq_file___199 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___199 *, void *);
	ssize_t (*read)(struct kernfs_open_file___212 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___212 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___212 *, struct poll_table_struct___149 *);
	int (*mmap)(struct kernfs_open_file___212 *, struct vm_area_struct___229 *);
};

struct kernfs_syscall_ops___212 {
	int (*show_options)(struct seq_file___199 *, struct kernfs_root___212 *);
	int (*mkdir)(struct kernfs_node___212 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___212 *);
	int (*rename)(struct kernfs_node___212 *, struct kernfs_node___212 *, const char *);
	int (*show_path)(struct seq_file___199 *, struct kernfs_node___212 *, struct kernfs_root___212 *);
};

struct kernfs_open_file___212 {
	struct kernfs_node___212 *kn;
	struct file___224 *file;
	struct seq_file___199 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___219 *vm_ops;
};

struct sock___32;

struct kobj_ns_type_operations___31 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___32 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___47 *net;
} possible_net_t___42;

struct proto___31;

struct sock_common___31 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___31 *skc_prot;
	possible_net_t___42 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___32 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___43;

struct sk_buff_head___42 {
	struct sk_buff___43 *next;
	struct sk_buff___43 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___31 {
	struct cgroup___154 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___31;

struct socket_wq___32;

struct dst_entry___31;

struct socket___33;

struct net_device___44;

struct sock___32 {
	struct sock_common___31 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___42 sk_error_queue;
	struct sk_buff___43 *sk_rx_skb_cache;
	struct sk_buff_head___42 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___43 *head;
		struct sk_buff___43 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___31 *sk_filter;
	union {
		struct socket_wq___32 *sk_wq;
		struct socket_wq___32 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___31 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___31 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___43 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___43 *sk_tx_skb_cache;
	struct sk_buff_head___42 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___229 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___31 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___201 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___33 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___31 sk_cgrp_data;
	struct mem_cgroup___97 *sk_memcg;
	void (*sk_state_change)(struct sock___32 *);
	void (*sk_data_ready)(struct sock___32 *);
	void (*sk_write_space)(struct sock___32 *);
	void (*sk_error_report)(struct sock___32 *);
	int (*sk_backlog_rcv)(struct sock___32 *, struct sk_buff___43 *);
	struct sk_buff___43 * (*sk_validate_xmit_skb)(struct sock___32 *, struct net_device___44 *, struct sk_buff___43 *);
	void (*sk_destruct)(struct sock___32 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___212;

struct attribute_group___212 {
	const char *name;
	umode_t (*is_visible)(struct kobject___212 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___212 *, struct bin_attribute___212 *, int);
	struct attribute **attrs;
	struct bin_attribute___212 **bin_attrs;
};

struct bin_attribute___212 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___224 * (*f_mapping)();
	ssize_t (*read)(struct file___224 *, struct kobject___212 *, struct bin_attribute___212 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___224 *, struct kobject___212 *, struct bin_attribute___212 *, char *, loff_t, size_t);
	int (*mmap)(struct file___224 *, struct kobject___212 *, struct bin_attribute___212 *, struct vm_area_struct___229 *);
};

struct sysfs_ops___212 {
	ssize_t (*show)(struct kobject___212 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___212 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___212;

struct kset___212 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___212 kobj;
	const struct kset_uevent_ops___212 *uevent_ops;
};

struct kobj_type___212 {
	void (*release)(struct kobject___212 *);
	const struct sysfs_ops___212 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___212 **default_groups;
	const struct kobj_ns_type_operations___31 * (*child_ns_type)(struct kobject___212 *);
	const void * (*namespace)(struct kobject___212 *);
	void (*get_ownership)(struct kobject___212 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___212 {
	int (* const filter)(struct kset___212 *, struct kobject___212 *);
	const char * (* const name)(struct kset___212 *, struct kobject___212 *);
	int (* const uevent)(struct kset___212 *, struct kobject___212 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___208 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___208 *);
	int (*get)(char *, const struct kernel_param___208 *);
	void (*free)(void *);
};

struct kparam_array___208;

struct kernel_param___208 {
	const char *name;
	struct module___208 *mod;
	const struct kernel_param_ops___208 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___208 *arr;
	};
};

struct kparam_array___208 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___208 *ops;
	void *elem;
};

struct module_attribute___208 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___208 *, struct module_kobject___209 *, char *);
	ssize_t (*store)(struct module_attribute___208 *, struct module_kobject___209 *, const char *, size_t);
	void (*setup)(struct module___208 *, const char *);
	int (*test)(struct module___208 *);
	void (*free)(struct module___208 *);
};

typedef struct poll_table_struct___149 poll_table___40;

struct dev_pagemap_ops___219 {
	void (*page_free)(struct page___229 *);
	void (*kill)(struct dev_pagemap___219 *);
	void (*cleanup)(struct dev_pagemap___219 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___219 *);
};

struct fwnode_operations___198;

struct fwnode_handle___198 {
	struct fwnode_handle___198 *secondary;
	const struct fwnode_operations___198 *ops;
	struct device___202 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___198;

struct fwnode_endpoint___198;

struct fwnode_operations___198 {
	struct fwnode_handle___198 * (*get)(struct fwnode_handle___198 *);
	void (*put)(struct fwnode_handle___198 *);
	bool (*device_is_available)(const struct fwnode_handle___198 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___198 *, const struct device___202 *);
	bool (*property_present)(const struct fwnode_handle___198 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___198 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___198 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___198 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*get_parent)(const struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*get_next_child_node)(const struct fwnode_handle___198 *, struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*get_named_child_node)(const struct fwnode_handle___198 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___198 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___198 *);
	struct fwnode_handle___198 * (*graph_get_next_endpoint)(const struct fwnode_handle___198 *, struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*graph_get_remote_endpoint)(const struct fwnode_handle___198 *);
	struct fwnode_handle___198 * (*graph_get_port_parent)(struct fwnode_handle___198 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___198 *, struct fwnode_endpoint___198 *);
	int (*add_links)(struct fwnode_handle___198 *);
};

struct fwnode_endpoint___198 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___198 *local_fwnode;
};

struct fwnode_reference_args___198 {
	struct fwnode_handle___198 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___31;

struct fqdir___47;

struct fib_notifier_ops___31;

struct netns_ipv4___47 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___31 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___32 *fibnl;
	struct sock___32 **icmp_sk;
	struct sock___32 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___32 **tcp_sk;
	struct fqdir___47 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___31 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___31 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___31 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___31;

struct dst_ops___47 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___47 *);
	struct dst_entry___31 * (*check)(struct dst_entry___31 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___31 *);
	unsigned int (*mtu)(const struct dst_entry___31 *);
	u32 * (*cow_metrics)(struct dst_entry___31 *, long unsigned int);
	void (*destroy)(struct dst_entry___31 *);
	void (*ifdown)(struct dst_entry___31 *, struct net_device___44 *, int);
	struct dst_entry___31 * (*negative_advice)(struct dst_entry___31 *);
	void (*link_failure)(struct sk_buff___43 *);
	void (*update_pmtu)(struct dst_entry___31 *, struct sock___32 *, struct sk_buff___43 *, u32, bool);
	void (*redirect)(struct dst_entry___31 *, struct sock___32 *, struct sk_buff___43 *);
	int (*local_out)(struct net___47 *, struct sock___32 *, struct sk_buff___43 *);
	struct neighbour___31 * (*neigh_lookup)(const struct dst_entry___31 *, struct sk_buff___43 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___31 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___2;

struct rt6_info___2;

struct fib6_table___2;

struct netns_ipv6___47 {
	struct dst_ops___47 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___47 *fqdir;
	struct fib6_info___2 *fib6_null_entry;
	struct rt6_info___2 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___2 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___2 *ip6_prohibit_entry;
	struct rt6_info___2 *ip6_blk_hole_entry;
	struct fib6_table___2 *fib6_local_tbl;
	struct fib_rules_ops___31 *fib6_rules_ops;
	struct sock___32 **icmp_sk;
	struct sock___32 *ndisc_sk;
	struct sock___32 *tcp_sk;
	struct sock___32 *igmp_sk;
	struct sock___32 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___31 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___31 *notifier_ops;
	struct fib_notifier_ops___31 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___47 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___47 *fqdir;
};

struct netns_sctp___31 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___32 *ctl_sock;
	struct sock___32 *udp4_sock;
	struct sock___32 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___38;

struct netns_bpf___38 {
	struct bpf_prog_array___38 *run_array[2];
	struct bpf_prog___38 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___47 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___32 *nlsk;
	struct sock___32 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___47 xfrm4_dst_ops;
	struct dst_ops___47 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___47 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___32 *rtnl;
	struct sock___32 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___44 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___47 ipv4;
	struct netns_ipv6___47 ipv6;
	struct netns_ieee802154_lowpan___47 ieee802154_lowpan;
	struct netns_sctp___31 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___42 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___38 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___47 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___32 *crypto_nlsk;
	struct sock___32 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___154 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___154 *root_cset;
};

struct msghdr___33 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___144 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___224 *msg_iocb;
};

struct socket_wq___32 {
	wait_queue_head_t wait;
	struct fasync_struct___224 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___32;

struct socket___33 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___224 *file;
	struct sock___32 *sk;
	const struct proto_ops___32 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___32 wq;
};

typedef int (*sk_read_actor_t___31)(read_descriptor_t *, struct sk_buff___43 *, unsigned int, size_t);

struct proto_ops___32 {
	int family;
	struct module___208 *owner;
	int (*release)(struct socket___33 *);
	int (*bind)(struct socket___33 *, struct sockaddr *, int);
	int (*connect)(struct socket___33 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___33 *, struct socket___33 *);
	int (*accept)(struct socket___33 *, struct socket___33 *, int, bool);
	int (*getname)(struct socket___33 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___224 *, struct socket___33 *, struct poll_table_struct___149 *);
	int (*ioctl)(struct socket___33 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___33 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___33 *, void *, bool, bool);
	int (*listen)(struct socket___33 *, int);
	int (*shutdown)(struct socket___33 *, int);
	int (*setsockopt)(struct socket___33 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___33 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___199 *, struct socket___33 *);
	int (*sendmsg)(struct socket___33 *, struct msghdr___33 *, size_t);
	int (*recvmsg)(struct socket___33 *, struct msghdr___33 *, size_t, int);
	int (*mmap)(struct file___224 *, struct socket___33 *, struct vm_area_struct___229 *);
	ssize_t (*sendpage)(struct socket___33 *, struct page___229 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___33 *, loff_t *, struct pipe_inode_info___74 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___32 *, int);
	int (*peek_len)(struct socket___33 *);
	int (*read_sock)(struct sock___32 *, read_descriptor_t *, sk_read_actor_t___31);
	int (*sendpage_locked)(struct sock___32 *, struct page___229 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___32 *, struct msghdr___33 *, size_t);
	int (*set_rcvlowat)(struct sock___32 *, int);
};

struct sk_buff___43 {
	union {
		struct {
			struct sk_buff___43 *next;
			struct sk_buff___43 *prev;
			union {
				struct net_device___44 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___32 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___43 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___202 {
	int (*prepare)(struct device___202 *);
	void (*complete)(struct device___202 *);
	int (*suspend)(struct device___202 *);
	int (*resume)(struct device___202 *);
	int (*freeze)(struct device___202 *);
	int (*thaw)(struct device___202 *);
	int (*poweroff)(struct device___202 *);
	int (*restore)(struct device___202 *);
	int (*suspend_late)(struct device___202 *);
	int (*resume_early)(struct device___202 *);
	int (*freeze_late)(struct device___202 *);
	int (*thaw_early)(struct device___202 *);
	int (*poweroff_late)(struct device___202 *);
	int (*restore_early)(struct device___202 *);
	int (*suspend_noirq)(struct device___202 *);
	int (*resume_noirq)(struct device___202 *);
	int (*freeze_noirq)(struct device___202 *);
	int (*thaw_noirq)(struct device___202 *);
	int (*poweroff_noirq)(struct device___202 *);
	int (*restore_noirq)(struct device___202 *);
	int (*runtime_suspend)(struct device___202 *);
	int (*runtime_resume)(struct device___202 *);
	int (*runtime_idle)(struct device___202 *);
};

struct wakeup_source___202 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___202 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___202 {
	struct dev_pm_ops___202 ops;
	int (*start)(struct device___202 *);
	void (*detach)(struct device___202 *, bool);
	int (*activate)(struct device___202 *);
	void (*sync)(struct device___202 *);
	void (*dismiss)(struct device___202 *);
};

struct bus_type___202 {
	const char *name;
	const char *dev_name;
	struct device___202 *dev_root;
	const struct attribute_group___212 **bus_groups;
	const struct attribute_group___212 **dev_groups;
	const struct attribute_group___212 **drv_groups;
	int (*match)(struct device___202 *, struct device_driver___202 *);
	int (*uevent)(struct device___202 *, struct kobj_uevent_env *);
	int (*probe)(struct device___202 *);
	void (*sync_state)(struct device___202 *);
	void (*remove)(struct device___202 *);
	void (*shutdown)(struct device___202 *);
	int (*online)(struct device___202 *);
	int (*offline)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	int (*num_vf)(struct device___202 *);
	int (*dma_configure)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___202 {
	const char *name;
	struct bus_type___202 *bus;
	struct module___208 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___202 *);
	void (*sync_state)(struct device___202 *);
	int (*remove)(struct device___202 *);
	void (*shutdown)(struct device___202 *);
	int (*suspend)(struct device___202 *, pm_message_t);
	int (*resume)(struct device___202 *);
	const struct attribute_group___212 **groups;
	const struct attribute_group___212 **dev_groups;
	const struct dev_pm_ops___202 *pm;
	void (*coredump)(struct device___202 *);
	struct driver_private *p;
};

struct device_type___202 {
	const char *name;
	const struct attribute_group___212 **groups;
	int (*uevent)(struct device___202 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___202 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___202 *);
	const struct dev_pm_ops___202 *pm;
};

struct class___202 {
	const char *name;
	struct module___208 *owner;
	const struct attribute_group___212 **class_groups;
	const struct attribute_group___212 **dev_groups;
	struct kobject___212 *dev_kobj;
	int (*dev_uevent)(struct device___202 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___202 *, umode_t *);
	void (*class_release)(struct class___202 *);
	void (*dev_release)(struct device___202 *);
	int (*shutdown_pre)(struct device___202 *);
	const struct kobj_ns_type_operations___31 *ns_type;
	const void * (*namespace)(struct device___202 *);
	void (*get_ownership)(struct device___202 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___202 *pm;
	struct subsys_private *p;
};

struct device_attribute___36 {
	struct attribute attr;
	ssize_t (*show)(struct device___202 *, struct device_attribute___36 *, char *);
	ssize_t (*store)(struct device___202 *, struct device_attribute___36 *, const char *, size_t);
};

struct flow_dissector_key_control {
	u16 thoff;
	u16 addr_type;
	u32 flags;
};

struct flow_dissector_key_basic {
	__be16 n_proto;
	u8 ip_proto;
	u8 padding;
};

struct flow_dissector {
	unsigned int used_keys;
	short unsigned int offset[28];
};

struct flow_keys_basic {
	struct flow_dissector_key_control control;
	struct flow_dissector_key_basic basic;
};

struct pipe_buf_operations___74;

struct pipe_buffer___74 {
	struct page___229 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___74 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___74 {
	int (*confirm)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
	void (*release)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
	bool (*try_steal)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
	bool (*get)(struct pipe_inode_info___74 *, struct pipe_buffer___74 *);
};

struct nf_conntrack {
	atomic_t use;
};

typedef rx_handler_result_t rx_handler_func_t___42(struct sk_buff___43 **);

struct bpf_xdp_entity___38 {
	struct bpf_prog___38 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___42;

struct net_device_ops___42;

struct ethtool_ops___18;

struct l3mdev_ops___31;

struct ndisc_ops___20;

struct xfrmdev_ops___42;

struct header_ops___42;

struct inet6_dev___20;

struct wpan_dev___2;

struct netdev_rx_queue___42;

struct mini_Qdisc___38;

struct netdev_queue___42;

struct Qdisc___38;

struct rtnl_link_ops___38;

struct dcbnl_rtnl_ops___42;

struct net_device___44 {
	char name[16];
	struct netdev_name_node___42 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___42 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___18 *ethtool_ops;
	const struct l3mdev_ops___31 *l3mdev_ops;
	const struct ndisc_ops___20 *ndisc_ops;
	const struct xfrmdev_ops___42 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___42 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___212 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___20 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev___2 *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___42 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___38 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___42 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___38 *miniq_ingress;
	struct netdev_queue___42 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___42 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___38 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___38 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___42 = 0,
		NETREG_REGISTERED___42 = 1,
		NETREG_UNREGISTERING___42 = 2,
		NETREG_UNREGISTERED___42 = 3,
		NETREG_RELEASED___42 = 4,
		NETREG_DUMMY___42 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___42 = 0,
		RTNL_LINK_INITIALIZING___42 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___44 *);
	struct netpoll_info *npinfo;
	possible_net_t___42 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___202 dev;
	const struct attribute_group___212 *sysfs_groups[4];
	const struct attribute_group___212 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___38 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___42 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___38 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___141 skb_frag_t___2;

enum {
	SKBFL_ZEROCOPY_ENABLE = 1,
	SKBFL_SHARED_FRAG = 2,
};

struct mmpin {
	struct user_struct *user;
	unsigned int num_pg;
};

struct ubuf_info {
	void (*callback)(struct sk_buff___43 *, struct ubuf_info *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___2 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___43 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___2 frags[17];
};

enum {
	SKB_GSO_TCPV4 = 1,
	SKB_GSO_DODGY = 2,
	SKB_GSO_TCP_ECN = 4,
	SKB_GSO_TCP_FIXEDID = 8,
	SKB_GSO_TCPV6 = 16,
	SKB_GSO_FCOE = 32,
	SKB_GSO_GRE = 64,
	SKB_GSO_GRE_CSUM = 128,
	SKB_GSO_IPXIP4 = 256,
	SKB_GSO_IPXIP6 = 512,
	SKB_GSO_UDP_TUNNEL = 1024,
	SKB_GSO_UDP_TUNNEL_CSUM = 2048,
	SKB_GSO_PARTIAL = 4096,
	SKB_GSO_TUNNEL_REMCSUM = 8192,
	SKB_GSO_SCTP = 16384,
	SKB_GSO_ESP = 32768,
	SKB_GSO_UDP = 65536,
	SKB_GSO_UDP_L4 = 131072,
	SKB_GSO_FRAGLIST = 262144,
};

struct inet_frags___47;

struct fqdir___47 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___47 *f;
	struct net___47 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___47;

struct inet_frags___47 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___47 *, const void *);
	void (*destructor)(struct inet_frag_queue___47 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___47 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___43 *fragments_tail;
	struct sk_buff___43 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___47 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___31;

struct fib_lookup_arg___31;

struct fib_rules_ops___31 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___31 *, struct flowi *, int, struct fib_lookup_arg___31 *);
	bool (*suppress)(struct fib_rule___31 *, int, struct fib_lookup_arg___31 *);
	int (*match)(struct fib_rule___31 *, struct flowi *, int);
	int (*configure)(struct fib_rule___31 *, struct sk_buff___43 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___31 *);
	int (*compare)(struct fib_rule___31 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___31 *, struct sk_buff___43 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___31 *);
	void (*flush_cache)(struct fib_rules_ops___31 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___208 *owner;
	struct net___47 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___31 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___47 *);
	int (*fib_dump)(struct net___47 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___208 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___16;

struct dst_entry___31 {
	struct net_device___44 *dev;
	struct dst_ops___47 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___43 *);
	int (*output)(struct net___47 *, struct sock___32 *, struct sk_buff___43 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___16 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___31;

struct neigh_parms___31;

struct neigh_ops___31;

struct neighbour___31 {
	struct neighbour___31 *next;
	struct neigh_table___31 *tbl;
	struct neigh_parms___31 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___42 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___31 *, struct sk_buff___43 *);
	const struct neigh_ops___31 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___44 *dev;
	u8 primary_key[0];
};

struct rtable___2;

struct fnhe_hash_bucket___2;

struct fib_nh_common___2 {
	struct net_device___44 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___16 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___2 **nhc_pcpu_rth_output;
	struct rtable___2 *nhc_rth_input;
	struct fnhe_hash_bucket___2 *nhc_exceptions;
};

struct fib6_nh___2 {
	struct fib_nh_common___2 nh_common;
	long unsigned int last_probe;
	struct rt6_info___2 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___2;

struct nexthop___2;

struct fib6_info___2 {
	struct fib6_table___2 *fib6_table;
	struct fib6_info___2 *fib6_next;
	struct fib6_node___2 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___2 *nh;
	struct fib6_nh___2 fib6_nh[0];
};

struct rt6_info___2 {
	struct dst_entry___31 dst;
	struct fib6_info___2 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___20 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___2 {
	struct fib6_node___2 *parent;
	struct fib6_node___2 *left;
	struct fib6_node___2 *right;
	struct fib6_node___2 *subtree;
	struct fib6_info___2 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___2 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___2 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___2 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___38 {
	struct bpf_prog___38 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___38 {
	struct callback_head rcu;
	struct bpf_prog_array_item___38 items[0];
};

struct bpf_prog_aux___45;

struct bpf_prog___38 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___45 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___199 {
	void * (*start)(struct seq_file___199 *, loff_t *);
	void (*stop)(struct seq_file___199 *, void *);
	void * (*next)(struct seq_file___199 *, void *, loff_t *);
	int (*show)(struct seq_file___199 *, void *);
};

struct dcbnl_rtnl_ops___42 {
	int (*ieee_getets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___44 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___44 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___44 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___44 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___44 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___44 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___44 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___44 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___44 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___44 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___44 *);
	u8 (*setstate)(struct net_device___44 *, u8);
	void (*getpermhwaddr)(struct net_device___44 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___44 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___44 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___44 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___44 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___44 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___44 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___44 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___44 *, int, u8 *);
	void (*setpfccfg)(struct net_device___44 *, int, u8);
	void (*getpfccfg)(struct net_device___44 *, int, u8 *);
	u8 (*setall)(struct net_device___44 *);
	u8 (*getcap)(struct net_device___44 *, int, u8 *);
	int (*getnumtcs)(struct net_device___44 *, int, u8 *);
	int (*setnumtcs)(struct net_device___44 *, int, u8);
	u8 (*getpfcstate)(struct net_device___44 *);
	void (*setpfcstate)(struct net_device___44 *, u8);
	void (*getbcncfg)(struct net_device___44 *, int, u32 *);
	void (*setbcncfg)(struct net_device___44 *, int, u32);
	void (*getbcnrp)(struct net_device___44 *, int, u8 *);
	void (*setbcnrp)(struct net_device___44 *, int, u8);
	int (*setapp)(struct net_device___44 *, u8, u16, u8);
	int (*getapp)(struct net_device___44 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___44 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___44 *, int, u8);
	u8 (*getdcbx)(struct net_device___44 *);
	u8 (*setdcbx)(struct net_device___44 *, u8);
	int (*peer_getappinfo)(struct net_device___44 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___44 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___44 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___44 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___44 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___44 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___45;

typedef int (*bpf_iter_init_seq_priv_t___44)(void *, struct bpf_iter_aux_info___45 *);

struct bpf_map___45;

struct bpf_iter_aux_info___45 {
	struct bpf_map___45 *map;
};

struct bpf_iter_seq_info___44 {
	const struct seq_operations___199 *seq_ops;
	bpf_iter_init_seq_priv_t___44 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___44 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___45 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___45 *, struct file___224 *);
	void (*map_free)(struct bpf_map___45 *);
	int (*map_get_next_key)(struct bpf_map___45 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___45 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___45 *, void *);
	int (*map_lookup_batch)(struct bpf_map___45 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___45 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___45 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___45 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___45 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___45 *, void *);
	int (*map_update_elem)(struct bpf_map___45 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___45 *, void *);
	int (*map_push_elem)(struct bpf_map___45 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___45 *, void *);
	int (*map_peek_elem)(struct bpf_map___45 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___45 *, struct file___224 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___45 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___45 *, void *, struct seq_file___199 *);
	int (*map_check_btf)(const struct bpf_map___45 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___45 *, struct bpf_prog_aux___45 *);
	void (*map_poke_untrack)(struct bpf_map___45 *, struct bpf_prog_aux___45 *);
	void (*map_poke_run)(struct bpf_map___45 *, u32, struct bpf_prog___38 *, struct bpf_prog___38 *);
	int (*map_direct_value_addr)(const struct bpf_map___45 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___45 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___45 *, struct vm_area_struct___229 *);
	__poll_t (*map_poll)(struct bpf_map___45 *, struct file___224 *, struct poll_table_struct___149 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___45 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___45 *, const struct bpf_map___45 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___45 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___44 *iter_seq_info;
};

struct bpf_map___45 {
	const struct bpf_map_ops___44 *ops;
	struct bpf_map___45 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___97 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___44;

struct bpf_jit_poke_descriptor___44;

struct bpf_prog_ops___38;

struct btf_mod_pair___44;

struct bpf_prog_offload___42;

struct bpf_prog_aux___45 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___38 *dst_prog;
	struct bpf_trampoline___44 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___38 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___44 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___38 *ops;
	struct bpf_map___45 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___44 *used_btfs;
	struct bpf_prog___38 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___45 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___42 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___42;

struct bpf_map_dev_ops___42 {
	int (*map_get_next_key)(struct bpf_offloaded_map___42 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___42 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___42 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___42 *, void *);
};

struct bpf_offloaded_map___42 {
	struct bpf_map___45 map;
	struct net_device___44 *netdev;
	const struct bpf_map_dev_ops___42 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___38 {
	int (*test_run)(struct bpf_prog___38 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___42 {
	struct bpf_prog___38 *prog;
	struct net_device___44 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___44 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___38 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___208 *mod;
};

struct bpf_jit_poke_descriptor___44 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___45 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___44 {
	struct btf *btf;
	struct module___208 *module;
};

struct cftype___154;

struct cgroup_subsys___154 {
	struct cgroup_subsys_state___154 * (*css_alloc)(struct cgroup_subsys_state___154 *);
	int (*css_online)(struct cgroup_subsys_state___154 *);
	void (*css_offline)(struct cgroup_subsys_state___154 *);
	void (*css_released)(struct cgroup_subsys_state___154 *);
	void (*css_free)(struct cgroup_subsys_state___154 *);
	void (*css_reset)(struct cgroup_subsys_state___154 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___154 *, int);
	int (*css_extra_stat_show)(struct seq_file___199 *, struct cgroup_subsys_state___154 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___231 *, struct css_set___154 *);
	void (*cancel_fork)(struct task_struct___231 *, struct css_set___154 *);
	void (*fork)(struct task_struct___231 *);
	void (*exit)(struct task_struct___231 *);
	void (*release)(struct task_struct___231 *);
	void (*bind)(struct cgroup_subsys_state___154 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___154 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___154 *dfl_cftypes;
	struct cftype___154 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___154 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___154 *updated_children;
	struct cgroup___154 *updated_next;
};

struct cgroup_root___154 {
	struct kernfs_root___212 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___154 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___154 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___154 *ss;
	struct list_head node;
	struct kernfs_ops___212 *kf_ops;
	int (*open)(struct kernfs_open_file___212 *);
	void (*release)(struct kernfs_open_file___212 *);
	u64 (*read_u64)(struct cgroup_subsys_state___154 *, struct cftype___154 *);
	s64 (*read_s64)(struct cgroup_subsys_state___154 *, struct cftype___154 *);
	int (*seq_show)(struct seq_file___199 *, void *);
	void * (*seq_start)(struct seq_file___199 *, loff_t *);
	void * (*seq_next)(struct seq_file___199 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___199 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___154 *, struct cftype___154 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___154 *, struct cftype___154 *, s64);
	ssize_t (*write)(struct kernfs_open_file___212 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___212 *, struct poll_table_struct___149 *);
};

struct xdp_rxq_info___42 {
	struct net_device___44 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___42 {
	struct net_device___44 *dev;
};

struct xdp_buff___42 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___42 *rxq;
	struct xdp_txq_info___42 *txq;
	u32 frame_sz;
};

struct xdp_frame___42 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___44 *dev_rx;
};

struct netlink_callback___42 {
	struct sk_buff___43 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___43 *, struct netlink_callback___42 *);
	int (*done)(struct netlink_callback___42 *);
	void *data;
	struct module___208 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum {
	IFLA_TUN_UNSPEC = 0,
	IFLA_TUN_OWNER = 1,
	IFLA_TUN_GROUP = 2,
	IFLA_TUN_TYPE = 3,
	IFLA_TUN_PI = 4,
	IFLA_TUN_VNET_HDR = 5,
	IFLA_TUN_PERSIST = 6,
	IFLA_TUN_MULTI_QUEUE = 7,
	IFLA_TUN_NUM_QUEUES = 8,
	IFLA_TUN_NUM_DISABLED_QUEUES = 9,
	__IFLA_TUN_MAX = 10,
};

struct header_ops___42 {
	int (*create)(struct sk_buff___43 *, struct net_device___44 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___43 *, unsigned char *);
	int (*cache)(const struct neighbour___31 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___44 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___43 *);
};

struct gro_list {
	struct list_head list;
	int count;
};

struct napi_struct {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct *, int);
	int poll_owner;
	struct net_device___44 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___43 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___231 *thread;
};

enum gro_result {
	GRO_MERGED = 0,
	GRO_MERGED_FREE = 1,
	GRO_HELD = 2,
	GRO_NORMAL = 3,
	GRO_CONSUMED = 4,
};

typedef enum gro_result gro_result_t;

enum netdev_queue_state_t {
	__QUEUE_STATE_DRV_XOFF = 0,
	__QUEUE_STATE_STACK_XOFF = 1,
	__QUEUE_STATE_FROZEN = 2,
};

struct netdev_queue___42 {
	struct net_device___44 *dev;
	struct Qdisc___38 *qdisc;
	struct Qdisc___38 *qdisc_sleeping;
	struct kobject___212 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___44 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___38 {
	struct sk_buff___43 *head;
	struct sk_buff___43 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___38;

struct Qdisc___38 {
	int (*enqueue)(struct sk_buff___43 *, struct Qdisc___38 *, struct sk_buff___43 **);
	struct sk_buff___43 * (*dequeue)(struct Qdisc___38 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___38 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___42 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___42 gso_skb;
	struct qdisc_skb_head___38 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___38 *next_sched;
	struct sk_buff_head___42 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct rps_sock_flow_table {
	u32 mask;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ents[0];
};

struct netdev_rx_queue___42 {
	struct xdp_rxq_info___42 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___212 kobj;
	struct net_device___44 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___42 {
	enum net_device_path_type type;
	const struct net_device___44 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___42 = 0,
				DEV_PATH_BR_VLAN_TAG___42 = 1,
				DEV_PATH_BR_VLAN_UNTAG___42 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___42 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___42 {
	const struct net_device___44 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___42 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___38 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___42 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___42 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___43 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___42 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___44 *dev;
	const char *name;
};

struct net_device_ops___42 {
	int (*ndo_init)(struct net_device___44 *);
	void (*ndo_uninit)(struct net_device___44 *);
	int (*ndo_open)(struct net_device___44 *);
	int (*ndo_stop)(struct net_device___44 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___43 *, struct net_device___44 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___43 *, struct net_device___44 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___44 *, struct sk_buff___43 *, struct net_device___44 *);
	void (*ndo_change_rx_flags)(struct net_device___44 *, int);
	void (*ndo_set_rx_mode)(struct net_device___44 *);
	int (*ndo_set_mac_address)(struct net_device___44 *, void *);
	int (*ndo_validate_addr)(struct net_device___44 *);
	int (*ndo_do_ioctl)(struct net_device___44 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___44 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___44 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___44 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___44 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___44 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___44 *, int);
	int (*ndo_neigh_setup)(struct net_device___44 *, struct neigh_parms___31 *);
	void (*ndo_tx_timeout)(struct net_device___44 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___44 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___44 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___44 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___44 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___44 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___44 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___44 *);
	int (*ndo_netpoll_setup)(struct net_device___44 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___44 *);
	int (*ndo_set_vf_mac)(struct net_device___44 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___44 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___44 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___44 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___44 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___44 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___44 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___44 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___44 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___44 *, int, struct sk_buff___43 *);
	int (*ndo_get_vf_guid)(struct net_device___44 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___44 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___44 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___44 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___44 *);
	int (*ndo_fcoe_disable)(struct net_device___44 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___44 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___44 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___44 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___44 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___44 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___44 *, const struct sk_buff___43 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___44 *, struct net_device___44 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___44 *, struct net_device___44 *);
	struct net_device___44 * (*ndo_get_xmit_slave)(struct net_device___44 *, struct sk_buff___43 *, bool);
	struct net_device___44 * (*ndo_sk_get_lower_dev)(struct net_device___44 *, struct sock___32 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___44 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___44 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___44 *, struct neighbour___31 *);
	void (*ndo_neigh_destroy)(struct net_device___44 *, struct neighbour___31 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___43 *, struct netlink_callback___42 *, struct net_device___44 *, struct net_device___44 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___43 *, struct nlattr **, struct net_device___44 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___44 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___43 *, u32, u32, struct net_device___44 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___44 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___44 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___44 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___44 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___44 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___44 *, struct net_device___44 *);
	void (*ndo_dfwd_del_station)(struct net_device___44 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___44 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___44 *);
	int (*ndo_change_proto_down)(struct net_device___44 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___44 *, struct sk_buff___43 *);
	void (*ndo_set_rx_headroom)(struct net_device___44 *, int);
	int (*ndo_bpf)(struct net_device___44 *, struct netdev_bpf___42 *);
	int (*ndo_xdp_xmit)(struct net_device___44 *, int, struct xdp_frame___42 **, u32);
	struct net_device___44 * (*ndo_xdp_get_xmit_slave)(struct net_device___44 *, struct xdp_buff___42 *);
	int (*ndo_xsk_wakeup)(struct net_device___44 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___44 *);
	int (*ndo_tunnel_ctl)(struct net_device___44 *, struct ip_tunnel_parm *, int);
	struct net_device___44 * (*ndo_get_peer_dev)(struct net_device___44 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___42 *, struct net_device_path___42 *);
};

struct neigh_parms___31 {
	possible_net_t___42 net;
	struct net_device___44 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___31 *);
	struct neigh_table___31 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ip_tunnel_parm {
	char name[16];
	int link;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	struct iphdr iph;
};

struct ethtool_ops___18 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___44 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___44 *);
	void (*get_regs)(struct net_device___44 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___44 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___44 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___44 *);
	void (*set_msglevel)(struct net_device___44 *, u32);
	int (*nway_reset)(struct net_device___44 *);
	u32 (*get_link)(struct net_device___44 *);
	int (*get_link_ext_state)(struct net_device___44 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___44 *);
	int (*get_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___44 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___44 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___44 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___44 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___44 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___44 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___44 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___44 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___44 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___44 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___44 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___44 *);
	void (*complete)(struct net_device___44 *);
	u32 (*get_priv_flags)(struct net_device___44 *);
	int (*set_priv_flags)(struct net_device___44 *, u32);
	int (*get_sset_count)(struct net_device___44 *, int);
	int (*get_rxnfc)(struct net_device___44 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___44 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___44 *, struct ethtool_flash *);
	int (*reset)(struct net_device___44 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___44 *);
	u32 (*get_rxfh_indir_size)(struct net_device___44 *);
	int (*get_rxfh)(struct net_device___44 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___44 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___44 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___44 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___44 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___44 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___44 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___44 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___44 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___44 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___44 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___44 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___44 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___44 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___44 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___44 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___44 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___44 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___44 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___44 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___44 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___44 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___44 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___44 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___44 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___44 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___44 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___44 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___44 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___44 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___44 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___31 {
	u32 (*l3mdev_fib_table)(const struct net_device___44 *);
	struct sk_buff___43 * (*l3mdev_l3_rcv)(struct net_device___44 *, struct sk_buff___43 *, u16);
	struct sk_buff___43 * (*l3mdev_l3_out)(struct net_device___44 *, struct sock___32 *, struct sk_buff___43 *, u16);
	struct dst_entry___31 * (*l3mdev_link_scope_lookup)(const struct net_device___44 *, struct flowi6 *);
};

struct ndisc_ops___20 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___44 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___44 *, struct neighbour___31 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___44 *, u8, struct neighbour___31 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___44 *, struct sk_buff___43 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___47 *, struct net_device___44 *, const struct prefix_info *, struct inet6_dev___20 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___20;

struct ifacaddr6___2;

struct inet6_dev___20 {
	struct net_device___44 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___20 *mc_list;
	struct ifmcaddr6___20 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___42 mc_query_queue;
	struct sk_buff_head___42 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___2 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___31 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct wpan_phy;

struct wpan_dev_header_ops;

struct wpan_dev___2 {
	struct wpan_phy *wpan_phy;
	int iftype;
	struct list_head list;
	struct net_device___44 *netdev;
	const struct wpan_dev_header_ops *header_ops;
	struct net_device___44 *lowpan_dev;
	u32 identifier;
	__le16 pan_id;
	__le16 short_addr;
	__le64 extended_addr;
	atomic_t bsn;
	atomic_t dsn;
	u8 min_be;
	u8 max_be;
	u8 csma_retries;
	s8 frame_retries;
	bool lbt;
	bool promiscuous_mode;
	bool ackreq;
};

struct tcf_proto___38;

struct tcf_block___38;

struct mini_Qdisc___38 {
	struct tcf_proto___38 *filter_list;
	struct tcf_block___38 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___38 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___44 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___44 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___47 *, struct net_device___44 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___44 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___44 *, struct list_head *);
	size_t (*get_size)(const struct net_device___44 *);
	int (*fill_info)(struct sk_buff___43 *, const struct net_device___44 *);
	size_t (*get_xstats_size)(const struct net_device___44 *);
	int (*fill_xstats)(struct sk_buff___43 *, const struct net_device___44 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___44 *, struct net_device___44 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___44 *, const struct net_device___44 *);
	int (*fill_slave_info)(struct sk_buff___43 *, const struct net_device___44 *, const struct net_device___44 *);
	struct net___47 * (*get_link_net)(const struct net_device___44 *);
	size_t (*get_linkxstats_size)(const struct net_device___44 *, int);
	int (*fill_linkxstats)(struct sk_buff___43 *, const struct net_device___44 *, int *, int);
};

struct netdev_notifier_info___3 {
	struct net_device___44 *dev;
	struct netlink_ext_ack *extack;
};

struct miscdevice___9 {
	int minor;
	const char *name;
	const struct file_operations___225 *fops;
	struct list_head list;
	struct device___202 *parent;
	struct device___202 *this_device;
	const struct attribute_group___212 **groups;
	const char *nodename;
	umode_t mode;
};

struct gnet_dump___38 {
	spinlock_t *lock;
	struct sk_buff___43 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___38;

struct Qdisc_ops___38 {
	struct Qdisc_ops___38 *next;
	const struct Qdisc_class_ops___38 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___43 *, struct Qdisc___38 *, struct sk_buff___43 **);
	struct sk_buff___43 * (*dequeue)(struct Qdisc___38 *);
	struct sk_buff___43 * (*peek)(struct Qdisc___38 *);
	int (*init)(struct Qdisc___38 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___38 *);
	void (*destroy)(struct Qdisc___38 *);
	int (*change)(struct Qdisc___38 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___38 *);
	int (*change_tx_queue_len)(struct Qdisc___38 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___38 *, unsigned int);
	int (*dump)(struct Qdisc___38 *, struct sk_buff___43 *);
	int (*dump_stats)(struct Qdisc___38 *, struct gnet_dump___38 *);
	void (*ingress_block_set)(struct Qdisc___38 *, u32);
	void (*egress_block_set)(struct Qdisc___38 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___38 *);
	u32 (*egress_block_get)(struct Qdisc___38 *);
	struct module___208 *owner;
};

struct Qdisc_class_ops___38 {
	unsigned int flags;
	struct netdev_queue___42 * (*select_queue)(struct Qdisc___38 *, struct tcmsg *);
	int (*graft)(struct Qdisc___38 *, long unsigned int, struct Qdisc___38 *, struct Qdisc___38 **, struct netlink_ext_ack *);
	struct Qdisc___38 * (*leaf)(struct Qdisc___38 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___38 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___38 *, u32);
	int (*change)(struct Qdisc___38 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___38 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___38 *, struct qdisc_walker *);
	struct tcf_block___38 * (*tcf_block)(struct Qdisc___38 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___38 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___38 *, long unsigned int);
	int (*dump)(struct Qdisc___38 *, long unsigned int, struct sk_buff___43 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___38 *, long unsigned int, struct gnet_dump___38 *);
};

struct tcf_chain___38;

struct tcf_block___38 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___47 *net;
	struct Qdisc___38 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___38 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___38;

struct tcf_proto_ops___38;

struct tcf_proto___38 {
	struct tcf_proto___38 *next;
	void *root;
	int (*classify)(struct sk_buff___43 *, const struct tcf_proto___38 *, struct tcf_result___38 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___38 *ops;
	struct tcf_chain___38 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___38 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___38 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___38 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___43 *, const struct tcf_proto___38 *, struct tcf_result___38 *);
	int (*init)(struct tcf_proto___38 *);
	void (*destroy)(struct tcf_proto___38 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___38 *, u32);
	void (*put)(struct tcf_proto___38 *, void *);
	int (*change)(struct net___47 *, struct sk_buff___43 *, struct tcf_proto___38 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___38 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___38 *);
	void (*walk)(struct tcf_proto___38 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___38 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___38 *, void *);
	void (*hw_del)(struct tcf_proto___38 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___47 *, struct tcf_chain___38 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___47 *, struct tcf_proto___38 *, void *, struct sk_buff___43 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___47 *, struct tcf_proto___38 *, void *, struct sk_buff___43 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___43 *, struct net___47 *, void *);
	struct module___208 *owner;
	int flags;
};

struct tcf_chain___38 {
	struct mutex filter_chain_lock;
	struct tcf_proto___38 *filter_chain;
	struct list_head list;
	struct tcf_block___38 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___38 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___31 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___38 *prog;
};

struct tun_pi {
	__u16 flags;
	__be16 proto;
};

struct tun_filter {
	__u16 flags;
	__u16 count;
	__u8 addr[0];
};

struct virtio_net_hdr {
	__u8 flags;
	__u8 gso_type;
	__virtio16 hdr_len;
	__virtio16 gso_size;
	__virtio16 csum_start;
	__virtio16 csum_offset;
};

struct tun_msg_ctl {
	short unsigned int type;
	short unsigned int num;
	void *ptr;
};

struct tun_xdp_hdr {
	int buflen;
	struct virtio_net_hdr gso;
};

struct block_device_operations___117;

struct gendisk___120 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___120 *part0;
	const struct block_device_operations___117 *fops;
	struct request_queue___117 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___106 *bdi;
	struct kobject___212 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___212 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___117 {
	struct bio___117 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___141 *bip_vec;
	struct bio_vec___141 bip_inline_vecs[0];
};

struct blkcg___108;

struct blkg_policy_data___108;

struct blkcg_gq___108 {
	struct request_queue___117 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___108 *blkcg;
	struct blkcg_gq___108 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___108 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___117 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___117(struct request___117 *);

typedef void integrity_complete_fn___117(struct request___117 *, unsigned int);

struct blk_integrity_profile___117 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___117 *prepare_fn;
	integrity_complete_fn___117 *complete_fn;
	const char *name;
};

struct block_device_operations___117 {
	blk_qc_t (*submit_bio)(struct bio___117 *);
	int (*open)(struct block_device___120 *, fmode_t);
	void (*release)(struct gendisk___120 *, fmode_t);
	int (*rw_page)(struct block_device___120 *, sector_t, struct page___229 *, unsigned int);
	int (*ioctl)(struct block_device___120 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___120 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___120 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___120 *);
	int (*getgeo)(struct block_device___120 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___120 *, bool);
	void (*swap_slot_free_notify)(struct block_device___120 *, long unsigned int);
	int (*report_zones)(struct gendisk___120 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___120 *, umode_t *);
	struct module___208 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___120 *, sector_t *);
};

typedef void rq_end_io_fn___117(struct request___117 *, blk_status_t);

struct request___117 {
	struct request_queue___117 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___114 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___117 *bio;
	struct bio___117 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___141 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___117 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___117 *saved_end_io;
		} flush;
	};
	struct gendisk___120 *rq_disk;
	struct block_device___120 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___117 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___114 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___117 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___212 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___224 *debugfs_dir;
	struct dentry___224 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___117;

struct elevator_mq_ops___117 {
	int (*init_sched)(struct request_queue___117 *, struct elevator_type___117 *);
	void (*exit_sched)(struct elevator_queue___117 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___114 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___114 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___114 *);
	bool (*allow_merge)(struct request_queue___117 *, struct request___117 *, struct bio___117 *);
	bool (*bio_merge)(struct request_queue___117 *, struct bio___117 *, unsigned int);
	int (*request_merge)(struct request_queue___117 *, struct request___117 **, struct bio___117 *);
	void (*request_merged)(struct request_queue___117 *, struct request___117 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___117 *, struct request___117 *, struct request___117 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___117 *);
	void (*finish_request)(struct request___117 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___114 *, struct list_head *, bool);
	struct request___117 * (*dispatch_request)(struct blk_mq_hw_ctx___114 *);
	bool (*has_work)(struct blk_mq_hw_ctx___114 *);
	void (*completed_request)(struct request___117 *, u64);
	void (*requeue_request)(struct request___117 *);
	struct request___117 * (*former_request)(struct request_queue___117 *, struct request___117 *);
	struct request___117 * (*next_request)(struct request_queue___117 *, struct request___117 *);
	void (*init_icq)(struct io_cq___117 *);
	void (*exit_icq)(struct io_cq___117 *);
};

struct elv_fs_entry___117;

struct elevator_type___117 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___117 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___117 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___208 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___117 {
	struct elevator_type___117 *type;
	void *elevator_data;
	struct kobject___212 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___117 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___117 *, char *);
	ssize_t (*store)(struct elevator_queue___117 *, const char *, size_t);
};

struct blk_mq_queue_data___114;

struct blk_mq_ops___114 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___114 *, const struct blk_mq_queue_data___114 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___114 *);
	int (*get_budget)(struct request_queue___117 *);
	void (*put_budget)(struct request_queue___117 *, int);
	void (*set_rq_budget_token)(struct request___117 *, int);
	int (*get_rq_budget_token)(struct request___117 *);
	enum blk_eh_timer_return (*timeout)(struct request___117 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___114 *);
	void (*complete)(struct request___117 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___114 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___114 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___114 *, struct request___117 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___114 *, struct request___117 *, unsigned int);
	void (*initialize_rq_fn)(struct request___117 *);
	void (*cleanup_rq)(struct request___117 *);
	bool (*busy)(struct request_queue___117 *);
	int (*map_queues)(struct blk_mq_tag_set___114 *);
	void (*show_rq)(struct seq_file___199 *, struct request___117 *);
};

struct blk_mq_tag_set___114 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___114 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___114 {
	struct request___117 *rq;
	bool last;
};

struct blkcg_policy_data___108;

struct blkcg___108 {
	struct cgroup_subsys_state___154 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___108 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___108 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___108 {
	struct blkcg___108 *blkcg;
	int plid;
};

struct blkg_policy_data___108 {
	struct blkcg_gq___108 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___97 {
	struct mem_cgroup___97 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___97 {
	struct lruvec___105 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___97 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___97 *memcg;
};

struct obj_cgroup___97 {
	struct percpu_ref refcnt;
	struct mem_cgroup___97 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___31;

struct neigh_hash_table___31;

struct neigh_table___31 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___44 *, __u32 *);
	bool (*key_eq)(const struct neighbour___31 *, const void *);
	int (*constructor)(struct neighbour___31 *);
	int (*pconstructor)(struct pneigh_entry___31 *);
	void (*pdestructor)(struct pneigh_entry___31 *);
	void (*proxy_redo)(struct sk_buff___43 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___44 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___31 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___42 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___31 *nht;
	struct pneigh_entry___31 **phash_buckets;
};

struct neigh_ops___31 {
	int family;
	void (*solicit)(struct neighbour___31 *, struct sk_buff___43 *);
	void (*error_report)(struct neighbour___31 *, struct sk_buff___43 *);
	int (*output)(struct neighbour___31 *, struct sk_buff___43 *);
	int (*connected_output)(struct neighbour___31 *, struct sk_buff___43 *);
};

struct pneigh_entry___31 {
	struct pneigh_entry___31 *next;
	possible_net_t___42 net;
	struct net_device___44 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___31 {
	struct neighbour___31 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___16 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___47 *, struct sock___32 *, struct sk_buff___43 *);
	int (*orig_input)(struct sk_buff___43 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___31 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___31 *ctarget;
	struct net___47 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___31 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___31 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___21;

struct timewait_sock_ops___21;

struct proto___31 {
	void (*close)(struct sock___32 *, long int);
	int (*pre_connect)(struct sock___32 *, struct sockaddr *, int);
	int (*connect)(struct sock___32 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___32 *, int);
	struct sock___32 * (*accept)(struct sock___32 *, int, int *, bool);
	int (*ioctl)(struct sock___32 *, int, long unsigned int);
	int (*init)(struct sock___32 *);
	void (*destroy)(struct sock___32 *);
	void (*shutdown)(struct sock___32 *, int);
	int (*setsockopt)(struct sock___32 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___32 *, int, int, char *, int *);
	void (*keepalive)(struct sock___32 *, int);
	int (*compat_ioctl)(struct sock___32 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___32 *, struct msghdr___33 *, size_t);
	int (*recvmsg)(struct sock___32 *, struct msghdr___33 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___32 *, struct page___229 *, int, size_t, int);
	int (*bind)(struct sock___32 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___32 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___32 *, struct sk_buff___43 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___32 *);
	int (*hash)(struct sock___32 *);
	void (*unhash)(struct sock___32 *);
	void (*rehash)(struct sock___32 *);
	int (*get_port)(struct sock___32 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___32 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___32 *, int);
	bool (*sock_is_readable)(struct sock___32 *);
	void (*enter_memory_pressure)(struct sock___32 *);
	void (*leave_memory_pressure)(struct sock___32 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___21 *rsk_prot;
	struct timewait_sock_ops___21 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___208 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___32 *, int);
};

struct request_sock___22;

struct request_sock_ops___21 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___32 *, struct request_sock___22 *);
	void (*send_ack)(const struct sock___32 *, struct sk_buff___43 *, struct request_sock___22 *);
	void (*send_reset)(const struct sock___32 *, struct sk_buff___43 *);
	void (*destructor)(struct request_sock___22 *);
	void (*syn_ack_timeout)(const struct request_sock___22 *);
};

struct timewait_sock_ops___21 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___32 *, struct sock___32 *, void *);
	void (*twsk_destructor)(struct sock___32 *);
};

struct request_sock___22 {
	struct sock_common___31 __req_common;
	struct request_sock___22 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___21 *rsk_ops;
	struct sock___32 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___20 {
	struct in6_addr mca_addr;
	struct inet6_dev___20 *idev;
	struct ifmcaddr6___20 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___2 {
	struct in6_addr aca_addr;
	struct fib6_info___2 *aca_rt;
	struct ifacaddr6___2 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___2 {
	struct fib_nh_exception___2 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___2 *fnhe_rth_input;
	struct rtable___2 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___2 {
	struct dst_entry___31 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___2 {
	struct fib_nh_exception___2 *chain;
};

struct fib_info;

struct fib_nh {
	struct fib_nh_common___2 nh_common;
	struct hlist_node nh_hash;
	struct fib_info *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___47 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___2 *nh;
	struct callback_head rcu;
	struct fib_nh fib_nh[0];
};

struct nh_info;

struct nh_group;

struct nexthop___2 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___47 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info *nh_info;
		struct nh_group *nh_grp;
	};
};

struct nh_info {
	struct hlist_node dev_hash;
	struct nexthop___2 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___2 fib_nhc;
		struct fib_nh fib_nh;
		struct fib6_nh___2 fib6_nh;
	};
};

struct nh_grp_entry;

struct nh_res_bucket {
	struct nh_grp_entry *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry {
	struct nexthop___2 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___2 *nh_parent;
};

struct nh_res_table {
	struct net___47 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket nh_buckets[0];
};

struct nh_group {
	struct nh_group *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table *res_table;
	struct nh_grp_entry nh_entries[0];
};

enum {
	AX25_VALUES_IPDEFMODE = 0,
	AX25_VALUES_AXDEFMODE = 1,
	AX25_VALUES_BACKOFF = 2,
	AX25_VALUES_CONMODE = 3,
	AX25_VALUES_WINDOW = 4,
	AX25_VALUES_EWINDOW = 5,
	AX25_VALUES_T1 = 6,
	AX25_VALUES_T2 = 7,
	AX25_VALUES_T3 = 8,
	AX25_VALUES_IDLE = 9,
	AX25_VALUES_N2 = 10,
	AX25_VALUES_PACLEN = 11,
	AX25_VALUES_PROTOCOL = 12,
	AX25_VALUES_DS_TIMEOUT = 13,
	AX25_MAX_VALUES = 14,
};

enum nl802154_cca_modes {
	__NL802154_CCA_INVALID = 0,
	NL802154_CCA_ENERGY = 1,
	NL802154_CCA_CARRIER = 2,
	NL802154_CCA_ENERGY_CARRIER = 3,
	NL802154_CCA_ALOHA = 4,
	NL802154_CCA_UWB_SHR = 5,
	NL802154_CCA_UWB_MULTIPLEXED = 6,
	__NL802154_CCA_ATTR_AFTER_LAST = 7,
	NL802154_CCA_ATTR_MAX = 6,
};

enum nl802154_cca_opts {
	NL802154_CCA_OPT_ENERGY_CARRIER_AND = 0,
	NL802154_CCA_OPT_ENERGY_CARRIER_OR = 1,
	__NL802154_CCA_OPT_ATTR_AFTER_LAST = 2,
	NL802154_CCA_OPT_ATTR_MAX = 1,
};

enum nl802154_supported_bool_states {
	NL802154_SUPPORTED_BOOL_FALSE = 0,
	NL802154_SUPPORTED_BOOL_TRUE = 1,
	__NL802154_SUPPORTED_BOOL_INVALD = 2,
	NL802154_SUPPORTED_BOOL_BOTH = 3,
	__NL802154_SUPPORTED_BOOL_AFTER_LAST = 4,
	NL802154_SUPPORTED_BOOL_MAX = 3,
};

struct wpan_phy_supported {
	u32 channels[32];
	u32 cca_modes;
	u32 cca_opts;
	u32 iftypes;
	enum nl802154_supported_bool_states lbt;
	u8 min_minbe;
	u8 max_minbe;
	u8 min_maxbe;
	u8 max_maxbe;
	u8 min_csma_backoffs;
	u8 max_csma_backoffs;
	s8 min_frame_retries;
	s8 max_frame_retries;
	size_t tx_powers_size;
	size_t cca_ed_levels_size;
	const s32 *tx_powers;
	const s32 *cca_ed_levels;
};

struct wpan_phy_cca {
	enum nl802154_cca_modes mode;
	enum nl802154_cca_opts opt;
};

struct wpan_phy {
	const void *privid;
	u32 flags;
	u8 current_channel;
	u8 current_page;
	struct wpan_phy_supported supported;
	s32 transmit_power;
	struct wpan_phy_cca cca;
	__le64 perm_extended_addr;
	s32 cca_ed_level;
	u8 symbol_duration;
	u16 lifs_period;
	u16 sifs_period;
	struct device___202 dev;
	possible_net_t___42 _net;
	long: 64;
	long: 64;
	char priv[0];
};

struct ieee802154_addr {
	u8 mode;
	__le16 pan_id;
	union {
		__le16 short_addr;
		__le64 extended_addr;
	};
};

struct wpan_dev_header_ops {
	int (*create)(struct sk_buff___43 *, struct net_device___44 *, const struct ieee802154_addr *, const struct ieee802154_addr *, unsigned int);
};

struct tap_filter {
	unsigned int count;
	u32 mask[2];
	unsigned char addr[48];
};

struct tun_struct;

struct tun_file {
	struct sock___32 sk;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___33 socket;
	struct tun_struct *tun;
	struct fasync_struct___224 *fasync;
	unsigned int flags;
	union {
		u16 queue_index;
		unsigned int ifindex;
	};
	struct napi_struct napi;
	bool napi_enabled;
	bool napi_frags_enabled;
	struct mutex napi_mutex;
	struct list_head next;
	struct tun_struct *detached;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring tx_ring;
	struct xdp_rxq_info___42 xdp_rxq;
};

struct tun_prog;

struct tun_struct {
	struct tun_file *tfiles[256];
	unsigned int numqueues;
	unsigned int flags;
	kuid_t owner;
	kgid_t group;
	struct net_device___44 *dev;
	netdev_features_t set_features;
	int align;
	int vnet_hdr_sz;
	int sndbuf;
	struct tap_filter txflt;
	struct sock_fprog fprog;
	bool filter_attached;
	u32 msg_enable;
	spinlock_t lock;
	struct hlist_head flows[1024];
	struct timer_list flow_gc_timer;
	long unsigned int ageing_time;
	unsigned int numdisabled;
	struct list_head disabled;
	void *security;
	u32 flow_count;
	u32 rx_batched;
	atomic_long_t rx_frame_errors;
	struct bpf_prog___38 *xdp_prog;
	struct tun_prog *steering_prog;
	struct tun_prog *filter_prog;
	struct ethtool_link_ksettings link_ksettings;
	struct file___224 *file;
	struct ifreq *ifr;
};

struct tun_page {
	struct page___229 *page;
	int count;
};

struct tun_flow_entry {
	struct hlist_node hash_link;
	struct callback_head rcu;
	struct tun_struct *tun;
	u32 rxhash;
	u32 rps_rxhash;
	int queue_index;
	long: 32;
	long: 64;
	long unsigned int updated;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tun_prog {
	struct callback_head rcu;
	struct bpf_prog___38 *prog;
};

struct veth {
	__be16 h_vlan_proto;
	__be16 h_vlan_TCI;
};

struct bcma_device_id {
	__u16 manuf;
	__u16 id;
	__u8 rev;
	__u8 class;
};

struct dentry___225;

struct super_block___225;

struct module___209;

struct file_system_type___225 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___225 * (*mount)(struct file_system_type___225 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___225 *);
	struct module___209 *owner;
	struct file_system_type___225 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___225;

struct kiocb___225;

struct iov_iter___145;

struct poll_table_struct___150;

struct vm_area_struct___230;

struct inode___225;

struct file_lock___225;

struct page___230;

struct pipe_inode_info___75;

struct seq_file___200;

struct file_operations___226 {
	struct module___209 *owner;
	loff_t (*llseek)(struct file___225 *, loff_t, int);
	ssize_t (*read)(struct file___225 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___225 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___225 *, struct iov_iter___145 *);
	ssize_t (*write_iter)(struct kiocb___225 *, struct iov_iter___145 *);
	int (*iopoll)(struct kiocb___225 *, bool);
	int (*iterate)(struct file___225 *, struct dir_context *);
	int (*iterate_shared)(struct file___225 *, struct dir_context *);
	__poll_t (*poll)(struct file___225 *, struct poll_table_struct___150 *);
	long int (*unlocked_ioctl)(struct file___225 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___225 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___225 *, struct vm_area_struct___230 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___225 *, struct file___225 *);
	int (*flush)(struct file___225 *, fl_owner_t);
	int (*release)(struct inode___225 *, struct file___225 *);
	int (*fsync)(struct file___225 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___225 *, int);
	int (*lock)(struct file___225 *, int, struct file_lock___225 *);
	ssize_t (*sendpage)(struct file___225 *, struct page___230 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___225 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___225 *, long unsigned int);
	int (*flock)(struct file___225 *, int, struct file_lock___225 *);
	ssize_t (*splice_write)(struct pipe_inode_info___75 *, struct file___225 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___225 *, loff_t *, struct pipe_inode_info___75 *, size_t, unsigned int);
	int (*setlease)(struct file___225 *, long int, struct file_lock___225 **, void **);
	long int (*fallocate)(struct file___225 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___200 *, struct file___225 *);
	ssize_t (*copy_file_range)(struct file___225 *, loff_t, struct file___225 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___225 *, loff_t, struct file___225 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___225 *, loff_t, loff_t, int);
};

struct vmacache___230 {
	u64 seqnum;
	struct vm_area_struct___230 *vmas[4];
};

struct page_frag___230 {
	struct page___230 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___231;

struct pid___202;

struct nsproxy___211;

struct signal_struct___226;

struct bio_list___118;

struct backing_dev_info___107;

struct io_context___118;

struct css_set___155;

struct mem_cgroup___98;

struct request_queue___118;

struct vm_struct___208;

struct task_struct___232 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___232 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___231 *mm;
	struct mm_struct___231 *active_mm;
	struct vmacache___230 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___232 *real_parent;
	struct task_struct___232 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___232 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___202 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___211 *nsproxy;
	struct signal_struct___226 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___232 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___118 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___107 *backing_dev_info;
	struct io_context___118 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___155 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___75 *splice_pipe;
	struct page_frag___230 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___98 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___98 *active_memcg;
	struct request_queue___118 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___232 *oom_reaper_list;
	struct vm_struct___208 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___213;

struct kobj_type___213;

struct kernfs_node___213;

struct kobject___213 {
	const char *name;
	struct list_head entry;
	struct kobject___213 *parent;
	struct kset___213 *kset;
	struct kobj_type___213 *ktype;
	struct kernfs_node___213 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___210 {
	struct kobject___213 kobj;
	struct module___209 *mod;
	struct kobject___213 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___209 {
	struct module___209 *mod;
	struct latch_tree_node node;
};

struct module_layout___209 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___209 mtn;
};

struct module_attribute___209;

struct kernel_param___209;

struct module___209 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___210 mkobj;
	struct module_attribute___209 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___213 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___209 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___209 core_layout;
	struct module_layout___209 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___230 *pgtable_t___230;

struct address_space___225;

struct page_pool___63;

struct dev_pagemap___220;

struct page___230 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___225 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___63 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___230 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___230 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___231 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___220 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___220;

struct vm_area_struct___230 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___230 *vm_next;
	struct vm_area_struct___230 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___231 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___220 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___225 *vm_file;
	struct file___225 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___230;

struct mm_struct___231 {
	struct {
		struct vm_area_struct___230 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___225 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___230 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___232 *owner;
		struct user_namespace___14 *user_ns;
		struct file___225 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___225;

struct address_space___225 {
	struct inode___225 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___225 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___203;

struct page_pool_params___63 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___203 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___63 {
	u32 count;
	struct page___230 *cache[128];
};

struct page_pool___63 {
	struct page_pool_params___63 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___230 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___63 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___220;

struct dev_pagemap___220 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___220 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___225;

struct path___225 {
	struct vfsmount___225 *mnt;
	struct dentry___225 *dentry;
};

struct fown_struct___202 {
	rwlock_t lock;
	struct pid___202 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___225 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___225 f_path;
	struct inode___225 *f_inode;
	const struct file_operations___226 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___202 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___225 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___220;

struct vm_operations_struct___220 {
	void (*open)(struct vm_area_struct___230 *);
	void (*close)(struct vm_area_struct___230 *);
	int (*may_split)(struct vm_area_struct___230 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___230 *);
	int (*mprotect)(struct vm_area_struct___230 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___220 *);
	vm_fault_t (*huge_fault)(struct vm_fault___220 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___220 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___230 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___220 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___220 *);
	int (*access)(struct vm_area_struct___230 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___230 *);
	int (*set_policy)(struct vm_area_struct___230 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___230 *, long unsigned int);
	struct page___230 * (*find_special_page)(struct vm_area_struct___230 *, long unsigned int);
};

struct core_thread___230 {
	struct task_struct___232 *task;
	struct core_thread___230 *next;
};

struct core_state___230 {
	atomic_t nr_threads;
	struct core_thread___230 dumper;
	struct completion startup;
};

struct vm_fault___220 {
	const struct {
		struct vm_area_struct___230 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___230 *cow_page;
	struct page___230 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___230 prealloc_pte;
};

struct pglist_data___106;

struct lruvec___106 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___106 *pgdat;
};

struct zone___106 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___106 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___106 {
	struct zone___106 *zone;
	int zone_idx;
};

struct zonelist___106 {
	struct zoneref___106 _zonerefs[321];
};

struct pglist_data___106 {
	struct zone___106 node_zones[5];
	struct zonelist___106 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___232 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___232 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___106 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___213;

struct kernfs_elem_dir___213 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___213 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___213;

struct kernfs_root___213 {
	struct kernfs_node___213 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___213 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___213 {
	struct kernfs_node___213 *target_kn;
};

struct kernfs_ops___213;

struct kernfs_elem_attr___213 {
	const struct kernfs_ops___213 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___213 *notify_next;
};

struct kernfs_node___213 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___213 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___213 dir;
		struct kernfs_elem_symlink___213 symlink;
		struct kernfs_elem_attr___213 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___213;

struct kernfs_ops___213 {
	int (*open)(struct kernfs_open_file___213 *);
	void (*release)(struct kernfs_open_file___213 *);
	int (*seq_show)(struct seq_file___200 *, void *);
	void * (*seq_start)(struct seq_file___200 *, loff_t *);
	void * (*seq_next)(struct seq_file___200 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___200 *, void *);
	ssize_t (*read)(struct kernfs_open_file___213 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___213 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___213 *, struct poll_table_struct___150 *);
	int (*mmap)(struct kernfs_open_file___213 *, struct vm_area_struct___230 *);
};

struct kernfs_syscall_ops___213 {
	int (*show_options)(struct seq_file___200 *, struct kernfs_root___213 *);
	int (*mkdir)(struct kernfs_node___213 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___213 *);
	int (*rename)(struct kernfs_node___213 *, struct kernfs_node___213 *, const char *);
	int (*show_path)(struct seq_file___200 *, struct kernfs_node___213 *, struct kernfs_root___213 *);
};

struct seq_operations___200;

struct seq_file___200 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___200 *op;
	int poll_event;
	const struct file___225 *file;
	void *private;
};

struct kernfs_open_file___213 {
	struct kernfs_node___213 *kn;
	struct file___225 *file;
	struct seq_file___200 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___220 *vm_ops;
};

typedef void (*poll_queue_proc___157)(struct file___225 *, wait_queue_head_t *, struct poll_table_struct___150 *);

struct poll_table_struct___150 {
	poll_queue_proc___157 _qproc;
	__poll_t _key;
};

struct sock___33;

struct kobj_ns_type_operations___32 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___33 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct net___48;

typedef struct {
	struct net___48 *net;
} possible_net_t___43;

struct proto___32;

struct sock_common___32 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___32 *skc_prot;
	possible_net_t___43 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___33 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___44;

struct sk_buff_head___43 {
	struct sk_buff___44 *next;
	struct sk_buff___44 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct cgroup___155;

struct sock_cgroup_data___32 {
	struct cgroup___155 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___32;

struct socket_wq___33;

struct dst_entry___32;

struct socket___34;

struct net_device___45;

struct sock___33 {
	struct sock_common___32 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___43 sk_error_queue;
	struct sk_buff___44 *sk_rx_skb_cache;
	struct sk_buff_head___43 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___44 *head;
		struct sk_buff___44 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___32 *sk_filter;
	union {
		struct socket_wq___33 *sk_wq;
		struct socket_wq___33 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___32 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___32 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___44 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___44 *sk_tx_skb_cache;
	struct sk_buff_head___43 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___230 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___32 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___202 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___34 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___32 sk_cgrp_data;
	struct mem_cgroup___98 *sk_memcg;
	void (*sk_state_change)(struct sock___33 *);
	void (*sk_data_ready)(struct sock___33 *);
	void (*sk_write_space)(struct sock___33 *);
	void (*sk_error_report)(struct sock___33 *);
	int (*sk_backlog_rcv)(struct sock___33 *, struct sk_buff___44 *);
	struct sk_buff___44 * (*sk_validate_xmit_skb)(struct sock___33 *, struct net_device___45 *, struct sk_buff___44 *);
	void (*sk_destruct)(struct sock___33 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct pid_namespace___202;

struct upid___202 {
	int nr;
	struct pid_namespace___202 *ns;
};

struct pid_namespace___202 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___232 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___202 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___202 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___202 numbers[1];
};

struct signal_struct___226 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___232 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___232 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___202 *pids[4];
	struct pid___202 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___231 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___155;

struct nsproxy___211 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___202 *pid_ns_for_children;
	struct net___48 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___155 *cgroup_ns;
};

struct bio___118;

struct bio_list___118 {
	struct bio___118 *head;
	struct bio___118 *tail;
};

struct cgroup_subsys_state___155;

struct bdi_writeback___107 {
	struct backing_dev_info___107 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___155 *memcg_css;
	struct cgroup_subsys_state___155 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___107 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___107 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___203 *dev;
	char dev_name[64];
	struct device___203 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___225 *debug_dir;
};

struct io_cq___118;

struct io_context___118 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___118 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___155 {
	struct cgroup_subsys_state___155 *subsys[14];
	refcount_t refcount;
	struct css_set___155 *dom_cset;
	struct cgroup___155 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___155 *mg_src_cgrp;
	struct cgroup___155 *mg_dst_cgrp;
	struct css_set___155 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___225;

struct pipe_buffer___75;

struct pipe_inode_info___75 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___230 *tmp_page;
	struct fasync_struct___225 *fasync_readers;
	struct fasync_struct___225 *fasync_writers;
	struct pipe_buffer___75 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___155;

struct cgroup_subsys_state___155 {
	struct cgroup___155 *cgroup;
	struct cgroup_subsys___155 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___155 *parent;
};

struct cgroup_file___155 {
	struct kernfs_node___213 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___98;

struct mem_cgroup_per_node___98;

struct mem_cgroup___98 {
	struct cgroup_subsys_state___155 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___155 events_file;
	struct cgroup_file___155 events_local_file;
	struct cgroup_file___155 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___98 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___232 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___98 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___118;

struct blk_integrity___118 {
	const struct blk_integrity_profile___118 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___118 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___118 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___118;

struct elevator_queue___118;

struct blk_mq_ops___115;

struct blk_mq_hw_ctx___115;

struct gendisk___121;

struct blkcg_gq___109;

struct blk_mq_tag_set___115;

struct request_queue___118 {
	struct request___118 *last_merge;
	struct elevator_queue___118 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___115 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___115 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___121 *disk;
	struct kobject___213 kobj;
	struct kobject___213 *mq_kobj;
	struct blk_integrity___118 integrity;
	struct device___203 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___109 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___115 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___118 bio_split;
	struct dentry___225 *debugfs_dir;
	struct dentry___225 *sched_debugfs_dir;
	struct dentry___225 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___208 {
	struct vm_struct___208 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___230 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___213;

struct attribute_group___213 {
	const char *name;
	umode_t (*is_visible)(struct kobject___213 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___213 *, struct bin_attribute___213 *, int);
	struct attribute **attrs;
	struct bin_attribute___213 **bin_attrs;
};

struct bin_attribute___213 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___225 * (*f_mapping)();
	ssize_t (*read)(struct file___225 *, struct kobject___213 *, struct bin_attribute___213 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___225 *, struct kobject___213 *, struct bin_attribute___213 *, char *, loff_t, size_t);
	int (*mmap)(struct file___225 *, struct kobject___213 *, struct bin_attribute___213 *, struct vm_area_struct___230 *);
};

struct sysfs_ops___213 {
	ssize_t (*show)(struct kobject___213 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___213 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___213;

struct kset___213 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___213 kobj;
	const struct kset_uevent_ops___213 *uevent_ops;
};

struct kobj_type___213 {
	void (*release)(struct kobject___213 *);
	const struct sysfs_ops___213 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___213 **default_groups;
	const struct kobj_ns_type_operations___32 * (*child_ns_type)(struct kobject___213 *);
	const void * (*namespace)(struct kobject___213 *);
	void (*get_ownership)(struct kobject___213 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___213 {
	int (* const filter)(struct kset___213 *, struct kobject___213 *);
	const char * (* const name)(struct kset___213 *, struct kobject___213 *);
	int (* const uevent)(struct kset___213 *, struct kobject___213 *, struct kobj_uevent_env *);
};

struct wakeup_source___203;

struct dev_pm_info___203 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___203 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___203 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___203;

struct bus_type___203;

struct device_driver___203;

struct dev_pm_domain___203;

struct irq_domain___56;

struct device_node___89;

struct fwnode_handle___199;

struct class___203;

struct device___203 {
	struct kobject___213 kobj;
	struct device___203 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___203 *type;
	struct bus_type___203 *bus;
	struct device_driver___203 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___203 power;
	struct dev_pm_domain___203 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___56 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___89 *of_node;
	struct fwnode_handle___199 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___203 *class;
	const struct attribute_group___213 **groups;
	void (*release)(struct device___203 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___203 {
	int (*prepare)(struct device___203 *);
	void (*complete)(struct device___203 *);
	int (*suspend)(struct device___203 *);
	int (*resume)(struct device___203 *);
	int (*freeze)(struct device___203 *);
	int (*thaw)(struct device___203 *);
	int (*poweroff)(struct device___203 *);
	int (*restore)(struct device___203 *);
	int (*suspend_late)(struct device___203 *);
	int (*resume_early)(struct device___203 *);
	int (*freeze_late)(struct device___203 *);
	int (*thaw_early)(struct device___203 *);
	int (*poweroff_late)(struct device___203 *);
	int (*restore_early)(struct device___203 *);
	int (*suspend_noirq)(struct device___203 *);
	int (*resume_noirq)(struct device___203 *);
	int (*freeze_noirq)(struct device___203 *);
	int (*thaw_noirq)(struct device___203 *);
	int (*poweroff_noirq)(struct device___203 *);
	int (*restore_noirq)(struct device___203 *);
	int (*runtime_suspend)(struct device___203 *);
	int (*runtime_resume)(struct device___203 *);
	int (*runtime_idle)(struct device___203 *);
};

struct wakeup_source___203 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___203 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___203 {
	struct dev_pm_ops___203 ops;
	int (*start)(struct device___203 *);
	void (*detach)(struct device___203 *, bool);
	int (*activate)(struct device___203 *);
	void (*sync)(struct device___203 *);
	void (*dismiss)(struct device___203 *);
};

struct bus_type___203 {
	const char *name;
	const char *dev_name;
	struct device___203 *dev_root;
	const struct attribute_group___213 **bus_groups;
	const struct attribute_group___213 **dev_groups;
	const struct attribute_group___213 **drv_groups;
	int (*match)(struct device___203 *, struct device_driver___203 *);
	int (*uevent)(struct device___203 *, struct kobj_uevent_env *);
	int (*probe)(struct device___203 *);
	void (*sync_state)(struct device___203 *);
	void (*remove)(struct device___203 *);
	void (*shutdown)(struct device___203 *);
	int (*online)(struct device___203 *);
	int (*offline)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	int (*num_vf)(struct device___203 *);
	int (*dma_configure)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___203 {
	const char *name;
	struct bus_type___203 *bus;
	struct module___209 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___203 *);
	void (*sync_state)(struct device___203 *);
	int (*remove)(struct device___203 *);
	void (*shutdown)(struct device___203 *);
	int (*suspend)(struct device___203 *, pm_message_t);
	int (*resume)(struct device___203 *);
	const struct attribute_group___213 **groups;
	const struct attribute_group___213 **dev_groups;
	const struct dev_pm_ops___203 *pm;
	void (*coredump)(struct device___203 *);
	struct driver_private *p;
};

struct device_type___203 {
	const char *name;
	const struct attribute_group___213 **groups;
	int (*uevent)(struct device___203 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___203 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___203 *);
	const struct dev_pm_ops___203 *pm;
};

struct class___203 {
	const char *name;
	struct module___209 *owner;
	const struct attribute_group___213 **class_groups;
	const struct attribute_group___213 **dev_groups;
	struct kobject___213 *dev_kobj;
	int (*dev_uevent)(struct device___203 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___203 *, umode_t *);
	void (*class_release)(struct class___203 *);
	void (*dev_release)(struct device___203 *);
	int (*shutdown_pre)(struct device___203 *);
	const struct kobj_ns_type_operations___32 *ns_type;
	const void * (*namespace)(struct device___203 *);
	void (*get_ownership)(struct device___203 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___203 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___56;

struct irq_domain_chip_generic___56;

struct irq_data___58;

struct irq_domain___56 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___56 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___199 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___56 *gc;
	struct irq_domain___56 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___58 *revmap[0];
};

struct fwnode_operations___199;

struct fwnode_handle___199 {
	struct fwnode_handle___199 *secondary;
	const struct fwnode_operations___199 *ops;
	struct device___203 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___66;

struct device_node___89 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___199 fwnode;
	struct property___66 *properties;
	struct property___66 *deadprops;
	struct device_node___89 *parent;
	struct device_node___89 *child;
	struct device_node___89 *sibling;
	struct kobject___213 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_desc___58;

typedef void (*irq_flow_handler_t___58)(struct irq_desc___58 *);

struct irq_chip___58;

struct irq_data___58 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___58 *chip;
	struct irq_domain___56 *domain;
	struct irq_data___58 *parent_data;
	void *chip_data;
};

struct irqaction___40;

struct irq_desc___58 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___58 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___58 handle_irq;
	struct irqaction___40 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___213 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___209 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___199;

struct fwnode_endpoint___199;

struct fwnode_operations___199 {
	struct fwnode_handle___199 * (*get)(struct fwnode_handle___199 *);
	void (*put)(struct fwnode_handle___199 *);
	bool (*device_is_available)(const struct fwnode_handle___199 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___199 *, const struct device___203 *);
	bool (*property_present)(const struct fwnode_handle___199 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___199 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___199 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___199 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*get_parent)(const struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*get_next_child_node)(const struct fwnode_handle___199 *, struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*get_named_child_node)(const struct fwnode_handle___199 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___199 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___199 *);
	struct fwnode_handle___199 * (*graph_get_next_endpoint)(const struct fwnode_handle___199 *, struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*graph_get_remote_endpoint)(const struct fwnode_handle___199 *);
	struct fwnode_handle___199 * (*graph_get_port_parent)(struct fwnode_handle___199 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___199 *, struct fwnode_endpoint___199 *);
	int (*add_links)(struct fwnode_handle___199 *);
};

struct fwnode_endpoint___199 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___199 *local_fwnode;
};

struct fwnode_reference_args___199 {
	struct fwnode_handle___199 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___58 {
	struct device___203 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___58 *);
	void (*irq_shutdown)(struct irq_data___58 *);
	void (*irq_enable)(struct irq_data___58 *);
	void (*irq_disable)(struct irq_data___58 *);
	void (*irq_ack)(struct irq_data___58 *);
	void (*irq_mask)(struct irq_data___58 *);
	void (*irq_mask_ack)(struct irq_data___58 *);
	void (*irq_unmask)(struct irq_data___58 *);
	void (*irq_eoi)(struct irq_data___58 *);
	int (*irq_set_affinity)(struct irq_data___58 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___58 *);
	int (*irq_set_type)(struct irq_data___58 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___58 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___58 *);
	void (*irq_bus_sync_unlock)(struct irq_data___58 *);
	void (*irq_cpu_online)(struct irq_data___58 *);
	void (*irq_cpu_offline)(struct irq_data___58 *);
	void (*irq_suspend)(struct irq_data___58 *);
	void (*irq_resume)(struct irq_data___58 *);
	void (*irq_pm_shutdown)(struct irq_data___58 *);
	void (*irq_calc_mask)(struct irq_data___58 *);
	void (*irq_print_chip)(struct irq_data___58 *, struct seq_file___200 *);
	int (*irq_request_resources)(struct irq_data___58 *);
	void (*irq_release_resources)(struct irq_data___58 *);
	void (*irq_compose_msi_msg)(struct irq_data___58 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___58 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___58 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___58 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___58 *, void *);
	void (*ipi_send_single)(struct irq_data___58 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___58 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___58 *);
	void (*irq_nmi_teardown)(struct irq_data___58 *);
	long unsigned int flags;
};

struct irqaction___40 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___40 *next;
	irq_handler_t thread_fn;
	struct task_struct___232 *thread;
	struct irqaction___40 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___56 {
	struct irq_chip___58 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___58 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___56 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___56 *);
	void (*resume)(struct irq_chip_generic___56 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___56 *domain;
	struct list_head list;
	struct irq_chip_type___56 chip_types[0];
};

struct irq_domain_chip_generic___56 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___56 *gc[0];
};

struct pci_bus___19;

struct pci_slot___19 {
	struct pci_bus___19 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___213 kobj;
};

struct pci_dev___19;

struct pci_ops___19;

struct pci_bus___19 {
	struct list_head node;
	struct pci_bus___19 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___19 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___19 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___203 *bridge;
	struct device___203 dev;
	struct bin_attribute___213 *legacy_io;
	struct bin_attribute___213 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___19;

struct pci_dev___19 {
	struct list_head bus_list;
	struct pci_bus___19 *bus;
	struct pci_bus___19 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___19 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___19 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___19 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___203 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___213 *res_attr[17];
	struct bin_attribute___213 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___213 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___19 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___19;

struct pci_driver___19 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___19 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___19 *);
	int (*suspend)(struct pci_dev___19 *, pm_message_t);
	int (*resume)(struct pci_dev___19 *);
	void (*shutdown)(struct pci_dev___19 *);
	int (*sriov_configure)(struct pci_dev___19 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___19 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___19 *);
	const struct pci_error_handlers___19 *err_handler;
	const struct attribute_group___213 **groups;
	const struct attribute_group___213 **dev_groups;
	struct device_driver___203 driver;
	struct pci_dynids dynids;
};

struct pci_ops___19 {
	int (*add_bus)(struct pci_bus___19 *);
	void (*remove_bus)(struct pci_bus___19 *);
	void * (*map_bus)(struct pci_bus___19 *, unsigned int, int);
	int (*read)(struct pci_bus___19 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___19 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___19 {
	pci_ers_result_t (*error_detected)(struct pci_dev___19 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___19 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___19 *);
	void (*reset_prepare)(struct pci_dev___19 *);
	void (*reset_done)(struct pci_dev___19 *);
	void (*resume)(struct pci_dev___19 *);
};

struct shrink_control___98 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___98 *memcg;
};

struct shrinker___98 {
	long unsigned int (*count_objects)(struct shrinker___98 *, struct shrink_control___98 *);
	long unsigned int (*scan_objects)(struct shrinker___98 *, struct shrink_control___98 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___220 {
	void (*page_free)(struct page___230 *);
	void (*kill)(struct dev_pagemap___220 *);
	void (*cleanup)(struct dev_pagemap___220 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___220 *);
};

struct dentry_operations___225;

struct dentry___225 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___225 *d_parent;
	struct qstr d_name;
	struct inode___225 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___225 *d_op;
	struct super_block___225 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___225;

struct inode___225 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___225 *i_op;
	struct super_block___225 *i_sb;
	struct address_space___225 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___107 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___226 *i_fop;
		void (*free_inode)(struct inode___225 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___225 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___75 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___225 {
	int (*d_revalidate)(struct dentry___225 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___225 *, unsigned int);
	int (*d_hash)(const struct dentry___225 *, struct qstr *);
	int (*d_compare)(const struct dentry___225 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___225 *);
	int (*d_init)(struct dentry___225 *);
	void (*d_release)(struct dentry___225 *);
	void (*d_prune)(struct dentry___225 *);
	void (*d_iput)(struct dentry___225 *, struct inode___225 *);
	char * (*d_dname)(struct dentry___225 *, char *, int);
	struct vfsmount___225 * (*d_automount)(struct path___225 *);
	int (*d_manage)(const struct path___225 *, bool);
	struct dentry___225 * (*d_real)(struct dentry___225 *, const struct inode___225 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___225;

struct mem_dqinfo___225 {
	struct quota_format_type___225 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___225;

struct quota_info___225 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___225 *files[3];
	struct mem_dqinfo___225 info[3];
	const struct quota_format_ops___225 *ops[3];
};

struct rcuwait___226 {
	struct task_struct___232 *task;
};

struct percpu_rw_semaphore___226 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___226 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___225 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___226 rw_sem[3];
};

struct super_operations___225;

struct dquot_operations___225;

struct quotactl_ops___225;

struct block_device___121;

struct super_block___225 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___225 *s_type;
	const struct super_operations___225 *s_op;
	const struct dquot_operations___225 *dq_op;
	const struct quotactl_ops___225 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___225 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___121 *s_bdev;
	struct backing_dev_info___107 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___225 s_dquot;
	struct sb_writers___225 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___225 *s_d_op;
	int cleancache_poolid;
	struct shrinker___98 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___225 {
	struct dentry___225 *mnt_root;
	struct super_block___225 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct psi_group___155 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___232 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___39;

struct cgroup_bpf___39 {
	struct bpf_prog_array___39 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___39 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___155;

struct cgroup_rstat_cpu___155;

struct cgroup___155 {
	struct cgroup_subsys_state___155 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___213 *kn;
	struct cgroup_file___155 procs_file;
	struct cgroup_file___155 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___155 *subsys[14];
	struct cgroup_root___155 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___155 *dom_cgrp;
	struct cgroup___155 *old_dom_cgrp;
	struct cgroup_rstat_cpu___155 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___155 psi;
	struct cgroup_bpf___39 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___118 {
	struct request_queue___118 *q;
	struct io_context___118 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___225 {
	struct file___225 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___225 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___105 *ki_waitq;
	};
};

struct iattr___225 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___225 *ia_file;
};

struct dquot___225 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___225 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___225 {
	int qf_fmt_id;
	const struct quota_format_ops___225 *qf_ops;
	struct module___209 *qf_owner;
	struct quota_format_type___225 *qf_next;
};

struct quota_format_ops___225 {
	int (*check_quota_file)(struct super_block___225 *, int);
	int (*read_file_info)(struct super_block___225 *, int);
	int (*write_file_info)(struct super_block___225 *, int);
	int (*free_file_info)(struct super_block___225 *, int);
	int (*read_dqblk)(struct dquot___225 *);
	int (*commit_dqblk)(struct dquot___225 *);
	int (*release_dqblk)(struct dquot___225 *);
	int (*get_next_id)(struct super_block___225 *, struct kqid *);
};

struct dquot_operations___225 {
	int (*write_dquot)(struct dquot___225 *);
	struct dquot___225 * (*alloc_dquot)(struct super_block___225 *, int);
	void (*destroy_dquot)(struct dquot___225 *);
	int (*acquire_dquot)(struct dquot___225 *);
	int (*release_dquot)(struct dquot___225 *);
	int (*mark_dirty)(struct dquot___225 *);
	int (*write_info)(struct super_block___225 *, int);
	qsize_t * (*get_reserved_space)(struct inode___225 *);
	int (*get_projid)(struct inode___225 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___225 *, qsize_t *);
	int (*get_next_id)(struct super_block___225 *, struct kqid *);
};

struct quotactl_ops___225 {
	int (*quota_on)(struct super_block___225 *, int, int, const struct path___225 *);
	int (*quota_off)(struct super_block___225 *, int);
	int (*quota_enable)(struct super_block___225 *, unsigned int);
	int (*quota_disable)(struct super_block___225 *, unsigned int);
	int (*quota_sync)(struct super_block___225 *, int);
	int (*set_info)(struct super_block___225 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___225 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___225 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___225 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___225 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___225 *, unsigned int);
};

struct writeback_control___107;

struct address_space_operations___225 {
	int (*writepage)(struct page___230 *, struct writeback_control___107 *);
	int (*readpage)(struct file___225 *, struct page___230 *);
	int (*writepages)(struct address_space___225 *, struct writeback_control___107 *);
	int (*set_page_dirty)(struct page___230 *);
	int (*readpages)(struct file___225 *, struct address_space___225 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___225 *, struct address_space___225 *, loff_t, unsigned int, unsigned int, struct page___230 **, void **);
	int (*write_end)(struct file___225 *, struct address_space___225 *, loff_t, unsigned int, unsigned int, struct page___230 *, void *);
	sector_t (*bmap)(struct address_space___225 *, sector_t);
	void (*invalidatepage)(struct page___230 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___230 *, gfp_t);
	void (*freepage)(struct page___230 *);
	ssize_t (*direct_IO)(struct kiocb___225 *, struct iov_iter___145 *);
	int (*migratepage)(struct address_space___225 *, struct page___230 *, struct page___230 *, enum migrate_mode);
	bool (*isolate_page)(struct page___230 *, isolate_mode_t);
	void (*putback_page)(struct page___230 *);
	int (*launder_page)(struct page___230 *);
	int (*is_partially_uptodate)(struct page___230 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___230 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___225 *, struct page___230 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___225 *, sector_t *);
	void (*swap_deactivate)(struct file___225 *);
};

struct writeback_control___107 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___107 *wb;
	struct inode___225 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___142;

struct iov_iter___145 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___142 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___75 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___225 {
	struct dentry___225 * (*lookup)(struct inode___225 *, struct dentry___225 *, unsigned int);
	const char * (*get_link)(struct dentry___225 *, struct inode___225 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___225 *, int);
	struct posix_acl * (*get_acl)(struct inode___225 *, int, bool);
	int (*readlink)(struct dentry___225 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___225 *, struct dentry___225 *, umode_t, bool);
	int (*link)(struct dentry___225 *, struct inode___225 *, struct dentry___225 *);
	int (*unlink)(struct inode___225 *, struct dentry___225 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___225 *, struct dentry___225 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___225 *, struct dentry___225 *, umode_t);
	int (*rmdir)(struct inode___225 *, struct dentry___225 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___225 *, struct dentry___225 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___225 *, struct dentry___225 *, struct inode___225 *, struct dentry___225 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___225 *, struct iattr___225 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___225 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___225 *, char *, size_t);
	int (*fiemap)(struct inode___225 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___225 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___225 *, struct dentry___225 *, struct file___225 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___225 *, struct dentry___225 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___225 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___225 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___225 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___225 {
	void (*fl_copy_lock)(struct file_lock___225 *, struct file_lock___225 *);
	void (*fl_release_private)(struct file_lock___225 *);
};

struct lock_manager_operations___225;

struct file_lock___225 {
	struct file_lock___225 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___225 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___225 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___225 *fl_ops;
	const struct lock_manager_operations___225 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___225 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___225 *);
	int (*lm_grant)(struct file_lock___225 *, int);
	bool (*lm_break)(struct file_lock___225 *);
	int (*lm_change)(struct file_lock___225 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___225 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___225 *);
};

struct fasync_struct___225 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___225 *fa_next;
	struct file___225 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___225 {
	struct inode___225 * (*alloc_inode)(struct super_block___225 *);
	void (*destroy_inode)(struct inode___225 *);
	void (*free_inode)(struct inode___225 *);
	void (*dirty_inode)(struct inode___225 *, int);
	int (*write_inode)(struct inode___225 *, struct writeback_control___107 *);
	int (*drop_inode)(struct inode___225 *);
	void (*evict_inode)(struct inode___225 *);
	void (*put_super)(struct super_block___225 *);
	int (*sync_fs)(struct super_block___225 *, int);
	int (*freeze_super)(struct super_block___225 *);
	int (*freeze_fs)(struct super_block___225 *);
	int (*thaw_super)(struct super_block___225 *);
	int (*unfreeze_fs)(struct super_block___225 *);
	int (*statfs)(struct dentry___225 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___225 *, int *, char *);
	void (*umount_begin)(struct super_block___225 *);
	int (*show_options)(struct seq_file___200 *, struct dentry___225 *);
	int (*show_devname)(struct seq_file___200 *, struct dentry___225 *);
	int (*show_path)(struct seq_file___200 *, struct dentry___225 *);
	int (*show_stats)(struct seq_file___200 *, struct dentry___225 *);
	ssize_t (*quota_read)(struct super_block___225 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___225 *, int, const char *, size_t, loff_t);
	struct dquot___225 ** (*get_dquots)(struct inode___225 *);
	long int (*nr_cached_objects)(struct super_block___225 *, struct shrink_control___98 *);
	long int (*free_cached_objects)(struct super_block___225 *, struct shrink_control___98 *);
	struct file___225 * (*real_loop)(struct file___225 *);
};

struct block_device___121 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___225 *bd_inode;
	struct super_block___225 *bd_super;
	void *bd_claiming;
	struct device___203 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___213 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___121 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___225 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___118(struct bio___118 *);

struct bio_vec___142 {
	struct page___230 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___118;

struct bio___118 {
	struct bio___118 *bi_next;
	struct block_device___121 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___118 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___109 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___118 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___142 *bi_io_vec;
	struct bio_set___118 *bi_pool;
	struct bio_vec___142 bi_inline_vecs[0];
};

struct platform_device___38 {
	const char *name;
	int id;
	bool id_auto;
	struct device___203 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct property___66 {
	char *name;
	int length;
	void *value;
	struct property___66 *next;
	long unsigned int _flags;
	struct bin_attribute___213 attr;
};

struct of_phandle_args___38 {
	struct device_node___89 *np;
	int args_count;
	uint32_t args[16];
};

struct irq_fwspec___54 {
	struct fwnode_handle___199 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___56 {
	int (*match)(struct irq_domain___56 *, struct device_node___89 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___56 *, struct irq_fwspec___54 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___56 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___56 *, unsigned int);
	int (*xlate)(struct irq_domain___56 *, struct device_node___89 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___56 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___56 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___56 *, struct irq_data___58 *, bool);
	void (*deactivate)(struct irq_domain___56 *, struct irq_data___58 *);
	int (*translate)(struct irq_domain___56 *, struct irq_fwspec___54 *, long unsigned int *, unsigned int *);
};

struct seq_operations___200 {
	void * (*start)(struct seq_file___200 *, loff_t *);
	void (*stop)(struct seq_file___200 *, void *);
	void * (*next)(struct seq_file___200 *, void *, loff_t *);
	int (*show)(struct seq_file___200 *, void *);
};

struct gpio_chip___11;

struct gpio_irq_chip___11 {
	struct irq_chip___58 *chip;
	struct irq_domain___56 *domain;
	const struct irq_domain_ops___56 *domain_ops;
	struct fwnode_handle___199 *fwnode;
	struct irq_domain___56 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___11 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___11 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___11 *, unsigned int);
	struct irq_domain_ops___56 child_irq_domain_ops;
	irq_flow_handler_t___58 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___58 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___11 *);
	void (*init_valid_mask)(struct gpio_chip___11 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___58 *);
	void (*irq_disable)(struct irq_data___58 *);
	void (*irq_unmask)(struct irq_data___58 *);
	void (*irq_mask)(struct irq_data___58 *);
};

struct gpio_chip___11 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___203 *parent;
	struct module___209 *owner;
	int (*request)(struct gpio_chip___11 *, unsigned int);
	void (*free)(struct gpio_chip___11 *, unsigned int);
	int (*get_direction)(struct gpio_chip___11 *, unsigned int);
	int (*direction_input)(struct gpio_chip___11 *, unsigned int);
	int (*direction_output)(struct gpio_chip___11 *, unsigned int, int);
	int (*get)(struct gpio_chip___11 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___11 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___11 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___11 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___11 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___11 *, unsigned int);
	void (*dbg_show)(struct seq_file___200 *, struct gpio_chip___11 *);
	int (*init_valid_mask)(struct gpio_chip___11 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___11 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___11 irq;
	long unsigned int *valid_mask;
	struct device_node___89 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___11 *, const struct of_phandle_args___38 *, u32 *);
};

struct bcma_device;

struct bcma_chipcommon_pmu {
	struct bcma_device *core;
	u8 rev;
	u32 crystalfreq;
};

struct bcma_bus;

struct bcma_device {
	struct bcma_bus *bus;
	struct bcma_device_id id;
	struct device___203 dev;
	struct device___203 *dma_dev;
	unsigned int irq;
	bool dev_registered;
	u8 core_index;
	u8 core_unit;
	u32 addr;
	u32 addr_s[8];
	u32 wrap;
	void *io_addr;
	void *io_wrap;
	void *drvdata;
	struct list_head list;
};

struct bcma_sflash {
	bool present;
	u32 blocksize;
	u16 numblocks;
	u32 size;
};

struct bcma_drv_cc {
	struct bcma_device *core;
	u32 status;
	u32 capabilities;
	u32 capabilities_ext;
	u8 setup_done: 1;
	u8 early_setup_done: 1;
	long: 47;
	long: 64;
	long: 64;
	u16 fast_pwrup_delay;
	struct bcma_chipcommon_pmu pmu;
	struct bcma_sflash sflash;
	u32 ticks_per_ms;
	struct platform_device___38 *watchdog;
	spinlock_t gpio_lock;
	struct gpio_chip___11 gpio;
};

struct bcma_drv_cc_b {
	struct bcma_device *core;
	u8 setup_done: 1;
	long: 63;
	long: 64;
	void *mii;
};

struct bcma_drv_pci {
	struct bcma_device *core;
	u8 early_setup_done: 1;
	u8 setup_done: 1;
	u8 hostmode: 1;
	long: 63;
	long: 64;
};

struct bcma_drv_pcie2 {
	struct bcma_device *core;
	u16 reqsize;
};

struct bcma_drv_mips {
	struct bcma_device *core;
	u8 setup_done: 1;
	u8 early_setup_done: 1;
	long: 63;
	long: 64;
};

struct bcma_drv_gmac_cmn {
	struct bcma_device *core;
	struct mutex phy_mutex;
};

struct ssb_sprom_core_pwr_info {
	u8 itssi_2g;
	u8 itssi_5g;
	u8 maxpwr_2g;
	u8 maxpwr_5gl;
	u8 maxpwr_5g;
	u8 maxpwr_5gh;
	u16 pa_2g[4];
	u16 pa_5gl[4];
	u16 pa_5g[4];
	u16 pa_5gh[4];
};

struct ssb_sprom {
	u8 revision;
	char: 8;
	u8 il0mac[6];
	u8 et0mac[6];
	u8 et1mac[6];
	u8 et2mac[6];
	u8 et0phyaddr;
	u8 et1phyaddr;
	u8 et2phyaddr;
	u8 et0mdcport;
	u8 et1mdcport;
	u8 et2mdcport;
	u16 dev_id;
	u16 board_rev;
	u16 board_num;
	u16 board_type;
	u8 country_code;
	char alpha2[2];
	u8 leddc_on_time;
	u8 leddc_off_time;
	u8 ant_available_a;
	u8 ant_available_bg;
	u16 pa0b0;
	u16 pa0b1;
	u16 pa0b2;
	u16 pa1b0;
	u16 pa1b1;
	u16 pa1b2;
	u16 pa1lob0;
	u16 pa1lob1;
	u16 pa1lob2;
	u16 pa1hib0;
	u16 pa1hib1;
	u16 pa1hib2;
	u8 gpio0;
	u8 gpio1;
	u8 gpio2;
	u8 gpio3;
	u8 maxpwr_bg;
	u8 maxpwr_al;
	u8 maxpwr_a;
	u8 maxpwr_ah;
	u8 itssi_a;
	u8 itssi_bg;
	u8 tri2g;
	u8 tri5gl;
	u8 tri5g;
	u8 tri5gh;
	u8 txpid2g[4];
	u8 txpid5gl[4];
	u8 txpid5g[4];
	u8 txpid5gh[4];
	s8 rxpo2g;
	s8 rxpo5g;
	u8 rssisav2g;
	u8 rssismc2g;
	u8 rssismf2g;
	u8 bxa2g;
	u8 rssisav5g;
	u8 rssismc5g;
	u8 rssismf5g;
	u8 bxa5g;
	u16 cck2gpo;
	u32 ofdm2gpo;
	u32 ofdm5glpo;
	u32 ofdm5gpo;
	u32 ofdm5ghpo;
	u32 boardflags;
	u32 boardflags2;
	u32 boardflags3;
	u16 boardflags_lo;
	u16 boardflags_hi;
	u16 boardflags2_lo;
	u16 boardflags2_hi;
	struct ssb_sprom_core_pwr_info core_pwr_info[4];
	struct {
		s8 a0;
		s8 a1;
		s8 a2;
		s8 a3;
	} antenna_gain;
	struct {
		struct {
			u8 tssipos;
			u8 extpa_gain;
			u8 pdet_range;
			u8 tr_iso;
			u8 antswlut;
		} ghz2;
		struct {
			u8 tssipos;
			u8 extpa_gain;
			u8 pdet_range;
			u8 tr_iso;
			u8 antswlut;
		} ghz5;
	} fem;
	u16 mcs2gpo[8];
	u16 mcs5gpo[8];
	u16 mcs5glpo[8];
	u16 mcs5ghpo[8];
	u8 opo;
	u8 rxgainerr2ga[3];
	u8 rxgainerr5gla[3];
	u8 rxgainerr5gma[3];
	u8 rxgainerr5gha[3];
	u8 rxgainerr5gua[3];
	u8 noiselvl2ga[3];
	u8 noiselvl5gla[3];
	u8 noiselvl5gma[3];
	u8 noiselvl5gha[3];
	u8 noiselvl5gua[3];
	u8 regrev;
	u8 txchain;
	u8 rxchain;
	u8 antswitch;
	u16 cddpo;
	u16 stbcpo;
	u16 bw40po;
	u16 bwduppo;
	u8 tempthresh;
	u8 tempoffset;
	u16 rawtempsense;
	u8 measpower;
	u8 tempsense_slope;
	u8 tempcorrx;
	u8 tempsense_option;
	u8 freqoffset_corr;
	u8 iqcal_swp_dis;
	u8 hw_iqcal_en;
	u8 elna2g;
	u8 elna5g;
	u8 phycal_tempdelta;
	u8 temps_period;
	u8 temps_hysteresis;
	u8 measpower1;
	u8 measpower2;
	u8 pcieingress_war;
	u16 cckbw202gpo;
	u16 cckbw20ul2gpo;
	u32 legofdmbw202gpo;
	u32 legofdmbw20ul2gpo;
	u32 legofdmbw205glpo;
	u32 legofdmbw20ul5glpo;
	u32 legofdmbw205gmpo;
	u32 legofdmbw20ul5gmpo;
	u32 legofdmbw205ghpo;
	u32 legofdmbw20ul5ghpo;
	u32 mcsbw202gpo;
	u32 mcsbw20ul2gpo;
	u32 mcsbw402gpo;
	u32 mcsbw205glpo;
	u32 mcsbw20ul5glpo;
	u32 mcsbw405glpo;
	u32 mcsbw205gmpo;
	u32 mcsbw20ul5gmpo;
	u32 mcsbw405gmpo;
	u32 mcsbw205ghpo;
	u32 mcsbw20ul5ghpo;
	u32 mcsbw405ghpo;
	u16 mcs32po;
	u16 legofdm40duppo;
	u8 sar2g;
	u8 sar5g;
};

enum bcma_hosttype {
	BCMA_HOSTTYPE_PCI = 0,
	BCMA_HOSTTYPE_SDIO = 1,
	BCMA_HOSTTYPE_SOC = 2,
};

struct bcma_chipinfo {
	u16 id;
	u8 rev;
	u8 pkg;
};

struct bcma_boardinfo {
	u16 vendor;
	u16 type;
};

struct bcma_host_ops {
	u8 (*read8)(struct bcma_device *, u16);
	u16 (*read16)(struct bcma_device *, u16);
	u32 (*read32)(struct bcma_device *, u16);
	void (*write8)(struct bcma_device *, u16, u8);
	void (*write16)(struct bcma_device *, u16, u16);
	void (*write32)(struct bcma_device *, u16, u32);
	void (*block_read)(struct bcma_device *, void *, size_t, u16, u8);
	void (*block_write)(struct bcma_device *, const void *, size_t, u16, u8);
	u32 (*aread32)(struct bcma_device *, u16);
	void (*awrite32)(struct bcma_device *, u16, u32);
};

struct bcma_bus {
	struct device___203 *dev;
	void *mmio;
	const struct bcma_host_ops *ops;
	enum bcma_hosttype hosttype;
	bool host_is_pcie2;
	struct pci_dev___19 *host_pci;
	struct bcma_chipinfo chipinfo;
	struct bcma_boardinfo boardinfo;
	struct bcma_device *mapped_core;
	struct list_head cores;
	u8 nr_cores;
	u8 num;
	struct bcma_drv_cc drv_cc;
	struct bcma_drv_cc_b drv_cc_b;
	struct bcma_drv_pci drv_pci[2];
	struct bcma_drv_pcie2 drv_pcie2;
	struct bcma_drv_mips drv_mips;
	struct bcma_drv_gmac_cmn drv_gmac_cmn;
	struct ssb_sprom sprom;
};

struct kernel_param_ops___209 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___209 *);
	int (*get)(char *, const struct kernel_param___209 *);
	void (*free)(void *);
};

struct kparam_array___209;

struct kernel_param___209 {
	const char *name;
	struct module___209 *mod;
	const struct kernel_param_ops___209 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___209 *arr;
	};
};

struct kparam_array___209 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___209 *ops;
	void *elem;
};

struct module_attribute___209 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___209 *, struct module_kobject___210 *, char *);
	ssize_t (*store)(struct module_attribute___209 *, struct module_kobject___210 *, const char *, size_t);
	void (*setup)(struct module___209 *, const char *);
	int (*test)(struct module___209 *);
	void (*free)(struct module___209 *);
};

struct fib_rules_ops___32;

struct fqdir___48;

struct fib_notifier_ops___32;

struct netns_ipv4___48 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___32 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___33 *fibnl;
	struct sock___33 **icmp_sk;
	struct sock___33 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___33 **tcp_sk;
	struct fqdir___48 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___32 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___32 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___32 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___32;

struct dst_ops___48 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___48 *);
	struct dst_entry___32 * (*check)(struct dst_entry___32 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___32 *);
	unsigned int (*mtu)(const struct dst_entry___32 *);
	u32 * (*cow_metrics)(struct dst_entry___32 *, long unsigned int);
	void (*destroy)(struct dst_entry___32 *);
	void (*ifdown)(struct dst_entry___32 *, struct net_device___45 *, int);
	struct dst_entry___32 * (*negative_advice)(struct dst_entry___32 *);
	void (*link_failure)(struct sk_buff___44 *);
	void (*update_pmtu)(struct dst_entry___32 *, struct sock___33 *, struct sk_buff___44 *, u32, bool);
	void (*redirect)(struct dst_entry___32 *, struct sock___33 *, struct sk_buff___44 *);
	int (*local_out)(struct net___48 *, struct sock___33 *, struct sk_buff___44 *);
	struct neighbour___32 * (*neigh_lookup)(const struct dst_entry___32 *, struct sk_buff___44 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___32 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___48 {
	struct dst_ops___48 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___48 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___32 *fib6_rules_ops;
	struct sock___33 **icmp_sk;
	struct sock___33 *ndisc_sk;
	struct sock___33 *tcp_sk;
	struct sock___33 *igmp_sk;
	struct sock___33 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___32 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___32 *notifier_ops;
	struct fib_notifier_ops___32 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___48 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___48 *fqdir;
};

struct netns_sctp___32 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___33 *ctl_sock;
	struct sock___33 *udp4_sock;
	struct sock___33 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___39;

struct netns_bpf___39 {
	struct bpf_prog_array___39 *run_array[2];
	struct bpf_prog___39 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___48 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___33 *nlsk;
	struct sock___33 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___48 xfrm4_dst_ops;
	struct dst_ops___48 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___48 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___33 *rtnl;
	struct sock___33 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___45 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___48 ipv4;
	struct netns_ipv6___48 ipv6;
	struct netns_ieee802154_lowpan___48 ieee802154_lowpan;
	struct netns_sctp___32 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___43 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___39 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___48 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___33 *crypto_nlsk;
	struct sock___33 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___155 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___155 *root_cset;
};

struct msghdr___34 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___145 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___225 *msg_iocb;
};

struct socket_wq___33 {
	wait_queue_head_t wait;
	struct fasync_struct___225 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___33;

struct socket___34 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___225 *file;
	struct sock___33 *sk;
	const struct proto_ops___33 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___33 wq;
};

typedef int (*sk_read_actor_t___32)(read_descriptor_t *, struct sk_buff___44 *, unsigned int, size_t);

struct proto_ops___33 {
	int family;
	struct module___209 *owner;
	int (*release)(struct socket___34 *);
	int (*bind)(struct socket___34 *, struct sockaddr *, int);
	int (*connect)(struct socket___34 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___34 *, struct socket___34 *);
	int (*accept)(struct socket___34 *, struct socket___34 *, int, bool);
	int (*getname)(struct socket___34 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___225 *, struct socket___34 *, struct poll_table_struct___150 *);
	int (*ioctl)(struct socket___34 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___34 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___34 *, void *, bool, bool);
	int (*listen)(struct socket___34 *, int);
	int (*shutdown)(struct socket___34 *, int);
	int (*setsockopt)(struct socket___34 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___34 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___200 *, struct socket___34 *);
	int (*sendmsg)(struct socket___34 *, struct msghdr___34 *, size_t);
	int (*recvmsg)(struct socket___34 *, struct msghdr___34 *, size_t, int);
	int (*mmap)(struct file___225 *, struct socket___34 *, struct vm_area_struct___230 *);
	ssize_t (*sendpage)(struct socket___34 *, struct page___230 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___34 *, loff_t *, struct pipe_inode_info___75 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___33 *, int);
	int (*peek_len)(struct socket___34 *);
	int (*read_sock)(struct sock___33 *, read_descriptor_t *, sk_read_actor_t___32);
	int (*sendpage_locked)(struct sock___33 *, struct page___230 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___33 *, struct msghdr___34 *, size_t);
	int (*set_rcvlowat)(struct sock___33 *, int);
};

struct sk_buff___44 {
	union {
		struct {
			struct sk_buff___44 *next;
			struct sk_buff___44 *prev;
			union {
				struct net_device___45 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___33 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___44 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct pipe_buf_operations___75;

struct pipe_buffer___75 {
	struct page___230 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___75 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___75 {
	int (*confirm)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
	void (*release)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
	bool (*try_steal)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
	bool (*get)(struct pipe_inode_info___75 *, struct pipe_buffer___75 *);
};

typedef rx_handler_result_t rx_handler_func_t___43(struct sk_buff___44 **);

struct bpf_xdp_entity___39 {
	struct bpf_prog___39 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___43;

struct net_device_ops___43;

struct ethtool_ops___19;

struct l3mdev_ops___32;

struct ndisc_ops___21;

struct xfrmdev_ops___43;

struct header_ops___43;

struct inet6_dev___21;

struct netdev_rx_queue___43;

struct mini_Qdisc___39;

struct netdev_queue___43;

struct Qdisc___39;

struct rtnl_link_ops___39;

struct dcbnl_rtnl_ops___43;

struct phy_device___5;

struct net_device___45 {
	char name[16];
	struct netdev_name_node___43 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___43 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___19 *ethtool_ops;
	const struct l3mdev_ops___32 *l3mdev_ops;
	const struct ndisc_ops___21 *ndisc_ops;
	const struct xfrmdev_ops___43 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___43 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___213 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___21 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___43 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___39 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___43 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___39 *miniq_ingress;
	struct netdev_queue___43 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___43 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___39 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___39 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___43 = 0,
		NETREG_REGISTERED___43 = 1,
		NETREG_UNREGISTERING___43 = 2,
		NETREG_UNREGISTERED___43 = 3,
		NETREG_RELEASED___43 = 4,
		NETREG_DUMMY___43 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___43 = 0,
		RTNL_LINK_INITIALIZING___43 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___45 *);
	struct netpoll_info *npinfo;
	possible_net_t___43 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___203 dev;
	const struct attribute_group___213 *sysfs_groups[4];
	const struct attribute_group___213 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___39 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___43 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___5 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___39 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___142 skb_frag_t___3;

struct skb_shared_info___3 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___44 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___3 frags[17];
};

struct inet_frags___48;

struct fqdir___48 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___48 *f;
	struct net___48 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___48;

struct inet_frags___48 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___48 *, const void *);
	void (*destructor)(struct inet_frag_queue___48 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___48 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___44 *fragments_tail;
	struct sk_buff___44 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___48 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___32;

struct fib_lookup_arg___32;

struct fib_rules_ops___32 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___32 *, struct flowi *, int, struct fib_lookup_arg___32 *);
	bool (*suppress)(struct fib_rule___32 *, int, struct fib_lookup_arg___32 *);
	int (*match)(struct fib_rule___32 *, struct flowi *, int);
	int (*configure)(struct fib_rule___32 *, struct sk_buff___44 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___32 *);
	int (*compare)(struct fib_rule___32 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___32 *, struct sk_buff___44 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___32 *);
	void (*flush_cache)(struct fib_rules_ops___32 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___209 *owner;
	struct net___48 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___32 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___48 *);
	int (*fib_dump)(struct net___48 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___209 *owner;
	struct callback_head rcu;
};

struct dst_entry___32 {
	struct net_device___45 *dev;
	struct dst_ops___48 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___44 *);
	int (*output)(struct net___48 *, struct sock___33 *, struct sk_buff___44 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___32;

struct neigh_parms___32;

struct neigh_ops___32;

struct neighbour___32 {
	struct neighbour___32 *next;
	struct neigh_table___32 *tbl;
	struct neigh_parms___32 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___43 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___32 *, struct sk_buff___44 *);
	const struct neigh_ops___32 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___45 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___39 {
	struct bpf_prog___39 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___39 {
	struct callback_head rcu;
	struct bpf_prog_array_item___39 items[0];
};

struct bpf_prog_aux___46;

struct bpf_prog___39 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___46 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dcbnl_rtnl_ops___43 {
	int (*ieee_getets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___45 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___45 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___45 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___45 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___45 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___45 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___45 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___45 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___45 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___45 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___45 *);
	u8 (*setstate)(struct net_device___45 *, u8);
	void (*getpermhwaddr)(struct net_device___45 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___45 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___45 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___45 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___45 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___45 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___45 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___45 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___45 *, int, u8 *);
	void (*setpfccfg)(struct net_device___45 *, int, u8);
	void (*getpfccfg)(struct net_device___45 *, int, u8 *);
	u8 (*setall)(struct net_device___45 *);
	u8 (*getcap)(struct net_device___45 *, int, u8 *);
	int (*getnumtcs)(struct net_device___45 *, int, u8 *);
	int (*setnumtcs)(struct net_device___45 *, int, u8);
	u8 (*getpfcstate)(struct net_device___45 *);
	void (*setpfcstate)(struct net_device___45 *, u8);
	void (*getbcncfg)(struct net_device___45 *, int, u32 *);
	void (*setbcncfg)(struct net_device___45 *, int, u32);
	void (*getbcnrp)(struct net_device___45 *, int, u8 *);
	void (*setbcnrp)(struct net_device___45 *, int, u8);
	int (*setapp)(struct net_device___45 *, u8, u16, u8);
	int (*getapp)(struct net_device___45 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___45 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___45 *, int, u8);
	u8 (*getdcbx)(struct net_device___45 *);
	u8 (*setdcbx)(struct net_device___45 *, u8);
	int (*peer_getappinfo)(struct net_device___45 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___45 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___45 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___45 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___45 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___45 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___46;

typedef int (*bpf_iter_init_seq_priv_t___45)(void *, struct bpf_iter_aux_info___46 *);

struct bpf_map___46;

struct bpf_iter_aux_info___46 {
	struct bpf_map___46 *map;
};

struct bpf_iter_seq_info___45 {
	const struct seq_operations___200 *seq_ops;
	bpf_iter_init_seq_priv_t___45 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___45 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___46 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___46 *, struct file___225 *);
	void (*map_free)(struct bpf_map___46 *);
	int (*map_get_next_key)(struct bpf_map___46 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___46 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___46 *, void *);
	int (*map_lookup_batch)(struct bpf_map___46 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___46 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___46 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___46 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___46 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___46 *, void *);
	int (*map_update_elem)(struct bpf_map___46 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___46 *, void *);
	int (*map_push_elem)(struct bpf_map___46 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___46 *, void *);
	int (*map_peek_elem)(struct bpf_map___46 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___46 *, struct file___225 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___46 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___46 *, void *, struct seq_file___200 *);
	int (*map_check_btf)(const struct bpf_map___46 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___46 *, struct bpf_prog_aux___46 *);
	void (*map_poke_untrack)(struct bpf_map___46 *, struct bpf_prog_aux___46 *);
	void (*map_poke_run)(struct bpf_map___46 *, u32, struct bpf_prog___39 *, struct bpf_prog___39 *);
	int (*map_direct_value_addr)(const struct bpf_map___46 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___46 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___46 *, struct vm_area_struct___230 *);
	__poll_t (*map_poll)(struct bpf_map___46 *, struct file___225 *, struct poll_table_struct___150 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___46 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___46 *, const struct bpf_map___46 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___46 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___45 *iter_seq_info;
};

struct bpf_map___46 {
	const struct bpf_map_ops___45 *ops;
	struct bpf_map___46 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___98 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___45;

struct bpf_jit_poke_descriptor___45;

struct bpf_prog_ops___39;

struct btf_mod_pair___45;

struct bpf_prog_offload___43;

struct bpf_prog_aux___46 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___39 *dst_prog;
	struct bpf_trampoline___45 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___39 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___45 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___39 *ops;
	struct bpf_map___46 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___45 *used_btfs;
	struct bpf_prog___39 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___46 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___43 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___43;

struct bpf_map_dev_ops___43 {
	int (*map_get_next_key)(struct bpf_offloaded_map___43 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___43 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___43 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___43 *, void *);
};

struct bpf_offloaded_map___43 {
	struct bpf_map___46 map;
	struct net_device___45 *netdev;
	const struct bpf_map_dev_ops___43 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___39 {
	int (*test_run)(struct bpf_prog___39 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___43 {
	struct bpf_prog___39 *prog;
	struct net_device___45 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___45 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___39 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___209 *mod;
};

struct bpf_jit_poke_descriptor___45 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___46 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___45 {
	struct btf *btf;
	struct module___209 *module;
};

struct cftype___155;

struct cgroup_subsys___155 {
	struct cgroup_subsys_state___155 * (*css_alloc)(struct cgroup_subsys_state___155 *);
	int (*css_online)(struct cgroup_subsys_state___155 *);
	void (*css_offline)(struct cgroup_subsys_state___155 *);
	void (*css_released)(struct cgroup_subsys_state___155 *);
	void (*css_free)(struct cgroup_subsys_state___155 *);
	void (*css_reset)(struct cgroup_subsys_state___155 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___155 *, int);
	int (*css_extra_stat_show)(struct seq_file___200 *, struct cgroup_subsys_state___155 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___232 *, struct css_set___155 *);
	void (*cancel_fork)(struct task_struct___232 *, struct css_set___155 *);
	void (*fork)(struct task_struct___232 *);
	void (*exit)(struct task_struct___232 *);
	void (*release)(struct task_struct___232 *);
	void (*bind)(struct cgroup_subsys_state___155 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___155 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___155 *dfl_cftypes;
	struct cftype___155 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___155 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___155 *updated_children;
	struct cgroup___155 *updated_next;
};

struct cgroup_root___155 {
	struct kernfs_root___213 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___155 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___155 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___155 *ss;
	struct list_head node;
	struct kernfs_ops___213 *kf_ops;
	int (*open)(struct kernfs_open_file___213 *);
	void (*release)(struct kernfs_open_file___213 *);
	u64 (*read_u64)(struct cgroup_subsys_state___155 *, struct cftype___155 *);
	s64 (*read_s64)(struct cgroup_subsys_state___155 *, struct cftype___155 *);
	int (*seq_show)(struct seq_file___200 *, void *);
	void * (*seq_start)(struct seq_file___200 *, loff_t *);
	void * (*seq_next)(struct seq_file___200 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___200 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___155 *, struct cftype___155 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___155 *, struct cftype___155 *, s64);
	ssize_t (*write)(struct kernfs_open_file___213 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___213 *, struct poll_table_struct___150 *);
};

struct xdp_rxq_info___43 {
	struct net_device___45 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___43 {
	struct net_device___45 *dev;
};

struct xdp_buff___43 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___43 *rxq;
	struct xdp_txq_info___43 *txq;
	u32 frame_sz;
};

struct xdp_frame___43 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___45 *dev_rx;
};

struct netlink_callback___43 {
	struct sk_buff___44 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___44 *, struct netlink_callback___43 *);
	int (*done)(struct netlink_callback___43 *);
	void *data;
	struct module___209 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___43 {
	int (*create)(struct sk_buff___44 *, struct net_device___45 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___44 *, unsigned char *);
	int (*cache)(const struct neighbour___32 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___45 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___44 *);
};

struct napi_struct___2 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___2 *, int);
	int poll_owner;
	struct net_device___45 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___44 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___232 *thread;
};

struct netdev_queue___43 {
	struct net_device___45 *dev;
	struct Qdisc___39 *qdisc;
	struct Qdisc___39 *qdisc_sleeping;
	struct kobject___213 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___45 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___39 {
	struct sk_buff___44 *head;
	struct sk_buff___44 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___39;

struct Qdisc___39 {
	int (*enqueue)(struct sk_buff___44 *, struct Qdisc___39 *, struct sk_buff___44 **);
	struct sk_buff___44 * (*dequeue)(struct Qdisc___39 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___39 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___43 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___43 gso_skb;
	struct qdisc_skb_head___39 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___39 *next_sched;
	struct sk_buff_head___43 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___43 {
	struct xdp_rxq_info___43 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___213 kobj;
	struct net_device___45 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___43 {
	enum net_device_path_type type;
	const struct net_device___45 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___43 = 0,
				DEV_PATH_BR_VLAN_TAG___43 = 1,
				DEV_PATH_BR_VLAN_UNTAG___43 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___43 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___43 {
	const struct net_device___45 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___43 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___39 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___43 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___43 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___44 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___43 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___45 *dev;
	const char *name;
};

struct net_device_ops___43 {
	int (*ndo_init)(struct net_device___45 *);
	void (*ndo_uninit)(struct net_device___45 *);
	int (*ndo_open)(struct net_device___45 *);
	int (*ndo_stop)(struct net_device___45 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___44 *, struct net_device___45 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___44 *, struct net_device___45 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___45 *, struct sk_buff___44 *, struct net_device___45 *);
	void (*ndo_change_rx_flags)(struct net_device___45 *, int);
	void (*ndo_set_rx_mode)(struct net_device___45 *);
	int (*ndo_set_mac_address)(struct net_device___45 *, void *);
	int (*ndo_validate_addr)(struct net_device___45 *);
	int (*ndo_do_ioctl)(struct net_device___45 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___45 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___45 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___45 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___45 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___45 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___45 *, int);
	int (*ndo_neigh_setup)(struct net_device___45 *, struct neigh_parms___32 *);
	void (*ndo_tx_timeout)(struct net_device___45 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___45 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___45 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___45 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___45 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___45 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___45 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___45 *);
	int (*ndo_netpoll_setup)(struct net_device___45 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___45 *);
	int (*ndo_set_vf_mac)(struct net_device___45 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___45 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___45 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___45 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___45 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___45 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___45 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___45 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___45 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___45 *, int, struct sk_buff___44 *);
	int (*ndo_get_vf_guid)(struct net_device___45 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___45 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___45 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___45 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___45 *);
	int (*ndo_fcoe_disable)(struct net_device___45 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___45 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___45 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___45 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___45 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___45 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___45 *, const struct sk_buff___44 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___45 *, struct net_device___45 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___45 *, struct net_device___45 *);
	struct net_device___45 * (*ndo_get_xmit_slave)(struct net_device___45 *, struct sk_buff___44 *, bool);
	struct net_device___45 * (*ndo_sk_get_lower_dev)(struct net_device___45 *, struct sock___33 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___45 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___45 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___45 *, struct neighbour___32 *);
	void (*ndo_neigh_destroy)(struct net_device___45 *, struct neighbour___32 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___44 *, struct netlink_callback___43 *, struct net_device___45 *, struct net_device___45 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___44 *, struct nlattr **, struct net_device___45 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___45 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___44 *, u32, u32, struct net_device___45 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___45 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___45 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___45 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___45 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___45 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___45 *, struct net_device___45 *);
	void (*ndo_dfwd_del_station)(struct net_device___45 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___45 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___45 *);
	int (*ndo_change_proto_down)(struct net_device___45 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___45 *, struct sk_buff___44 *);
	void (*ndo_set_rx_headroom)(struct net_device___45 *, int);
	int (*ndo_bpf)(struct net_device___45 *, struct netdev_bpf___43 *);
	int (*ndo_xdp_xmit)(struct net_device___45 *, int, struct xdp_frame___43 **, u32);
	struct net_device___45 * (*ndo_xdp_get_xmit_slave)(struct net_device___45 *, struct xdp_buff___43 *);
	int (*ndo_xsk_wakeup)(struct net_device___45 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___45 *);
	int (*ndo_tunnel_ctl)(struct net_device___45 *, struct ip_tunnel_parm *, int);
	struct net_device___45 * (*ndo_get_peer_dev)(struct net_device___45 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___43 *, struct net_device_path___43 *);
};

struct neigh_parms___32 {
	possible_net_t___43 net;
	struct net_device___45 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___32 *);
	struct neigh_table___32 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

enum devlink_port_type {
	DEVLINK_PORT_TYPE_NOTSET = 0,
	DEVLINK_PORT_TYPE_AUTO = 1,
	DEVLINK_PORT_TYPE_ETH = 2,
	DEVLINK_PORT_TYPE_IB = 3,
};

enum devlink_port_flavour {
	DEVLINK_PORT_FLAVOUR_PHYSICAL = 0,
	DEVLINK_PORT_FLAVOUR_CPU = 1,
	DEVLINK_PORT_FLAVOUR_DSA = 2,
	DEVLINK_PORT_FLAVOUR_PCI_PF = 3,
	DEVLINK_PORT_FLAVOUR_PCI_VF = 4,
	DEVLINK_PORT_FLAVOUR_VIRTUAL = 5,
	DEVLINK_PORT_FLAVOUR_UNUSED = 6,
	DEVLINK_PORT_FLAVOUR_PCI_SF = 7,
};

struct devlink_port_phys_attrs {
	u32 port_number;
	u32 split_subport_number;
};

struct devlink_port_pci_pf_attrs {
	u32 controller;
	u16 pf;
	u8 external: 1;
	long: 63;
};

struct devlink_port_pci_vf_attrs {
	u32 controller;
	u16 pf;
	u16 vf;
	u8 external: 1;
	long: 31;
	long: 64;
};

struct devlink_port_pci_sf_attrs {
	u32 controller;
	u32 sf;
	u16 pf;
	u8 external: 1;
	long: 31;
	long: 64;
};

struct devlink_port_attrs {
	u8 split: 1;
	u8 splittable: 1;
	u32 lanes;
	enum devlink_port_flavour flavour;
	struct netdev_phys_item_id switch_id;
	union {
		struct devlink_port_phys_attrs phys;
		struct devlink_port_pci_pf_attrs pci_pf;
		struct devlink_port_pci_vf_attrs pci_vf;
		struct devlink_port_pci_sf_attrs pci_sf;
	};
};

struct devlink;

struct devlink_rate;

struct devlink_port {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set: 1;
	u8 switch_port: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate *devlink_rate;
};

struct ethtool_ops___19 {
	u32 cap_link_lanes_supported;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___45 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___45 *);
	void (*get_regs)(struct net_device___45 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___45 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___45 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___45 *);
	void (*set_msglevel)(struct net_device___45 *, u32);
	int (*nway_reset)(struct net_device___45 *);
	u32 (*get_link)(struct net_device___45 *);
	int (*get_link_ext_state)(struct net_device___45 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___45 *);
	int (*get_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___45 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___45 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___45 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___45 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___45 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___45 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___45 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___45 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___45 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___45 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___45 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___45 *);
	void (*complete)(struct net_device___45 *);
	u32 (*get_priv_flags)(struct net_device___45 *);
	int (*set_priv_flags)(struct net_device___45 *, u32);
	int (*get_sset_count)(struct net_device___45 *, int);
	int (*get_rxnfc)(struct net_device___45 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___45 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___45 *, struct ethtool_flash *);
	int (*reset)(struct net_device___45 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___45 *);
	u32 (*get_rxfh_indir_size)(struct net_device___45 *);
	int (*get_rxfh)(struct net_device___45 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___45 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___45 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___45 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___45 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___45 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___45 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___45 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___45 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___45 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___45 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___45 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___45 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___45 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___45 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___45 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___45 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___45 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___45 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___45 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___45 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___45 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___45 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___45 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___45 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___45 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___45 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___45 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___45 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___45 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___45 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___32 {
	u32 (*l3mdev_fib_table)(const struct net_device___45 *);
	struct sk_buff___44 * (*l3mdev_l3_rcv)(struct net_device___45 *, struct sk_buff___44 *, u16);
	struct sk_buff___44 * (*l3mdev_l3_out)(struct net_device___45 *, struct sock___33 *, struct sk_buff___44 *, u16);
	struct dst_entry___32 * (*l3mdev_link_scope_lookup)(const struct net_device___45 *, struct flowi6 *);
};

struct ndisc_ops___21 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___45 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___45 *, struct neighbour___32 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___45 *, u8, struct neighbour___32 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___45 *, struct sk_buff___44 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___48 *, struct net_device___45 *, const struct prefix_info *, struct inet6_dev___21 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

enum phylink_op_type {
	PHYLINK_NETDEV = 0,
	PHYLINK_DEV = 1,
};

struct phylink_link_state;

struct phylink_config {
	struct device___203 *dev;
	enum phylink_op_type type;
	bool pcs_poll;
	bool poll_fixed_state;
	bool ovr_an_inband;
	void (*get_fixed_state)(struct phylink_config *, struct phylink_link_state *);
};

struct dsa_device_ops;

struct dsa_switch_tree;

struct dsa_switch;

struct dsa_netdevice_ops;

struct dsa_port {
	union {
		struct net_device___45 *master;
		struct net_device___45 *slave;
	};
	const struct dsa_device_ops *tag_ops;
	struct dsa_switch_tree *dst;
	struct sk_buff___44 * (*rcv)(struct sk_buff___44 *, struct net_device___45 *);
	enum {
		DSA_PORT_TYPE_UNUSED = 0,
		DSA_PORT_TYPE_CPU = 1,
		DSA_PORT_TYPE_DSA = 2,
		DSA_PORT_TYPE_USER = 3,
	} type;
	struct dsa_switch *ds;
	unsigned int index;
	const char *name;
	struct dsa_port *cpu_dp;
	u8 mac[6];
	struct device_node___89 *dn;
	unsigned int ageing_time;
	bool vlan_filtering;
	bool learning;
	u8 stp_state;
	struct net_device___45 *bridge_dev;
	int bridge_num;
	struct devlink_port devlink_port;
	bool devlink_port_setup;
	struct phylink *pl;
	struct phylink_config pl_config;
	struct net_device___45 *lag_dev;
	bool lag_tx_enabled;
	struct net_device___45 *hsr_dev;
	struct list_head list;
	void *priv;
	const struct ethtool_ops___19 *orig_ethtool_ops;
	const struct dsa_netdevice_ops *netdev_ops;
	struct list_head fdbs;
	struct list_head mdbs;
	bool setup;
};

struct ifmcaddr6___21;

struct inet6_dev___21 {
	struct net_device___45 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___21 *mc_list;
	struct ifmcaddr6___21 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___43 mc_query_queue;
	struct sk_buff_head___43 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___2 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___32 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___39;

struct tcf_block___39;

struct mini_Qdisc___39 {
	struct tcf_proto___39 *filter_list;
	struct tcf_block___39 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___39 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___45 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___45 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___48 *, struct net_device___45 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___45 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___45 *, struct list_head *);
	size_t (*get_size)(const struct net_device___45 *);
	int (*fill_info)(struct sk_buff___44 *, const struct net_device___45 *);
	size_t (*get_xstats_size)(const struct net_device___45 *);
	int (*fill_xstats)(struct sk_buff___44 *, const struct net_device___45 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___45 *, struct net_device___45 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___45 *, const struct net_device___45 *);
	int (*fill_slave_info)(struct sk_buff___44 *, const struct net_device___45 *, const struct net_device___45 *);
	struct net___48 * (*get_link_net)(const struct net_device___45 *);
	size_t (*get_linkxstats_size)(const struct net_device___45 *, int);
	int (*fill_linkxstats)(struct sk_buff___44 *, const struct net_device___45 *, int *, int);
};

struct mii_bus___8;

struct mdio_device___8 {
	struct device___203 dev;
	struct mii_bus___8 *bus;
	char modalias[32];
	int (*bus_match)(struct device___203 *, struct device_driver___203 *);
	void (*device_free)(struct mdio_device___8 *);
	void (*device_remove)(struct mdio_device___8 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___5;

struct mii_timestamper___5;

struct phy_device___5 {
	struct mdio_device___8 mdio;
	struct phy_driver___5 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45;
	unsigned int is_internal;
	unsigned int is_pseudo_fixed_link;
	unsigned int is_gigabit_capable;
	unsigned int has_fixups;
	unsigned int suspended;
	unsigned int suspended_by_mdio_bus;
	unsigned int sysfs_links;
	unsigned int loopback_enabled;
	unsigned int downshifted_rate;
	unsigned int is_on_sfp_module;
	unsigned int mac_managed_pm;
	unsigned int autoneg;
	unsigned int link;
	unsigned int autoneg_complete;
	unsigned int interrupts;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___44 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___45 *attached_dev;
	struct mii_timestamper___5 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___5 *, bool);
	void (*adjust_link)(struct net_device___45 *);
	const struct macsec_ops *macsec_ops;
};

enum netdev_lag_tx_type {
	NETDEV_LAG_TX_TYPE_UNKNOWN = 0,
	NETDEV_LAG_TX_TYPE_RANDOM = 1,
	NETDEV_LAG_TX_TYPE_BROADCAST = 2,
	NETDEV_LAG_TX_TYPE_ROUNDROBIN = 3,
	NETDEV_LAG_TX_TYPE_ACTIVEBACKUP = 4,
	NETDEV_LAG_TX_TYPE_HASH = 5,
};

enum netdev_lag_hash {
	NETDEV_LAG_HASH_NONE = 0,
	NETDEV_LAG_HASH_L2 = 1,
	NETDEV_LAG_HASH_L34 = 2,
	NETDEV_LAG_HASH_L23 = 3,
	NETDEV_LAG_HASH_E23 = 4,
	NETDEV_LAG_HASH_E34 = 5,
	NETDEV_LAG_HASH_VLAN_SRCMAC = 6,
	NETDEV_LAG_HASH_UNKNOWN = 7,
};

struct netdev_lag_upper_info {
	enum netdev_lag_tx_type tx_type;
	enum netdev_lag_hash hash_type;
};

struct netdev_notifier_info___4 {
	struct net_device___45 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_changeupper_info {
	struct netdev_notifier_info___4 info;
	struct net_device___45 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

enum ethtool_stringset {
	ETH_SS_TEST = 0,
	ETH_SS_STATS = 1,
	ETH_SS_PRIV_FLAGS = 2,
	ETH_SS_NTUPLE_FILTERS = 3,
	ETH_SS_FEATURES = 4,
	ETH_SS_RSS_HASH_FUNCS = 5,
	ETH_SS_TUNABLES = 6,
	ETH_SS_PHY_STATS = 7,
	ETH_SS_PHY_TUNABLES = 8,
	ETH_SS_LINK_MODES = 9,
	ETH_SS_MSG_CLASSES = 10,
	ETH_SS_WOL_MODES = 11,
	ETH_SS_SOF_TIMESTAMPING = 12,
	ETH_SS_TS_TX_TYPES = 13,
	ETH_SS_TS_RX_FILTERS = 14,
	ETH_SS_UDP_TUNNEL_TYPES = 15,
	ETH_SS_STATS_STD = 16,
	ETH_SS_STATS_ETH_PHY = 17,
	ETH_SS_STATS_ETH_MAC = 18,
	ETH_SS_STATS_ETH_CTRL = 19,
	ETH_SS_STATS_RMON = 20,
	ETH_SS_COUNT = 21,
};

struct flow_match {
	struct flow_dissector *dissector;
	void *mask;
	void *key;
};

enum flow_action_id {
	FLOW_ACTION_ACCEPT = 0,
	FLOW_ACTION_DROP = 1,
	FLOW_ACTION_TRAP = 2,
	FLOW_ACTION_GOTO = 3,
	FLOW_ACTION_REDIRECT = 4,
	FLOW_ACTION_MIRRED = 5,
	FLOW_ACTION_REDIRECT_INGRESS = 6,
	FLOW_ACTION_MIRRED_INGRESS = 7,
	FLOW_ACTION_VLAN_PUSH = 8,
	FLOW_ACTION_VLAN_POP = 9,
	FLOW_ACTION_VLAN_MANGLE = 10,
	FLOW_ACTION_TUNNEL_ENCAP = 11,
	FLOW_ACTION_TUNNEL_DECAP = 12,
	FLOW_ACTION_MANGLE = 13,
	FLOW_ACTION_ADD = 14,
	FLOW_ACTION_CSUM = 15,
	FLOW_ACTION_MARK = 16,
	FLOW_ACTION_PTYPE = 17,
	FLOW_ACTION_PRIORITY = 18,
	FLOW_ACTION_WAKE = 19,
	FLOW_ACTION_QUEUE = 20,
	FLOW_ACTION_SAMPLE = 21,
	FLOW_ACTION_POLICE = 22,
	FLOW_ACTION_CT = 23,
	FLOW_ACTION_CT_METADATA = 24,
	FLOW_ACTION_MPLS_PUSH = 25,
	FLOW_ACTION_MPLS_POP = 26,
	FLOW_ACTION_MPLS_MANGLE = 27,
	FLOW_ACTION_GATE = 28,
	FLOW_ACTION_PPPOE_PUSH = 29,
	NUM_FLOW_ACTIONS = 30,
};

enum flow_action_hw_stats {
	FLOW_ACTION_HW_STATS_IMMEDIATE = 1,
	FLOW_ACTION_HW_STATS_DELAYED = 2,
	FLOW_ACTION_HW_STATS_ANY = 3,
	FLOW_ACTION_HW_STATS_DISABLED = 4,
	FLOW_ACTION_HW_STATS_DONT_CARE = 7,
};

typedef void (*action_destr)(void *);

enum flow_action_mangle_base {
	FLOW_ACT_MANGLE_UNSPEC = 0,
	FLOW_ACT_MANGLE_HDR_TYPE_ETH = 1,
	FLOW_ACT_MANGLE_HDR_TYPE_IP4 = 2,
	FLOW_ACT_MANGLE_HDR_TYPE_IP6 = 3,
	FLOW_ACT_MANGLE_HDR_TYPE_TCP = 4,
	FLOW_ACT_MANGLE_HDR_TYPE_UDP = 5,
};

struct ip_tunnel_info;

struct nf_flowtable;

struct psample_group;

struct action_gate_entry;

struct flow_action_cookie;

struct flow_action_entry {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___45 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action {
	unsigned int num_entries;
	struct flow_action_entry entries[0];
};

struct flow_rule {
	struct flow_match match;
	struct flow_action action;
};

struct mii_bus___8 {
	struct module___209 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___8 *, int, int);
	int (*write)(struct mii_bus___8 *, int, int, u16);
	int (*reset)(struct mii_bus___8 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___203 *parent;
	enum {
		MDIOBUS_ALLOCATED___8 = 1,
		MDIOBUS_REGISTERED___8 = 2,
		MDIOBUS_UNREGISTERED___8 = 3,
		MDIOBUS_RELEASED___8 = 4,
	} state;
	struct device___203 dev;
	struct mdio_device___8 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___8 = 0,
		MDIOBUS_C22___8 = 1,
		MDIOBUS_C45___8 = 2,
		MDIOBUS_C22_C45___8 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___7 {
	struct device_driver___203 driver;
	int flags;
};

struct mii_timestamper___5 {
	bool (*rxtstamp)(struct mii_timestamper___5 *, struct sk_buff___44 *, int);
	void (*txtstamp)(struct mii_timestamper___5 *, struct sk_buff___44 *, int);
	int (*hwtstamp)(struct mii_timestamper___5 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___5 *, struct phy_device___5 *);
	int (*ts_info)(struct mii_timestamper___5 *, struct ethtool_ts_info *);
	struct device___203 *device;
};

struct phy_driver___5 {
	struct mdio_driver_common___7 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___5 *);
	int (*config_init)(struct phy_device___5 *);
	int (*probe)(struct phy_device___5 *);
	int (*get_features)(struct phy_device___5 *);
	int (*suspend)(struct phy_device___5 *);
	int (*resume)(struct phy_device___5 *);
	int (*config_aneg)(struct phy_device___5 *);
	int (*aneg_done)(struct phy_device___5 *);
	int (*read_status)(struct phy_device___5 *);
	int (*config_intr)(struct phy_device___5 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___5 *);
	void (*remove)(struct phy_device___5 *);
	int (*match_phy_device)(struct phy_device___5 *);
	int (*set_wol)(struct phy_device___5 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___5 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___5 *);
	int (*read_mmd)(struct phy_device___5 *, int, u16);
	int (*write_mmd)(struct phy_device___5 *, int, u16, u16);
	int (*read_page)(struct phy_device___5 *);
	int (*write_page)(struct phy_device___5 *, int);
	int (*module_info)(struct phy_device___5 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___5 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___5 *);
	int (*cable_test_tdr_start)(struct phy_device___5 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___5 *, bool *);
	int (*get_sset_count)(struct phy_device___5 *);
	void (*get_strings)(struct phy_device___5 *, u8 *);
	void (*get_stats)(struct phy_device___5 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___5 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___5 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___5 *, bool);
	int (*get_sqi)(struct phy_device___5 *);
	int (*get_sqi_max)(struct phy_device___5 *);
};

struct dsa_chip_data {
	struct device___203 *host_dev;
	int sw_addr;
	struct device___203 *netdev[12];
	int eeprom_len;
	struct device_node___89 *of_node;
	char *port_names[12];
	struct device_node___89 *port_dn[12];
	s8 rtable[4];
};

struct dsa_platform_data {
	struct device___203 *netdev;
	struct net_device___45 *of_netdev;
	int nr_chips;
	struct dsa_chip_data *chip;
};

struct phylink_link_state {
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	phy_interface_t interface;
	int speed;
	int duplex;
	int pause;
	unsigned int link: 1;
	unsigned int an_enabled: 1;
	unsigned int an_complete: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct flow_action_cookie {
	u32 cookie_len;
	u8 cookie[0];
};

struct flow_stats {
	u64 pkts;
	u64 bytes;
	u64 drops;
	u64 lastused;
	enum flow_action_hw_stats used_hw_stats;
	bool used_hw_stats_valid;
};

enum flow_cls_command {
	FLOW_CLS_REPLACE = 0,
	FLOW_CLS_DESTROY = 1,
	FLOW_CLS_STATS = 2,
	FLOW_CLS_TMPLT_CREATE = 3,
	FLOW_CLS_TMPLT_DESTROY = 4,
};

struct flow_cls_common_offload {
	u32 chain_index;
	__be16 protocol;
	u32 prio;
	struct netlink_ext_ack *extack;
};

struct flow_cls_offload {
	struct flow_cls_common_offload common;
	enum flow_cls_command command;
	long unsigned int cookie;
	struct flow_rule *rule;
	struct flow_stats stats;
	u32 classid;
};

enum devlink_sb_pool_type {
	DEVLINK_SB_POOL_TYPE_INGRESS = 0,
	DEVLINK_SB_POOL_TYPE_EGRESS = 1,
};

enum devlink_sb_threshold_type {
	DEVLINK_SB_THRESHOLD_TYPE_STATIC = 0,
	DEVLINK_SB_THRESHOLD_TYPE_DYNAMIC = 1,
};

enum devlink_eswitch_encap_mode {
	DEVLINK_ESWITCH_ENCAP_MODE_NONE = 0,
	DEVLINK_ESWITCH_ENCAP_MODE_BASIC = 1,
};

enum devlink_rate_type {
	DEVLINK_RATE_TYPE_LEAF = 0,
	DEVLINK_RATE_TYPE_NODE = 1,
};

enum devlink_param_cmode {
	DEVLINK_PARAM_CMODE_RUNTIME = 0,
	DEVLINK_PARAM_CMODE_DRIVERINIT = 1,
	DEVLINK_PARAM_CMODE_PERMANENT = 2,
	__DEVLINK_PARAM_CMODE_MAX = 3,
	DEVLINK_PARAM_CMODE_MAX = 2,
};

enum devlink_trap_action {
	DEVLINK_TRAP_ACTION_DROP = 0,
	DEVLINK_TRAP_ACTION_TRAP = 1,
	DEVLINK_TRAP_ACTION_MIRROR = 2,
};

enum devlink_trap_type {
	DEVLINK_TRAP_TYPE_DROP = 0,
	DEVLINK_TRAP_TYPE_EXCEPTION = 1,
	DEVLINK_TRAP_TYPE_CONTROL = 2,
};

enum devlink_reload_action {
	DEVLINK_RELOAD_ACTION_UNSPEC = 0,
	DEVLINK_RELOAD_ACTION_DRIVER_REINIT = 1,
	DEVLINK_RELOAD_ACTION_FW_ACTIVATE = 2,
	__DEVLINK_RELOAD_ACTION_MAX = 3,
	DEVLINK_RELOAD_ACTION_MAX = 2,
};

enum devlink_reload_limit {
	DEVLINK_RELOAD_LIMIT_UNSPEC = 0,
	DEVLINK_RELOAD_LIMIT_NO_RESET = 1,
	__DEVLINK_RELOAD_LIMIT_MAX = 2,
	DEVLINK_RELOAD_LIMIT_MAX = 1,
};

enum devlink_dpipe_field_mapping_type {
	DEVLINK_DPIPE_FIELD_MAPPING_TYPE_NONE = 0,
	DEVLINK_DPIPE_FIELD_MAPPING_TYPE_IFINDEX = 1,
};

enum devlink_port_fn_state {
	DEVLINK_PORT_FN_STATE_INACTIVE = 0,
	DEVLINK_PORT_FN_STATE_ACTIVE = 1,
};

enum devlink_port_fn_opstate {
	DEVLINK_PORT_FN_OPSTATE_DETACHED = 0,
	DEVLINK_PORT_FN_OPSTATE_ATTACHED = 1,
};

struct devlink_dev_stats {
	u32 reload_stats[6];
	u32 remote_reload_stats[6];
};

struct devlink_dpipe_headers;

struct devlink_ops;

struct devlink {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___203 *dev;
	possible_net_t___43 _net;
	struct mutex lock;
	u8 reload_failed: 1;
	u8 reload_enabled: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_dpipe_header;

struct devlink_dpipe_headers {
	struct devlink_dpipe_header **headers;
	unsigned int headers_count;
};

struct devlink_info_req;

struct devlink_sb_pool_info;

struct devlink_flash_update_params;

struct devlink_trap;

struct devlink_trap_group;

struct devlink_trap_policer;

struct devlink_port_new_attrs;

struct devlink_ops {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port *, enum devlink_port_type);
	int (*port_split)(struct devlink *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink *, u16 *);
	int (*eswitch_mode_set)(struct devlink *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate *, struct devlink_rate *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate *, struct devlink_rate *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate *parent;
	union {
		struct devlink_port *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct devlink_port_new_attrs {
	enum devlink_port_flavour flavour;
	unsigned int port_index;
	u32 controller;
	u32 sfnum;
	u16 pfnum;
	u8 port_index_valid: 1;
	u8 controller_valid: 1;
	u8 sfnum_valid: 1;
	long: 31;
	long: 64;
	long: 64;
};

struct devlink_sb_pool_info {
	enum devlink_sb_pool_type pool_type;
	u32 size;
	enum devlink_sb_threshold_type threshold_type;
	u32 cell_size;
};

struct devlink_dpipe_field {
	const char *name;
	unsigned int id;
	unsigned int bitwidth;
	enum devlink_dpipe_field_mapping_type mapping_type;
};

struct devlink_dpipe_header {
	const char *name;
	unsigned int id;
	struct devlink_dpipe_field *fields;
	unsigned int fields_count;
	bool global;
};

union devlink_param_value {
	u8 vu8;
	u16 vu16;
	u32 vu32;
	char vstr[32];
	bool vbool;
};

struct devlink_param_gset_ctx {
	union devlink_param_value val;
	enum devlink_param_cmode cmode;
};

struct devlink_flash_update_params {
	const struct firmware *fw;
	const char *component;
	u32 overwrite_mask;
};

struct devlink_trap_policer {
	u32 id;
	u64 init_rate;
	u64 init_burst;
	u64 max_rate;
	u64 min_rate;
	u64 max_burst;
	u64 min_burst;
};

struct devlink_trap_group {
	const char *name;
	u16 id;
	bool generic;
	u32 init_policer_id;
};

struct devlink_trap {
	enum devlink_trap_type type;
	enum devlink_trap_action init_action;
	bool generic;
	u16 id;
	const char *name;
	u16 init_group_id;
	u32 metadata_cap;
};

struct fib_rule___32 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___32 *ctarget;
	struct net___48 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___32 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___32 *rule;
	u32 table;
	int flags;
};

struct block_device_operations___118;

struct gendisk___121 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___121 *part0;
	const struct block_device_operations___118 *fops;
	struct request_queue___118 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___107 *bdi;
	struct kobject___213 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___213 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___118 {
	struct bio___118 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___142 *bip_vec;
	struct bio_vec___142 bip_inline_vecs[0];
};

struct blkcg___109;

struct blkg_policy_data___109;

struct blkcg_gq___109 {
	struct request_queue___118 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___109 *blkcg;
	struct blkcg_gq___109 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___109 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___118 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___118(struct request___118 *);

typedef void integrity_complete_fn___118(struct request___118 *, unsigned int);

struct blk_integrity_profile___118 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___118 *prepare_fn;
	integrity_complete_fn___118 *complete_fn;
	const char *name;
};

struct block_device_operations___118 {
	blk_qc_t (*submit_bio)(struct bio___118 *);
	int (*open)(struct block_device___121 *, fmode_t);
	void (*release)(struct gendisk___121 *, fmode_t);
	int (*rw_page)(struct block_device___121 *, sector_t, struct page___230 *, unsigned int);
	int (*ioctl)(struct block_device___121 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___121 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___121 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___121 *);
	int (*getgeo)(struct block_device___121 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___121 *, bool);
	void (*swap_slot_free_notify)(struct block_device___121 *, long unsigned int);
	int (*report_zones)(struct gendisk___121 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___121 *, umode_t *);
	struct module___209 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___121 *, sector_t *);
};

typedef void rq_end_io_fn___118(struct request___118 *, blk_status_t);

struct request___118 {
	struct request_queue___118 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___115 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___118 *bio;
	struct bio___118 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___142 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___118 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___118 *saved_end_io;
		} flush;
	};
	struct gendisk___121 *rq_disk;
	struct block_device___121 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___118 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___115 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___118 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___213 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___225 *debugfs_dir;
	struct dentry___225 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___118;

struct elevator_mq_ops___118 {
	int (*init_sched)(struct request_queue___118 *, struct elevator_type___118 *);
	void (*exit_sched)(struct elevator_queue___118 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___115 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___115 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___115 *);
	bool (*allow_merge)(struct request_queue___118 *, struct request___118 *, struct bio___118 *);
	bool (*bio_merge)(struct request_queue___118 *, struct bio___118 *, unsigned int);
	int (*request_merge)(struct request_queue___118 *, struct request___118 **, struct bio___118 *);
	void (*request_merged)(struct request_queue___118 *, struct request___118 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___118 *, struct request___118 *, struct request___118 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___118 *);
	void (*finish_request)(struct request___118 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___115 *, struct list_head *, bool);
	struct request___118 * (*dispatch_request)(struct blk_mq_hw_ctx___115 *);
	bool (*has_work)(struct blk_mq_hw_ctx___115 *);
	void (*completed_request)(struct request___118 *, u64);
	void (*requeue_request)(struct request___118 *);
	struct request___118 * (*former_request)(struct request_queue___118 *, struct request___118 *);
	struct request___118 * (*next_request)(struct request_queue___118 *, struct request___118 *);
	void (*init_icq)(struct io_cq___118 *);
	void (*exit_icq)(struct io_cq___118 *);
};

struct elv_fs_entry___118;

struct elevator_type___118 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___118 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___118 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___209 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___118 {
	struct elevator_type___118 *type;
	void *elevator_data;
	struct kobject___213 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___118 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___118 *, char *);
	ssize_t (*store)(struct elevator_queue___118 *, const char *, size_t);
};

struct blk_mq_queue_data___115;

struct blk_mq_ops___115 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___115 *, const struct blk_mq_queue_data___115 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___115 *);
	int (*get_budget)(struct request_queue___118 *);
	void (*put_budget)(struct request_queue___118 *, int);
	void (*set_rq_budget_token)(struct request___118 *, int);
	int (*get_rq_budget_token)(struct request___118 *);
	enum blk_eh_timer_return (*timeout)(struct request___118 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___115 *);
	void (*complete)(struct request___118 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___115 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___115 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___115 *, struct request___118 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___115 *, struct request___118 *, unsigned int);
	void (*initialize_rq_fn)(struct request___118 *);
	void (*cleanup_rq)(struct request___118 *);
	bool (*busy)(struct request_queue___118 *);
	int (*map_queues)(struct blk_mq_tag_set___115 *);
	void (*show_rq)(struct seq_file___200 *, struct request___118 *);
};

struct blk_mq_tag_set___115 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___115 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___115 {
	struct request___118 *rq;
	bool last;
};

struct blkcg_policy_data___109;

struct blkcg___109 {
	struct cgroup_subsys_state___155 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___109 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___109 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___109 {
	struct blkcg___109 *blkcg;
	int plid;
};

struct blkg_policy_data___109 {
	struct blkcg_gq___109 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___98 {
	struct mem_cgroup___98 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___98 {
	struct lruvec___106 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___98 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___98 *memcg;
};

struct obj_cgroup___98 {
	struct percpu_ref refcnt;
	struct mem_cgroup___98 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___39 {
	spinlock_t *lock;
	struct sk_buff___44 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___39;

struct Qdisc_ops___39 {
	struct Qdisc_ops___39 *next;
	const struct Qdisc_class_ops___39 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___44 *, struct Qdisc___39 *, struct sk_buff___44 **);
	struct sk_buff___44 * (*dequeue)(struct Qdisc___39 *);
	struct sk_buff___44 * (*peek)(struct Qdisc___39 *);
	int (*init)(struct Qdisc___39 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___39 *);
	void (*destroy)(struct Qdisc___39 *);
	int (*change)(struct Qdisc___39 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___39 *);
	int (*change_tx_queue_len)(struct Qdisc___39 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___39 *, unsigned int);
	int (*dump)(struct Qdisc___39 *, struct sk_buff___44 *);
	int (*dump_stats)(struct Qdisc___39 *, struct gnet_dump___39 *);
	void (*ingress_block_set)(struct Qdisc___39 *, u32);
	void (*egress_block_set)(struct Qdisc___39 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___39 *);
	u32 (*egress_block_get)(struct Qdisc___39 *);
	struct module___209 *owner;
};

struct Qdisc_class_ops___39 {
	unsigned int flags;
	struct netdev_queue___43 * (*select_queue)(struct Qdisc___39 *, struct tcmsg *);
	int (*graft)(struct Qdisc___39 *, long unsigned int, struct Qdisc___39 *, struct Qdisc___39 **, struct netlink_ext_ack *);
	struct Qdisc___39 * (*leaf)(struct Qdisc___39 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___39 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___39 *, u32);
	int (*change)(struct Qdisc___39 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___39 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___39 *, struct qdisc_walker *);
	struct tcf_block___39 * (*tcf_block)(struct Qdisc___39 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___39 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___39 *, long unsigned int);
	int (*dump)(struct Qdisc___39 *, long unsigned int, struct sk_buff___44 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___39 *, long unsigned int, struct gnet_dump___39 *);
};

struct tcf_chain___39;

struct tcf_block___39 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___48 *net;
	struct Qdisc___39 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___39 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___39;

struct tcf_proto_ops___39;

struct tcf_proto___39 {
	struct tcf_proto___39 *next;
	void *root;
	int (*classify)(struct sk_buff___44 *, const struct tcf_proto___39 *, struct tcf_result___39 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___39 *ops;
	struct tcf_chain___39 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___39 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___39 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___39 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___44 *, const struct tcf_proto___39 *, struct tcf_result___39 *);
	int (*init)(struct tcf_proto___39 *);
	void (*destroy)(struct tcf_proto___39 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___39 *, u32);
	void (*put)(struct tcf_proto___39 *, void *);
	int (*change)(struct net___48 *, struct sk_buff___44 *, struct tcf_proto___39 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___39 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___39 *);
	void (*walk)(struct tcf_proto___39 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___39 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___39 *, void *);
	void (*hw_del)(struct tcf_proto___39 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___48 *, struct tcf_chain___39 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___48 *, struct tcf_proto___39 *, void *, struct sk_buff___44 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___48 *, struct tcf_proto___39 *, void *, struct sk_buff___44 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___44 *, struct net___48 *, void *);
	struct module___209 *owner;
	int flags;
};

struct tcf_chain___39 {
	struct mutex filter_chain_lock;
	struct tcf_proto___39 *filter_chain;
	struct list_head list;
	struct tcf_block___39 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___39 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___32 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___39 *prog;
};

struct pneigh_entry___32;

struct neigh_hash_table___32;

struct neigh_table___32 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___45 *, __u32 *);
	bool (*key_eq)(const struct neighbour___32 *, const void *);
	int (*constructor)(struct neighbour___32 *);
	int (*pconstructor)(struct pneigh_entry___32 *);
	void (*pdestructor)(struct pneigh_entry___32 *);
	void (*proxy_redo)(struct sk_buff___44 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___45 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___32 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___43 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___32 *nht;
	struct pneigh_entry___32 **phash_buckets;
};

struct neigh_ops___32 {
	int family;
	void (*solicit)(struct neighbour___32 *, struct sk_buff___44 *);
	void (*error_report)(struct neighbour___32 *, struct sk_buff___44 *);
	int (*output)(struct neighbour___32 *, struct sk_buff___44 *);
	int (*connected_output)(struct neighbour___32 *, struct sk_buff___44 *);
};

struct pneigh_entry___32 {
	struct pneigh_entry___32 *next;
	possible_net_t___43 net;
	struct net_device___45 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___32 {
	struct neighbour___32 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct request_sock_ops___22;

struct timewait_sock_ops___22;

struct proto___32 {
	void (*close)(struct sock___33 *, long int);
	int (*pre_connect)(struct sock___33 *, struct sockaddr *, int);
	int (*connect)(struct sock___33 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___33 *, int);
	struct sock___33 * (*accept)(struct sock___33 *, int, int *, bool);
	int (*ioctl)(struct sock___33 *, int, long unsigned int);
	int (*init)(struct sock___33 *);
	void (*destroy)(struct sock___33 *);
	void (*shutdown)(struct sock___33 *, int);
	int (*setsockopt)(struct sock___33 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___33 *, int, int, char *, int *);
	void (*keepalive)(struct sock___33 *, int);
	int (*compat_ioctl)(struct sock___33 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___33 *, struct msghdr___34 *, size_t);
	int (*recvmsg)(struct sock___33 *, struct msghdr___34 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___33 *, struct page___230 *, int, size_t, int);
	int (*bind)(struct sock___33 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___33 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___33 *, struct sk_buff___44 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___33 *);
	int (*hash)(struct sock___33 *);
	void (*unhash)(struct sock___33 *);
	void (*rehash)(struct sock___33 *);
	int (*get_port)(struct sock___33 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___33 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___33 *, int);
	bool (*sock_is_readable)(struct sock___33 *);
	void (*enter_memory_pressure)(struct sock___33 *);
	void (*leave_memory_pressure)(struct sock___33 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___22 *rsk_prot;
	struct timewait_sock_ops___22 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___209 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___33 *, int);
};

struct request_sock___23;

struct request_sock_ops___22 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___33 *, struct request_sock___23 *);
	void (*send_ack)(const struct sock___33 *, struct sk_buff___44 *, struct request_sock___23 *);
	void (*send_reset)(const struct sock___33 *, struct sk_buff___44 *);
	void (*destructor)(struct request_sock___23 *);
	void (*syn_ack_timeout)(const struct request_sock___23 *);
};

struct timewait_sock_ops___22 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___33 *, struct sock___33 *, void *);
	void (*twsk_destructor)(struct sock___33 *);
};

struct request_sock___23 {
	struct sock_common___32 __req_common;
	struct request_sock___23 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___22 *rsk_ops;
	struct sock___33 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___21 {
	struct in6_addr mca_addr;
	struct inet6_dev___21 *idev;
	struct ifmcaddr6___21 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct switchdev_brport_flags {
	long unsigned int val;
	long unsigned int mask;
};

enum switchdev_obj_id {
	SWITCHDEV_OBJ_ID_UNDEFINED = 0,
	SWITCHDEV_OBJ_ID_PORT_VLAN = 1,
	SWITCHDEV_OBJ_ID_PORT_MDB = 2,
	SWITCHDEV_OBJ_ID_HOST_MDB = 3,
	SWITCHDEV_OBJ_ID_MRP = 4,
	SWITCHDEV_OBJ_ID_RING_TEST_MRP = 5,
	SWITCHDEV_OBJ_ID_RING_ROLE_MRP = 6,
	SWITCHDEV_OBJ_ID_RING_STATE_MRP = 7,
	SWITCHDEV_OBJ_ID_IN_TEST_MRP = 8,
	SWITCHDEV_OBJ_ID_IN_ROLE_MRP = 9,
	SWITCHDEV_OBJ_ID_IN_STATE_MRP = 10,
};

struct switchdev_obj {
	struct list_head list;
	struct net_device___45 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___45 *, int, void *);
};

struct switchdev_obj_port_vlan {
	struct switchdev_obj obj;
	u16 flags;
	u16 vid;
};

struct switchdev_obj_port_mdb {
	struct switchdev_obj obj;
	unsigned char addr[6];
	u16 vid;
};

struct switchdev_obj_mrp {
	struct switchdev_obj obj;
	struct net_device___45 *p_port;
	struct net_device___45 *s_port;
	u32 ring_id;
	u16 prio;
};

struct switchdev_obj_ring_role_mrp {
	struct switchdev_obj obj;
	u8 ring_role;
	u32 ring_id;
	u8 sw_backup;
};

enum dsa_tag_protocol {
	DSA_TAG_PROTO_NONE = 0,
	DSA_TAG_PROTO_BRCM = 1,
	DSA_TAG_PROTO_BRCM_LEGACY = 22,
	DSA_TAG_PROTO_BRCM_PREPEND = 2,
	DSA_TAG_PROTO_DSA = 3,
	DSA_TAG_PROTO_EDSA = 4,
	DSA_TAG_PROTO_GSWIP = 5,
	DSA_TAG_PROTO_KSZ9477 = 6,
	DSA_TAG_PROTO_KSZ9893 = 7,
	DSA_TAG_PROTO_LAN9303 = 8,
	DSA_TAG_PROTO_MTK = 9,
	DSA_TAG_PROTO_QCA = 10,
	DSA_TAG_PROTO_TRAILER = 11,
	DSA_TAG_PROTO_8021Q = 12,
	DSA_TAG_PROTO_SJA1105 = 13,
	DSA_TAG_PROTO_KSZ8795 = 14,
	DSA_TAG_PROTO_OCELOT = 15,
	DSA_TAG_PROTO_AR9331 = 16,
	DSA_TAG_PROTO_RTL4_A = 17,
	DSA_TAG_PROTO_HELLCREEK = 18,
	DSA_TAG_PROTO_XRS700X = 19,
	DSA_TAG_PROTO_OCELOT_8021Q = 20,
	DSA_TAG_PROTO_SEVILLE = 21,
	DSA_TAG_PROTO_SJA1110 = 23,
};

struct dsa_device_ops {
	struct sk_buff___44 * (*xmit)(struct sk_buff___44 *, struct net_device___45 *);
	struct sk_buff___44 * (*rcv)(struct sk_buff___44 *, struct net_device___45 *);
	void (*flow_dissect)(const struct sk_buff___44 *, __be16 *, int *);
	unsigned int needed_headroom;
	unsigned int needed_tailroom;
	const char *name;
	enum dsa_tag_protocol proto;
	bool promisc_on_master;
};

struct dsa_netdevice_ops {
	int (*ndo_eth_ioctl)(struct net_device___45 *, struct ifreq *, int);
};

struct dsa_switch_tree {
	struct list_head list;
	struct raw_notifier_head nh;
	unsigned int index;
	struct kref refcount;
	bool setup;
	const struct dsa_device_ops *tag_ops;
	enum dsa_tag_protocol default_proto;
	struct dsa_platform_data *pd;
	struct list_head ports;
	struct list_head rtable;
	struct net_device___45 **lags;
	unsigned int lags_len;
	unsigned int last_switch;
};

struct dsa_mall_mirror_tc_entry {
	u8 to_local_port;
	bool ingress;
};

struct dsa_mall_policer_tc_entry {
	u32 burst;
	u64 rate_bytes_per_sec;
};

struct dsa_8021q_context;

struct dsa_switch_ops;

struct dsa_switch {
	bool setup;
	struct device___203 *dev;
	struct dsa_switch_tree *dst;
	unsigned int index;
	struct notifier_block nb;
	void *priv;
	struct dsa_chip_data *cd;
	const struct dsa_switch_ops *ops;
	u32 phys_mii_mask;
	struct mii_bus___8 *slave_mii_bus;
	unsigned int ageing_time_min;
	unsigned int ageing_time_max;
	struct dsa_8021q_context *tag_8021q_ctx;
	struct devlink *devlink;
	unsigned int num_tx_queues;
	bool vlan_filtering_is_global;
	bool needs_standalone_vlan_filtering;
	bool configure_vlan_while_not_filtering;
	bool untag_bridge_pvid;
	bool assisted_learning_on_cpu_port;
	bool vlan_filtering;
	bool pcs_poll;
	bool mtu_enforcement_ingress;
	unsigned int num_lag_ids;
	unsigned int num_fwd_offloading_bridges;
	size_t num_ports;
};

typedef int dsa_fdb_dump_cb_t(const unsigned char *, u16, bool, void *);

struct dsa_switch_ops {
	enum dsa_tag_protocol (*get_tag_protocol)(struct dsa_switch *, int, enum dsa_tag_protocol);
	int (*change_tag_protocol)(struct dsa_switch *, int, enum dsa_tag_protocol);
	int (*setup)(struct dsa_switch *);
	void (*teardown)(struct dsa_switch *);
	int (*port_setup)(struct dsa_switch *, int);
	void (*port_teardown)(struct dsa_switch *, int);
	u32 (*get_phy_flags)(struct dsa_switch *, int);
	int (*phy_read)(struct dsa_switch *, int, int);
	int (*phy_write)(struct dsa_switch *, int, int, u16);
	void (*adjust_link)(struct dsa_switch *, int, struct phy_device___5 *);
	void (*fixed_link_update)(struct dsa_switch *, int, struct fixed_phy_status *);
	void (*phylink_validate)(struct dsa_switch *, int, long unsigned int *, struct phylink_link_state *);
	int (*phylink_mac_link_state)(struct dsa_switch *, int, struct phylink_link_state *);
	void (*phylink_mac_config)(struct dsa_switch *, int, unsigned int, const struct phylink_link_state *);
	void (*phylink_mac_an_restart)(struct dsa_switch *, int);
	void (*phylink_mac_link_down)(struct dsa_switch *, int, unsigned int, phy_interface_t);
	void (*phylink_mac_link_up)(struct dsa_switch *, int, unsigned int, phy_interface_t, struct phy_device___5 *, int, int, bool, bool);
	void (*phylink_fixed_state)(struct dsa_switch *, int, struct phylink_link_state *);
	void (*get_strings)(struct dsa_switch *, int, u32, uint8_t *);
	void (*get_ethtool_stats)(struct dsa_switch *, int, uint64_t *);
	int (*get_sset_count)(struct dsa_switch *, int, int);
	void (*get_ethtool_phy_stats)(struct dsa_switch *, int, uint64_t *);
	void (*get_stats64)(struct dsa_switch *, int, struct rtnl_link_stats64 *);
	void (*self_test)(struct dsa_switch *, int, struct ethtool_test *, u64 *);
	void (*get_wol)(struct dsa_switch *, int, struct ethtool_wolinfo *);
	int (*set_wol)(struct dsa_switch *, int, struct ethtool_wolinfo *);
	int (*get_ts_info)(struct dsa_switch *, int, struct ethtool_ts_info *);
	int (*suspend)(struct dsa_switch *);
	int (*resume)(struct dsa_switch *);
	int (*port_enable)(struct dsa_switch *, int, struct phy_device___5 *);
	void (*port_disable)(struct dsa_switch *, int);
	int (*set_mac_eee)(struct dsa_switch *, int, struct ethtool_eee *);
	int (*get_mac_eee)(struct dsa_switch *, int, struct ethtool_eee *);
	int (*get_eeprom_len)(struct dsa_switch *);
	int (*get_eeprom)(struct dsa_switch *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct dsa_switch *, struct ethtool_eeprom *, u8 *);
	int (*get_regs_len)(struct dsa_switch *, int);
	void (*get_regs)(struct dsa_switch *, int, struct ethtool_regs *, void *);
	int (*port_prechangeupper)(struct dsa_switch *, int, struct netdev_notifier_changeupper_info *);
	int (*set_ageing_time)(struct dsa_switch *, unsigned int);
	int (*port_bridge_join)(struct dsa_switch *, int, struct net_device___45 *);
	void (*port_bridge_leave)(struct dsa_switch *, int, struct net_device___45 *);
	int (*port_bridge_tx_fwd_offload)(struct dsa_switch *, int, struct net_device___45 *, int);
	void (*port_bridge_tx_fwd_unoffload)(struct dsa_switch *, int, struct net_device___45 *, int);
	void (*port_stp_state_set)(struct dsa_switch *, int, u8);
	void (*port_fast_age)(struct dsa_switch *, int);
	int (*port_pre_bridge_flags)(struct dsa_switch *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_bridge_flags)(struct dsa_switch *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_vlan_filtering)(struct dsa_switch *, int, bool, struct netlink_ext_ack *);
	int (*port_vlan_add)(struct dsa_switch *, int, const struct switchdev_obj_port_vlan *, struct netlink_ext_ack *);
	int (*port_vlan_del)(struct dsa_switch *, int, const struct switchdev_obj_port_vlan *);
	int (*port_fdb_add)(struct dsa_switch *, int, const unsigned char *, u16);
	int (*port_fdb_del)(struct dsa_switch *, int, const unsigned char *, u16);
	int (*port_fdb_dump)(struct dsa_switch *, int, dsa_fdb_dump_cb_t *, void *);
	int (*port_mdb_add)(struct dsa_switch *, int, const struct switchdev_obj_port_mdb *);
	int (*port_mdb_del)(struct dsa_switch *, int, const struct switchdev_obj_port_mdb *);
	int (*get_rxnfc)(struct dsa_switch *, int, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct dsa_switch *, int, struct ethtool_rxnfc *);
	int (*cls_flower_add)(struct dsa_switch *, int, struct flow_cls_offload *, bool);
	int (*cls_flower_del)(struct dsa_switch *, int, struct flow_cls_offload *, bool);
	int (*cls_flower_stats)(struct dsa_switch *, int, struct flow_cls_offload *, bool);
	int (*port_mirror_add)(struct dsa_switch *, int, struct dsa_mall_mirror_tc_entry *, bool);
	void (*port_mirror_del)(struct dsa_switch *, int, struct dsa_mall_mirror_tc_entry *);
	int (*port_policer_add)(struct dsa_switch *, int, struct dsa_mall_policer_tc_entry *);
	void (*port_policer_del)(struct dsa_switch *, int);
	int (*port_setup_tc)(struct dsa_switch *, int, enum tc_setup_type, void *);
	int (*crosschip_bridge_join)(struct dsa_switch *, int, int, int, struct net_device___45 *);
	void (*crosschip_bridge_leave)(struct dsa_switch *, int, int, int, struct net_device___45 *);
	int (*crosschip_lag_change)(struct dsa_switch *, int, int);
	int (*crosschip_lag_join)(struct dsa_switch *, int, int, struct net_device___45 *, struct netdev_lag_upper_info *);
	int (*crosschip_lag_leave)(struct dsa_switch *, int, int, struct net_device___45 *);
	int (*port_hwtstamp_get)(struct dsa_switch *, int, struct ifreq *);
	int (*port_hwtstamp_set)(struct dsa_switch *, int, struct ifreq *);
	void (*port_txtstamp)(struct dsa_switch *, int, struct sk_buff___44 *);
	bool (*port_rxtstamp)(struct dsa_switch *, int, struct sk_buff___44 *, unsigned int);
	int (*devlink_param_get)(struct dsa_switch *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_param_set)(struct dsa_switch *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_info_get)(struct dsa_switch *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*devlink_sb_pool_get)(struct dsa_switch *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*devlink_sb_pool_set)(struct dsa_switch *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*devlink_sb_port_pool_get)(struct dsa_switch *, int, unsigned int, u16, u32 *);
	int (*devlink_sb_port_pool_set)(struct dsa_switch *, int, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_tc_pool_bind_get)(struct dsa_switch *, int, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*devlink_sb_tc_pool_bind_set)(struct dsa_switch *, int, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_occ_snapshot)(struct dsa_switch *, unsigned int);
	int (*devlink_sb_occ_max_clear)(struct dsa_switch *, unsigned int);
	int (*devlink_sb_occ_port_pool_get)(struct dsa_switch *, int, unsigned int, u16, u32 *, u32 *);
	int (*devlink_sb_occ_tc_port_bind_get)(struct dsa_switch *, int, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*port_change_mtu)(struct dsa_switch *, int, int);
	int (*port_max_mtu)(struct dsa_switch *, int);
	int (*port_lag_change)(struct dsa_switch *, int);
	int (*port_lag_join)(struct dsa_switch *, int, struct net_device___45 *, struct netdev_lag_upper_info *);
	int (*port_lag_leave)(struct dsa_switch *, int, struct net_device___45 *);
	int (*port_hsr_join)(struct dsa_switch *, int, struct net_device___45 *);
	int (*port_hsr_leave)(struct dsa_switch *, int, struct net_device___45 *);
	int (*port_mrp_add)(struct dsa_switch *, int, const struct switchdev_obj_mrp *);
	int (*port_mrp_del)(struct dsa_switch *, int, const struct switchdev_obj_mrp *);
	int (*port_mrp_add_ring_role)(struct dsa_switch *, int, const struct switchdev_obj_ring_role_mrp *);
	int (*port_mrp_del_ring_role)(struct dsa_switch *, int, const struct switchdev_obj_ring_role_mrp *);
	int (*tag_8021q_vlan_add)(struct dsa_switch *, int, u16, u16);
	int (*tag_8021q_vlan_del)(struct dsa_switch *, int, u16);
};

struct bgmac_slot_info {
	union {
		struct sk_buff___44 *skb;
		void *buf;
	};
	dma_addr_t dma_addr;
};

struct bgmac_dma_desc {
	__le32 ctl0;
	__le32 ctl1;
	__le32 addr_low;
	__le32 addr_high;
};

enum bgmac_dma_ring_type {
	BGMAC_DMA_RING_TX = 0,
	BGMAC_DMA_RING_RX = 1,
};

struct bgmac_dma_ring {
	u32 start;
	u32 end;
	struct bgmac_dma_desc *cpu_base;
	dma_addr_t dma_base;
	u32 index_base;
	u16 mmio_base;
	bool unaligned;
	struct bgmac_slot_info slots[512];
};

struct bgmac_rx_header {
	__le16 len;
	__le16 flags;
	__le16 pad[12];
};

struct bgmac {
	union {
		struct {
			void *base;
			void *idm_base;
			void *nicpm_base;
		} plat;
		struct {
			struct bcma_device *core;
			struct bcma_device *cmn;
		} bcma;
	};
	struct device___203 *dev;
	struct device___203 *dma_dev;
	u32 feature_flags;
	struct net_device___45 *net_dev;
	struct napi_struct___2 napi;
	struct mii_bus___8 *mii_bus;
	struct bgmac_dma_ring tx_ring[4];
	struct bgmac_dma_ring rx_ring[1];
	bool stats_grabbed;
	u32 mib_tx_regs[43];
	u32 mib_rx_regs[31];
	int irq;
	u32 int_mask;
	int mac_speed;
	int mac_duplex;
	u8 phyaddr;
	bool has_robosw;
	bool loopback;
	u32 (*read)(struct bgmac *, u16);
	void (*write)(struct bgmac *, u16, u32);
	u32 (*idm_read)(struct bgmac *, u16);
	void (*idm_write)(struct bgmac *, u16, u32);
	bool (*clk_enabled)(struct bgmac *);
	void (*clk_enable)(struct bgmac *, u32);
	void (*cco_ctl_maskset)(struct bgmac *, u32, u32, u32);
	u32 (*get_bus_clock)(struct bgmac *);
	void (*cmn_maskset32)(struct bgmac *, u16, u32, u32);
	int (*phy_connect)(struct bgmac *);
};

struct bgmac_stat {
	u8 size;
	u32 offset;
	const char *name;
};

struct pci_bus___20;

struct pci_slot___20 {
	struct pci_bus___20 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___195 kobj;
};

struct pci_dev___20;

struct pci_ops___20;

struct pci_bus___20 {
	struct list_head node;
	struct pci_bus___20 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___20 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___20 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___178 *bridge;
	struct device___178 dev;
	struct bin_attribute___195 *legacy_io;
	struct bin_attribute___195 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___20;

struct pci_dev___20 {
	struct list_head bus_list;
	struct pci_bus___20 *bus;
	struct pci_bus___20 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___20 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___20 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___20 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___178 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___195 *res_attr[17];
	struct bin_attribute___195 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___195 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___20 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___20;

struct pci_driver___20 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___20 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___20 *);
	int (*suspend)(struct pci_dev___20 *, pm_message_t);
	int (*resume)(struct pci_dev___20 *);
	void (*shutdown)(struct pci_dev___20 *);
	int (*sriov_configure)(struct pci_dev___20 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___20 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___20 *);
	const struct pci_error_handlers___20 *err_handler;
	const struct attribute_group___195 **groups;
	const struct attribute_group___195 **dev_groups;
	struct device_driver___178 driver;
	struct pci_dynids dynids;
};

struct pci_ops___20 {
	int (*add_bus)(struct pci_bus___20 *);
	void (*remove_bus)(struct pci_bus___20 *);
	void * (*map_bus)(struct pci_bus___20 *, unsigned int, int);
	int (*read)(struct pci_bus___20 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___20 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___20 {
	pci_ers_result_t (*error_detected)(struct pci_dev___20 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___20 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___20 *);
	void (*reset_prepare)(struct pci_dev___20 *);
	void (*reset_done)(struct pci_dev___20 *);
	void (*resume)(struct pci_dev___20 *);
};

struct platform_driver___32 {
	int (*probe)(struct platform_device___36 *);
	int (*remove)(struct platform_device___36 *);
	void (*shutdown)(struct platform_device___36 *);
	int (*suspend)(struct platform_device___36 *, pm_message_t);
	int (*resume)(struct platform_device___36 *);
	struct device_driver___178 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct of_phandle_args___39 {
	struct device_node___75 *np;
	int args_count;
	uint32_t args[16];
};

struct gpio_chip___12;

struct gpio_irq_chip___12 {
	struct irq_chip___48 *chip;
	struct irq_domain___47 *domain;
	const struct irq_domain_ops___47 *domain_ops;
	struct fwnode_handle___176 *fwnode;
	struct irq_domain___47 *parent_domain;
	int (*child_to_parent_hwirq)(struct gpio_chip___12 *, unsigned int, unsigned int, unsigned int *, unsigned int *);
	void * (*populate_parent_alloc_arg)(struct gpio_chip___12 *, unsigned int, unsigned int);
	unsigned int (*child_offset_to_irq)(struct gpio_chip___12 *, unsigned int);
	struct irq_domain_ops___47 child_irq_domain_ops;
	irq_flow_handler_t___49 handler;
	unsigned int default_type;
	struct lock_class_key *lock_key;
	struct lock_class_key *request_key;
	irq_flow_handler_t___49 parent_handler;
	void *parent_handler_data;
	unsigned int num_parents;
	unsigned int *parents;
	unsigned int *map;
	bool threaded;
	int (*init_hw)(struct gpio_chip___12 *);
	void (*init_valid_mask)(struct gpio_chip___12 *, long unsigned int *, unsigned int);
	bool initialized;
	long unsigned int *valid_mask;
	unsigned int first;
	void (*irq_enable)(struct irq_data___48 *);
	void (*irq_disable)(struct irq_data___48 *);
	void (*irq_unmask)(struct irq_data___48 *);
	void (*irq_mask)(struct irq_data___48 *);
};

struct gpio_chip___12 {
	const char *label;
	struct gpio_device *gpiodev;
	struct device___178 *parent;
	struct module___191 *owner;
	int (*request)(struct gpio_chip___12 *, unsigned int);
	void (*free)(struct gpio_chip___12 *, unsigned int);
	int (*get_direction)(struct gpio_chip___12 *, unsigned int);
	int (*direction_input)(struct gpio_chip___12 *, unsigned int);
	int (*direction_output)(struct gpio_chip___12 *, unsigned int, int);
	int (*get)(struct gpio_chip___12 *, unsigned int);
	int (*get_multiple)(struct gpio_chip___12 *, long unsigned int *, long unsigned int *);
	void (*set)(struct gpio_chip___12 *, unsigned int, int);
	void (*set_multiple)(struct gpio_chip___12 *, long unsigned int *, long unsigned int *);
	int (*set_config)(struct gpio_chip___12 *, unsigned int, long unsigned int);
	int (*to_irq)(struct gpio_chip___12 *, unsigned int);
	void (*dbg_show)(struct seq_file___182 *, struct gpio_chip___12 *);
	int (*init_valid_mask)(struct gpio_chip___12 *, long unsigned int *, unsigned int);
	int (*add_pin_ranges)(struct gpio_chip___12 *);
	int base;
	u16 ngpio;
	u16 offset;
	const char * const *names;
	bool can_sleep;
	long unsigned int (*read_reg)(void *);
	void (*write_reg)(void *, long unsigned int);
	bool be_bits;
	void *reg_dat;
	void *reg_set;
	void *reg_clr;
	void *reg_dir_out;
	void *reg_dir_in;
	bool bgpio_dir_unreadable;
	int bgpio_bits;
	spinlock_t bgpio_lock;
	long unsigned int bgpio_data;
	long unsigned int bgpio_dir;
	struct gpio_irq_chip___12 irq;
	long unsigned int *valid_mask;
	struct device_node___75 *of_node;
	unsigned int of_gpio_n_cells;
	int (*of_xlate)(struct gpio_chip___12 *, const struct of_phandle_args___39 *, u32 *);
};

struct bcma_device___2;

struct bcma_chipcommon_pmu___2 {
	struct bcma_device___2 *core;
	u8 rev;
	u32 crystalfreq;
};

struct bcma_bus___2;

struct bcma_device___2 {
	struct bcma_bus___2 *bus;
	struct bcma_device_id id;
	struct device___178 dev;
	struct device___178 *dma_dev;
	unsigned int irq;
	bool dev_registered;
	u8 core_index;
	u8 core_unit;
	u32 addr;
	u32 addr_s[8];
	u32 wrap;
	void *io_addr;
	void *io_wrap;
	void *drvdata;
	struct list_head list;
};

struct bcma_drv_cc___2 {
	struct bcma_device___2 *core;
	u32 status;
	u32 capabilities;
	u32 capabilities_ext;
	u8 setup_done: 1;
	u8 early_setup_done: 1;
	long: 47;
	long: 64;
	long: 64;
	u16 fast_pwrup_delay;
	struct bcma_chipcommon_pmu___2 pmu;
	struct bcma_sflash sflash;
	u32 ticks_per_ms;
	struct platform_device___36 *watchdog;
	spinlock_t gpio_lock;
	struct gpio_chip___12 gpio;
};

struct bcma_drv_cc_b___2 {
	struct bcma_device___2 *core;
	u8 setup_done: 1;
	long: 63;
	long: 64;
	void *mii;
};

struct bcma_drv_pci___2 {
	struct bcma_device___2 *core;
	u8 early_setup_done: 1;
	u8 setup_done: 1;
	u8 hostmode: 1;
	long: 63;
	long: 64;
};

struct bcma_drv_pcie2___2 {
	struct bcma_device___2 *core;
	u16 reqsize;
};

struct bcma_drv_mips___2 {
	struct bcma_device___2 *core;
	u8 setup_done: 1;
	u8 early_setup_done: 1;
	long: 63;
	long: 64;
};

struct bcma_drv_gmac_cmn___2 {
	struct bcma_device___2 *core;
	struct mutex phy_mutex;
};

struct bcma_host_ops___2 {
	u8 (*read8)(struct bcma_device___2 *, u16);
	u16 (*read16)(struct bcma_device___2 *, u16);
	u32 (*read32)(struct bcma_device___2 *, u16);
	void (*write8)(struct bcma_device___2 *, u16, u8);
	void (*write16)(struct bcma_device___2 *, u16, u16);
	void (*write32)(struct bcma_device___2 *, u16, u32);
	void (*block_read)(struct bcma_device___2 *, void *, size_t, u16, u8);
	void (*block_write)(struct bcma_device___2 *, const void *, size_t, u16, u8);
	u32 (*aread32)(struct bcma_device___2 *, u16);
	void (*awrite32)(struct bcma_device___2 *, u16, u32);
};

struct bcma_bus___2 {
	struct device___178 *dev;
	void *mmio;
	const struct bcma_host_ops___2 *ops;
	enum bcma_hosttype hosttype;
	bool host_is_pcie2;
	struct pci_dev___20 *host_pci;
	struct bcma_chipinfo chipinfo;
	struct bcma_boardinfo boardinfo;
	struct bcma_device___2 *mapped_core;
	struct list_head cores;
	u8 nr_cores;
	u8 num;
	struct bcma_drv_cc___2 drv_cc;
	struct bcma_drv_cc_b___2 drv_cc_b;
	struct bcma_drv_pci___2 drv_pci[2];
	struct bcma_drv_pcie2___2 drv_pcie2;
	struct bcma_drv_mips___2 drv_mips;
	struct bcma_drv_gmac_cmn___2 drv_gmac_cmn;
	struct ssb_sprom sprom;
};

struct napi_struct___3 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___3 *, int);
	int poll_owner;
	struct net_device___40 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___39 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___214 *thread;
};

struct bgmac_slot_info___2 {
	union {
		struct sk_buff___39 *skb;
		void *buf;
	};
	dma_addr_t dma_addr;
};

struct bgmac_dma_ring___2 {
	u32 start;
	u32 end;
	struct bgmac_dma_desc *cpu_base;
	dma_addr_t dma_base;
	u32 index_base;
	u16 mmio_base;
	bool unaligned;
	struct bgmac_slot_info___2 slots[512];
};

struct bgmac___2 {
	union {
		struct {
			void *base;
			void *idm_base;
			void *nicpm_base;
		} plat;
		struct {
			struct bcma_device___2 *core;
			struct bcma_device___2 *cmn;
		} bcma;
	};
	struct device___178 *dev;
	struct device___178 *dma_dev;
	u32 feature_flags;
	struct net_device___40 *net_dev;
	struct napi_struct___3 napi;
	struct mii_bus___2 *mii_bus;
	struct bgmac_dma_ring___2 tx_ring[4];
	struct bgmac_dma_ring___2 rx_ring[1];
	bool stats_grabbed;
	u32 mib_tx_regs[43];
	u32 mib_rx_regs[31];
	int irq;
	u32 int_mask;
	int mac_speed;
	int mac_duplex;
	u8 phyaddr;
	bool has_robosw;
	bool loopback;
	u32 (*read)(struct bgmac___2 *, u16);
	void (*write)(struct bgmac___2 *, u16, u32);
	u32 (*idm_read)(struct bgmac___2 *, u16);
	void (*idm_write)(struct bgmac___2 *, u16, u32);
	bool (*clk_enabled)(struct bgmac___2 *);
	void (*clk_enable)(struct bgmac___2 *, u32);
	void (*cco_ctl_maskset)(struct bgmac___2 *, u32, u32, u32);
	u32 (*get_bus_clock)(struct bgmac___2 *);
	void (*cmn_maskset32)(struct bgmac___2 *, u16, u32, u32);
	int (*phy_connect)(struct bgmac___2 *);
};

struct dentry___226;

struct super_block___226;

struct module___210;

struct file_system_type___226 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___226 * (*mount)(struct file_system_type___226 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___226 *);
	struct module___210 *owner;
	struct file_system_type___226 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___226;

struct kiocb___226;

struct iov_iter___146;

struct poll_table_struct___151;

struct vm_area_struct___231;

struct inode___226;

struct file_lock___226;

struct page___231;

struct pipe_inode_info___76;

struct seq_file___201;

struct file_operations___227 {
	struct module___210 *owner;
	loff_t (*llseek)(struct file___226 *, loff_t, int);
	ssize_t (*read)(struct file___226 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___226 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___226 *, struct iov_iter___146 *);
	ssize_t (*write_iter)(struct kiocb___226 *, struct iov_iter___146 *);
	int (*iopoll)(struct kiocb___226 *, bool);
	int (*iterate)(struct file___226 *, struct dir_context *);
	int (*iterate_shared)(struct file___226 *, struct dir_context *);
	__poll_t (*poll)(struct file___226 *, struct poll_table_struct___151 *);
	long int (*unlocked_ioctl)(struct file___226 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___226 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___226 *, struct vm_area_struct___231 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___226 *, struct file___226 *);
	int (*flush)(struct file___226 *, fl_owner_t);
	int (*release)(struct inode___226 *, struct file___226 *);
	int (*fsync)(struct file___226 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___226 *, int);
	int (*lock)(struct file___226 *, int, struct file_lock___226 *);
	ssize_t (*sendpage)(struct file___226 *, struct page___231 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___226 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___226 *, long unsigned int);
	int (*flock)(struct file___226 *, int, struct file_lock___226 *);
	ssize_t (*splice_write)(struct pipe_inode_info___76 *, struct file___226 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___226 *, loff_t *, struct pipe_inode_info___76 *, size_t, unsigned int);
	int (*setlease)(struct file___226 *, long int, struct file_lock___226 **, void **);
	long int (*fallocate)(struct file___226 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___201 *, struct file___226 *);
	ssize_t (*copy_file_range)(struct file___226 *, loff_t, struct file___226 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___226 *, loff_t, struct file___226 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___226 *, loff_t, loff_t, int);
};

struct vmacache___231 {
	u64 seqnum;
	struct vm_area_struct___231 *vmas[4];
};

struct page_frag___231 {
	struct page___231 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___232;

struct pid___203;

struct nsproxy___212;

struct signal_struct___227;

struct bio_list___119;

struct backing_dev_info___108;

struct io_context___119;

struct css_set___156;

struct mem_cgroup___99;

struct request_queue___119;

struct vm_struct___209;

struct task_struct___233 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___233 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___232 *mm;
	struct mm_struct___232 *active_mm;
	struct vmacache___231 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___233 *real_parent;
	struct task_struct___233 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___233 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___203 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___212 *nsproxy;
	struct signal_struct___227 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___233 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___119 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___108 *backing_dev_info;
	struct io_context___119 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___156 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___76 *splice_pipe;
	struct page_frag___231 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___99 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___99 *active_memcg;
	struct request_queue___119 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___233 *oom_reaper_list;
	struct vm_struct___209 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___214;

struct kobj_type___214;

struct kernfs_node___214;

struct kobject___214 {
	const char *name;
	struct list_head entry;
	struct kobject___214 *parent;
	struct kset___214 *kset;
	struct kobj_type___214 *ktype;
	struct kernfs_node___214 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___211 {
	struct kobject___214 kobj;
	struct module___210 *mod;
	struct kobject___214 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___210 {
	struct module___210 *mod;
	struct latch_tree_node node;
};

struct module_layout___210 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___210 mtn;
};

struct module_attribute___210;

struct kernel_param___210;

struct module___210 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___211 mkobj;
	struct module_attribute___210 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___214 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___210 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___210 core_layout;
	struct module_layout___210 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___203;

struct upid___203 {
	int nr;
	struct pid_namespace___203 *ns;
};

struct pid_namespace___203 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___233 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___203 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___203 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___203 numbers[1];
};

typedef struct page___231 *pgtable_t___231;

struct address_space___226;

struct page_pool___64;

struct dev_pagemap___221;

struct page___231 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___226 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___64 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___231 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___231 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___232 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___221 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___221;

struct vm_area_struct___231 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___231 *vm_next;
	struct vm_area_struct___231 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___232 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___221 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___226 *vm_file;
	struct file___226 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___227 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___233 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___233 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___203 *pids[4];
	struct pid___203 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___232 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___231;

struct mm_struct___232 {
	struct {
		struct vm_area_struct___231 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___226 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___231 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___233 *owner;
		struct user_namespace___14 *user_ns;
		struct file___226 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___49;

struct cgroup_namespace___156;

struct nsproxy___212 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___203 *pid_ns_for_children;
	struct net___49 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___156 *cgroup_ns;
};

struct bio___119;

struct bio_list___119 {
	struct bio___119 *head;
	struct bio___119 *tail;
};

struct cgroup_subsys_state___156;

struct bdi_writeback___108 {
	struct backing_dev_info___108 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___156 *memcg_css;
	struct cgroup_subsys_state___156 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___204;

struct backing_dev_info___108 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___108 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___204 *dev;
	char dev_name[64];
	struct device___204 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___226 *debug_dir;
};

struct io_cq___119;

struct io_context___119 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___119 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___156;

struct css_set___156 {
	struct cgroup_subsys_state___156 *subsys[14];
	refcount_t refcount;
	struct css_set___156 *dom_cset;
	struct cgroup___156 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___156 *mg_src_cgrp;
	struct cgroup___156 *mg_dst_cgrp;
	struct css_set___156 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___226;

struct pipe_buffer___76;

struct pipe_inode_info___76 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___231 *tmp_page;
	struct fasync_struct___226 *fasync_readers;
	struct fasync_struct___226 *fasync_writers;
	struct pipe_buffer___76 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___156;

struct cgroup_subsys_state___156 {
	struct cgroup___156 *cgroup;
	struct cgroup_subsys___156 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___156 *parent;
};

struct cgroup_file___156 {
	struct kernfs_node___214 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___99;

struct mem_cgroup_per_node___99;

struct mem_cgroup___99 {
	struct cgroup_subsys_state___156 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___156 events_file;
	struct cgroup_file___156 events_local_file;
	struct cgroup_file___156 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___99 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___233 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___99 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___119;

struct blk_integrity___119 {
	const struct blk_integrity_profile___119 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___119 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___119 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___119;

struct elevator_queue___119;

struct blk_mq_ops___116;

struct blk_mq_hw_ctx___116;

struct gendisk___122;

struct blkcg_gq___110;

struct blk_mq_tag_set___116;

struct request_queue___119 {
	struct request___119 *last_merge;
	struct elevator_queue___119 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___116 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___116 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___122 *disk;
	struct kobject___214 kobj;
	struct kobject___214 *mq_kobj;
	struct blk_integrity___119 integrity;
	struct device___204 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___110 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___116 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___119 bio_split;
	struct dentry___226 *debugfs_dir;
	struct dentry___226 *sched_debugfs_dir;
	struct dentry___226 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___209 {
	struct vm_struct___209 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___231 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___226;

struct address_space___226 {
	struct inode___226 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___226 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___64 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___204 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___64 {
	u32 count;
	struct page___231 *cache[128];
};

struct page_pool___64 {
	struct page_pool_params___64 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___231 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___64 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___221;

struct dev_pagemap___221 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___221 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___226;

struct path___226 {
	struct vfsmount___226 *mnt;
	struct dentry___226 *dentry;
};

struct fown_struct___203 {
	rwlock_t lock;
	struct pid___203 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___226 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___226 f_path;
	struct inode___226 *f_inode;
	const struct file_operations___227 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___203 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___226 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___221;

struct vm_operations_struct___221 {
	void (*open)(struct vm_area_struct___231 *);
	void (*close)(struct vm_area_struct___231 *);
	int (*may_split)(struct vm_area_struct___231 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___231 *);
	int (*mprotect)(struct vm_area_struct___231 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___221 *);
	vm_fault_t (*huge_fault)(struct vm_fault___221 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___221 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___231 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___221 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___221 *);
	int (*access)(struct vm_area_struct___231 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___231 *);
	int (*set_policy)(struct vm_area_struct___231 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___231 *, long unsigned int);
	struct page___231 * (*find_special_page)(struct vm_area_struct___231 *, long unsigned int);
};

struct core_thread___231 {
	struct task_struct___233 *task;
	struct core_thread___231 *next;
};

struct core_state___231 {
	atomic_t nr_threads;
	struct core_thread___231 dumper;
	struct completion startup;
};

struct vm_fault___221 {
	const struct {
		struct vm_area_struct___231 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___231 *cow_page;
	struct page___231 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___231 prealloc_pte;
};

struct pglist_data___107;

struct lruvec___107 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___107 *pgdat;
};

struct zone___107 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___107 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___107 {
	struct zone___107 *zone;
	int zone_idx;
};

struct zonelist___107 {
	struct zoneref___107 _zonerefs[321];
};

struct pglist_data___107 {
	struct zone___107 node_zones[5];
	struct zonelist___107 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___233 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___233 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___107 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___226;

struct dentry___226 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___226 *d_parent;
	struct qstr d_name;
	struct inode___226 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___226 *d_op;
	struct super_block___226 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___226;

struct cdev___60;

struct inode___226 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___226 *i_op;
	struct super_block___226 *i_sb;
	struct address_space___226 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___108 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___227 *i_fop;
		void (*free_inode)(struct inode___226 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___226 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___76 *i_pipe;
		struct cdev___60 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___226 {
	int (*d_revalidate)(struct dentry___226 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___226 *, unsigned int);
	int (*d_hash)(const struct dentry___226 *, struct qstr *);
	int (*d_compare)(const struct dentry___226 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___226 *);
	int (*d_init)(struct dentry___226 *);
	void (*d_release)(struct dentry___226 *);
	void (*d_prune)(struct dentry___226 *);
	void (*d_iput)(struct dentry___226 *, struct inode___226 *);
	char * (*d_dname)(struct dentry___226 *, char *, int);
	struct vfsmount___226 * (*d_automount)(struct path___226 *);
	int (*d_manage)(const struct path___226 *, bool);
	struct dentry___226 * (*d_real)(struct dentry___226 *, const struct inode___226 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___226;

struct mem_dqinfo___226 {
	struct quota_format_type___226 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___226;

struct quota_info___226 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___226 *files[3];
	struct mem_dqinfo___226 info[3];
	const struct quota_format_ops___226 *ops[3];
};

struct rcuwait___227 {
	struct task_struct___233 *task;
};

struct percpu_rw_semaphore___227 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___227 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___226 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___227 rw_sem[3];
};

struct shrink_control___99;

struct shrinker___99 {
	long unsigned int (*count_objects)(struct shrinker___99 *, struct shrink_control___99 *);
	long unsigned int (*scan_objects)(struct shrinker___99 *, struct shrink_control___99 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___226;

struct dquot_operations___226;

struct quotactl_ops___226;

struct block_device___122;

struct super_block___226 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___226 *s_type;
	const struct super_operations___226 *s_op;
	const struct dquot_operations___226 *dq_op;
	const struct quotactl_ops___226 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___226 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___122 *s_bdev;
	struct backing_dev_info___108 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___226 s_dquot;
	struct sb_writers___226 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___226 *s_d_op;
	int cleancache_poolid;
	struct shrinker___99 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___226 {
	struct dentry___226 *mnt_root;
	struct super_block___226 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___99 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___99 *memcg;
};

struct psi_group___156 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___233 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___40;

struct cgroup_bpf___40 {
	struct bpf_prog_array___40 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___40 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___156;

struct cgroup_rstat_cpu___156;

struct cgroup___156 {
	struct cgroup_subsys_state___156 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___214 *kn;
	struct cgroup_file___156 procs_file;
	struct cgroup_file___156 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___156 *subsys[14];
	struct cgroup_root___156 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___156 *dom_cgrp;
	struct cgroup___156 *old_dom_cgrp;
	struct cgroup_rstat_cpu___156 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___156 psi;
	struct cgroup_bpf___40 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___119 {
	struct request_queue___119 *q;
	struct io_context___119 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___106;

struct kiocb___226 {
	struct file___226 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___226 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___106 *ki_waitq;
	};
};

struct iattr___226 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___226 *ia_file;
};

struct dquot___226 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___226 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___226 {
	int qf_fmt_id;
	const struct quota_format_ops___226 *qf_ops;
	struct module___210 *qf_owner;
	struct quota_format_type___226 *qf_next;
};

struct quota_format_ops___226 {
	int (*check_quota_file)(struct super_block___226 *, int);
	int (*read_file_info)(struct super_block___226 *, int);
	int (*write_file_info)(struct super_block___226 *, int);
	int (*free_file_info)(struct super_block___226 *, int);
	int (*read_dqblk)(struct dquot___226 *);
	int (*commit_dqblk)(struct dquot___226 *);
	int (*release_dqblk)(struct dquot___226 *);
	int (*get_next_id)(struct super_block___226 *, struct kqid *);
};

struct dquot_operations___226 {
	int (*write_dquot)(struct dquot___226 *);
	struct dquot___226 * (*alloc_dquot)(struct super_block___226 *, int);
	void (*destroy_dquot)(struct dquot___226 *);
	int (*acquire_dquot)(struct dquot___226 *);
	int (*release_dquot)(struct dquot___226 *);
	int (*mark_dirty)(struct dquot___226 *);
	int (*write_info)(struct super_block___226 *, int);
	qsize_t * (*get_reserved_space)(struct inode___226 *);
	int (*get_projid)(struct inode___226 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___226 *, qsize_t *);
	int (*get_next_id)(struct super_block___226 *, struct kqid *);
};

struct quotactl_ops___226 {
	int (*quota_on)(struct super_block___226 *, int, int, const struct path___226 *);
	int (*quota_off)(struct super_block___226 *, int);
	int (*quota_enable)(struct super_block___226 *, unsigned int);
	int (*quota_disable)(struct super_block___226 *, unsigned int);
	int (*quota_sync)(struct super_block___226 *, int);
	int (*set_info)(struct super_block___226 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___226 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___226 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___226 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___226 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___226 *, unsigned int);
};

struct wait_page_queue___106 {
	struct page___231 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___108;

struct readahead_control___106;

struct swap_info_struct___64;

struct address_space_operations___226 {
	int (*writepage)(struct page___231 *, struct writeback_control___108 *);
	int (*readpage)(struct file___226 *, struct page___231 *);
	int (*writepages)(struct address_space___226 *, struct writeback_control___108 *);
	int (*set_page_dirty)(struct page___231 *);
	int (*readpages)(struct file___226 *, struct address_space___226 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___106 *);
	int (*write_begin)(struct file___226 *, struct address_space___226 *, loff_t, unsigned int, unsigned int, struct page___231 **, void **);
	int (*write_end)(struct file___226 *, struct address_space___226 *, loff_t, unsigned int, unsigned int, struct page___231 *, void *);
	sector_t (*bmap)(struct address_space___226 *, sector_t);
	void (*invalidatepage)(struct page___231 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___231 *, gfp_t);
	void (*freepage)(struct page___231 *);
	ssize_t (*direct_IO)(struct kiocb___226 *, struct iov_iter___146 *);
	int (*migratepage)(struct address_space___226 *, struct page___231 *, struct page___231 *, enum migrate_mode);
	bool (*isolate_page)(struct page___231 *, isolate_mode_t);
	void (*putback_page)(struct page___231 *);
	int (*launder_page)(struct page___231 *);
	int (*is_partially_uptodate)(struct page___231 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___231 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___226 *, struct page___231 *);
	int (*swap_activate)(struct swap_info_struct___64 *, struct file___226 *, sector_t *);
	void (*swap_deactivate)(struct file___226 *);
};

struct writeback_control___108 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___108 *wb;
	struct inode___226 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___106 {
	struct file___226 *file;
	struct address_space___226 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___143;

struct iov_iter___146 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___143 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___76 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___64 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___122 *bdev;
	struct file___226 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___60 {
	struct kobject___214 kobj;
	struct module___210 *owner;
	const struct file_operations___227 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___226 {
	struct dentry___226 * (*lookup)(struct inode___226 *, struct dentry___226 *, unsigned int);
	const char * (*get_link)(struct dentry___226 *, struct inode___226 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___226 *, int);
	struct posix_acl * (*get_acl)(struct inode___226 *, int, bool);
	int (*readlink)(struct dentry___226 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___226 *, struct dentry___226 *, umode_t, bool);
	int (*link)(struct dentry___226 *, struct inode___226 *, struct dentry___226 *);
	int (*unlink)(struct inode___226 *, struct dentry___226 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___226 *, struct dentry___226 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___226 *, struct dentry___226 *, umode_t);
	int (*rmdir)(struct inode___226 *, struct dentry___226 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___226 *, struct dentry___226 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___226 *, struct dentry___226 *, struct inode___226 *, struct dentry___226 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___226 *, struct iattr___226 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___226 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___226 *, char *, size_t);
	int (*fiemap)(struct inode___226 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___226 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___226 *, struct dentry___226 *, struct file___226 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___226 *, struct dentry___226 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___226 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___226 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___226 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___226 {
	void (*fl_copy_lock)(struct file_lock___226 *, struct file_lock___226 *);
	void (*fl_release_private)(struct file_lock___226 *);
};

struct lock_manager_operations___226;

struct file_lock___226 {
	struct file_lock___226 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___226 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___226 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___226 *fl_ops;
	const struct lock_manager_operations___226 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___226 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___226 *);
	int (*lm_grant)(struct file_lock___226 *, int);
	bool (*lm_break)(struct file_lock___226 *);
	int (*lm_change)(struct file_lock___226 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___226 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___226 *);
};

struct fasync_struct___226 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___226 *fa_next;
	struct file___226 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___226 {
	struct inode___226 * (*alloc_inode)(struct super_block___226 *);
	void (*destroy_inode)(struct inode___226 *);
	void (*free_inode)(struct inode___226 *);
	void (*dirty_inode)(struct inode___226 *, int);
	int (*write_inode)(struct inode___226 *, struct writeback_control___108 *);
	int (*drop_inode)(struct inode___226 *);
	void (*evict_inode)(struct inode___226 *);
	void (*put_super)(struct super_block___226 *);
	int (*sync_fs)(struct super_block___226 *, int);
	int (*freeze_super)(struct super_block___226 *);
	int (*freeze_fs)(struct super_block___226 *);
	int (*thaw_super)(struct super_block___226 *);
	int (*unfreeze_fs)(struct super_block___226 *);
	int (*statfs)(struct dentry___226 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___226 *, int *, char *);
	void (*umount_begin)(struct super_block___226 *);
	int (*show_options)(struct seq_file___201 *, struct dentry___226 *);
	int (*show_devname)(struct seq_file___201 *, struct dentry___226 *);
	int (*show_path)(struct seq_file___201 *, struct dentry___226 *);
	int (*show_stats)(struct seq_file___201 *, struct dentry___226 *);
	ssize_t (*quota_read)(struct super_block___226 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___226 *, int, const char *, size_t, loff_t);
	struct dquot___226 ** (*get_dquots)(struct inode___226 *);
	long int (*nr_cached_objects)(struct super_block___226 *, struct shrink_control___99 *);
	long int (*free_cached_objects)(struct super_block___226 *, struct shrink_control___99 *);
	struct file___226 * (*real_loop)(struct file___226 *);
};

struct wakeup_source___204;

struct dev_pm_info___204 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___204 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___204 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___204;

struct bus_type___204;

struct device_driver___204;

struct dev_pm_domain___204;

struct irq_domain___57;

struct device_node___90;

struct fwnode_handle___200;

struct class___204;

struct attribute_group___214;

struct device___204 {
	struct kobject___214 kobj;
	struct device___204 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___204 *type;
	struct bus_type___204 *bus;
	struct device_driver___204 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___204 power;
	struct dev_pm_domain___204 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___57 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___90 *of_node;
	struct fwnode_handle___200 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___204 *class;
	const struct attribute_group___214 **groups;
	void (*release)(struct device___204 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___122 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___226 *bd_inode;
	struct super_block___226 *bd_super;
	void *bd_claiming;
	struct device___204 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___214 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___122 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___226 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___158)(struct file___226 *, wait_queue_head_t *, struct poll_table_struct___151 *);

struct poll_table_struct___151 {
	poll_queue_proc___158 _qproc;
	__poll_t _key;
};

struct seq_operations___201;

struct seq_file___201 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___201 *op;
	int poll_event;
	const struct file___226 *file;
	void *private;
};

typedef void bio_end_io_t___119(struct bio___119 *);

struct bio_vec___143 {
	struct page___231 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___119;

struct bio___119 {
	struct bio___119 *bi_next;
	struct block_device___122 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___119 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___110 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___119 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___143 *bi_io_vec;
	struct bio_set___119 *bi_pool;
	struct bio_vec___143 bi_inline_vecs[0];
};

struct kernfs_root___214;

struct kernfs_elem_dir___214 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___214 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___214;

struct kernfs_root___214 {
	struct kernfs_node___214 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___214 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___214 {
	struct kernfs_node___214 *target_kn;
};

struct kernfs_ops___214;

struct kernfs_elem_attr___214 {
	const struct kernfs_ops___214 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___214 *notify_next;
};

struct kernfs_node___214 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___214 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___214 dir;
		struct kernfs_elem_symlink___214 symlink;
		struct kernfs_elem_attr___214 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___214;

struct kernfs_ops___214 {
	int (*open)(struct kernfs_open_file___214 *);
	void (*release)(struct kernfs_open_file___214 *);
	int (*seq_show)(struct seq_file___201 *, void *);
	void * (*seq_start)(struct seq_file___201 *, loff_t *);
	void * (*seq_next)(struct seq_file___201 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___201 *, void *);
	ssize_t (*read)(struct kernfs_open_file___214 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___214 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___214 *, struct poll_table_struct___151 *);
	int (*mmap)(struct kernfs_open_file___214 *, struct vm_area_struct___231 *);
};

struct kernfs_syscall_ops___214 {
	int (*show_options)(struct seq_file___201 *, struct kernfs_root___214 *);
	int (*mkdir)(struct kernfs_node___214 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___214 *);
	int (*rename)(struct kernfs_node___214 *, struct kernfs_node___214 *, const char *);
	int (*show_path)(struct seq_file___201 *, struct kernfs_node___214 *, struct kernfs_root___214 *);
};

struct kernfs_open_file___214 {
	struct kernfs_node___214 *kn;
	struct file___226 *file;
	struct seq_file___201 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___221 *vm_ops;
};

struct sock___34;

struct kobj_ns_type_operations___33 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___34 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___49 *net;
} possible_net_t___44;

struct proto___33;

struct sock_common___33 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___33 *skc_prot;
	possible_net_t___44 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___34 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___45;

struct sk_buff_head___44 {
	struct sk_buff___45 *next;
	struct sk_buff___45 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___33 {
	struct cgroup___156 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___33;

struct socket_wq___34;

struct dst_entry___33;

struct socket___35;

struct net_device___46;

struct sock___34 {
	struct sock_common___33 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___44 sk_error_queue;
	struct sk_buff___45 *sk_rx_skb_cache;
	struct sk_buff_head___44 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___45 *head;
		struct sk_buff___45 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___33 *sk_filter;
	union {
		struct socket_wq___34 *sk_wq;
		struct socket_wq___34 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___33 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___33 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___45 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___45 *sk_tx_skb_cache;
	struct sk_buff_head___44 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___231 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___33 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___203 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___35 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___33 sk_cgrp_data;
	struct mem_cgroup___99 *sk_memcg;
	void (*sk_state_change)(struct sock___34 *);
	void (*sk_data_ready)(struct sock___34 *);
	void (*sk_write_space)(struct sock___34 *);
	void (*sk_error_report)(struct sock___34 *);
	int (*sk_backlog_rcv)(struct sock___34 *, struct sk_buff___45 *);
	struct sk_buff___45 * (*sk_validate_xmit_skb)(struct sock___34 *, struct net_device___46 *, struct sk_buff___45 *);
	void (*sk_destruct)(struct sock___34 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___214;

struct attribute_group___214 {
	const char *name;
	umode_t (*is_visible)(struct kobject___214 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___214 *, struct bin_attribute___214 *, int);
	struct attribute **attrs;
	struct bin_attribute___214 **bin_attrs;
};

struct bin_attribute___214 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___226 * (*f_mapping)();
	ssize_t (*read)(struct file___226 *, struct kobject___214 *, struct bin_attribute___214 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___226 *, struct kobject___214 *, struct bin_attribute___214 *, char *, loff_t, size_t);
	int (*mmap)(struct file___226 *, struct kobject___214 *, struct bin_attribute___214 *, struct vm_area_struct___231 *);
};

struct sysfs_ops___214 {
	ssize_t (*show)(struct kobject___214 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___214 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___214;

struct kset___214 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___214 kobj;
	const struct kset_uevent_ops___214 *uevent_ops;
};

struct kobj_type___214 {
	void (*release)(struct kobject___214 *);
	const struct sysfs_ops___214 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___214 **default_groups;
	const struct kobj_ns_type_operations___33 * (*child_ns_type)(struct kobject___214 *);
	const void * (*namespace)(struct kobject___214 *);
	void (*get_ownership)(struct kobject___214 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___214 {
	int (* const filter)(struct kset___214 *, struct kobject___214 *);
	const char * (* const name)(struct kset___214 *, struct kobject___214 *);
	int (* const uevent)(struct kset___214 *, struct kobject___214 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___210 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___210 *);
	int (*get)(char *, const struct kernel_param___210 *);
	void (*free)(void *);
};

struct kparam_array___210;

struct kernel_param___210 {
	const char *name;
	struct module___210 *mod;
	const struct kernel_param_ops___210 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___210 *arr;
	};
};

struct kparam_array___210 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___210 *ops;
	void *elem;
};

struct module_attribute___210 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___210 *, struct module_kobject___211 *, char *);
	ssize_t (*store)(struct module_attribute___210 *, struct module_kobject___211 *, const char *, size_t);
	void (*setup)(struct module___210 *, const char *);
	int (*test)(struct module___210 *);
	void (*free)(struct module___210 *);
};

struct dev_pm_ops___204 {
	int (*prepare)(struct device___204 *);
	void (*complete)(struct device___204 *);
	int (*suspend)(struct device___204 *);
	int (*resume)(struct device___204 *);
	int (*freeze)(struct device___204 *);
	int (*thaw)(struct device___204 *);
	int (*poweroff)(struct device___204 *);
	int (*restore)(struct device___204 *);
	int (*suspend_late)(struct device___204 *);
	int (*resume_early)(struct device___204 *);
	int (*freeze_late)(struct device___204 *);
	int (*thaw_early)(struct device___204 *);
	int (*poweroff_late)(struct device___204 *);
	int (*restore_early)(struct device___204 *);
	int (*suspend_noirq)(struct device___204 *);
	int (*resume_noirq)(struct device___204 *);
	int (*freeze_noirq)(struct device___204 *);
	int (*thaw_noirq)(struct device___204 *);
	int (*poweroff_noirq)(struct device___204 *);
	int (*restore_noirq)(struct device___204 *);
	int (*runtime_suspend)(struct device___204 *);
	int (*runtime_resume)(struct device___204 *);
	int (*runtime_idle)(struct device___204 *);
};

struct wakeup_source___204 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___204 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___204 {
	struct dev_pm_ops___204 ops;
	int (*start)(struct device___204 *);
	void (*detach)(struct device___204 *, bool);
	int (*activate)(struct device___204 *);
	void (*sync)(struct device___204 *);
	void (*dismiss)(struct device___204 *);
};

struct bus_type___204 {
	const char *name;
	const char *dev_name;
	struct device___204 *dev_root;
	const struct attribute_group___214 **bus_groups;
	const struct attribute_group___214 **dev_groups;
	const struct attribute_group___214 **drv_groups;
	int (*match)(struct device___204 *, struct device_driver___204 *);
	int (*uevent)(struct device___204 *, struct kobj_uevent_env *);
	int (*probe)(struct device___204 *);
	void (*sync_state)(struct device___204 *);
	void (*remove)(struct device___204 *);
	void (*shutdown)(struct device___204 *);
	int (*online)(struct device___204 *);
	int (*offline)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	int (*num_vf)(struct device___204 *);
	int (*dma_configure)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___204 {
	const char *name;
	struct bus_type___204 *bus;
	struct module___210 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___204 *);
	void (*sync_state)(struct device___204 *);
	int (*remove)(struct device___204 *);
	void (*shutdown)(struct device___204 *);
	int (*suspend)(struct device___204 *, pm_message_t);
	int (*resume)(struct device___204 *);
	const struct attribute_group___214 **groups;
	const struct attribute_group___214 **dev_groups;
	const struct dev_pm_ops___204 *pm;
	void (*coredump)(struct device___204 *);
	struct driver_private *p;
};

struct device_type___204 {
	const char *name;
	const struct attribute_group___214 **groups;
	int (*uevent)(struct device___204 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___204 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___204 *);
	const struct dev_pm_ops___204 *pm;
};

struct class___204 {
	const char *name;
	struct module___210 *owner;
	const struct attribute_group___214 **class_groups;
	const struct attribute_group___214 **dev_groups;
	struct kobject___214 *dev_kobj;
	int (*dev_uevent)(struct device___204 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___204 *, umode_t *);
	void (*class_release)(struct class___204 *);
	void (*dev_release)(struct device___204 *);
	int (*shutdown_pre)(struct device___204 *);
	const struct kobj_ns_type_operations___33 *ns_type;
	const void * (*namespace)(struct device___204 *);
	void (*get_ownership)(struct device___204 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___204 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___57;

struct irq_domain_chip_generic___57;

struct irq_data___59;

struct irq_domain___57 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___57 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___200 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___57 *gc;
	struct irq_domain___57 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___59 *revmap[0];
};

struct fwnode_operations___200;

struct fwnode_handle___200 {
	struct fwnode_handle___200 *secondary;
	const struct fwnode_operations___200 *ops;
	struct device___204 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___67;

struct device_node___90 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___200 fwnode;
	struct property___67 *properties;
	struct property___67 *deadprops;
	struct device_node___90 *parent;
	struct device_node___90 *child;
	struct device_node___90 *sibling;
	struct kobject___214 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___221 {
	void (*page_free)(struct page___231 *);
	void (*kill)(struct dev_pagemap___221 *);
	void (*cleanup)(struct dev_pagemap___221 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___221 *);
};

struct ip_ra_chain___16;

struct fib_rules_ops___33;

struct fqdir___49;

struct fib_notifier_ops___33;

struct netns_ipv4___49 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___16 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___33 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___34 *fibnl;
	struct sock___34 **icmp_sk;
	struct sock___34 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___34 **tcp_sk;
	struct fqdir___49 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___33 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___33 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___33 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___33;

struct dst_ops___49 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___49 *);
	struct dst_entry___33 * (*check)(struct dst_entry___33 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___33 *);
	unsigned int (*mtu)(const struct dst_entry___33 *);
	u32 * (*cow_metrics)(struct dst_entry___33 *, long unsigned int);
	void (*destroy)(struct dst_entry___33 *);
	void (*ifdown)(struct dst_entry___33 *, struct net_device___46 *, int);
	struct dst_entry___33 * (*negative_advice)(struct dst_entry___33 *);
	void (*link_failure)(struct sk_buff___45 *);
	void (*update_pmtu)(struct dst_entry___33 *, struct sock___34 *, struct sk_buff___45 *, u32, bool);
	void (*redirect)(struct dst_entry___33 *, struct sock___34 *, struct sk_buff___45 *);
	int (*local_out)(struct net___49 *, struct sock___34 *, struct sk_buff___45 *);
	struct neighbour___33 * (*neigh_lookup)(const struct dst_entry___33 *, struct sk_buff___45 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___33 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___49 {
	struct dst_ops___49 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___49 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___33 *fib6_rules_ops;
	struct sock___34 **icmp_sk;
	struct sock___34 *ndisc_sk;
	struct sock___34 *tcp_sk;
	struct sock___34 *igmp_sk;
	struct sock___34 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___33 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___33 *notifier_ops;
	struct fib_notifier_ops___33 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___49 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___49 *fqdir;
};

struct netns_sctp___33 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___34 *ctl_sock;
	struct sock___34 *udp4_sock;
	struct sock___34 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___40;

struct netns_bpf___40 {
	struct bpf_prog_array___40 *run_array[2];
	struct bpf_prog___40 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___49 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___34 *nlsk;
	struct sock___34 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___49 xfrm4_dst_ops;
	struct dst_ops___49 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___49 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___34 *rtnl;
	struct sock___34 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___46 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___49 ipv4;
	struct netns_ipv6___49 ipv6;
	struct netns_ieee802154_lowpan___49 ieee802154_lowpan;
	struct netns_sctp___33 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___44 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___40 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___49 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___34 *crypto_nlsk;
	struct sock___34 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___156 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___156 *root_cset;
};

struct irq_desc___59;

typedef void (*irq_flow_handler_t___59)(struct irq_desc___59 *);

struct irq_chip___59;

struct irq_data___59 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___59 *chip;
	struct irq_domain___57 *domain;
	struct irq_data___59 *parent_data;
	void *chip_data;
};

struct irqaction___41;

struct irq_desc___59 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___59 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___59 handle_irq;
	struct irqaction___41 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___214 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___210 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_reference_args___200;

struct fwnode_endpoint___200;

struct fwnode_operations___200 {
	struct fwnode_handle___200 * (*get)(struct fwnode_handle___200 *);
	void (*put)(struct fwnode_handle___200 *);
	bool (*device_is_available)(const struct fwnode_handle___200 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___200 *, const struct device___204 *);
	bool (*property_present)(const struct fwnode_handle___200 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___200 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___200 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___200 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*get_parent)(const struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*get_next_child_node)(const struct fwnode_handle___200 *, struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*get_named_child_node)(const struct fwnode_handle___200 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___200 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___200 *);
	struct fwnode_handle___200 * (*graph_get_next_endpoint)(const struct fwnode_handle___200 *, struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*graph_get_remote_endpoint)(const struct fwnode_handle___200 *);
	struct fwnode_handle___200 * (*graph_get_port_parent)(struct fwnode_handle___200 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___200 *, struct fwnode_endpoint___200 *);
	int (*add_links)(struct fwnode_handle___200 *);
};

struct fwnode_endpoint___200 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___200 *local_fwnode;
};

struct fwnode_reference_args___200 {
	struct fwnode_handle___200 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___59 {
	struct device___204 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___59 *);
	void (*irq_shutdown)(struct irq_data___59 *);
	void (*irq_enable)(struct irq_data___59 *);
	void (*irq_disable)(struct irq_data___59 *);
	void (*irq_ack)(struct irq_data___59 *);
	void (*irq_mask)(struct irq_data___59 *);
	void (*irq_mask_ack)(struct irq_data___59 *);
	void (*irq_unmask)(struct irq_data___59 *);
	void (*irq_eoi)(struct irq_data___59 *);
	int (*irq_set_affinity)(struct irq_data___59 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___59 *);
	int (*irq_set_type)(struct irq_data___59 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___59 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___59 *);
	void (*irq_bus_sync_unlock)(struct irq_data___59 *);
	void (*irq_cpu_online)(struct irq_data___59 *);
	void (*irq_cpu_offline)(struct irq_data___59 *);
	void (*irq_suspend)(struct irq_data___59 *);
	void (*irq_resume)(struct irq_data___59 *);
	void (*irq_pm_shutdown)(struct irq_data___59 *);
	void (*irq_calc_mask)(struct irq_data___59 *);
	void (*irq_print_chip)(struct irq_data___59 *, struct seq_file___201 *);
	int (*irq_request_resources)(struct irq_data___59 *);
	void (*irq_release_resources)(struct irq_data___59 *);
	void (*irq_compose_msi_msg)(struct irq_data___59 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___59 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___59 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___59 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___59 *, void *);
	void (*ipi_send_single)(struct irq_data___59 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___59 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___59 *);
	void (*irq_nmi_teardown)(struct irq_data___59 *);
	long unsigned int flags;
};

struct irqaction___41 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___41 *next;
	irq_handler_t thread_fn;
	struct task_struct___233 *thread;
	struct irqaction___41 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___57 {
	struct irq_chip___59 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___59 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___57 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___57 *);
	void (*resume)(struct irq_chip_generic___57 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___57 *domain;
	struct list_head list;
	struct irq_chip_type___57 chip_types[0];
};

struct irq_domain_chip_generic___57 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___57 *gc[0];
};

struct msghdr___35 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___146 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___226 *msg_iocb;
};

struct sk_buff___45 {
	union {
		struct {
			struct sk_buff___45 *next;
			struct sk_buff___45 *prev;
			union {
				struct net_device___46 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___34 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___45 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___49;

struct fqdir___49 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___49 *f;
	struct net___49 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___49;

struct inet_frags___49 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___49 *, const void *);
	void (*destructor)(struct inet_frag_queue___49 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___49 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___45 *fragments_tail;
	struct sk_buff___45 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___49 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___16 {
	struct ip_ra_chain___16 *next;
	struct sock___34 *sk;
	union {
		void (*destructor)(struct sock___34 *);
		struct sock___34 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___33;

struct fib_lookup_arg___33;

struct fib_rules_ops___33 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___33 *, struct flowi *, int, struct fib_lookup_arg___33 *);
	bool (*suppress)(struct fib_rule___33 *, int, struct fib_lookup_arg___33 *);
	int (*match)(struct fib_rule___33 *, struct flowi *, int);
	int (*configure)(struct fib_rule___33 *, struct sk_buff___45 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___33 *);
	int (*compare)(struct fib_rule___33 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___33 *, struct sk_buff___45 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___33 *);
	void (*flush_cache)(struct fib_rules_ops___33 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___210 *owner;
	struct net___49 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___33 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___49 *);
	int (*fib_dump)(struct net___49 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___210 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___17;

struct dst_entry___33 {
	struct net_device___46 *dev;
	struct dst_ops___49 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___45 *);
	int (*output)(struct net___49 *, struct sock___34 *, struct sk_buff___45 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___17 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___44(struct sk_buff___45 **);

struct bpf_xdp_entity___40 {
	struct bpf_prog___40 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___44;

struct net_device_ops___44;

struct ethtool_ops___20;

struct l3mdev_ops___33;

struct ndisc_ops___22;

struct xfrmdev_ops___44;

struct header_ops___44;

struct inet6_dev___22;

struct netdev_rx_queue___44;

struct mini_Qdisc___40;

struct netdev_queue___44;

struct Qdisc___40;

struct rtnl_link_ops___40;

struct dcbnl_rtnl_ops___44;

struct phy_device___6;

struct net_device___46 {
	char name[16];
	struct netdev_name_node___44 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___44 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___20 *ethtool_ops;
	const struct l3mdev_ops___33 *l3mdev_ops;
	const struct ndisc_ops___22 *ndisc_ops;
	const struct xfrmdev_ops___44 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___44 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___214 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___22 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___44 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___40 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___44 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___40 *miniq_ingress;
	struct netdev_queue___44 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___44 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___40 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___40 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___44 = 0,
		NETREG_REGISTERED___44 = 1,
		NETREG_UNREGISTERING___44 = 2,
		NETREG_UNREGISTERED___44 = 3,
		NETREG_RELEASED___44 = 4,
		NETREG_DUMMY___44 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___44 = 0,
		RTNL_LINK_INITIALIZING___44 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___46 *);
	struct netpoll_info *npinfo;
	possible_net_t___44 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___204 dev;
	const struct attribute_group___214 *sysfs_groups[4];
	const struct attribute_group___214 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___40 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___44 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___6 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___40 xdp_state[3];
	long: 64;
};

struct neigh_table___33;

struct neigh_parms___33;

struct neigh_ops___33;

struct neighbour___33 {
	struct neighbour___33 *next;
	struct neigh_table___33 *tbl;
	struct neigh_parms___33 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___44 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___33 *, struct sk_buff___45 *);
	const struct neigh_ops___33 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___46 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___40 {
	struct bpf_prog___40 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___40 {
	struct callback_head rcu;
	struct bpf_prog_array_item___40 items[0];
};

struct bpf_prog_aux___47;

struct bpf_prog___40 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___47 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct socket_wq___34 {
	wait_queue_head_t wait;
	struct fasync_struct___226 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___34;

struct socket___35 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___226 *file;
	struct sock___34 *sk;
	const struct proto_ops___34 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___34 wq;
};

typedef int (*sk_read_actor_t___33)(read_descriptor_t *, struct sk_buff___45 *, unsigned int, size_t);

struct proto_ops___34 {
	int family;
	struct module___210 *owner;
	int (*release)(struct socket___35 *);
	int (*bind)(struct socket___35 *, struct sockaddr *, int);
	int (*connect)(struct socket___35 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___35 *, struct socket___35 *);
	int (*accept)(struct socket___35 *, struct socket___35 *, int, bool);
	int (*getname)(struct socket___35 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___226 *, struct socket___35 *, struct poll_table_struct___151 *);
	int (*ioctl)(struct socket___35 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___35 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___35 *, void *, bool, bool);
	int (*listen)(struct socket___35 *, int);
	int (*shutdown)(struct socket___35 *, int);
	int (*setsockopt)(struct socket___35 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___35 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___201 *, struct socket___35 *);
	int (*sendmsg)(struct socket___35 *, struct msghdr___35 *, size_t);
	int (*recvmsg)(struct socket___35 *, struct msghdr___35 *, size_t, int);
	int (*mmap)(struct file___226 *, struct socket___35 *, struct vm_area_struct___231 *);
	ssize_t (*sendpage)(struct socket___35 *, struct page___231 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___35 *, loff_t *, struct pipe_inode_info___76 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___34 *, int);
	int (*peek_len)(struct socket___35 *);
	int (*read_sock)(struct sock___34 *, read_descriptor_t *, sk_read_actor_t___33);
	int (*sendpage_locked)(struct sock___34 *, struct page___231 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___34 *, struct msghdr___35 *, size_t);
	int (*set_rcvlowat)(struct sock___34 *, int);
};

struct pipe_buf_operations___76;

struct pipe_buffer___76 {
	struct page___231 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___76 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___76 {
	int (*confirm)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
	void (*release)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
	bool (*try_steal)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
	bool (*get)(struct pipe_inode_info___76 *, struct pipe_buffer___76 *);
};

typedef struct bio_vec___143 skb_frag_t___4;

struct skb_shared_info___4 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___45 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___4 frags[17];
};

struct seq_operations___201 {
	void * (*start)(struct seq_file___201 *, loff_t *);
	void (*stop)(struct seq_file___201 *, void *);
	void * (*next)(struct seq_file___201 *, void *, loff_t *);
	int (*show)(struct seq_file___201 *, void *);
};

struct dcbnl_rtnl_ops___44 {
	int (*ieee_getets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___46 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___46 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___46 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___46 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___46 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___46 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___46 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___46 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___46 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___46 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___46 *);
	u8 (*setstate)(struct net_device___46 *, u8);
	void (*getpermhwaddr)(struct net_device___46 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___46 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___46 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___46 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___46 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___46 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___46 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___46 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___46 *, int, u8 *);
	void (*setpfccfg)(struct net_device___46 *, int, u8);
	void (*getpfccfg)(struct net_device___46 *, int, u8 *);
	u8 (*setall)(struct net_device___46 *);
	u8 (*getcap)(struct net_device___46 *, int, u8 *);
	int (*getnumtcs)(struct net_device___46 *, int, u8 *);
	int (*setnumtcs)(struct net_device___46 *, int, u8);
	u8 (*getpfcstate)(struct net_device___46 *);
	void (*setpfcstate)(struct net_device___46 *, u8);
	void (*getbcncfg)(struct net_device___46 *, int, u32 *);
	void (*setbcncfg)(struct net_device___46 *, int, u32);
	void (*getbcnrp)(struct net_device___46 *, int, u8 *);
	void (*setbcnrp)(struct net_device___46 *, int, u8);
	int (*setapp)(struct net_device___46 *, u8, u16, u8);
	int (*getapp)(struct net_device___46 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___46 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___46 *, int, u8);
	u8 (*getdcbx)(struct net_device___46 *);
	u8 (*setdcbx)(struct net_device___46 *, u8);
	int (*peer_getappinfo)(struct net_device___46 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___46 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___46 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___46 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___46 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___46 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___47;

typedef int (*bpf_iter_init_seq_priv_t___46)(void *, struct bpf_iter_aux_info___47 *);

struct bpf_map___47;

struct bpf_iter_aux_info___47 {
	struct bpf_map___47 *map;
};

struct bpf_iter_seq_info___46 {
	const struct seq_operations___201 *seq_ops;
	bpf_iter_init_seq_priv_t___46 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___46 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___47 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___47 *, struct file___226 *);
	void (*map_free)(struct bpf_map___47 *);
	int (*map_get_next_key)(struct bpf_map___47 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___47 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___47 *, void *);
	int (*map_lookup_batch)(struct bpf_map___47 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___47 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___47 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___47 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___47 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___47 *, void *);
	int (*map_update_elem)(struct bpf_map___47 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___47 *, void *);
	int (*map_push_elem)(struct bpf_map___47 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___47 *, void *);
	int (*map_peek_elem)(struct bpf_map___47 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___47 *, struct file___226 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___47 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___47 *, void *, struct seq_file___201 *);
	int (*map_check_btf)(const struct bpf_map___47 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___47 *, struct bpf_prog_aux___47 *);
	void (*map_poke_untrack)(struct bpf_map___47 *, struct bpf_prog_aux___47 *);
	void (*map_poke_run)(struct bpf_map___47 *, u32, struct bpf_prog___40 *, struct bpf_prog___40 *);
	int (*map_direct_value_addr)(const struct bpf_map___47 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___47 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___47 *, struct vm_area_struct___231 *);
	__poll_t (*map_poll)(struct bpf_map___47 *, struct file___226 *, struct poll_table_struct___151 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___47 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___47 *, const struct bpf_map___47 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___47 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___46 *iter_seq_info;
};

struct bpf_map___47 {
	const struct bpf_map_ops___46 *ops;
	struct bpf_map___47 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___99 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___46;

struct bpf_jit_poke_descriptor___46;

struct bpf_prog_ops___40;

struct btf_mod_pair___46;

struct bpf_prog_offload___44;

struct bpf_prog_aux___47 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___40 *dst_prog;
	struct bpf_trampoline___46 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___40 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___46 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___40 *ops;
	struct bpf_map___47 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___46 *used_btfs;
	struct bpf_prog___40 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___47 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___44 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___44;

struct bpf_map_dev_ops___44 {
	int (*map_get_next_key)(struct bpf_offloaded_map___44 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___44 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___44 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___44 *, void *);
};

struct bpf_offloaded_map___44 {
	struct bpf_map___47 map;
	struct net_device___46 *netdev;
	const struct bpf_map_dev_ops___44 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___40 {
	int (*test_run)(struct bpf_prog___40 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___44 {
	struct bpf_prog___40 *prog;
	struct net_device___46 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___46 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___40 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___210 *mod;
};

struct bpf_jit_poke_descriptor___46 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___47 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___46 {
	struct btf *btf;
	struct module___210 *module;
};

struct cftype___156;

struct cgroup_subsys___156 {
	struct cgroup_subsys_state___156 * (*css_alloc)(struct cgroup_subsys_state___156 *);
	int (*css_online)(struct cgroup_subsys_state___156 *);
	void (*css_offline)(struct cgroup_subsys_state___156 *);
	void (*css_released)(struct cgroup_subsys_state___156 *);
	void (*css_free)(struct cgroup_subsys_state___156 *);
	void (*css_reset)(struct cgroup_subsys_state___156 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___156 *, int);
	int (*css_extra_stat_show)(struct seq_file___201 *, struct cgroup_subsys_state___156 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___233 *, struct css_set___156 *);
	void (*cancel_fork)(struct task_struct___233 *, struct css_set___156 *);
	void (*fork)(struct task_struct___233 *);
	void (*exit)(struct task_struct___233 *);
	void (*release)(struct task_struct___233 *);
	void (*bind)(struct cgroup_subsys_state___156 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___156 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___156 *dfl_cftypes;
	struct cftype___156 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___156 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___156 *updated_children;
	struct cgroup___156 *updated_next;
};

struct cgroup_root___156 {
	struct kernfs_root___214 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___156 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___156 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___156 *ss;
	struct list_head node;
	struct kernfs_ops___214 *kf_ops;
	int (*open)(struct kernfs_open_file___214 *);
	void (*release)(struct kernfs_open_file___214 *);
	u64 (*read_u64)(struct cgroup_subsys_state___156 *, struct cftype___156 *);
	s64 (*read_s64)(struct cgroup_subsys_state___156 *, struct cftype___156 *);
	int (*seq_show)(struct seq_file___201 *, void *);
	void * (*seq_start)(struct seq_file___201 *, loff_t *);
	void * (*seq_next)(struct seq_file___201 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___201 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___156 *, struct cftype___156 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___156 *, struct cftype___156 *, s64);
	ssize_t (*write)(struct kernfs_open_file___214 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___214 *, struct poll_table_struct___151 *);
};

struct xdp_rxq_info___44 {
	struct net_device___46 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___44 {
	struct net_device___46 *dev;
};

struct xdp_buff___44 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___44 *rxq;
	struct xdp_txq_info___44 *txq;
	u32 frame_sz;
};

struct xdp_frame___44 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___46 *dev_rx;
};

struct netlink_callback___44 {
	struct sk_buff___45 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___45 *, struct netlink_callback___44 *);
	int (*done)(struct netlink_callback___44 *);
	void *data;
	struct module___210 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct netdev_hw_addr {
	struct list_head list;
	struct rb_node node;
	unsigned char addr[32];
	unsigned char type;
	bool global_use;
	int sync_cnt;
	int refcount;
	int synced;
	struct callback_head callback_head;
};

struct header_ops___44 {
	int (*create)(struct sk_buff___45 *, struct net_device___46 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___45 *, unsigned char *);
	int (*cache)(const struct neighbour___33 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___46 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___45 *);
};

struct napi_struct___4 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___4 *, int);
	int poll_owner;
	struct net_device___46 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___45 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___233 *thread;
};

struct netdev_queue___44 {
	struct net_device___46 *dev;
	struct Qdisc___40 *qdisc;
	struct Qdisc___40 *qdisc_sleeping;
	struct kobject___214 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___46 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___40 {
	struct sk_buff___45 *head;
	struct sk_buff___45 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___40;

struct Qdisc___40 {
	int (*enqueue)(struct sk_buff___45 *, struct Qdisc___40 *, struct sk_buff___45 **);
	struct sk_buff___45 * (*dequeue)(struct Qdisc___40 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___40 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___44 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___44 gso_skb;
	struct qdisc_skb_head___40 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___40 *next_sched;
	struct sk_buff_head___44 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___44 {
	struct xdp_rxq_info___44 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___214 kobj;
	struct net_device___46 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___44 {
	enum net_device_path_type type;
	const struct net_device___46 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___44 = 0,
				DEV_PATH_BR_VLAN_TAG___44 = 1,
				DEV_PATH_BR_VLAN_UNTAG___44 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___44 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___44 {
	const struct net_device___46 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___44 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___40 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___44 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___44 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___45 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___44 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___46 *dev;
	const char *name;
};

struct net_device_ops___44 {
	int (*ndo_init)(struct net_device___46 *);
	void (*ndo_uninit)(struct net_device___46 *);
	int (*ndo_open)(struct net_device___46 *);
	int (*ndo_stop)(struct net_device___46 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___45 *, struct net_device___46 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___45 *, struct net_device___46 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___46 *, struct sk_buff___45 *, struct net_device___46 *);
	void (*ndo_change_rx_flags)(struct net_device___46 *, int);
	void (*ndo_set_rx_mode)(struct net_device___46 *);
	int (*ndo_set_mac_address)(struct net_device___46 *, void *);
	int (*ndo_validate_addr)(struct net_device___46 *);
	int (*ndo_do_ioctl)(struct net_device___46 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___46 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___46 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___46 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___46 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___46 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___46 *, int);
	int (*ndo_neigh_setup)(struct net_device___46 *, struct neigh_parms___33 *);
	void (*ndo_tx_timeout)(struct net_device___46 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___46 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___46 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___46 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___46 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___46 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___46 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___46 *);
	int (*ndo_netpoll_setup)(struct net_device___46 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___46 *);
	int (*ndo_set_vf_mac)(struct net_device___46 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___46 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___46 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___46 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___46 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___46 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___46 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___46 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___46 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___46 *, int, struct sk_buff___45 *);
	int (*ndo_get_vf_guid)(struct net_device___46 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___46 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___46 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___46 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___46 *);
	int (*ndo_fcoe_disable)(struct net_device___46 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___46 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___46 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___46 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___46 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___46 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___46 *, const struct sk_buff___45 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___46 *, struct net_device___46 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___46 *, struct net_device___46 *);
	struct net_device___46 * (*ndo_get_xmit_slave)(struct net_device___46 *, struct sk_buff___45 *, bool);
	struct net_device___46 * (*ndo_sk_get_lower_dev)(struct net_device___46 *, struct sock___34 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___46 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___46 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___46 *, struct neighbour___33 *);
	void (*ndo_neigh_destroy)(struct net_device___46 *, struct neighbour___33 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___45 *, struct netlink_callback___44 *, struct net_device___46 *, struct net_device___46 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___45 *, struct nlattr **, struct net_device___46 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___46 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___45 *, u32, u32, struct net_device___46 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___46 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___46 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___46 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___46 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___46 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___46 *, struct net_device___46 *);
	void (*ndo_dfwd_del_station)(struct net_device___46 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___46 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___46 *);
	int (*ndo_change_proto_down)(struct net_device___46 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___46 *, struct sk_buff___45 *);
	void (*ndo_set_rx_headroom)(struct net_device___46 *, int);
	int (*ndo_bpf)(struct net_device___46 *, struct netdev_bpf___44 *);
	int (*ndo_xdp_xmit)(struct net_device___46 *, int, struct xdp_frame___44 **, u32);
	struct net_device___46 * (*ndo_xdp_get_xmit_slave)(struct net_device___46 *, struct xdp_buff___44 *);
	int (*ndo_xsk_wakeup)(struct net_device___46 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___46 *);
	int (*ndo_tunnel_ctl)(struct net_device___46 *, struct ip_tunnel_parm *, int);
	struct net_device___46 * (*ndo_get_peer_dev)(struct net_device___46 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___44 *, struct net_device_path___44 *);
};

struct neigh_parms___33 {
	possible_net_t___44 net;
	struct net_device___46 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___33 *);
	struct neigh_table___33 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___20 {
	u32 cap_link_lanes_supported;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___46 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___46 *);
	void (*get_regs)(struct net_device___46 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___46 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___46 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___46 *);
	void (*set_msglevel)(struct net_device___46 *, u32);
	int (*nway_reset)(struct net_device___46 *);
	u32 (*get_link)(struct net_device___46 *);
	int (*get_link_ext_state)(struct net_device___46 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___46 *);
	int (*get_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___46 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___46 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___46 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___46 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___46 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___46 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___46 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___46 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___46 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___46 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___46 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___46 *);
	void (*complete)(struct net_device___46 *);
	u32 (*get_priv_flags)(struct net_device___46 *);
	int (*set_priv_flags)(struct net_device___46 *, u32);
	int (*get_sset_count)(struct net_device___46 *, int);
	int (*get_rxnfc)(struct net_device___46 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___46 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___46 *, struct ethtool_flash *);
	int (*reset)(struct net_device___46 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___46 *);
	u32 (*get_rxfh_indir_size)(struct net_device___46 *);
	int (*get_rxfh)(struct net_device___46 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___46 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___46 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___46 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___46 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___46 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___46 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___46 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___46 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___46 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___46 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___46 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___46 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___46 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___46 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___46 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___46 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___46 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___46 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___46 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___46 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___46 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___46 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___46 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___46 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___46 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___46 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___46 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___46 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___46 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___46 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___33 {
	u32 (*l3mdev_fib_table)(const struct net_device___46 *);
	struct sk_buff___45 * (*l3mdev_l3_rcv)(struct net_device___46 *, struct sk_buff___45 *, u16);
	struct sk_buff___45 * (*l3mdev_l3_out)(struct net_device___46 *, struct sock___34 *, struct sk_buff___45 *, u16);
	struct dst_entry___33 * (*l3mdev_link_scope_lookup)(const struct net_device___46 *, struct flowi6 *);
};

struct ndisc_ops___22 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___46 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___46 *, struct neighbour___33 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___46 *, u8, struct neighbour___33 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___46 *, struct sk_buff___45 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___49 *, struct net_device___46 *, const struct prefix_info *, struct inet6_dev___22 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___22;

struct inet6_dev___22 {
	struct net_device___46 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___22 *mc_list;
	struct ifmcaddr6___22 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___44 mc_query_queue;
	struct sk_buff_head___44 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___2 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___33 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___40;

struct tcf_block___40;

struct mini_Qdisc___40 {
	struct tcf_proto___40 *filter_list;
	struct tcf_block___40 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___40 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___46 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___46 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___49 *, struct net_device___46 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___46 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___46 *, struct list_head *);
	size_t (*get_size)(const struct net_device___46 *);
	int (*fill_info)(struct sk_buff___45 *, const struct net_device___46 *);
	size_t (*get_xstats_size)(const struct net_device___46 *);
	int (*fill_xstats)(struct sk_buff___45 *, const struct net_device___46 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___46 *, struct net_device___46 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___46 *, const struct net_device___46 *);
	int (*fill_slave_info)(struct sk_buff___45 *, const struct net_device___46 *, const struct net_device___46 *);
	struct net___49 * (*get_link_net)(const struct net_device___46 *);
	size_t (*get_linkxstats_size)(const struct net_device___46 *, int);
	int (*fill_linkxstats)(struct sk_buff___45 *, const struct net_device___46 *, int *, int);
};

struct mii_bus___9;

struct mdio_device___9 {
	struct device___204 dev;
	struct mii_bus___9 *bus;
	char modalias[32];
	int (*bus_match)(struct device___204 *, struct device_driver___204 *);
	void (*device_free)(struct mdio_device___9 *);
	void (*device_remove)(struct mdio_device___9 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___6;

struct mii_timestamper___6;

struct phy_device___6 {
	struct mdio_device___9 mdio;
	struct phy_driver___6 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___45 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___46 *attached_dev;
	struct mii_timestamper___6 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___6 *, bool);
	void (*adjust_link)(struct net_device___46 *);
	const struct macsec_ops *macsec_ops;
};

enum skb_free_reason {
	SKB_REASON_CONSUMED = 0,
	SKB_REASON_DROPPED = 1,
};

struct block_device_operations___119;

struct gendisk___122 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___122 *part0;
	const struct block_device_operations___119 *fops;
	struct request_queue___119 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___108 *bdi;
	struct kobject___214 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___214 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___119 {
	struct bio___119 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___143 *bip_vec;
	struct bio_vec___143 bip_inline_vecs[0];
};

struct blkcg___110;

struct blkg_policy_data___110;

struct blkcg_gq___110 {
	struct request_queue___119 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___110 *blkcg;
	struct blkcg_gq___110 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___110 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___119 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___119(struct request___119 *);

typedef void integrity_complete_fn___119(struct request___119 *, unsigned int);

struct blk_integrity_profile___119 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___119 *prepare_fn;
	integrity_complete_fn___119 *complete_fn;
	const char *name;
};

struct block_device_operations___119 {
	blk_qc_t (*submit_bio)(struct bio___119 *);
	int (*open)(struct block_device___122 *, fmode_t);
	void (*release)(struct gendisk___122 *, fmode_t);
	int (*rw_page)(struct block_device___122 *, sector_t, struct page___231 *, unsigned int);
	int (*ioctl)(struct block_device___122 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___122 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___122 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___122 *);
	int (*getgeo)(struct block_device___122 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___122 *, bool);
	void (*swap_slot_free_notify)(struct block_device___122 *, long unsigned int);
	int (*report_zones)(struct gendisk___122 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___122 *, umode_t *);
	struct module___210 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___122 *, sector_t *);
};

typedef void rq_end_io_fn___119(struct request___119 *, blk_status_t);

struct request___119 {
	struct request_queue___119 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___116 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___119 *bio;
	struct bio___119 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___143 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___119 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___119 *saved_end_io;
		} flush;
	};
	struct gendisk___122 *rq_disk;
	struct block_device___122 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___119 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___116 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___119 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___214 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___226 *debugfs_dir;
	struct dentry___226 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___119;

struct elevator_mq_ops___119 {
	int (*init_sched)(struct request_queue___119 *, struct elevator_type___119 *);
	void (*exit_sched)(struct elevator_queue___119 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___116 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___116 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___116 *);
	bool (*allow_merge)(struct request_queue___119 *, struct request___119 *, struct bio___119 *);
	bool (*bio_merge)(struct request_queue___119 *, struct bio___119 *, unsigned int);
	int (*request_merge)(struct request_queue___119 *, struct request___119 **, struct bio___119 *);
	void (*request_merged)(struct request_queue___119 *, struct request___119 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___119 *, struct request___119 *, struct request___119 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___119 *);
	void (*finish_request)(struct request___119 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___116 *, struct list_head *, bool);
	struct request___119 * (*dispatch_request)(struct blk_mq_hw_ctx___116 *);
	bool (*has_work)(struct blk_mq_hw_ctx___116 *);
	void (*completed_request)(struct request___119 *, u64);
	void (*requeue_request)(struct request___119 *);
	struct request___119 * (*former_request)(struct request_queue___119 *, struct request___119 *);
	struct request___119 * (*next_request)(struct request_queue___119 *, struct request___119 *);
	void (*init_icq)(struct io_cq___119 *);
	void (*exit_icq)(struct io_cq___119 *);
};

struct elv_fs_entry___119;

struct elevator_type___119 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___119 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___119 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___210 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___119 {
	struct elevator_type___119 *type;
	void *elevator_data;
	struct kobject___214 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___119 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___119 *, char *);
	ssize_t (*store)(struct elevator_queue___119 *, const char *, size_t);
};

struct blk_mq_queue_data___116;

struct blk_mq_ops___116 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___116 *, const struct blk_mq_queue_data___116 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___116 *);
	int (*get_budget)(struct request_queue___119 *);
	void (*put_budget)(struct request_queue___119 *, int);
	void (*set_rq_budget_token)(struct request___119 *, int);
	int (*get_rq_budget_token)(struct request___119 *);
	enum blk_eh_timer_return (*timeout)(struct request___119 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___116 *);
	void (*complete)(struct request___119 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___116 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___116 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___116 *, struct request___119 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___116 *, struct request___119 *, unsigned int);
	void (*initialize_rq_fn)(struct request___119 *);
	void (*cleanup_rq)(struct request___119 *);
	bool (*busy)(struct request_queue___119 *);
	int (*map_queues)(struct blk_mq_tag_set___116 *);
	void (*show_rq)(struct seq_file___201 *, struct request___119 *);
};

struct blk_mq_tag_set___116 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___116 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___116 {
	struct request___119 *rq;
	bool last;
};

struct blkcg_policy_data___110;

struct blkcg___110 {
	struct cgroup_subsys_state___156 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___110 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___110 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___110 {
	struct blkcg___110 *blkcg;
	int plid;
};

struct blkg_policy_data___110 {
	struct blkcg_gq___110 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___99 {
	struct mem_cgroup___99 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___99 {
	struct lruvec___107 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___99 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___99 *memcg;
};

struct obj_cgroup___99 {
	struct percpu_ref refcnt;
	struct mem_cgroup___99 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct vlan_hdr {
	__be16 h_vlan_TCI;
	__be16 h_vlan_encapsulated_proto;
};

struct vlan_ethhdr {
	unsigned char h_dest[6];
	unsigned char h_source[6];
	__be16 h_vlan_proto;
	__be16 h_vlan_TCI;
	__be16 h_vlan_encapsulated_proto;
};

struct gnet_dump___40 {
	spinlock_t *lock;
	struct sk_buff___45 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___40;

struct Qdisc_ops___40 {
	struct Qdisc_ops___40 *next;
	const struct Qdisc_class_ops___40 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___45 *, struct Qdisc___40 *, struct sk_buff___45 **);
	struct sk_buff___45 * (*dequeue)(struct Qdisc___40 *);
	struct sk_buff___45 * (*peek)(struct Qdisc___40 *);
	int (*init)(struct Qdisc___40 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___40 *);
	void (*destroy)(struct Qdisc___40 *);
	int (*change)(struct Qdisc___40 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___40 *);
	int (*change_tx_queue_len)(struct Qdisc___40 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___40 *, unsigned int);
	int (*dump)(struct Qdisc___40 *, struct sk_buff___45 *);
	int (*dump_stats)(struct Qdisc___40 *, struct gnet_dump___40 *);
	void (*ingress_block_set)(struct Qdisc___40 *, u32);
	void (*egress_block_set)(struct Qdisc___40 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___40 *);
	u32 (*egress_block_get)(struct Qdisc___40 *);
	struct module___210 *owner;
};

struct Qdisc_class_ops___40 {
	unsigned int flags;
	struct netdev_queue___44 * (*select_queue)(struct Qdisc___40 *, struct tcmsg *);
	int (*graft)(struct Qdisc___40 *, long unsigned int, struct Qdisc___40 *, struct Qdisc___40 **, struct netlink_ext_ack *);
	struct Qdisc___40 * (*leaf)(struct Qdisc___40 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___40 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___40 *, u32);
	int (*change)(struct Qdisc___40 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___40 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___40 *, struct qdisc_walker *);
	struct tcf_block___40 * (*tcf_block)(struct Qdisc___40 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___40 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___40 *, long unsigned int);
	int (*dump)(struct Qdisc___40 *, long unsigned int, struct sk_buff___45 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___40 *, long unsigned int, struct gnet_dump___40 *);
};

struct tcf_chain___40;

struct tcf_block___40 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___49 *net;
	struct Qdisc___40 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___40 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___40;

struct tcf_proto_ops___40;

struct tcf_proto___40 {
	struct tcf_proto___40 *next;
	void *root;
	int (*classify)(struct sk_buff___45 *, const struct tcf_proto___40 *, struct tcf_result___40 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___40 *ops;
	struct tcf_chain___40 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___40 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___40 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___40 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___45 *, const struct tcf_proto___40 *, struct tcf_result___40 *);
	int (*init)(struct tcf_proto___40 *);
	void (*destroy)(struct tcf_proto___40 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___40 *, u32);
	void (*put)(struct tcf_proto___40 *, void *);
	int (*change)(struct net___49 *, struct sk_buff___45 *, struct tcf_proto___40 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___40 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___40 *);
	void (*walk)(struct tcf_proto___40 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___40 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___40 *, void *);
	void (*hw_del)(struct tcf_proto___40 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___49 *, struct tcf_chain___40 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___49 *, struct tcf_proto___40 *, void *, struct sk_buff___45 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___49 *, struct tcf_proto___40 *, void *, struct sk_buff___45 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___45 *, struct net___49 *, void *);
	struct module___210 *owner;
	int flags;
};

struct tcf_chain___40 {
	struct mutex filter_chain_lock;
	struct tcf_proto___40 *filter_chain;
	struct list_head list;
	struct tcf_block___40 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___40 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___33 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___40 *prog;
};

struct pneigh_entry___33;

struct neigh_hash_table___33;

struct neigh_table___33 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___46 *, __u32 *);
	bool (*key_eq)(const struct neighbour___33 *, const void *);
	int (*constructor)(struct neighbour___33 *);
	int (*pconstructor)(struct pneigh_entry___33 *);
	void (*pdestructor)(struct pneigh_entry___33 *);
	void (*proxy_redo)(struct sk_buff___45 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___46 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___33 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___44 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___33 *nht;
	struct pneigh_entry___33 **phash_buckets;
};

struct neigh_ops___33 {
	int family;
	void (*solicit)(struct neighbour___33 *, struct sk_buff___45 *);
	void (*error_report)(struct neighbour___33 *, struct sk_buff___45 *);
	int (*output)(struct neighbour___33 *, struct sk_buff___45 *);
	int (*connected_output)(struct neighbour___33 *, struct sk_buff___45 *);
};

struct pneigh_entry___33 {
	struct pneigh_entry___33 *next;
	possible_net_t___44 net;
	struct net_device___46 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___33 {
	struct neighbour___33 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___17 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___49 *, struct sock___34 *, struct sk_buff___45 *);
	int (*orig_input)(struct sk_buff___45 *);
	struct callback_head rcu;
	__u8 data[0];
};

enum {
	SOF_TIMESTAMPING_TX_HARDWARE = 1,
	SOF_TIMESTAMPING_TX_SOFTWARE = 2,
	SOF_TIMESTAMPING_RX_HARDWARE = 4,
	SOF_TIMESTAMPING_RX_SOFTWARE = 8,
	SOF_TIMESTAMPING_SOFTWARE = 16,
	SOF_TIMESTAMPING_SYS_HARDWARE = 32,
	SOF_TIMESTAMPING_RAW_HARDWARE = 64,
	SOF_TIMESTAMPING_OPT_ID = 128,
	SOF_TIMESTAMPING_TX_SCHED = 256,
	SOF_TIMESTAMPING_TX_ACK = 512,
	SOF_TIMESTAMPING_OPT_CMSG = 1024,
	SOF_TIMESTAMPING_OPT_TSONLY = 2048,
	SOF_TIMESTAMPING_OPT_STATS = 4096,
	SOF_TIMESTAMPING_OPT_PKTINFO = 8192,
	SOF_TIMESTAMPING_OPT_TX_SWHW = 16384,
	SOF_TIMESTAMPING_BIND_PHC = 32768,
	SOF_TIMESTAMPING_LAST = 32768,
	SOF_TIMESTAMPING_MASK = 65535,
};

enum hwtstamp_tx_types {
	HWTSTAMP_TX_OFF = 0,
	HWTSTAMP_TX_ON = 1,
	HWTSTAMP_TX_ONESTEP_SYNC = 2,
	HWTSTAMP_TX_ONESTEP_P2P = 3,
	__HWTSTAMP_TX_CNT = 4,
};

enum hwtstamp_rx_filters {
	HWTSTAMP_FILTER_NONE = 0,
	HWTSTAMP_FILTER_ALL = 1,
	HWTSTAMP_FILTER_SOME = 2,
	HWTSTAMP_FILTER_PTP_V1_L4_EVENT = 3,
	HWTSTAMP_FILTER_PTP_V1_L4_SYNC = 4,
	HWTSTAMP_FILTER_PTP_V1_L4_DELAY_REQ = 5,
	HWTSTAMP_FILTER_PTP_V2_L4_EVENT = 6,
	HWTSTAMP_FILTER_PTP_V2_L4_SYNC = 7,
	HWTSTAMP_FILTER_PTP_V2_L4_DELAY_REQ = 8,
	HWTSTAMP_FILTER_PTP_V2_L2_EVENT = 9,
	HWTSTAMP_FILTER_PTP_V2_L2_SYNC = 10,
	HWTSTAMP_FILTER_PTP_V2_L2_DELAY_REQ = 11,
	HWTSTAMP_FILTER_PTP_V2_EVENT = 12,
	HWTSTAMP_FILTER_PTP_V2_SYNC = 13,
	HWTSTAMP_FILTER_PTP_V2_DELAY_REQ = 14,
	HWTSTAMP_FILTER_NTP_ALL = 15,
	__HWTSTAMP_FILTER_CNT = 16,
};

struct fib_rule___33 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___33 *ctarget;
	struct net___49 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___33 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___33 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___23;

struct timewait_sock_ops___23;

struct proto___33 {
	void (*close)(struct sock___34 *, long int);
	int (*pre_connect)(struct sock___34 *, struct sockaddr *, int);
	int (*connect)(struct sock___34 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___34 *, int);
	struct sock___34 * (*accept)(struct sock___34 *, int, int *, bool);
	int (*ioctl)(struct sock___34 *, int, long unsigned int);
	int (*init)(struct sock___34 *);
	void (*destroy)(struct sock___34 *);
	void (*shutdown)(struct sock___34 *, int);
	int (*setsockopt)(struct sock___34 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___34 *, int, int, char *, int *);
	void (*keepalive)(struct sock___34 *, int);
	int (*compat_ioctl)(struct sock___34 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___34 *, struct msghdr___35 *, size_t);
	int (*recvmsg)(struct sock___34 *, struct msghdr___35 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___34 *, struct page___231 *, int, size_t, int);
	int (*bind)(struct sock___34 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___34 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___34 *, struct sk_buff___45 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___34 *);
	int (*hash)(struct sock___34 *);
	void (*unhash)(struct sock___34 *);
	void (*rehash)(struct sock___34 *);
	int (*get_port)(struct sock___34 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___34 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___34 *, int);
	bool (*sock_is_readable)(struct sock___34 *);
	void (*enter_memory_pressure)(struct sock___34 *);
	void (*leave_memory_pressure)(struct sock___34 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___23 *rsk_prot;
	struct timewait_sock_ops___23 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___210 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___34 *, int);
};

struct request_sock___24;

struct request_sock_ops___23 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___34 *, struct request_sock___24 *);
	void (*send_ack)(const struct sock___34 *, struct sk_buff___45 *, struct request_sock___24 *);
	void (*send_reset)(const struct sock___34 *, struct sk_buff___45 *);
	void (*destructor)(struct request_sock___24 *);
	void (*syn_ack_timeout)(const struct request_sock___24 *);
};

struct timewait_sock_ops___23 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___34 *, struct sock___34 *, void *);
	void (*twsk_destructor)(struct sock___34 *);
};

struct request_sock___24 {
	struct sock_common___33 __req_common;
	struct request_sock___24 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___23 *rsk_ops;
	struct sock___34 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___22 {
	struct in6_addr mca_addr;
	struct inet6_dev___22 *idev;
	struct ifmcaddr6___22 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

enum tunable_id {
	ETHTOOL_ID_UNSPEC = 0,
	ETHTOOL_RX_COPYBREAK = 1,
	ETHTOOL_TX_COPYBREAK = 2,
	ETHTOOL_PFC_PREVENTION_TOUT = 3,
	__ETHTOOL_TUNABLE_COUNT = 4,
};

struct tso_t {
	int next_frag_idx;
	int size;
	void *data;
	u16 ip_id;
	u8 tlen;
	bool ipv6;
	u32 tcp_seq;
};

struct platform_device___39 {
	const char *name;
	int id;
	bool id_auto;
	struct device___204 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___33 {
	int (*probe)(struct platform_device___39 *);
	int (*remove)(struct platform_device___39 *);
	void (*shutdown)(struct platform_device___39 *);
	int (*suspend)(struct platform_device___39 *, pm_message_t);
	int (*resume)(struct platform_device___39 *);
	struct device_driver___204 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct mii_bus___9 {
	struct module___210 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___9 *, int, int);
	int (*write)(struct mii_bus___9 *, int, int, u16);
	int (*reset)(struct mii_bus___9 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___204 *parent;
	enum {
		MDIOBUS_ALLOCATED___9 = 1,
		MDIOBUS_REGISTERED___9 = 2,
		MDIOBUS_UNREGISTERED___9 = 3,
		MDIOBUS_RELEASED___9 = 4,
	} state;
	struct device___204 dev;
	struct mdio_device___9 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___9 = 0,
		MDIOBUS_C22___9 = 1,
		MDIOBUS_C45___9 = 2,
		MDIOBUS_C22_C45___9 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___8 {
	struct device_driver___204 driver;
	int flags;
};

struct mii_timestamper___6 {
	bool (*rxtstamp)(struct mii_timestamper___6 *, struct sk_buff___45 *, int);
	void (*txtstamp)(struct mii_timestamper___6 *, struct sk_buff___45 *, int);
	int (*hwtstamp)(struct mii_timestamper___6 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___6 *, struct phy_device___6 *);
	int (*ts_info)(struct mii_timestamper___6 *, struct ethtool_ts_info *);
	struct device___204 *device;
};

struct phy_driver___6 {
	struct mdio_driver_common___8 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___6 *);
	int (*config_init)(struct phy_device___6 *);
	int (*probe)(struct phy_device___6 *);
	int (*get_features)(struct phy_device___6 *);
	int (*suspend)(struct phy_device___6 *);
	int (*resume)(struct phy_device___6 *);
	int (*config_aneg)(struct phy_device___6 *);
	int (*aneg_done)(struct phy_device___6 *);
	int (*read_status)(struct phy_device___6 *);
	int (*config_intr)(struct phy_device___6 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___6 *);
	void (*remove)(struct phy_device___6 *);
	int (*match_phy_device)(struct phy_device___6 *);
	int (*set_wol)(struct phy_device___6 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___6 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___6 *);
	int (*read_mmd)(struct phy_device___6 *, int, u16);
	int (*write_mmd)(struct phy_device___6 *, int, u16, u16);
	int (*read_page)(struct phy_device___6 *);
	int (*write_page)(struct phy_device___6 *, int);
	int (*module_info)(struct phy_device___6 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___6 *);
	int (*cable_test_tdr_start)(struct phy_device___6 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___6 *, bool *);
	int (*get_sset_count)(struct phy_device___6 *);
	void (*get_strings)(struct phy_device___6 *, u8 *);
	void (*get_stats)(struct phy_device___6 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___6 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___6 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___6 *, bool);
	int (*get_sqi)(struct phy_device___6 *);
	int (*get_sqi_max)(struct phy_device___6 *);
};

struct fec_platform_data {
	phy_interface_t phy;
	unsigned char mac[6];
	void (*sleep_mode_enable)(int);
};

struct property___67 {
	char *name;
	int length;
	void *value;
	struct property___67 *next;
	long unsigned int _flags;
	struct bin_attribute___214 attr;
};

struct irq_fwspec___55 {
	struct fwnode_handle___200 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___57 {
	int (*match)(struct irq_domain___57 *, struct device_node___90 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___57 *, struct irq_fwspec___55 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___57 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___57 *, unsigned int);
	int (*xlate)(struct irq_domain___57 *, struct device_node___90 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___57 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___57 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___57 *, struct irq_data___59 *, bool);
	void (*deactivate)(struct irq_domain___57 *, struct irq_data___59 *);
	int (*translate)(struct irq_domain___57 *, struct irq_fwspec___55 *, long unsigned int *, unsigned int *);
};

struct ptp_clock_time {
	__s64 sec;
	__u32 nsec;
	__u32 reserved;
};

struct ptp_extts_request {
	unsigned int index;
	unsigned int flags;
	unsigned int rsv[2];
};

struct ptp_perout_request {
	union {
		struct ptp_clock_time start;
		struct ptp_clock_time phase;
	};
	struct ptp_clock_time period;
	unsigned int index;
	unsigned int flags;
	union {
		struct ptp_clock_time on;
		unsigned int rsv[4];
	};
};

enum ptp_pin_function {
	PTP_PF_NONE = 0,
	PTP_PF_EXTTS = 1,
	PTP_PF_PEROUT = 2,
	PTP_PF_PHYSYNC = 3,
};

struct ptp_pin_desc {
	char name[64];
	unsigned int index;
	unsigned int func;
	unsigned int chan;
	unsigned int rsv[5];
};

struct ptp_clock_request {
	enum {
		PTP_CLK_REQ_EXTTS = 0,
		PTP_CLK_REQ_PEROUT = 1,
		PTP_CLK_REQ_PPS = 2,
	} type;
	union {
		struct ptp_extts_request extts;
		struct ptp_perout_request perout;
	};
};

struct ptp_clock_info {
	struct module___210 *owner;
	char name[32];
	s32 max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int n_pins;
	int pps;
	struct ptp_pin_desc *pin_config;
	int (*adjfine)(struct ptp_clock_info *, long int);
	int (*adjfreq)(struct ptp_clock_info *, s32);
	int (*adjphase)(struct ptp_clock_info *, s32);
	int (*adjtime)(struct ptp_clock_info *, s64);
	int (*gettime64)(struct ptp_clock_info *, struct timespec64 *);
	int (*gettimex64)(struct ptp_clock_info *, struct timespec64 *, struct ptp_system_timestamp *);
	int (*getcrosststamp)(struct ptp_clock_info *, struct system_device_crosststamp *);
	int (*settime64)(struct ptp_clock_info *, const struct timespec64 *);
	int (*enable)(struct ptp_clock_info *, struct ptp_clock_request *, int);
	int (*verify)(struct ptp_clock_info *, unsigned int, enum ptp_pin_function, unsigned int);
	long int (*do_aux_work)(struct ptp_clock_info *);
};

struct bufdesc {
	__le16 cbd_datlen;
	__le16 cbd_sc;
	__le32 cbd_bufaddr;
};

struct bufdesc_ex {
	struct bufdesc desc;
	__le32 cbd_esc;
	__le32 cbd_prot;
	__le32 cbd_bdu;
	__le32 ts;
	__le16 res0[4];
};

struct bufdesc_prop {
	int qid;
	struct bufdesc *base;
	struct bufdesc *last;
	struct bufdesc *cur;
	void *reg_desc_active;
	dma_addr_t dma;
	short unsigned int ring_size;
	unsigned char dsize;
	unsigned char dsize_log2;
};

struct fec_enet_priv_tx_q {
	struct bufdesc_prop bd;
	unsigned char *tx_bounce[512];
	struct sk_buff___45 *tx_skbuff[512];
	short unsigned int tx_stop_threshold;
	short unsigned int tx_wake_threshold;
	struct bufdesc *dirty_tx;
	char *tso_hdrs;
	dma_addr_t tso_hdrs_dma;
};

struct fec_enet_priv_rx_q {
	struct bufdesc_prop bd;
	struct sk_buff___45 *rx_skbuff[512];
};

struct fec_stop_mode_gpr {
	struct regmap *gpr;
	u8 reg;
	u8 bit;
};

struct ptp_clock;

struct fec_enet_private {
	void *hwp;
	struct net_device___46 *netdev;
	struct clk *clk_ipg;
	struct clk *clk_ahb;
	struct clk *clk_ref;
	struct clk *clk_enet_out;
	struct clk *clk_ptp;
	struct clk *clk_2x_txclk;
	bool ptp_clk_on;
	struct mutex ptp_clk_mutex;
	unsigned int num_tx_queues;
	unsigned int num_rx_queues;
	struct fec_enet_priv_tx_q *tx_queue[3];
	struct fec_enet_priv_rx_q *rx_queue[3];
	unsigned int total_tx_ring_size;
	unsigned int total_rx_ring_size;
	struct platform_device___39 *pdev;
	int dev_id;
	struct mii_bus___9 *mii_bus;
	uint phy_speed;
	phy_interface_t phy_interface;
	struct device_node___90 *phy_node;
	bool rgmii_txc_dly;
	bool rgmii_rxc_dly;
	int link;
	int full_duplex;
	int speed;
	int irq[3];
	bool bufdesc_ex;
	int pause_flag;
	int wol_flag;
	int wake_irq;
	u32 quirks;
	struct napi_struct___4 napi;
	int csum_flags;
	struct work_struct tx_timeout_work;
	struct ptp_clock *ptp_clock;
	struct ptp_clock_info ptp_caps;
	long unsigned int last_overflow_check;
	spinlock_t tmreg_lock;
	struct cyclecounter cc;
	struct timecounter tc;
	int rx_hwtstamp_filter;
	u32 base_incval;
	u32 cycle_speed;
	int hwts_rx_en;
	int hwts_tx_en;
	struct delayed_work time_keep;
	struct regulator *reg_phy;
	struct fec_stop_mode_gpr stop_gpr;
	unsigned int tx_align;
	unsigned int rx_align;
	unsigned int rx_pkts_itr;
	unsigned int rx_time_itr;
	unsigned int tx_pkts_itr;
	unsigned int tx_time_itr;
	unsigned int itr_clk_rate;
	struct ethtool_eee eee;
	unsigned int clk_ref_rate;
	u32 rx_copybreak;
	unsigned int ptp_inc;
	int pps_channel;
	unsigned int reload_period;
	int pps_enable;
	unsigned int next_counter;
	u64 ethtool_stats[0];
};

struct fec_devinfo {
	u32 quirks;
};

enum imx_fec_type {
	IMX25_FEC = 1,
	IMX27_FEC = 2,
	IMX28_FEC = 3,
	IMX6Q_FEC = 4,
	MVF600_FEC = 5,
	IMX6SX_FEC = 6,
	IMX6UL_FEC = 7,
	IMX8MQ_FEC = 8,
	IMX8QM_FEC = 9,
};

struct fec_stat {
	char name[32];
	u16 offset;
};

struct hwtstamp_config {
	int flags;
	int tx_type;
	int rx_filter;
};

struct pps_event_time {
	struct timespec64 ts_real;
};

struct ptp_clock_info___2 {
	struct module___191 *owner;
	char name[32];
	s32 max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int n_pins;
	int pps;
	struct ptp_pin_desc *pin_config;
	int (*adjfine)(struct ptp_clock_info___2 *, long int);
	int (*adjfreq)(struct ptp_clock_info___2 *, s32);
	int (*adjphase)(struct ptp_clock_info___2 *, s32);
	int (*adjtime)(struct ptp_clock_info___2 *, s64);
	int (*gettime64)(struct ptp_clock_info___2 *, struct timespec64 *);
	int (*gettimex64)(struct ptp_clock_info___2 *, struct timespec64 *, struct ptp_system_timestamp *);
	int (*getcrosststamp)(struct ptp_clock_info___2 *, struct system_device_crosststamp *);
	int (*settime64)(struct ptp_clock_info___2 *, const struct timespec64 *);
	int (*enable)(struct ptp_clock_info___2 *, struct ptp_clock_request *, int);
	int (*verify)(struct ptp_clock_info___2 *, unsigned int, enum ptp_pin_function, unsigned int);
	long int (*do_aux_work)(struct ptp_clock_info___2 *);
};

enum ptp_clock_events {
	PTP_CLOCK_ALARM = 0,
	PTP_CLOCK_EXTTS = 1,
	PTP_CLOCK_PPS = 2,
	PTP_CLOCK_PPSUSR = 3,
};

struct ptp_clock_event {
	int type;
	int index;
	union {
		u64 timestamp;
		struct pps_event_time pps_times;
	};
};

struct fec_enet_priv_tx_q___2 {
	struct bufdesc_prop bd;
	unsigned char *tx_bounce[512];
	struct sk_buff___39 *tx_skbuff[512];
	short unsigned int tx_stop_threshold;
	short unsigned int tx_wake_threshold;
	struct bufdesc *dirty_tx;
	char *tso_hdrs;
	dma_addr_t tso_hdrs_dma;
};

struct fec_enet_priv_rx_q___2 {
	struct bufdesc_prop bd;
	struct sk_buff___39 *rx_skbuff[512];
};

struct fec_enet_private___2 {
	void *hwp;
	struct net_device___40 *netdev;
	struct clk *clk_ipg;
	struct clk *clk_ahb;
	struct clk *clk_ref;
	struct clk *clk_enet_out;
	struct clk *clk_ptp;
	struct clk *clk_2x_txclk;
	bool ptp_clk_on;
	struct mutex ptp_clk_mutex;
	unsigned int num_tx_queues;
	unsigned int num_rx_queues;
	struct fec_enet_priv_tx_q___2 *tx_queue[3];
	struct fec_enet_priv_rx_q___2 *rx_queue[3];
	unsigned int total_tx_ring_size;
	unsigned int total_rx_ring_size;
	struct platform_device___36 *pdev;
	int dev_id;
	struct mii_bus___2 *mii_bus;
	uint phy_speed;
	phy_interface_t phy_interface;
	struct device_node___75 *phy_node;
	bool rgmii_txc_dly;
	bool rgmii_rxc_dly;
	int link;
	int full_duplex;
	int speed;
	int irq[3];
	bool bufdesc_ex;
	int pause_flag;
	int wol_flag;
	int wake_irq;
	u32 quirks;
	struct napi_struct___3 napi;
	int csum_flags;
	struct work_struct tx_timeout_work;
	struct ptp_clock *ptp_clock;
	struct ptp_clock_info___2 ptp_caps;
	long unsigned int last_overflow_check;
	spinlock_t tmreg_lock;
	struct cyclecounter cc;
	struct timecounter tc;
	int rx_hwtstamp_filter;
	u32 base_incval;
	u32 cycle_speed;
	int hwts_rx_en;
	int hwts_tx_en;
	struct delayed_work time_keep;
	struct regulator *reg_phy;
	struct fec_stop_mode_gpr stop_gpr;
	unsigned int tx_align;
	unsigned int rx_align;
	unsigned int rx_pkts_itr;
	unsigned int rx_time_itr;
	unsigned int tx_pkts_itr;
	unsigned int tx_time_itr;
	unsigned int itr_clk_rate;
	struct ethtool_eee eee;
	unsigned int clk_ref_rate;
	u32 rx_copybreak;
	unsigned int ptp_inc;
	int pps_channel;
	unsigned int reload_period;
	int pps_enable;
	unsigned int next_counter;
	u64 ethtool_stats[0];
};

struct tgec_mdio_controller {
	__be32 reserved[12];
	__be32 mdio_stat;
	__be32 mdio_ctl;
	__be32 mdio_data;
	__be32 mdio_addr;
};

struct mdio_fsl_priv {
	struct tgec_mdio_controller *mdio_base;
	bool is_little_endian;
	bool has_a009885;
	bool has_a011043;
};

struct gen_pool___2;

typedef long unsigned int (*genpool_algo_t___2)(long unsigned int *, long unsigned int, long unsigned int, unsigned int, void *, struct gen_pool___2 *, long unsigned int);

struct gen_pool___2 {
	spinlock_t___2 lock;
	struct list_head chunks;
	int min_alloc_order;
	genpool_algo_t___2 algo;
	void *data;
	const char *name;
};

struct muram_info {
	struct gen_pool___2 *pool;
	void *vbase;
	size_t size;
	phys_addr_t pbase;
};

enum fman_port_type {
	FMAN_PORT_TYPE_TX = 0,
	FMAN_PORT_TYPE_RX = 1,
};

struct fman_rev_info {
	u8 major;
	u8 minor;
};

enum fman_exceptions {
	FMAN_EX_DMA_BUS_ERROR = 0,
	FMAN_EX_DMA_READ_ECC = 1,
	FMAN_EX_DMA_SYSTEM_WRITE_ECC = 2,
	FMAN_EX_DMA_FM_WRITE_ECC = 3,
	FMAN_EX_DMA_SINGLE_PORT_ECC = 4,
	FMAN_EX_FPM_STALL_ON_TASKS = 5,
	FMAN_EX_FPM_SINGLE_ECC = 6,
	FMAN_EX_FPM_DOUBLE_ECC = 7,
	FMAN_EX_QMI_SINGLE_ECC = 8,
	FMAN_EX_QMI_DOUBLE_ECC = 9,
	FMAN_EX_QMI_DEQ_FROM_UNKNOWN_PORTID = 10,
	FMAN_EX_BMI_LIST_RAM_ECC = 11,
	FMAN_EX_BMI_STORAGE_PROFILE_ECC = 12,
	FMAN_EX_BMI_STATISTICS_RAM_ECC = 13,
	FMAN_EX_BMI_DISPATCH_RAM_ECC = 14,
	FMAN_EX_IRAM_ECC = 15,
	FMAN_EX_MURAM_ECC = 16,
};

enum fman_event_modules {
	FMAN_MOD_MAC = 0,
	FMAN_MOD_FMAN_CTRL = 1,
	FMAN_MOD_DUMMY_LAST = 2,
};

enum fman_intr_type {
	FMAN_INTR_TYPE_ERR = 0,
	FMAN_INTR_TYPE_NORMAL = 1,
};

enum fman_inter_module_event {
	FMAN_EV_ERR_MAC0 = 0,
	FMAN_EV_ERR_MAC1 = 1,
	FMAN_EV_ERR_MAC2 = 2,
	FMAN_EV_ERR_MAC3 = 3,
	FMAN_EV_ERR_MAC4 = 4,
	FMAN_EV_ERR_MAC5 = 5,
	FMAN_EV_ERR_MAC6 = 6,
	FMAN_EV_ERR_MAC7 = 7,
	FMAN_EV_ERR_MAC8 = 8,
	FMAN_EV_ERR_MAC9 = 9,
	FMAN_EV_MAC0 = 10,
	FMAN_EV_MAC1 = 11,
	FMAN_EV_MAC2 = 12,
	FMAN_EV_MAC3 = 13,
	FMAN_EV_MAC4 = 14,
	FMAN_EV_MAC5 = 15,
	FMAN_EV_MAC6 = 16,
	FMAN_EV_MAC7 = 17,
	FMAN_EV_MAC8 = 18,
	FMAN_EV_MAC9 = 19,
	FMAN_EV_FMAN_CTRL_0 = 20,
	FMAN_EV_FMAN_CTRL_1 = 21,
	FMAN_EV_FMAN_CTRL_2 = 22,
	FMAN_EV_FMAN_CTRL_3 = 23,
	FMAN_EV_CNT = 24,
};

struct fman_intr_src {
	void (*isr_cb)(void *);
	void *src_handle;
};

struct fman;

typedef irqreturn_t fman_exceptions_cb(struct fman *, enum fman_exceptions);

struct fman_kg_regs;

typedef irqreturn_t fman_bus_error_cb(struct fman *, u8, u64, u8, u16);

struct muram_info___2;

struct fman_keygen;

struct fman_dts_params {
	void *base_addr;
	struct resource *res;
	u8 id;
	int err_irq;
	u16 clk_freq;
	u32 qman_channel_base;
	u32 num_of_qman_channels;
	struct resource muram_res;
};

struct fman_fpm_regs;

struct fman_bmi_regs;

struct fman_qmi_regs;

struct fman_dma_regs;

struct fman_hwp_regs;

struct fman_state_struct;

struct fman_cfg;

struct fman {
	struct device___198 *dev;
	void *base_addr;
	struct fman_intr_src intr_mng[24];
	struct fman_fpm_regs *fpm_regs;
	struct fman_bmi_regs *bmi_regs;
	struct fman_qmi_regs *qmi_regs;
	struct fman_dma_regs *dma_regs;
	struct fman_hwp_regs *hwp_regs;
	struct fman_kg_regs *kg_regs;
	fman_exceptions_cb *exception_cb;
	fman_bus_error_cb *bus_error_cb;
	spinlock_t spinlock;
	struct fman_state_struct *state;
	struct fman_cfg *cfg;
	struct muram_info___2 *muram;
	struct fman_keygen *keygen;
	long unsigned int cam_offset;
	size_t cam_size;
	long unsigned int fifo_offset;
	size_t fifo_size;
	u32 liodn_base[64];
	u32 liodn_offset[64];
	struct fman_dts_params dts_params;
};

struct fman_fpm_regs {
	u32 fmfp_tnc;
	u32 fmfp_prc;
	u32 fmfp_brkc;
	u32 fmfp_mxd;
	u32 fmfp_dist1;
	u32 fmfp_dist2;
	u32 fm_epi;
	u32 fm_rie;
	u32 fmfp_fcev[4];
	u32 res0030[4];
	u32 fmfp_cee[4];
	u32 res0050[4];
	u32 fmfp_tsc1;
	u32 fmfp_tsc2;
	u32 fmfp_tsp;
	u32 fmfp_tsf;
	u32 fm_rcr;
	u32 fmfp_extc;
	u32 fmfp_ext1;
	u32 fmfp_ext2;
	u32 fmfp_drd[16];
	u32 fmfp_dra;
	u32 fm_ip_rev_1;
	u32 fm_ip_rev_2;
	u32 fm_rstc;
	u32 fm_cld;
	u32 fm_npi;
	u32 fmfp_exte;
	u32 fmfp_ee;
	u32 fmfp_cev[4];
	u32 res00f0[4];
	u32 fmfp_ps[50];
	u32 res01c8[14];
	u32 fmfp_clfabc;
	u32 fmfp_clfcc;
	u32 fmfp_clfaval;
	u32 fmfp_clfbval;
	u32 fmfp_clfcval;
	u32 fmfp_clfamsk;
	u32 fmfp_clfbmsk;
	u32 fmfp_clfcmsk;
	u32 fmfp_clfamc;
	u32 fmfp_clfbmc;
	u32 fmfp_clfcmc;
	u32 fmfp_decceh;
	u32 res0230[116];
	u32 fmfp_ts[128];
	u32 res0600[640];
};

struct fman_bmi_regs {
	u32 fmbm_init;
	u32 fmbm_cfg1;
	u32 fmbm_cfg2;
	u32 res000c[5];
	u32 fmbm_ievr;
	u32 fmbm_ier;
	u32 fmbm_ifr;
	u32 res002c[5];
	u32 fmbm_arb[8];
	u32 res0060[12];
	u32 fmbm_dtc[3];
	u32 res009c;
	u32 fmbm_dcv[12];
	u32 fmbm_dcm[12];
	u32 fmbm_gde;
	u32 fmbm_pp[63];
	u32 res0200;
	u32 fmbm_pfs[63];
	u32 res0300;
	u32 fmbm_spliodn[63];
};

struct fman_qmi_regs {
	u32 fmqm_gc;
	u32 res0004;
	u32 fmqm_eie;
	u32 fmqm_eien;
	u32 fmqm_eif;
	u32 fmqm_ie;
	u32 fmqm_ien;
	u32 fmqm_if;
	u32 fmqm_gs;
	u32 fmqm_ts;
	u32 fmqm_etfc;
	u32 fmqm_dtfc;
	u32 fmqm_dc0;
	u32 fmqm_dc1;
	u32 fmqm_dc2;
	u32 fmqm_dc3;
	u32 fmqm_dfdc;
	u32 fmqm_dfcc;
	u32 fmqm_dffc;
	u32 fmqm_dcc;
	u32 res0050[7];
	u32 fmqm_tapc;
	u32 fmqm_dmcvc;
	u32 fmqm_difdcc;
	u32 fmqm_da1v;
	u32 res007c;
	u32 fmqm_dtc;
	u32 fmqm_efddd;
	u32 res0088[2];
	struct {
		u32 fmqm_dtcfg1;
		u32 fmqm_dtval1;
		u32 fmqm_dtm1;
		u32 fmqm_dtc1;
		u32 fmqm_dtcfg2;
		u32 fmqm_dtval2;
		u32 fmqm_dtm2;
		u32 res001c;
	} dbg_traps[3];
	u8 res00f0[784];
};

struct fman_dma_regs {
	u32 fmdmsr;
	u32 fmdmmr;
	u32 fmdmtr;
	u32 fmdmhy;
	u32 fmdmsetr;
	u32 fmdmtah;
	u32 fmdmtal;
	u32 fmdmtcid;
	u32 fmdmra;
	u32 fmdmrd;
	u32 fmdmwcr;
	u32 fmdmebcr;
	u32 fmdmccqdr;
	u32 fmdmccqvr1;
	u32 fmdmccqvr2;
	u32 fmdmcqvr3;
	u32 fmdmcqvr4;
	u32 fmdmcqvr5;
	u32 fmdmsefrc;
	u32 fmdmsqfrc;
	u32 fmdmssrc;
	u32 fmdmdcr;
	u32 fmdmemsr;
	u32 res005c;
	u32 fmdmplr[32];
	u32 res00e0[968];
};

struct fman_hwp_regs {
	u32 res0000[529];
	u32 fmprrpimac;
	u32 res[494];
};

struct fman_state_struct {
	u8 fm_id;
	u16 fm_clk_freq;
	struct fman_rev_info rev_info;
	bool enabled_time_stamp;
	u8 count1_micro_bit;
	u8 total_num_of_tasks;
	u8 accumulated_num_of_tasks;
	u32 accumulated_fifo_size;
	u8 accumulated_num_of_open_dmas;
	u8 accumulated_num_of_deq_tnums;
	u32 exceptions;
	u32 extra_fifo_pool_size;
	u8 extra_tasks_pool_size;
	u8 extra_open_dmas_pool_size;
	u16 port_mfl[10];
	u16 mac_mfl[10];
	u32 fm_iram_size;
	u32 dma_thresh_max_commq;
	u32 dma_thresh_max_buf;
	u32 max_num_of_open_dmas;
	u32 qmi_max_num_of_tnums;
	u32 qmi_def_tnums_thresh;
	u32 bmi_max_num_of_tasks;
	u32 bmi_max_fifo_size;
	u32 fm_port_num_of_cg;
	u32 num_of_rx_ports;
	u32 total_fifo_size;
	u32 qman_channel_base;
	u32 num_of_qman_channels;
	struct resource *res;
};

enum fman_dma_aid_mode {
	FMAN_DMA_AID_OUT_PORT_ID = 0,
	FMAN_DMA_AID_OUT_TNUM = 1,
};

struct fman_cfg {
	u8 disp_limit_tsh;
	u8 prs_disp_tsh;
	u8 plcr_disp_tsh;
	u8 kg_disp_tsh;
	u8 bmi_disp_tsh;
	u8 qmi_enq_disp_tsh;
	u8 qmi_deq_disp_tsh;
	u8 fm_ctl1_disp_tsh;
	u8 fm_ctl2_disp_tsh;
	int dma_cache_override;
	enum fman_dma_aid_mode dma_aid_mode;
	u32 dma_axi_dbg_num_of_beats;
	u32 dma_cam_num_of_entries;
	u32 dma_watchdog;
	u8 dma_comm_qtsh_asrt_emer;
	u32 dma_write_buf_tsh_asrt_emer;
	u32 dma_read_buf_tsh_asrt_emer;
	u8 dma_comm_qtsh_clr_emer;
	u32 dma_write_buf_tsh_clr_emer;
	u32 dma_read_buf_tsh_clr_emer;
	u32 dma_sos_emergency;
	int dma_dbg_cnt_mode;
	int catastrophic_err;
	int dma_err;
	u32 exceptions;
	u16 clk_freq;
	u32 cam_base_addr;
	u32 fifo_base_addr;
	u32 total_fifo_size;
	u32 total_num_of_tasks;
	u32 qmi_def_tnums_thresh;
};

struct fman_port_init_params {
	u8 port_id;
	enum fman_port_type port_type;
	u16 port_speed;
	u16 liodn_offset;
	u8 num_of_tasks;
	u8 num_of_extra_tasks;
	u8 num_of_open_dmas;
	u8 num_of_extra_open_dmas;
	u32 size_of_fifo;
	u32 extra_size_of_fifo;
	u8 deq_pipeline_depth;
	u16 max_frame_length;
	u16 liodn_base;
};

struct fman_iram_regs {
	u32 iadd;
	u32 idata;
	u32 itcfg;
	u32 iready;
};

struct fman_buffer_prefix_content {
	u16 priv_data_size;
	bool pass_prs_result;
	bool pass_time_stamp;
	bool pass_hash_result;
	u16 data_align;
};

struct fman_ext_pool_params {
	u8 id;
	u16 size;
};

struct fman_ext_pools {
	u8 num_of_pools_used;
	struct fman_ext_pool_params ext_buf_pool[8];
};

struct fman_sp_int_context_data_copy {
	u16 ext_buf_offset;
	u8 int_context_offset;
	u16 size;
};

struct fman_sp_buf_margins {
	u16 start_margins;
	u16 end_margins;
};

struct fman_sp_buffer_offsets {
	u32 data_offset;
	u32 prs_result_offset;
	u32 time_stamp_offset;
	u32 hash_result_offset;
};

struct fman_kg_scheme_regs {
	u32 kgse_mode;
	u32 kgse_ekfc;
	u32 kgse_ekdv;
	u32 kgse_bmch;
	u32 kgse_bmcl;
	u32 kgse_fqb;
	u32 kgse_hc;
	u32 kgse_ppc;
	u32 kgse_gec[8];
	u32 kgse_spc;
	u32 kgse_dv0;
	u32 kgse_dv1;
	u32 kgse_ccbs;
	u32 kgse_mv;
	u32 kgse_om;
	u32 kgse_vsp;
};

struct fman_kg_pe_regs {
	u32 fmkg_pe_sp;
	u32 fmkg_pe_cpp;
};

struct fman_kg_regs___2 {
	u32 fmkg_gcr;
	u32 res004;
	u32 res008;
	u32 fmkg_eer;
	u32 fmkg_eeer;
	u32 res014;
	u32 res018;
	u32 fmkg_seer;
	u32 fmkg_seeer;
	u32 fmkg_gsr;
	u32 fmkg_tpc;
	u32 fmkg_serc;
	u32 res030[4];
	u32 fmkg_fdor;
	u32 fmkg_gdv0r;
	u32 fmkg_gdv1r;
	u32 res04c[6];
	u32 fmkg_feer;
	u32 res068[38];
	union {
		u32 fmkg_indirect[63];
		struct fman_kg_scheme_regs fmkg_sch;
		struct fman_kg_pe_regs fmkg_pe;
	};
	u32 fmkg_ar;
};

struct keygen_scheme {
	bool used;
	u8 hw_port_id;
	u32 base_fqid;
	u32 hash_fqid_count;
	bool use_hashing;
	bool symmetric_hash;
	u8 hashShift;
	u32 match_vector;
};

struct fman_keygen___2 {
	struct keygen_scheme schemes[32];
	struct fman_kg_regs___2 *keygen_regs;
};

struct fman_buf_pool_depletion {
	bool pools_grp_mode_enable;
	u8 num_of_pools;
	bool pools_to_consider[64];
	bool single_pool_mode_enable;
	bool pools_to_consider_for_single_mode[64];
};

struct fman_port_rx_params {
	u32 err_fqid;
	u32 dflt_fqid;
	u32 pcd_base_fqid;
	u32 pcd_fqs_count;
	struct fman_ext_pools ext_buf_pools;
};

struct fman_port_non_rx_params {
	u32 err_fqid;
	u32 dflt_fqid;
};

union fman_port_specific_params {
	struct fman_port_rx_params rx_params;
	struct fman_port_non_rx_params non_rx_params;
};

struct fman_port_params {
	void *fm;
	union fman_port_specific_params specific_params;
};

struct fman_port_rx_bmi_regs {
	u32 fmbm_rcfg;
	u32 fmbm_rst;
	u32 fmbm_rda;
	u32 fmbm_rfp;
	u32 fmbm_rfed;
	u32 fmbm_ricp;
	u32 fmbm_rim;
	u32 fmbm_rebm;
	u32 fmbm_rfne;
	u32 fmbm_rfca;
	u32 fmbm_rfpne;
	u32 fmbm_rpso;
	u32 fmbm_rpp;
	u32 fmbm_rccb;
	u32 fmbm_reth;
	u32 reserved003c[1];
	u32 fmbm_rprai[8];
	u32 fmbm_rfqid;
	u32 fmbm_refqid;
	u32 fmbm_rfsdm;
	u32 fmbm_rfsem;
	u32 fmbm_rfene;
	u32 reserved0074[2];
	u32 fmbm_rcmne;
	u32 reserved0080[32];
	u32 fmbm_ebmpi[8];
	u32 fmbm_acnt[8];
	u32 reserved0130[8];
	u32 fmbm_rcgm[8];
	u32 fmbm_mpd;
	u32 reserved0184[31];
	u32 fmbm_rstc;
	u32 fmbm_rfrc;
	u32 fmbm_rfbc;
	u32 fmbm_rlfc;
	u32 fmbm_rffc;
	u32 fmbm_rfdc;
	u32 fmbm_rfldec;
	u32 fmbm_rodc;
	u32 fmbm_rbdc;
	u32 fmbm_rpec;
	u32 reserved0224[22];
	u32 fmbm_rpc;
	u32 fmbm_rpcp;
	u32 fmbm_rccn;
	u32 fmbm_rtuc;
	u32 fmbm_rrquc;
	u32 fmbm_rduc;
	u32 fmbm_rfuc;
	u32 fmbm_rpac;
	u32 reserved02a0[24];
	u32 fmbm_rdcfg[3];
	u32 fmbm_rgpr;
	u32 reserved0310[58];
};

struct fman_port_tx_bmi_regs {
	u32 fmbm_tcfg;
	u32 fmbm_tst;
	u32 fmbm_tda;
	u32 fmbm_tfp;
	u32 fmbm_tfed;
	u32 fmbm_ticp;
	u32 fmbm_tfdne;
	u32 fmbm_tfca;
	u32 fmbm_tcfqid;
	u32 fmbm_tefqid;
	u32 fmbm_tfene;
	u32 fmbm_trlmts;
	u32 fmbm_trlmt;
	u32 reserved0034[14];
	u32 fmbm_tccb;
	u32 fmbm_tfne;
	u32 fmbm_tpfcm[2];
	u32 fmbm_tcmne;
	u32 reserved0080[96];
	u32 fmbm_tstc;
	u32 fmbm_tfrc;
	u32 fmbm_tfdc;
	u32 fmbm_tfledc;
	u32 fmbm_tfufdc;
	u32 fmbm_tbdc;
	u32 reserved0218[26];
	u32 fmbm_tpc;
	u32 fmbm_tpcp;
	u32 fmbm_tccn;
	u32 fmbm_ttuc;
	u32 fmbm_ttcquc;
	u32 fmbm_tduc;
	u32 fmbm_tfuc;
	u32 reserved029c[16];
	u32 fmbm_tdcfg[3];
	u32 fmbm_tgpr;
	u32 reserved0310[58];
};

union fman_port_bmi_regs {
	struct fman_port_rx_bmi_regs rx;
	struct fman_port_tx_bmi_regs tx;
};

struct fman_port_qmi_regs {
	u32 fmqm_pnc;
	u32 fmqm_pns;
	u32 fmqm_pnts;
	u32 reserved00c[4];
	u32 fmqm_pnen;
	u32 fmqm_pnetfc;
	u32 reserved024[2];
	u32 fmqm_pndn;
	u32 fmqm_pndc;
	u32 fmqm_pndtfc;
	u32 fmqm_pndfdc;
	u32 fmqm_pndcc;
};

struct fman_port_hwp_regs {
	struct {
		u32 ssa;
		u32 lcv;
	} pmda[16];
	u32 reserved080[222];
	u32 fmpr_pcac;
};

enum fman_port_deq_prefetch {
	FMAN_PORT_DEQ_NO_PREFETCH = 0,
	FMAN_PORT_DEQ_PART_PREFETCH = 1,
	FMAN_PORT_DEQ_FULL_PREFETCH = 2,
};

struct fman_port_rsrc {
	u32 num;
	u32 extra;
};

enum fman_port_dma_swap {
	FMAN_PORT_DMA_NO_SWAP = 0,
	FMAN_PORT_DMA_SWAP_LE = 1,
	FMAN_PORT_DMA_SWAP_BE = 2,
};

enum fman_port_color {
	FMAN_PORT_COLOR_GREEN = 0,
	FMAN_PORT_COLOR_YELLOW = 1,
	FMAN_PORT_COLOR_RED = 2,
	FMAN_PORT_COLOR_OVERRIDE = 3,
};

enum fman_port_deq_type {
	FMAN_PORT_DEQ_BY_PRI = 0,
	FMAN_PORT_DEQ_ACTIVE_FQ = 1,
	FMAN_PORT_DEQ_ACTIVE_FQ_NO_ICS = 2,
};

struct fman_port_bpools {
	u8 count;
	bool counters_enable;
	u8 grp_bp_depleted_num;
	struct {
		u8 bpid;
		u16 size;
		bool is_backup;
		bool grp_bp_depleted;
		bool single_bp_depleted;
	} bpool[8];
};

struct fman_port_cfg {
	u32 dflt_fqid;
	u32 err_fqid;
	u32 pcd_base_fqid;
	u32 pcd_fqs_count;
	u8 deq_sp;
	bool deq_high_priority;
	enum fman_port_deq_type deq_type;
	enum fman_port_deq_prefetch deq_prefetch_option;
	u16 deq_byte_cnt;
	u8 cheksum_last_bytes_ignore;
	u8 rx_cut_end_bytes;
	struct fman_buf_pool_depletion buf_pool_depletion;
	struct fman_ext_pools ext_buf_pools;
	u32 tx_fifo_min_level;
	u32 tx_fifo_low_comf_level;
	u32 rx_pri_elevation;
	u32 rx_fifo_thr;
	struct fman_sp_buf_margins buf_margins;
	u32 int_buf_start_margin;
	struct fman_sp_int_context_data_copy int_context;
	u32 discard_mask;
	u32 err_mask;
	struct fman_buffer_prefix_content buffer_prefix_content;
	bool dont_release_buf;
	u8 rx_fd_bits;
	u32 tx_fifo_deq_pipeline_depth;
	bool errata_A006320;
	bool excessive_threshold_register;
	bool fmbm_tfne_has_features;
	enum fman_port_dma_swap dma_swap_data;
	enum fman_port_color color;
};

struct fman_port_rx_pools_params {
	u8 num_of_pools;
	u16 largest_buf_size;
};

struct fman_port_dts_params {
	void *base_addr;
	enum fman_port_type type;
	u16 speed;
	u8 id;
	u32 qman_channel_id;
	struct fman *fman;
};

struct fman_port {
	void *fm;
	struct device___198 *dev;
	struct fman_rev_info rev_info;
	u8 port_id;
	enum fman_port_type port_type;
	u16 port_speed;
	union fman_port_bmi_regs *bmi_regs;
	struct fman_port_qmi_regs *qmi_regs;
	struct fman_port_hwp_regs *hwp_regs;
	struct fman_sp_buffer_offsets buffer_offsets;
	u8 internal_buf_offset;
	struct fman_ext_pools ext_buf_pools;
	u16 max_frame_length;
	struct fman_port_rsrc open_dmas;
	struct fman_port_rsrc tasks;
	struct fman_port_rsrc fifo_bufs;
	struct fman_port_rx_pools_params rx_pools_params;
	struct fman_port_cfg *cfg;
	struct fman_port_dts_params dts_params;
	u8 ext_pools_num;
	u32 max_port_fifo_size;
	u32 max_num_of_ext_pools;
	u32 max_num_of_sub_portals;
	u32 bm_max_num_of_pools;
};

struct platform_device___40 {
	const char *name;
	int id;
	bool id_auto;
	struct device___201 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___34 {
	int (*probe)(struct platform_device___40 *);
	int (*remove)(struct platform_device___40 *);
	void (*shutdown)(struct platform_device___40 *);
	int (*suspend)(struct platform_device___40 *, pm_message_t);
	int (*resume)(struct platform_device___40 *);
	struct device_driver___201 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct fman___2;

typedef irqreturn_t fman_exceptions_cb___2(struct fman___2 *, enum fman_exceptions);

typedef irqreturn_t fman_bus_error_cb___2(struct fman___2 *, u8, u64, u8, u16);

struct fman___2 {
	struct device___201 *dev;
	void *base_addr;
	struct fman_intr_src intr_mng[24];
	struct fman_fpm_regs *fpm_regs;
	struct fman_bmi_regs *bmi_regs;
	struct fman_qmi_regs *qmi_regs;
	struct fman_dma_regs *dma_regs;
	struct fman_hwp_regs *hwp_regs;
	struct fman_kg_regs *kg_regs;
	fman_exceptions_cb___2 *exception_cb;
	fman_bus_error_cb___2 *bus_error_cb;
	spinlock_t spinlock;
	struct fman_state_struct *state;
	struct fman_cfg *cfg;
	struct muram_info___2 *muram;
	struct fman_keygen *keygen;
	long unsigned int cam_offset;
	size_t cam_size;
	long unsigned int fifo_offset;
	size_t fifo_size;
	u32 liodn_base[64];
	u32 liodn_offset[64];
	struct fman_dts_params dts_params;
};

typedef u8 enet_addr_t[6];

enum comm_mode {
	COMM_MODE_NONE = 0,
	COMM_MODE_RX = 1,
	COMM_MODE_TX = 2,
	COMM_MODE_RX_AND_TX = 3,
};

enum fman_mac_exceptions {
	FM_MAC_EX_10G_MDIO_SCAN_EVENT = 0,
	FM_MAC_EX_10G_MDIO_CMD_CMPL = 1,
	FM_MAC_EX_10G_REM_FAULT = 2,
	FM_MAC_EX_10G_LOC_FAULT = 3,
	FM_MAC_EX_10G_TX_ECC_ER = 4,
	FM_MAC_EX_10G_TX_FIFO_UNFL = 5,
	FM_MAC_EX_10G_TX_FIFO_OVFL = 6,
	FM_MAC_EX_10G_TX_ER = 7,
	FM_MAC_EX_10G_RX_FIFO_OVFL = 8,
	FM_MAC_EX_10G_RX_ECC_ER = 9,
	FM_MAC_EX_10G_RX_JAB_FRM = 10,
	FM_MAC_EX_10G_RX_OVRSZ_FRM = 11,
	FM_MAC_EX_10G_RX_RUNT_FRM = 12,
	FM_MAC_EX_10G_RX_FRAG_FRM = 13,
	FM_MAC_EX_10G_RX_LEN_ER = 14,
	FM_MAC_EX_10G_RX_CRC_ER = 15,
	FM_MAC_EX_10G_RX_ALIGN_ER = 16,
	FM_MAC_EX_1G_BAB_RX = 17,
	FM_MAC_EX_1G_RX_CTL = 18,
	FM_MAC_EX_1G_GRATEFUL_TX_STP_COMPLET = 19,
	FM_MAC_EX_1G_BAB_TX = 20,
	FM_MAC_EX_1G_TX_CTL = 21,
	FM_MAC_EX_1G_TX_ERR = 22,
	FM_MAC_EX_1G_LATE_COL = 23,
	FM_MAC_EX_1G_COL_RET_LMT = 24,
	FM_MAC_EX_1G_TX_FIFO_UNDRN = 25,
	FM_MAC_EX_1G_MAG_PCKT = 26,
	FM_MAC_EX_1G_MII_MNG_RD_COMPLET = 27,
	FM_MAC_EX_1G_MII_MNG_WR_COMPLET = 28,
	FM_MAC_EX_1G_GRATEFUL_RX_STP_COMPLET = 29,
	FM_MAC_EX_1G_DATA_ERR = 30,
	FM_MAC_1G_RX_DATA_ERR = 31,
	FM_MAC_EX_1G_1588_TS_RX_ERR = 32,
	FM_MAC_EX_1G_RX_MIB_CNT_OVFL = 33,
	FM_MAC_EX_TS_FIFO_ECC_ERR = 34,
	FM_MAC_EX_MAGIC_PACKET_INDICATION = 26,
};

typedef void fman_mac_exception_cb(void *, enum fman_mac_exceptions);

struct fman_mac_params {
	void *base_addr;
	enet_addr_t addr;
	u8 mac_id;
	phy_interface_t phy_if;
	u16 max_speed;
	void *fm;
	void *dev_id;
	fman_mac_exception_cb *event_cb;
	fman_mac_exception_cb *exception_cb;
	bool basex_if;
	struct device_node___88 *internal_phy_node;
};

struct fman_port___2;

struct fman_mac;

struct mac_priv_s;

struct mac_device {
	struct resource *res;
	u8 addr[6];
	struct fman_port___2 *port[2];
	u32 if_support;
	struct phy_device___4 *phy_dev;
	phy_interface_t phy_if;
	struct device_node___88 *phy_node;
	bool autoneg_pause;
	bool rx_pause_req;
	bool tx_pause_req;
	bool rx_pause_active;
	bool tx_pause_active;
	bool promisc;
	bool allmulti;
	int (*init)(struct mac_device *);
	int (*start)(struct mac_device *);
	int (*stop)(struct mac_device *);
	void (*adjust_link)(struct mac_device *);
	int (*set_promisc)(struct fman_mac *, bool);
	int (*change_addr)(struct fman_mac *, enet_addr_t *);
	int (*set_allmulti)(struct fman_mac *, bool);
	int (*set_tstamp)(struct fman_mac *, bool);
	int (*set_multi)(struct net_device___43 *, struct mac_device *);
	int (*set_rx_pause)(struct fman_mac *, bool);
	int (*set_tx_pause)(struct fman_mac *, u8, u16, u16);
	int (*set_exception)(struct fman_mac *, enum fman_mac_exceptions, bool);
	int (*add_hash_mac_addr)(struct fman_mac *, enet_addr_t *);
	int (*remove_hash_mac_addr)(struct fman_mac *, enet_addr_t *);
	struct fman_mac *fman_mac;
	struct mac_priv_s *priv;
};

struct mac_priv_s {
	struct device___201 *dev;
	void *vaddr;
	u8 cell_index;
	struct fman___2 *fman;
	struct device_node___88 *internal_phy_node;
	struct list_head mc_addr_list;
	struct platform_device___40 *eth_dev;
	struct fixed_phy_status *fixed_link;
	u16 speed;
	u16 max_speed;
	int (*enable)(struct fman_mac *, enum comm_mode);
	int (*disable)(struct fman_mac *, enum comm_mode);
};

struct dpaa_eth_data {
	struct mac_device *mac_dev;
	int mac_hw_id;
	int fman_hw_id;
};

struct mac_address {
	u8 addr[6];
	struct list_head list;
};

struct eth_hash_entry {
	u64 addr;
	struct list_head node;
};

struct eth_hash_t {
	u16 size;
	struct list_head *lsts;
};

struct dtsec_regs {
	u32 tsec_id;
	u32 tsec_id2;
	u32 ievent;
	u32 imask;
	u32 reserved0010[1];
	u32 ecntrl;
	u32 ptv;
	u32 tbipa;
	u32 tmr_ctrl;
	u32 tmr_pevent;
	u32 tmr_pemask;
	u32 reserved002c[5];
	u32 tctrl;
	u32 reserved0044[3];
	u32 rctrl;
	u32 reserved0054[11];
	u32 igaddr[8];
	u32 gaddr[8];
	u32 reserved00c0[16];
	u32 maccfg1;
	u32 maccfg2;
	u32 ipgifg;
	u32 hafdup;
	u32 maxfrm;
	u32 reserved0114[10];
	u32 ifstat;
	u32 macstnaddr1;
	u32 macstnaddr2;
	struct {
		u32 exact_match1;
		u32 exact_match2;
	} macaddr[15];
	u32 reserved01c0[16];
	u32 tr64;
	u32 tr127;
	u32 tr255;
	u32 tr511;
	u32 tr1k;
	u32 trmax;
	u32 trmgv;
	u32 rbyt;
	u32 rpkt;
	u32 rfcs;
	u32 rmca;
	u32 rbca;
	u32 rxcf;
	u32 rxpf;
	u32 rxuo;
	u32 raln;
	u32 rflr;
	u32 rcde;
	u32 rcse;
	u32 rund;
	u32 rovr;
	u32 rfrg;
	u32 rjbr;
	u32 rdrp;
	u32 tbyt;
	u32 tpkt;
	u32 tmca;
	u32 tbca;
	u32 txpf;
	u32 tdfr;
	u32 tedf;
	u32 tscl;
	u32 tmcl;
	u32 tlcl;
	u32 txcl;
	u32 tncl;
	u32 reserved0290[1];
	u32 tdrp;
	u32 tjbr;
	u32 tfcs;
	u32 txcf;
	u32 tovr;
	u32 tund;
	u32 tfrg;
	u32 car1;
	u32 car2;
	u32 cam1;
	u32 cam2;
	u32 reserved02c0[848];
};

struct dtsec_cfg {
	u16 halfdup_retransmit;
	u16 halfdup_coll_window;
	bool tx_pad_crc;
	u16 tx_pause_time;
	bool ptp_tsu_en;
	bool ptp_exception_en;
	u32 preamble_len;
	u32 rx_prepend;
	u16 tx_pause_time_extd;
	u16 maximum_frame;
	u32 non_back_to_back_ipg1;
	u32 non_back_to_back_ipg2;
	u32 min_ifg_enforcement;
	u32 back_to_back_ipg;
};

struct fman_mac___2 {
	struct dtsec_regs *regs;
	u64 addr;
	phy_interface_t phy_if;
	u16 max_speed;
	void *dev_id;
	fman_mac_exception_cb *exception_cb;
	fman_mac_exception_cb *event_cb;
	u8 num_of_ind_addr_in_regs;
	struct eth_hash_t *multicast_addr_hash;
	struct eth_hash_t *unicast_addr_hash;
	u8 mac_id;
	u32 exceptions;
	bool ptp_tsu_enabled;
	bool en_tsu_err_exception;
	struct dtsec_cfg *dtsec_drv_param;
	void *fm;
	struct fman_rev_info fm_rev_info;
	bool basex_if;
	struct phy_device___6 *tbiphy;
};

struct fman___3;

typedef irqreturn_t fman_exceptions_cb___3(struct fman___3 *, enum fman_exceptions);

typedef irqreturn_t fman_bus_error_cb___3(struct fman___3 *, u8, u64, u8, u16);

struct fman___3 {
	struct device___178 *dev;
	void *base_addr;
	struct fman_intr_src intr_mng[24];
	struct fman_fpm_regs *fpm_regs;
	struct fman_bmi_regs *bmi_regs;
	struct fman_qmi_regs *qmi_regs;
	struct fman_dma_regs *dma_regs;
	struct fman_hwp_regs *hwp_regs;
	struct fman_kg_regs *kg_regs;
	fman_exceptions_cb___3 *exception_cb;
	fman_bus_error_cb___3 *bus_error_cb;
	spinlock_t spinlock;
	struct fman_state_struct *state;
	struct fman_cfg *cfg;
	struct muram_info___2 *muram;
	struct fman_keygen *keygen;
	long unsigned int cam_offset;
	size_t cam_size;
	long unsigned int fifo_offset;
	size_t fifo_size;
	u32 liodn_base[64];
	u32 liodn_offset[64];
	struct fman_dts_params dts_params;
};

struct fman_mac_params___2 {
	void *base_addr;
	enet_addr_t addr;
	u8 mac_id;
	phy_interface_t phy_if;
	u16 max_speed;
	void *fm;
	void *dev_id;
	fman_mac_exception_cb *event_cb;
	fman_mac_exception_cb *exception_cb;
	bool basex_if;
	struct device_node___75 *internal_phy_node;
};

struct mac_addr {
	u32 mac_addr_l;
	u32 mac_addr_u;
};

struct memac_regs {
	u32 res0000[2];
	u32 command_config;
	struct mac_addr mac_addr0;
	u32 maxfrm;
	u32 res0018[1];
	u32 rx_fifo_sections;
	u32 tx_fifo_sections;
	u32 res0024[2];
	u32 hashtable_ctrl;
	u32 res0030[4];
	u32 ievent;
	u32 tx_ipg_length;
	u32 res0048;
	u32 imask;
	u32 res0050;
	u32 pause_quanta[4];
	u32 pause_thresh[4];
	u32 rx_pause_status;
	u32 res0078[2];
	struct mac_addr mac_addr[7];
	u32 lpwake_timer;
	u32 sleep_timer;
	u32 res00c0[8];
	u32 statn_config;
	u32 res00e4[7];
	u32 reoct_l;
	u32 reoct_u;
	u32 roct_l;
	u32 roct_u;
	u32 raln_l;
	u32 raln_u;
	u32 rxpf_l;
	u32 rxpf_u;
	u32 rfrm_l;
	u32 rfrm_u;
	u32 rfcs_l;
	u32 rfcs_u;
	u32 rvlan_l;
	u32 rvlan_u;
	u32 rerr_l;
	u32 rerr_u;
	u32 ruca_l;
	u32 ruca_u;
	u32 rmca_l;
	u32 rmca_u;
	u32 rbca_l;
	u32 rbca_u;
	u32 rdrp_l;
	u32 rdrp_u;
	u32 rpkt_l;
	u32 rpkt_u;
	u32 rund_l;
	u32 rund_u;
	u32 r64_l;
	u32 r64_u;
	u32 r127_l;
	u32 r127_u;
	u32 r255_l;
	u32 r255_u;
	u32 r511_l;
	u32 r511_u;
	u32 r1023_l;
	u32 r1023_u;
	u32 r1518_l;
	u32 r1518_u;
	u32 r1519x_l;
	u32 r1519x_u;
	u32 rovr_l;
	u32 rovr_u;
	u32 rjbr_l;
	u32 rjbr_u;
	u32 rfrg_l;
	u32 rfrg_u;
	u32 rcnp_l;
	u32 rcnp_u;
	u32 rdrntp_l;
	u32 rdrntp_u;
	u32 res01d0[12];
	u32 teoct_l;
	u32 teoct_u;
	u32 toct_l;
	u32 toct_u;
	u32 res0210[2];
	u32 txpf_l;
	u32 txpf_u;
	u32 tfrm_l;
	u32 tfrm_u;
	u32 tfcs_l;
	u32 tfcs_u;
	u32 tvlan_l;
	u32 tvlan_u;
	u32 terr_l;
	u32 terr_u;
	u32 tuca_l;
	u32 tuca_u;
	u32 tmca_l;
	u32 tmca_u;
	u32 tbca_l;
	u32 tbca_u;
	u32 res0258[2];
	u32 tpkt_l;
	u32 tpkt_u;
	u32 tund_l;
	u32 tund_u;
	u32 t64_l;
	u32 t64_u;
	u32 t127_l;
	u32 t127_u;
	u32 t255_l;
	u32 t255_u;
	u32 t511_l;
	u32 t511_u;
	u32 t1023_l;
	u32 t1023_u;
	u32 t1518_l;
	u32 t1518_u;
	u32 t1519x_l;
	u32 t1519x_u;
	u32 res02a8[6];
	u32 tcnp_l;
	u32 tcnp_u;
	u32 res02c8[14];
	u32 if_mode;
	u32 if_status;
	u32 res0308[14];
	u32 hg_config;
	u32 res0344[3];
	u32 hg_pause_quanta;
	u32 res0354[3];
	u32 hg_pause_thresh;
	u32 res0364[3];
	u32 hgrx_pause_status;
	u32 hg_fifos_status;
	u32 rhm;
	u32 thm;
};

struct memac_cfg {
	bool reset_on_init;
	bool pause_ignore;
	bool promiscuous_mode_enable;
	struct fixed_phy_status *fixed_link;
	u16 max_frame_length;
	u16 pause_quanta;
	u32 tx_ipg_length;
};

struct fman_mac___3 {
	struct memac_regs *regs;
	u64 addr;
	phy_interface_t phy_if;
	u16 max_speed;
	void *dev_id;
	fman_mac_exception_cb *exception_cb;
	fman_mac_exception_cb *event_cb;
	struct eth_hash_t *multicast_addr_hash;
	struct eth_hash_t *unicast_addr_hash;
	u8 mac_id;
	u32 exceptions;
	struct memac_cfg *memac_drv_param;
	void *fm;
	struct fman_rev_info fm_rev_info;
	bool basex_if;
	struct phy_device___2 *pcsphy;
	bool allmulti_enabled;
};

struct fman___4;

typedef irqreturn_t fman_exceptions_cb___4(struct fman___4 *, enum fman_exceptions);

typedef irqreturn_t fman_bus_error_cb___4(struct fman___4 *, u8, u64, u8, u16);

struct fman___4 {
	struct device___190 *dev;
	void *base_addr;
	struct fman_intr_src intr_mng[24];
	struct fman_fpm_regs *fpm_regs;
	struct fman_bmi_regs *bmi_regs;
	struct fman_qmi_regs *qmi_regs;
	struct fman_dma_regs *dma_regs;
	struct fman_hwp_regs *hwp_regs;
	struct fman_kg_regs *kg_regs;
	fman_exceptions_cb___4 *exception_cb;
	fman_bus_error_cb___4 *bus_error_cb;
	spinlock_t spinlock;
	struct fman_state_struct *state;
	struct fman_cfg *cfg;
	struct muram_info___2 *muram;
	struct fman_keygen *keygen;
	long unsigned int cam_offset;
	size_t cam_size;
	long unsigned int fifo_offset;
	size_t fifo_size;
	u32 liodn_base[64];
	u32 liodn_offset[64];
	struct fman_dts_params dts_params;
};

struct fman_mac_params___3 {
	void *base_addr;
	enet_addr_t addr;
	u8 mac_id;
	phy_interface_t phy_if;
	u16 max_speed;
	void *fm;
	void *dev_id;
	fman_mac_exception_cb *event_cb;
	fman_mac_exception_cb *exception_cb;
	bool basex_if;
	struct device_node___82 *internal_phy_node;
};

struct tgec_regs {
	u32 tgec_id;
	u32 reserved001[1];
	u32 command_config;
	u32 mac_addr_0;
	u32 mac_addr_1;
	u32 maxfrm;
	u32 pause_quant;
	u32 rx_fifo_sections;
	u32 tx_fifo_sections;
	u32 rx_fifo_almost_f_e;
	u32 tx_fifo_almost_f_e;
	u32 hashtable_ctrl;
	u32 mdio_cfg_status;
	u32 mdio_command;
	u32 mdio_data;
	u32 mdio_regaddr;
	u32 status;
	u32 tx_ipg_len;
	u32 mac_addr_2;
	u32 mac_addr_3;
	u32 rx_fifo_ptr_rd;
	u32 rx_fifo_ptr_wr;
	u32 tx_fifo_ptr_rd;
	u32 tx_fifo_ptr_wr;
	u32 imask;
	u32 ievent;
	u32 udp_port;
	u32 type_1588v2;
	u32 reserved070[4];
	u32 tfrm_u;
	u32 tfrm_l;
	u32 rfrm_u;
	u32 rfrm_l;
	u32 rfcs_u;
	u32 rfcs_l;
	u32 raln_u;
	u32 raln_l;
	u32 txpf_u;
	u32 txpf_l;
	u32 rxpf_u;
	u32 rxpf_l;
	u32 rlong_u;
	u32 rlong_l;
	u32 rflr_u;
	u32 rflr_l;
	u32 tvlan_u;
	u32 tvlan_l;
	u32 rvlan_u;
	u32 rvlan_l;
	u32 toct_u;
	u32 toct_l;
	u32 roct_u;
	u32 roct_l;
	u32 ruca_u;
	u32 ruca_l;
	u32 rmca_u;
	u32 rmca_l;
	u32 rbca_u;
	u32 rbca_l;
	u32 terr_u;
	u32 terr_l;
	u32 reserved100[2];
	u32 tuca_u;
	u32 tuca_l;
	u32 tmca_u;
	u32 tmca_l;
	u32 tbca_u;
	u32 tbca_l;
	u32 rdrp_u;
	u32 rdrp_l;
	u32 reoct_u;
	u32 reoct_l;
	u32 rpkt_u;
	u32 rpkt_l;
	u32 trund_u;
	u32 trund_l;
	u32 r64_u;
	u32 r64_l;
	u32 r127_u;
	u32 r127_l;
	u32 r255_u;
	u32 r255_l;
	u32 r511_u;
	u32 r511_l;
	u32 r1023_u;
	u32 r1023_l;
	u32 r1518_u;
	u32 r1518_l;
	u32 r1519x_u;
	u32 r1519x_l;
	u32 trovr_u;
	u32 trovr_l;
	u32 trjbr_u;
	u32 trjbr_l;
	u32 trfrg_u;
	u32 trfrg_l;
	u32 rerr_u;
	u32 rerr_l;
};

struct tgec_cfg {
	bool pause_ignore;
	bool promiscuous_mode_enable;
	u16 max_frame_length;
	u16 pause_quant;
	u32 tx_ipg_length;
};

struct fman_mac___4 {
	struct tgec_regs *regs;
	u64 addr;
	u16 max_speed;
	void *dev_id;
	fman_mac_exception_cb *exception_cb;
	fman_mac_exception_cb *event_cb;
	struct eth_hash_t *multicast_addr_hash;
	struct eth_hash_t *unicast_addr_hash;
	u8 mac_id;
	u32 exceptions;
	struct tgec_cfg *cfg;
	void *fm;
	struct fman_rev_info fm_rev_info;
	bool allmulti_enabled;
};

struct mii_if_info___2 {
	int phy_id;
	int advertising;
	int phy_id_mask;
	int reg_num_mask;
	unsigned int full_duplex: 1;
	unsigned int force_media: 1;
	unsigned int supports_gmii: 1;
	long: 63;
	long: 64;
	long: 64;
	struct net_device___43 *dev;
	int (*mdio_read)(struct net_device___43 *, int, int);
	void (*mdio_write)(struct net_device___43 *, int, int, int);
};

struct dma_router___9 {
	struct device___201 *dev;
	void (*route_free)(struct device___201 *, void *);
};

struct dma_device___9;

struct dma_chan_dev___9;

struct dma_chan___9 {
	struct dma_device___9 *device;
	struct device___201 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___9 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___9 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___9)(struct dma_chan___9 *, void *);

struct dma_filter___9 {
	dma_filter_fn___9 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___9;

struct dma_device___9 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___9 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___201 *dev;
	struct module___207 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___9 *);
	int (*device_router_config)(struct dma_chan___9 *);
	void (*device_free_chan_resources)(struct dma_chan___9 *);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memcpy)(struct dma_chan___9 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_xor)(struct dma_chan___9 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_xor_val)(struct dma_chan___9 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_pq)(struct dma_chan___9 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_pq_val)(struct dma_chan___9 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memset)(struct dma_chan___9 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_memset_sg)(struct dma_chan___9 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_interrupt)(struct dma_chan___9 *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_slave_sg)(struct dma_chan___9 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_cyclic)(struct dma_chan___9 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_interleaved_dma)(struct dma_chan___9 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___9 * (*device_prep_dma_imm_data)(struct dma_chan___9 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___9 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___9 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___9 *);
	int (*device_resume)(struct dma_chan___9 *);
	int (*device_terminate_all)(struct dma_chan___9 *);
	void (*device_synchronize)(struct dma_chan___9 *);
	enum dma_status (*device_tx_status)(struct dma_chan___9 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___9 *);
	void (*device_release)(struct dma_device___9 *);
	void (*dbg_summary_show)(struct seq_file___198 *, struct dma_device___9 *);
	struct dentry___223 *dbg_dev_root;
};

struct dma_chan_dev___9 {
	struct dma_chan___9 *chan;
	struct device___201 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___9 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___201 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___9 {
	int (*attach)(struct dma_async_tx_descriptor___9 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___9 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___9 *, size_t);
};

struct dma_async_tx_descriptor___9 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___9 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___9 *);
	int (*desc_free)(struct dma_async_tx_descriptor___9 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___9 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___9 *metadata_ops;
	struct dma_async_tx_descriptor___9 *next;
	struct dma_async_tx_descriptor___9 *parent;
	spinlock_t lock;
};

struct smc91x_platdata {
	long unsigned int flags;
	unsigned char leda;
	unsigned char ledb;
	bool pxa_u16_align4;
};

struct smc_local {
	struct sk_buff___42 *pending_tx_skb;
	struct tasklet_struct tx_task;
	struct gpio_desc *power_gpio;
	struct gpio_desc *reset_gpio;
	int version;
	int tcr_cur_mode;
	int rcr_cur_mode;
	int rpc_cur_mode;
	int ctl_rfduplx;
	int ctl_rspeed;
	u32 msg_enable;
	u32 phy_type;
	struct mii_if_info___2 mii;
	struct work_struct phy_configure;
	struct net_device___43 *dev;
	int work_pending;
	spinlock_t lock;
	struct dma_chan___9 *dma_chan;
	void *base;
	void *datacs;
	int io_shift;
	bool half_word_align4;
	struct smc91x_platdata cfg;
};

struct mdio_platform_data {
	long unsigned int bus_freq;
};

struct davinci_mdio_of_param {
	int autosuspend_delay_ms;
};

struct davinci_mdio_regs {
	u32 version;
	u32 control;
	u32 alive;
	u32 link;
	u32 linkintraw;
	u32 linkintmasked;
	u32 __reserved_0[2];
	u32 userintraw;
	u32 userintmasked;
	u32 userintmaskset;
	u32 userintmaskclr;
	u32 __reserved_1[20];
	struct {
		u32 access;
		u32 physel;
	} user[0];
};

struct davinci_mdio_data {
	struct mdio_platform_data pdata;
	struct davinci_mdio_regs *regs;
	struct clk *clk;
	struct device___203 *dev;
	struct mii_bus___2 *bus;
	bool active_in_suspend;
	long unsigned int access_time;
	bool skip_scan;
	u32 clk_div;
};

struct dentry___227;

struct super_block___227;

struct module___211;

struct file_system_type___227 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___227 * (*mount)(struct file_system_type___227 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___227 *);
	struct module___211 *owner;
	struct file_system_type___227 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___227;

struct kiocb___227;

struct iov_iter___147;

struct poll_table_struct___152;

struct vm_area_struct___232;

struct inode___227;

struct file_lock___227;

struct page___232;

struct pipe_inode_info___77;

struct seq_file___202;

struct file_operations___228 {
	struct module___211 *owner;
	loff_t (*llseek)(struct file___227 *, loff_t, int);
	ssize_t (*read)(struct file___227 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___227 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___227 *, struct iov_iter___147 *);
	ssize_t (*write_iter)(struct kiocb___227 *, struct iov_iter___147 *);
	int (*iopoll)(struct kiocb___227 *, bool);
	int (*iterate)(struct file___227 *, struct dir_context *);
	int (*iterate_shared)(struct file___227 *, struct dir_context *);
	__poll_t (*poll)(struct file___227 *, struct poll_table_struct___152 *);
	long int (*unlocked_ioctl)(struct file___227 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___227 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___227 *, struct vm_area_struct___232 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___227 *, struct file___227 *);
	int (*flush)(struct file___227 *, fl_owner_t);
	int (*release)(struct inode___227 *, struct file___227 *);
	int (*fsync)(struct file___227 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___227 *, int);
	int (*lock)(struct file___227 *, int, struct file_lock___227 *);
	ssize_t (*sendpage)(struct file___227 *, struct page___232 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___227 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___227 *, long unsigned int);
	int (*flock)(struct file___227 *, int, struct file_lock___227 *);
	ssize_t (*splice_write)(struct pipe_inode_info___77 *, struct file___227 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___227 *, loff_t *, struct pipe_inode_info___77 *, size_t, unsigned int);
	int (*setlease)(struct file___227 *, long int, struct file_lock___227 **, void **);
	long int (*fallocate)(struct file___227 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___202 *, struct file___227 *);
	ssize_t (*copy_file_range)(struct file___227 *, loff_t, struct file___227 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___227 *, loff_t, struct file___227 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___227 *, loff_t, loff_t, int);
};

struct vmacache___232 {
	u64 seqnum;
	struct vm_area_struct___232 *vmas[4];
};

struct page_frag___232 {
	struct page___232 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___233;

struct pid___204;

struct nsproxy___213;

struct signal_struct___228;

struct bio_list___120;

struct backing_dev_info___109;

struct io_context___120;

struct css_set___157;

struct mem_cgroup___100;

struct request_queue___120;

struct uprobe_task___4;

struct vm_struct___210;

struct task_struct___234 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___234 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___233 *mm;
	struct mm_struct___233 *active_mm;
	struct vmacache___232 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___234 *real_parent;
	struct task_struct___234 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___234 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___204 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___213 *nsproxy;
	struct signal_struct___228 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___234 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___120 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___109 *backing_dev_info;
	struct io_context___120 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___157 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___77 *splice_pipe;
	struct page_frag___232 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___100 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___100 *active_memcg;
	struct request_queue___120 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___234 *oom_reaper_list;
	struct vm_struct___210 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___215;

struct kobj_type___215;

struct kernfs_node___215;

struct kobject___215 {
	const char *name;
	struct list_head entry;
	struct kobject___215 *parent;
	struct kset___215 *kset;
	struct kobj_type___215 *ktype;
	struct kernfs_node___215 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___212 {
	struct kobject___215 kobj;
	struct module___211 *mod;
	struct kobject___215 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___211 {
	struct module___211 *mod;
	struct latch_tree_node node;
};

struct module_layout___211 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___211 mtn;
};

struct module_attribute___211;

struct kernel_param___211;

struct module___211 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___212 mkobj;
	struct module_attribute___211 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___215 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___211 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___211 core_layout;
	struct module_layout___211 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___204;

struct upid___204 {
	int nr;
	struct pid_namespace___204 *ns;
};

struct pid_namespace___204 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___234 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___204 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___204 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___204 numbers[1];
};

typedef struct page___232 *pgtable_t___232;

struct address_space___227;

struct page_pool___65;

struct dev_pagemap___222;

struct page___232 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___227 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___65 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___232 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___232 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___233 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___222 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___222;

struct vm_area_struct___232 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___232 *vm_next;
	struct vm_area_struct___232 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___233 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___222 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___227 *vm_file;
	struct file___227 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___228 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___234 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___234 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___204 *pids[4];
	struct pid___204 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___233 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___232;

struct mm_struct___233 {
	struct {
		struct vm_area_struct___232 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___227 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___232 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___234 *owner;
		struct user_namespace___14 *user_ns;
		struct file___227 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___50;

struct cgroup_namespace___157;

struct nsproxy___213 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___204 *pid_ns_for_children;
	struct net___50 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___157 *cgroup_ns;
};

struct bio___120;

struct bio_list___120 {
	struct bio___120 *head;
	struct bio___120 *tail;
};

struct cgroup_subsys_state___157;

struct bdi_writeback___109 {
	struct backing_dev_info___109 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___157 *memcg_css;
	struct cgroup_subsys_state___157 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___205;

struct backing_dev_info___109 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___109 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___205 *dev;
	char dev_name[64];
	struct device___205 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___227 *debug_dir;
};

struct io_cq___120;

struct io_context___120 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___120 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___157;

struct css_set___157 {
	struct cgroup_subsys_state___157 *subsys[14];
	refcount_t refcount;
	struct css_set___157 *dom_cset;
	struct cgroup___157 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___157 *mg_src_cgrp;
	struct cgroup___157 *mg_dst_cgrp;
	struct css_set___157 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___227;

struct pipe_buffer___77;

struct pipe_inode_info___77 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___232 *tmp_page;
	struct fasync_struct___227 *fasync_readers;
	struct fasync_struct___227 *fasync_writers;
	struct pipe_buffer___77 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___157;

struct cgroup_subsys_state___157 {
	struct cgroup___157 *cgroup;
	struct cgroup_subsys___157 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___157 *parent;
};

struct cgroup_file___157 {
	struct kernfs_node___215 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___100;

struct mem_cgroup_per_node___100;

struct mem_cgroup___100 {
	struct cgroup_subsys_state___157 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___157 events_file;
	struct cgroup_file___157 events_local_file;
	struct cgroup_file___157 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___100 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___234 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___100 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___120;

struct blk_integrity___120 {
	const struct blk_integrity_profile___120 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___120 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___120 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___120;

struct elevator_queue___120;

struct blk_mq_ops___117;

struct blk_mq_hw_ctx___117;

struct gendisk___123;

struct blkcg_gq___111;

struct blk_mq_tag_set___117;

struct request_queue___120 {
	struct request___120 *last_merge;
	struct elevator_queue___120 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___117 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___117 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___123 *disk;
	struct kobject___215 kobj;
	struct kobject___215 *mq_kobj;
	struct blk_integrity___120 integrity;
	struct device___205 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___111 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___117 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___120 bio_split;
	struct dentry___227 *debugfs_dir;
	struct dentry___227 *sched_debugfs_dir;
	struct dentry___227 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct uprobe_task___4 {
	enum uprobe_task_state state;
	union {
		struct {
			struct arch_uprobe_task autask;
			long unsigned int vaddr;
		};
		struct {
			struct callback_head dup_xol_work;
			long unsigned int dup_xol_addr;
		};
	};
	struct uprobe *active_uprobe;
	long unsigned int xol_vaddr;
	struct return_instance *return_instances;
	unsigned int depth;
};

struct vm_struct___210 {
	struct vm_struct___210 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___232 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___227;

struct address_space___227 {
	struct inode___227 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___227 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___65 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___205 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___65 {
	u32 count;
	struct page___232 *cache[128];
};

struct page_pool___65 {
	struct page_pool_params___65 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___232 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___65 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___222;

struct dev_pagemap___222 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___222 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___227;

struct path___227 {
	struct vfsmount___227 *mnt;
	struct dentry___227 *dentry;
};

struct fown_struct___204 {
	rwlock_t lock;
	struct pid___204 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___227 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___227 f_path;
	struct inode___227 *f_inode;
	const struct file_operations___228 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___204 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___227 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___222;

struct vm_operations_struct___222 {
	void (*open)(struct vm_area_struct___232 *);
	void (*close)(struct vm_area_struct___232 *);
	int (*may_split)(struct vm_area_struct___232 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___232 *);
	int (*mprotect)(struct vm_area_struct___232 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___222 *);
	vm_fault_t (*huge_fault)(struct vm_fault___222 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___222 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___232 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___222 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___222 *);
	int (*access)(struct vm_area_struct___232 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___232 *);
	int (*set_policy)(struct vm_area_struct___232 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___232 *, long unsigned int);
	struct page___232 * (*find_special_page)(struct vm_area_struct___232 *, long unsigned int);
};

struct core_thread___232 {
	struct task_struct___234 *task;
	struct core_thread___232 *next;
};

struct core_state___232 {
	atomic_t nr_threads;
	struct core_thread___232 dumper;
	struct completion startup;
};

struct vm_fault___222 {
	const struct {
		struct vm_area_struct___232 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___232 *cow_page;
	struct page___232 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___232 prealloc_pte;
};

struct pglist_data___108;

struct lruvec___108 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___108 *pgdat;
};

struct zone___108 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___108 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___108 {
	struct zone___108 *zone;
	int zone_idx;
};

struct zonelist___108 {
	struct zoneref___108 _zonerefs[321];
};

struct pglist_data___108 {
	struct zone___108 node_zones[5];
	struct zonelist___108 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___234 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___234 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___108 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___227;

struct dentry___227 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___227 *d_parent;
	struct qstr d_name;
	struct inode___227 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___227 *d_op;
	struct super_block___227 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___227;

struct inode___227 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___227 *i_op;
	struct super_block___227 *i_sb;
	struct address_space___227 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___109 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___228 *i_fop;
		void (*free_inode)(struct inode___227 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___227 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___77 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___227 {
	int (*d_revalidate)(struct dentry___227 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___227 *, unsigned int);
	int (*d_hash)(const struct dentry___227 *, struct qstr *);
	int (*d_compare)(const struct dentry___227 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___227 *);
	int (*d_init)(struct dentry___227 *);
	void (*d_release)(struct dentry___227 *);
	void (*d_prune)(struct dentry___227 *);
	void (*d_iput)(struct dentry___227 *, struct inode___227 *);
	char * (*d_dname)(struct dentry___227 *, char *, int);
	struct vfsmount___227 * (*d_automount)(struct path___227 *);
	int (*d_manage)(const struct path___227 *, bool);
	struct dentry___227 * (*d_real)(struct dentry___227 *, const struct inode___227 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___227;

struct mem_dqinfo___227 {
	struct quota_format_type___227 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___227;

struct quota_info___227 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___227 *files[3];
	struct mem_dqinfo___227 info[3];
	const struct quota_format_ops___227 *ops[3];
};

struct rcuwait___228 {
	struct task_struct___234 *task;
};

struct percpu_rw_semaphore___228 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___228 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___227 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___228 rw_sem[3];
};

struct shrink_control___100;

struct shrinker___100 {
	long unsigned int (*count_objects)(struct shrinker___100 *, struct shrink_control___100 *);
	long unsigned int (*scan_objects)(struct shrinker___100 *, struct shrink_control___100 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___227;

struct dquot_operations___227;

struct quotactl_ops___227;

struct block_device___123;

struct super_block___227 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___227 *s_type;
	const struct super_operations___227 *s_op;
	const struct dquot_operations___227 *dq_op;
	const struct quotactl_ops___227 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___227 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___123 *s_bdev;
	struct backing_dev_info___109 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___227 s_dquot;
	struct sb_writers___227 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___227 *s_d_op;
	int cleancache_poolid;
	struct shrinker___100 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___227 {
	struct dentry___227 *mnt_root;
	struct super_block___227 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___100 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___100 *memcg;
};

struct psi_group___157 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___234 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___41;

struct cgroup_bpf___41 {
	struct bpf_prog_array___41 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___41 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___157;

struct cgroup_rstat_cpu___157;

struct cgroup___157 {
	struct cgroup_subsys_state___157 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___215 *kn;
	struct cgroup_file___157 procs_file;
	struct cgroup_file___157 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___157 *subsys[14];
	struct cgroup_root___157 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___157 *dom_cgrp;
	struct cgroup___157 *old_dom_cgrp;
	struct cgroup_rstat_cpu___157 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___157 psi;
	struct cgroup_bpf___41 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___120 {
	struct request_queue___120 *q;
	struct io_context___120 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___227 {
	struct file___227 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___227 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___106 *ki_waitq;
	};
};

struct iattr___227 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___227 *ia_file;
};

struct dquot___227 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___227 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___227 {
	int qf_fmt_id;
	const struct quota_format_ops___227 *qf_ops;
	struct module___211 *qf_owner;
	struct quota_format_type___227 *qf_next;
};

struct quota_format_ops___227 {
	int (*check_quota_file)(struct super_block___227 *, int);
	int (*read_file_info)(struct super_block___227 *, int);
	int (*write_file_info)(struct super_block___227 *, int);
	int (*free_file_info)(struct super_block___227 *, int);
	int (*read_dqblk)(struct dquot___227 *);
	int (*commit_dqblk)(struct dquot___227 *);
	int (*release_dqblk)(struct dquot___227 *);
	int (*get_next_id)(struct super_block___227 *, struct kqid *);
};

struct dquot_operations___227 {
	int (*write_dquot)(struct dquot___227 *);
	struct dquot___227 * (*alloc_dquot)(struct super_block___227 *, int);
	void (*destroy_dquot)(struct dquot___227 *);
	int (*acquire_dquot)(struct dquot___227 *);
	int (*release_dquot)(struct dquot___227 *);
	int (*mark_dirty)(struct dquot___227 *);
	int (*write_info)(struct super_block___227 *, int);
	qsize_t * (*get_reserved_space)(struct inode___227 *);
	int (*get_projid)(struct inode___227 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___227 *, qsize_t *);
	int (*get_next_id)(struct super_block___227 *, struct kqid *);
};

struct quotactl_ops___227 {
	int (*quota_on)(struct super_block___227 *, int, int, const struct path___227 *);
	int (*quota_off)(struct super_block___227 *, int);
	int (*quota_enable)(struct super_block___227 *, unsigned int);
	int (*quota_disable)(struct super_block___227 *, unsigned int);
	int (*quota_sync)(struct super_block___227 *, int);
	int (*set_info)(struct super_block___227 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___227 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___227 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___227 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___227 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___227 *, unsigned int);
};

struct writeback_control___109;

struct address_space_operations___227 {
	int (*writepage)(struct page___232 *, struct writeback_control___109 *);
	int (*readpage)(struct file___227 *, struct page___232 *);
	int (*writepages)(struct address_space___227 *, struct writeback_control___109 *);
	int (*set_page_dirty)(struct page___232 *);
	int (*readpages)(struct file___227 *, struct address_space___227 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___227 *, struct address_space___227 *, loff_t, unsigned int, unsigned int, struct page___232 **, void **);
	int (*write_end)(struct file___227 *, struct address_space___227 *, loff_t, unsigned int, unsigned int, struct page___232 *, void *);
	sector_t (*bmap)(struct address_space___227 *, sector_t);
	void (*invalidatepage)(struct page___232 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___232 *, gfp_t);
	void (*freepage)(struct page___232 *);
	ssize_t (*direct_IO)(struct kiocb___227 *, struct iov_iter___147 *);
	int (*migratepage)(struct address_space___227 *, struct page___232 *, struct page___232 *, enum migrate_mode);
	bool (*isolate_page)(struct page___232 *, isolate_mode_t);
	void (*putback_page)(struct page___232 *);
	int (*launder_page)(struct page___232 *);
	int (*is_partially_uptodate)(struct page___232 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___232 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___227 *, struct page___232 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___227 *, sector_t *);
	void (*swap_deactivate)(struct file___227 *);
};

struct writeback_control___109 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___109 *wb;
	struct inode___227 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___144;

struct iov_iter___147 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___144 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___77 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___227 {
	struct dentry___227 * (*lookup)(struct inode___227 *, struct dentry___227 *, unsigned int);
	const char * (*get_link)(struct dentry___227 *, struct inode___227 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___227 *, int);
	struct posix_acl * (*get_acl)(struct inode___227 *, int, bool);
	int (*readlink)(struct dentry___227 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___227 *, struct dentry___227 *, umode_t, bool);
	int (*link)(struct dentry___227 *, struct inode___227 *, struct dentry___227 *);
	int (*unlink)(struct inode___227 *, struct dentry___227 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___227 *, struct dentry___227 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___227 *, struct dentry___227 *, umode_t);
	int (*rmdir)(struct inode___227 *, struct dentry___227 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___227 *, struct dentry___227 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___227 *, struct dentry___227 *, struct inode___227 *, struct dentry___227 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___227 *, struct iattr___227 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___227 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___227 *, char *, size_t);
	int (*fiemap)(struct inode___227 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___227 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___227 *, struct dentry___227 *, struct file___227 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___227 *, struct dentry___227 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___227 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___227 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___227 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___227 {
	void (*fl_copy_lock)(struct file_lock___227 *, struct file_lock___227 *);
	void (*fl_release_private)(struct file_lock___227 *);
};

struct lock_manager_operations___227;

struct file_lock___227 {
	struct file_lock___227 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___227 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___227 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___227 *fl_ops;
	const struct lock_manager_operations___227 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___227 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___227 *);
	int (*lm_grant)(struct file_lock___227 *, int);
	bool (*lm_break)(struct file_lock___227 *);
	int (*lm_change)(struct file_lock___227 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___227 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___227 *);
};

struct fasync_struct___227 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___227 *fa_next;
	struct file___227 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___227 {
	struct inode___227 * (*alloc_inode)(struct super_block___227 *);
	void (*destroy_inode)(struct inode___227 *);
	void (*free_inode)(struct inode___227 *);
	void (*dirty_inode)(struct inode___227 *, int);
	int (*write_inode)(struct inode___227 *, struct writeback_control___109 *);
	int (*drop_inode)(struct inode___227 *);
	void (*evict_inode)(struct inode___227 *);
	void (*put_super)(struct super_block___227 *);
	int (*sync_fs)(struct super_block___227 *, int);
	int (*freeze_super)(struct super_block___227 *);
	int (*freeze_fs)(struct super_block___227 *);
	int (*thaw_super)(struct super_block___227 *);
	int (*unfreeze_fs)(struct super_block___227 *);
	int (*statfs)(struct dentry___227 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___227 *, int *, char *);
	void (*umount_begin)(struct super_block___227 *);
	int (*show_options)(struct seq_file___202 *, struct dentry___227 *);
	int (*show_devname)(struct seq_file___202 *, struct dentry___227 *);
	int (*show_path)(struct seq_file___202 *, struct dentry___227 *);
	int (*show_stats)(struct seq_file___202 *, struct dentry___227 *);
	ssize_t (*quota_read)(struct super_block___227 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___227 *, int, const char *, size_t, loff_t);
	struct dquot___227 ** (*get_dquots)(struct inode___227 *);
	long int (*nr_cached_objects)(struct super_block___227 *, struct shrink_control___100 *);
	long int (*free_cached_objects)(struct super_block___227 *, struct shrink_control___100 *);
	struct file___227 * (*real_loop)(struct file___227 *);
};

struct wakeup_source___205;

struct dev_pm_info___205 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___205 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___205 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___205;

struct bus_type___205;

struct device_driver___205;

struct dev_pm_domain___205;

struct fwnode_handle___201;

struct class___205;

struct attribute_group___215;

struct device___205 {
	struct kobject___215 kobj;
	struct device___205 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___205 *type;
	struct bus_type___205 *bus;
	struct device_driver___205 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___205 power;
	struct dev_pm_domain___205 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___201 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___205 *class;
	const struct attribute_group___215 **groups;
	void (*release)(struct device___205 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___123 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___227 *bd_inode;
	struct super_block___227 *bd_super;
	void *bd_claiming;
	struct device___205 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___215 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___123 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___227 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___159)(struct file___227 *, wait_queue_head_t *, struct poll_table_struct___152 *);

struct poll_table_struct___152 {
	poll_queue_proc___159 _qproc;
	__poll_t _key;
};

struct seq_operations___202;

struct seq_file___202 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___202 *op;
	int poll_event;
	const struct file___227 *file;
	void *private;
};

typedef void bio_end_io_t___120(struct bio___120 *);

struct bio_vec___144 {
	struct page___232 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___120;

struct bio___120 {
	struct bio___120 *bi_next;
	struct block_device___123 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___120 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___111 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___120 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___144 *bi_io_vec;
	struct bio_set___120 *bi_pool;
	struct bio_vec___144 bi_inline_vecs[0];
};

struct kernfs_root___215;

struct kernfs_elem_dir___215 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___215 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___215;

struct kernfs_root___215 {
	struct kernfs_node___215 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___215 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___215 {
	struct kernfs_node___215 *target_kn;
};

struct kernfs_ops___215;

struct kernfs_elem_attr___215 {
	const struct kernfs_ops___215 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___215 *notify_next;
};

struct kernfs_node___215 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___215 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___215 dir;
		struct kernfs_elem_symlink___215 symlink;
		struct kernfs_elem_attr___215 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___215;

struct kernfs_ops___215 {
	int (*open)(struct kernfs_open_file___215 *);
	void (*release)(struct kernfs_open_file___215 *);
	int (*seq_show)(struct seq_file___202 *, void *);
	void * (*seq_start)(struct seq_file___202 *, loff_t *);
	void * (*seq_next)(struct seq_file___202 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___202 *, void *);
	ssize_t (*read)(struct kernfs_open_file___215 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___215 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___215 *, struct poll_table_struct___152 *);
	int (*mmap)(struct kernfs_open_file___215 *, struct vm_area_struct___232 *);
};

struct kernfs_syscall_ops___215 {
	int (*show_options)(struct seq_file___202 *, struct kernfs_root___215 *);
	int (*mkdir)(struct kernfs_node___215 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___215 *);
	int (*rename)(struct kernfs_node___215 *, struct kernfs_node___215 *, const char *);
	int (*show_path)(struct seq_file___202 *, struct kernfs_node___215 *, struct kernfs_root___215 *);
};

struct kernfs_open_file___215 {
	struct kernfs_node___215 *kn;
	struct file___227 *file;
	struct seq_file___202 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___222 *vm_ops;
};

struct sock___35;

struct kobj_ns_type_operations___34 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___35 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___50 *net;
} possible_net_t___45;

struct proto___34;

struct sock_common___34 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___34 *skc_prot;
	possible_net_t___45 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___35 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___46;

struct sk_buff_head___45 {
	struct sk_buff___46 *next;
	struct sk_buff___46 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___34 {
	struct cgroup___157 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___34;

struct socket_wq___35;

struct dst_entry___34;

struct socket___36;

struct net_device___47;

struct sock___35 {
	struct sock_common___34 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___45 sk_error_queue;
	struct sk_buff___46 *sk_rx_skb_cache;
	struct sk_buff_head___45 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___46 *head;
		struct sk_buff___46 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___34 *sk_filter;
	union {
		struct socket_wq___35 *sk_wq;
		struct socket_wq___35 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___34 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___34 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___46 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___46 *sk_tx_skb_cache;
	struct sk_buff_head___45 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___232 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___34 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___204 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___36 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___34 sk_cgrp_data;
	struct mem_cgroup___100 *sk_memcg;
	void (*sk_state_change)(struct sock___35 *);
	void (*sk_data_ready)(struct sock___35 *);
	void (*sk_write_space)(struct sock___35 *);
	void (*sk_error_report)(struct sock___35 *);
	int (*sk_backlog_rcv)(struct sock___35 *, struct sk_buff___46 *);
	struct sk_buff___46 * (*sk_validate_xmit_skb)(struct sock___35 *, struct net_device___47 *, struct sk_buff___46 *);
	void (*sk_destruct)(struct sock___35 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___215;

struct attribute_group___215 {
	const char *name;
	umode_t (*is_visible)(struct kobject___215 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___215 *, struct bin_attribute___215 *, int);
	struct attribute **attrs;
	struct bin_attribute___215 **bin_attrs;
};

struct bin_attribute___215 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___227 * (*f_mapping)();
	ssize_t (*read)(struct file___227 *, struct kobject___215 *, struct bin_attribute___215 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___227 *, struct kobject___215 *, struct bin_attribute___215 *, char *, loff_t, size_t);
	int (*mmap)(struct file___227 *, struct kobject___215 *, struct bin_attribute___215 *, struct vm_area_struct___232 *);
};

struct sysfs_ops___215 {
	ssize_t (*show)(struct kobject___215 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___215 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___215;

struct kset___215 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___215 kobj;
	const struct kset_uevent_ops___215 *uevent_ops;
};

struct kobj_type___215 {
	void (*release)(struct kobject___215 *);
	const struct sysfs_ops___215 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___215 **default_groups;
	const struct kobj_ns_type_operations___34 * (*child_ns_type)(struct kobject___215 *);
	const void * (*namespace)(struct kobject___215 *);
	void (*get_ownership)(struct kobject___215 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___215 {
	int (* const filter)(struct kset___215 *, struct kobject___215 *);
	const char * (* const name)(struct kset___215 *, struct kobject___215 *);
	int (* const uevent)(struct kset___215 *, struct kobject___215 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___211 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___211 *);
	int (*get)(char *, const struct kernel_param___211 *);
	void (*free)(void *);
};

struct kparam_array___211;

struct kernel_param___211 {
	const char *name;
	struct module___211 *mod;
	const struct kernel_param_ops___211 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___211 *arr;
	};
};

struct kparam_array___211 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___211 *ops;
	void *elem;
};

struct module_attribute___211 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___211 *, struct module_kobject___212 *, char *);
	ssize_t (*store)(struct module_attribute___211 *, struct module_kobject___212 *, const char *, size_t);
	void (*setup)(struct module___211 *, const char *);
	int (*test)(struct module___211 *);
	void (*free)(struct module___211 *);
};

struct msghdr___36 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___147 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___227 *msg_iocb;
};

struct sk_buff___46 {
	union {
		struct {
			struct sk_buff___46 *next;
			struct sk_buff___46 *prev;
			union {
				struct net_device___47 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___35 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___46 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___50;

struct fqdir___50 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___50 *f;
	struct net___50 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___50;

struct inet_frags___50 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___50 *, const void *);
	void (*destructor)(struct inet_frag_queue___50 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct fib_rules_ops___34;

struct fib_notifier_ops___34;

struct netns_ipv4___50 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___34 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___35 *fibnl;
	struct sock___35 **icmp_sk;
	struct sock___35 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___35 **tcp_sk;
	struct fqdir___50 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___34 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___34 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___34 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___34;

struct dst_ops___50 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___50 *);
	struct dst_entry___34 * (*check)(struct dst_entry___34 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___34 *);
	unsigned int (*mtu)(const struct dst_entry___34 *);
	u32 * (*cow_metrics)(struct dst_entry___34 *, long unsigned int);
	void (*destroy)(struct dst_entry___34 *);
	void (*ifdown)(struct dst_entry___34 *, struct net_device___47 *, int);
	struct dst_entry___34 * (*negative_advice)(struct dst_entry___34 *);
	void (*link_failure)(struct sk_buff___46 *);
	void (*update_pmtu)(struct dst_entry___34 *, struct sock___35 *, struct sk_buff___46 *, u32, bool);
	void (*redirect)(struct dst_entry___34 *, struct sock___35 *, struct sk_buff___46 *);
	int (*local_out)(struct net___50 *, struct sock___35 *, struct sk_buff___46 *);
	struct neighbour___34 * (*neigh_lookup)(const struct dst_entry___34 *, struct sk_buff___46 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___34 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___50 {
	struct dst_ops___50 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___50 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___34 *fib6_rules_ops;
	struct sock___35 **icmp_sk;
	struct sock___35 *ndisc_sk;
	struct sock___35 *tcp_sk;
	struct sock___35 *igmp_sk;
	struct sock___35 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___34 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___34 *notifier_ops;
	struct fib_notifier_ops___34 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___50 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___50 *fqdir;
};

struct netns_sctp___34 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___35 *ctl_sock;
	struct sock___35 *udp4_sock;
	struct sock___35 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___41;

struct netns_bpf___41 {
	struct bpf_prog_array___41 *run_array[2];
	struct bpf_prog___41 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___50 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___35 *nlsk;
	struct sock___35 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___50 xfrm4_dst_ops;
	struct dst_ops___50 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net_generic___2;

struct net___50 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___35 *rtnl;
	struct sock___35 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___47 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___50 ipv4;
	struct netns_ipv6___50 ipv6;
	struct netns_ieee802154_lowpan___50 ieee802154_lowpan;
	struct netns_sctp___34 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___45 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___41 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___50 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___35 *crypto_nlsk;
	struct sock___35 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___50 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___46 *fragments_tail;
	struct sk_buff___46 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___50 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___34;

struct fib_lookup_arg___34;

struct fib_rules_ops___34 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___34 *, struct flowi *, int, struct fib_lookup_arg___34 *);
	bool (*suppress)(struct fib_rule___34 *, int, struct fib_lookup_arg___34 *);
	int (*match)(struct fib_rule___34 *, struct flowi *, int);
	int (*configure)(struct fib_rule___34 *, struct sk_buff___46 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___34 *);
	int (*compare)(struct fib_rule___34 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___34 *, struct sk_buff___46 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___34 *);
	void (*flush_cache)(struct fib_rules_ops___34 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___211 *owner;
	struct net___50 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___34 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___50 *);
	int (*fib_dump)(struct net___50 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___211 *owner;
	struct callback_head rcu;
};

struct dst_entry___34 {
	struct net_device___47 *dev;
	struct dst_ops___50 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___46 *);
	int (*output)(struct net___50 *, struct sock___35 *, struct sk_buff___46 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___45(struct sk_buff___46 **);

struct bpf_xdp_entity___41 {
	struct bpf_prog___41 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___45;

struct net_device_ops___45;

struct l3mdev_ops___34;

struct xfrmdev_ops___45;

struct header_ops___45;

struct netdev_rx_queue___45;

struct mini_Qdisc___41;

struct netdev_queue___45;

struct Qdisc___41;

struct rtnl_link_ops___41;

struct dcbnl_rtnl_ops___45;

struct net_device___47 {
	char name[16];
	struct netdev_name_node___45 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___45 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___34 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___45 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___45 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___215 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___45 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___41 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___45 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___41 *miniq_ingress;
	struct netdev_queue___45 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___45 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___41 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___41 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___45 = 0,
		NETREG_REGISTERED___45 = 1,
		NETREG_UNREGISTERING___45 = 2,
		NETREG_UNREGISTERED___45 = 3,
		NETREG_RELEASED___45 = 4,
		NETREG_DUMMY___45 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___45 = 0,
		RTNL_LINK_INITIALIZING___45 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___47 *);
	struct netpoll_info *npinfo;
	possible_net_t___45 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___205 dev;
	const struct attribute_group___215 *sysfs_groups[4];
	const struct attribute_group___215 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___41 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___45 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___41 xdp_state[3];
	long: 64;
};

struct neigh_table___34;

struct neigh_parms___34;

struct neigh_ops___34;

struct neighbour___34 {
	struct neighbour___34 *next;
	struct neigh_table___34 *tbl;
	struct neigh_parms___34 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___45 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___34 *, struct sk_buff___46 *);
	const struct neigh_ops___34 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___47 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___41 {
	struct bpf_prog___41 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___41 {
	struct callback_head rcu;
	struct bpf_prog_array_item___41 items[0];
};

struct bpf_prog_aux___48;

struct bpf_prog___41 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___48 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___222 {
	void (*page_free)(struct page___232 *);
	void (*kill)(struct dev_pagemap___222 *);
	void (*cleanup)(struct dev_pagemap___222 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___222 *);
};

struct fwnode_operations___201;

struct fwnode_handle___201 {
	struct fwnode_handle___201 *secondary;
	const struct fwnode_operations___201 *ops;
	struct device___205 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___201;

struct fwnode_endpoint___201;

struct fwnode_operations___201 {
	struct fwnode_handle___201 * (*get)(struct fwnode_handle___201 *);
	void (*put)(struct fwnode_handle___201 *);
	bool (*device_is_available)(const struct fwnode_handle___201 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___201 *, const struct device___205 *);
	bool (*property_present)(const struct fwnode_handle___201 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___201 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___201 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___201 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*get_parent)(const struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*get_next_child_node)(const struct fwnode_handle___201 *, struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*get_named_child_node)(const struct fwnode_handle___201 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___201 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___201 *);
	struct fwnode_handle___201 * (*graph_get_next_endpoint)(const struct fwnode_handle___201 *, struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*graph_get_remote_endpoint)(const struct fwnode_handle___201 *);
	struct fwnode_handle___201 * (*graph_get_port_parent)(struct fwnode_handle___201 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___201 *, struct fwnode_endpoint___201 *);
	int (*add_links)(struct fwnode_handle___201 *);
};

struct fwnode_endpoint___201 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___201 *local_fwnode;
};

struct fwnode_reference_args___201 {
	struct fwnode_handle___201 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___157 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___157 *root_cset;
};

struct socket_wq___35 {
	wait_queue_head_t wait;
	struct fasync_struct___227 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___35;

struct socket___36 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___227 *file;
	struct sock___35 *sk;
	const struct proto_ops___35 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___35 wq;
};

typedef int (*sk_read_actor_t___34)(read_descriptor_t *, struct sk_buff___46 *, unsigned int, size_t);

struct proto_ops___35 {
	int family;
	struct module___211 *owner;
	int (*release)(struct socket___36 *);
	int (*bind)(struct socket___36 *, struct sockaddr *, int);
	int (*connect)(struct socket___36 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___36 *, struct socket___36 *);
	int (*accept)(struct socket___36 *, struct socket___36 *, int, bool);
	int (*getname)(struct socket___36 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___227 *, struct socket___36 *, struct poll_table_struct___152 *);
	int (*ioctl)(struct socket___36 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___36 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___36 *, void *, bool, bool);
	int (*listen)(struct socket___36 *, int);
	int (*shutdown)(struct socket___36 *, int);
	int (*setsockopt)(struct socket___36 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___36 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___202 *, struct socket___36 *);
	int (*sendmsg)(struct socket___36 *, struct msghdr___36 *, size_t);
	int (*recvmsg)(struct socket___36 *, struct msghdr___36 *, size_t, int);
	int (*mmap)(struct file___227 *, struct socket___36 *, struct vm_area_struct___232 *);
	ssize_t (*sendpage)(struct socket___36 *, struct page___232 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___36 *, loff_t *, struct pipe_inode_info___77 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___35 *, int);
	int (*peek_len)(struct socket___36 *);
	int (*read_sock)(struct sock___35 *, read_descriptor_t *, sk_read_actor_t___34);
	int (*sendpage_locked)(struct sock___35 *, struct page___232 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___35 *, struct msghdr___36 *, size_t);
	int (*set_rcvlowat)(struct sock___35 *, int);
};

struct dev_pm_ops___205 {
	int (*prepare)(struct device___205 *);
	void (*complete)(struct device___205 *);
	int (*suspend)(struct device___205 *);
	int (*resume)(struct device___205 *);
	int (*freeze)(struct device___205 *);
	int (*thaw)(struct device___205 *);
	int (*poweroff)(struct device___205 *);
	int (*restore)(struct device___205 *);
	int (*suspend_late)(struct device___205 *);
	int (*resume_early)(struct device___205 *);
	int (*freeze_late)(struct device___205 *);
	int (*thaw_early)(struct device___205 *);
	int (*poweroff_late)(struct device___205 *);
	int (*restore_early)(struct device___205 *);
	int (*suspend_noirq)(struct device___205 *);
	int (*resume_noirq)(struct device___205 *);
	int (*freeze_noirq)(struct device___205 *);
	int (*thaw_noirq)(struct device___205 *);
	int (*poweroff_noirq)(struct device___205 *);
	int (*restore_noirq)(struct device___205 *);
	int (*runtime_suspend)(struct device___205 *);
	int (*runtime_resume)(struct device___205 *);
	int (*runtime_idle)(struct device___205 *);
};

struct wakeup_source___205 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___205 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___205 {
	struct dev_pm_ops___205 ops;
	int (*start)(struct device___205 *);
	void (*detach)(struct device___205 *, bool);
	int (*activate)(struct device___205 *);
	void (*sync)(struct device___205 *);
	void (*dismiss)(struct device___205 *);
};

struct bus_type___205 {
	const char *name;
	const char *dev_name;
	struct device___205 *dev_root;
	const struct attribute_group___215 **bus_groups;
	const struct attribute_group___215 **dev_groups;
	const struct attribute_group___215 **drv_groups;
	int (*match)(struct device___205 *, struct device_driver___205 *);
	int (*uevent)(struct device___205 *, struct kobj_uevent_env *);
	int (*probe)(struct device___205 *);
	void (*sync_state)(struct device___205 *);
	void (*remove)(struct device___205 *);
	void (*shutdown)(struct device___205 *);
	int (*online)(struct device___205 *);
	int (*offline)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	int (*num_vf)(struct device___205 *);
	int (*dma_configure)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___205 {
	const char *name;
	struct bus_type___205 *bus;
	struct module___211 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___205 *);
	void (*sync_state)(struct device___205 *);
	int (*remove)(struct device___205 *);
	void (*shutdown)(struct device___205 *);
	int (*suspend)(struct device___205 *, pm_message_t);
	int (*resume)(struct device___205 *);
	const struct attribute_group___215 **groups;
	const struct attribute_group___215 **dev_groups;
	const struct dev_pm_ops___205 *pm;
	void (*coredump)(struct device___205 *);
	struct driver_private *p;
};

struct device_type___205 {
	const char *name;
	const struct attribute_group___215 **groups;
	int (*uevent)(struct device___205 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___205 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___205 *);
	const struct dev_pm_ops___205 *pm;
};

struct class___205 {
	const char *name;
	struct module___211 *owner;
	const struct attribute_group___215 **class_groups;
	const struct attribute_group___215 **dev_groups;
	struct kobject___215 *dev_kobj;
	int (*dev_uevent)(struct device___205 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___205 *, umode_t *);
	void (*class_release)(struct class___205 *);
	void (*dev_release)(struct device___205 *);
	int (*shutdown_pre)(struct device___205 *);
	const struct kobj_ns_type_operations___34 *ns_type;
	const void * (*namespace)(struct device___205 *);
	void (*get_ownership)(struct device___205 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___205 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___77;

struct pipe_buffer___77 {
	struct page___232 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___77 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___77 {
	int (*confirm)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
	void (*release)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
	bool (*try_steal)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
	bool (*get)(struct pipe_inode_info___77 *, struct pipe_buffer___77 *);
};

typedef struct bio_vec___144 skb_frag_t___5;

struct skb_shared_info___5 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___46 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___5 frags[17];
};

struct net_generic___2 {
	union {
		struct {
			unsigned int len;
			struct callback_head rcu;
		} s;
		void *ptr[0];
	};
};

struct seq_operations___202 {
	void * (*start)(struct seq_file___202 *, loff_t *);
	void (*stop)(struct seq_file___202 *, void *);
	void * (*next)(struct seq_file___202 *, void *, loff_t *);
	int (*show)(struct seq_file___202 *, void *);
};

struct pernet_operations___7 {
	struct list_head list;
	int (*init)(struct net___50 *);
	void (*pre_exit)(struct net___50 *);
	void (*exit)(struct net___50 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___45 {
	int (*ieee_getets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___47 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___47 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___47 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___47 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___47 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___47 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___47 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___47 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___47 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___47 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___47 *);
	u8 (*setstate)(struct net_device___47 *, u8);
	void (*getpermhwaddr)(struct net_device___47 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___47 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___47 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___47 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___47 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___47 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___47 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___47 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___47 *, int, u8 *);
	void (*setpfccfg)(struct net_device___47 *, int, u8);
	void (*getpfccfg)(struct net_device___47 *, int, u8 *);
	u8 (*setall)(struct net_device___47 *);
	u8 (*getcap)(struct net_device___47 *, int, u8 *);
	int (*getnumtcs)(struct net_device___47 *, int, u8 *);
	int (*setnumtcs)(struct net_device___47 *, int, u8);
	u8 (*getpfcstate)(struct net_device___47 *);
	void (*setpfcstate)(struct net_device___47 *, u8);
	void (*getbcncfg)(struct net_device___47 *, int, u32 *);
	void (*setbcncfg)(struct net_device___47 *, int, u32);
	void (*getbcnrp)(struct net_device___47 *, int, u8 *);
	void (*setbcnrp)(struct net_device___47 *, int, u8);
	int (*setapp)(struct net_device___47 *, u8, u16, u8);
	int (*getapp)(struct net_device___47 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___47 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___47 *, int, u8);
	u8 (*getdcbx)(struct net_device___47 *);
	u8 (*setdcbx)(struct net_device___47 *, u8);
	int (*peer_getappinfo)(struct net_device___47 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___47 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___47 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___47 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___47 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___47 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___48;

typedef int (*bpf_iter_init_seq_priv_t___47)(void *, struct bpf_iter_aux_info___48 *);

struct bpf_map___48;

struct bpf_iter_aux_info___48 {
	struct bpf_map___48 *map;
};

struct bpf_iter_seq_info___47 {
	const struct seq_operations___202 *seq_ops;
	bpf_iter_init_seq_priv_t___47 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___47 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___48 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___48 *, struct file___227 *);
	void (*map_free)(struct bpf_map___48 *);
	int (*map_get_next_key)(struct bpf_map___48 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___48 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___48 *, void *);
	int (*map_lookup_batch)(struct bpf_map___48 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___48 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___48 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___48 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___48 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___48 *, void *);
	int (*map_update_elem)(struct bpf_map___48 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___48 *, void *);
	int (*map_push_elem)(struct bpf_map___48 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___48 *, void *);
	int (*map_peek_elem)(struct bpf_map___48 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___48 *, struct file___227 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___48 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___48 *, void *, struct seq_file___202 *);
	int (*map_check_btf)(const struct bpf_map___48 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___48 *, struct bpf_prog_aux___48 *);
	void (*map_poke_untrack)(struct bpf_map___48 *, struct bpf_prog_aux___48 *);
	void (*map_poke_run)(struct bpf_map___48 *, u32, struct bpf_prog___41 *, struct bpf_prog___41 *);
	int (*map_direct_value_addr)(const struct bpf_map___48 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___48 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___48 *, struct vm_area_struct___232 *);
	__poll_t (*map_poll)(struct bpf_map___48 *, struct file___227 *, struct poll_table_struct___152 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___48 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___48 *, const struct bpf_map___48 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___48 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___47 *iter_seq_info;
};

struct bpf_map___48 {
	const struct bpf_map_ops___47 *ops;
	struct bpf_map___48 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___100 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___47;

struct bpf_jit_poke_descriptor___47;

struct bpf_prog_ops___41;

struct btf_mod_pair___47;

struct bpf_prog_offload___45;

struct bpf_prog_aux___48 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___41 *dst_prog;
	struct bpf_trampoline___47 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___41 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___47 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___41 *ops;
	struct bpf_map___48 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___47 *used_btfs;
	struct bpf_prog___41 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___48 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___45 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___45;

struct bpf_map_dev_ops___45 {
	int (*map_get_next_key)(struct bpf_offloaded_map___45 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___45 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___45 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___45 *, void *);
};

struct bpf_offloaded_map___45 {
	struct bpf_map___48 map;
	struct net_device___47 *netdev;
	const struct bpf_map_dev_ops___45 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___41 {
	int (*test_run)(struct bpf_prog___41 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___45 {
	struct bpf_prog___41 *prog;
	struct net_device___47 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___47 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___41 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___211 *mod;
};

struct bpf_jit_poke_descriptor___47 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___48 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___47 {
	struct btf *btf;
	struct module___211 *module;
};

struct cftype___157;

struct cgroup_subsys___157 {
	struct cgroup_subsys_state___157 * (*css_alloc)(struct cgroup_subsys_state___157 *);
	int (*css_online)(struct cgroup_subsys_state___157 *);
	void (*css_offline)(struct cgroup_subsys_state___157 *);
	void (*css_released)(struct cgroup_subsys_state___157 *);
	void (*css_free)(struct cgroup_subsys_state___157 *);
	void (*css_reset)(struct cgroup_subsys_state___157 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___157 *, int);
	int (*css_extra_stat_show)(struct seq_file___202 *, struct cgroup_subsys_state___157 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___234 *, struct css_set___157 *);
	void (*cancel_fork)(struct task_struct___234 *, struct css_set___157 *);
	void (*fork)(struct task_struct___234 *);
	void (*exit)(struct task_struct___234 *);
	void (*release)(struct task_struct___234 *);
	void (*bind)(struct cgroup_subsys_state___157 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___157 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___157 *dfl_cftypes;
	struct cftype___157 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___157 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___157 *updated_children;
	struct cgroup___157 *updated_next;
};

struct cgroup_root___157 {
	struct kernfs_root___215 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___157 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___157 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___157 *ss;
	struct list_head node;
	struct kernfs_ops___215 *kf_ops;
	int (*open)(struct kernfs_open_file___215 *);
	void (*release)(struct kernfs_open_file___215 *);
	u64 (*read_u64)(struct cgroup_subsys_state___157 *, struct cftype___157 *);
	s64 (*read_s64)(struct cgroup_subsys_state___157 *, struct cftype___157 *);
	int (*seq_show)(struct seq_file___202 *, void *);
	void * (*seq_start)(struct seq_file___202 *, loff_t *);
	void * (*seq_next)(struct seq_file___202 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___202 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___157 *, struct cftype___157 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___157 *, struct cftype___157 *, s64);
	ssize_t (*write)(struct kernfs_open_file___215 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___215 *, struct poll_table_struct___152 *);
};

struct xdp_rxq_info___45 {
	struct net_device___47 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___45 {
	struct net_device___47 *dev;
};

struct xdp_buff___45 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___45 *rxq;
	struct xdp_txq_info___45 *txq;
	u32 frame_sz;
};

struct xdp_frame___45 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___47 *dev_rx;
};

struct netlink_callback___45 {
	struct sk_buff___46 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___46 *, struct netlink_callback___45 *);
	int (*done)(struct netlink_callback___45 *);
	void *data;
	struct module___211 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum {
	IFLA_UNSPEC = 0,
	IFLA_ADDRESS = 1,
	IFLA_BROADCAST = 2,
	IFLA_IFNAME = 3,
	IFLA_MTU = 4,
	IFLA_LINK = 5,
	IFLA_QDISC = 6,
	IFLA_STATS = 7,
	IFLA_COST = 8,
	IFLA_PRIORITY = 9,
	IFLA_MASTER = 10,
	IFLA_WIRELESS = 11,
	IFLA_PROTINFO = 12,
	IFLA_TXQLEN = 13,
	IFLA_MAP = 14,
	IFLA_WEIGHT = 15,
	IFLA_OPERSTATE = 16,
	IFLA_LINKMODE = 17,
	IFLA_LINKINFO = 18,
	IFLA_NET_NS_PID = 19,
	IFLA_IFALIAS = 20,
	IFLA_NUM_VF = 21,
	IFLA_VFINFO_LIST = 22,
	IFLA_STATS64 = 23,
	IFLA_VF_PORTS = 24,
	IFLA_PORT_SELF = 25,
	IFLA_AF_SPEC = 26,
	IFLA_GROUP = 27,
	IFLA_NET_NS_FD = 28,
	IFLA_EXT_MASK = 29,
	IFLA_PROMISCUITY = 30,
	IFLA_NUM_TX_QUEUES = 31,
	IFLA_NUM_RX_QUEUES = 32,
	IFLA_CARRIER = 33,
	IFLA_PHYS_PORT_ID = 34,
	IFLA_CARRIER_CHANGES = 35,
	IFLA_PHYS_SWITCH_ID = 36,
	IFLA_LINK_NETNSID = 37,
	IFLA_PHYS_PORT_NAME = 38,
	IFLA_PROTO_DOWN = 39,
	IFLA_GSO_MAX_SEGS = 40,
	IFLA_GSO_MAX_SIZE = 41,
	IFLA_PAD = 42,
	IFLA_XDP = 43,
	IFLA_EVENT = 44,
	IFLA_NEW_NETNSID = 45,
	IFLA_IF_NETNSID = 46,
	IFLA_TARGET_NETNSID = 46,
	IFLA_CARRIER_UP_COUNT = 47,
	IFLA_CARRIER_DOWN_COUNT = 48,
	IFLA_NEW_IFINDEX = 49,
	IFLA_MIN_MTU = 50,
	IFLA_MAX_MTU = 51,
	IFLA_PROP_LIST = 52,
	IFLA_ALT_IFNAME = 53,
	IFLA_PERM_ADDRESS = 54,
	IFLA_PROTO_DOWN_REASON = 55,
	IFLA_PARENT_DEV_NAME = 56,
	IFLA_PARENT_DEV_BUS_NAME = 57,
	__IFLA_MAX = 58,
};

enum {
	IFLA_PPP_UNSPEC = 0,
	IFLA_PPP_DEV_FD = 1,
	__IFLA_PPP_MAX = 2,
};

struct header_ops___45 {
	int (*create)(struct sk_buff___46 *, struct net_device___47 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___46 *, unsigned char *);
	int (*cache)(const struct neighbour___34 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___47 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___46 *);
};

struct netdev_queue___45 {
	struct net_device___47 *dev;
	struct Qdisc___41 *qdisc;
	struct Qdisc___41 *qdisc_sleeping;
	struct kobject___215 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___47 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___41 {
	struct sk_buff___46 *head;
	struct sk_buff___46 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___41;

struct Qdisc___41 {
	int (*enqueue)(struct sk_buff___46 *, struct Qdisc___41 *, struct sk_buff___46 **);
	struct sk_buff___46 * (*dequeue)(struct Qdisc___41 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___41 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___45 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___45 gso_skb;
	struct qdisc_skb_head___41 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___41 *next_sched;
	struct sk_buff_head___45 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___45 {
	struct xdp_rxq_info___45 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___215 kobj;
	struct net_device___47 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___45 {
	enum net_device_path_type type;
	const struct net_device___47 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___45 = 0,
				DEV_PATH_BR_VLAN_TAG___45 = 1,
				DEV_PATH_BR_VLAN_UNTAG___45 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___45 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___45 {
	const struct net_device___47 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___45 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___41 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___45 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___45 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___46 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___45 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___47 *dev;
	const char *name;
};

struct net_device_ops___45 {
	int (*ndo_init)(struct net_device___47 *);
	void (*ndo_uninit)(struct net_device___47 *);
	int (*ndo_open)(struct net_device___47 *);
	int (*ndo_stop)(struct net_device___47 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___46 *, struct net_device___47 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___46 *, struct net_device___47 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___47 *, struct sk_buff___46 *, struct net_device___47 *);
	void (*ndo_change_rx_flags)(struct net_device___47 *, int);
	void (*ndo_set_rx_mode)(struct net_device___47 *);
	int (*ndo_set_mac_address)(struct net_device___47 *, void *);
	int (*ndo_validate_addr)(struct net_device___47 *);
	int (*ndo_do_ioctl)(struct net_device___47 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___47 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___47 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___47 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___47 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___47 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___47 *, int);
	int (*ndo_neigh_setup)(struct net_device___47 *, struct neigh_parms___34 *);
	void (*ndo_tx_timeout)(struct net_device___47 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___47 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___47 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___47 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___47 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___47 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___47 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___47 *);
	int (*ndo_netpoll_setup)(struct net_device___47 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___47 *);
	int (*ndo_set_vf_mac)(struct net_device___47 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___47 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___47 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___47 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___47 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___47 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___47 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___47 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___47 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___47 *, int, struct sk_buff___46 *);
	int (*ndo_get_vf_guid)(struct net_device___47 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___47 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___47 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___47 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___47 *);
	int (*ndo_fcoe_disable)(struct net_device___47 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___47 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___47 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___47 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___47 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___47 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___47 *, const struct sk_buff___46 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___47 *, struct net_device___47 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___47 *, struct net_device___47 *);
	struct net_device___47 * (*ndo_get_xmit_slave)(struct net_device___47 *, struct sk_buff___46 *, bool);
	struct net_device___47 * (*ndo_sk_get_lower_dev)(struct net_device___47 *, struct sock___35 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___47 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___47 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___47 *, struct neighbour___34 *);
	void (*ndo_neigh_destroy)(struct net_device___47 *, struct neighbour___34 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___46 *, struct netlink_callback___45 *, struct net_device___47 *, struct net_device___47 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___46 *, struct nlattr **, struct net_device___47 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___47 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___46 *, u32, u32, struct net_device___47 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___47 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___47 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___47 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___47 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___47 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___47 *, struct net_device___47 *);
	void (*ndo_dfwd_del_station)(struct net_device___47 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___47 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___47 *);
	int (*ndo_change_proto_down)(struct net_device___47 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___47 *, struct sk_buff___46 *);
	void (*ndo_set_rx_headroom)(struct net_device___47 *, int);
	int (*ndo_bpf)(struct net_device___47 *, struct netdev_bpf___45 *);
	int (*ndo_xdp_xmit)(struct net_device___47 *, int, struct xdp_frame___45 **, u32);
	struct net_device___47 * (*ndo_xdp_get_xmit_slave)(struct net_device___47 *, struct xdp_buff___45 *);
	int (*ndo_xsk_wakeup)(struct net_device___47 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___47 *);
	int (*ndo_tunnel_ctl)(struct net_device___47 *, struct ip_tunnel_parm *, int);
	struct net_device___47 * (*ndo_get_peer_dev)(struct net_device___47 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___45 *, struct net_device_path___45 *);
};

struct neigh_parms___34 {
	possible_net_t___45 net;
	struct net_device___47 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___34 *);
	struct neigh_table___34 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___34 {
	u32 (*l3mdev_fib_table)(const struct net_device___47 *);
	struct sk_buff___46 * (*l3mdev_l3_rcv)(struct net_device___47 *, struct sk_buff___46 *, u16);
	struct sk_buff___46 * (*l3mdev_l3_out)(struct net_device___47 *, struct sock___35 *, struct sk_buff___46 *, u16);
	struct dst_entry___34 * (*l3mdev_link_scope_lookup)(const struct net_device___47 *, struct flowi6 *);
};

struct tcf_proto___41;

struct tcf_block___41;

struct mini_Qdisc___41 {
	struct tcf_proto___41 *filter_list;
	struct tcf_block___41 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___41 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___47 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___47 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___50 *, struct net_device___47 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___47 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___47 *, struct list_head *);
	size_t (*get_size)(const struct net_device___47 *);
	int (*fill_info)(struct sk_buff___46 *, const struct net_device___47 *);
	size_t (*get_xstats_size)(const struct net_device___47 *);
	int (*fill_xstats)(struct sk_buff___46 *, const struct net_device___47 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___47 *, struct net_device___47 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___47 *, const struct net_device___47 *);
	int (*fill_slave_info)(struct sk_buff___46 *, const struct net_device___47 *, const struct net_device___47 *);
	struct net___50 * (*get_link_net)(const struct net_device___47 *);
	size_t (*get_linkxstats_size)(const struct net_device___47 *, int);
	int (*fill_linkxstats)(struct sk_buff___46 *, const struct net_device___47 *, int *, int);
};

typedef struct poll_table_struct___152 poll_table___41;

enum NPmode {
	NPMODE_PASS = 0,
	NPMODE_DROP = 1,
	NPMODE_ERROR = 2,
	NPMODE_QUEUE = 3,
};

struct pppstat {
	__u32 ppp_discards;
	__u32 ppp_ibytes;
	__u32 ppp_ioctects;
	__u32 ppp_ipackets;
	__u32 ppp_ierrors;
	__u32 ppp_ilqrs;
	__u32 ppp_obytes;
	__u32 ppp_ooctects;
	__u32 ppp_opackets;
	__u32 ppp_oerrors;
	__u32 ppp_olqrs;
};

struct vjstat {
	__u32 vjs_packets;
	__u32 vjs_compressed;
	__u32 vjs_searches;
	__u32 vjs_misses;
	__u32 vjs_uncompressedin;
	__u32 vjs_compressedin;
	__u32 vjs_errorin;
	__u32 vjs_tossed;
};

struct compstat {
	__u32 unc_bytes;
	__u32 unc_packets;
	__u32 comp_bytes;
	__u32 comp_packets;
	__u32 inc_bytes;
	__u32 inc_packets;
	__u32 in_count;
	__u32 bytes_out;
	double ratio;
};

struct ppp_stats {
	struct pppstat p;
	struct vjstat vj;
};

struct ppp_comp_stats {
	struct compstat c;
	struct compstat d;
};

struct ppp_idle32 {
	__s32 xmit_idle;
	__s32 recv_idle;
};

struct ppp_idle64 {
	__s64 xmit_idle;
	__s64 recv_idle;
};

struct gnet_dump___41 {
	spinlock_t *lock;
	struct sk_buff___46 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___41;

struct Qdisc_ops___41 {
	struct Qdisc_ops___41 *next;
	const struct Qdisc_class_ops___41 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___46 *, struct Qdisc___41 *, struct sk_buff___46 **);
	struct sk_buff___46 * (*dequeue)(struct Qdisc___41 *);
	struct sk_buff___46 * (*peek)(struct Qdisc___41 *);
	int (*init)(struct Qdisc___41 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___41 *);
	void (*destroy)(struct Qdisc___41 *);
	int (*change)(struct Qdisc___41 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___41 *);
	int (*change_tx_queue_len)(struct Qdisc___41 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___41 *, unsigned int);
	int (*dump)(struct Qdisc___41 *, struct sk_buff___46 *);
	int (*dump_stats)(struct Qdisc___41 *, struct gnet_dump___41 *);
	void (*ingress_block_set)(struct Qdisc___41 *, u32);
	void (*egress_block_set)(struct Qdisc___41 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___41 *);
	u32 (*egress_block_get)(struct Qdisc___41 *);
	struct module___211 *owner;
};

struct Qdisc_class_ops___41 {
	unsigned int flags;
	struct netdev_queue___45 * (*select_queue)(struct Qdisc___41 *, struct tcmsg *);
	int (*graft)(struct Qdisc___41 *, long unsigned int, struct Qdisc___41 *, struct Qdisc___41 **, struct netlink_ext_ack *);
	struct Qdisc___41 * (*leaf)(struct Qdisc___41 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___41 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___41 *, u32);
	int (*change)(struct Qdisc___41 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___41 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___41 *, struct qdisc_walker *);
	struct tcf_block___41 * (*tcf_block)(struct Qdisc___41 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___41 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___41 *, long unsigned int);
	int (*dump)(struct Qdisc___41 *, long unsigned int, struct sk_buff___46 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___41 *, long unsigned int, struct gnet_dump___41 *);
};

struct tcf_chain___41;

struct tcf_block___41 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___50 *net;
	struct Qdisc___41 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___41 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___41;

struct tcf_proto_ops___41;

struct tcf_proto___41 {
	struct tcf_proto___41 *next;
	void *root;
	int (*classify)(struct sk_buff___46 *, const struct tcf_proto___41 *, struct tcf_result___41 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___41 *ops;
	struct tcf_chain___41 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___41 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___41 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___41 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___46 *, const struct tcf_proto___41 *, struct tcf_result___41 *);
	int (*init)(struct tcf_proto___41 *);
	void (*destroy)(struct tcf_proto___41 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___41 *, u32);
	void (*put)(struct tcf_proto___41 *, void *);
	int (*change)(struct net___50 *, struct sk_buff___46 *, struct tcf_proto___41 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___41 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___41 *);
	void (*walk)(struct tcf_proto___41 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___41 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___41 *, void *);
	void (*hw_del)(struct tcf_proto___41 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___50 *, struct tcf_chain___41 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___50 *, struct tcf_proto___41 *, void *, struct sk_buff___46 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___50 *, struct tcf_proto___41 *, void *, struct sk_buff___46 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___46 *, struct net___50 *, void *);
	struct module___211 *owner;
	int flags;
};

struct tcf_chain___41 {
	struct mutex filter_chain_lock;
	struct tcf_proto___41 *filter_chain;
	struct list_head list;
	struct tcf_block___41 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___41 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___34 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___41 *prog;
};

struct npioctl {
	int protocol;
	enum NPmode mode;
};

struct ppp_option_data {
	__u8 *ptr;
	__u32 length;
	int transmit;
};

struct ppp_channel;

struct ppp_channel_ops {
	int (*start_xmit)(struct ppp_channel *, struct sk_buff___46 *);
	int (*ioctl)(struct ppp_channel *, unsigned int, long unsigned int);
	int (*fill_forward_path)(struct net_device_path_ctx___45 *, struct net_device_path___45 *, const struct ppp_channel *);
};

struct ppp_channel {
	void *private;
	const struct ppp_channel_ops *ops;
	int mtu;
	int hdrlen;
	void *ppp;
	int speed;
	int latency;
};

struct compressor {
	int compress_proto;
	void * (*comp_alloc)(unsigned char *, int);
	void (*comp_free)(void *);
	int (*comp_init)(void *, unsigned char *, int, int, int, int);
	void (*comp_reset)(void *);
	int (*compress)(void *, unsigned char *, unsigned char *, int, int);
	void (*comp_stat)(void *, struct compstat *);
	void * (*decomp_alloc)(unsigned char *, int);
	void (*decomp_free)(void *);
	int (*decomp_init)(void *, unsigned char *, int, int, int, int, int);
	void (*decomp_reset)(void *);
	int (*decompress)(void *, unsigned char *, int, unsigned char *, int);
	void (*incomp)(void *, unsigned char *, int);
	void (*decomp_stat)(void *, struct compstat *);
	struct module___211 *owner;
	unsigned int comp_extra;
};

struct iphdr___2 {
	__u8 ihl: 4;
	__u8 version;
	__u8 tos;
	__be16 tot_len;
	__be16 id;
	__be16 frag_off;
	__u8 ttl;
	__u8 protocol;
	__sum16 check;
	__be32 saddr;
	__be32 daddr;
};

struct block_device_operations___120;

struct gendisk___123 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___123 *part0;
	const struct block_device_operations___120 *fops;
	struct request_queue___120 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___109 *bdi;
	struct kobject___215 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___215 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___120 {
	struct bio___120 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___144 *bip_vec;
	struct bio_vec___144 bip_inline_vecs[0];
};

struct blkcg___111;

struct blkg_policy_data___111;

struct blkcg_gq___111 {
	struct request_queue___120 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___111 *blkcg;
	struct blkcg_gq___111 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___111 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___120 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___120(struct request___120 *);

typedef void integrity_complete_fn___120(struct request___120 *, unsigned int);

struct blk_integrity_profile___120 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___120 *prepare_fn;
	integrity_complete_fn___120 *complete_fn;
	const char *name;
};

struct block_device_operations___120 {
	blk_qc_t (*submit_bio)(struct bio___120 *);
	int (*open)(struct block_device___123 *, fmode_t);
	void (*release)(struct gendisk___123 *, fmode_t);
	int (*rw_page)(struct block_device___123 *, sector_t, struct page___232 *, unsigned int);
	int (*ioctl)(struct block_device___123 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___123 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___123 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___123 *);
	int (*getgeo)(struct block_device___123 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___123 *, bool);
	void (*swap_slot_free_notify)(struct block_device___123 *, long unsigned int);
	int (*report_zones)(struct gendisk___123 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___123 *, umode_t *);
	struct module___211 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___123 *, sector_t *);
};

typedef void rq_end_io_fn___120(struct request___120 *, blk_status_t);

struct request___120 {
	struct request_queue___120 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___117 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___120 *bio;
	struct bio___120 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___144 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___120 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___120 *saved_end_io;
		} flush;
	};
	struct gendisk___123 *rq_disk;
	struct block_device___123 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___120 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___117 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___120 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___215 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___227 *debugfs_dir;
	struct dentry___227 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___120;

struct elevator_mq_ops___120 {
	int (*init_sched)(struct request_queue___120 *, struct elevator_type___120 *);
	void (*exit_sched)(struct elevator_queue___120 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___117 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___117 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___117 *);
	bool (*allow_merge)(struct request_queue___120 *, struct request___120 *, struct bio___120 *);
	bool (*bio_merge)(struct request_queue___120 *, struct bio___120 *, unsigned int);
	int (*request_merge)(struct request_queue___120 *, struct request___120 **, struct bio___120 *);
	void (*request_merged)(struct request_queue___120 *, struct request___120 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___120 *, struct request___120 *, struct request___120 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___120 *);
	void (*finish_request)(struct request___120 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___117 *, struct list_head *, bool);
	struct request___120 * (*dispatch_request)(struct blk_mq_hw_ctx___117 *);
	bool (*has_work)(struct blk_mq_hw_ctx___117 *);
	void (*completed_request)(struct request___120 *, u64);
	void (*requeue_request)(struct request___120 *);
	struct request___120 * (*former_request)(struct request_queue___120 *, struct request___120 *);
	struct request___120 * (*next_request)(struct request_queue___120 *, struct request___120 *);
	void (*init_icq)(struct io_cq___120 *);
	void (*exit_icq)(struct io_cq___120 *);
};

struct elv_fs_entry___120;

struct elevator_type___120 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___120 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___120 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___211 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___120 {
	struct elevator_type___120 *type;
	void *elevator_data;
	struct kobject___215 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___120 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___120 *, char *);
	ssize_t (*store)(struct elevator_queue___120 *, const char *, size_t);
};

struct blk_mq_queue_data___117;

struct blk_mq_ops___117 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___117 *, const struct blk_mq_queue_data___117 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___117 *);
	int (*get_budget)(struct request_queue___120 *);
	void (*put_budget)(struct request_queue___120 *, int);
	void (*set_rq_budget_token)(struct request___120 *, int);
	int (*get_rq_budget_token)(struct request___120 *);
	enum blk_eh_timer_return (*timeout)(struct request___120 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___117 *);
	void (*complete)(struct request___120 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___117 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___117 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___117 *, struct request___120 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___117 *, struct request___120 *, unsigned int);
	void (*initialize_rq_fn)(struct request___120 *);
	void (*cleanup_rq)(struct request___120 *);
	bool (*busy)(struct request_queue___120 *);
	int (*map_queues)(struct blk_mq_tag_set___117 *);
	void (*show_rq)(struct seq_file___202 *, struct request___120 *);
};

struct blk_mq_tag_set___117 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___117 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___117 {
	struct request___120 *rq;
	bool last;
};

struct blkcg_policy_data___111;

struct blkcg___111 {
	struct cgroup_subsys_state___157 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___111 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___111 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___111 {
	struct blkcg___111 *blkcg;
	int plid;
};

struct blkg_policy_data___111 {
	struct blkcg_gq___111 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___100 {
	struct mem_cgroup___100 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___100 {
	struct lruvec___108 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___100 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___100 *memcg;
};

struct obj_cgroup___100 {
	struct percpu_ref refcnt;
	struct mem_cgroup___100 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___34;

struct neigh_hash_table___34;

struct neigh_table___34 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___47 *, __u32 *);
	bool (*key_eq)(const struct neighbour___34 *, const void *);
	int (*constructor)(struct neighbour___34 *);
	int (*pconstructor)(struct pneigh_entry___34 *);
	void (*pdestructor)(struct pneigh_entry___34 *);
	void (*proxy_redo)(struct sk_buff___46 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___47 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___34 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___45 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___34 *nht;
	struct pneigh_entry___34 **phash_buckets;
};

struct neigh_ops___34 {
	int family;
	void (*solicit)(struct neighbour___34 *, struct sk_buff___46 *);
	void (*error_report)(struct neighbour___34 *, struct sk_buff___46 *);
	int (*output)(struct neighbour___34 *, struct sk_buff___46 *);
	int (*connected_output)(struct neighbour___34 *, struct sk_buff___46 *);
};

struct pneigh_entry___34 {
	struct pneigh_entry___34 *next;
	possible_net_t___45 net;
	struct net_device___47 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___34 {
	struct neighbour___34 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___34 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___34 *ctarget;
	struct net___50 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___34 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___34 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___24;

struct timewait_sock_ops___24;

struct proto___34 {
	void (*close)(struct sock___35 *, long int);
	int (*pre_connect)(struct sock___35 *, struct sockaddr *, int);
	int (*connect)(struct sock___35 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___35 *, int);
	struct sock___35 * (*accept)(struct sock___35 *, int, int *, bool);
	int (*ioctl)(struct sock___35 *, int, long unsigned int);
	int (*init)(struct sock___35 *);
	void (*destroy)(struct sock___35 *);
	void (*shutdown)(struct sock___35 *, int);
	int (*setsockopt)(struct sock___35 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___35 *, int, int, char *, int *);
	void (*keepalive)(struct sock___35 *, int);
	int (*compat_ioctl)(struct sock___35 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___35 *, struct msghdr___36 *, size_t);
	int (*recvmsg)(struct sock___35 *, struct msghdr___36 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___35 *, struct page___232 *, int, size_t, int);
	int (*bind)(struct sock___35 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___35 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___35 *, struct sk_buff___46 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___35 *);
	int (*hash)(struct sock___35 *);
	void (*unhash)(struct sock___35 *);
	void (*rehash)(struct sock___35 *);
	int (*get_port)(struct sock___35 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___35 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___35 *, int);
	bool (*sock_is_readable)(struct sock___35 *);
	void (*enter_memory_pressure)(struct sock___35 *);
	void (*leave_memory_pressure)(struct sock___35 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___24 *rsk_prot;
	struct timewait_sock_ops___24 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___211 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___35 *, int);
};

struct request_sock___25;

struct request_sock_ops___24 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___35 *, struct request_sock___25 *);
	void (*send_ack)(const struct sock___35 *, struct sk_buff___46 *, struct request_sock___25 *);
	void (*send_reset)(const struct sock___35 *, struct sk_buff___46 *);
	void (*destructor)(struct request_sock___25 *);
	void (*syn_ack_timeout)(const struct request_sock___25 *);
};

struct timewait_sock_ops___24 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___35 *, struct sock___35 *, void *);
	void (*twsk_destructor)(struct sock___35 *);
};

struct request_sock___25 {
	struct sock_common___34 __req_common;
	struct request_sock___25 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___24 *rsk_ops;
	struct sock___35 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct tcphdr___3 {
	__be16 source;
	__be16 dest;
	__be32 seq;
	__be32 ack_seq;
	__u16 res1;
	__u16 doff;
	__u16 fin: 1;
	__u16 syn: 1;
	__u16 rst: 1;
	__u16 psh: 1;
	__u16 ack: 1;
	__u16 urg: 1;
	__u16 ece: 1;
	__u16 cwr: 1;
	long: 47;
	long: 64;
	__be16 window;
	__sum16 check;
	__be16 urg_ptr;
};

typedef __u8 byte_t;

typedef __u32 int32;

struct cstate___2 {
	byte_t cs_this;
	bool initialized;
	struct cstate___2 *next;
	struct iphdr___2 cs_ip;
	struct tcphdr___3 cs_tcp;
	unsigned char cs_ipopt[64];
	unsigned char cs_tcpopt[64];
	int cs_hsize;
};

struct slcompress {
	struct cstate___2 *tstate;
	struct cstate___2 *rstate;
	byte_t tslot_limit;
	byte_t rslot_limit;
	byte_t xmit_oldest;
	byte_t xmit_current;
	byte_t recv_current;
	byte_t flags;
	int32 sls_o_nontcp;
	int32 sls_o_tcp;
	int32 sls_o_uncompressed;
	int32 sls_o_compressed;
	int32 sls_o_searches;
	int32 sls_o_misses;
	int32 sls_i_uncompressed;
	int32 sls_i_compressed;
	int32 sls_i_error;
	int32 sls_i_tossed;
	int32 sls_i_runt;
	int32 sls_i_badcheck;
};

struct ppp_file {
	enum {
		INTERFACE = 1,
		CHANNEL = 2,
	} kind;
	struct sk_buff_head___45 xq;
	struct sk_buff_head___45 rq;
	wait_queue_head_t rwait;
	refcount_t refcnt;
	int hdrlen;
	int index;
	int dead;
};

struct ppp_link_stats {
	u64 rx_packets;
	u64 tx_packets;
	u64 rx_bytes;
	u64 tx_bytes;
};

struct ppp {
	struct ppp_file file;
	struct file___227 *owner;
	struct list_head channels;
	int n_channels;
	spinlock_t rlock;
	spinlock_t wlock;
	int *xmit_recursion;
	int mru;
	unsigned int flags;
	unsigned int xstate;
	unsigned int rstate;
	int debug;
	struct slcompress *vj;
	enum NPmode npmode[6];
	struct sk_buff___46 *xmit_pending;
	struct compressor *xcomp;
	void *xc_state;
	struct compressor *rcomp;
	void *rc_state;
	long unsigned int last_xmit;
	long unsigned int last_recv;
	struct net_device___47 *dev;
	int closing;
	int nxchan;
	u32 nxseq;
	int mrru;
	u32 nextseq;
	u32 minseq;
	struct sk_buff_head___45 mrq;
	struct bpf_prog___41 *pass_filter;
	struct bpf_prog___41 *active_filter;
	struct net___50 *ppp_net;
	struct ppp_link_stats stats64;
};

struct channel {
	struct ppp_file file;
	struct list_head list;
	struct ppp_channel *chan;
	struct rw_semaphore chan_sem;
	spinlock_t downl;
	struct ppp *ppp;
	struct net___50 *chan_net;
	struct list_head clist;
	rwlock_t upl;
	struct channel *bridge;
	u8 avail;
	u8 had_frag;
	u32 lastseq;
	int speed;
};

struct ppp_config {
	struct file___227 *file;
	s32 unit;
	bool ifname_is_set;
};

struct ppp_net {
	struct idr units_idr;
	struct mutex all_ppp_mutex;
	struct list_head all_channels;
	struct list_head new_channels;
	int last_channel_index;
	spinlock_t all_channels_lock;
};

struct sock_fprog32 {
	short unsigned int len;
	compat_caddr_t filter;
};

struct ppp_option_data32 {
	compat_uptr_t ptr;
	u32 length;
	compat_int_t transmit;
};

struct ppp_mp_skb_parm {
	u32 sequence;
	u8 BEbits;
};

struct compressor_entry {
	struct list_head list;
	struct compressor *comp;
};

struct wl1251_platform_data {
	int power_gpio;
	int irq;
	bool use_eeprom;
};

typedef struct poll_table_struct___150 poll_table___42;

struct class_dev_iter___4 {
	struct klist_iter ki;
	const struct device_type___203 *type;
};

struct device_attribute___37 {
	struct attribute attr;
	ssize_t (*show)(struct device___203 *, struct device_attribute___37 *, char *);
	ssize_t (*store)(struct device___203 *, struct device_attribute___37 *, const char *, size_t);
};

enum {
	IFLA_INFO_UNSPEC = 0,
	IFLA_INFO_KIND = 1,
	IFLA_INFO_DATA = 2,
	IFLA_INFO_XSTATS = 3,
	IFLA_INFO_SLAVE_KIND = 4,
	IFLA_INFO_SLAVE_DATA = 5,
	__IFLA_INFO_MAX = 6,
};

enum wwan_port_type {
	WWAN_PORT_AT = 0,
	WWAN_PORT_MBIM = 1,
	WWAN_PORT_QMI = 2,
	WWAN_PORT_QCDM = 3,
	WWAN_PORT_FIREHOSE = 4,
	__WWAN_PORT_MAX = 5,
	WWAN_PORT_MAX = 4,
	WWAN_PORT_UNKNOWN = 5,
};

struct wwan_port;

struct wwan_port_ops {
	int (*start)(struct wwan_port *);
	void (*stop)(struct wwan_port *);
	int (*tx)(struct wwan_port *, struct sk_buff___44 *);
	int (*tx_blocking)(struct wwan_port *, struct sk_buff___44 *);
	__poll_t (*tx_poll)(struct wwan_port *, struct file___225 *, poll_table___42 *);
};

struct wwan_port {
	enum wwan_port_type type;
	unsigned int start_count;
	long unsigned int flags;
	const struct wwan_port_ops *ops;
	struct mutex ops_lock;
	struct device___203 dev;
	struct sk_buff_head___43 rxq;
	wait_queue_head_t waitqueue;
	struct mutex data_lock;
	union {
		struct {
			struct ktermios termios;
			int mdmbits;
		} at_data;
	};
};

struct wwan_netdev_priv {
	u32 link_id;
	int: 32;
	u8 drv_priv[0];
};

struct wwan_ops {
	unsigned int priv_size;
	void (*setup)(struct net_device___45 *);
	int (*newlink)(void *, struct net_device___45 *, u32, struct netlink_ext_ack *);
	void (*dellink)(void *, struct net_device___45 *, struct list_head *);
};

struct ifinfomsg {
	unsigned char ifi_family;
	unsigned char __ifi_pad;
	short unsigned int ifi_type;
	int ifi_index;
	unsigned int ifi_flags;
	unsigned int ifi_change;
};

enum {
	IFLA_WWAN_UNSPEC = 0,
	IFLA_WWAN_LINK_ID = 1,
	__IFLA_WWAN_MAX = 2,
};

struct wwan_device {
	unsigned int id;
	struct device___203 dev;
	atomic_t port_id;
	const struct wwan_ops *ops;
	void *ops_ctxt;
};

struct dentry___228;

struct super_block___228;

struct module___212;

struct file_system_type___228 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___228 * (*mount)(struct file_system_type___228 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___228 *);
	struct module___212 *owner;
	struct file_system_type___228 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___228;

struct kiocb___228;

struct iov_iter___148;

struct poll_table_struct___153;

struct vm_area_struct___233;

struct inode___228;

struct file_lock___228;

struct page___233;

struct pipe_inode_info___78;

struct seq_file___203;

struct file_operations___229 {
	struct module___212 *owner;
	loff_t (*llseek)(struct file___228 *, loff_t, int);
	ssize_t (*read)(struct file___228 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___228 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___228 *, struct iov_iter___148 *);
	ssize_t (*write_iter)(struct kiocb___228 *, struct iov_iter___148 *);
	int (*iopoll)(struct kiocb___228 *, bool);
	int (*iterate)(struct file___228 *, struct dir_context *);
	int (*iterate_shared)(struct file___228 *, struct dir_context *);
	__poll_t (*poll)(struct file___228 *, struct poll_table_struct___153 *);
	long int (*unlocked_ioctl)(struct file___228 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___228 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___228 *, struct vm_area_struct___233 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___228 *, struct file___228 *);
	int (*flush)(struct file___228 *, fl_owner_t);
	int (*release)(struct inode___228 *, struct file___228 *);
	int (*fsync)(struct file___228 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___228 *, int);
	int (*lock)(struct file___228 *, int, struct file_lock___228 *);
	ssize_t (*sendpage)(struct file___228 *, struct page___233 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___228 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___228 *, long unsigned int);
	int (*flock)(struct file___228 *, int, struct file_lock___228 *);
	ssize_t (*splice_write)(struct pipe_inode_info___78 *, struct file___228 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___228 *, loff_t *, struct pipe_inode_info___78 *, size_t, unsigned int);
	int (*setlease)(struct file___228 *, long int, struct file_lock___228 **, void **);
	long int (*fallocate)(struct file___228 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___203 *, struct file___228 *);
	ssize_t (*copy_file_range)(struct file___228 *, loff_t, struct file___228 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___228 *, loff_t, struct file___228 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___228 *, loff_t, loff_t, int);
};

struct vmacache___233 {
	u64 seqnum;
	struct vm_area_struct___233 *vmas[4];
};

struct page_frag___233 {
	struct page___233 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___234;

struct pid___205;

struct nsproxy___214;

struct signal_struct___229;

struct bio_list___121;

struct backing_dev_info___110;

struct io_context___121;

struct css_set___158;

struct mem_cgroup___101;

struct request_queue___121;

struct vm_struct___211;

struct task_struct___235 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___235 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___234 *mm;
	struct mm_struct___234 *active_mm;
	struct vmacache___233 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___235 *real_parent;
	struct task_struct___235 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___235 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___205 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___214 *nsproxy;
	struct signal_struct___229 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___235 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___121 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___110 *backing_dev_info;
	struct io_context___121 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___158 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___78 *splice_pipe;
	struct page_frag___233 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___101 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___101 *active_memcg;
	struct request_queue___121 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___235 *oom_reaper_list;
	struct vm_struct___211 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___216;

struct kobj_type___216;

struct kernfs_node___216;

struct kobject___216 {
	const char *name;
	struct list_head entry;
	struct kobject___216 *parent;
	struct kset___216 *kset;
	struct kobj_type___216 *ktype;
	struct kernfs_node___216 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___213 {
	struct kobject___216 kobj;
	struct module___212 *mod;
	struct kobject___216 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___212 {
	struct module___212 *mod;
	struct latch_tree_node node;
};

struct module_layout___212 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___212 mtn;
};

struct module_attribute___212;

struct kernel_param___212;

struct module___212 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___213 mkobj;
	struct module_attribute___212 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___216 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___212 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___212 core_layout;
	struct module_layout___212 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___205;

struct upid___205 {
	int nr;
	struct pid_namespace___205 *ns;
};

struct pid_namespace___205 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___235 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___205 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___205 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___205 numbers[1];
};

typedef struct page___233 *pgtable_t___233;

struct address_space___228;

struct page_pool___66;

struct dev_pagemap___223;

struct page___233 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___228 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___233 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___233 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___234 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___223 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___223;

struct vm_area_struct___233 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___233 *vm_next;
	struct vm_area_struct___233 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___234 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___223 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___228 *vm_file;
	struct file___228 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___229 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___235 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___235 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___205 *pids[4];
	struct pid___205 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___234 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___233;

struct mm_struct___234 {
	struct {
		struct vm_area_struct___233 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___228 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___233 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___235 *owner;
		struct user_namespace___14 *user_ns;
		struct file___228 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___51;

struct cgroup_namespace___158;

struct nsproxy___214 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___205 *pid_ns_for_children;
	struct net___51 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___158 *cgroup_ns;
};

struct bio___121;

struct bio_list___121 {
	struct bio___121 *head;
	struct bio___121 *tail;
};

struct cgroup_subsys_state___158;

struct bdi_writeback___110 {
	struct backing_dev_info___110 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___158 *memcg_css;
	struct cgroup_subsys_state___158 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___206;

struct backing_dev_info___110 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___110 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___206 *dev;
	char dev_name[64];
	struct device___206 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___228 *debug_dir;
};

struct io_cq___121;

struct io_context___121 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___121 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___158;

struct css_set___158 {
	struct cgroup_subsys_state___158 *subsys[14];
	refcount_t refcount;
	struct css_set___158 *dom_cset;
	struct cgroup___158 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___158 *mg_src_cgrp;
	struct cgroup___158 *mg_dst_cgrp;
	struct css_set___158 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___228;

struct pipe_buffer___78;

struct pipe_inode_info___78 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___233 *tmp_page;
	struct fasync_struct___228 *fasync_readers;
	struct fasync_struct___228 *fasync_writers;
	struct pipe_buffer___78 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___158;

struct cgroup_subsys_state___158 {
	struct cgroup___158 *cgroup;
	struct cgroup_subsys___158 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___158 *parent;
};

struct cgroup_file___158 {
	struct kernfs_node___216 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___101;

struct mem_cgroup_per_node___101;

struct mem_cgroup___101 {
	struct cgroup_subsys_state___158 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___158 events_file;
	struct cgroup_file___158 events_local_file;
	struct cgroup_file___158 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___101 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___235 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___101 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___121;

struct blk_integrity___121 {
	const struct blk_integrity_profile___121 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___121 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___121 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___121;

struct elevator_queue___121;

struct blk_mq_ops___118;

struct blk_mq_hw_ctx___118;

struct gendisk___124;

struct blkcg_gq___112;

struct blk_mq_tag_set___118;

struct request_queue___121 {
	struct request___121 *last_merge;
	struct elevator_queue___121 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___118 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___118 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___124 *disk;
	struct kobject___216 kobj;
	struct kobject___216 *mq_kobj;
	struct blk_integrity___121 integrity;
	struct device___206 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___112 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___118 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___121 bio_split;
	struct dentry___228 *debugfs_dir;
	struct dentry___228 *sched_debugfs_dir;
	struct dentry___228 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___211 {
	struct vm_struct___211 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___233 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___228;

struct address_space___228 {
	struct inode___228 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___228 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___66 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___206 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___66 {
	u32 count;
	struct page___233 *cache[128];
};

struct page_pool___66 {
	struct page_pool_params___66 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___233 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___66 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___223;

struct dev_pagemap___223 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___223 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___228;

struct path___228 {
	struct vfsmount___228 *mnt;
	struct dentry___228 *dentry;
};

struct fown_struct___205 {
	rwlock_t lock;
	struct pid___205 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___228 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___228 f_path;
	struct inode___228 *f_inode;
	const struct file_operations___229 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___205 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___228 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___223;

struct vm_operations_struct___223 {
	void (*open)(struct vm_area_struct___233 *);
	void (*close)(struct vm_area_struct___233 *);
	int (*may_split)(struct vm_area_struct___233 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___233 *);
	int (*mprotect)(struct vm_area_struct___233 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___223 *);
	vm_fault_t (*huge_fault)(struct vm_fault___223 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___223 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___233 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___223 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___223 *);
	int (*access)(struct vm_area_struct___233 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___233 *);
	int (*set_policy)(struct vm_area_struct___233 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___233 *, long unsigned int);
	struct page___233 * (*find_special_page)(struct vm_area_struct___233 *, long unsigned int);
};

struct core_thread___233 {
	struct task_struct___235 *task;
	struct core_thread___233 *next;
};

struct core_state___233 {
	atomic_t nr_threads;
	struct core_thread___233 dumper;
	struct completion startup;
};

struct vm_fault___223 {
	const struct {
		struct vm_area_struct___233 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___233 *cow_page;
	struct page___233 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___233 prealloc_pte;
};

struct pglist_data___109;

struct lruvec___109 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___109 *pgdat;
};

struct zone___109 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___109 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___109 {
	struct zone___109 *zone;
	int zone_idx;
};

struct zonelist___109 {
	struct zoneref___109 _zonerefs[321];
};

struct pglist_data___109 {
	struct zone___109 node_zones[5];
	struct zonelist___109 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___235 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___235 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___109 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___228;

struct dentry___228 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___228 *d_parent;
	struct qstr d_name;
	struct inode___228 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___228 *d_op;
	struct super_block___228 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___228;

struct inode___228 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___228 *i_op;
	struct super_block___228 *i_sb;
	struct address_space___228 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___110 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___229 *i_fop;
		void (*free_inode)(struct inode___228 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___228 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___78 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___228 {
	int (*d_revalidate)(struct dentry___228 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___228 *, unsigned int);
	int (*d_hash)(const struct dentry___228 *, struct qstr *);
	int (*d_compare)(const struct dentry___228 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___228 *);
	int (*d_init)(struct dentry___228 *);
	void (*d_release)(struct dentry___228 *);
	void (*d_prune)(struct dentry___228 *);
	void (*d_iput)(struct dentry___228 *, struct inode___228 *);
	char * (*d_dname)(struct dentry___228 *, char *, int);
	struct vfsmount___228 * (*d_automount)(struct path___228 *);
	int (*d_manage)(const struct path___228 *, bool);
	struct dentry___228 * (*d_real)(struct dentry___228 *, const struct inode___228 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___228;

struct mem_dqinfo___228 {
	struct quota_format_type___228 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___228;

struct quota_info___228 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___228 *files[3];
	struct mem_dqinfo___228 info[3];
	const struct quota_format_ops___228 *ops[3];
};

struct rcuwait___229 {
	struct task_struct___235 *task;
};

struct percpu_rw_semaphore___229 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___229 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___228 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___229 rw_sem[3];
};

struct shrink_control___101;

struct shrinker___101 {
	long unsigned int (*count_objects)(struct shrinker___101 *, struct shrink_control___101 *);
	long unsigned int (*scan_objects)(struct shrinker___101 *, struct shrink_control___101 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___228;

struct dquot_operations___228;

struct quotactl_ops___228;

struct block_device___124;

struct super_block___228 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___228 *s_type;
	const struct super_operations___228 *s_op;
	const struct dquot_operations___228 *dq_op;
	const struct quotactl_ops___228 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___228 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___124 *s_bdev;
	struct backing_dev_info___110 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___228 s_dquot;
	struct sb_writers___228 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___228 *s_d_op;
	int cleancache_poolid;
	struct shrinker___101 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___228 {
	struct dentry___228 *mnt_root;
	struct super_block___228 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___101 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___101 *memcg;
};

struct psi_group___158 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___235 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___42;

struct cgroup_bpf___42 {
	struct bpf_prog_array___42 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___42 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___158;

struct cgroup_rstat_cpu___158;

struct cgroup___158 {
	struct cgroup_subsys_state___158 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___216 *kn;
	struct cgroup_file___158 procs_file;
	struct cgroup_file___158 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___158 *subsys[14];
	struct cgroup_root___158 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___158 *dom_cgrp;
	struct cgroup___158 *old_dom_cgrp;
	struct cgroup_rstat_cpu___158 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___158 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___121 {
	struct request_queue___121 *q;
	struct io_context___121 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___228 {
	struct file___228 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___228 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___106 *ki_waitq;
	};
};

struct iattr___228 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___228 *ia_file;
};

struct dquot___228 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___228 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___228 {
	int qf_fmt_id;
	const struct quota_format_ops___228 *qf_ops;
	struct module___212 *qf_owner;
	struct quota_format_type___228 *qf_next;
};

struct quota_format_ops___228 {
	int (*check_quota_file)(struct super_block___228 *, int);
	int (*read_file_info)(struct super_block___228 *, int);
	int (*write_file_info)(struct super_block___228 *, int);
	int (*free_file_info)(struct super_block___228 *, int);
	int (*read_dqblk)(struct dquot___228 *);
	int (*commit_dqblk)(struct dquot___228 *);
	int (*release_dqblk)(struct dquot___228 *);
	int (*get_next_id)(struct super_block___228 *, struct kqid *);
};

struct dquot_operations___228 {
	int (*write_dquot)(struct dquot___228 *);
	struct dquot___228 * (*alloc_dquot)(struct super_block___228 *, int);
	void (*destroy_dquot)(struct dquot___228 *);
	int (*acquire_dquot)(struct dquot___228 *);
	int (*release_dquot)(struct dquot___228 *);
	int (*mark_dirty)(struct dquot___228 *);
	int (*write_info)(struct super_block___228 *, int);
	qsize_t * (*get_reserved_space)(struct inode___228 *);
	int (*get_projid)(struct inode___228 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___228 *, qsize_t *);
	int (*get_next_id)(struct super_block___228 *, struct kqid *);
};

struct quotactl_ops___228 {
	int (*quota_on)(struct super_block___228 *, int, int, const struct path___228 *);
	int (*quota_off)(struct super_block___228 *, int);
	int (*quota_enable)(struct super_block___228 *, unsigned int);
	int (*quota_disable)(struct super_block___228 *, unsigned int);
	int (*quota_sync)(struct super_block___228 *, int);
	int (*set_info)(struct super_block___228 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___228 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___228 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___228 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___228 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___228 *, unsigned int);
};

struct writeback_control___110;

struct address_space_operations___228 {
	int (*writepage)(struct page___233 *, struct writeback_control___110 *);
	int (*readpage)(struct file___228 *, struct page___233 *);
	int (*writepages)(struct address_space___228 *, struct writeback_control___110 *);
	int (*set_page_dirty)(struct page___233 *);
	int (*readpages)(struct file___228 *, struct address_space___228 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___228 *, struct address_space___228 *, loff_t, unsigned int, unsigned int, struct page___233 **, void **);
	int (*write_end)(struct file___228 *, struct address_space___228 *, loff_t, unsigned int, unsigned int, struct page___233 *, void *);
	sector_t (*bmap)(struct address_space___228 *, sector_t);
	void (*invalidatepage)(struct page___233 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___233 *, gfp_t);
	void (*freepage)(struct page___233 *);
	ssize_t (*direct_IO)(struct kiocb___228 *, struct iov_iter___148 *);
	int (*migratepage)(struct address_space___228 *, struct page___233 *, struct page___233 *, enum migrate_mode);
	bool (*isolate_page)(struct page___233 *, isolate_mode_t);
	void (*putback_page)(struct page___233 *);
	int (*launder_page)(struct page___233 *);
	int (*is_partially_uptodate)(struct page___233 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___233 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___228 *, struct page___233 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___228 *, sector_t *);
	void (*swap_deactivate)(struct file___228 *);
};

struct writeback_control___110 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___110 *wb;
	struct inode___228 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___145;

struct iov_iter___148 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___145 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___78 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___228 {
	struct dentry___228 * (*lookup)(struct inode___228 *, struct dentry___228 *, unsigned int);
	const char * (*get_link)(struct dentry___228 *, struct inode___228 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___228 *, int);
	struct posix_acl * (*get_acl)(struct inode___228 *, int, bool);
	int (*readlink)(struct dentry___228 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___228 *, struct dentry___228 *, umode_t, bool);
	int (*link)(struct dentry___228 *, struct inode___228 *, struct dentry___228 *);
	int (*unlink)(struct inode___228 *, struct dentry___228 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___228 *, struct dentry___228 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___228 *, struct dentry___228 *, umode_t);
	int (*rmdir)(struct inode___228 *, struct dentry___228 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___228 *, struct dentry___228 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___228 *, struct dentry___228 *, struct inode___228 *, struct dentry___228 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___228 *, struct iattr___228 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___228 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___228 *, char *, size_t);
	int (*fiemap)(struct inode___228 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___228 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___228 *, struct dentry___228 *, struct file___228 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___228 *, struct dentry___228 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___228 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___228 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___228 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___228 {
	void (*fl_copy_lock)(struct file_lock___228 *, struct file_lock___228 *);
	void (*fl_release_private)(struct file_lock___228 *);
};

struct lock_manager_operations___228;

struct file_lock___228 {
	struct file_lock___228 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___228 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___228 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___228 *fl_ops;
	const struct lock_manager_operations___228 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___228 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___228 *);
	int (*lm_grant)(struct file_lock___228 *, int);
	bool (*lm_break)(struct file_lock___228 *);
	int (*lm_change)(struct file_lock___228 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___228 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___228 *);
};

struct fasync_struct___228 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___228 *fa_next;
	struct file___228 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___228 {
	struct inode___228 * (*alloc_inode)(struct super_block___228 *);
	void (*destroy_inode)(struct inode___228 *);
	void (*free_inode)(struct inode___228 *);
	void (*dirty_inode)(struct inode___228 *, int);
	int (*write_inode)(struct inode___228 *, struct writeback_control___110 *);
	int (*drop_inode)(struct inode___228 *);
	void (*evict_inode)(struct inode___228 *);
	void (*put_super)(struct super_block___228 *);
	int (*sync_fs)(struct super_block___228 *, int);
	int (*freeze_super)(struct super_block___228 *);
	int (*freeze_fs)(struct super_block___228 *);
	int (*thaw_super)(struct super_block___228 *);
	int (*unfreeze_fs)(struct super_block___228 *);
	int (*statfs)(struct dentry___228 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___228 *, int *, char *);
	void (*umount_begin)(struct super_block___228 *);
	int (*show_options)(struct seq_file___203 *, struct dentry___228 *);
	int (*show_devname)(struct seq_file___203 *, struct dentry___228 *);
	int (*show_path)(struct seq_file___203 *, struct dentry___228 *);
	int (*show_stats)(struct seq_file___203 *, struct dentry___228 *);
	ssize_t (*quota_read)(struct super_block___228 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___228 *, int, const char *, size_t, loff_t);
	struct dquot___228 ** (*get_dquots)(struct inode___228 *);
	long int (*nr_cached_objects)(struct super_block___228 *, struct shrink_control___101 *);
	long int (*free_cached_objects)(struct super_block___228 *, struct shrink_control___101 *);
	struct file___228 * (*real_loop)(struct file___228 *);
};

struct wakeup_source___206;

struct dev_pm_info___206 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___206 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___206 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___206;

struct bus_type___206;

struct device_driver___206;

struct dev_pm_domain___206;

struct fwnode_handle___202;

struct class___206;

struct attribute_group___216;

struct device___206 {
	struct kobject___216 kobj;
	struct device___206 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___206 *type;
	struct bus_type___206 *bus;
	struct device_driver___206 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___206 power;
	struct dev_pm_domain___206 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___202 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___206 *class;
	const struct attribute_group___216 **groups;
	void (*release)(struct device___206 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___124 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___228 *bd_inode;
	struct super_block___228 *bd_super;
	void *bd_claiming;
	struct device___206 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___216 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___124 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___228 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___160)(struct file___228 *, wait_queue_head_t *, struct poll_table_struct___153 *);

struct poll_table_struct___153 {
	poll_queue_proc___160 _qproc;
	__poll_t _key;
};

struct seq_operations___203;

struct seq_file___203 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___203 *op;
	int poll_event;
	const struct file___228 *file;
	void *private;
};

typedef void bio_end_io_t___121(struct bio___121 *);

struct bio_vec___145 {
	struct page___233 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___121;

struct bio___121 {
	struct bio___121 *bi_next;
	struct block_device___124 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___121 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___112 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___121 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___145 *bi_io_vec;
	struct bio_set___121 *bi_pool;
	struct bio_vec___145 bi_inline_vecs[0];
};

struct kernfs_root___216;

struct kernfs_elem_dir___216 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___216 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___216;

struct kernfs_root___216 {
	struct kernfs_node___216 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___216 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___216 {
	struct kernfs_node___216 *target_kn;
};

struct kernfs_ops___216;

struct kernfs_elem_attr___216 {
	const struct kernfs_ops___216 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___216 *notify_next;
};

struct kernfs_node___216 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___216 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___216 dir;
		struct kernfs_elem_symlink___216 symlink;
		struct kernfs_elem_attr___216 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___216;

struct kernfs_ops___216 {
	int (*open)(struct kernfs_open_file___216 *);
	void (*release)(struct kernfs_open_file___216 *);
	int (*seq_show)(struct seq_file___203 *, void *);
	void * (*seq_start)(struct seq_file___203 *, loff_t *);
	void * (*seq_next)(struct seq_file___203 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___203 *, void *);
	ssize_t (*read)(struct kernfs_open_file___216 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___216 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___216 *, struct poll_table_struct___153 *);
	int (*mmap)(struct kernfs_open_file___216 *, struct vm_area_struct___233 *);
};

struct kernfs_syscall_ops___216 {
	int (*show_options)(struct seq_file___203 *, struct kernfs_root___216 *);
	int (*mkdir)(struct kernfs_node___216 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___216 *);
	int (*rename)(struct kernfs_node___216 *, struct kernfs_node___216 *, const char *);
	int (*show_path)(struct seq_file___203 *, struct kernfs_node___216 *, struct kernfs_root___216 *);
};

struct kernfs_open_file___216 {
	struct kernfs_node___216 *kn;
	struct file___228 *file;
	struct seq_file___203 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___223 *vm_ops;
};

struct sock___36;

struct kobj_ns_type_operations___35 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___36 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___51 *net;
} possible_net_t___46;

struct proto___35;

struct sock_common___35 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___35 *skc_prot;
	possible_net_t___46 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___36 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___47;

struct sk_buff_head___46 {
	struct sk_buff___47 *next;
	struct sk_buff___47 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___35 {
	struct cgroup___158 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___35;

struct socket_wq___36;

struct dst_entry___35;

struct socket___37;

struct net_device___48;

struct sock_reuseport___6;

struct sock___36 {
	struct sock_common___35 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___46 sk_error_queue;
	struct sk_buff___47 *sk_rx_skb_cache;
	struct sk_buff_head___46 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___47 *head;
		struct sk_buff___47 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___35 *sk_filter;
	union {
		struct socket_wq___36 *sk_wq;
		struct socket_wq___36 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___35 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___35 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___47 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___47 *sk_tx_skb_cache;
	struct sk_buff_head___46 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___233 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___35 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___205 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___37 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___35 sk_cgrp_data;
	struct mem_cgroup___101 *sk_memcg;
	void (*sk_state_change)(struct sock___36 *);
	void (*sk_data_ready)(struct sock___36 *);
	void (*sk_write_space)(struct sock___36 *);
	void (*sk_error_report)(struct sock___36 *);
	int (*sk_backlog_rcv)(struct sock___36 *, struct sk_buff___47 *);
	struct sk_buff___47 * (*sk_validate_xmit_skb)(struct sock___36 *, struct net_device___48 *, struct sk_buff___47 *);
	void (*sk_destruct)(struct sock___36 *);
	struct sock_reuseport___6 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___216;

struct attribute_group___216 {
	const char *name;
	umode_t (*is_visible)(struct kobject___216 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___216 *, struct bin_attribute___216 *, int);
	struct attribute **attrs;
	struct bin_attribute___216 **bin_attrs;
};

struct bin_attribute___216 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___228 * (*f_mapping)();
	ssize_t (*read)(struct file___228 *, struct kobject___216 *, struct bin_attribute___216 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___228 *, struct kobject___216 *, struct bin_attribute___216 *, char *, loff_t, size_t);
	int (*mmap)(struct file___228 *, struct kobject___216 *, struct bin_attribute___216 *, struct vm_area_struct___233 *);
};

struct sysfs_ops___216 {
	ssize_t (*show)(struct kobject___216 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___216 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___216;

struct kset___216 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___216 kobj;
	const struct kset_uevent_ops___216 *uevent_ops;
};

struct kobj_type___216 {
	void (*release)(struct kobject___216 *);
	const struct sysfs_ops___216 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___216 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___216 *);
	const void * (*namespace)(struct kobject___216 *);
	void (*get_ownership)(struct kobject___216 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___216 {
	int (* const filter)(struct kset___216 *, struct kobject___216 *);
	const char * (* const name)(struct kset___216 *, struct kobject___216 *);
	int (* const uevent)(struct kset___216 *, struct kobject___216 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___212 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___212 *);
	int (*get)(char *, const struct kernel_param___212 *);
	void (*free)(void *);
};

struct kparam_array___212;

struct kernel_param___212 {
	const char *name;
	struct module___212 *mod;
	const struct kernel_param_ops___212 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___212 *arr;
	};
};

struct kparam_array___212 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___212 *ops;
	void *elem;
};

struct module_attribute___212 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___212 *, struct module_kobject___213 *, char *);
	ssize_t (*store)(struct module_attribute___212 *, struct module_kobject___213 *, const char *, size_t);
	void (*setup)(struct module___212 *, const char *);
	int (*test)(struct module___212 *);
	void (*free)(struct module___212 *);
};

struct msghdr___37 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___148 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___228 *msg_iocb;
};

struct sk_buff___47 {
	union {
		struct {
			struct sk_buff___47 *next;
			struct sk_buff___47 *prev;
			union {
				struct net_device___48 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___36 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___47 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___51;

struct fqdir___51 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___51 *f;
	struct net___51 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___51;

struct inet_frags___51 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___51 *, const void *);
	void (*destructor)(struct inet_frag_queue___51 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___17;

struct fib_rules_ops___35;

struct tcp_congestion_ops___5;

struct fib_notifier_ops___35;

struct netns_ipv4___51 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___17 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___35 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___36 *fibnl;
	struct sock___36 **icmp_sk;
	struct sock___36 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___36 **tcp_sk;
	struct fqdir___51 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___5 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___35 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___35 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___35 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___35;

struct dst_ops___51 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___51 *);
	struct dst_entry___35 * (*check)(struct dst_entry___35 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___35 *);
	unsigned int (*mtu)(const struct dst_entry___35 *);
	u32 * (*cow_metrics)(struct dst_entry___35 *, long unsigned int);
	void (*destroy)(struct dst_entry___35 *);
	void (*ifdown)(struct dst_entry___35 *, struct net_device___48 *, int);
	struct dst_entry___35 * (*negative_advice)(struct dst_entry___35 *);
	void (*link_failure)(struct sk_buff___47 *);
	void (*update_pmtu)(struct dst_entry___35 *, struct sock___36 *, struct sk_buff___47 *, u32, bool);
	void (*redirect)(struct dst_entry___35 *, struct sock___36 *, struct sk_buff___47 *);
	int (*local_out)(struct net___51 *, struct sock___36 *, struct sk_buff___47 *);
	struct neighbour___35 * (*neigh_lookup)(const struct dst_entry___35 *, struct sk_buff___47 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___35 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___51 {
	struct dst_ops___51 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___51 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___35 *fib6_rules_ops;
	struct sock___36 **icmp_sk;
	struct sock___36 *ndisc_sk;
	struct sock___36 *tcp_sk;
	struct sock___36 *igmp_sk;
	struct sock___36 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___35 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___35 *notifier_ops;
	struct fib_notifier_ops___35 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___51 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___51 *fqdir;
};

struct netns_sctp___35 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___36 *ctl_sock;
	struct sock___36 *udp4_sock;
	struct sock___36 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___42;

struct netns_bpf___42 {
	struct bpf_prog_array___42 *run_array[2];
	struct bpf_prog___42 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___51 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___36 *nlsk;
	struct sock___36 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___51 xfrm4_dst_ops;
	struct dst_ops___51 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___51 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___36 *rtnl;
	struct sock___36 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___48 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___51 ipv4;
	struct netns_ipv6___51 ipv6;
	struct netns_ieee802154_lowpan___51 ieee802154_lowpan;
	struct netns_sctp___35 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___46 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___42 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___51 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___36 *crypto_nlsk;
	struct sock___36 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___51 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___47 *fragments_tail;
	struct sk_buff___47 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___51 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___17 {
	struct ip_ra_chain___17 *next;
	struct sock___36 *sk;
	union {
		void (*destructor)(struct sock___36 *);
		struct sock___36 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___35;

struct fib_lookup_arg___35;

struct fib_rules_ops___35 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___35 *, struct flowi *, int, struct fib_lookup_arg___35 *);
	bool (*suppress)(struct fib_rule___35 *, int, struct fib_lookup_arg___35 *);
	int (*match)(struct fib_rule___35 *, struct flowi *, int);
	int (*configure)(struct fib_rule___35 *, struct sk_buff___47 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___35 *);
	int (*compare)(struct fib_rule___35 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___35 *, struct sk_buff___47 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___35 *);
	void (*flush_cache)(struct fib_rules_ops___35 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___212 *owner;
	struct net___51 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___5 {
	u32 (*ssthresh)(struct sock___36 *);
	void (*cong_avoid)(struct sock___36 *, u32, u32);
	void (*set_state)(struct sock___36 *, u8);
	void (*cwnd_event)(struct sock___36 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___36 *, u32);
	void (*pkts_acked)(struct sock___36 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___36 *);
	void (*cong_control)(struct sock___36 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___36 *);
	u32 (*sndbuf_expand)(struct sock___36 *);
	size_t (*get_info)(struct sock___36 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___212 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___36 *);
	void (*release)(struct sock___36 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___35 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___51 *);
	int (*fib_dump)(struct net___51 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___212 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___18;

struct dst_entry___35 {
	struct net_device___48 *dev;
	struct dst_ops___51 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___47 *);
	int (*output)(struct net___51 *, struct sock___36 *, struct sk_buff___47 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___18 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___46(struct sk_buff___47 **);

struct bpf_xdp_entity___42 {
	struct bpf_prog___42 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___46;

struct net_device_ops___46;

struct ethtool_ops___21;

struct l3mdev_ops___35;

struct ndisc_ops___23;

struct xfrmdev_ops___46;

struct header_ops___46;

struct inet6_dev___23;

struct netdev_rx_queue___46;

struct mini_Qdisc___42;

struct netdev_queue___46;

struct Qdisc___42;

struct rtnl_link_ops___42;

struct dcbnl_rtnl_ops___46;

struct net_device___48 {
	char name[16];
	struct netdev_name_node___46 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___46 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___21 *ethtool_ops;
	const struct l3mdev_ops___35 *l3mdev_ops;
	const struct ndisc_ops___23 *ndisc_ops;
	const struct xfrmdev_ops___46 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___46 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___216 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___23 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___46 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___42 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___46 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___42 *miniq_ingress;
	struct netdev_queue___46 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___46 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___42 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___42 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___46 = 0,
		NETREG_REGISTERED___46 = 1,
		NETREG_UNREGISTERING___46 = 2,
		NETREG_UNREGISTERED___46 = 3,
		NETREG_RELEASED___46 = 4,
		NETREG_DUMMY___46 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___46 = 0,
		RTNL_LINK_INITIALIZING___46 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___48 *);
	struct netpoll_info *npinfo;
	possible_net_t___46 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___206 dev;
	const struct attribute_group___216 *sysfs_groups[4];
	const struct attribute_group___216 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___42 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___46 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___42 xdp_state[3];
	long: 64;
};

struct neigh_table___35;

struct neigh_parms___35;

struct neigh_ops___35;

struct neighbour___35 {
	struct neighbour___35 *next;
	struct neigh_table___35 *tbl;
	struct neigh_parms___35 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___46 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___35 *, struct sk_buff___47 *);
	const struct neigh_ops___35 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___48 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___42 {
	struct bpf_prog___42 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___42 {
	struct callback_head rcu;
	struct bpf_prog_array_item___42 items[0];
};

struct bpf_prog_aux___49;

struct bpf_prog___42 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___49 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___223 {
	void (*page_free)(struct page___233 *);
	void (*kill)(struct dev_pagemap___223 *);
	void (*cleanup)(struct dev_pagemap___223 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___223 *);
};

struct fwnode_operations___202;

struct fwnode_handle___202 {
	struct fwnode_handle___202 *secondary;
	const struct fwnode_operations___202 *ops;
	struct device___206 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___202;

struct fwnode_endpoint___202;

struct fwnode_operations___202 {
	struct fwnode_handle___202 * (*get)(struct fwnode_handle___202 *);
	void (*put)(struct fwnode_handle___202 *);
	bool (*device_is_available)(const struct fwnode_handle___202 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___202 *, const struct device___206 *);
	bool (*property_present)(const struct fwnode_handle___202 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___202 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___202 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___202 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*get_parent)(const struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*get_next_child_node)(const struct fwnode_handle___202 *, struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*get_named_child_node)(const struct fwnode_handle___202 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___202 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___202 *);
	struct fwnode_handle___202 * (*graph_get_next_endpoint)(const struct fwnode_handle___202 *, struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*graph_get_remote_endpoint)(const struct fwnode_handle___202 *);
	struct fwnode_handle___202 * (*graph_get_port_parent)(struct fwnode_handle___202 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___202 *, struct fwnode_endpoint___202 *);
	int (*add_links)(struct fwnode_handle___202 *);
};

struct fwnode_endpoint___202 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___202 *local_fwnode;
};

struct fwnode_reference_args___202 {
	struct fwnode_handle___202 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___158 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___158 *root_cset;
};

struct socket_wq___36 {
	wait_queue_head_t wait;
	struct fasync_struct___228 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___36;

struct socket___37 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___228 *file;
	struct sock___36 *sk;
	const struct proto_ops___36 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___36 wq;
};

typedef int (*sk_read_actor_t___35)(read_descriptor_t *, struct sk_buff___47 *, unsigned int, size_t);

struct proto_ops___36 {
	int family;
	struct module___212 *owner;
	int (*release)(struct socket___37 *);
	int (*bind)(struct socket___37 *, struct sockaddr *, int);
	int (*connect)(struct socket___37 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___37 *, struct socket___37 *);
	int (*accept)(struct socket___37 *, struct socket___37 *, int, bool);
	int (*getname)(struct socket___37 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___228 *, struct socket___37 *, struct poll_table_struct___153 *);
	int (*ioctl)(struct socket___37 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___37 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___37 *, void *, bool, bool);
	int (*listen)(struct socket___37 *, int);
	int (*shutdown)(struct socket___37 *, int);
	int (*setsockopt)(struct socket___37 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___37 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___203 *, struct socket___37 *);
	int (*sendmsg)(struct socket___37 *, struct msghdr___37 *, size_t);
	int (*recvmsg)(struct socket___37 *, struct msghdr___37 *, size_t, int);
	int (*mmap)(struct file___228 *, struct socket___37 *, struct vm_area_struct___233 *);
	ssize_t (*sendpage)(struct socket___37 *, struct page___233 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___37 *, loff_t *, struct pipe_inode_info___78 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___36 *, int);
	int (*peek_len)(struct socket___37 *);
	int (*read_sock)(struct sock___36 *, read_descriptor_t *, sk_read_actor_t___35);
	int (*sendpage_locked)(struct sock___36 *, struct page___233 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___36 *, struct msghdr___37 *, size_t);
	int (*set_rcvlowat)(struct sock___36 *, int);
};

struct dev_pm_ops___206 {
	int (*prepare)(struct device___206 *);
	void (*complete)(struct device___206 *);
	int (*suspend)(struct device___206 *);
	int (*resume)(struct device___206 *);
	int (*freeze)(struct device___206 *);
	int (*thaw)(struct device___206 *);
	int (*poweroff)(struct device___206 *);
	int (*restore)(struct device___206 *);
	int (*suspend_late)(struct device___206 *);
	int (*resume_early)(struct device___206 *);
	int (*freeze_late)(struct device___206 *);
	int (*thaw_early)(struct device___206 *);
	int (*poweroff_late)(struct device___206 *);
	int (*restore_early)(struct device___206 *);
	int (*suspend_noirq)(struct device___206 *);
	int (*resume_noirq)(struct device___206 *);
	int (*freeze_noirq)(struct device___206 *);
	int (*thaw_noirq)(struct device___206 *);
	int (*poweroff_noirq)(struct device___206 *);
	int (*restore_noirq)(struct device___206 *);
	int (*runtime_suspend)(struct device___206 *);
	int (*runtime_resume)(struct device___206 *);
	int (*runtime_idle)(struct device___206 *);
};

struct wakeup_source___206 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___206 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___206 {
	struct dev_pm_ops___206 ops;
	int (*start)(struct device___206 *);
	void (*detach)(struct device___206 *, bool);
	int (*activate)(struct device___206 *);
	void (*sync)(struct device___206 *);
	void (*dismiss)(struct device___206 *);
};

struct bus_type___206 {
	const char *name;
	const char *dev_name;
	struct device___206 *dev_root;
	const struct attribute_group___216 **bus_groups;
	const struct attribute_group___216 **dev_groups;
	const struct attribute_group___216 **drv_groups;
	int (*match)(struct device___206 *, struct device_driver___206 *);
	int (*uevent)(struct device___206 *, struct kobj_uevent_env *);
	int (*probe)(struct device___206 *);
	void (*sync_state)(struct device___206 *);
	void (*remove)(struct device___206 *);
	void (*shutdown)(struct device___206 *);
	int (*online)(struct device___206 *);
	int (*offline)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	int (*num_vf)(struct device___206 *);
	int (*dma_configure)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___206 {
	const char *name;
	struct bus_type___206 *bus;
	struct module___212 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___206 *);
	void (*sync_state)(struct device___206 *);
	int (*remove)(struct device___206 *);
	void (*shutdown)(struct device___206 *);
	int (*suspend)(struct device___206 *, pm_message_t);
	int (*resume)(struct device___206 *);
	const struct attribute_group___216 **groups;
	const struct attribute_group___216 **dev_groups;
	const struct dev_pm_ops___206 *pm;
	void (*coredump)(struct device___206 *);
	struct driver_private *p;
};

struct device_type___206 {
	const char *name;
	const struct attribute_group___216 **groups;
	int (*uevent)(struct device___206 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___206 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___206 *);
	const struct dev_pm_ops___206 *pm;
};

struct class___206 {
	const char *name;
	struct module___212 *owner;
	const struct attribute_group___216 **class_groups;
	const struct attribute_group___216 **dev_groups;
	struct kobject___216 *dev_kobj;
	int (*dev_uevent)(struct device___206 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___206 *, umode_t *);
	void (*class_release)(struct class___206 *);
	void (*dev_release)(struct device___206 *);
	int (*shutdown_pre)(struct device___206 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___206 *);
	void (*get_ownership)(struct device___206 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___206 *pm;
	struct subsys_private *p;
};

struct device_attribute___38 {
	struct attribute attr;
	ssize_t (*show)(struct device___206 *, struct device_attribute___38 *, char *);
	ssize_t (*store)(struct device___206 *, struct device_attribute___38 *, const char *, size_t);
};

struct pipe_buf_operations___78;

struct pipe_buffer___78 {
	struct page___233 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___78 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___78 {
	int (*confirm)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
	void (*release)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
	bool (*try_steal)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
	bool (*get)(struct pipe_inode_info___78 *, struct pipe_buffer___78 *);
};

typedef struct bio_vec___145 skb_frag_t___6;

struct skb_shared_info___6 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___47 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___6 frags[17];
};

struct seq_operations___203 {
	void * (*start)(struct seq_file___203 *, loff_t *);
	void (*stop)(struct seq_file___203 *, void *);
	void * (*next)(struct seq_file___203 *, void *, loff_t *);
	int (*show)(struct seq_file___203 *, void *);
};

struct dcbnl_rtnl_ops___46 {
	int (*ieee_getets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___48 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___48 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___48 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___48 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___48 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___48 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___48 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___48 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___48 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___48 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___48 *);
	u8 (*setstate)(struct net_device___48 *, u8);
	void (*getpermhwaddr)(struct net_device___48 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___48 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___48 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___48 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___48 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___48 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___48 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___48 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___48 *, int, u8 *);
	void (*setpfccfg)(struct net_device___48 *, int, u8);
	void (*getpfccfg)(struct net_device___48 *, int, u8 *);
	u8 (*setall)(struct net_device___48 *);
	u8 (*getcap)(struct net_device___48 *, int, u8 *);
	int (*getnumtcs)(struct net_device___48 *, int, u8 *);
	int (*setnumtcs)(struct net_device___48 *, int, u8);
	u8 (*getpfcstate)(struct net_device___48 *);
	void (*setpfcstate)(struct net_device___48 *, u8);
	void (*getbcncfg)(struct net_device___48 *, int, u32 *);
	void (*setbcncfg)(struct net_device___48 *, int, u32);
	void (*getbcnrp)(struct net_device___48 *, int, u8 *);
	void (*setbcnrp)(struct net_device___48 *, int, u8);
	int (*setapp)(struct net_device___48 *, u8, u16, u8);
	int (*getapp)(struct net_device___48 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___48 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___48 *, int, u8);
	u8 (*getdcbx)(struct net_device___48 *);
	u8 (*setdcbx)(struct net_device___48 *, u8);
	int (*peer_getappinfo)(struct net_device___48 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___48 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___48 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___48 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___48 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___48 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___49;

typedef int (*bpf_iter_init_seq_priv_t___48)(void *, struct bpf_iter_aux_info___49 *);

struct bpf_map___49;

struct bpf_iter_aux_info___49 {
	struct bpf_map___49 *map;
};

struct bpf_iter_seq_info___48 {
	const struct seq_operations___203 *seq_ops;
	bpf_iter_init_seq_priv_t___48 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___48 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___49 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___49 *, struct file___228 *);
	void (*map_free)(struct bpf_map___49 *);
	int (*map_get_next_key)(struct bpf_map___49 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___49 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___49 *, void *);
	int (*map_lookup_batch)(struct bpf_map___49 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___49 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___49 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___49 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___49 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___49 *, void *);
	int (*map_update_elem)(struct bpf_map___49 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___49 *, void *);
	int (*map_push_elem)(struct bpf_map___49 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___49 *, void *);
	int (*map_peek_elem)(struct bpf_map___49 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___49 *, struct file___228 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___49 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___49 *, void *, struct seq_file___203 *);
	int (*map_check_btf)(const struct bpf_map___49 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___49 *, struct bpf_prog_aux___49 *);
	void (*map_poke_untrack)(struct bpf_map___49 *, struct bpf_prog_aux___49 *);
	void (*map_poke_run)(struct bpf_map___49 *, u32, struct bpf_prog___42 *, struct bpf_prog___42 *);
	int (*map_direct_value_addr)(const struct bpf_map___49 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___49 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___49 *, struct vm_area_struct___233 *);
	__poll_t (*map_poll)(struct bpf_map___49 *, struct file___228 *, struct poll_table_struct___153 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___49 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___49 *, const struct bpf_map___49 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___49 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___48 *iter_seq_info;
};

struct bpf_map___49 {
	const struct bpf_map_ops___48 *ops;
	struct bpf_map___49 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___101 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___48;

struct bpf_jit_poke_descriptor___48;

struct bpf_prog_ops___42;

struct btf_mod_pair___48;

struct bpf_prog_offload___46;

struct bpf_prog_aux___49 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___42 *dst_prog;
	struct bpf_trampoline___48 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___42 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___48 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___42 *ops;
	struct bpf_map___49 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___48 *used_btfs;
	struct bpf_prog___42 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___49 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___46 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___46;

struct bpf_map_dev_ops___46 {
	int (*map_get_next_key)(struct bpf_offloaded_map___46 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___46 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___46 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___46 *, void *);
};

struct bpf_offloaded_map___46 {
	struct bpf_map___49 map;
	struct net_device___48 *netdev;
	const struct bpf_map_dev_ops___46 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___42 {
	int (*test_run)(struct bpf_prog___42 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___46 {
	struct bpf_prog___42 *prog;
	struct net_device___48 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___48 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___42 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___212 *mod;
};

struct bpf_jit_poke_descriptor___48 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___49 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___48 {
	struct btf *btf;
	struct module___212 *module;
};

struct cftype___158;

struct cgroup_subsys___158 {
	struct cgroup_subsys_state___158 * (*css_alloc)(struct cgroup_subsys_state___158 *);
	int (*css_online)(struct cgroup_subsys_state___158 *);
	void (*css_offline)(struct cgroup_subsys_state___158 *);
	void (*css_released)(struct cgroup_subsys_state___158 *);
	void (*css_free)(struct cgroup_subsys_state___158 *);
	void (*css_reset)(struct cgroup_subsys_state___158 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___158 *, int);
	int (*css_extra_stat_show)(struct seq_file___203 *, struct cgroup_subsys_state___158 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___235 *, struct css_set___158 *);
	void (*cancel_fork)(struct task_struct___235 *, struct css_set___158 *);
	void (*fork)(struct task_struct___235 *);
	void (*exit)(struct task_struct___235 *);
	void (*release)(struct task_struct___235 *);
	void (*bind)(struct cgroup_subsys_state___158 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___158 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___158 *dfl_cftypes;
	struct cftype___158 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___158 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___158 *updated_children;
	struct cgroup___158 *updated_next;
};

struct cgroup_root___158 {
	struct kernfs_root___216 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___158 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___158 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___158 *ss;
	struct list_head node;
	struct kernfs_ops___216 *kf_ops;
	int (*open)(struct kernfs_open_file___216 *);
	void (*release)(struct kernfs_open_file___216 *);
	u64 (*read_u64)(struct cgroup_subsys_state___158 *, struct cftype___158 *);
	s64 (*read_s64)(struct cgroup_subsys_state___158 *, struct cftype___158 *);
	int (*seq_show)(struct seq_file___203 *, void *);
	void * (*seq_start)(struct seq_file___203 *, loff_t *);
	void * (*seq_next)(struct seq_file___203 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___203 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___158 *, struct cftype___158 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___158 *, struct cftype___158 *, s64);
	ssize_t (*write)(struct kernfs_open_file___216 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___216 *, struct poll_table_struct___153 *);
};

struct xdp_rxq_info___46 {
	struct net_device___48 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___46 {
	struct net_device___48 *dev;
};

struct xdp_buff___46 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___46 *rxq;
	struct xdp_txq_info___46 *txq;
	u32 frame_sz;
};

struct xdp_frame___46 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___48 *dev_rx;
};

struct netlink_callback___46 {
	struct sk_buff___47 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___47 *, struct netlink_callback___46 *);
	int (*done)(struct netlink_callback___46 *);
	void *data;
	struct module___212 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___46 {
	int (*create)(struct sk_buff___47 *, struct net_device___48 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___47 *, unsigned char *);
	int (*cache)(const struct neighbour___35 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___48 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___47 *);
};

struct napi_struct___5 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___5 *, int);
	int poll_owner;
	struct net_device___48 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___47 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___235 *thread;
};

struct netdev_queue___46 {
	struct net_device___48 *dev;
	struct Qdisc___42 *qdisc;
	struct Qdisc___42 *qdisc_sleeping;
	struct kobject___216 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___48 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___42 {
	struct sk_buff___47 *head;
	struct sk_buff___47 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___42;

struct Qdisc___42 {
	int (*enqueue)(struct sk_buff___47 *, struct Qdisc___42 *, struct sk_buff___47 **);
	struct sk_buff___47 * (*dequeue)(struct Qdisc___42 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___42 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___46 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___46 gso_skb;
	struct qdisc_skb_head___42 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___42 *next_sched;
	struct sk_buff_head___46 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___46 {
	struct xdp_rxq_info___46 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___216 kobj;
	struct net_device___48 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___46 {
	enum net_device_path_type type;
	const struct net_device___48 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___46 = 0,
				DEV_PATH_BR_VLAN_TAG___46 = 1,
				DEV_PATH_BR_VLAN_UNTAG___46 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___46 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___46 {
	const struct net_device___48 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___46 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___42 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___46 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___46 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___47 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___46 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___48 *dev;
	const char *name;
};

struct net_device_ops___46 {
	int (*ndo_init)(struct net_device___48 *);
	void (*ndo_uninit)(struct net_device___48 *);
	int (*ndo_open)(struct net_device___48 *);
	int (*ndo_stop)(struct net_device___48 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___47 *, struct net_device___48 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___47 *, struct net_device___48 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___48 *, struct sk_buff___47 *, struct net_device___48 *);
	void (*ndo_change_rx_flags)(struct net_device___48 *, int);
	void (*ndo_set_rx_mode)(struct net_device___48 *);
	int (*ndo_set_mac_address)(struct net_device___48 *, void *);
	int (*ndo_validate_addr)(struct net_device___48 *);
	int (*ndo_do_ioctl)(struct net_device___48 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___48 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___48 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___48 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___48 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___48 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___48 *, int);
	int (*ndo_neigh_setup)(struct net_device___48 *, struct neigh_parms___35 *);
	void (*ndo_tx_timeout)(struct net_device___48 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___48 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___48 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___48 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___48 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___48 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___48 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___48 *);
	int (*ndo_netpoll_setup)(struct net_device___48 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___48 *);
	int (*ndo_set_vf_mac)(struct net_device___48 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___48 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___48 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___48 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___48 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___48 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___48 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___48 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___48 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___48 *, int, struct sk_buff___47 *);
	int (*ndo_get_vf_guid)(struct net_device___48 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___48 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___48 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___48 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___48 *);
	int (*ndo_fcoe_disable)(struct net_device___48 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___48 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___48 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___48 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___48 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___48 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___48 *, const struct sk_buff___47 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___48 *, struct net_device___48 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___48 *, struct net_device___48 *);
	struct net_device___48 * (*ndo_get_xmit_slave)(struct net_device___48 *, struct sk_buff___47 *, bool);
	struct net_device___48 * (*ndo_sk_get_lower_dev)(struct net_device___48 *, struct sock___36 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___48 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___48 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___48 *, struct neighbour___35 *);
	void (*ndo_neigh_destroy)(struct net_device___48 *, struct neighbour___35 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___47 *, struct netlink_callback___46 *, struct net_device___48 *, struct net_device___48 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___47 *, struct nlattr **, struct net_device___48 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___48 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___47 *, u32, u32, struct net_device___48 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___48 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___48 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___48 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___48 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___48 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___48 *, struct net_device___48 *);
	void (*ndo_dfwd_del_station)(struct net_device___48 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___48 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___48 *);
	int (*ndo_change_proto_down)(struct net_device___48 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___48 *, struct sk_buff___47 *);
	void (*ndo_set_rx_headroom)(struct net_device___48 *, int);
	int (*ndo_bpf)(struct net_device___48 *, struct netdev_bpf___46 *);
	int (*ndo_xdp_xmit)(struct net_device___48 *, int, struct xdp_frame___46 **, u32);
	struct net_device___48 * (*ndo_xdp_get_xmit_slave)(struct net_device___48 *, struct xdp_buff___46 *);
	int (*ndo_xsk_wakeup)(struct net_device___48 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___48 *);
	int (*ndo_tunnel_ctl)(struct net_device___48 *, struct ip_tunnel_parm *, int);
	struct net_device___48 * (*ndo_get_peer_dev)(struct net_device___48 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___46 *, struct net_device_path___46 *);
};

struct neigh_parms___35 {
	possible_net_t___46 net;
	struct net_device___48 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___35 *);
	struct neigh_table___35 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___21 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___48 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___48 *);
	void (*get_regs)(struct net_device___48 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___48 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___48 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___48 *);
	void (*set_msglevel)(struct net_device___48 *, u32);
	int (*nway_reset)(struct net_device___48 *);
	u32 (*get_link)(struct net_device___48 *);
	int (*get_link_ext_state)(struct net_device___48 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___48 *);
	int (*get_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___48 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___48 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___48 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___48 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___48 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___48 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___48 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___48 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___48 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___48 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___48 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___48 *);
	void (*complete)(struct net_device___48 *);
	u32 (*get_priv_flags)(struct net_device___48 *);
	int (*set_priv_flags)(struct net_device___48 *, u32);
	int (*get_sset_count)(struct net_device___48 *, int);
	int (*get_rxnfc)(struct net_device___48 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___48 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___48 *, struct ethtool_flash *);
	int (*reset)(struct net_device___48 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___48 *);
	u32 (*get_rxfh_indir_size)(struct net_device___48 *);
	int (*get_rxfh)(struct net_device___48 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___48 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___48 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___48 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___48 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___48 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___48 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___48 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___48 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___48 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___48 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___48 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___48 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___48 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___48 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___48 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___48 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___48 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___48 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___48 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___48 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___48 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___48 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___48 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___48 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___48 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___48 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___48 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___48 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___48 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___48 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___35 {
	u32 (*l3mdev_fib_table)(const struct net_device___48 *);
	struct sk_buff___47 * (*l3mdev_l3_rcv)(struct net_device___48 *, struct sk_buff___47 *, u16);
	struct sk_buff___47 * (*l3mdev_l3_out)(struct net_device___48 *, struct sock___36 *, struct sk_buff___47 *, u16);
	struct dst_entry___35 * (*l3mdev_link_scope_lookup)(const struct net_device___48 *, struct flowi6 *);
};

struct ndisc_ops___23 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___48 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___48 *, struct neighbour___35 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___48 *, u8, struct neighbour___35 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___48 *, struct sk_buff___47 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___51 *, struct net_device___48 *, const struct prefix_info *, struct inet6_dev___23 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___23;

struct inet6_dev___23 {
	struct net_device___48 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___23 *mc_list;
	struct ifmcaddr6___23 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___46 mc_query_queue;
	struct sk_buff_head___46 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___2 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___35 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___42;

struct tcf_block___42;

struct mini_Qdisc___42 {
	struct tcf_proto___42 *filter_list;
	struct tcf_block___42 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___42 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___48 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___48 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___51 *, struct net_device___48 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___48 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___48 *, struct list_head *);
	size_t (*get_size)(const struct net_device___48 *);
	int (*fill_info)(struct sk_buff___47 *, const struct net_device___48 *);
	size_t (*get_xstats_size)(const struct net_device___48 *);
	int (*fill_xstats)(struct sk_buff___47 *, const struct net_device___48 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___48 *, struct net_device___48 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___48 *, const struct net_device___48 *);
	int (*fill_slave_info)(struct sk_buff___47 *, const struct net_device___48 *, const struct net_device___48 *);
	struct net___51 * (*get_link_net)(const struct net_device___48 *);
	size_t (*get_linkxstats_size)(const struct net_device___48 *, int);
	int (*fill_linkxstats)(struct sk_buff___47 *, const struct net_device___48 *, int *, int);
};

struct block_device_operations___121;

struct gendisk___124 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___124 *part0;
	const struct block_device_operations___121 *fops;
	struct request_queue___121 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___110 *bdi;
	struct kobject___216 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___216 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___121 {
	struct bio___121 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___145 *bip_vec;
	struct bio_vec___145 bip_inline_vecs[0];
};

struct blkcg___112;

struct blkg_policy_data___112;

struct blkcg_gq___112 {
	struct request_queue___121 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___112 *blkcg;
	struct blkcg_gq___112 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___112 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___121 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___121(struct request___121 *);

typedef void integrity_complete_fn___121(struct request___121 *, unsigned int);

struct blk_integrity_profile___121 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___121 *prepare_fn;
	integrity_complete_fn___121 *complete_fn;
	const char *name;
};

struct block_device_operations___121 {
	blk_qc_t (*submit_bio)(struct bio___121 *);
	int (*open)(struct block_device___124 *, fmode_t);
	void (*release)(struct gendisk___124 *, fmode_t);
	int (*rw_page)(struct block_device___124 *, sector_t, struct page___233 *, unsigned int);
	int (*ioctl)(struct block_device___124 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___124 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___124 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___124 *);
	int (*getgeo)(struct block_device___124 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___124 *, bool);
	void (*swap_slot_free_notify)(struct block_device___124 *, long unsigned int);
	int (*report_zones)(struct gendisk___124 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___124 *, umode_t *);
	struct module___212 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___124 *, sector_t *);
};

typedef void rq_end_io_fn___121(struct request___121 *, blk_status_t);

struct request___121 {
	struct request_queue___121 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___118 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___121 *bio;
	struct bio___121 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___145 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___121 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___121 *saved_end_io;
		} flush;
	};
	struct gendisk___124 *rq_disk;
	struct block_device___124 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___121 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___118 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___121 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___216 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___228 *debugfs_dir;
	struct dentry___228 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___121;

struct elevator_mq_ops___121 {
	int (*init_sched)(struct request_queue___121 *, struct elevator_type___121 *);
	void (*exit_sched)(struct elevator_queue___121 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___118 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___118 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___118 *);
	bool (*allow_merge)(struct request_queue___121 *, struct request___121 *, struct bio___121 *);
	bool (*bio_merge)(struct request_queue___121 *, struct bio___121 *, unsigned int);
	int (*request_merge)(struct request_queue___121 *, struct request___121 **, struct bio___121 *);
	void (*request_merged)(struct request_queue___121 *, struct request___121 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___121 *, struct request___121 *, struct request___121 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___121 *);
	void (*finish_request)(struct request___121 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___118 *, struct list_head *, bool);
	struct request___121 * (*dispatch_request)(struct blk_mq_hw_ctx___118 *);
	bool (*has_work)(struct blk_mq_hw_ctx___118 *);
	void (*completed_request)(struct request___121 *, u64);
	void (*requeue_request)(struct request___121 *);
	struct request___121 * (*former_request)(struct request_queue___121 *, struct request___121 *);
	struct request___121 * (*next_request)(struct request_queue___121 *, struct request___121 *);
	void (*init_icq)(struct io_cq___121 *);
	void (*exit_icq)(struct io_cq___121 *);
};

struct elv_fs_entry___121;

struct elevator_type___121 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___121 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___121 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___212 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___121 {
	struct elevator_type___121 *type;
	void *elevator_data;
	struct kobject___216 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___121 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___121 *, char *);
	ssize_t (*store)(struct elevator_queue___121 *, const char *, size_t);
};

struct blk_mq_queue_data___118;

struct blk_mq_ops___118 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___118 *, const struct blk_mq_queue_data___118 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___118 *);
	int (*get_budget)(struct request_queue___121 *);
	void (*put_budget)(struct request_queue___121 *, int);
	void (*set_rq_budget_token)(struct request___121 *, int);
	int (*get_rq_budget_token)(struct request___121 *);
	enum blk_eh_timer_return (*timeout)(struct request___121 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___118 *);
	void (*complete)(struct request___121 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___118 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___118 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___118 *, struct request___121 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___118 *, struct request___121 *, unsigned int);
	void (*initialize_rq_fn)(struct request___121 *);
	void (*cleanup_rq)(struct request___121 *);
	bool (*busy)(struct request_queue___121 *);
	int (*map_queues)(struct blk_mq_tag_set___118 *);
	void (*show_rq)(struct seq_file___203 *, struct request___121 *);
};

struct blk_mq_tag_set___118 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___118 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___118 {
	struct request___121 *rq;
	bool last;
};

struct blkcg_policy_data___112;

struct blkcg___112 {
	struct cgroup_subsys_state___158 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___112 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___112 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___112 {
	struct blkcg___112 *blkcg;
	int plid;
};

struct blkg_policy_data___112 {
	struct blkcg_gq___112 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___101 {
	struct mem_cgroup___101 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___101 {
	struct lruvec___109 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___101 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___101 *memcg;
};

struct obj_cgroup___101 {
	struct percpu_ref refcnt;
	struct mem_cgroup___101 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___42 {
	spinlock_t *lock;
	struct sk_buff___47 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___42;

struct Qdisc_ops___42 {
	struct Qdisc_ops___42 *next;
	const struct Qdisc_class_ops___42 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___47 *, struct Qdisc___42 *, struct sk_buff___47 **);
	struct sk_buff___47 * (*dequeue)(struct Qdisc___42 *);
	struct sk_buff___47 * (*peek)(struct Qdisc___42 *);
	int (*init)(struct Qdisc___42 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___42 *);
	void (*destroy)(struct Qdisc___42 *);
	int (*change)(struct Qdisc___42 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___42 *);
	int (*change_tx_queue_len)(struct Qdisc___42 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___42 *, unsigned int);
	int (*dump)(struct Qdisc___42 *, struct sk_buff___47 *);
	int (*dump_stats)(struct Qdisc___42 *, struct gnet_dump___42 *);
	void (*ingress_block_set)(struct Qdisc___42 *, u32);
	void (*egress_block_set)(struct Qdisc___42 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___42 *);
	u32 (*egress_block_get)(struct Qdisc___42 *);
	struct module___212 *owner;
};

struct Qdisc_class_ops___42 {
	unsigned int flags;
	struct netdev_queue___46 * (*select_queue)(struct Qdisc___42 *, struct tcmsg *);
	int (*graft)(struct Qdisc___42 *, long unsigned int, struct Qdisc___42 *, struct Qdisc___42 **, struct netlink_ext_ack *);
	struct Qdisc___42 * (*leaf)(struct Qdisc___42 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___42 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___42 *, u32);
	int (*change)(struct Qdisc___42 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___42 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___42 *, struct qdisc_walker *);
	struct tcf_block___42 * (*tcf_block)(struct Qdisc___42 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___42 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___42 *, long unsigned int);
	int (*dump)(struct Qdisc___42 *, long unsigned int, struct sk_buff___47 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___42 *, long unsigned int, struct gnet_dump___42 *);
};

struct tcf_chain___42;

struct tcf_block___42 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___51 *net;
	struct Qdisc___42 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___42 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___42;

struct tcf_proto_ops___42;

struct tcf_proto___42 {
	struct tcf_proto___42 *next;
	void *root;
	int (*classify)(struct sk_buff___47 *, const struct tcf_proto___42 *, struct tcf_result___42 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___42 *ops;
	struct tcf_chain___42 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___42 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___42 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___42 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___47 *, const struct tcf_proto___42 *, struct tcf_result___42 *);
	int (*init)(struct tcf_proto___42 *);
	void (*destroy)(struct tcf_proto___42 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___42 *, u32);
	void (*put)(struct tcf_proto___42 *, void *);
	int (*change)(struct net___51 *, struct sk_buff___47 *, struct tcf_proto___42 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___42 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___42 *);
	void (*walk)(struct tcf_proto___42 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___42 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___42 *, void *);
	void (*hw_del)(struct tcf_proto___42 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___51 *, struct tcf_chain___42 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___51 *, struct tcf_proto___42 *, void *, struct sk_buff___47 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___51 *, struct tcf_proto___42 *, void *, struct sk_buff___47 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___47 *, struct net___51 *, void *);
	struct module___212 *owner;
	int flags;
};

struct tcf_chain___42 {
	struct mutex filter_chain_lock;
	struct tcf_proto___42 *filter_chain;
	struct list_head list;
	struct tcf_block___42 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___42 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___35 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___42 *prog;
};

struct pneigh_entry___35;

struct neigh_hash_table___35;

struct neigh_table___35 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___48 *, __u32 *);
	bool (*key_eq)(const struct neighbour___35 *, const void *);
	int (*constructor)(struct neighbour___35 *);
	int (*pconstructor)(struct pneigh_entry___35 *);
	void (*pdestructor)(struct pneigh_entry___35 *);
	void (*proxy_redo)(struct sk_buff___47 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___48 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___35 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___46 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___35 *nht;
	struct pneigh_entry___35 **phash_buckets;
};

struct neigh_ops___35 {
	int family;
	void (*solicit)(struct neighbour___35 *, struct sk_buff___47 *);
	void (*error_report)(struct neighbour___35 *, struct sk_buff___47 *);
	int (*output)(struct neighbour___35 *, struct sk_buff___47 *);
	int (*connected_output)(struct neighbour___35 *, struct sk_buff___47 *);
};

struct pneigh_entry___35 {
	struct pneigh_entry___35 *next;
	possible_net_t___46 net;
	struct net_device___48 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___35 {
	struct neighbour___35 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___18 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___51 *, struct sock___36 *, struct sk_buff___47 *);
	int (*orig_input)(struct sk_buff___47 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___35 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___35 *ctarget;
	struct net___51 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___35 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___35 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___25;

struct timewait_sock_ops___25;

struct proto___35 {
	void (*close)(struct sock___36 *, long int);
	int (*pre_connect)(struct sock___36 *, struct sockaddr *, int);
	int (*connect)(struct sock___36 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___36 *, int);
	struct sock___36 * (*accept)(struct sock___36 *, int, int *, bool);
	int (*ioctl)(struct sock___36 *, int, long unsigned int);
	int (*init)(struct sock___36 *);
	void (*destroy)(struct sock___36 *);
	void (*shutdown)(struct sock___36 *, int);
	int (*setsockopt)(struct sock___36 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___36 *, int, int, char *, int *);
	void (*keepalive)(struct sock___36 *, int);
	int (*compat_ioctl)(struct sock___36 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___36 *, struct msghdr___37 *, size_t);
	int (*recvmsg)(struct sock___36 *, struct msghdr___37 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___36 *, struct page___233 *, int, size_t, int);
	int (*bind)(struct sock___36 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___36 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___36 *, struct sk_buff___47 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___36 *);
	int (*hash)(struct sock___36 *);
	void (*unhash)(struct sock___36 *);
	void (*rehash)(struct sock___36 *);
	int (*get_port)(struct sock___36 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___36 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___36 *, int);
	bool (*sock_is_readable)(struct sock___36 *);
	void (*enter_memory_pressure)(struct sock___36 *);
	void (*leave_memory_pressure)(struct sock___36 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___25 *rsk_prot;
	struct timewait_sock_ops___25 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___212 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___36 *, int);
};

struct sock_reuseport___6 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___42 *prog;
	struct sock___36 *socks[0];
};

struct request_sock___26;

struct request_sock_ops___25 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___36 *, struct request_sock___26 *);
	void (*send_ack)(const struct sock___36 *, struct sk_buff___47 *, struct request_sock___26 *);
	void (*send_reset)(const struct sock___36 *, struct sk_buff___47 *);
	void (*destructor)(struct request_sock___26 *);
	void (*syn_ack_timeout)(const struct request_sock___26 *);
};

struct timewait_sock_ops___25 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___36 *, struct sock___36 *, void *);
	void (*twsk_destructor)(struct sock___36 *);
};

struct request_sock___26 {
	struct sock_common___35 __req_common;
	struct request_sock___26 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___25 *rsk_ops;
	struct sock___36 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___23 {
	struct in6_addr mca_addr;
	struct inet6_dev___23 *idev;
	struct ifmcaddr6___23 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct xenbus_device___4 {
	const char *devicetype;
	const char *nodename;
	const char *otherend;
	int otherend_id;
	struct xenbus_watch otherend_watch;
	struct device___206 dev;
	enum xenbus_state state;
	struct completion down;
	struct work_struct work;
	struct semaphore reclaim_sem;
	atomic_t event_channels;
	atomic_t events;
	atomic_t spurious_events;
	atomic_t jiffies_eoi_delayed;
	unsigned int spurious_threshold;
};

struct xenbus_driver___4 {
	const char *name;
	const struct xenbus_device_id *ids;
	bool allow_rebind;
	int (*probe)(struct xenbus_device___4 *, const struct xenbus_device_id *);
	void (*otherend_changed)(struct xenbus_device___4 *, enum xenbus_state);
	int (*remove)(struct xenbus_device___4 *);
	int (*suspend)(struct xenbus_device___4 *);
	int (*resume)(struct xenbus_device___4 *);
	int (*uevent)(struct xenbus_device___4 *, struct kobj_uevent_env *);
	struct device_driver___206 driver;
	int (*read_otherend_details)(struct xenbus_device___4 *);
	int (*is_ready)(struct xenbus_device___4 *);
	void (*reclaim_memory)(struct xenbus_device___4 *);
};

struct xen_netif_tx_request {
	grant_ref_t gref;
	uint16_t offset;
	uint16_t flags;
	uint16_t id;
	uint16_t size;
};

struct xen_netif_extra_info {
	uint8_t type;
	uint8_t flags;
	union {
		struct {
			uint16_t size;
			uint8_t type;
			uint8_t pad;
			uint16_t features;
		} gso;
		struct {
			uint8_t addr[6];
		} mcast;
		struct {
			uint8_t type;
			uint8_t algorithm;
			uint8_t value[4];
		} hash;
		struct {
			uint16_t headroom;
			uint16_t pad[2];
		} xdp;
		uint16_t pad[3];
	} u;
};

struct xen_netif_tx_response {
	uint16_t id;
	int16_t status;
};

struct xen_netif_rx_request {
	uint16_t id;
	uint16_t pad;
	grant_ref_t gref;
};

struct xen_netif_rx_response {
	uint16_t id;
	uint16_t offset;
	uint16_t flags;
	int16_t status;
};

union xen_netif_tx_sring_entry {
	struct xen_netif_tx_request req;
	struct xen_netif_tx_response rsp;
};

struct xen_netif_tx_sring {
	RING_IDX req_prod;
	RING_IDX req_event;
	RING_IDX rsp_prod;
	RING_IDX rsp_event;
	uint8_t __pad[48];
	union xen_netif_tx_sring_entry ring[1];
};

struct xen_netif_tx_front_ring {
	RING_IDX req_prod_pvt;
	RING_IDX rsp_cons;
	unsigned int nr_ents;
	struct xen_netif_tx_sring *sring;
};

union xen_netif_rx_sring_entry {
	struct xen_netif_rx_request req;
	struct xen_netif_rx_response rsp;
};

struct xen_netif_rx_sring {
	RING_IDX req_prod;
	RING_IDX req_event;
	RING_IDX rsp_prod;
	RING_IDX rsp_event;
	uint8_t __pad[48];
	union xen_netif_rx_sring_entry ring[1];
};

struct xen_netif_rx_front_ring {
	RING_IDX req_prod_pvt;
	RING_IDX rsp_cons;
	unsigned int nr_ents;
	struct xen_netif_rx_sring *sring;
};

struct netfront_cb {
	int pull_to;
};

struct netfront_stats {
	u64 packets;
	u64 bytes;
	struct u64_stats_sync syncp;
};

struct netfront_info;

struct netfront_queue {
	unsigned int id;
	char name[22];
	struct netfront_info *info;
	struct bpf_prog___42 *xdp_prog;
	struct napi_struct___5 napi;
	unsigned int tx_evtchn;
	unsigned int rx_evtchn;
	unsigned int tx_irq;
	unsigned int rx_irq;
	char tx_irq_name[25];
	char rx_irq_name[25];
	spinlock_t tx_lock;
	struct xen_netif_tx_front_ring tx;
	int tx_ring_ref;
	struct sk_buff___47 *tx_skbs[256];
	short unsigned int tx_link[256];
	grant_ref_t gref_tx_head;
	grant_ref_t grant_tx_ref[256];
	struct page___233 *grant_tx_page[256];
	unsigned int tx_skb_freelist;
	unsigned int tx_pend_queue;
	long: 64;
	spinlock_t rx_lock;
	struct xen_netif_rx_front_ring rx;
	int rx_ring_ref;
	struct timer_list rx_refill_timer;
	struct sk_buff___47 *rx_skbs[256];
	grant_ref_t gref_rx_head;
	grant_ref_t grant_rx_ref[256];
	unsigned int rx_rsp_unconsumed;
	spinlock_t rx_cons_lock;
	struct page_pool___66 *page_pool;
	long: 64;
	long: 64;
	long: 64;
	struct xdp_rxq_info___46 xdp_rxq;
};

struct netfront_info {
	struct list_head list;
	struct net_device___48 *netdev;
	struct xenbus_device___4 *xbdev;
	struct netfront_queue *queues;
	struct netfront_stats *rx_stats;
	struct netfront_stats *tx_stats;
	bool netback_has_xdp_headroom;
	bool netfront_xdp_enabled;
	bool broken;
	atomic_t rx_gso_checksum_fixup;
};

struct netfront_rx_info {
	struct xen_netif_rx_response rx;
	struct xen_netif_extra_info extras[5];
};

struct xennet_gnttab_make_txreq {
	struct netfront_queue *queue;
	struct sk_buff___47 *skb;
	struct page___233 *page;
	struct xen_netif_tx_request *tx;
	struct xen_netif_tx_request tx_local;
	unsigned int size;
};

struct xennet_stat {
	char name[32];
	u16 offset;
};

struct cdrom_msf {
	__u8 cdmsf_min0;
	__u8 cdmsf_sec0;
	__u8 cdmsf_frame0;
	__u8 cdmsf_min1;
	__u8 cdmsf_sec1;
	__u8 cdmsf_frame1;
};

struct cdrom_volctrl {
	__u8 channel0;
	__u8 channel1;
	__u8 channel2;
	__u8 channel3;
};

struct cdrom_subchnl {
	__u8 cdsc_format;
	__u8 cdsc_audiostatus;
	__u8 cdsc_adr: 4;
	__u8 cdsc_ctrl: 4;
	int: 20;
	__u8 cdsc_trk;
	__u8 cdsc_ind;
	union cdrom_addr cdsc_absaddr;
	union cdrom_addr cdsc_reladdr;
};

struct cdrom_read_audio {
	union cdrom_addr addr;
	__u8 addr_format;
	int nframes;
	__u8 *buf;
};

struct cdrom_blk {
	unsigned int from;
	short unsigned int len;
};

struct dvd_layer {
	__u8 book_version: 4;
	__u8 book_type: 4;
	__u8 min_rate: 4;
	__u8 disc_size: 4;
	__u8 layer_type: 4;
	__u8 track_path: 1;
	__u8 nlayers: 2;
	__u8 track_density: 4;
	__u8 linear_density: 4;
	__u8 bca: 1;
	long: 63;
	__u32 start_sector;
	__u32 end_sector;
	__u32 end_sector_l0;
};

struct dvd_physical {
	__u8 type;
	__u8 layer_num;
	struct dvd_layer layer[4];
};

struct dvd_copyright {
	__u8 type;
	__u8 layer_num;
	__u8 cpst;
	__u8 rmi;
};

struct dvd_disckey {
	__u8 type;
	unsigned int agid: 2;
	short: 14;
	__u8 value[2048];
};

struct dvd_bca {
	__u8 type;
	int len;
	__u8 value[188];
};

struct dvd_manufact {
	__u8 type;
	__u8 layer_num;
	int len;
	__u8 value[2048];
};

typedef union {
	__u8 type;
	struct dvd_physical physical;
	struct dvd_copyright copyright;
	struct dvd_disckey disckey;
	struct dvd_bca bca;
	struct dvd_manufact manufact;
} dvd_struct;

typedef __u8 dvd_key[5];

typedef __u8 dvd_challenge[10];

struct dvd_lu_send_agid {
	__u8 type;
	unsigned int agid: 2;
};

struct dvd_host_send_challenge {
	__u8 type;
	unsigned int agid: 2;
	short: 14;
	dvd_challenge chal;
};

struct dvd_send_key {
	__u8 type;
	unsigned int agid: 2;
	short: 14;
	dvd_key key;
};

struct dvd_lu_send_challenge {
	__u8 type;
	unsigned int agid: 2;
	short: 14;
	dvd_challenge chal;
};

struct dvd_lu_send_title_key {
	__u8 type;
	unsigned int agid: 2;
	short: 14;
	dvd_key title_key;
	int lba;
	unsigned int cpm: 1;
	unsigned int cp_sec: 1;
	unsigned int cgms: 2;
	long: 62;
	long: 64;
};

struct dvd_lu_send_asf {
	__u8 type;
	unsigned int agid: 2;
	unsigned int asf: 1;
};

struct dvd_host_send_rpcstate {
	__u8 type;
	__u8 pdrc;
};

struct dvd_lu_send_rpcstate {
	__u8 type: 2;
	__u8 vra: 3;
	__u8 ucca: 3;
	__u8 region_mask;
	__u8 rpc_scheme;
};

typedef union {
	__u8 type;
	struct dvd_lu_send_agid lsa;
	struct dvd_host_send_challenge hsc;
	struct dvd_send_key lsk;
	struct dvd_lu_send_challenge lsc;
	struct dvd_send_key hsk;
	struct dvd_lu_send_title_key lstk;
	struct dvd_lu_send_asf lsasf;
	struct dvd_host_send_rpcstate hrpcs;
	struct dvd_lu_send_rpcstate lrpcs;
} dvd_authinfo;

struct mrw_feature_desc {
	__be16 feature_code;
	__u8 curr: 1;
	__u8 persistent: 1;
	__u8 feature_version: 4;
	__u8 reserved1: 2;
	int: 22;
	__u8 add_len;
	__u8 write: 1;
	__u8 reserved2: 7;
	long: 33;
	__u8 reserved3;
	__u8 reserved4;
	__u8 reserved5;
};

struct rwrt_feature_desc {
	__be16 feature_code;
	__u8 curr: 1;
	__u8 persistent: 1;
	__u8 feature_version: 4;
	__u8 reserved1: 2;
	int: 22;
	__u8 add_len;
	__u32 last_lba;
	__u32 block_size;
	__u16 blocking;
	__u8 page_present: 1;
	__u8 reserved2: 7;
	long: 49;
	long: 64;
	__u8 reserved3;
};

typedef struct {
	__be16 disc_information_length;
	__u8 disc_status: 2;
	__u8 border_status: 2;
	__u8 erasable: 1;
	__u8 reserved1: 3;
	int: 21;
	__u8 n_first_track;
	__u8 n_sessions_lsb;
	__u8 first_track_lsb;
	__u8 last_track_lsb;
	__u8 mrw_status: 2;
	__u8 dbit: 1;
	__u8 reserved2: 2;
	__u8 uru: 1;
	__u8 dbc_v: 1;
	__u8 did_v: 1;
	long: 63;
	__u8 disc_type;
	__u8 n_sessions_msb;
	__u8 first_track_msb;
	__u8 last_track_msb;
	__u32 disc_id;
	__u32 lead_in;
	__u32 lead_out;
	__u8 disc_bar_code[8];
	__u8 reserved3;
	__u8 n_opc;
} disc_information;

typedef struct {
	__be16 track_information_length;
	__u8 track_lsb;
	__u8 session_lsb;
	__u8 reserved1;
	__u8 track_mode: 4;
	__u8 copy: 1;
	__u8 damage: 1;
	__u8 reserved2: 2;
	__u8 data_mode: 4;
	__u8 fp: 1;
	__u8 packet: 1;
	__u8 blank: 1;
	__u8 rt: 1;
	__u8 nwa_v: 1;
	__u8 lra_v: 1;
	__u8 reserved3: 6;
	long: 58;
	__be32 track_start;
	__be32 next_writable;
	__be32 free_blocks;
	__be32 fixed_packet_size;
	__be32 track_size;
	__be32 last_rec_address;
} track_information;

struct mode_page_header {
	__be16 mode_data_length;
	__u8 medium_type;
	__u8 reserved1;
	__u8 reserved2;
	__u8 reserved3;
	__be16 desc_length;
};

typedef struct {
	int data;
	int audio;
	int cdi;
	int xa;
	long int error;
} tracktype;

struct cdrom_mechstat_header {
	__u8 curslot: 5;
	__u8 changer_state: 2;
	__u8 fault: 1;
	__u8 reserved1: 4;
	__u8 door_open: 1;
	__u8 mech_state: 3;
	short: 13;
	__u8 curlba[3];
	__u8 nslots;
	__u16 slot_tablelen;
};

struct cdrom_slot {
	__u8 change: 1;
	__u8 reserved1: 6;
	__u8 disc_present: 1;
	__u8 reserved2[3];
};

struct cdrom_changer_info {
	struct cdrom_mechstat_header hdr;
	struct cdrom_slot slots[256];
};

struct modesel_head {
	__u8 reserved1;
	__u8 medium;
	__u8 reserved2;
	__u8 block_desc_length;
	__u8 density;
	__u8 number_of_blocks_hi;
	__u8 number_of_blocks_med;
	__u8 number_of_blocks_lo;
	__u8 reserved3;
	__u8 block_length_hi;
	__u8 block_length_med;
	__u8 block_length_lo;
};

typedef struct {
	__u16 report_key_length;
	__u8 reserved1;
	__u8 reserved2;
	__u8 ucca: 3;
	__u8 vra: 3;
	__u8 type_code: 2;
	long: 38;
	__u8 region_mask;
	__u8 rpc_scheme;
	__u8 reserved3;
} rpc_state_t;

struct cdrom_sysctl_settings {
	char info[1000];
	int autoclose;
	int autoeject;
	int debug;
	int lock;
	int check;
};

enum cdrom_print_option {
	CTL_NAME = 0,
	CTL_SPEED = 1,
	CTL_SLOTS = 2,
	CTL_CAPABILITY = 3,
};

struct compat_cdrom_read_audio {
	union cdrom_addr addr;
	u8 addr_format;
	compat_int_t nframes;
	compat_caddr_t buf;
};

enum usb_otg_state {
	OTG_STATE_UNDEFINED = 0,
	OTG_STATE_B_IDLE = 1,
	OTG_STATE_B_SRP_INIT = 2,
	OTG_STATE_B_PERIPHERAL = 3,
	OTG_STATE_B_WAIT_ACON = 4,
	OTG_STATE_B_HOST = 5,
	OTG_STATE_A_IDLE = 6,
	OTG_STATE_A_WAIT_VRISE = 7,
	OTG_STATE_A_WAIT_BCON = 8,
	OTG_STATE_A_HOST = 9,
	OTG_STATE_A_SUSPEND = 10,
	OTG_STATE_A_PERIPHERAL = 11,
	OTG_STATE_A_WAIT_VFALL = 12,
	OTG_STATE_A_VBUS_ERR = 13,
};

struct usb_otg_caps {
	u16 otg_rev;
	bool hnp_support;
	bool srp_support;
	bool adp_support;
};

enum usb_dr_mode {
	USB_DR_MODE_UNKNOWN = 0,
	USB_DR_MODE_HOST = 1,
	USB_DR_MODE_PERIPHERAL = 2,
	USB_DR_MODE_OTG = 3,
};

enum usb_led_event {
	USB_LED_EVENT_HOST = 0,
	USB_LED_EVENT_GADGET = 1,
};

struct usb_device_id {
	__u16 match_flags;
	__u16 idVendor;
	__u16 idProduct;
	__u16 bcdDevice_lo;
	__u16 bcdDevice_hi;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bInterfaceClass;
	__u8 bInterfaceSubClass;
	__u8 bInterfaceProtocol;
	__u8 bInterfaceNumber;
	kernel_ulong_t driver_info;
};

struct usb_descriptor_header {
	__u8 bLength;
	__u8 bDescriptorType;
};

struct usb_interface___2 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created;
	unsigned int ep_devs_created;
	unsigned int unregistering;
	unsigned int needs_remote_wakeup;
	unsigned int needs_altsetting0;
	unsigned int needs_binding;
	unsigned int resetting_device;
	unsigned int authorized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct device___15 dev;
	struct device___15 *usb_dev;
	struct work_struct reset_ws;
};

struct usb_host_config___2 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___2 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___2;

struct usb_bus___2 {
	struct device___15 *controller;
	struct device___15 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___2 *root_hub;
	struct usb_bus___2 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___2;

struct usb_device___2 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	enum usb_ssp_rate ssp_rate;
	struct usb_tt___2 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___2 *parent;
	struct usb_bus___2 *bus;
	struct usb_host_endpoint ep0;
	struct device___15 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___2 *config;
	struct usb_host_config___2 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	u8 devaddr;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct wusb_dev *wusb_dev;
	int slot_id;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
	unsigned int use_generic_driver: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum usb_port_connect_type {
	USB_PORT_CONNECT_TYPE_UNKNOWN = 0,
	USB_PORT_CONNECT_TYPE_HOT_PLUG = 1,
	USB_PORT_CONNECT_TYPE_HARD_WIRED = 2,
	USB_PORT_NOT_USED = 3,
};

struct usb_tt___2 {
	struct usb_device___2 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usb_dynids {
	spinlock_t lock;
	struct list_head list;
};

struct usbdrv_wrap {
	struct device_driver___15 driver;
	int for_devices;
};

struct usb_driver {
	const char *name;
	int (*probe)(struct usb_interface___2 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___2 *);
	int (*unlocked_ioctl)(struct usb_interface___2 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___2 *, pm_message_t);
	int (*resume)(struct usb_interface___2 *);
	int (*reset_resume)(struct usb_interface___2 *);
	int (*pre_reset)(struct usb_interface___2 *);
	int (*post_reset)(struct usb_interface___2 *);
	const struct usb_device_id *id_table;
	const struct attribute_group___17 **dev_groups;
	struct usb_dynids dynids;
	struct usbdrv_wrap drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_device_driver {
	const char *name;
	bool (*match)(struct usb_device___2 *);
	int (*probe)(struct usb_device___2 *);
	void (*disconnect)(struct usb_device___2 *);
	int (*suspend)(struct usb_device___2 *, pm_message_t);
	int (*resume)(struct usb_device___2 *, pm_message_t);
	const struct attribute_group___17 **dev_groups;
	struct usbdrv_wrap drvwrap;
	const struct usb_device_id *id_table;
	unsigned int supports_autosuspend: 1;
	unsigned int generic_subclass: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct urb___2;

typedef void (*usb_complete_t___2)(struct urb___2 *);

struct urb___2 {
	struct kref kref;
	int unlinked;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___2 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___2 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___2;

struct usb_phy___2;

struct usb_hcd___2 {
	struct usb_bus___2 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___2 *status_urb;
	struct work_struct wakeup_work;
	struct work_struct died_work;
	const struct hc_driver___2 *driver;
	struct usb_phy___2 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	enum usb_dev_authorize_policy dev_policy;
	unsigned int rh_registered;
	unsigned int rh_pollable;
	unsigned int msix_enabled;
	unsigned int msi_enabled;
	unsigned int skip_phy_initialization;
	unsigned int uses_new_polling;
	unsigned int wireless;
	unsigned int has_tt;
	unsigned int amd_resume_bug;
	unsigned int can_do_streams;
	unsigned int tpl_support;
	unsigned int cant_recv_wakeups;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___2 *shared_hcd;
	struct usb_hcd___2 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	struct gen_pool *localmem_pool;
	long unsigned int hcd_priv[0];
};

struct hc_driver___2 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___2 *);
	int flags;
	int (*reset)(struct usb_hcd___2 *);
	int (*start)(struct usb_hcd___2 *);
	int (*pci_suspend)(struct usb_hcd___2 *, bool);
	int (*pci_resume)(struct usb_hcd___2 *, bool);
	void (*stop)(struct usb_hcd___2 *);
	void (*shutdown)(struct usb_hcd___2 *);
	int (*get_frame_number)(struct usb_hcd___2 *);
	int (*urb_enqueue)(struct usb_hcd___2 *, struct urb___2 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___2 *, struct urb___2 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___2 *, struct urb___2 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___2 *, struct urb___2 *);
	void (*endpoint_disable)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___2 *, char *);
	int (*hub_control)(struct usb_hcd___2 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___2 *);
	int (*bus_resume)(struct usb_hcd___2 *);
	int (*start_port_reset)(struct usb_hcd___2 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___2 *);
	void (*relinquish_port)(struct usb_hcd___2 *, int);
	int (*port_handed_over)(struct usb_hcd___2 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___2 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___2 *, struct usb_device___2 *);
	void (*free_dev)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*alloc_streams)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___2 *, struct usb_device___2 *);
	void (*reset_bandwidth)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*address_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*enable_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*update_hub_device)(struct usb_hcd___2 *, struct usb_device___2 *, struct usb_tt___2 *, gfp_t);
	int (*reset_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*update_device)(struct usb_hcd___2 *, struct usb_device___2 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___2 *, struct usb_device___2 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___2 *, struct usb_device___2 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___2 *, struct usb_device___2 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___2 *, int);
	int (*port_power)(struct usb_hcd___2 *, int, bool);
	int (*submit_single_step_set_feature)(struct usb_hcd___2 *, struct urb___2 *, int);
};

enum usb_phy_type {
	USB_PHY_TYPE_UNDEFINED = 0,
	USB_PHY_TYPE_USB2 = 1,
	USB_PHY_TYPE_USB3 = 2,
};

enum usb_phy_events {
	USB_EVENT_NONE = 0,
	USB_EVENT_VBUS = 1,
	USB_EVENT_ID = 2,
	USB_EVENT_CHARGER = 3,
	USB_EVENT_ENUMERATED = 4,
};

enum usb_charger_type {
	UNKNOWN_TYPE = 0,
	SDP_TYPE = 1,
	DCP_TYPE = 2,
	CDP_TYPE = 3,
	ACA_TYPE = 4,
};

enum usb_charger_state {
	USB_CHARGER_DEFAULT = 0,
	USB_CHARGER_PRESENT = 1,
	USB_CHARGER_ABSENT = 2,
};

struct usb_charger_current {
	unsigned int sdp_min;
	unsigned int sdp_max;
	unsigned int dcp_min;
	unsigned int dcp_max;
	unsigned int cdp_min;
	unsigned int cdp_max;
	unsigned int aca_min;
	unsigned int aca_max;
};

struct usb_otg;

struct usb_phy_io_ops;

struct usb_phy___2 {
	struct device___15 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg *otg;
	struct device___15 *io_dev;
	struct usb_phy_io_ops *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___2 *);
	void (*shutdown)(struct usb_phy___2 *);
	int (*set_vbus)(struct usb_phy___2 *, int);
	int (*set_power)(struct usb_phy___2 *, unsigned int);
	int (*set_suspend)(struct usb_phy___2 *, int);
	int (*set_wakeup)(struct usb_phy___2 *, bool);
	int (*notify_connect)(struct usb_phy___2 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___2 *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy___2 *);
};

struct usb_port_status {
	__le16 wPortStatus;
	__le16 wPortChange;
	__le32 dwExtPortStatus;
};

struct usb_hub_status {
	__le16 wHubStatus;
	__le16 wHubChange;
};

struct usb_hub_descriptor {
	__u8 bDescLength;
	__u8 bDescriptorType;
	__u8 bNbrPorts;
	__le16 wHubCharacteristics;
	__u8 bPwrOn2PwrGood;
	__u8 bHubContrCurrent;
	union {
		struct {
			__u8 DeviceRemovable[4];
			__u8 PortPwrCtrlMask[4];
		} hs;
		struct {
			__u8 bHubHdrDecLat;
			__le16 wHubDelay;
			__le16 DeviceRemovable;
		} __attribute__((packed)) ss;
	} u;
} __attribute__((packed));

struct phy___10;

struct phy_ops___9 {
	int (*init)(struct phy___10 *);
	int (*exit)(struct phy___10 *);
	int (*power_on)(struct phy___10 *);
	int (*power_off)(struct phy___10 *);
	int (*set_mode)(struct phy___10 *, enum phy_mode, int);
	int (*set_media)(struct phy___10 *, enum phy_media);
	int (*set_speed)(struct phy___10 *, int);
	int (*configure)(struct phy___10 *, union phy_configure_opts___2 *);
	int (*validate)(struct phy___10 *, enum phy_mode, int, union phy_configure_opts___2 *);
	int (*reset)(struct phy___10 *);
	int (*calibrate)(struct phy___10 *);
	void (*release)(struct phy___10 *);
	struct module___19 *owner;
};

struct phy___10 {
	struct device___15 dev;
	int id;
	const struct phy_ops___9 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct usb_phy_io_ops {
	int (*read)(struct usb_phy___2 *, u32);
	int (*write)(struct usb_phy___2 *, u32, u32);
};

struct usb_gadget;

struct usb_otg {
	u8 default_a;
	struct phy___10 *phy;
	struct usb_phy___2 *usb_phy;
	struct usb_bus___2 *host;
	struct usb_gadget *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg *, struct usb_bus___2 *);
	int (*set_peripheral)(struct usb_otg *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg *, bool);
	int (*start_srp)(struct usb_otg *);
	int (*start_hnp)(struct usb_otg *);
};

typedef u32 usb_port_location_t;

struct usb_port;

struct usb_hub {
	struct device___15 *intfdev;
	struct usb_device___2 *hdev;
	struct kref kref;
	struct urb___2 *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt___2 tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power;
	unsigned int quiescing;
	unsigned int disconnected;
	unsigned int in_reset;
	unsigned int quirk_disable_autosuspend;
	unsigned int quirk_check_port_auto_suspend;
	unsigned int has_indicators;
	long: 40;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	spinlock_t irq_urb_lock;
	struct timer_list irq_urb_retry;
	struct usb_port **ports;
};

struct usb_dev_state;

struct usb_port {
	struct usb_device___2 *child;
	struct device___15 dev;
	struct usb_dev_state *port_owner;
	struct usb_port *peer;
	struct dev_pm_qos_request___11 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex status_lock;
	u32 over_current_count;
	u8 portnum;
	u32 quirks;
	unsigned int is_superspeed;
	unsigned int usb3_lpm_u1_permit;
	unsigned int usb3_lpm_u2_permit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct find_interface_arg {
	int minor;
	struct device_driver___15 *drv;
};

struct each_dev_arg {
	void *data;
	int (*fn)(struct usb_device___2 *, void *);
};

struct each_hub_arg {
	void *data;
	int (*fn)(struct device___15 *, void *);
};

struct usb_qualifier_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 bcdUSB;
	__u8 bDeviceClass;
	__u8 bDeviceSubClass;
	__u8 bDeviceProtocol;
	__u8 bMaxPacketSize0;
	__u8 bNumConfigurations;
	__u8 bRESERVED;
};

struct usb_set_sel_req {
	__u8 u1_sel;
	__u8 u1_pel;
	__le16 u2_sel;
	__le16 u2_pel;
};

struct usb_interface___3 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct device___154 dev;
	struct device___154 *usb_dev;
	struct work_struct reset_ws;
};

struct usb_host_config___3 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___3 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___3;

struct usb_bus___3 {
	struct device___154 *controller;
	struct device___154 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___3 *root_hub;
	struct usb_bus___3 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___3;

struct usb_device___3 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	enum usb_ssp_rate ssp_rate;
	struct usb_tt___3 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___3 *parent;
	struct usb_bus___3 *bus;
	struct usb_host_endpoint ep0;
	struct device___154 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___3 *config;
	struct usb_host_config___3 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	u8 devaddr;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct wusb_dev *wusb_dev;
	int slot_id;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
	unsigned int use_generic_driver: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_tt___3 {
	struct usb_device___3 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___2 {
	struct device_driver___154 driver;
	int for_devices;
};

struct usb_driver___2 {
	const char *name;
	int (*probe)(struct usb_interface___3 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___3 *);
	int (*unlocked_ioctl)(struct usb_interface___3 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___3 *, pm_message_t);
	int (*resume)(struct usb_interface___3 *);
	int (*reset_resume)(struct usb_interface___3 *);
	int (*pre_reset)(struct usb_interface___3 *);
	int (*post_reset)(struct usb_interface___3 *);
	const struct usb_device_id *id_table;
	const struct attribute_group___183 **dev_groups;
	struct usb_dynids dynids;
	struct usbdrv_wrap___2 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct urb___3;

typedef void (*usb_complete_t___3)(struct urb___3 *);

struct urb___3 {
	struct kref kref;
	int unlinked;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___3 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___3 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct usbdevfs_hub_portinfo {
	char nports;
	char port[127];
};

struct hc_driver___3;

struct usb_hcd___3 {
	struct usb_bus___3 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___3 *status_urb;
	struct work_struct wakeup_work;
	struct work_struct died_work;
	const struct hc_driver___3 *driver;
	struct usb_phy *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	enum usb_dev_authorize_policy dev_policy;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___3 *shared_hcd;
	struct usb_hcd___3 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	struct gen_pool *localmem_pool;
	long unsigned int hcd_priv[0];
};

struct hc_driver___3 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___3 *);
	int flags;
	int (*reset)(struct usb_hcd___3 *);
	int (*start)(struct usb_hcd___3 *);
	int (*pci_suspend)(struct usb_hcd___3 *, bool);
	int (*pci_resume)(struct usb_hcd___3 *, bool);
	void (*stop)(struct usb_hcd___3 *);
	void (*shutdown)(struct usb_hcd___3 *);
	int (*get_frame_number)(struct usb_hcd___3 *);
	int (*urb_enqueue)(struct usb_hcd___3 *, struct urb___3 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___3 *, struct urb___3 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___3 *, struct urb___3 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___3 *, struct urb___3 *);
	void (*endpoint_disable)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___3 *, char *);
	int (*hub_control)(struct usb_hcd___3 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___3 *);
	int (*bus_resume)(struct usb_hcd___3 *);
	int (*start_port_reset)(struct usb_hcd___3 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___3 *);
	void (*relinquish_port)(struct usb_hcd___3 *, int);
	int (*port_handed_over)(struct usb_hcd___3 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___3 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___3 *, struct usb_device___3 *);
	void (*free_dev)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*alloc_streams)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___3 *, struct usb_device___3 *);
	void (*reset_bandwidth)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*address_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*enable_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*update_hub_device)(struct usb_hcd___3 *, struct usb_device___3 *, struct usb_tt___3 *, gfp_t);
	int (*reset_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*update_device)(struct usb_hcd___3 *, struct usb_device___3 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___3 *, struct usb_device___3 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___3 *, struct usb_device___3 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___3 *, struct usb_device___3 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___3 *, int);
	int (*port_power)(struct usb_hcd___3 *, int, bool);
	int (*submit_single_step_set_feature)(struct usb_hcd___3 *, struct urb___3 *, int);
};

struct usb_otg___2;

struct usb_phy_io_ops___2;

struct usb_phy {
	struct device___154 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg___2 *otg;
	struct device___154 *io_dev;
	struct usb_phy_io_ops___2 *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy *);
	void (*shutdown)(struct usb_phy *);
	int (*set_vbus)(struct usb_phy *, int);
	int (*set_power)(struct usb_phy *, unsigned int);
	int (*set_suspend)(struct usb_phy *, int);
	int (*set_wakeup)(struct usb_phy *, bool);
	int (*notify_connect)(struct usb_phy *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy *);
};

enum hub_led_mode {
	INDICATOR_AUTO = 0,
	INDICATOR_CYCLE = 1,
	INDICATOR_GREEN_BLINK = 2,
	INDICATOR_GREEN_BLINK_OFF = 3,
	INDICATOR_AMBER_BLINK = 4,
	INDICATOR_AMBER_BLINK_OFF = 5,
	INDICATOR_ALT_BLINK = 6,
	INDICATOR_ALT_BLINK_OFF = 7,
};

struct usb_tt_clear {
	struct list_head clear_list;
	unsigned int tt;
	u16 devinfo;
	struct usb_hcd___3 *hcd;
	struct usb_host_endpoint *ep;
};

struct phy___11;

struct phy_ops___10 {
	int (*init)(struct phy___11 *);
	int (*exit)(struct phy___11 *);
	int (*power_on)(struct phy___11 *);
	int (*power_off)(struct phy___11 *);
	int (*set_mode)(struct phy___11 *, enum phy_mode, int);
	int (*set_media)(struct phy___11 *, enum phy_media);
	int (*set_speed)(struct phy___11 *, int);
	int (*configure)(struct phy___11 *, union phy_configure_opts *);
	int (*validate)(struct phy___11 *, enum phy_mode, int, union phy_configure_opts *);
	int (*reset)(struct phy___11 *);
	int (*calibrate)(struct phy___11 *);
	void (*release)(struct phy___11 *);
	struct module___179 *owner;
};

struct phy___11 {
	struct device___154 dev;
	int id;
	const struct phy_ops___10 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct usb_phy_io_ops___2 {
	int (*read)(struct usb_phy *, u32);
	int (*write)(struct usb_phy *, u32, u32);
};

struct usb_otg___2 {
	u8 default_a;
	struct phy___11 *phy;
	struct usb_phy *usb_phy;
	struct usb_bus___3 *host;
	struct usb_gadget *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg___2 *, struct usb_bus___3 *);
	int (*set_peripheral)(struct usb_otg___2 *, struct usb_gadget *);
	int (*set_vbus)(struct usb_otg___2 *, bool);
	int (*start_srp)(struct usb_otg___2 *);
	int (*start_hnp)(struct usb_otg___2 *);
};

struct usb_port___2;

struct usb_hub___2 {
	struct device___154 *intfdev;
	struct usb_device___3 *hdev;
	struct kref kref;
	struct urb___3 *urb;
	u8 (*buffer)[8];
	union {
		struct usb_hub_status hub;
		struct usb_port_status port;
	} *status;
	struct mutex status_mutex;
	int error;
	int nerrors;
	long unsigned int event_bits[1];
	long unsigned int change_bits[1];
	long unsigned int removed_bits[1];
	long unsigned int wakeup_bits[1];
	long unsigned int power_bits[1];
	long unsigned int child_usage_bits[1];
	long unsigned int warm_reset_bits[1];
	struct usb_hub_descriptor *descriptor;
	struct usb_tt___3 tt;
	unsigned int mA_per_port;
	unsigned int wakeup_enabled_descendants;
	unsigned int limited_power: 1;
	unsigned int quiescing: 1;
	unsigned int disconnected: 1;
	unsigned int in_reset: 1;
	unsigned int quirk_disable_autosuspend: 1;
	unsigned int quirk_check_port_auto_suspend: 1;
	unsigned int has_indicators: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 indicator[31];
	struct delayed_work leds;
	struct delayed_work init_work;
	struct work_struct events;
	spinlock_t irq_urb_lock;
	struct timer_list irq_urb_retry;
	struct usb_port___2 **ports;
};

struct usb_port___2 {
	struct usb_device___3 *child;
	struct device___154 dev;
	struct usb_dev_state *port_owner;
	struct usb_port___2 *peer;
	struct dev_pm_qos_request___11 *req;
	enum usb_port_connect_type connect_type;
	usb_port_location_t location;
	struct mutex status_lock;
	u32 over_current_count;
	u8 portnum;
	u32 quirks;
	unsigned int is_superspeed: 1;
	unsigned int usb3_lpm_u1_permit: 1;
	unsigned int usb3_lpm_u2_permit: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum hub_activation_type {
	HUB_INIT = 0,
	HUB_INIT2 = 1,
	HUB_INIT3 = 2,
	HUB_POST_RESET = 3,
	HUB_RESUME = 4,
	HUB_RESET_RESUME = 5,
};

enum hub_quiescing_type {
	HUB_DISCONNECT = 0,
	HUB_PRE_RESET = 1,
	HUB_SUSPEND = 2,
};

struct usb_ctrlrequest {
	__u8 bRequestType;
	__u8 bRequest;
	__le16 wValue;
	__le16 wIndex;
	__le16 wLength;
};

struct usb_mon_operations {
	void (*urb_submit)(struct usb_bus___3 *, struct urb___3 *);
	void (*urb_submit_error)(struct usb_bus___3 *, struct urb___3 *, int);
	void (*urb_complete)(struct usb_bus___3 *, struct urb___3 *, int);
};

struct usb_sg_request {
	int status;
	size_t bytes;
	spinlock_t lock;
	struct usb_device___3 *dev;
	int pipe;
	int entries;
	struct urb___3 **urbs;
	int count;
	struct completion complete;
};

struct usb_cdc_header_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdCDC;
} __attribute__((packed));

struct usb_cdc_call_mgmt_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bmCapabilities;
	__u8 bDataInterface;
};

struct usb_cdc_acm_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bmCapabilities;
};

struct usb_cdc_union_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bMasterInterface0;
	__u8 bSlaveInterface0;
};

struct usb_cdc_country_functional_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 iCountryCodeRelDate;
	__le16 wCountyCode0;
};

struct usb_cdc_network_terminal_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bEntityId;
	__u8 iName;
	__u8 bChannelIndex;
	__u8 bPhysicalInterface;
};

struct usb_cdc_ether_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 iMACAddress;
	__le32 bmEthernetStatistics;
	__le16 wMaxSegmentSize;
	__le16 wNumberMCFilters;
	__u8 bNumberPowerFilters;
} __attribute__((packed));

struct usb_cdc_dmm_desc {
	__u8 bFunctionLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubtype;
	__u16 bcdVersion;
	__le16 wMaxCommand;
} __attribute__((packed));

struct usb_cdc_mdlm_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdVersion;
	__u8 bGUID[16];
} __attribute__((packed));

struct usb_cdc_mdlm_detail_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__u8 bGuidDescriptorType;
	__u8 bDetailData[0];
};

struct usb_cdc_obex_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdVersion;
} __attribute__((packed));

struct usb_cdc_ncm_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdNcmVersion;
	__u8 bmNetworkCapabilities;
} __attribute__((packed));

struct usb_cdc_mbim_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdMBIMVersion;
	__le16 wMaxControlMessage;
	__u8 bNumberFilters;
	__u8 bMaxFilterSize;
	__le16 wMaxSegmentSize;
	__u8 bmNetworkCapabilities;
} __attribute__((packed));

struct usb_cdc_mbim_extended_desc {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDescriptorSubType;
	__le16 bcdMBIMExtendedVersion;
	__u8 bMaxOutstandingCommandMessages;
	__le16 wMTU;
} __attribute__((packed));

struct usb_cdc_parsed_header {
	struct usb_cdc_union_desc *usb_cdc_union_desc;
	struct usb_cdc_header_desc *usb_cdc_header_desc;
	struct usb_cdc_call_mgmt_descriptor *usb_cdc_call_mgmt_descriptor;
	struct usb_cdc_acm_descriptor *usb_cdc_acm_descriptor;
	struct usb_cdc_country_functional_desc *usb_cdc_country_functional_desc;
	struct usb_cdc_network_terminal_desc *usb_cdc_network_terminal_desc;
	struct usb_cdc_ether_desc *usb_cdc_ether_desc;
	struct usb_cdc_dmm_desc *usb_cdc_dmm_desc;
	struct usb_cdc_mdlm_desc *usb_cdc_mdlm_desc;
	struct usb_cdc_mdlm_detail_desc *usb_cdc_mdlm_detail_desc;
	struct usb_cdc_obex_desc *usb_cdc_obex_desc;
	struct usb_cdc_ncm_desc *usb_cdc_ncm_desc;
	struct usb_cdc_mbim_desc *usb_cdc_mbim_desc;
	struct usb_cdc_mbim_extended_desc *usb_cdc_mbim_extended_desc;
	bool phonet_magic_present;
};

struct api_context {
	struct completion done;
	int status;
};

struct set_config_request {
	struct usb_device___3 *udev;
	int config;
	struct work_struct work;
	struct list_head node;
};

struct usb_dynid {
	struct list_head node;
	struct usb_device_id id;
};

struct usb_device_driver___2 {
	const char *name;
	bool (*match)(struct usb_device___3 *);
	int (*probe)(struct usb_device___3 *);
	void (*disconnect)(struct usb_device___3 *);
	int (*suspend)(struct usb_device___3 *, pm_message_t);
	int (*resume)(struct usb_device___3 *, pm_message_t);
	const struct attribute_group___208 **dev_groups;
	struct usbdrv_wrap___2 drvwrap;
	const struct usb_device_id *id_table;
	unsigned int supports_autosuspend: 1;
	unsigned int generic_subclass: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_dev_cap_header {
	__u8 bLength;
	__u8 bDescriptorType;
	__u8 bDevCapabilityType;
};

struct usb_class_driver {
	char *name;
	char * (*devnode)(struct device___198 *, umode_t *);
	const struct file_operations___221 *fops;
	int minor_base;
};

struct usb_class {
	struct kref kref;
	struct class___198 *class;
};

struct ep_device {
	struct usb_endpoint_descriptor *desc;
	struct usb_device___2 *udev;
	struct device___194 dev;
};

typedef struct poll_table_struct___145 poll_table___43;

struct usbdevfs_ctrltransfer {
	__u8 bRequestType;
	__u8 bRequest;
	__u16 wValue;
	__u16 wIndex;
	__u16 wLength;
	__u32 timeout;
	void *data;
};

struct usbdevfs_bulktransfer {
	unsigned int ep;
	unsigned int len;
	unsigned int timeout;
	void *data;
};

struct usbdevfs_setinterface {
	unsigned int interface;
	unsigned int altsetting;
};

struct usbdevfs_disconnectsignal {
	unsigned int signr;
	void *context;
};

struct usbdevfs_getdriver {
	unsigned int interface;
	char driver[256];
};

struct usbdevfs_connectinfo {
	unsigned int devnum;
	unsigned char slow;
};

struct usbdevfs_conninfo_ex {
	__u32 size;
	__u32 busnum;
	__u32 devnum;
	__u32 speed;
	__u8 num_ports;
	__u8 ports[7];
};

struct usbdevfs_iso_packet_desc {
	unsigned int length;
	unsigned int actual_length;
	unsigned int status;
};

struct usbdevfs_urb {
	unsigned char type;
	unsigned char endpoint;
	int status;
	unsigned int flags;
	void *buffer;
	int buffer_length;
	int actual_length;
	int start_frame;
	union {
		int number_of_packets;
		unsigned int stream_id;
	};
	int error_count;
	unsigned int signr;
	void *usercontext;
	struct usbdevfs_iso_packet_desc iso_frame_desc[0];
};

struct usbdevfs_ioctl {
	int ifno;
	int ioctl_code;
	void *data;
};

struct usbdevfs_disconnect_claim {
	unsigned int interface;
	unsigned int flags;
	char driver[256];
};

struct usbdevfs_streams {
	unsigned int num_streams;
	unsigned int num_eps;
	unsigned char eps[0];
};

struct usbdevfs_ctrltransfer32 {
	u8 bRequestType;
	u8 bRequest;
	u16 wValue;
	u16 wIndex;
	u16 wLength;
	u32 timeout;
	compat_caddr_t data;
};

struct usbdevfs_bulktransfer32 {
	compat_uint_t ep;
	compat_uint_t len;
	compat_uint_t timeout;
	compat_caddr_t data;
};

struct usbdevfs_disconnectsignal32 {
	compat_int_t signr;
	compat_caddr_t context;
};

struct usbdevfs_urb32 {
	unsigned char type;
	unsigned char endpoint;
	compat_int_t status;
	compat_uint_t flags;
	compat_caddr_t buffer;
	compat_int_t buffer_length;
	compat_int_t actual_length;
	compat_int_t start_frame;
	compat_int_t number_of_packets;
	compat_int_t error_count;
	compat_uint_t signr;
	compat_caddr_t usercontext;
	struct usbdevfs_iso_packet_desc iso_frame_desc[0];
};

struct usbdevfs_ioctl32 {
	s32 ifno;
	s32 ioctl_code;
	compat_caddr_t data;
};

struct usb_dev_state___2 {
	struct list_head list;
	struct usb_device___3 *dev;
	struct file___220 *file;
	spinlock_t lock;
	struct list_head async_pending;
	struct list_head async_completed;
	struct list_head memory_list;
	wait_queue_head_t wait;
	wait_queue_head_t wait_for_resume;
	unsigned int discsignr;
	struct pid___197 *disc_pid;
	const struct cred___13 *cred;
	sigval_t disccontext;
	long unsigned int ifclaimed;
	u32 disabled_bulk_eps;
	long unsigned int interface_allowed_mask;
	int not_yet_resumed;
	bool suspend_allowed;
	bool privileges_dropped;
};

struct usb_memory {
	struct list_head memlist;
	int vma_use_count;
	int urb_use_count;
	u32 size;
	void *mem;
	dma_addr_t dma_handle;
	long unsigned int vm_start;
	struct usb_dev_state___2 *ps;
};

struct async {
	struct list_head asynclist;
	struct usb_dev_state___2 *ps;
	struct pid___197 *pid;
	const struct cred___13 *cred;
	unsigned int signr;
	unsigned int ifnum;
	void *userbuffer;
	void *userurb;
	sigval_t userurb_sigval;
	struct urb___3 *urb;
	struct usb_memory *usbm;
	unsigned int mem_usage;
	int status;
	u8 bulk_addr;
	u8 bulk_status;
};

enum snoop_when {
	SUBMIT = 0,
	COMPLETE = 1,
};

struct quirk_entry {
	u16 vid;
	u16 pid;
	u32 flags;
};

struct class_info {
	int class;
	char *class_name;
};

struct usb_phy_roothub___2 {
	struct phy___10 *phy;
	struct list_head list;
};

typedef void (*companion_fn)(struct pci_dev___18 *, struct usb_hcd___3 *, struct pci_dev___18 *, struct usb_hcd___3 *);

typedef int (*dr_match_t___23)(struct device___198 *, void *, void *);

struct phy_devm {
	struct usb_phy *phy;
	struct notifier_block *nb;
};

enum usb_phy_interface {
	USBPHY_INTERFACE_MODE_UNKNOWN = 0,
	USBPHY_INTERFACE_MODE_UTMI = 1,
	USBPHY_INTERFACE_MODE_UTMIW = 2,
	USBPHY_INTERFACE_MODE_ULPI = 3,
	USBPHY_INTERFACE_MODE_SERIAL = 4,
	USBPHY_INTERFACE_MODE_HSIC = 5,
};

struct mxs_phy_data {
	unsigned int flags;
};

struct mxs_phy {
	struct usb_phy phy;
	struct clk *clk;
	const struct mxs_phy_data *data;
	struct regmap *regmap_anatop;
	int port_id;
	u32 tx_reg_set;
	u32 tx_reg_mask;
};

struct ulpi_info {
	unsigned int id;
	char *name;
};

struct dentry___229;

struct super_block___229;

struct module___213;

struct file_system_type___229 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___229 * (*mount)(struct file_system_type___229 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___229 *);
	struct module___213 *owner;
	struct file_system_type___229 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___229;

struct kiocb___229;

struct iov_iter___149;

struct poll_table_struct___154;

struct vm_area_struct___234;

struct inode___229;

struct file_lock___229;

struct page___234;

struct seq_file___204;

struct file_operations___230 {
	struct module___213 *owner;
	loff_t (*llseek)(struct file___229 *, loff_t, int);
	ssize_t (*read)(struct file___229 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___229 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___229 *, struct iov_iter___149 *);
	ssize_t (*write_iter)(struct kiocb___229 *, struct iov_iter___149 *);
	int (*iopoll)(struct kiocb___229 *, bool);
	int (*iterate)(struct file___229 *, struct dir_context *);
	int (*iterate_shared)(struct file___229 *, struct dir_context *);
	__poll_t (*poll)(struct file___229 *, struct poll_table_struct___154 *);
	long int (*unlocked_ioctl)(struct file___229 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___229 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___229 *, struct vm_area_struct___234 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___229 *, struct file___229 *);
	int (*flush)(struct file___229 *, fl_owner_t);
	int (*release)(struct inode___229 *, struct file___229 *);
	int (*fsync)(struct file___229 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___229 *, int);
	int (*lock)(struct file___229 *, int, struct file_lock___229 *);
	ssize_t (*sendpage)(struct file___229 *, struct page___234 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___229 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___229 *, long unsigned int);
	int (*flock)(struct file___229 *, int, struct file_lock___229 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___229 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___229 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___229 *, long int, struct file_lock___229 **, void **);
	long int (*fallocate)(struct file___229 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___204 *, struct file___229 *);
	ssize_t (*copy_file_range)(struct file___229 *, loff_t, struct file___229 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___229 *, loff_t, struct file___229 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___229 *, loff_t, loff_t, int);
};

union rcu_special___2 {
	struct {
		u8 blocked;
		u8 need_qs;
		u8 exp_hint;
		u8 need_mb;
	} b;
	u32 s;
};

struct vmacache___234 {
	u64 seqnum;
	struct vm_area_struct___234 *vmas[4];
};

struct page_frag___234 {
	struct page___234 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___235;

struct pid___206;

struct nsproxy___215;

struct signal_struct___230;

struct bio_list___122;

struct backing_dev_info___111;

struct io_context___122;

struct css_set___159;

struct mem_cgroup___102;

struct request_queue___122;

struct vm_struct___212;

struct task_struct___236 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___236 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special___2 trc_reader_special;
	int: 32;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___235 *mm;
	struct mm_struct___235 *active_mm;
	struct vmacache___234 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___236 *real_parent;
	struct task_struct___236 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___236 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___206 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___215 *nsproxy;
	struct signal_struct___230 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___236 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___122 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___111 *backing_dev_info;
	struct io_context___122 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___159 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___234 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___102 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___102 *active_memcg;
	struct request_queue___122 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___236 *oom_reaper_list;
	struct vm_struct___212 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___81 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___217;

struct kobj_type___217;

struct kernfs_node___217;

struct kobject___217 {
	const char *name;
	struct list_head entry;
	struct kobject___217 *parent;
	struct kset___217 *kset;
	struct kobj_type___217 *ktype;
	struct kernfs_node___217 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___214 {
	struct kobject___217 kobj;
	struct module___213 *mod;
	struct kobject___217 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___213 {
	struct module___213 *mod;
	struct latch_tree_node node;
};

struct module_layout___213 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___213 mtn;
};

struct module_attribute___213;

struct kernel_param___213;

struct module___213 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___214 mkobj;
	struct module_attribute___213 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___217 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___213 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___213 core_layout;
	struct module_layout___213 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___206;

struct upid___206 {
	int nr;
	struct pid_namespace___206 *ns;
};

struct pid_namespace___206 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___236 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___206 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___206 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___206 numbers[1];
};

typedef struct page___234 *pgtable_t___234;

struct address_space___229;

struct dev_pagemap___224;

struct page___234 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___229 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___234 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___234 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___235 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___224 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___224;

struct vm_area_struct___234 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___234 *vm_next;
	struct vm_area_struct___234 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___235 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___224 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___229 *vm_file;
	struct file___229 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___230 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___236 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___236 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___206 *pids[4];
	struct pid___206 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___235 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___234;

struct mm_struct___235 {
	struct {
		struct vm_area_struct___234 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___229 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___234 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___236 *owner;
		struct user_namespace___14 *user_ns;
		struct file___229 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___159;

struct nsproxy___215 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___206 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___159 *cgroup_ns;
};

struct bio___122;

struct bio_list___122 {
	struct bio___122 *head;
	struct bio___122 *tail;
};

struct cgroup_subsys_state___159;

struct bdi_writeback___111 {
	struct backing_dev_info___111 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___159 *memcg_css;
	struct cgroup_subsys_state___159 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___207;

struct backing_dev_info___111 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___111 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___207 *dev;
	char dev_name[64];
	struct device___207 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___229 *debug_dir;
};

struct io_cq___122;

struct io_context___122 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___122 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___159;

struct css_set___159 {
	struct cgroup_subsys_state___159 *subsys[14];
	refcount_t refcount;
	struct css_set___159 *dom_cset;
	struct cgroup___159 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___159 *mg_src_cgrp;
	struct cgroup___159 *mg_dst_cgrp;
	struct css_set___159 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___159;

struct cgroup_subsys_state___159 {
	struct cgroup___159 *cgroup;
	struct cgroup_subsys___159 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___159 *parent;
};

struct cgroup_file___159 {
	struct kernfs_node___217 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___102;

struct mem_cgroup_per_node___102;

struct mem_cgroup___102 {
	struct cgroup_subsys_state___159 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___159 events_file;
	struct cgroup_file___159 events_local_file;
	struct cgroup_file___159 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___102 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___236 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___102 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___122;

struct blk_integrity___122 {
	const struct blk_integrity_profile___122 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___122 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___122 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___122;

struct elevator_queue___122;

struct blk_mq_ops___119;

struct blk_mq_hw_ctx___119;

struct gendisk___125;

struct blkcg_gq___113;

struct blk_mq_tag_set___119;

struct request_queue___122 {
	struct request___122 *last_merge;
	struct elevator_queue___122 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___119 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___119 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___125 *disk;
	struct kobject___217 kobj;
	struct kobject___217 *mq_kobj;
	struct blk_integrity___122 integrity;
	struct device___207 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___113 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___119 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___122 bio_split;
	struct dentry___229 *debugfs_dir;
	struct dentry___229 *sched_debugfs_dir;
	struct dentry___229 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___212 {
	struct vm_struct___212 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___234 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___229;

struct address_space___229 {
	struct inode___229 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___229 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___224;

struct dev_pagemap___224 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___224 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___229;

struct path___229 {
	struct vfsmount___229 *mnt;
	struct dentry___229 *dentry;
};

struct fown_struct___206 {
	rwlock_t lock;
	struct pid___206 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___229 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___229 f_path;
	struct inode___229 *f_inode;
	const struct file_operations___230 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___206 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___229 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___224;

struct vm_operations_struct___224 {
	void (*open)(struct vm_area_struct___234 *);
	void (*close)(struct vm_area_struct___234 *);
	int (*may_split)(struct vm_area_struct___234 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___234 *);
	int (*mprotect)(struct vm_area_struct___234 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___224 *);
	vm_fault_t (*huge_fault)(struct vm_fault___224 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___224 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___234 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___224 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___224 *);
	int (*access)(struct vm_area_struct___234 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___234 *);
	int (*set_policy)(struct vm_area_struct___234 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___234 *, long unsigned int);
	struct page___234 * (*find_special_page)(struct vm_area_struct___234 *, long unsigned int);
};

struct core_thread___234 {
	struct task_struct___236 *task;
	struct core_thread___234 *next;
};

struct core_state___234 {
	atomic_t nr_threads;
	struct core_thread___234 dumper;
	struct completion startup;
};

struct vm_fault___224 {
	const struct {
		struct vm_area_struct___234 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___234 *cow_page;
	struct page___234 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___234 prealloc_pte;
};

struct pglist_data___110;

struct lruvec___110 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___110 *pgdat;
};

struct zone___110 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___110 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___110 {
	struct zone___110 *zone;
	int zone_idx;
};

struct zonelist___110 {
	struct zoneref___110 _zonerefs[321];
};

struct pglist_data___110 {
	struct zone___110 node_zones[5];
	struct zonelist___110 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___236 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___236 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___110 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___229;

struct dentry___229 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___229 *d_parent;
	struct qstr d_name;
	struct inode___229 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___229 *d_op;
	struct super_block___229 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___229;

struct cdev___61;

struct inode___229 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___229 *i_op;
	struct super_block___229 *i_sb;
	struct address_space___229 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___111 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___230 *i_fop;
		void (*free_inode)(struct inode___229 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___229 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___61 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___229 {
	int (*d_revalidate)(struct dentry___229 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___229 *, unsigned int);
	int (*d_hash)(const struct dentry___229 *, struct qstr *);
	int (*d_compare)(const struct dentry___229 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___229 *);
	int (*d_init)(struct dentry___229 *);
	void (*d_release)(struct dentry___229 *);
	void (*d_prune)(struct dentry___229 *);
	void (*d_iput)(struct dentry___229 *, struct inode___229 *);
	char * (*d_dname)(struct dentry___229 *, char *, int);
	struct vfsmount___229 * (*d_automount)(struct path___229 *);
	int (*d_manage)(const struct path___229 *, bool);
	struct dentry___229 * (*d_real)(struct dentry___229 *, const struct inode___229 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___229;

struct mem_dqinfo___229 {
	struct quota_format_type___229 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___229;

struct quota_info___229 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___229 *files[3];
	struct mem_dqinfo___229 info[3];
	const struct quota_format_ops___229 *ops[3];
};

struct rcuwait___230 {
	struct task_struct___236 *task;
};

struct percpu_rw_semaphore___230 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___230 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___229 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___230 rw_sem[3];
};

struct shrink_control___102;

struct shrinker___102 {
	long unsigned int (*count_objects)(struct shrinker___102 *, struct shrink_control___102 *);
	long unsigned int (*scan_objects)(struct shrinker___102 *, struct shrink_control___102 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___229;

struct dquot_operations___229;

struct quotactl_ops___229;

struct block_device___125;

struct super_block___229 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___229 *s_type;
	const struct super_operations___229 *s_op;
	const struct dquot_operations___229 *dq_op;
	const struct quotactl_ops___229 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___229 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___125 *s_bdev;
	struct backing_dev_info___111 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___229 s_dquot;
	struct sb_writers___229 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___229 *s_d_op;
	int cleancache_poolid;
	struct shrinker___102 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___229 {
	struct dentry___229 *mnt_root;
	struct super_block___229 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___102 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___102 *memcg;
};

struct psi_group___159 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___236 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___159;

struct cgroup_rstat_cpu___159;

struct cgroup___159 {
	struct cgroup_subsys_state___159 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___217 *kn;
	struct cgroup_file___159 procs_file;
	struct cgroup_file___159 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___159 *subsys[14];
	struct cgroup_root___159 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___159 *dom_cgrp;
	struct cgroup___159 *old_dom_cgrp;
	struct cgroup_rstat_cpu___159 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___159 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___122 {
	struct request_queue___122 *q;
	struct io_context___122 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___107;

struct kiocb___229 {
	struct file___229 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___229 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___107 *ki_waitq;
	};
};

struct iattr___229 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___229 *ia_file;
};

struct dquot___229 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___229 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___229 {
	int qf_fmt_id;
	const struct quota_format_ops___229 *qf_ops;
	struct module___213 *qf_owner;
	struct quota_format_type___229 *qf_next;
};

struct quota_format_ops___229 {
	int (*check_quota_file)(struct super_block___229 *, int);
	int (*read_file_info)(struct super_block___229 *, int);
	int (*write_file_info)(struct super_block___229 *, int);
	int (*free_file_info)(struct super_block___229 *, int);
	int (*read_dqblk)(struct dquot___229 *);
	int (*commit_dqblk)(struct dquot___229 *);
	int (*release_dqblk)(struct dquot___229 *);
	int (*get_next_id)(struct super_block___229 *, struct kqid *);
};

struct dquot_operations___229 {
	int (*write_dquot)(struct dquot___229 *);
	struct dquot___229 * (*alloc_dquot)(struct super_block___229 *, int);
	void (*destroy_dquot)(struct dquot___229 *);
	int (*acquire_dquot)(struct dquot___229 *);
	int (*release_dquot)(struct dquot___229 *);
	int (*mark_dirty)(struct dquot___229 *);
	int (*write_info)(struct super_block___229 *, int);
	qsize_t * (*get_reserved_space)(struct inode___229 *);
	int (*get_projid)(struct inode___229 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___229 *, qsize_t *);
	int (*get_next_id)(struct super_block___229 *, struct kqid *);
};

struct quotactl_ops___229 {
	int (*quota_on)(struct super_block___229 *, int, int, const struct path___229 *);
	int (*quota_off)(struct super_block___229 *, int);
	int (*quota_enable)(struct super_block___229 *, unsigned int);
	int (*quota_disable)(struct super_block___229 *, unsigned int);
	int (*quota_sync)(struct super_block___229 *, int);
	int (*set_info)(struct super_block___229 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___229 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___229 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___229 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___229 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___229 *, unsigned int);
};

struct wait_page_queue___107 {
	struct page___234 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___111;

struct readahead_control___107;

struct swap_info_struct___65;

struct address_space_operations___229 {
	int (*writepage)(struct page___234 *, struct writeback_control___111 *);
	int (*readpage)(struct file___229 *, struct page___234 *);
	int (*writepages)(struct address_space___229 *, struct writeback_control___111 *);
	int (*set_page_dirty)(struct page___234 *);
	int (*readpages)(struct file___229 *, struct address_space___229 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___107 *);
	int (*write_begin)(struct file___229 *, struct address_space___229 *, loff_t, unsigned int, unsigned int, struct page___234 **, void **);
	int (*write_end)(struct file___229 *, struct address_space___229 *, loff_t, unsigned int, unsigned int, struct page___234 *, void *);
	sector_t (*bmap)(struct address_space___229 *, sector_t);
	void (*invalidatepage)(struct page___234 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___234 *, gfp_t);
	void (*freepage)(struct page___234 *);
	ssize_t (*direct_IO)(struct kiocb___229 *, struct iov_iter___149 *);
	int (*migratepage)(struct address_space___229 *, struct page___234 *, struct page___234 *, enum migrate_mode);
	bool (*isolate_page)(struct page___234 *, isolate_mode_t);
	void (*putback_page)(struct page___234 *);
	int (*launder_page)(struct page___234 *);
	int (*is_partially_uptodate)(struct page___234 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___234 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___229 *, struct page___234 *);
	int (*swap_activate)(struct swap_info_struct___65 *, struct file___229 *, sector_t *);
	void (*swap_deactivate)(struct file___229 *);
};

struct writeback_control___111 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___111 *wb;
	struct inode___229 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___107 {
	struct file___229 *file;
	struct address_space___229 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___146;

struct iov_iter___149 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___146 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___65 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___125 *bdev;
	struct file___229 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___61 {
	struct kobject___217 kobj;
	struct module___213 *owner;
	const struct file_operations___230 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___229 {
	struct dentry___229 * (*lookup)(struct inode___229 *, struct dentry___229 *, unsigned int);
	const char * (*get_link)(struct dentry___229 *, struct inode___229 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___229 *, int);
	struct posix_acl * (*get_acl)(struct inode___229 *, int, bool);
	int (*readlink)(struct dentry___229 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___229 *, struct dentry___229 *, umode_t, bool);
	int (*link)(struct dentry___229 *, struct inode___229 *, struct dentry___229 *);
	int (*unlink)(struct inode___229 *, struct dentry___229 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___229 *, struct dentry___229 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___229 *, struct dentry___229 *, umode_t);
	int (*rmdir)(struct inode___229 *, struct dentry___229 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___229 *, struct dentry___229 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___229 *, struct dentry___229 *, struct inode___229 *, struct dentry___229 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___229 *, struct iattr___229 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___229 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___229 *, char *, size_t);
	int (*fiemap)(struct inode___229 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___229 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___229 *, struct dentry___229 *, struct file___229 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___229 *, struct dentry___229 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___229 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___229 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___229 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___229 {
	void (*fl_copy_lock)(struct file_lock___229 *, struct file_lock___229 *);
	void (*fl_release_private)(struct file_lock___229 *);
};

struct fasync_struct___229;

struct lock_manager_operations___229;

struct file_lock___229 {
	struct file_lock___229 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___229 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___229 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___229 *fl_ops;
	const struct lock_manager_operations___229 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___229 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___229 *);
	int (*lm_grant)(struct file_lock___229 *, int);
	bool (*lm_break)(struct file_lock___229 *);
	int (*lm_change)(struct file_lock___229 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___229 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___229 *);
};

struct fasync_struct___229 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___229 *fa_next;
	struct file___229 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___229 {
	struct inode___229 * (*alloc_inode)(struct super_block___229 *);
	void (*destroy_inode)(struct inode___229 *);
	void (*free_inode)(struct inode___229 *);
	void (*dirty_inode)(struct inode___229 *, int);
	int (*write_inode)(struct inode___229 *, struct writeback_control___111 *);
	int (*drop_inode)(struct inode___229 *);
	void (*evict_inode)(struct inode___229 *);
	void (*put_super)(struct super_block___229 *);
	int (*sync_fs)(struct super_block___229 *, int);
	int (*freeze_super)(struct super_block___229 *);
	int (*freeze_fs)(struct super_block___229 *);
	int (*thaw_super)(struct super_block___229 *);
	int (*unfreeze_fs)(struct super_block___229 *);
	int (*statfs)(struct dentry___229 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___229 *, int *, char *);
	void (*umount_begin)(struct super_block___229 *);
	int (*show_options)(struct seq_file___204 *, struct dentry___229 *);
	int (*show_devname)(struct seq_file___204 *, struct dentry___229 *);
	int (*show_path)(struct seq_file___204 *, struct dentry___229 *);
	int (*show_stats)(struct seq_file___204 *, struct dentry___229 *);
	ssize_t (*quota_read)(struct super_block___229 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___229 *, int, const char *, size_t, loff_t);
	struct dquot___229 ** (*get_dquots)(struct inode___229 *);
	long int (*nr_cached_objects)(struct super_block___229 *, struct shrink_control___102 *);
	long int (*free_cached_objects)(struct super_block___229 *, struct shrink_control___102 *);
	struct file___229 * (*real_loop)(struct file___229 *);
};

struct wakeup_source___207;

struct dev_pm_info___207 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___207 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___11 *subsys_data;
	void (*set_latency_tolerance)(struct device___207 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___207;

struct bus_type___207;

struct device_driver___207;

struct dev_pm_domain___207;

struct irq_domain___58;

struct device_node___91;

struct fwnode_handle___203;

struct class___207;

struct attribute_group___217;

struct device___207 {
	struct kobject___217 kobj;
	struct device___207 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___207 *type;
	struct bus_type___207 *bus;
	struct device_driver___207 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___207 power;
	struct dev_pm_domain___207 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___58 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___91 *of_node;
	struct fwnode_handle___203 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___207 *class;
	const struct attribute_group___217 **groups;
	void (*release)(struct device___207 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___125 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___229 *bd_inode;
	struct super_block___229 *bd_super;
	void *bd_claiming;
	struct device___207 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___217 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___125 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___229 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___161)(struct file___229 *, wait_queue_head_t *, struct poll_table_struct___154 *);

struct poll_table_struct___154 {
	poll_queue_proc___161 _qproc;
	__poll_t _key;
};

struct seq_operations___204;

struct seq_file___204 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___204 *op;
	int poll_event;
	const struct file___229 *file;
	void *private;
};

typedef void bio_end_io_t___122(struct bio___122 *);

struct bio_vec___146 {
	struct page___234 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___122;

struct bio___122 {
	struct bio___122 *bi_next;
	struct block_device___125 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___122 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___113 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___122 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___146 *bi_io_vec;
	struct bio_set___122 *bi_pool;
	struct bio_vec___146 bi_inline_vecs[0];
};

struct kernfs_root___217;

struct kernfs_elem_dir___217 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___217 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___217;

struct kernfs_root___217 {
	struct kernfs_node___217 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___217 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___217 {
	struct kernfs_node___217 *target_kn;
};

struct kernfs_ops___217;

struct kernfs_elem_attr___217 {
	const struct kernfs_ops___217 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___217 *notify_next;
};

struct kernfs_node___217 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___217 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___217 dir;
		struct kernfs_elem_symlink___217 symlink;
		struct kernfs_elem_attr___217 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___217;

struct kernfs_ops___217 {
	int (*open)(struct kernfs_open_file___217 *);
	void (*release)(struct kernfs_open_file___217 *);
	int (*seq_show)(struct seq_file___204 *, void *);
	void * (*seq_start)(struct seq_file___204 *, loff_t *);
	void * (*seq_next)(struct seq_file___204 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___204 *, void *);
	ssize_t (*read)(struct kernfs_open_file___217 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___217 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___217 *, struct poll_table_struct___154 *);
	int (*mmap)(struct kernfs_open_file___217 *, struct vm_area_struct___234 *);
};

struct kernfs_syscall_ops___217 {
	int (*show_options)(struct seq_file___204 *, struct kernfs_root___217 *);
	int (*mkdir)(struct kernfs_node___217 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___217 *);
	int (*rename)(struct kernfs_node___217 *, struct kernfs_node___217 *, const char *);
	int (*show_path)(struct seq_file___204 *, struct kernfs_node___217 *, struct kernfs_root___217 *);
};

struct kernfs_open_file___217 {
	struct kernfs_node___217 *kn;
	struct file___229 *file;
	struct seq_file___204 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___224 *vm_ops;
};

struct bin_attribute___217;

struct attribute_group___217 {
	const char *name;
	umode_t (*is_visible)(struct kobject___217 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___217 *, struct bin_attribute___217 *, int);
	struct attribute **attrs;
	struct bin_attribute___217 **bin_attrs;
};

struct bin_attribute___217 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___229 * (*f_mapping)();
	ssize_t (*read)(struct file___229 *, struct kobject___217 *, struct bin_attribute___217 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___229 *, struct kobject___217 *, struct bin_attribute___217 *, char *, loff_t, size_t);
	int (*mmap)(struct file___229 *, struct kobject___217 *, struct bin_attribute___217 *, struct vm_area_struct___234 *);
};

struct sysfs_ops___217 {
	ssize_t (*show)(struct kobject___217 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___217 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___217;

struct kset___217 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___217 kobj;
	const struct kset_uevent_ops___217 *uevent_ops;
};

struct kobj_type___217 {
	void (*release)(struct kobject___217 *);
	const struct sysfs_ops___217 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___217 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___217 *);
	const void * (*namespace)(struct kobject___217 *);
	void (*get_ownership)(struct kobject___217 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___217 {
	int (* const filter)(struct kset___217 *, struct kobject___217 *);
	const char * (* const name)(struct kset___217 *, struct kobject___217 *);
	int (* const uevent)(struct kset___217 *, struct kobject___217 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___213 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___213 *);
	int (*get)(char *, const struct kernel_param___213 *);
	void (*free)(void *);
};

struct kparam_array___213;

struct kernel_param___213 {
	const char *name;
	struct module___213 *mod;
	const struct kernel_param_ops___213 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___213 *arr;
	};
};

struct kparam_array___213 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___213 *ops;
	void *elem;
};

struct module_attribute___213 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___213 *, struct module_kobject___214 *, char *);
	ssize_t (*store)(struct module_attribute___213 *, struct module_kobject___214 *, const char *, size_t);
	void (*setup)(struct module___213 *, const char *);
	int (*test)(struct module___213 *);
	void (*free)(struct module___213 *);
};

struct irq_desc___60;

typedef void (*irq_flow_handler_t___60)(struct irq_desc___60 *);

struct irq_chip___60;

struct irq_data___60 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___60 *chip;
	struct irq_domain___58 *domain;
	struct irq_data___60 *parent_data;
	void *chip_data;
};

struct irqaction___42;

struct irq_desc___60 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___60 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___60 handle_irq;
	struct irqaction___42 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___217 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___213 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_operations___203;

struct fwnode_handle___203 {
	struct fwnode_handle___203 *secondary;
	const struct fwnode_operations___203 *ops;
	struct device___207 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___203;

struct fwnode_endpoint___203;

struct fwnode_operations___203 {
	struct fwnode_handle___203 * (*get)(struct fwnode_handle___203 *);
	void (*put)(struct fwnode_handle___203 *);
	bool (*device_is_available)(const struct fwnode_handle___203 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___203 *, const struct device___207 *);
	bool (*property_present)(const struct fwnode_handle___203 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___203 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___203 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___203 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*get_parent)(const struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*get_next_child_node)(const struct fwnode_handle___203 *, struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*get_named_child_node)(const struct fwnode_handle___203 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___203 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___203 *);
	struct fwnode_handle___203 * (*graph_get_next_endpoint)(const struct fwnode_handle___203 *, struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*graph_get_remote_endpoint)(const struct fwnode_handle___203 *);
	struct fwnode_handle___203 * (*graph_get_port_parent)(struct fwnode_handle___203 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___203 *, struct fwnode_endpoint___203 *);
	int (*add_links)(struct fwnode_handle___203 *);
};

struct fwnode_endpoint___203 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___203 *local_fwnode;
};

struct fwnode_reference_args___203 {
	struct fwnode_handle___203 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct irq_chip___60 {
	struct device___207 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___60 *);
	void (*irq_shutdown)(struct irq_data___60 *);
	void (*irq_enable)(struct irq_data___60 *);
	void (*irq_disable)(struct irq_data___60 *);
	void (*irq_ack)(struct irq_data___60 *);
	void (*irq_mask)(struct irq_data___60 *);
	void (*irq_mask_ack)(struct irq_data___60 *);
	void (*irq_unmask)(struct irq_data___60 *);
	void (*irq_eoi)(struct irq_data___60 *);
	int (*irq_set_affinity)(struct irq_data___60 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___60 *);
	int (*irq_set_type)(struct irq_data___60 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___60 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___60 *);
	void (*irq_bus_sync_unlock)(struct irq_data___60 *);
	void (*irq_cpu_online)(struct irq_data___60 *);
	void (*irq_cpu_offline)(struct irq_data___60 *);
	void (*irq_suspend)(struct irq_data___60 *);
	void (*irq_resume)(struct irq_data___60 *);
	void (*irq_pm_shutdown)(struct irq_data___60 *);
	void (*irq_calc_mask)(struct irq_data___60 *);
	void (*irq_print_chip)(struct irq_data___60 *, struct seq_file___204 *);
	int (*irq_request_resources)(struct irq_data___60 *);
	void (*irq_release_resources)(struct irq_data___60 *);
	void (*irq_compose_msi_msg)(struct irq_data___60 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___60 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___60 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___60 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___60 *, void *);
	void (*ipi_send_single)(struct irq_data___60 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___60 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___60 *);
	void (*irq_nmi_teardown)(struct irq_data___60 *);
	long unsigned int flags;
};

struct irq_domain_ops___58;

struct irq_domain_chip_generic___58;

struct irq_domain___58 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___58 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___203 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___58 *gc;
	struct irq_domain___58 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___60 *revmap[0];
};

struct irqaction___42 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___42 *next;
	irq_handler_t thread_fn;
	struct task_struct___236 *thread;
	struct irqaction___42 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___58 {
	struct irq_chip___60 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___60 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___58 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___58 *);
	void (*resume)(struct irq_chip_generic___58 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___58 *domain;
	struct list_head list;
	struct irq_chip_type___58 chip_types[0];
};

struct irq_domain_chip_generic___58 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___58 *gc[0];
};

struct dev_pm_ops___207 {
	int (*prepare)(struct device___207 *);
	void (*complete)(struct device___207 *);
	int (*suspend)(struct device___207 *);
	int (*resume)(struct device___207 *);
	int (*freeze)(struct device___207 *);
	int (*thaw)(struct device___207 *);
	int (*poweroff)(struct device___207 *);
	int (*restore)(struct device___207 *);
	int (*suspend_late)(struct device___207 *);
	int (*resume_early)(struct device___207 *);
	int (*freeze_late)(struct device___207 *);
	int (*thaw_early)(struct device___207 *);
	int (*poweroff_late)(struct device___207 *);
	int (*restore_early)(struct device___207 *);
	int (*suspend_noirq)(struct device___207 *);
	int (*resume_noirq)(struct device___207 *);
	int (*freeze_noirq)(struct device___207 *);
	int (*thaw_noirq)(struct device___207 *);
	int (*poweroff_noirq)(struct device___207 *);
	int (*restore_noirq)(struct device___207 *);
	int (*runtime_suspend)(struct device___207 *);
	int (*runtime_resume)(struct device___207 *);
	int (*runtime_idle)(struct device___207 *);
};

struct wakeup_source___207 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___207 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___207 {
	struct dev_pm_ops___207 ops;
	int (*start)(struct device___207 *);
	void (*detach)(struct device___207 *, bool);
	int (*activate)(struct device___207 *);
	void (*sync)(struct device___207 *);
	void (*dismiss)(struct device___207 *);
};

struct bus_type___207 {
	const char *name;
	const char *dev_name;
	struct device___207 *dev_root;
	const struct attribute_group___217 **bus_groups;
	const struct attribute_group___217 **dev_groups;
	const struct attribute_group___217 **drv_groups;
	int (*match)(struct device___207 *, struct device_driver___207 *);
	int (*uevent)(struct device___207 *, struct kobj_uevent_env *);
	int (*probe)(struct device___207 *);
	void (*sync_state)(struct device___207 *);
	void (*remove)(struct device___207 *);
	void (*shutdown)(struct device___207 *);
	int (*online)(struct device___207 *);
	int (*offline)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	int (*num_vf)(struct device___207 *);
	int (*dma_configure)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___207 {
	const char *name;
	struct bus_type___207 *bus;
	struct module___213 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___207 *);
	void (*sync_state)(struct device___207 *);
	int (*remove)(struct device___207 *);
	void (*shutdown)(struct device___207 *);
	int (*suspend)(struct device___207 *, pm_message_t);
	int (*resume)(struct device___207 *);
	const struct attribute_group___217 **groups;
	const struct attribute_group___217 **dev_groups;
	const struct dev_pm_ops___207 *pm;
	void (*coredump)(struct device___207 *);
	struct driver_private *p;
};

struct device_type___207 {
	const char *name;
	const struct attribute_group___217 **groups;
	int (*uevent)(struct device___207 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___207 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___207 *);
	const struct dev_pm_ops___207 *pm;
};

struct class___207 {
	const char *name;
	struct module___213 *owner;
	const struct attribute_group___217 **class_groups;
	const struct attribute_group___217 **dev_groups;
	struct kobject___217 *dev_kobj;
	int (*dev_uevent)(struct device___207 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___207 *, umode_t *);
	void (*class_release)(struct class___207 *);
	void (*dev_release)(struct device___207 *);
	int (*shutdown_pre)(struct device___207 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___207 *);
	void (*get_ownership)(struct device___207 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___207 *pm;
	struct subsys_private *p;
};

struct property___68;

struct device_node___91 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___203 fwnode;
	struct property___68 *properties;
	struct property___68 *deadprops;
	struct device_node___91 *parent;
	struct device_node___91 *child;
	struct device_node___91 *sibling;
	struct kobject___217 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___224 {
	void (*page_free)(struct page___234 *);
	void (*kill)(struct dev_pagemap___224 *);
	void (*cleanup)(struct dev_pagemap___224 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___224 *);
};

struct usb_interface___4 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct device___207 dev;
	struct device___207 *usb_dev;
	struct work_struct reset_ws;
};

struct usb_host_config___4 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___4 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___4;

struct usb_bus___4 {
	struct device___207 *controller;
	struct device___207 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___4 *root_hub;
	struct usb_bus___4 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___4;

struct usb_device___4 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	enum usb_ssp_rate ssp_rate;
	struct usb_tt___4 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___4 *parent;
	struct usb_bus___4 *bus;
	struct usb_host_endpoint ep0;
	struct device___207 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___4 *config;
	struct usb_host_config___4 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	u8 devaddr;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct wusb_dev *wusb_dev;
	int slot_id;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
	unsigned int use_generic_driver: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_tt___4 {
	struct usb_device___4 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usb_otg___3;

struct usb_phy_io_ops___3;

struct usb_phy___3 {
	struct device___207 *dev;
	const char *label;
	unsigned int flags;
	enum usb_phy_type type;
	enum usb_phy_events last_event;
	struct usb_otg___3 *otg;
	struct device___207 *io_dev;
	struct usb_phy_io_ops___3 *io_ops;
	void *io_priv;
	struct extcon_dev *edev;
	struct extcon_dev *id_edev;
	struct notifier_block vbus_nb;
	struct notifier_block id_nb;
	struct notifier_block type_nb;
	enum usb_charger_type chg_type;
	enum usb_charger_state chg_state;
	struct usb_charger_current chg_cur;
	struct work_struct chg_work;
	struct atomic_notifier_head notifier;
	u16 port_status;
	u16 port_change;
	struct list_head head;
	int (*init)(struct usb_phy___3 *);
	void (*shutdown)(struct usb_phy___3 *);
	int (*set_vbus)(struct usb_phy___3 *, int);
	int (*set_power)(struct usb_phy___3 *, unsigned int);
	int (*set_suspend)(struct usb_phy___3 *, int);
	int (*set_wakeup)(struct usb_phy___3 *, bool);
	int (*notify_connect)(struct usb_phy___3 *, enum usb_device_speed);
	int (*notify_disconnect)(struct usb_phy___3 *, enum usb_device_speed);
	enum usb_charger_type (*charger_detect)(struct usb_phy___3 *);
};

struct property___68 {
	char *name;
	int length;
	void *value;
	struct property___68 *next;
	long unsigned int _flags;
	struct bin_attribute___217 attr;
};

struct irq_fwspec___56 {
	struct fwnode_handle___203 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___58 {
	int (*match)(struct irq_domain___58 *, struct device_node___91 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___58 *, struct irq_fwspec___56 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___58 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___58 *, unsigned int);
	int (*xlate)(struct irq_domain___58 *, struct device_node___91 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___58 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___58 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___58 *, struct irq_data___60 *, bool);
	void (*deactivate)(struct irq_domain___58 *, struct irq_data___60 *);
	int (*translate)(struct irq_domain___58 *, struct irq_fwspec___56 *, long unsigned int *, unsigned int *);
};

struct seq_operations___204 {
	void * (*start)(struct seq_file___204 *, loff_t *);
	void (*stop)(struct seq_file___204 *, void *);
	void * (*next)(struct seq_file___204 *, void *, loff_t *);
	int (*show)(struct seq_file___204 *, void *);
};

struct cgroup_namespace___159 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___159 *root_cset;
};

struct cftype___159;

struct cgroup_subsys___159 {
	struct cgroup_subsys_state___159 * (*css_alloc)(struct cgroup_subsys_state___159 *);
	int (*css_online)(struct cgroup_subsys_state___159 *);
	void (*css_offline)(struct cgroup_subsys_state___159 *);
	void (*css_released)(struct cgroup_subsys_state___159 *);
	void (*css_free)(struct cgroup_subsys_state___159 *);
	void (*css_reset)(struct cgroup_subsys_state___159 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___159 *, int);
	int (*css_extra_stat_show)(struct seq_file___204 *, struct cgroup_subsys_state___159 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___236 *, struct css_set___159 *);
	void (*cancel_fork)(struct task_struct___236 *, struct css_set___159 *);
	void (*fork)(struct task_struct___236 *);
	void (*exit)(struct task_struct___236 *);
	void (*release)(struct task_struct___236 *);
	void (*bind)(struct cgroup_subsys_state___159 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___159 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___159 *dfl_cftypes;
	struct cftype___159 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___159 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___159 *updated_children;
	struct cgroup___159 *updated_next;
};

struct cgroup_root___159 {
	struct kernfs_root___217 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___159 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___159 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___159 *ss;
	struct list_head node;
	struct kernfs_ops___217 *kf_ops;
	int (*open)(struct kernfs_open_file___217 *);
	void (*release)(struct kernfs_open_file___217 *);
	u64 (*read_u64)(struct cgroup_subsys_state___159 *, struct cftype___159 *);
	s64 (*read_s64)(struct cgroup_subsys_state___159 *, struct cftype___159 *);
	int (*seq_show)(struct seq_file___204 *, void *);
	void * (*seq_start)(struct seq_file___204 *, loff_t *);
	void * (*seq_next)(struct seq_file___204 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___204 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___159 *, struct cftype___159 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___159 *, struct cftype___159 *, s64);
	ssize_t (*write)(struct kernfs_open_file___217 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___217 *, struct poll_table_struct___154 *);
};

struct block_device_operations___122;

struct gendisk___125 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___125 *part0;
	const struct block_device_operations___122 *fops;
	struct request_queue___122 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___111 *bdi;
	struct kobject___217 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___217 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___122 {
	struct bio___122 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___146 *bip_vec;
	struct bio_vec___146 bip_inline_vecs[0];
};

struct blkcg___113;

struct blkg_policy_data___113;

struct blkcg_gq___113 {
	struct request_queue___122 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___113 *blkcg;
	struct blkcg_gq___113 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___113 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___122 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___122(struct request___122 *);

typedef void integrity_complete_fn___122(struct request___122 *, unsigned int);

struct blk_integrity_profile___122 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___122 *prepare_fn;
	integrity_complete_fn___122 *complete_fn;
	const char *name;
};

struct block_device_operations___122 {
	blk_qc_t (*submit_bio)(struct bio___122 *);
	int (*open)(struct block_device___125 *, fmode_t);
	void (*release)(struct gendisk___125 *, fmode_t);
	int (*rw_page)(struct block_device___125 *, sector_t, struct page___234 *, unsigned int);
	int (*ioctl)(struct block_device___125 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___125 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___125 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___125 *);
	int (*getgeo)(struct block_device___125 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___125 *, bool);
	void (*swap_slot_free_notify)(struct block_device___125 *, long unsigned int);
	int (*report_zones)(struct gendisk___125 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___125 *, umode_t *);
	struct module___213 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___125 *, sector_t *);
};

typedef void rq_end_io_fn___122(struct request___122 *, blk_status_t);

struct request___122 {
	struct request_queue___122 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___119 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___122 *bio;
	struct bio___122 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___146 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___122 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___122 *saved_end_io;
		} flush;
	};
	struct gendisk___125 *rq_disk;
	struct block_device___125 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___122 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___119 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___122 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___217 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___229 *debugfs_dir;
	struct dentry___229 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___122;

struct elevator_mq_ops___122 {
	int (*init_sched)(struct request_queue___122 *, struct elevator_type___122 *);
	void (*exit_sched)(struct elevator_queue___122 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___119 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___119 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___119 *);
	bool (*allow_merge)(struct request_queue___122 *, struct request___122 *, struct bio___122 *);
	bool (*bio_merge)(struct request_queue___122 *, struct bio___122 *, unsigned int);
	int (*request_merge)(struct request_queue___122 *, struct request___122 **, struct bio___122 *);
	void (*request_merged)(struct request_queue___122 *, struct request___122 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___122 *, struct request___122 *, struct request___122 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___122 *);
	void (*finish_request)(struct request___122 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___119 *, struct list_head *, bool);
	struct request___122 * (*dispatch_request)(struct blk_mq_hw_ctx___119 *);
	bool (*has_work)(struct blk_mq_hw_ctx___119 *);
	void (*completed_request)(struct request___122 *, u64);
	void (*requeue_request)(struct request___122 *);
	struct request___122 * (*former_request)(struct request_queue___122 *, struct request___122 *);
	struct request___122 * (*next_request)(struct request_queue___122 *, struct request___122 *);
	void (*init_icq)(struct io_cq___122 *);
	void (*exit_icq)(struct io_cq___122 *);
};

struct elv_fs_entry___122;

struct elevator_type___122 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___122 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___122 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___213 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___122 {
	struct elevator_type___122 *type;
	void *elevator_data;
	struct kobject___217 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___122 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___122 *, char *);
	ssize_t (*store)(struct elevator_queue___122 *, const char *, size_t);
};

struct blk_mq_queue_data___119;

struct blk_mq_ops___119 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___119 *, const struct blk_mq_queue_data___119 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___119 *);
	int (*get_budget)(struct request_queue___122 *);
	void (*put_budget)(struct request_queue___122 *, int);
	void (*set_rq_budget_token)(struct request___122 *, int);
	int (*get_rq_budget_token)(struct request___122 *);
	enum blk_eh_timer_return (*timeout)(struct request___122 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___119 *);
	void (*complete)(struct request___122 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___119 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___119 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___119 *, struct request___122 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___119 *, struct request___122 *, unsigned int);
	void (*initialize_rq_fn)(struct request___122 *);
	void (*cleanup_rq)(struct request___122 *);
	bool (*busy)(struct request_queue___122 *);
	int (*map_queues)(struct blk_mq_tag_set___119 *);
	void (*show_rq)(struct seq_file___204 *, struct request___122 *);
};

struct blk_mq_tag_set___119 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___119 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___119 {
	struct request___122 *rq;
	bool last;
};

struct blkcg_policy_data___113;

struct blkcg___113 {
	struct cgroup_subsys_state___159 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___113 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___113 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___113 {
	struct blkcg___113 *blkcg;
	int plid;
};

struct blkg_policy_data___113 {
	struct blkcg_gq___113 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___102 {
	struct mem_cgroup___102 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___102 {
	struct lruvec___110 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___102 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___102 *memcg;
};

struct obj_cgroup___102 {
	struct percpu_ref refcnt;
	struct mem_cgroup___102 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct phy___12;

struct phy_ops___11 {
	int (*init)(struct phy___12 *);
	int (*exit)(struct phy___12 *);
	int (*power_on)(struct phy___12 *);
	int (*power_off)(struct phy___12 *);
	int (*set_mode)(struct phy___12 *, enum phy_mode, int);
	int (*set_media)(struct phy___12 *, enum phy_media);
	int (*set_speed)(struct phy___12 *, int);
	int (*configure)(struct phy___12 *, union phy_configure_opts *);
	int (*validate)(struct phy___12 *, enum phy_mode, int, union phy_configure_opts *);
	int (*reset)(struct phy___12 *);
	int (*calibrate)(struct phy___12 *);
	void (*release)(struct phy___12 *);
	struct module___213 *owner;
};

struct phy___12 {
	struct device___207 dev;
	int id;
	const struct phy_ops___11 *ops;
	struct mutex mutex;
	int init_count;
	int power_count;
	struct phy_attrs attrs;
	struct regulator *pwr;
};

struct usb_ep;

struct usb_request {
	void *buf;
	unsigned int length;
	dma_addr_t dma;
	struct scatterlist *sg;
	unsigned int num_sgs;
	unsigned int num_mapped_sgs;
	unsigned int stream_id: 16;
	unsigned int is_last: 1;
	unsigned int no_interrupt: 1;
	unsigned int zero: 1;
	unsigned int short_not_ok: 1;
	unsigned int dma_mapped: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void (*complete)(struct usb_ep *, struct usb_request *);
	void *context;
	struct list_head list;
	unsigned int frame_number;
	int status;
	unsigned int actual;
};

struct usb_ep_caps {
	unsigned int type_control: 1;
	unsigned int type_iso: 1;
	unsigned int type_bulk: 1;
	unsigned int type_int: 1;
	unsigned int dir_in: 1;
	unsigned int dir_out: 1;
};

struct usb_ep_ops;

struct usb_ep {
	void *driver_data;
	const char *name;
	const struct usb_ep_ops *ops;
	struct list_head ep_list;
	struct usb_ep_caps caps;
	bool claimed;
	bool enabled;
	unsigned int maxpacket: 16;
	unsigned int maxpacket_limit: 16;
	unsigned int max_streams: 16;
	unsigned int mult: 2;
	unsigned int maxburst: 5;
	long: 35;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 address;
	const struct usb_endpoint_descriptor *desc;
	const struct usb_ss_ep_comp_descriptor *comp_desc;
};

struct usb_ep_ops {
	int (*enable)(struct usb_ep *, const struct usb_endpoint_descriptor *);
	int (*disable)(struct usb_ep *);
	void (*dispose)(struct usb_ep *);
	struct usb_request * (*alloc_request)(struct usb_ep *, gfp_t);
	void (*free_request)(struct usb_ep *, struct usb_request *);
	int (*queue)(struct usb_ep *, struct usb_request *, gfp_t);
	int (*dequeue)(struct usb_ep *, struct usb_request *);
	int (*set_halt)(struct usb_ep *, int);
	int (*set_wedge)(struct usb_ep *);
	int (*fifo_status)(struct usb_ep *);
	void (*fifo_flush)(struct usb_ep *);
};

struct usb_dcd_config_params {
	__u8 bU1devExitLat;
	__le16 bU2DevExitLat;
	__u8 besl_baseline;
	__u8 besl_deep;
};

struct usb_gadget___2;

struct usb_gadget_driver;

struct usb_gadget_ops {
	int (*get_frame)(struct usb_gadget___2 *);
	int (*wakeup)(struct usb_gadget___2 *);
	int (*set_selfpowered)(struct usb_gadget___2 *, int);
	int (*vbus_session)(struct usb_gadget___2 *, int);
	int (*vbus_draw)(struct usb_gadget___2 *, unsigned int);
	int (*pullup)(struct usb_gadget___2 *, int);
	int (*ioctl)(struct usb_gadget___2 *, unsigned int, long unsigned int);
	void (*get_config_params)(struct usb_gadget___2 *, struct usb_dcd_config_params *);
	int (*udc_start)(struct usb_gadget___2 *, struct usb_gadget_driver *);
	int (*udc_stop)(struct usb_gadget___2 *);
	void (*udc_set_speed)(struct usb_gadget___2 *, enum usb_device_speed);
	void (*udc_set_ssp_rate)(struct usb_gadget___2 *, enum usb_ssp_rate);
	void (*udc_async_callbacks)(struct usb_gadget___2 *, bool);
	struct usb_ep * (*match_ep)(struct usb_gadget___2 *, struct usb_endpoint_descriptor *, struct usb_ss_ep_comp_descriptor *);
	int (*check_config)(struct usb_gadget___2 *);
};

struct usb_udc;

struct usb_gadget___2 {
	struct work_struct work;
	struct usb_udc *udc;
	const struct usb_gadget_ops *ops;
	struct usb_ep *ep0;
	struct list_head ep_list;
	enum usb_device_speed speed;
	enum usb_device_speed max_speed;
	enum usb_ssp_rate ssp_rate;
	enum usb_ssp_rate max_ssp_rate;
	enum usb_device_state state;
	const char *name;
	struct device___207 dev;
	unsigned int isoch_delay;
	unsigned int out_epnum;
	unsigned int in_epnum;
	unsigned int mA;
	struct usb_otg_caps *otg_caps;
	unsigned int sg_supported: 1;
	unsigned int is_otg: 1;
	unsigned int is_a_peripheral: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int a_hnp_support: 1;
	unsigned int a_alt_hnp_support: 1;
	unsigned int hnp_polling_support: 1;
	unsigned int host_request_flag: 1;
	unsigned int quirk_ep_out_aligned_size: 1;
	unsigned int quirk_altset_not_supp: 1;
	unsigned int quirk_stall_not_supp: 1;
	unsigned int quirk_zlp_not_supp: 1;
	unsigned int quirk_avoids_skb_reserve: 1;
	unsigned int is_selfpowered: 1;
	unsigned int deactivated: 1;
	unsigned int connected: 1;
	unsigned int lpm_capable: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int irq;
};

struct usb_gadget_driver {
	char *function;
	enum usb_device_speed max_speed;
	int (*bind)(struct usb_gadget___2 *, struct usb_gadget_driver *);
	void (*unbind)(struct usb_gadget___2 *);
	int (*setup)(struct usb_gadget___2 *, const struct usb_ctrlrequest *);
	void (*disconnect)(struct usb_gadget___2 *);
	void (*suspend)(struct usb_gadget___2 *);
	void (*resume)(struct usb_gadget___2 *);
	void (*reset)(struct usb_gadget___2 *);
	struct device_driver___207 driver;
	char *udc_name;
	struct list_head pending;
	unsigned int match_existing_only: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_phy_io_ops___3 {
	int (*read)(struct usb_phy___3 *, u32);
	int (*write)(struct usb_phy___3 *, u32, u32);
};

struct usb_otg___3 {
	u8 default_a;
	struct phy___12 *phy;
	struct usb_phy___3 *usb_phy;
	struct usb_bus___4 *host;
	struct usb_gadget___2 *gadget;
	enum usb_otg_state state;
	int (*set_host)(struct usb_otg___3 *, struct usb_bus___4 *);
	int (*set_peripheral)(struct usb_otg___3 *, struct usb_gadget___2 *);
	int (*set_vbus)(struct usb_otg___3 *, bool);
	int (*start_srp)(struct usb_otg___3 *);
	int (*start_hnp)(struct usb_otg___3 *);
};

struct dwc2_dma_desc {
	u32 status;
	u32 buf;
};

struct dwc2_hw_params {
	unsigned int op_mode: 3;
	unsigned int arch: 2;
	unsigned int dma_desc_enable: 1;
	unsigned int enable_dynamic_fifo: 1;
	unsigned int en_multiple_tx_fifo: 1;
	unsigned int rx_fifo_size: 16;
	unsigned int host_nperio_tx_fifo_size: 16;
	unsigned int dev_nperio_tx_fifo_size: 16;
	unsigned int host_perio_tx_fifo_size: 16;
	unsigned int nperio_tx_q_depth: 3;
	unsigned int host_perio_tx_q_depth: 3;
	unsigned int dev_token_q_depth: 5;
	unsigned int max_transfer_size: 26;
	unsigned int max_packet_count: 11;
	unsigned int host_channels: 5;
	unsigned int hs_phy_type: 2;
	unsigned int fs_phy_type: 2;
	unsigned int i2c_enable: 1;
	unsigned int acg_enable: 1;
	unsigned int num_dev_ep: 4;
	unsigned int num_dev_in_eps: 4;
	unsigned int num_dev_perio_in_ep: 4;
	unsigned int total_fifo_size: 16;
	unsigned int power_optimized: 1;
	unsigned int hibernation: 1;
	unsigned int utmi_phy_data_width: 2;
	unsigned int lpm_mode: 1;
	unsigned int ipg_isoc_en: 1;
	unsigned int service_interval_mode: 1;
	long: 63;
	long: 64;
	long: 64;
	u32 snpsid;
	u32 dev_ep_dirs;
	u32 g_tx_fifo_size[16];
};

struct dwc2_core_params {
	u8 otg_cap;
	u8 phy_type;
	u8 speed;
	u8 phy_utmi_width;
	bool phy_ulpi_ddr;
	bool phy_ulpi_ext_vbus;
	bool enable_dynamic_fifo;
	bool en_multiple_tx_fifo;
	bool i2c_enable;
	bool acg_enable;
	bool ulpi_fs_ls;
	bool ts_dline;
	bool reload_ctl;
	bool uframe_sched;
	bool external_id_pin_ctl;
	int power_down;
	bool no_clock_gating;
	bool lpm;
	bool lpm_clock_gating;
	bool besl;
	bool hird_threshold_en;
	bool service_interval;
	u8 hird_threshold;
	bool activate_stm_fs_transceiver;
	bool activate_stm_id_vb_detection;
	bool ipg_isoc_en;
	u16 max_packet_count;
	u32 max_transfer_size;
	u32 ahbcfg;
	u32 ref_clk_per;
	u16 sof_cnt_wkup_alert;
	bool host_dma;
	bool dma_desc_enable;
	bool dma_desc_fs_enable;
	bool host_support_fs_ls_low_power;
	bool host_ls_low_power_phy_clk;
	bool oc_disable;
	u8 host_channels;
	u16 host_rx_fifo_size;
	u16 host_nperio_tx_fifo_size;
	u16 host_perio_tx_fifo_size;
	bool g_dma;
	bool g_dma_desc;
	u32 g_rx_fifo_size;
	u32 g_np_tx_fifo_size;
	u32 g_tx_fifo_size[16];
	bool change_speed_quirk;
};

struct usb_role_switch;

enum dwc2_lx_state {
	DWC2_L0 = 0,
	DWC2_L1 = 1,
	DWC2_L2 = 2,
	DWC2_L3 = 3,
};

struct dwc2_gregs_backup {
	u32 gotgctl;
	u32 gintmsk;
	u32 gahbcfg;
	u32 gusbcfg;
	u32 grxfsiz;
	u32 gnptxfsiz;
	u32 gi2cctl;
	u32 glpmcfg;
	u32 pcgcctl;
	u32 pcgcctl1;
	u32 gdfifocfg;
	u32 gpwrdn;
	bool valid;
};

struct dwc2_dregs_backup {
	u32 dcfg;
	u32 dctl;
	u32 daintmsk;
	u32 diepmsk;
	u32 doepmsk;
	u32 diepctl[16];
	u32 dieptsiz[16];
	u32 diepdma[16];
	u32 doepctl[16];
	u32 doeptsiz[16];
	u32 doepdma[16];
	u32 dtxfsiz[16];
	bool valid;
};

struct dwc2_hregs_backup {
	u32 hcfg;
	u32 haintmsk;
	u32 hcintmsk[16];
	u32 hprt0;
	u32 hfir;
	u32 hptxfsiz;
	bool valid;
};

union dwc2_hcd_internal_flags {
	u32 d32;
	struct {
		unsigned int port_connect_status_change: 1;
		unsigned int port_connect_status: 1;
		unsigned int port_reset_change: 1;
		unsigned int port_enable_change: 1;
		unsigned int port_suspend_change: 1;
		unsigned int port_over_current_change: 1;
		unsigned int port_l1_change: 1;
		unsigned int reserved: 25;
	} b;
};

struct dwc2_hsotg_plat;

struct debugfs_regset32___2;

struct dwc2_host_chan;

struct dwc2_hsotg {
	struct device___207 *dev;
	void *regs;
	struct dwc2_hw_params hw_params;
	struct dwc2_core_params params;
	enum usb_otg_state op_state;
	enum usb_dr_mode dr_mode;
	struct usb_role_switch *role_sw;
	unsigned int hcd_enabled: 1;
	unsigned int gadget_enabled: 1;
	unsigned int ll_hw_enabled: 1;
	unsigned int hibernated: 1;
	unsigned int in_ppd: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool bus_suspended;
	unsigned int reset_phy_on_wake: 1;
	unsigned int need_phy_for_wake: 1;
	unsigned int phy_off_for_suspend: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 frame_number;
	struct phy___12 *phy;
	struct usb_phy___3 *uphy;
	struct dwc2_hsotg_plat *plat;
	struct regulator_bulk_data supplies[2];
	struct regulator *vbus_supply;
	struct regulator *usb33d;
	spinlock_t lock;
	void *priv;
	int irq;
	struct clk *clk;
	struct reset_control *reset;
	struct reset_control *reset_ecc;
	unsigned int queuing_high_bandwidth: 1;
	unsigned int srp_success: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct workqueue_struct *wq_otg;
	struct work_struct wf_otg;
	struct timer_list wkp_timer;
	enum dwc2_lx_state lx_state;
	struct dwc2_gregs_backup gr_backup;
	struct dwc2_dregs_backup dr_backup;
	struct dwc2_hregs_backup hr_backup;
	struct dentry___229 *debug_root;
	struct debugfs_regset32___2 *regset;
	bool needs_byte_swap;
	union dwc2_hcd_internal_flags flags;
	struct list_head non_periodic_sched_inactive;
	struct list_head non_periodic_sched_waiting;
	struct list_head non_periodic_sched_active;
	struct list_head *non_periodic_qh_ptr;
	struct list_head periodic_sched_inactive;
	struct list_head periodic_sched_ready;
	struct list_head periodic_sched_assigned;
	struct list_head periodic_sched_queued;
	struct list_head split_order;
	u16 periodic_usecs;
	long unsigned int hs_periodic_bitmap[13];
	u16 periodic_qh_count;
	bool new_connection;
	u16 last_frame_num;
	struct list_head free_hc_list;
	int periodic_channels;
	int non_periodic_channels;
	int available_host_channels;
	struct dwc2_host_chan *hc_ptr_array[16];
	u8 *status_buf;
	dma_addr_t status_buf_dma;
	struct delayed_work start_work;
	struct delayed_work reset_work;
	struct work_struct phy_reset_work;
	u8 otg_port;
	u32 *frame_list;
	dma_addr_t frame_list_dma;
	u32 frame_list_sz;
	struct kmem_cache *desc_gen_cache;
	struct kmem_cache *desc_hsisoc_cache;
	struct kmem_cache *unaligned_cache;
};

enum dwc2_halt_status {
	DWC2_HC_XFER_NO_HALT_STATUS = 0,
	DWC2_HC_XFER_COMPLETE = 1,
	DWC2_HC_XFER_URB_COMPLETE = 2,
	DWC2_HC_XFER_ACK = 3,
	DWC2_HC_XFER_NAK = 4,
	DWC2_HC_XFER_NYET = 5,
	DWC2_HC_XFER_STALL = 6,
	DWC2_HC_XFER_XACT_ERR = 7,
	DWC2_HC_XFER_FRAME_OVERRUN = 8,
	DWC2_HC_XFER_BABBLE_ERR = 9,
	DWC2_HC_XFER_DATA_TOGGLE_ERR = 10,
	DWC2_HC_XFER_AHB_ERR = 11,
	DWC2_HC_XFER_PERIODIC_INCOMPLETE = 12,
	DWC2_HC_XFER_URB_DEQUEUE = 13,
};

struct dwc2_qh;

struct dwc2_host_chan {
	u8 hc_num;
	unsigned int dev_addr: 7;
	unsigned int ep_num: 4;
	unsigned int ep_is_in: 1;
	unsigned int speed: 4;
	unsigned int ep_type: 2;
	unsigned int max_packet: 11;
	unsigned int data_pid_start: 2;
	unsigned int multi_count: 2;
	u8 *xfer_buf;
	dma_addr_t xfer_dma;
	dma_addr_t align_buf;
	u32 xfer_len;
	u32 xfer_count;
	u16 start_pkt_count;
	u8 xfer_started;
	u8 do_ping;
	u8 error_state;
	u8 halt_on_queue;
	u8 halt_pending;
	u8 do_split;
	u8 complete_split;
	u8 hub_addr;
	u8 hub_port;
	u8 xact_pos;
	u8 requests;
	u8 schinfo;
	u16 ntd;
	enum dwc2_halt_status halt_status;
	u32 hcint;
	struct dwc2_qh *qh;
	struct list_head hc_list_entry;
	dma_addr_t desc_list_addr;
	u32 desc_list_sz;
	struct list_head split_order_list_entry;
};

struct dwc2_hs_transfer_time {
	u32 start_schedule_us;
	u16 duration_us;
};

struct dwc2_tt;

struct dwc2_qh {
	struct dwc2_hsotg *hsotg;
	u8 ep_type;
	u8 ep_is_in;
	u16 maxp;
	u16 maxp_mult;
	u8 dev_speed;
	u8 data_toggle;
	u8 ping_state;
	u8 do_split;
	u8 td_first;
	u8 td_last;
	u16 host_us;
	u16 device_us;
	u16 host_interval;
	u16 device_interval;
	u16 next_active_frame;
	u16 start_active_frame;
	s16 num_hs_transfers;
	struct dwc2_hs_transfer_time hs_transfers[8];
	u32 ls_start_schedule_slice;
	u16 ntd;
	u8 *dw_align_buf;
	dma_addr_t dw_align_buf_dma;
	struct list_head qtd_list;
	struct dwc2_host_chan *channel;
	struct list_head qh_list_entry;
	struct dwc2_dma_desc *desc_list;
	dma_addr_t desc_list_dma;
	u32 desc_list_sz;
	u32 *n_bytes;
	struct timer_list unreserve_timer;
	struct hrtimer wait_timer;
	struct dwc2_tt *dwc_tt;
	int ttport;
	unsigned int tt_buffer_dirty: 1;
	unsigned int unreserve_pending: 1;
	unsigned int schedule_low_speed: 1;
	unsigned int want_wait: 1;
	unsigned int wait_timer_cancel: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dwc2_tt {
	int refcount;
	struct usb_tt___4 *usb_tt;
	long unsigned int periodic_bitmaps[0];
};

struct platform_device___41 {
	const char *name;
	int id;
	bool id_auto;
	struct device___207 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___35 {
	int (*probe)(struct platform_device___41 *);
	int (*remove)(struct platform_device___41 *);
	void (*shutdown)(struct platform_device___41 *);
	int (*suspend)(struct platform_device___41 *, pm_message_t);
	int (*resume)(struct platform_device___41 *);
	struct device_driver___207 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum dwc2_hsotg_dmamode {
	S3C_HSOTG_DMA_NONE = 0,
	S3C_HSOTG_DMA_ONLY = 1,
	S3C_HSOTG_DMA_DRV = 2,
};

struct dwc2_hsotg_plat {
	enum dwc2_hsotg_dmamode dma;
	unsigned int is_osc: 1;
	long: 63;
	int phy_type;
	int (*phy_init)(struct platform_device___41 *, int);
	int (*phy_exit)(struct platform_device___41 *, int);
};

enum usb_role {
	USB_ROLE_NONE = 0,
	USB_ROLE_HOST = 1,
	USB_ROLE_DEVICE = 2,
};

typedef int (*usb_role_switch_set_t)(struct usb_role_switch *, enum usb_role);

typedef enum usb_role (*usb_role_switch_get_t)(struct usb_role_switch *);

struct usb_role_switch_desc {
	struct fwnode_handle___203 *fwnode;
	struct device___207 *usb2_port;
	struct device___207 *usb3_port;
	struct device___207 *udc;
	usb_role_switch_set_t set;
	usb_role_switch_get_t get;
	bool allow_userspace_control;
	void *driver_data;
	const char *name;
};

typedef void (*set_params_cb)(struct dwc2_hsotg *);

struct urb___4;

typedef void (*usb_complete_t___4)(struct urb___4 *);

struct urb___4 {
	struct kref kref;
	int unlinked;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___4 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___4 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___4;

struct usb_hcd___4 {
	struct usb_bus___4 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___4 *status_urb;
	struct work_struct wakeup_work;
	struct work_struct died_work;
	const struct hc_driver___4 *driver;
	struct usb_phy___3 *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	enum usb_dev_authorize_policy dev_policy;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___4 *shared_hcd;
	struct usb_hcd___4 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	struct gen_pool *localmem_pool;
	long unsigned int hcd_priv[0];
};

struct hc_driver___4 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___4 *);
	int flags;
	int (*reset)(struct usb_hcd___4 *);
	int (*start)(struct usb_hcd___4 *);
	int (*pci_suspend)(struct usb_hcd___4 *, bool);
	int (*pci_resume)(struct usb_hcd___4 *, bool);
	void (*stop)(struct usb_hcd___4 *);
	void (*shutdown)(struct usb_hcd___4 *);
	int (*get_frame_number)(struct usb_hcd___4 *);
	int (*urb_enqueue)(struct usb_hcd___4 *, struct urb___4 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___4 *, struct urb___4 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___4 *, struct urb___4 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___4 *, struct urb___4 *);
	void (*endpoint_disable)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___4 *, char *);
	int (*hub_control)(struct usb_hcd___4 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___4 *);
	int (*bus_resume)(struct usb_hcd___4 *);
	int (*start_port_reset)(struct usb_hcd___4 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___4 *);
	void (*relinquish_port)(struct usb_hcd___4 *, int);
	int (*port_handed_over)(struct usb_hcd___4 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___4 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___4 *, struct usb_device___4 *);
	void (*free_dev)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*alloc_streams)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___4 *, struct usb_device___4 *);
	void (*reset_bandwidth)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*address_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*enable_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*update_hub_device)(struct usb_hcd___4 *, struct usb_device___4 *, struct usb_tt___4 *, gfp_t);
	int (*reset_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*update_device)(struct usb_hcd___4 *, struct usb_device___4 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___4 *, struct usb_device___4 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___4 *, struct usb_device___4 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___4 *, struct usb_device___4 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___4 *, int);
	int (*port_power)(struct usb_hcd___4 *, int, bool);
	int (*submit_single_step_set_feature)(struct usb_hcd___4 *, struct urb___4 *, int);
};

struct dwc2_hcd_pipe_info {
	u8 dev_addr;
	u8 ep_num;
	u8 pipe_type;
	u8 pipe_dir;
	u16 maxp;
	u16 maxp_mult;
};

struct dwc2_hcd_iso_packet_desc {
	u32 offset;
	u32 length;
	u32 actual_length;
	u32 status;
};

struct dwc2_qtd;

struct dwc2_hcd_urb {
	void *priv;
	struct dwc2_qtd *qtd;
	void *buf;
	dma_addr_t dma;
	void *setup_packet;
	dma_addr_t setup_dma;
	u32 length;
	u32 actual_length;
	u32 status;
	u32 error_count;
	u32 packet_count;
	u32 flags;
	u16 interval;
	struct dwc2_hcd_pipe_info pipe_info;
	struct dwc2_hcd_iso_packet_desc iso_descs[0];
};

enum dwc2_control_phase {
	DWC2_CONTROL_SETUP = 0,
	DWC2_CONTROL_DATA = 1,
	DWC2_CONTROL_STATUS = 2,
};

struct dwc2_qtd {
	enum dwc2_control_phase control_phase;
	u8 in_process;
	u8 data_toggle;
	u8 complete_split;
	u8 isoc_split_pos;
	u16 isoc_frame_index;
	u16 isoc_split_offset;
	u16 isoc_td_last;
	u16 isoc_td_first;
	u32 ssplit_out_xfer_count;
	u8 error_count;
	u8 n_desc;
	u16 isoc_frame_index_last;
	u16 num_naks;
	struct dwc2_hcd_urb *urb;
	struct dwc2_qh *qh;
	struct list_head qtd_list_entry;
};

enum dwc2_transaction_type {
	DWC2_TRANSACTION_NONE = 0,
	DWC2_TRANSACTION_PERIODIC = 1,
	DWC2_TRANSACTION_NON_PERIODIC = 2,
	DWC2_TRANSACTION_ALL = 3,
};

struct wrapper_priv_data {
	struct dwc2_hsotg *hsotg;
};

struct debugfs_regset32___2 {
	const struct debugfs_reg32 *regs;
	int nregs;
	void *base;
	struct device___207 *dev;
};

enum amd_chipset_gen {
	NOT_AMD_CHIPSET = 0,
	AMD_CHIPSET_SB600 = 1,
	AMD_CHIPSET_SB700 = 2,
	AMD_CHIPSET_SB800 = 3,
	AMD_CHIPSET_HUDSON2 = 4,
	AMD_CHIPSET_BOLTON = 5,
	AMD_CHIPSET_YANGTZE = 6,
	AMD_CHIPSET_TAISHAN = 7,
	AMD_CHIPSET_UNKNOWN = 8,
};

struct amd_chipset_type {
	enum amd_chipset_gen gen;
	u8 rev;
};

struct amd_chipset_info {
	struct pci_dev___18 *nb_dev;
	struct pci_dev___18 *smbus_dev;
	int nb_type;
	struct amd_chipset_type sb_type;
	int isoc_reqs;
	int probe_count;
	bool need_pll_quirk;
};

struct ehci_stats {
	long unsigned int normal;
	long unsigned int error;
	long unsigned int iaa;
	long unsigned int lost_iaa;
	long unsigned int complete;
	long unsigned int unlink;
};

struct ehci_per_sched {
	struct usb_device___3 *udev;
	struct usb_host_endpoint *ep;
	struct list_head ps_list;
	u16 tt_usecs;
	u16 cs_mask;
	u16 period;
	u16 phase;
	u8 bw_phase;
	u8 phase_uf;
	u8 usecs;
	u8 c_usecs;
	u8 bw_uperiod;
	u8 bw_period;
};

enum ehci_rh_state {
	EHCI_RH_HALTED = 0,
	EHCI_RH_SUSPENDED = 1,
	EHCI_RH_RUNNING = 2,
	EHCI_RH_STOPPING = 3,
};

enum ehci_hrtimer_event {
	EHCI_HRTIMER_POLL_ASS = 0,
	EHCI_HRTIMER_POLL_PSS = 1,
	EHCI_HRTIMER_POLL_DEAD = 2,
	EHCI_HRTIMER_UNLINK_INTR = 3,
	EHCI_HRTIMER_FREE_ITDS = 4,
	EHCI_HRTIMER_ACTIVE_UNLINK = 5,
	EHCI_HRTIMER_START_UNLINK_INTR = 6,
	EHCI_HRTIMER_ASYNC_UNLINKS = 7,
	EHCI_HRTIMER_IAA_WATCHDOG = 8,
	EHCI_HRTIMER_DISABLE_PERIODIC = 9,
	EHCI_HRTIMER_DISABLE_ASYNC = 10,
	EHCI_HRTIMER_IO_WATCHDOG = 11,
	EHCI_HRTIMER_NUM_EVENTS = 12,
};

struct ehci_caps;

struct ehci_regs;

struct ehci_dbg_port;

struct ehci_qh;

union ehci_shadow;

struct ehci_itd;

struct ehci_sitd;

struct ehci_hcd {
	enum ehci_hrtimer_event next_hrtimer_event;
	unsigned int enabled_hrtimer_events;
	ktime_t hr_timeouts[12];
	struct hrtimer hrtimer;
	int PSS_poll_count;
	int ASS_poll_count;
	int died_poll_count;
	struct ehci_caps *caps;
	struct ehci_regs *regs;
	struct ehci_dbg_port *debug;
	__u32 hcs_params;
	spinlock_t lock;
	enum ehci_rh_state rh_state;
	bool scanning: 1;
	bool need_rescan: 1;
	bool intr_unlinking: 1;
	bool iaa_in_progress: 1;
	bool async_unlinking: 1;
	bool shutdown: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ehci_qh *qh_scan_next;
	struct ehci_qh *async;
	struct ehci_qh *dummy;
	struct list_head async_unlink;
	struct list_head async_idle;
	unsigned int async_unlink_cycle;
	unsigned int async_count;
	__le32 old_current;
	__le32 old_token;
	unsigned int periodic_size;
	__le32 *periodic;
	dma_addr_t periodic_dma;
	struct list_head intr_qh_list;
	unsigned int i_thresh;
	union ehci_shadow *pshadow;
	struct list_head intr_unlink_wait;
	struct list_head intr_unlink;
	unsigned int intr_unlink_wait_cycle;
	unsigned int intr_unlink_cycle;
	unsigned int now_frame;
	unsigned int last_iso_frame;
	unsigned int intr_count;
	unsigned int isoc_count;
	unsigned int periodic_count;
	unsigned int uframe_periodic_max;
	struct list_head cached_itd_list;
	struct ehci_itd *last_itd_to_free;
	struct list_head cached_sitd_list;
	struct ehci_sitd *last_sitd_to_free;
	long unsigned int reset_done[15];
	long unsigned int bus_suspended;
	long unsigned int companion_ports;
	long unsigned int owned_ports;
	long unsigned int port_c_suspend;
	long unsigned int suspended_ports;
	long unsigned int resuming_ports;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *qtd_pool;
	struct dma_pool___2 *itd_pool;
	struct dma_pool___2 *sitd_pool;
	unsigned int random_frame;
	long unsigned int next_statechange;
	ktime_t last_periodic_enable;
	u32 command;
	unsigned int no_selective_suspend: 1;
	unsigned int has_fsl_port_bug: 1;
	unsigned int has_fsl_hs_errata: 1;
	unsigned int has_fsl_susp_errata: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	unsigned int big_endian_capbase: 1;
	unsigned int has_amcc_usb23: 1;
	unsigned int need_io_watchdog: 1;
	unsigned int amd_pll_fix: 1;
	unsigned int use_dummy_qh: 1;
	unsigned int has_synopsys_hc_bug: 1;
	unsigned int frame_index_bug: 1;
	unsigned int need_oc_pp_cycle: 1;
	unsigned int imx28_write_fix: 1;
	unsigned int spurious_oc: 1;
	unsigned int is_aspeed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__le32 *ohci_hcctrl_reg;
	unsigned int has_hostpc: 1;
	unsigned int has_tdi_phy_lpm: 1;
	unsigned int has_ppcd: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sbrn;
	struct ehci_stats stats;
	struct dentry___218 *debug_dir;
	u8 bandwidth[64];
	u8 tt_budget[64];
	struct list_head tt_list;
	long unsigned int priv[0];
};

struct ehci_caps {
	u32 hc_capbase;
	u32 hcs_params;
	u32 hcc_params;
	u8 portroute[8];
};

struct ehci_regs {
	u32 command;
	u32 status;
	u32 intr_enable;
	u32 frame_index;
	u32 segment;
	u32 frame_list;
	u32 async_next;
	u32 reserved1[2];
	u32 txfill_tuning;
	u32 reserved2[6];
	u32 configured_flag;
	union {
		u32 port_status[15];
		struct {
			u32 reserved3[9];
			u32 usbmode;
		};
	};
	union {
		struct {
			u32 reserved4;
			u32 hostpc[15];
		};
		u32 brcm_insnreg[4];
	};
	u32 reserved5[2];
	u32 usbmode_ex;
};

struct ehci_dbg_port {
	u32 control;
	u32 pids;
	u32 data03;
	u32 data47;
	u32 address;
};

struct ehci_fstn;

union ehci_shadow {
	struct ehci_qh *qh;
	struct ehci_itd *itd;
	struct ehci_sitd *sitd;
	struct ehci_fstn *fstn;
	__le32 *hw_next;
	void *ptr;
};

struct ehci_qh_hw;

struct ehci_qtd;

struct ehci_qh {
	struct ehci_qh_hw *hw;
	dma_addr_t qh_dma;
	union ehci_shadow qh_next;
	struct list_head qtd_list;
	struct list_head intr_node;
	struct ehci_qtd *dummy;
	struct list_head unlink_node;
	struct ehci_per_sched ps;
	unsigned int unlink_cycle;
	u8 qh_state;
	u8 xacterrs;
	u8 unlink_reason;
	u8 gap_uf;
	unsigned int is_out: 1;
	unsigned int clearing_tt: 1;
	unsigned int dequeue_during_giveback: 1;
	unsigned int should_be_inactive: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ehci_iso_stream;

struct ehci_itd {
	__le32 hw_next;
	__le32 hw_transaction[8];
	__le32 hw_bufp[7];
	__le32 hw_bufp_hi[7];
	dma_addr_t itd_dma;
	union ehci_shadow itd_next;
	struct urb___3 *urb;
	struct ehci_iso_stream *stream;
	struct list_head itd_list;
	unsigned int frame;
	unsigned int pg;
	unsigned int index[8];
	long: 64;
};

struct ehci_sitd {
	__le32 hw_next;
	__le32 hw_fullspeed_ep;
	__le32 hw_uframe;
	__le32 hw_results;
	__le32 hw_buf[2];
	__le32 hw_backpointer;
	__le32 hw_buf_hi[2];
	dma_addr_t sitd_dma;
	union ehci_shadow sitd_next;
	struct urb___3 *urb;
	struct ehci_iso_stream *stream;
	struct list_head sitd_list;
	unsigned int frame;
	unsigned int index;
};

struct ehci_qtd {
	__le32 hw_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	dma_addr_t qtd_dma;
	struct list_head qtd_list;
	struct urb___3 *urb;
	size_t length;
};

struct ehci_fstn {
	__le32 hw_next;
	__le32 hw_prev;
	dma_addr_t fstn_dma;
	union ehci_shadow fstn_next;
	long: 64;
};

struct ehci_qh_hw {
	__le32 hw_next;
	__le32 hw_info1;
	__le32 hw_info2;
	__le32 hw_current;
	__le32 hw_qtd_next;
	__le32 hw_alt_next;
	__le32 hw_token;
	__le32 hw_buf[5];
	__le32 hw_buf_hi[5];
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct ehci_iso_packet {
	u64 bufp;
	__le32 transaction;
	u8 cross;
	u32 buf1;
};

struct ehci_iso_sched {
	struct list_head td_list;
	unsigned int span;
	unsigned int first_packet;
	struct ehci_iso_packet packet[0];
};

struct ehci_iso_stream {
	struct ehci_qh_hw *hw;
	u8 bEndpointAddress;
	u8 highspeed;
	struct list_head td_list;
	struct list_head free_list;
	struct ehci_per_sched ps;
	unsigned int next_uframe;
	__le32 splits;
	u16 uperiod;
	u16 maxp;
	unsigned int bandwidth;
	__le32 buf0;
	__le32 buf1;
	__le32 buf2;
	__le32 address;
};

struct ehci_tt {
	u16 bandwidth[8];
	struct list_head tt_list;
	struct list_head ps_list;
	struct usb_tt___3 *usb_tt;
	int tt_port;
};

struct ehci_driver_overrides {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___3 *);
	int (*port_power)(struct usb_hcd___3 *, int, bool);
};

struct debug_buffer {
	ssize_t (*fill_func)(struct debug_buffer *);
	struct usb_bus___3 *bus;
	struct mutex mutex;
	size_t count;
	char *output_buf;
	size_t alloc_size;
};

enum orion_ehci_phy_ver {
	EHCI_PHY_ORION = 0,
	EHCI_PHY_DD = 1,
	EHCI_PHY_KW = 2,
	EHCI_PHY_NA = 3,
};

struct orion_ehci_data {
	enum orion_ehci_phy_ver phy_version;
};

struct orion_ehci_hcd {
	struct clk *clk;
	struct phy___11 *phy;
};

typedef __u32 __hc32;

typedef __u16 __hc16;

struct td;

struct ed {
	__hc32 hwINFO;
	__hc32 hwTailP;
	__hc32 hwHeadP;
	__hc32 hwNextED;
	dma_addr_t dma;
	struct td *dummy;
	struct ed *ed_next;
	struct ed *ed_prev;
	struct list_head td_list;
	struct list_head in_use_list;
	u8 state;
	u8 type;
	u8 branch;
	u16 interval;
	u16 load;
	u16 last_iso;
	u16 tick;
	unsigned int takeback_wdh_cnt;
	struct td *pending_td;
	long: 64;
};

struct td {
	__hc32 hwINFO;
	__hc32 hwCBP;
	__hc32 hwNextTD;
	__hc32 hwBE;
	__hc16 hwPSW[2];
	__u8 index;
	struct ed *ed;
	struct td *td_hash;
	struct td *next_dl_td;
	struct urb___3 *urb;
	dma_addr_t td_dma;
	dma_addr_t data_dma;
	struct list_head td_list;
	long: 64;
};

struct ohci_hcca {
	__hc32 int_table[32];
	__hc32 frame_no;
	__hc32 done_head;
	u8 reserved_for_hc[116];
	u8 what[4];
};

struct ohci_roothub_regs {
	__hc32 a;
	__hc32 b;
	__hc32 status;
	__hc32 portstatus[15];
};

struct ohci_regs {
	__hc32 revision;
	__hc32 control;
	__hc32 cmdstatus;
	__hc32 intrstatus;
	__hc32 intrenable;
	__hc32 intrdisable;
	__hc32 hcca;
	__hc32 ed_periodcurrent;
	__hc32 ed_controlhead;
	__hc32 ed_controlcurrent;
	__hc32 ed_bulkhead;
	__hc32 ed_bulkcurrent;
	__hc32 donehead;
	__hc32 fminterval;
	__hc32 fmremaining;
	__hc32 fmnumber;
	__hc32 periodicstart;
	__hc32 lsthresh;
	struct ohci_roothub_regs roothub;
	long: 64;
	long: 64;
};

struct urb_priv {
	struct ed *ed;
	u16 length;
	u16 td_cnt;
	struct list_head pending;
	struct td *td[0];
};

typedef struct urb_priv urb_priv_t;

enum ohci_rh_state {
	OHCI_RH_HALTED = 0,
	OHCI_RH_SUSPENDED = 1,
	OHCI_RH_RUNNING = 2,
};

struct ohci_hcd {
	spinlock_t lock;
	struct ohci_regs *regs;
	struct ohci_hcca *hcca;
	dma_addr_t hcca_dma;
	struct ed *ed_rm_list;
	struct ed *ed_bulktail;
	struct ed *ed_controltail;
	struct ed *periodic[32];
	void (*start_hnp)(struct ohci_hcd *);
	struct dma_pool___2 *td_cache;
	struct dma_pool___2 *ed_cache;
	struct td *td_hash[64];
	struct td *dl_start;
	struct td *dl_end;
	struct list_head pending;
	struct list_head eds_in_use;
	enum ohci_rh_state rh_state;
	int num_ports;
	int load[32];
	u32 hc_control;
	long unsigned int next_statechange;
	u32 fminterval;
	unsigned int autostop: 1;
	unsigned int working: 1;
	unsigned int restart_work: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int flags;
	unsigned int prev_frame_no;
	unsigned int wdh_cnt;
	unsigned int prev_wdh_cnt;
	u32 prev_donehead;
	struct timer_list io_watchdog;
	struct work_struct nec_work;
	struct dentry___218 *debug_dir;
	long unsigned int priv[0];
};

struct ohci_driver_overrides {
	const char *product_desc;
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___3 *);
};

struct debug_buffer___2 {
	ssize_t (*fill_func)(struct debug_buffer___2 *);
	struct ohci_hcd *ohci;
	struct mutex mutex;
	size_t count;
	char *page;
};

struct uhci_td;

struct uhci_qh {
	__le32 link;
	__le32 element;
	dma_addr_t dma_handle;
	struct list_head node;
	struct usb_host_endpoint *hep;
	struct usb_device___3 *udev;
	struct list_head queue;
	struct uhci_td *dummy_td;
	struct uhci_td *post_td;
	struct usb_iso_packet_descriptor *iso_packet_desc;
	long unsigned int advance_jiffies;
	unsigned int unlink_frame;
	unsigned int period;
	short int phase;
	short int load;
	unsigned int iso_frame;
	int state;
	int type;
	int skel;
	unsigned int initial_toggle: 1;
	unsigned int needs_fixup: 1;
	unsigned int is_stopped: 1;
	unsigned int wait_expired: 1;
	unsigned int bandwidth_reserved: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uhci_td {
	__le32 link;
	__le32 status;
	__le32 token;
	__le32 buffer;
	dma_addr_t dma_handle;
	struct list_head list;
	int frame;
	struct list_head fl_list;
};

enum uhci_rh_state {
	UHCI_RH_RESET = 0,
	UHCI_RH_SUSPENDED = 1,
	UHCI_RH_AUTO_STOPPED = 2,
	UHCI_RH_RESUMING = 3,
	UHCI_RH_SUSPENDING = 4,
	UHCI_RH_RUNNING = 5,
	UHCI_RH_RUNNING_NODEVS = 6,
};

struct uhci_hcd {
	long unsigned int io_addr;
	void *regs;
	struct dma_pool___2 *qh_pool;
	struct dma_pool___2 *td_pool;
	struct uhci_td *term_td;
	struct uhci_qh *skelqh[11];
	struct uhci_qh *next_qh;
	spinlock_t lock;
	dma_addr_t frame_dma_handle;
	__le32 *frame;
	void **frame_cpu;
	enum uhci_rh_state rh_state;
	long unsigned int auto_stop_time;
	unsigned int frame_number;
	unsigned int is_stopped;
	unsigned int last_iso_frame;
	unsigned int cur_iso_frame;
	unsigned int scan_in_progress: 1;
	unsigned int need_rescan: 1;
	unsigned int dead: 1;
	unsigned int RD_enable: 1;
	unsigned int is_initialized: 1;
	unsigned int fsbr_is_on: 1;
	unsigned int fsbr_is_wanted: 1;
	unsigned int fsbr_expiring: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct timer_list fsbr_timer;
	unsigned int oc_low: 1;
	unsigned int wait_for_hp: 1;
	unsigned int big_endian_mmio: 1;
	unsigned int big_endian_desc: 1;
	unsigned int is_aspeed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int port_c_suspend;
	long unsigned int resuming_ports;
	long unsigned int ports_timeout;
	struct list_head idle_qh_list;
	int rh_numports;
	wait_queue_head_t waitqh;
	int num_waiting;
	int total_load;
	short int load[32];
	struct clk *clk;
	void (*reset_hc)(struct uhci_hcd *);
	int (*check_and_reset_hc)(struct uhci_hcd *);
	void (*configure_hc)(struct uhci_hcd *);
	int (*resume_detect_interrupts_are_broken)(struct uhci_hcd *);
	int (*global_suspend_mode_is_broken)(struct uhci_hcd *);
};

struct urb_priv___2 {
	struct list_head node;
	struct urb___3 *urb;
	struct uhci_qh *qh;
	struct list_head td_list;
	unsigned int fsbr: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct uhci_debug {
	int size;
	char *data;
};

struct usb_interface___5 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created: 1;
	unsigned int ep_devs_created: 1;
	unsigned int unregistering: 1;
	unsigned int needs_remote_wakeup: 1;
	unsigned int needs_altsetting0: 1;
	unsigned int needs_binding: 1;
	unsigned int resetting_device: 1;
	unsigned int authorized: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct device___37 dev;
	struct device___37 *usb_dev;
	struct work_struct reset_ws;
};

struct usb_host_config___5 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___5 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___5;

struct usb_bus___5 {
	struct device___37 *controller;
	struct device___37 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___5 *root_hub;
	struct usb_bus___5 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___5;

struct usb_device___5 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	enum usb_ssp_rate ssp_rate;
	struct usb_tt___5 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___5 *parent;
	struct usb_bus___5 *bus;
	struct usb_host_endpoint ep0;
	struct device___37 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___5 *config;
	struct usb_host_config___5 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	u8 devaddr;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct wusb_dev *wusb_dev;
	int slot_id;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
	unsigned int use_generic_driver: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_tt___5 {
	struct usb_device___5 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct usbdrv_wrap___3 {
	struct device_driver___37 driver;
	int for_devices;
};

struct usb_driver___3 {
	const char *name;
	int (*probe)(struct usb_interface___5 *, const struct usb_device_id *);
	void (*disconnect)(struct usb_interface___5 *);
	int (*unlocked_ioctl)(struct usb_interface___5 *, unsigned int, void *);
	int (*suspend)(struct usb_interface___5 *, pm_message_t);
	int (*resume)(struct usb_interface___5 *);
	int (*reset_resume)(struct usb_interface___5 *);
	int (*pre_reset)(struct usb_interface___5 *);
	int (*post_reset)(struct usb_interface___5 *);
	const struct usb_device_id *id_table;
	const struct attribute_group___40 **dev_groups;
	struct usb_dynids dynids;
	struct usbdrv_wrap___3 drvwrap;
	unsigned int no_dynamic_id: 1;
	unsigned int supports_autosuspend: 1;
	unsigned int disable_hub_initiated_lpm: 1;
	unsigned int soft_unbind: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct urb___5;

typedef void (*usb_complete_t___5)(struct urb___5 *);

struct urb___5 {
	struct kref kref;
	int unlinked;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___5 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___5 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___5;

struct usb_hcd___5 {
	struct usb_bus___5 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___5 *status_urb;
	struct work_struct wakeup_work;
	struct work_struct died_work;
	const struct hc_driver___5 *driver;
	struct usb_phy *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	enum usb_dev_authorize_policy dev_policy;
	unsigned int rh_registered: 1;
	unsigned int rh_pollable: 1;
	unsigned int msix_enabled: 1;
	unsigned int msi_enabled: 1;
	unsigned int skip_phy_initialization: 1;
	unsigned int uses_new_polling: 1;
	unsigned int wireless: 1;
	unsigned int has_tt: 1;
	unsigned int amd_resume_bug: 1;
	unsigned int can_do_streams: 1;
	unsigned int tpl_support: 1;
	unsigned int cant_recv_wakeups: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___5 *shared_hcd;
	struct usb_hcd___5 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	struct gen_pool *localmem_pool;
	long unsigned int hcd_priv[0];
};

struct hc_driver___5 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___5 *);
	int flags;
	int (*reset)(struct usb_hcd___5 *);
	int (*start)(struct usb_hcd___5 *);
	int (*pci_suspend)(struct usb_hcd___5 *, bool);
	int (*pci_resume)(struct usb_hcd___5 *, bool);
	void (*stop)(struct usb_hcd___5 *);
	void (*shutdown)(struct usb_hcd___5 *);
	int (*get_frame_number)(struct usb_hcd___5 *);
	int (*urb_enqueue)(struct usb_hcd___5 *, struct urb___5 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___5 *, struct urb___5 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___5 *, struct urb___5 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___5 *, struct urb___5 *);
	void (*endpoint_disable)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___5 *, char *);
	int (*hub_control)(struct usb_hcd___5 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___5 *);
	int (*bus_resume)(struct usb_hcd___5 *);
	int (*start_port_reset)(struct usb_hcd___5 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___5 *);
	void (*relinquish_port)(struct usb_hcd___5 *, int);
	int (*port_handed_over)(struct usb_hcd___5 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___5 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*free_dev)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*alloc_streams)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*reset_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*address_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*enable_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*update_hub_device)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_tt___5 *, gfp_t);
	int (*reset_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*update_device)(struct usb_hcd___5 *, struct usb_device___5 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___5 *, struct usb_device___5 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___5 *, struct usb_device___5 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___5 *, struct usb_device___5 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___5 *, int);
	int (*port_power)(struct usb_hcd___5 *, int, bool);
	int (*submit_single_step_set_feature)(struct usb_hcd___5 *, struct urb___5 *, int);
};

struct xhci_cap_regs {
	__le32 hc_capbase;
	__le32 hcs_params1;
	__le32 hcs_params2;
	__le32 hcs_params3;
	__le32 hcc_params;
	__le32 db_off;
	__le32 run_regs_off;
	__le32 hcc_params2;
};

struct xhci_op_regs {
	__le32 command;
	__le32 status;
	__le32 page_size;
	__le32 reserved1;
	__le32 reserved2;
	__le32 dev_notification;
	__le64 cmd_ring;
	__le32 reserved3[4];
	__le64 dcbaa_ptr;
	__le32 config_reg;
	__le32 reserved4[241];
	__le32 port_status_base;
	__le32 port_power_base;
	__le32 port_link_base;
	__le32 reserved5;
	__le32 reserved6[1016];
};

struct xhci_intr_reg {
	__le32 irq_pending;
	__le32 irq_control;
	__le32 erst_size;
	__le32 rsvd;
	__le64 erst_base;
	__le64 erst_dequeue;
};

struct xhci_run_regs {
	__le32 microframe_index;
	__le32 rsvd[7];
	struct xhci_intr_reg ir_set[128];
};

struct xhci_doorbell_array {
	__le32 doorbell[256];
};

struct xhci_container_ctx {
	unsigned int type;
	int size;
	u8 *bytes;
	dma_addr_t dma;
};

struct xhci_slot_ctx {
	__le32 dev_info;
	__le32 dev_info2;
	__le32 tt_info;
	__le32 dev_state;
	__le32 reserved[4];
};

struct xhci_ep_ctx {
	__le32 ep_info;
	__le32 ep_info2;
	__le64 deq;
	__le32 tx_info;
	__le32 reserved[3];
};

struct xhci_input_control_ctx {
	__le32 drop_flags;
	__le32 add_flags;
	__le32 rsvd2[6];
};

union xhci_trb;

struct xhci_command {
	struct xhci_container_ctx *in_ctx;
	u32 status;
	int slot_id;
	struct completion *completion;
	union xhci_trb *command_trb;
	struct list_head cmd_list;
};

struct xhci_link_trb {
	__le64 segment_ptr;
	__le32 intr_target;
	__le32 control;
};

struct xhci_transfer_event {
	__le64 buffer;
	__le32 transfer_len;
	__le32 flags;
};

struct xhci_event_cmd {
	__le64 cmd_trb;
	__le32 status;
	__le32 flags;
};

struct xhci_generic_trb {
	__le32 field[4];
};

union xhci_trb {
	struct xhci_link_trb link;
	struct xhci_transfer_event trans_event;
	struct xhci_event_cmd event_cmd;
	struct xhci_generic_trb generic;
};

struct xhci_stream_ctx {
	__le64 stream_ring;
	__le32 reserved[2];
};

struct xhci_ring;

struct xhci_stream_info {
	struct xhci_ring **stream_rings;
	unsigned int num_streams;
	struct xhci_stream_ctx *stream_ctx_array;
	unsigned int num_stream_ctxs;
	dma_addr_t ctx_array_dma;
	struct xarray trb_address_map;
	struct xhci_command *free_streams_command;
};

enum xhci_ring_type {
	TYPE_CTRL = 0,
	TYPE_ISOC = 1,
	TYPE_BULK = 2,
	TYPE_INTR = 3,
	TYPE_STREAM = 4,
	TYPE_COMMAND = 5,
	TYPE_EVENT = 6,
};

struct xhci_segment;

struct xhci_ring {
	struct xhci_segment *first_seg;
	struct xhci_segment *last_seg;
	union xhci_trb *enqueue;
	struct xhci_segment *enq_seg;
	union xhci_trb *dequeue;
	struct xhci_segment *deq_seg;
	struct list_head td_list;
	u32 cycle_state;
	unsigned int err_count;
	unsigned int stream_id;
	unsigned int num_segs;
	unsigned int num_trbs_free;
	unsigned int num_trbs_free_temp;
	unsigned int bounce_buf_len;
	enum xhci_ring_type type;
	bool last_td_was_short;
	struct xarray *trb_address_map;
};

struct xhci_bw_info {
	unsigned int ep_interval;
	unsigned int mult;
	unsigned int num_packets;
	unsigned int max_packet_size;
	unsigned int max_esit_payload;
	unsigned int type;
};

struct xhci_virt_device;

struct xhci_hcd;

struct xhci_virt_ep {
	struct xhci_virt_device *vdev;
	unsigned int ep_index;
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_interval_bw_table;

struct xhci_tt_bw_info;

struct xhci_virt_device {
	int slot_id;
	struct usb_device___5 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	long unsigned int flags;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_erst_entry;

struct xhci_erst {
	struct xhci_erst_entry *entries;
	unsigned int num_entries;
	dma_addr_t erst_dma_addr;
	unsigned int erst_size;
};

struct s3_save {
	u32 command;
	u32 dev_nt;
	u64 dcbaa_ptr;
	u32 config_reg;
	u32 irq_pending;
	u32 irq_control;
	u32 erst_size;
	u64 erst_base;
	u64 erst_dequeue;
};

struct xhci_bus_state {
	long unsigned int bus_suspended;
	long unsigned int next_statechange;
	u32 port_c_suspend;
	u32 suspended_ports;
	u32 port_remote_wakeup;
	long unsigned int resume_done[31];
	long unsigned int resuming_ports;
	long unsigned int rexit_ports;
	struct completion rexit_done[31];
	struct completion u3exit_done[31];
};

struct xhci_port;

struct xhci_hub {
	struct xhci_port **ports;
	unsigned int num_ports;
	struct usb_hcd___5 *hcd;
	struct xhci_bus_state bus_state;
	u8 maj_rev;
	u8 min_rev;
};

struct xhci_device_context_array;

struct xhci_scratchpad;

struct xhci_root_port_bw_info;

struct xhci_port_cap;

struct xhci_hcd {
	struct usb_hcd___5 *main_hcd;
	struct usb_hcd___5 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	u32 isoc_bei_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct reset_control *reset;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_port *hw_ports;
	struct xhci_hub usb2_rhub;
	struct xhci_hub usb3_rhub;
	unsigned int hw_lpm_support: 1;
	unsigned int broken_suspend: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct xhci_port_cap *port_caps;
	unsigned int num_port_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___41 *debugfs_root;
	struct dentry___41 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_segment {
	union xhci_trb *trbs;
	struct xhci_segment *next;
	dma_addr_t dma;
	dma_addr_t bounce_dma;
	void *bounce_buf;
	unsigned int bounce_offs;
	unsigned int bounce_len;
};

enum xhci_overhead_type {
	LS_OVERHEAD_TYPE = 0,
	FS_OVERHEAD_TYPE = 1,
	HS_OVERHEAD_TYPE = 2,
};

struct xhci_interval_bw {
	unsigned int num_packets;
	struct list_head endpoints;
	unsigned int overhead[3];
};

struct xhci_interval_bw_table {
	unsigned int interval0_esit_payload;
	struct xhci_interval_bw interval_bw[16];
	unsigned int bw_used;
	unsigned int ss_bw_in;
	unsigned int ss_bw_out;
};

struct xhci_tt_bw_info {
	struct list_head tt_list;
	int slot_id;
	int ttport;
	struct xhci_interval_bw_table bw_table;
	int active_eps;
};

struct xhci_root_port_bw_info {
	struct list_head tts;
	unsigned int num_active_tts;
	struct xhci_interval_bw_table bw_table;
};

struct xhci_device_context_array {
	__le64 dev_context_ptrs[256];
	dma_addr_t dma;
};

enum xhci_setup_dev {
	SETUP_CONTEXT_ONLY = 0,
	SETUP_CONTEXT_ADDRESS = 1,
};

enum xhci_cancelled_td_status {
	TD_DIRTY = 0,
	TD_HALTED = 1,
	TD_CLEARING_CACHE = 2,
	TD_CLEARED = 3,
};

struct xhci_td {
	struct list_head td_list;
	struct list_head cancelled_td_list;
	int status;
	enum xhci_cancelled_td_status cancel_status;
	struct urb___5 *urb;
	struct xhci_segment *start_seg;
	union xhci_trb *first_trb;
	union xhci_trb *last_trb;
	struct xhci_segment *last_trb_seg;
	struct xhci_segment *bounce_seg;
	bool urb_length_set;
	unsigned int num_trbs;
};

struct xhci_erst_entry {
	__le64 seg_addr;
	__le32 seg_size;
	__le32 rsvd;
};

struct xhci_scratchpad {
	u64 *sp_array;
	dma_addr_t sp_dma;
	void **sp_buffers;
};

struct urb_priv___3 {
	int num_tds;
	int num_tds_done;
	struct xhci_td td[0];
};

struct xhci_port_cap {
	u32 *psi;
	u8 psi_count;
	u8 psi_uid_count;
	u8 maj_rev;
	u8 min_rev;
};

struct xhci_port {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub *rhub;
	struct xhci_port_cap *port_cap;
};

struct xhci_driver_overrides {
	size_t extra_priv_size;
	int (*reset)(struct usb_hcd___5 *);
	int (*start)(struct usb_hcd___5 *);
	int (*add_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___5 *, struct usb_device___5 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
	void (*reset_bandwidth)(struct usb_hcd___5 *, struct usb_device___5 *);
};

typedef void (*xhci_get_quirks_t)(struct device___37 *, struct xhci_hcd *);

struct xhci_virt_device___2;

struct xhci_hcd___2;

struct xhci_virt_ep___2 {
	struct xhci_virt_device___2 *vdev;
	unsigned int ep_index;
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___2 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_virt_device___2 {
	int slot_id;
	struct usb_device___2 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___2 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	long unsigned int flags;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_port___2;

struct xhci_hub___2 {
	struct xhci_port___2 **ports;
	unsigned int num_ports;
	struct usb_hcd___2 *hcd;
	struct xhci_bus_state bus_state;
	u8 maj_rev;
	u8 min_rev;
};

struct xhci_hcd___2 {
	struct usb_hcd___2 *main_hcd;
	struct usb_hcd___2 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	u32 isoc_bei_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct reset_control *reset;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___2 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_port___2 *hw_ports;
	struct xhci_hub___2 usb2_rhub;
	struct xhci_hub___2 usb3_rhub;
	unsigned int hw_lpm_support: 1;
	unsigned int broken_suspend: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct xhci_port_cap *port_caps;
	unsigned int num_port_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___216 *debugfs_root;
	struct dentry___216 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_port___2 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___2 *rhub;
	struct xhci_port_cap *port_cap;
};

enum xhci_ep_reset_type {
	EP_HARD_RESET = 0,
	EP_SOFT_RESET = 1,
};

struct usb_interface___6 {
	struct usb_host_interface *altsetting;
	struct usb_host_interface *cur_altsetting;
	unsigned int num_altsetting;
	struct usb_interface_assoc_descriptor *intf_assoc;
	int minor;
	enum usb_interface_condition condition;
	unsigned int sysfs_files_created;
	unsigned int ep_devs_created;
	unsigned int unregistering;
	unsigned int needs_remote_wakeup;
	unsigned int needs_altsetting0;
	unsigned int needs_binding;
	unsigned int resetting_device;
	unsigned int authorized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct device___47 dev;
	struct device___47 *usb_dev;
	struct work_struct reset_ws;
};

struct usb_host_config___6 {
	struct usb_config_descriptor desc;
	char *string;
	struct usb_interface_assoc_descriptor *intf_assoc[16];
	struct usb_interface___6 *interface[32];
	struct usb_interface_cache *intf_cache[32];
	unsigned char *extra;
	int extralen;
};

struct usb_device___6;

struct usb_bus___6 {
	struct device___47 *controller;
	struct device___47 *sysdev;
	int busnum;
	const char *bus_name;
	u8 uses_pio_for_control;
	u8 otg_port;
	unsigned int is_b_host: 1;
	unsigned int b_hnp_enable: 1;
	unsigned int no_stop_on_short: 1;
	unsigned int no_sg_constraint: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int sg_tablesize;
	int devnum_next;
	struct mutex devnum_next_mutex;
	struct usb_devmap devmap;
	struct usb_device___6 *root_hub;
	struct usb_bus___6 *hs_companion;
	int bandwidth_allocated;
	int bandwidth_int_reqs;
	int bandwidth_isoc_reqs;
	unsigned int resuming_ports;
	struct mon_bus *mon_bus;
	int monitored;
};

struct usb_tt___6;

struct usb_device___6 {
	int devnum;
	char devpath[16];
	u32 route;
	enum usb_device_state state;
	enum usb_device_speed speed;
	unsigned int rx_lanes;
	unsigned int tx_lanes;
	enum usb_ssp_rate ssp_rate;
	struct usb_tt___6 *tt;
	int ttport;
	unsigned int toggle[2];
	struct usb_device___6 *parent;
	struct usb_bus___6 *bus;
	struct usb_host_endpoint ep0;
	struct device___47 dev;
	struct usb_device_descriptor descriptor;
	struct usb_host_bos *bos;
	struct usb_host_config___6 *config;
	struct usb_host_config___6 *actconfig;
	struct usb_host_endpoint *ep_in[16];
	struct usb_host_endpoint *ep_out[16];
	char **rawdescriptors;
	short unsigned int bus_mA;
	u8 portnum;
	u8 level;
	u8 devaddr;
	unsigned int can_submit: 1;
	unsigned int persist_enabled: 1;
	unsigned int have_langid: 1;
	unsigned int authorized: 1;
	unsigned int authenticated: 1;
	unsigned int wusb: 1;
	unsigned int lpm_capable: 1;
	unsigned int usb2_hw_lpm_capable: 1;
	unsigned int usb2_hw_lpm_besl_capable: 1;
	unsigned int usb2_hw_lpm_enabled: 1;
	unsigned int usb2_hw_lpm_allowed: 1;
	unsigned int usb3_lpm_u1_enabled: 1;
	unsigned int usb3_lpm_u2_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int string_langid;
	char *product;
	char *manufacturer;
	char *serial;
	struct list_head filelist;
	int maxchild;
	u32 quirks;
	atomic_t urbnum;
	long unsigned int active_duration;
	long unsigned int connect_time;
	unsigned int do_remote_wakeup: 1;
	unsigned int reset_resume: 1;
	unsigned int port_is_suspended: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct wusb_dev *wusb_dev;
	int slot_id;
	struct usb2_lpm_parameters l1_params;
	struct usb3_lpm_parameters u1_params;
	struct usb3_lpm_parameters u2_params;
	unsigned int lpm_disable_count;
	u16 hub_delay;
	unsigned int use_generic_driver: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct usb_tt___6 {
	struct usb_device___6 *hub;
	int multi;
	unsigned int think_time;
	void *hcpriv;
	spinlock_t lock;
	struct list_head clear_list;
	struct work_struct clear_work;
};

struct urb___6;

typedef void (*usb_complete_t___6)(struct urb___6 *);

struct urb___6 {
	struct kref kref;
	int unlinked;
	void *hcpriv;
	atomic_t use_count;
	atomic_t reject;
	struct list_head urb_list;
	struct list_head anchor_list;
	struct usb_anchor *anchor;
	struct usb_device___6 *dev;
	struct usb_host_endpoint *ep;
	unsigned int pipe;
	unsigned int stream_id;
	int status;
	unsigned int transfer_flags;
	void *transfer_buffer;
	dma_addr_t transfer_dma;
	struct scatterlist *sg;
	int num_mapped_sgs;
	int num_sgs;
	u32 transfer_buffer_length;
	u32 actual_length;
	unsigned char *setup_packet;
	dma_addr_t setup_dma;
	int start_frame;
	int number_of_packets;
	int interval;
	int error_count;
	void *context;
	usb_complete_t___6 complete;
	struct usb_iso_packet_descriptor iso_frame_desc[0];
};

struct hc_driver___6;

struct usb_hcd___6 {
	struct usb_bus___6 self;
	struct kref kref;
	const char *product_desc;
	int speed;
	char irq_descr[24];
	struct timer_list rh_timer;
	struct urb___6 *status_urb;
	struct work_struct wakeup_work;
	struct work_struct died_work;
	const struct hc_driver___6 *driver;
	struct usb_phy *usb_phy;
	struct usb_phy_roothub *phy_roothub;
	long unsigned int flags;
	enum usb_dev_authorize_policy dev_policy;
	unsigned int rh_registered;
	unsigned int rh_pollable;
	unsigned int msix_enabled;
	unsigned int msi_enabled;
	unsigned int skip_phy_initialization;
	unsigned int uses_new_polling;
	unsigned int wireless;
	unsigned int has_tt;
	unsigned int amd_resume_bug;
	unsigned int can_do_streams;
	unsigned int tpl_support;
	unsigned int cant_recv_wakeups;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq;
	void *regs;
	resource_size_t rsrc_start;
	resource_size_t rsrc_len;
	unsigned int power_budget;
	struct giveback_urb_bh high_prio_bh;
	struct giveback_urb_bh low_prio_bh;
	struct mutex *address0_mutex;
	struct mutex *bandwidth_mutex;
	struct usb_hcd___6 *shared_hcd;
	struct usb_hcd___6 *primary_hcd;
	struct dma_pool___2 *pool[4];
	int state;
	struct gen_pool *localmem_pool;
	long unsigned int hcd_priv[0];
};

struct hc_driver___6 {
	const char *description;
	const char *product_desc;
	size_t hcd_priv_size;
	irqreturn_t (*irq)(struct usb_hcd___6 *);
	int flags;
	int (*reset)(struct usb_hcd___6 *);
	int (*start)(struct usb_hcd___6 *);
	int (*pci_suspend)(struct usb_hcd___6 *, bool);
	int (*pci_resume)(struct usb_hcd___6 *, bool);
	void (*stop)(struct usb_hcd___6 *);
	void (*shutdown)(struct usb_hcd___6 *);
	int (*get_frame_number)(struct usb_hcd___6 *);
	int (*urb_enqueue)(struct usb_hcd___6 *, struct urb___6 *, gfp_t);
	int (*urb_dequeue)(struct usb_hcd___6 *, struct urb___6 *, int);
	int (*map_urb_for_dma)(struct usb_hcd___6 *, struct urb___6 *, gfp_t);
	void (*unmap_urb_for_dma)(struct usb_hcd___6 *, struct urb___6 *);
	void (*endpoint_disable)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	void (*endpoint_reset)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	int (*hub_status_data)(struct usb_hcd___6 *, char *);
	int (*hub_control)(struct usb_hcd___6 *, u16, u16, u16, char *, u16);
	int (*bus_suspend)(struct usb_hcd___6 *);
	int (*bus_resume)(struct usb_hcd___6 *);
	int (*start_port_reset)(struct usb_hcd___6 *, unsigned int);
	long unsigned int (*get_resuming_ports)(struct usb_hcd___6 *);
	void (*relinquish_port)(struct usb_hcd___6 *, int);
	int (*port_handed_over)(struct usb_hcd___6 *, int);
	void (*clear_tt_buffer_complete)(struct usb_hcd___6 *, struct usb_host_endpoint *);
	int (*alloc_dev)(struct usb_hcd___6 *, struct usb_device___6 *);
	void (*free_dev)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*alloc_streams)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint **, unsigned int, unsigned int, gfp_t);
	int (*free_streams)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint **, unsigned int, gfp_t);
	int (*add_endpoint)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint *);
	int (*drop_endpoint)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_host_endpoint *);
	int (*check_bandwidth)(struct usb_hcd___6 *, struct usb_device___6 *);
	void (*reset_bandwidth)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*address_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*enable_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*update_hub_device)(struct usb_hcd___6 *, struct usb_device___6 *, struct usb_tt___6 *, gfp_t);
	int (*reset_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*update_device)(struct usb_hcd___6 *, struct usb_device___6 *);
	int (*set_usb2_hw_lpm)(struct usb_hcd___6 *, struct usb_device___6 *, int);
	int (*enable_usb3_lpm_timeout)(struct usb_hcd___6 *, struct usb_device___6 *, enum usb3_link_state);
	int (*disable_usb3_lpm_timeout)(struct usb_hcd___6 *, struct usb_device___6 *, enum usb3_link_state);
	int (*find_raw_port_number)(struct usb_hcd___6 *, int);
	int (*port_power)(struct usb_hcd___6 *, int, bool);
	int (*submit_single_step_set_feature)(struct usb_hcd___6 *, struct urb___6 *, int);
};

struct xhci_virt_device___3;

struct xhci_hcd___3;

struct xhci_virt_ep___3 {
	struct xhci_virt_device___3 *vdev;
	unsigned int ep_index;
	struct xhci_ring *ring;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *new_ring;
	unsigned int ep_state;
	struct list_head cancelled_td_list;
	struct timer_list stop_cmd_timer;
	struct xhci_hcd___3 *xhci;
	struct xhci_segment *queued_deq_seg;
	union xhci_trb *queued_deq_ptr;
	bool skip;
	struct xhci_bw_info bw_info;
	struct list_head bw_endpoint_list;
	int next_frame_id;
	bool use_extended_tbc;
};

struct xhci_virt_device___3 {
	int slot_id;
	struct usb_device___6 *udev;
	struct xhci_container_ctx *out_ctx;
	struct xhci_container_ctx *in_ctx;
	struct xhci_virt_ep___3 eps[31];
	u8 fake_port;
	u8 real_port;
	struct xhci_interval_bw_table *bw_table;
	struct xhci_tt_bw_info *tt_info;
	long unsigned int flags;
	u16 current_mel;
	void *debugfs_private;
};

struct xhci_port___3;

struct xhci_hub___3 {
	struct xhci_port___3 **ports;
	unsigned int num_ports;
	struct usb_hcd___6 *hcd;
	struct xhci_bus_state bus_state;
	u8 maj_rev;
	u8 min_rev;
};

struct xhci_hcd___3 {
	struct usb_hcd___6 *main_hcd;
	struct usb_hcd___6 *shared_hcd;
	struct xhci_cap_regs *cap_regs;
	struct xhci_op_regs *op_regs;
	struct xhci_run_regs *run_regs;
	struct xhci_doorbell_array *dba;
	struct xhci_intr_reg *ir_set;
	__u32 hcs_params1;
	__u32 hcs_params2;
	__u32 hcs_params3;
	__u32 hcc_params;
	__u32 hcc_params2;
	spinlock_t lock;
	u8 sbrn;
	u16 hci_version;
	u8 max_slots;
	u8 max_interrupters;
	u8 max_ports;
	u8 isoc_threshold;
	u32 imod_interval;
	u32 isoc_bei_interval;
	int event_ring_max;
	int page_size;
	int page_shift;
	int msix_count;
	struct clk *clk;
	struct clk *reg_clk;
	struct reset_control *reset;
	struct xhci_device_context_array *dcbaa;
	struct xhci_ring *cmd_ring;
	unsigned int cmd_ring_state;
	struct list_head cmd_list;
	unsigned int cmd_ring_reserved_trbs;
	struct delayed_work cmd_timer;
	struct completion cmd_ring_stop_completion;
	struct xhci_command *current_cmd;
	struct xhci_ring *event_ring;
	struct xhci_erst erst;
	struct xhci_scratchpad *scratchpad;
	struct list_head lpm_failed_devs;
	struct mutex mutex;
	struct xhci_command *lpm_command;
	struct xhci_virt_device___3 *devs[256];
	struct xhci_root_port_bw_info *rh_bw;
	struct dma_pool___2 *device_pool;
	struct dma_pool___2 *segment_pool;
	struct dma_pool___2 *small_streams_pool;
	struct dma_pool___2 *medium_streams_pool;
	unsigned int xhc_state;
	u32 command;
	struct s3_save s3;
	long long unsigned int quirks;
	unsigned int num_active_eps;
	unsigned int limit_active_eps;
	struct xhci_port___3 *hw_ports;
	struct xhci_hub___3 usb2_rhub;
	struct xhci_hub___3 usb3_rhub;
	unsigned int hw_lpm_support: 1;
	unsigned int broken_suspend: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 *ext_caps;
	unsigned int num_ext_caps;
	struct xhci_port_cap *port_caps;
	unsigned int num_port_caps;
	struct timer_list comp_mode_recovery_timer;
	u32 port_status_u0;
	u16 test_mode;
	struct dentry___53 *debugfs_root;
	struct dentry___53 *debugfs_slots;
	struct list_head regset_list;
	void *dbc;
	long unsigned int priv[0];
};

struct xhci_port___3 {
	__le32 *addr;
	int hw_portnum;
	int hcd_portnum;
	struct xhci_hub___3 *rhub;
	struct xhci_port_cap *port_cap;
};

struct dbc_regs {
	__le32 capability;
	__le32 doorbell;
	__le32 ersts;
	__le32 __reserved_0;
	__le64 erstba;
	__le64 erdp;
	__le32 control;
	__le32 status;
	__le32 portsc;
	__le32 __reserved_1;
	__le64 dccp;
	__le32 devinfo1;
	__le32 devinfo2;
};

struct dbc_str_descs {
	char string0[64];
	char manufacturer[64];
	char product[64];
	char serial[64];
};

enum dbc_state {
	DS_DISABLED = 0,
	DS_INITIALIZED = 1,
	DS_ENABLED = 2,
	DS_CONNECTED = 3,
	DS_CONFIGURED = 4,
	DS_STALLED = 5,
};

struct xhci_dbc;

struct dbc_ep {
	struct xhci_dbc *dbc;
	struct list_head list_pending;
	struct xhci_ring *ring;
	unsigned int direction;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dbc_driver;

struct xhci_dbc {
	spinlock_t lock;
	struct device___47 *dev;
	struct xhci_hcd___3 *xhci;
	struct dbc_regs *regs;
	struct xhci_ring *ring_evt;
	struct xhci_ring *ring_in;
	struct xhci_ring *ring_out;
	struct xhci_erst erst;
	struct xhci_container_ctx *ctx;
	struct dbc_str_descs *string;
	dma_addr_t string_dma;
	size_t string_size;
	enum dbc_state state;
	struct delayed_work event_work;
	unsigned int resume_required;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dbc_ep eps[2];
	const struct dbc_driver *driver;
	void *priv;
};

struct dbc_driver {
	int (*configure)(struct xhci_dbc *);
	void (*disconnect)(struct xhci_dbc *);
};

struct dbc_request {
	void *buf;
	unsigned int length;
	dma_addr_t dma;
	void (*complete)(struct xhci_dbc *, struct dbc_request *);
	struct list_head list_pool;
	int status;
	unsigned int actual;
	struct xhci_dbc *dbc;
	struct list_head list_pending;
	dma_addr_t trb_dma;
	union xhci_trb *trb;
	unsigned int direction;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_file___35;

struct trace_event_buffer___34 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___35 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___35 {
	struct list_head list;
	struct trace_event_call___30 *event_call;
	struct event_filter *filter;
	struct dentry___53 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_xhci_log_msg {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_raw_xhci_log_ctx {
	struct trace_entry ent;
	int ctx_64;
	unsigned int ctx_type;
	dma_addr_t ctx_dma;
	u8 *ctx_va;
	unsigned int ctx_ep_num;
	int slot_id;
	u32 __data_loc_ctx_data;
	char __data[0];
};

struct trace_event_raw_xhci_log_trb {
	struct trace_entry ent;
	u32 type;
	u32 field0;
	u32 field1;
	u32 field2;
	u32 field3;
	u32 __data_loc_str;
	char __data[0];
};

struct trace_event_raw_xhci_log_free_virt_dev {
	struct trace_entry ent;
	void *vdev;
	long long unsigned int out_ctx;
	long long unsigned int in_ctx;
	u8 fake_port;
	u8 real_port;
	u16 current_mel;
	char __data[0];
};

struct trace_event_raw_xhci_log_virt_dev {
	struct trace_entry ent;
	void *vdev;
	long long unsigned int out_ctx;
	long long unsigned int in_ctx;
	int devnum;
	int state;
	int speed;
	u8 portnum;
	u8 level;
	int slot_id;
	char __data[0];
};

struct trace_event_raw_xhci_log_urb {
	struct trace_entry ent;
	void *urb;
	unsigned int pipe;
	unsigned int stream;
	int status;
	unsigned int flags;
	int num_mapped_sgs;
	int num_sgs;
	int length;
	int actual;
	int epnum;
	int dir_in;
	int type;
	int slot_id;
	char __data[0];
};

struct trace_event_raw_xhci_log_ep_ctx {
	struct trace_entry ent;
	u32 info;
	u32 info2;
	u64 deq;
	u32 tx_info;
	u32 __data_loc_str;
	char __data[0];
};

struct trace_event_raw_xhci_log_slot_ctx {
	struct trace_entry ent;
	u32 info;
	u32 info2;
	u32 tt_info;
	u32 state;
	u32 __data_loc_str;
	char __data[0];
};

struct trace_event_raw_xhci_log_ctrl_ctx {
	struct trace_entry ent;
	u32 drop;
	u32 add;
	u32 __data_loc_str;
	char __data[0];
};

struct trace_event_raw_xhci_log_ring {
	struct trace_entry ent;
	u32 type;
	void *ring;
	dma_addr_t enq;
	dma_addr_t deq;
	dma_addr_t enq_seg;
	dma_addr_t deq_seg;
	unsigned int num_segs;
	unsigned int stream_id;
	unsigned int cycle_state;
	unsigned int num_trbs_free;
	unsigned int bounce_buf_len;
	char __data[0];
};

struct trace_event_raw_xhci_log_portsc {
	struct trace_entry ent;
	u32 portnum;
	u32 portsc;
	u32 __data_loc_str;
	char __data[0];
};

struct trace_event_raw_xhci_log_doorbell {
	struct trace_entry ent;
	u32 slot;
	u32 doorbell;
	u32 __data_loc_str;
	char __data[0];
};

struct trace_event_raw_xhci_dbc_log_request {
	struct trace_entry ent;
	struct dbc_request *req;
	bool dir;
	unsigned int actual;
	unsigned int length;
	int status;
	char __data[0];
};

struct trace_event_data_offsets_xhci_log_msg {
	u32 msg;
};

struct trace_event_data_offsets_xhci_log_ctx {
	u32 ctx_data;
};

struct trace_event_data_offsets_xhci_log_trb {
	u32 str;
};

struct trace_event_data_offsets_xhci_log_free_virt_dev {};

struct trace_event_data_offsets_xhci_log_virt_dev {};

struct trace_event_data_offsets_xhci_log_urb {};

struct trace_event_data_offsets_xhci_log_ep_ctx {
	u32 str;
};

struct trace_event_data_offsets_xhci_log_slot_ctx {
	u32 str;
};

struct trace_event_data_offsets_xhci_log_ctrl_ctx {
	u32 str;
};

struct trace_event_data_offsets_xhci_log_ring {};

struct trace_event_data_offsets_xhci_log_portsc {
	u32 str;
};

struct trace_event_data_offsets_xhci_log_doorbell {
	u32 str;
};

struct trace_event_data_offsets_xhci_dbc_log_request {};

typedef void (*btf_trace_xhci_dbg_address)(void *, struct va_format *);

typedef void (*btf_trace_xhci_dbg_context_change)(void *, struct va_format *);

typedef void (*btf_trace_xhci_dbg_quirks)(void *, struct va_format *);

typedef void (*btf_trace_xhci_dbg_reset_ep)(void *, struct va_format *);

typedef void (*btf_trace_xhci_dbg_cancel_urb)(void *, struct va_format *);

typedef void (*btf_trace_xhci_dbg_init)(void *, struct va_format *);

typedef void (*btf_trace_xhci_dbg_ring_expansion)(void *, struct va_format *);

typedef void (*btf_trace_xhci_address_ctx)(void *, struct xhci_hcd___3 *, struct xhci_container_ctx *, unsigned int);

typedef void (*btf_trace_xhci_handle_event)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_handle_command)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_handle_transfer)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_queue_trb)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_dbc_handle_event)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_dbc_handle_transfer)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_dbc_gadget_ep_queue)(void *, struct xhci_ring *, struct xhci_generic_trb *);

typedef void (*btf_trace_xhci_free_virt_device)(void *, struct xhci_virt_device___3 *);

typedef void (*btf_trace_xhci_alloc_virt_device)(void *, struct xhci_virt_device___3 *);

typedef void (*btf_trace_xhci_setup_device)(void *, struct xhci_virt_device___3 *);

typedef void (*btf_trace_xhci_setup_addressable_virt_device)(void *, struct xhci_virt_device___3 *);

typedef void (*btf_trace_xhci_stop_device)(void *, struct xhci_virt_device___3 *);

typedef void (*btf_trace_xhci_urb_enqueue)(void *, struct urb___6 *);

typedef void (*btf_trace_xhci_urb_giveback)(void *, struct urb___6 *);

typedef void (*btf_trace_xhci_urb_dequeue)(void *, struct urb___6 *);

typedef void (*btf_trace_xhci_handle_cmd_stop_ep)(void *, struct xhci_ep_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_set_deq_ep)(void *, struct xhci_ep_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_reset_ep)(void *, struct xhci_ep_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_config_ep)(void *, struct xhci_ep_ctx *);

typedef void (*btf_trace_xhci_add_endpoint)(void *, struct xhci_ep_ctx *);

typedef void (*btf_trace_xhci_alloc_dev)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_free_dev)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_disable_slot)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_discover_or_reset_device)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_setup_device_slot)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_addr_dev)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_reset_dev)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_handle_cmd_set_deq)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_configure_endpoint)(void *, struct xhci_slot_ctx *);

typedef void (*btf_trace_xhci_address_ctrl_ctx)(void *, struct xhci_input_control_ctx *);

typedef void (*btf_trace_xhci_configure_endpoint_ctrl_ctx)(void *, struct xhci_input_control_ctx *);

typedef void (*btf_trace_xhci_ring_alloc)(void *, struct xhci_ring *);

typedef void (*btf_trace_xhci_ring_free)(void *, struct xhci_ring *);

typedef void (*btf_trace_xhci_ring_expansion)(void *, struct xhci_ring *);

typedef void (*btf_trace_xhci_inc_enq)(void *, struct xhci_ring *);

typedef void (*btf_trace_xhci_inc_deq)(void *, struct xhci_ring *);

typedef void (*btf_trace_xhci_handle_port_status)(void *, u32, u32);

typedef void (*btf_trace_xhci_get_port_status)(void *, u32, u32);

typedef void (*btf_trace_xhci_hub_status_data)(void *, u32, u32);

typedef void (*btf_trace_xhci_ring_ep_doorbell)(void *, u32, u32);

typedef void (*btf_trace_xhci_ring_host_doorbell)(void *, u32, u32);

typedef void (*btf_trace_xhci_dbc_alloc_request)(void *, struct dbc_request *);

typedef void (*btf_trace_xhci_dbc_free_request)(void *, struct dbc_request *);

typedef void (*btf_trace_xhci_dbc_queue_request)(void *, struct dbc_request *);

typedef void (*btf_trace_xhci_dbc_giveback_request)(void *, struct dbc_request *);

struct usb_string_descriptor {
	__u8 bLength;
	__u8 bDescriptorType;
	__le16 wData[1];
};

struct dbc_info_context {
	__le64 string0;
	__le64 manufacturer;
	__le64 product;
	__le64 serial;
	__le32 length;
	__le32 __reserved_0[7];
};

struct xhci_dbc___2;

struct dbc_ep___2 {
	struct xhci_dbc___2 *dbc;
	struct list_head list_pending;
	struct xhci_ring *ring;
	unsigned int direction;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dbc_driver___2;

struct xhci_dbc___2 {
	spinlock_t lock;
	struct device___12 *dev;
	struct xhci_hcd___2 *xhci;
	struct dbc_regs *regs;
	struct xhci_ring *ring_evt;
	struct xhci_ring *ring_in;
	struct xhci_ring *ring_out;
	struct xhci_erst erst;
	struct xhci_container_ctx *ctx;
	struct dbc_str_descs *string;
	dma_addr_t string_dma;
	size_t string_size;
	enum dbc_state state;
	struct delayed_work event_work;
	unsigned int resume_required;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dbc_ep___2 eps[2];
	const struct dbc_driver___2 *driver;
	void *priv;
};

struct dbc_driver___2 {
	int (*configure)(struct xhci_dbc___2 *);
	void (*disconnect)(struct xhci_dbc___2 *);
};

struct dbc_request___2 {
	void *buf;
	unsigned int length;
	dma_addr_t dma;
	void (*complete)(struct xhci_dbc___2 *, struct dbc_request___2 *);
	struct list_head list_pool;
	int status;
	unsigned int actual;
	struct xhci_dbc___2 *dbc;
	struct list_head list_pending;
	dma_addr_t trb_dma;
	union xhci_trb *trb;
	unsigned int direction;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum evtreturn {
	EVT_ERR = 4294967295,
	EVT_DONE = 0,
	EVT_GSER = 1,
	EVT_DISC = 2,
};

struct kfifo {
	union {
		struct __kfifo kfifo;
		unsigned char *type;
		const unsigned char *const_type;
		char (*rectype)[0];
		void *ptr;
		const void *ptr_const;
	};
	unsigned char buf[0];
};

struct dbc_port {
	struct tty_port___2 port;
	spinlock_t port_lock;
	struct list_head read_pool;
	struct list_head read_queue;
	unsigned int n_read;
	struct tasklet_struct push;
	struct list_head write_pool;
	struct kfifo write_fifo;
	bool registered;
};

struct xhci_regset {
	char name[32];
	struct debugfs_regset32 regset;
	size_t nregs;
	struct list_head list;
};

struct xhci_file_map {
	const char *name;
	int (*show)(struct seq_file___191 *, void *);
};

struct xhci_ep_priv {
	char name[32];
	struct dentry___216 *root;
	struct xhci_stream_info *stream_info;
	struct xhci_ring *show_ring;
	unsigned int stream_id;
};

struct xhci_slot_priv {
	char name[32];
	struct dentry___216 *root;
	struct xhci_ep_priv *eps[31];
	struct xhci_virt_device___2 *dev;
};

struct usb_role_switch___2;

typedef int (*usb_role_switch_set_t___2)(struct usb_role_switch___2 *, enum usb_role);

typedef enum usb_role (*usb_role_switch_get_t___2)(struct usb_role_switch___2 *);

struct usb_role_switch___2 {
	struct device___194 dev;
	struct mutex lock;
	enum usb_role role;
	struct device___194 *usb2_port;
	struct device___194 *usb3_port;
	struct device___194 *udc;
	usb_role_switch_set_t___2 set;
	usb_role_switch_get_t___2 get;
	bool allow_userspace_control;
};

struct usb_role_switch_desc___2 {
	struct fwnode_handle___190 *fwnode;
	struct device___194 *usb2_port;
	struct device___194 *usb3_port;
	struct device___194 *udc;
	usb_role_switch_set_t___2 set;
	usb_role_switch_get_t___2 get;
	bool allow_userspace_control;
	void *driver_data;
	const char *name;
};

typedef void * (*devcon_match_fn_t___2)(struct fwnode_handle___190 *, const char *, void *);

struct serio_device_id {
	__u8 type;
	__u8 extra;
	__u8 id;
	__u8 proto;
};

struct serio_driver;

struct serio {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio *, unsigned char);
	int (*open)(struct serio *);
	void (*close)(struct serio *);
	int (*start)(struct serio *);
	void (*stop)(struct serio *);
	struct serio *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver *drv;
	struct mutex drv_mutex;
	struct device___194 dev;
	struct list_head node;
	struct mutex *ps2_cmd_mutex;
};

struct serio_driver {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio *);
	irqreturn_t (*interrupt)(struct serio *, unsigned char, unsigned int);
	int (*connect)(struct serio *, struct serio_driver *);
	int (*reconnect)(struct serio *);
	int (*fast_reconnect)(struct serio *);
	void (*disconnect)(struct serio *);
	void (*cleanup)(struct serio *);
	struct device_driver___194 driver;
};

enum serio_event_type {
	SERIO_RESCAN_PORT = 0,
	SERIO_RECONNECT_PORT = 1,
	SERIO_RECONNECT_SUBTREE = 2,
	SERIO_REGISTER_PORT = 3,
	SERIO_ATTACH_DRIVER = 4,
};

struct serio_event {
	enum serio_event_type type;
	void *object;
	struct module___200 *owner;
	struct list_head node;
};

struct serio_driver___2;

struct serio___2 {
	void *port_data;
	char name[32];
	char phys[32];
	char firmware_id[128];
	bool manual_bind;
	struct serio_device_id id;
	spinlock_t lock;
	int (*write)(struct serio___2 *, unsigned char);
	int (*open)(struct serio___2 *);
	void (*close)(struct serio___2 *);
	int (*start)(struct serio___2 *);
	void (*stop)(struct serio___2 *);
	struct serio___2 *parent;
	struct list_head child_node;
	struct list_head children;
	unsigned int depth;
	struct serio_driver___2 *drv;
	struct mutex drv_mutex;
	struct device___198 dev;
	struct list_head node;
	struct mutex *ps2_cmd_mutex;
};

struct serio_driver___2 {
	const char *description;
	const struct serio_device_id *id_table;
	bool manual_bind;
	void (*write_wakeup)(struct serio___2 *);
	irqreturn_t (*interrupt)(struct serio___2 *, unsigned char, unsigned int);
	int (*connect)(struct serio___2 *, struct serio_driver___2 *);
	int (*reconnect)(struct serio___2 *);
	int (*fast_reconnect)(struct serio___2 *);
	void (*disconnect)(struct serio___2 *);
	void (*cleanup)(struct serio___2 *);
	struct device_driver___198 driver;
};

struct ps2dev {
	struct serio___2 *serio;
	struct mutex cmd_mutex;
	wait_queue_head_t wait;
	long unsigned int flags;
	u8 cmdbuf[8];
	u8 cmdcnt;
	u8 nak;
};

struct input_mt_slot {
	int abs[14];
	unsigned int frame;
	unsigned int key;
};

struct input_mt {
	int trkid;
	int num_slots;
	int slot;
	unsigned int flags;
	unsigned int frame;
	int *red;
	struct input_mt_slot slots[0];
};

union input_seq_state {
	struct {
		short unsigned int pos;
		bool mutex_acquired;
	};
	void *p;
};

struct input_devres {
	struct input_dev *input;
};

struct input_event {
	__kernel_ulong_t __sec;
	__kernel_ulong_t __usec;
	__u16 type;
	__u16 code;
	__s32 value;
};

struct input_event_compat {
	compat_ulong_t sec;
	compat_ulong_t usec;
	__u16 type;
	__u16 code;
	__s32 value;
};

struct ff_periodic_effect_compat {
	__u16 waveform;
	__u16 period;
	__s16 magnitude;
	__s16 offset;
	__u16 phase;
	struct ff_envelope envelope;
	__u32 custom_len;
	compat_uptr_t custom_data;
};

struct ff_effect_compat {
	__u16 type;
	__s16 id;
	__u16 direction;
	struct ff_trigger trigger;
	struct ff_replay replay;
	union {
		struct ff_constant_effect constant;
		struct ff_ramp_effect ramp;
		struct ff_periodic_effect_compat periodic;
		struct ff_condition_effect condition[2];
		struct ff_rumble_effect rumble;
	} u;
};

struct ff_device___3;

struct input_handle___3;

struct input_dev___3 {
	const char *name;
	const char *phys;
	const char *uniq;
	struct input_id id;
	long unsigned int propbit[1];
	long unsigned int evbit[1];
	long unsigned int keybit[12];
	long unsigned int relbit[1];
	long unsigned int absbit[1];
	long unsigned int mscbit[1];
	long unsigned int ledbit[1];
	long unsigned int sndbit[1];
	long unsigned int ffbit[2];
	long unsigned int swbit[1];
	unsigned int hint_events_per_packet;
	unsigned int keycodemax;
	unsigned int keycodesize;
	void *keycode;
	int (*setkeycode)(struct input_dev___3 *, const struct input_keymap_entry *, unsigned int *);
	int (*getkeycode)(struct input_dev___3 *, struct input_keymap_entry *);
	struct ff_device___3 *ff;
	struct input_dev_poller *poller;
	unsigned int repeat_key;
	struct timer_list timer;
	int rep[2];
	struct input_mt *mt;
	struct input_absinfo *absinfo;
	long unsigned int key[12];
	long unsigned int led[1];
	long unsigned int snd[1];
	long unsigned int sw[1];
	int (*open)(struct input_dev___3 *);
	void (*close)(struct input_dev___3 *);
	int (*flush)(struct input_dev___3 *, struct file___216 *);
	int (*event)(struct input_dev___3 *, unsigned int, unsigned int, int);
	struct input_handle___3 *grab;
	spinlock_t event_lock;
	struct mutex mutex;
	unsigned int users;
	bool going_away;
	struct device___194 dev;
	struct list_head h_list;
	struct list_head node;
	unsigned int num_vals;
	unsigned int max_vals;
	struct input_value *vals;
	bool devres_managed;
	ktime_t timestamp[3];
	bool inhibited;
};

struct ff_device___3 {
	int (*upload)(struct input_dev___3 *, struct ff_effect *, struct ff_effect *);
	int (*erase)(struct input_dev___3 *, int);
	int (*playback)(struct input_dev___3 *, int, int);
	void (*set_gain)(struct input_dev___3 *, u16);
	void (*set_autocenter)(struct input_dev___3 *, u16);
	void (*destroy)(struct ff_device___3 *);
	void *private;
	long unsigned int ffbit[2];
	struct mutex mutex;
	int max_effects;
	struct ff_effect *effects;
	struct file___216 *effect_owners[0];
};

struct input_handler___3;

struct input_handle___3 {
	void *private;
	int open;
	const char *name;
	struct input_dev___3 *dev;
	struct input_handler___3 *handler;
	struct list_head d_node;
	struct list_head h_node;
};

struct input_handler___3 {
	void *private;
	void (*event)(struct input_handle___3 *, unsigned int, unsigned int, int);
	void (*events)(struct input_handle___3 *, const struct input_value *, unsigned int);
	bool (*filter)(struct input_handle___3 *, unsigned int, unsigned int, int);
	bool (*match)(struct input_handler___3 *, struct input_dev___3 *);
	int (*connect)(struct input_handler___3 *, struct input_dev___3 *, const struct input_device_id *);
	void (*disconnect)(struct input_handle___3 *);
	void (*start)(struct input_handle___3 *);
	bool legacy_minors;
	int minor;
	const char *name;
	const struct input_device_id *id_table;
	struct list_head h_list;
	struct list_head node;
};

struct input_mt_pos {
	s16 x;
	s16 y;
};

struct input_dev_poller {
	void (*poll)(struct input_dev___3 *);
	unsigned int poll_interval;
	unsigned int poll_interval_max;
	unsigned int poll_interval_min;
	struct input_dev___3 *input;
	struct delayed_work work;
};

struct touchscreen_properties {
	unsigned int max_x;
	unsigned int max_y;
	bool invert_x;
	bool invert_y;
	bool swap_x_y;
};

struct mousedev_hw_data {
	int dx;
	int dy;
	int dz;
	int x;
	int y;
	int abs_event;
	long unsigned int buttons;
};

struct mousedev {
	int open;
	struct input_handle___3 handle;
	wait_queue_head_t wait;
	struct list_head client_list;
	spinlock_t client_lock;
	struct mutex mutex;
	struct device___194 dev;
	struct cdev___54 cdev;
	bool exist;
	struct list_head mixdev_node;
	bool opened_by_mixdev;
	struct mousedev_hw_data packet;
	unsigned int pkt_count;
	int old_x[4];
	int old_y[4];
	int frac_dx;
	int frac_dy;
	long unsigned int touch;
	int (*open_device)(struct mousedev *);
	void (*close_device)(struct mousedev *);
};

enum mousedev_emul {
	MOUSEDEV_EMUL_PS2 = 0,
	MOUSEDEV_EMUL_IMPS = 1,
	MOUSEDEV_EMUL_EXPS = 2,
};

struct mousedev_motion {
	int dx;
	int dy;
	int dz;
	long unsigned int buttons;
};

struct mousedev_client {
	struct fasync_struct___216 *fasync;
	struct mousedev *mousedev;
	struct list_head node;
	struct mousedev_motion packets[16];
	unsigned int head;
	unsigned int tail;
	spinlock_t packet_lock;
	int pos_x;
	int pos_y;
	u8 ps2[6];
	unsigned char ready;
	unsigned char buffer;
	unsigned char bufsiz;
	unsigned char imexseq;
	unsigned char impsseq;
	enum mousedev_emul mode;
	long unsigned int last_buttons;
};

enum {
	FRACTION_DENOM = 128,
};

struct input_mask {
	__u32 type;
	__u32 codes_size;
	__u64 codes_ptr;
};

struct evdev_client;

struct evdev {
	int open;
	struct input_handle___3 handle;
	struct evdev_client *grab;
	struct list_head client_list;
	spinlock_t client_lock;
	struct mutex mutex;
	struct device___194 dev;
	struct cdev___54 cdev;
	bool exist;
};

struct evdev_client {
	unsigned int head;
	unsigned int tail;
	unsigned int packet_head;
	spinlock_t buffer_lock;
	wait_queue_head_t wait;
	struct fasync_struct___216 *fasync;
	struct evdev *evdev;
	struct list_head node;
	enum input_clock_type clk_type;
	bool revoked;
	long unsigned int *evmasks[32];
	unsigned int bufsize;
	struct input_event buffer[0];
};

struct atkbd {
	struct ps2dev ps2dev;
	struct input_dev *dev;
	char name[64];
	char phys[32];
	short unsigned int id;
	short unsigned int keycode[512];
	long unsigned int force_release_mask[8];
	unsigned char set;
	bool translated;
	bool extra;
	bool write;
	bool softrepeat;
	bool softraw;
	bool scroll;
	bool enabled;
	unsigned char emul;
	bool resend;
	bool release;
	long unsigned int xl_bit;
	unsigned int last;
	long unsigned int time;
	long unsigned int err_count;
	struct delayed_work event_work;
	long unsigned int event_jiffies;
	long unsigned int event_mask;
	struct mutex mutex;
	u32 function_row_physmap[24];
	int num_function_row_keys;
};

struct uinput_ff_upload {
	__u32 request_id;
	__s32 retval;
	struct ff_effect effect;
	struct ff_effect old;
};

struct uinput_ff_erase {
	__u32 request_id;
	__s32 retval;
	__u32 effect_id;
};

struct uinput_setup {
	struct input_id id;
	char name[80];
	__u32 ff_effects_max;
};

struct uinput_abs_setup {
	__u16 code;
	struct input_absinfo absinfo;
};

struct uinput_user_dev {
	char name[80];
	struct input_id id;
	__u32 ff_effects_max;
	__s32 absmax[64];
	__s32 absmin[64];
	__s32 absfuzz[64];
	__s32 absflat[64];
};

enum uinput_state {
	UIST_NEW_DEVICE = 0,
	UIST_SETUP_COMPLETE = 1,
	UIST_CREATED = 2,
};

struct uinput_request {
	unsigned int id;
	unsigned int code;
	int retval;
	struct completion done;
	union {
		unsigned int effect_id;
		struct {
			struct ff_effect *effect;
			struct ff_effect *old;
		} upload;
	} u;
};

struct uinput_device {
	struct input_dev___3 *dev;
	struct mutex mutex;
	enum uinput_state state;
	wait_queue_head_t waitq;
	unsigned char ready;
	unsigned char head;
	unsigned char tail;
	struct input_event buff[16];
	unsigned int ff_effects_max;
	struct uinput_request *requests[16];
	wait_queue_head_t requests_waitq;
	spinlock_t requests_lock;
};

struct uinput_ff_upload_compat {
	__u32 request_id;
	__s32 retval;
	struct ff_effect_compat effect;
	struct ff_effect_compat old;
};

struct rtc_class_ops___4 {
	int (*ioctl)(struct device___198 *, unsigned int, long unsigned int);
	int (*read_time)(struct device___198 *, struct rtc_time *);
	int (*set_time)(struct device___198 *, struct rtc_time *);
	int (*read_alarm)(struct device___198 *, struct rtc_wkalrm *);
	int (*set_alarm)(struct device___198 *, struct rtc_wkalrm *);
	int (*proc)(struct device___198 *, struct seq_file___195 *);
	int (*alarm_irq_enable)(struct device___198 *, unsigned int);
	int (*read_offset)(struct device___198 *, long int *);
	int (*set_offset)(struct device___198 *, long int);
};

struct rtc_device___4;

struct rtc_timer___4 {
	struct timerqueue_node node;
	ktime_t period;
	void (*func)(struct rtc_device___4 *);
	struct rtc_device___4 *rtc;
	int enabled;
};

struct rtc_device___4 {
	struct device___198 dev;
	struct module___204 *owner;
	int id;
	const struct rtc_class_ops___4 *ops;
	struct mutex ops_lock;
	struct cdev___58 char_dev;
	long unsigned int flags;
	long unsigned int irq_data;
	spinlock_t irq_lock;
	wait_queue_head_t irq_queue;
	struct fasync_struct___220 *async_queue;
	int irq_freq;
	int max_user_freq;
	struct timerqueue_head timerqueue;
	struct rtc_timer___4 aie_timer;
	struct rtc_timer___4 uie_rtctimer;
	struct hrtimer pie_timer;
	int pie_enabled;
	struct work_struct irqwork;
	int uie_unsupported;
	long unsigned int set_offset_nsec;
	long unsigned int features[1];
	time64_t range_min;
	timeu64_t range_max;
	time64_t start_secs;
	time64_t offset_secs;
	bool set_start_time;
};

struct trace_event_raw_rtc_time_alarm_class {
	struct trace_entry ent;
	time64_t secs;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_irq_set_freq {
	struct trace_entry ent;
	int freq;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_irq_set_state {
	struct trace_entry ent;
	int enabled;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_alarm_irq_enable {
	struct trace_entry ent;
	unsigned int enabled;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_offset_class {
	struct trace_entry ent;
	long int offset;
	int err;
	char __data[0];
};

struct trace_event_raw_rtc_timer_class {
	struct trace_entry ent;
	struct rtc_timer___4 *timer;
	ktime_t expires;
	ktime_t period;
	char __data[0];
};

struct trace_event_data_offsets_rtc_time_alarm_class {};

struct trace_event_data_offsets_rtc_irq_set_freq {};

struct trace_event_data_offsets_rtc_irq_set_state {};

struct trace_event_data_offsets_rtc_alarm_irq_enable {};

struct trace_event_data_offsets_rtc_offset_class {};

struct trace_event_data_offsets_rtc_timer_class {};

typedef void (*btf_trace_rtc_set_time)(void *, time64_t, int);

typedef void (*btf_trace_rtc_read_time)(void *, time64_t, int);

typedef void (*btf_trace_rtc_set_alarm)(void *, time64_t, int);

typedef void (*btf_trace_rtc_read_alarm)(void *, time64_t, int);

typedef void (*btf_trace_rtc_irq_set_freq)(void *, int, int);

typedef void (*btf_trace_rtc_irq_set_state)(void *, int, int);

typedef void (*btf_trace_rtc_alarm_irq_enable)(void *, unsigned int, int);

typedef void (*btf_trace_rtc_set_offset)(void *, long int, int);

typedef void (*btf_trace_rtc_read_offset)(void *, long int, int);

typedef void (*btf_trace_rtc_timer_enqueue)(void *, struct rtc_timer___4 *);

typedef void (*btf_trace_rtc_timer_dequeue)(void *, struct rtc_timer___4 *);

typedef void (*btf_trace_rtc_timer_fired)(void *, struct rtc_timer___4 *);

enum {
	none = 0,
	day = 1,
	month = 2,
	year = 3,
};

struct nvmem_config___2 {
	struct device___194 *dev;
	const char *name;
	int id;
	struct module___8 *owner;
	struct gpio_desc *wp_gpio;
	const struct nvmem_cell_info *cells;
	int ncells;
	const struct nvmem_keepout *keepout;
	unsigned int nkeepout;
	enum nvmem_type type;
	bool read_only;
	bool root_only;
	bool ignore_wp;
	struct device_node___2 *of_node;
	bool no_of_node;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	int size;
	int word_size;
	int stride;
	void *priv;
	bool compat;
	struct device___194 *base_dev;
};

struct rtc_plat_data {
	struct rtc_device___2 *rtc;
	void *ioaddr;
	int irq;
	struct clk *clk;
};

struct rtd119x_rtc {
	void *base;
	struct clk *clk;
	struct rtc_device___4 *rtcdev;
	unsigned int base_year;
};

typedef void (*of_init_fn_1___7)(struct device_node___2 *);

struct clk_hw___6;

struct clk_rate_request___6 {
	long unsigned int rate;
	long unsigned int min_rate;
	long unsigned int max_rate;
	long unsigned int best_parent_rate;
	struct clk_hw___6 *best_parent_hw;
};

struct clk_init_data___6;

struct clk_hw___6 {
	struct clk_core___2 *core;
	struct clk *clk;
	const struct clk_init_data___6 *init;
};

struct clk_ops___6 {
	int (*prepare)(struct clk_hw___6 *);
	void (*unprepare)(struct clk_hw___6 *);
	int (*is_prepared)(struct clk_hw___6 *);
	void (*unprepare_unused)(struct clk_hw___6 *);
	int (*enable)(struct clk_hw___6 *);
	void (*disable)(struct clk_hw___6 *);
	int (*is_enabled)(struct clk_hw___6 *);
	void (*disable_unused)(struct clk_hw___6 *);
	int (*save_context)(struct clk_hw___6 *);
	void (*restore_context)(struct clk_hw___6 *);
	long unsigned int (*recalc_rate)(struct clk_hw___6 *, long unsigned int);
	long int (*round_rate)(struct clk_hw___6 *, long unsigned int, long unsigned int *);
	int (*determine_rate)(struct clk_hw___6 *, struct clk_rate_request___6 *);
	int (*set_parent)(struct clk_hw___6 *, u8);
	u8 (*get_parent)(struct clk_hw___6 *);
	int (*set_rate)(struct clk_hw___6 *, long unsigned int, long unsigned int);
	int (*set_rate_and_parent)(struct clk_hw___6 *, long unsigned int, long unsigned int, u8);
	long unsigned int (*recalc_accuracy)(struct clk_hw___6 *, long unsigned int);
	int (*get_phase)(struct clk_hw___6 *);
	int (*set_phase)(struct clk_hw___6 *, int);
	int (*get_duty_cycle)(struct clk_hw___6 *, struct clk_duty *);
	int (*set_duty_cycle)(struct clk_hw___6 *, struct clk_duty *);
	int (*init)(struct clk_hw___6 *);
	void (*terminate)(struct clk_hw___6 *);
	void (*debug_init)(struct clk_hw___6 *, struct dentry___216 *);
};

struct clk_parent_data___6 {
	const struct clk_hw___6 *hw;
	const char *fw_name;
	const char *name;
	int index;
};

struct clk_init_data___6 {
	const char *name;
	const struct clk_ops___6 *ops;
	const char * const *parent_names;
	const struct clk_parent_data___6 *parent_data;
	const struct clk_hw___6 **parent_hws;
	u8 num_parents;
	long unsigned int flags;
};

struct clk_hw_onecell_data___3 {
	unsigned int num;
	struct clk_hw___6 *hws[0];
};

struct sun6i_rtc_clk_data {
	long unsigned int rc_osc_rate;
	unsigned int fixed_prescaler: 16;
	unsigned int has_prescaler: 1;
	unsigned int has_out_clk: 1;
	unsigned int export_iosc: 1;
	unsigned int has_losc_en: 1;
	unsigned int has_auto_swt: 1;
	long: 63;
	long: 64;
};

struct sun6i_rtc_dev {
	struct rtc_device___2 *rtc;
	const struct sun6i_rtc_clk_data *data;
	void *base;
	int irq;
	long unsigned int alarm;
	struct clk_hw___6 hw;
	struct clk_hw___6 *int_osc;
	struct clk *losc;
	struct clk *ext_losc;
	spinlock_t lock;
};

struct xgene_rtc_dev {
	struct rtc_device___2 *rtc;
	void *csr_base;
	struct clk *clk;
	unsigned int irq_wake;
	unsigned int irq_enabled;
};

struct i2c_devinfo {
	struct list_head list;
	int busnum;
	struct i2c_board_info___2 board_info;
};

struct irq_desc___61;

typedef void (*irq_flow_handler_t___61)(struct irq_desc___61 *);

struct irq_chip___61;

struct irq_domain___59;

struct irq_data___61 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___61 *chip;
	struct irq_domain___59 *domain;
	struct irq_data___61 *parent_data;
	void *chip_data;
};

struct kset___218;

struct kobj_type___218;

struct kernfs_node___218;

struct kobject___218 {
	const char *name;
	struct list_head entry;
	struct kobject___218 *parent;
	struct kset___218 *kset;
	struct kobj_type___218 *ktype;
	struct kernfs_node___218 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irqaction___43;

struct module___214;

struct irq_desc___61 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___61 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___61 handle_irq;
	struct irqaction___43 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___218 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___214 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___230;

struct super_block___230;

struct file_system_type___230 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___230 * (*mount)(struct file_system_type___230 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___230 *);
	struct module___214 *owner;
	struct file_system_type___230 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___230;

struct kiocb___230;

struct iov_iter___150;

struct poll_table_struct___155;

struct vm_area_struct___235;

struct inode___230;

struct file_lock___230;

struct page___235;

struct seq_file___205;

struct file_operations___231 {
	struct module___214 *owner;
	loff_t (*llseek)(struct file___230 *, loff_t, int);
	ssize_t (*read)(struct file___230 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___230 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___230 *, struct iov_iter___150 *);
	ssize_t (*write_iter)(struct kiocb___230 *, struct iov_iter___150 *);
	int (*iopoll)(struct kiocb___230 *, bool);
	int (*iterate)(struct file___230 *, struct dir_context *);
	int (*iterate_shared)(struct file___230 *, struct dir_context *);
	__poll_t (*poll)(struct file___230 *, struct poll_table_struct___155 *);
	long int (*unlocked_ioctl)(struct file___230 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___230 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___230 *, struct vm_area_struct___235 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___230 *, struct file___230 *);
	int (*flush)(struct file___230 *, fl_owner_t);
	int (*release)(struct inode___230 *, struct file___230 *);
	int (*fsync)(struct file___230 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___230 *, int);
	int (*lock)(struct file___230 *, int, struct file_lock___230 *);
	ssize_t (*sendpage)(struct file___230 *, struct page___235 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___230 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___230 *, long unsigned int);
	int (*flock)(struct file___230 *, int, struct file_lock___230 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___230 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___230 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___230 *, long int, struct file_lock___230 **, void **);
	long int (*fallocate)(struct file___230 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___205 *, struct file___230 *);
	ssize_t (*copy_file_range)(struct file___230 *, loff_t, struct file___230 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___230 *, loff_t, struct file___230 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___230 *, loff_t, loff_t, int);
};

struct vmacache___235 {
	u64 seqnum;
	struct vm_area_struct___235 *vmas[4];
};

struct page_frag___235 {
	struct page___235 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___82;

struct debug_info___82 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___82 *hbp_break[16];
	struct perf_event___82 *hbp_watch[16];
};

struct thread_struct___82 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___82 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___236;

struct pid___207;

struct nsproxy___216;

struct signal_struct___231;

struct bio_list___123;

struct backing_dev_info___112;

struct io_context___123;

struct css_set___160;

struct perf_event_context___82;

struct mem_cgroup___103;

struct request_queue___123;

struct vm_struct___213;

struct task_struct___237 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___237 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___236 *mm;
	struct mm_struct___236 *active_mm;
	struct vmacache___235 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___237 *real_parent;
	struct task_struct___237 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___237 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___207 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___216 *nsproxy;
	struct signal_struct___231 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___237 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___123 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___112 *backing_dev_info;
	struct io_context___123 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___160 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___82 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___235 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___103 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___103 *active_memcg;
	struct request_queue___123 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___237 *oom_reaper_list;
	struct vm_struct___213 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___82 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___215 {
	struct kobject___218 kobj;
	struct module___214 *mod;
	struct kobject___218 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___214 {
	struct module___214 *mod;
	struct latch_tree_node node;
};

struct module_layout___214 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___214 mtn;
};

struct module_attribute___214;

struct kernel_param___214;

struct trace_event_call___76;

struct module___214 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___215 mkobj;
	struct module_attribute___214 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___218 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___214 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___214 core_layout;
	struct module_layout___214 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___76 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___82 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___237 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___82)(struct perf_event___82 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___82;

struct fasync_struct___230;

struct pid_namespace___207;

struct perf_cgroup___82;

struct perf_event___82 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___82 *group_leader;
	struct pmu___82 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___82 hw;
	struct perf_event_context___82 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___82 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___237 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___230 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___82 *aux_event;
	void (*destroy)(struct perf_event___82 *);
	struct callback_head callback_head;
	struct pid_namespace___207 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___82 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___82 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___76 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___82 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct rt_mutex_base___6 {
	raw_spinlock_t wait_lock;
	struct rb_root_cached waiters;
	struct task_struct___237 *owner;
};

struct rt_mutex___5 {
	struct rt_mutex_base___6 rtmutex;
};

typedef struct page___235 *pgtable_t___235;

struct address_space___230;

struct dev_pagemap___225;

struct page___235 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___230 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___235 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___235 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___236 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___225 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___225;

struct vm_area_struct___235 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___235 *vm_next;
	struct vm_area_struct___235 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___236 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___225 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___230 *vm_file;
	struct file___230 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___235;

struct mm_struct___236 {
	struct {
		struct vm_area_struct___235 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___230 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___235 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___237 *owner;
		struct user_namespace___14 *user_ns;
		struct file___230 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___230;

struct address_space___230 {
	struct inode___230 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___230 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___225;

struct dev_pagemap___225 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___225 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___230;

struct path___230 {
	struct vfsmount___230 *mnt;
	struct dentry___230 *dentry;
};

struct fown_struct___207 {
	rwlock_t lock;
	struct pid___207 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___230 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___230 f_path;
	struct inode___230 *f_inode;
	const struct file_operations___231 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___207 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___230 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___225;

struct vm_operations_struct___225 {
	void (*open)(struct vm_area_struct___235 *);
	void (*close)(struct vm_area_struct___235 *);
	int (*may_split)(struct vm_area_struct___235 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___235 *);
	int (*mprotect)(struct vm_area_struct___235 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___225 *);
	vm_fault_t (*huge_fault)(struct vm_fault___225 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___225 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___235 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___225 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___225 *);
	int (*access)(struct vm_area_struct___235 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___235 *);
	int (*set_policy)(struct vm_area_struct___235 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___235 *, long unsigned int);
	struct page___235 * (*find_special_page)(struct vm_area_struct___235 *, long unsigned int);
};

struct core_thread___235 {
	struct task_struct___237 *task;
	struct core_thread___235 *next;
};

struct core_state___235 {
	atomic_t nr_threads;
	struct core_thread___235 dumper;
	struct completion startup;
};

struct vm_fault___225 {
	const struct {
		struct vm_area_struct___235 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___235 *cow_page;
	struct page___235 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___235 prealloc_pte;
};

struct pglist_data___111;

struct lruvec___111 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___111 *pgdat;
};

struct zone___111 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___111 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___111 {
	struct zone___111 *zone;
	int zone_idx;
};

struct zonelist___111 {
	struct zoneref___111 _zonerefs[321];
};

struct pglist_data___111 {
	struct zone___111 node_zones[5];
	struct zonelist___111 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___237 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___237 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___111 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___218;

struct kernfs_elem_dir___218 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___218 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___218;

struct kernfs_root___218 {
	struct kernfs_node___218 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___218 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___218 {
	struct kernfs_node___218 *target_kn;
};

struct kernfs_ops___218;

struct kernfs_elem_attr___218 {
	const struct kernfs_ops___218 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___218 *notify_next;
};

struct kernfs_node___218 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___218 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___218 dir;
		struct kernfs_elem_symlink___218 symlink;
		struct kernfs_elem_attr___218 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___218;

struct kernfs_ops___218 {
	int (*open)(struct kernfs_open_file___218 *);
	void (*release)(struct kernfs_open_file___218 *);
	int (*seq_show)(struct seq_file___205 *, void *);
	void * (*seq_start)(struct seq_file___205 *, loff_t *);
	void * (*seq_next)(struct seq_file___205 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___205 *, void *);
	ssize_t (*read)(struct kernfs_open_file___218 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___218 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___218 *, struct poll_table_struct___155 *);
	int (*mmap)(struct kernfs_open_file___218 *, struct vm_area_struct___235 *);
};

struct kernfs_syscall_ops___218 {
	int (*show_options)(struct seq_file___205 *, struct kernfs_root___218 *);
	int (*mkdir)(struct kernfs_node___218 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___218 *);
	int (*rename)(struct kernfs_node___218 *, struct kernfs_node___218 *, const char *);
	int (*show_path)(struct seq_file___205 *, struct kernfs_node___218 *, struct kernfs_root___218 *);
};

struct seq_operations___205;

struct seq_file___205 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___205 *op;
	int poll_event;
	const struct file___230 *file;
	void *private;
};

struct kernfs_open_file___218 {
	struct kernfs_node___218 *kn;
	struct file___230 *file;
	struct seq_file___205 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___225 *vm_ops;
};

typedef void (*poll_queue_proc___162)(struct file___230 *, wait_queue_head_t *, struct poll_table_struct___155 *);

struct poll_table_struct___155 {
	poll_queue_proc___162 _qproc;
	__poll_t _key;
};

struct upid___207 {
	int nr;
	struct pid_namespace___207 *ns;
};

struct pid_namespace___207 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___237 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___207 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___207 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___207 numbers[1];
};

struct signal_struct___231 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___237 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___237 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___207 *pids[4];
	struct pid___207 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___236 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___160;

struct nsproxy___216 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___207 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___160 *cgroup_ns;
};

struct bio___123;

struct bio_list___123 {
	struct bio___123 *head;
	struct bio___123 *tail;
};

struct cgroup_subsys_state___160;

struct bdi_writeback___112 {
	struct backing_dev_info___112 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___160 *memcg_css;
	struct cgroup_subsys_state___160 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___208;

struct backing_dev_info___112 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___112 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___208 *dev;
	char dev_name[64];
	struct device___208 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___230 *debug_dir;
};

struct io_cq___123;

struct io_context___123 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___123 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___160;

struct css_set___160 {
	struct cgroup_subsys_state___160 *subsys[14];
	refcount_t refcount;
	struct css_set___160 *dom_cset;
	struct cgroup___160 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___160 *mg_src_cgrp;
	struct cgroup___160 *mg_dst_cgrp;
	struct css_set___160 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___82 {
	struct pmu___82 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___237 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___82 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___160;

struct cgroup_subsys_state___160 {
	struct cgroup___160 *cgroup;
	struct cgroup_subsys___160 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___160 *parent;
};

struct cgroup_file___160 {
	struct kernfs_node___218 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___103;

struct mem_cgroup_per_node___103;

struct mem_cgroup___103 {
	struct cgroup_subsys_state___160 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___160 events_file;
	struct cgroup_file___160 events_local_file;
	struct cgroup_file___160 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___103 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___237 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___103 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___123;

struct blk_integrity___123 {
	const struct blk_integrity_profile___123 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___123 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___123 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___123;

struct elevator_queue___123;

struct blk_mq_ops___120;

struct blk_mq_hw_ctx___120;

struct gendisk___126;

struct blkcg_gq___114;

struct blk_mq_tag_set___120;

struct request_queue___123 {
	struct request___123 *last_merge;
	struct elevator_queue___123 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___120 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___120 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___126 *disk;
	struct kobject___218 kobj;
	struct kobject___218 *mq_kobj;
	struct blk_integrity___123 integrity;
	struct device___208 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___114 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___120 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___123 bio_split;
	struct dentry___230 *debugfs_dir;
	struct dentry___230 *sched_debugfs_dir;
	struct dentry___230 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___213 {
	struct vm_struct___213 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___235 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bin_attribute___218;

struct attribute_group___218 {
	const char *name;
	umode_t (*is_visible)(struct kobject___218 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___218 *, struct bin_attribute___218 *, int);
	struct attribute **attrs;
	struct bin_attribute___218 **bin_attrs;
};

struct bin_attribute___218 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___230 * (*f_mapping)();
	ssize_t (*read)(struct file___230 *, struct kobject___218 *, struct bin_attribute___218 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___230 *, struct kobject___218 *, struct bin_attribute___218 *, char *, loff_t, size_t);
	int (*mmap)(struct file___230 *, struct kobject___218 *, struct bin_attribute___218 *, struct vm_area_struct___235 *);
};

struct sysfs_ops___218 {
	ssize_t (*show)(struct kobject___218 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___218 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___218;

struct kset___218 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___218 kobj;
	const struct kset_uevent_ops___218 *uevent_ops;
};

struct kobj_type___218 {
	void (*release)(struct kobject___218 *);
	const struct sysfs_ops___218 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___218 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___218 *);
	const void * (*namespace)(struct kobject___218 *);
	void (*get_ownership)(struct kobject___218 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___218 {
	int (* const filter)(struct kset___218 *, struct kobject___218 *);
	const char * (* const name)(struct kset___218 *, struct kobject___218 *);
	int (* const uevent)(struct kset___218 *, struct kobject___218 *, struct kobj_uevent_env *);
};

struct fwnode_operations___204;

struct fwnode_handle___204 {
	struct fwnode_handle___204 *secondary;
	const struct fwnode_operations___204 *ops;
	struct device___208 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___204;

struct fwnode_endpoint___204;

struct fwnode_operations___204 {
	struct fwnode_handle___204 * (*get)(struct fwnode_handle___204 *);
	void (*put)(struct fwnode_handle___204 *);
	bool (*device_is_available)(const struct fwnode_handle___204 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___204 *, const struct device___208 *);
	bool (*property_present)(const struct fwnode_handle___204 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___204 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___204 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___204 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*get_parent)(const struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*get_next_child_node)(const struct fwnode_handle___204 *, struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*get_named_child_node)(const struct fwnode_handle___204 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___204 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___204 *);
	struct fwnode_handle___204 * (*graph_get_next_endpoint)(const struct fwnode_handle___204 *, struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*graph_get_remote_endpoint)(const struct fwnode_handle___204 *);
	struct fwnode_handle___204 * (*graph_get_port_parent)(struct fwnode_handle___204 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___204 *, struct fwnode_endpoint___204 *);
	int (*add_links)(struct fwnode_handle___204 *);
};

struct wakeup_source___208;

struct pm_subsys_data___12;

struct dev_pm_info___208 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___208 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___208 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___208;

struct bus_type___208;

struct device_driver___208;

struct dev_pm_domain___208;

struct device_node___92;

struct class___208;

struct device___208 {
	struct kobject___218 kobj;
	struct device___208 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___208 *type;
	struct bus_type___208 *bus;
	struct device_driver___208 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___208 power;
	struct dev_pm_domain___208 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___59 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___92 *of_node;
	struct fwnode_handle___204 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___208 *class;
	const struct attribute_group___218 **groups;
	void (*release)(struct device___208 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___204 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___204 *local_fwnode;
};

struct fwnode_reference_args___204 {
	struct fwnode_handle___204 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___69 {
	char *name;
	int length;
	void *value;
	struct property___69 *next;
	long unsigned int _flags;
	struct bin_attribute___218 attr;
};

struct device_node___92 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___204 fwnode;
	struct property___69 *properties;
	struct property___69 *deadprops;
	struct device_node___92 *parent;
	struct device_node___92 *child;
	struct device_node___92 *sibling;
	struct kobject___218 kobj;
	long unsigned int _flags;
	void *data;
};

struct irq_fwspec___57 {
	struct fwnode_handle___204 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___59 {
	int (*match)(struct irq_domain___59 *, struct device_node___92 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___59 *, struct irq_fwspec___57 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___59 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___59 *, unsigned int);
	int (*xlate)(struct irq_domain___59 *, struct device_node___92 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___59 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___59 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___59 *, struct irq_data___61 *, bool);
	void (*deactivate)(struct irq_domain___59 *, struct irq_data___61 *);
	int (*translate)(struct irq_domain___59 *, struct irq_fwspec___57 *, long unsigned int *, unsigned int *);
};

struct irq_domain_chip_generic___59;

struct irq_domain___59 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___59 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___204 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___59 *gc;
	struct irq_domain___59 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___61 *revmap[0];
};

struct irq_chip_generic___59;

struct irq_domain_chip_generic___59 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___59 *gc[0];
};

struct dev_pm_ops___208 {
	int (*prepare)(struct device___208 *);
	void (*complete)(struct device___208 *);
	int (*suspend)(struct device___208 *);
	int (*resume)(struct device___208 *);
	int (*freeze)(struct device___208 *);
	int (*thaw)(struct device___208 *);
	int (*poweroff)(struct device___208 *);
	int (*restore)(struct device___208 *);
	int (*suspend_late)(struct device___208 *);
	int (*resume_early)(struct device___208 *);
	int (*freeze_late)(struct device___208 *);
	int (*thaw_early)(struct device___208 *);
	int (*poweroff_late)(struct device___208 *);
	int (*restore_early)(struct device___208 *);
	int (*suspend_noirq)(struct device___208 *);
	int (*resume_noirq)(struct device___208 *);
	int (*freeze_noirq)(struct device___208 *);
	int (*thaw_noirq)(struct device___208 *);
	int (*poweroff_noirq)(struct device___208 *);
	int (*restore_noirq)(struct device___208 *);
	int (*runtime_suspend)(struct device___208 *);
	int (*runtime_resume)(struct device___208 *);
	int (*runtime_idle)(struct device___208 *);
};

struct pm_domain_data___12;

struct pm_subsys_data___12 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___12 *domain_data;
};

struct pm_domain_data___12 {
	struct list_head list_node;
	struct device___208 *dev;
};

struct wakeup_source___208 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___208 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___208 {
	struct dev_pm_ops___208 ops;
	int (*start)(struct device___208 *);
	void (*detach)(struct device___208 *, bool);
	int (*activate)(struct device___208 *);
	void (*sync)(struct device___208 *);
	void (*dismiss)(struct device___208 *);
};

struct bus_type___208 {
	const char *name;
	const char *dev_name;
	struct device___208 *dev_root;
	const struct attribute_group___218 **bus_groups;
	const struct attribute_group___218 **dev_groups;
	const struct attribute_group___218 **drv_groups;
	int (*match)(struct device___208 *, struct device_driver___208 *);
	int (*uevent)(struct device___208 *, struct kobj_uevent_env *);
	int (*probe)(struct device___208 *);
	void (*sync_state)(struct device___208 *);
	void (*remove)(struct device___208 *);
	void (*shutdown)(struct device___208 *);
	int (*online)(struct device___208 *);
	int (*offline)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	int (*num_vf)(struct device___208 *);
	int (*dma_configure)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___208 {
	const char *name;
	struct bus_type___208 *bus;
	struct module___214 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___208 *);
	void (*sync_state)(struct device___208 *);
	int (*remove)(struct device___208 *);
	void (*shutdown)(struct device___208 *);
	int (*suspend)(struct device___208 *, pm_message_t);
	int (*resume)(struct device___208 *);
	const struct attribute_group___218 **groups;
	const struct attribute_group___218 **dev_groups;
	const struct dev_pm_ops___208 *pm;
	void (*coredump)(struct device___208 *);
	struct driver_private *p;
};

struct device_type___208 {
	const char *name;
	const struct attribute_group___218 **groups;
	int (*uevent)(struct device___208 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___208 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___208 *);
	const struct dev_pm_ops___208 *pm;
};

struct class___208 {
	const char *name;
	struct module___214 *owner;
	const struct attribute_group___218 **class_groups;
	const struct attribute_group___218 **dev_groups;
	struct kobject___218 *dev_kobj;
	int (*dev_uevent)(struct device___208 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___208 *, umode_t *);
	void (*class_release)(struct class___208 *);
	void (*dev_release)(struct device___208 *);
	int (*shutdown_pre)(struct device___208 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___208 *);
	void (*get_ownership)(struct device___208 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___208 *pm;
	struct subsys_private *p;
};

struct device_attribute___39 {
	struct attribute attr;
	ssize_t (*show)(struct device___208 *, struct device_attribute___39 *, char *);
	ssize_t (*store)(struct device___208 *, struct device_attribute___39 *, const char *, size_t);
};

struct dentry_operations___230;

struct dentry___230 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___230 *d_parent;
	struct qstr d_name;
	struct inode___230 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___230 *d_op;
	struct super_block___230 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___230;

struct cdev___62;

struct inode___230 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___230 *i_op;
	struct super_block___230 *i_sb;
	struct address_space___230 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___112 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___231 *i_fop;
		void (*free_inode)(struct inode___230 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___230 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___230 {
	int (*d_revalidate)(struct dentry___230 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___230 *, unsigned int);
	int (*d_hash)(const struct dentry___230 *, struct qstr *);
	int (*d_compare)(const struct dentry___230 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___230 *);
	int (*d_init)(struct dentry___230 *);
	void (*d_release)(struct dentry___230 *);
	void (*d_prune)(struct dentry___230 *);
	void (*d_iput)(struct dentry___230 *, struct inode___230 *);
	char * (*d_dname)(struct dentry___230 *, char *, int);
	struct vfsmount___230 * (*d_automount)(struct path___230 *);
	int (*d_manage)(const struct path___230 *, bool);
	struct dentry___230 * (*d_real)(struct dentry___230 *, const struct inode___230 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___230;

struct mem_dqinfo___230 {
	struct quota_format_type___230 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___230;

struct quota_info___230 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___230 *files[3];
	struct mem_dqinfo___230 info[3];
	const struct quota_format_ops___230 *ops[3];
};

struct rcuwait___231 {
	struct task_struct___237 *task;
};

struct percpu_rw_semaphore___231 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___231 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___230 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___231 rw_sem[3];
};

struct shrink_control___103;

struct shrinker___103 {
	long unsigned int (*count_objects)(struct shrinker___103 *, struct shrink_control___103 *);
	long unsigned int (*scan_objects)(struct shrinker___103 *, struct shrink_control___103 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___230;

struct dquot_operations___230;

struct quotactl_ops___230;

struct block_device___126;

struct super_block___230 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___230 *s_type;
	const struct super_operations___230 *s_op;
	const struct dquot_operations___230 *dq_op;
	const struct quotactl_ops___230 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___230 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___126 *s_bdev;
	struct backing_dev_info___112 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___230 s_dquot;
	struct sb_writers___230 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___230 *s_d_op;
	int cleancache_poolid;
	struct shrinker___103 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___230 {
	struct dentry___230 *mnt_root;
	struct super_block___230 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___103 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___103 *memcg;
};

struct psi_group___160 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___237 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___160;

struct cgroup_rstat_cpu___160;

struct cgroup___160 {
	struct cgroup_subsys_state___160 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___218 *kn;
	struct cgroup_file___160 procs_file;
	struct cgroup_file___160 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___160 *subsys[14];
	struct cgroup_root___160 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___160 *dom_cgrp;
	struct cgroup___160 *old_dom_cgrp;
	struct cgroup_rstat_cpu___160 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___160 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___123 {
	struct request_queue___123 *q;
	struct io_context___123 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___108;

struct kiocb___230 {
	struct file___230 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___230 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___108 *ki_waitq;
	};
};

struct iattr___230 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___230 *ia_file;
};

struct dquot___230 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___230 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___230 {
	int qf_fmt_id;
	const struct quota_format_ops___230 *qf_ops;
	struct module___214 *qf_owner;
	struct quota_format_type___230 *qf_next;
};

struct quota_format_ops___230 {
	int (*check_quota_file)(struct super_block___230 *, int);
	int (*read_file_info)(struct super_block___230 *, int);
	int (*write_file_info)(struct super_block___230 *, int);
	int (*free_file_info)(struct super_block___230 *, int);
	int (*read_dqblk)(struct dquot___230 *);
	int (*commit_dqblk)(struct dquot___230 *);
	int (*release_dqblk)(struct dquot___230 *);
	int (*get_next_id)(struct super_block___230 *, struct kqid *);
};

struct dquot_operations___230 {
	int (*write_dquot)(struct dquot___230 *);
	struct dquot___230 * (*alloc_dquot)(struct super_block___230 *, int);
	void (*destroy_dquot)(struct dquot___230 *);
	int (*acquire_dquot)(struct dquot___230 *);
	int (*release_dquot)(struct dquot___230 *);
	int (*mark_dirty)(struct dquot___230 *);
	int (*write_info)(struct super_block___230 *, int);
	qsize_t * (*get_reserved_space)(struct inode___230 *);
	int (*get_projid)(struct inode___230 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___230 *, qsize_t *);
	int (*get_next_id)(struct super_block___230 *, struct kqid *);
};

struct quotactl_ops___230 {
	int (*quota_on)(struct super_block___230 *, int, int, const struct path___230 *);
	int (*quota_off)(struct super_block___230 *, int);
	int (*quota_enable)(struct super_block___230 *, unsigned int);
	int (*quota_disable)(struct super_block___230 *, unsigned int);
	int (*quota_sync)(struct super_block___230 *, int);
	int (*set_info)(struct super_block___230 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___230 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___230 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___230 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___230 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___230 *, unsigned int);
};

struct wait_page_queue___108 {
	struct page___235 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___112;

struct readahead_control___108;

struct swap_info_struct___66;

struct address_space_operations___230 {
	int (*writepage)(struct page___235 *, struct writeback_control___112 *);
	int (*readpage)(struct file___230 *, struct page___235 *);
	int (*writepages)(struct address_space___230 *, struct writeback_control___112 *);
	int (*set_page_dirty)(struct page___235 *);
	int (*readpages)(struct file___230 *, struct address_space___230 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___108 *);
	int (*write_begin)(struct file___230 *, struct address_space___230 *, loff_t, unsigned int, unsigned int, struct page___235 **, void **);
	int (*write_end)(struct file___230 *, struct address_space___230 *, loff_t, unsigned int, unsigned int, struct page___235 *, void *);
	sector_t (*bmap)(struct address_space___230 *, sector_t);
	void (*invalidatepage)(struct page___235 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___235 *, gfp_t);
	void (*freepage)(struct page___235 *);
	ssize_t (*direct_IO)(struct kiocb___230 *, struct iov_iter___150 *);
	int (*migratepage)(struct address_space___230 *, struct page___235 *, struct page___235 *, enum migrate_mode);
	bool (*isolate_page)(struct page___235 *, isolate_mode_t);
	void (*putback_page)(struct page___235 *);
	int (*launder_page)(struct page___235 *);
	int (*is_partially_uptodate)(struct page___235 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___235 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___230 *, struct page___235 *);
	int (*swap_activate)(struct swap_info_struct___66 *, struct file___230 *, sector_t *);
	void (*swap_deactivate)(struct file___230 *);
};

struct writeback_control___112 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___112 *wb;
	struct inode___230 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___108 {
	struct file___230 *file;
	struct address_space___230 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___147;

struct iov_iter___150 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___147 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___66 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___126 *bdev;
	struct file___230 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct cdev___62 {
	struct kobject___218 kobj;
	struct module___214 *owner;
	const struct file_operations___231 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___230 {
	struct dentry___230 * (*lookup)(struct inode___230 *, struct dentry___230 *, unsigned int);
	const char * (*get_link)(struct dentry___230 *, struct inode___230 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___230 *, int);
	struct posix_acl * (*get_acl)(struct inode___230 *, int, bool);
	int (*readlink)(struct dentry___230 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___230 *, struct dentry___230 *, umode_t, bool);
	int (*link)(struct dentry___230 *, struct inode___230 *, struct dentry___230 *);
	int (*unlink)(struct inode___230 *, struct dentry___230 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___230 *, struct dentry___230 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___230 *, struct dentry___230 *, umode_t);
	int (*rmdir)(struct inode___230 *, struct dentry___230 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___230 *, struct dentry___230 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___230 *, struct dentry___230 *, struct inode___230 *, struct dentry___230 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___230 *, struct iattr___230 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___230 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___230 *, char *, size_t);
	int (*fiemap)(struct inode___230 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___230 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___230 *, struct dentry___230 *, struct file___230 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___230 *, struct dentry___230 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___230 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___230 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___230 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___230 {
	void (*fl_copy_lock)(struct file_lock___230 *, struct file_lock___230 *);
	void (*fl_release_private)(struct file_lock___230 *);
};

struct lock_manager_operations___230;

struct file_lock___230 {
	struct file_lock___230 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___230 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___230 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___230 *fl_ops;
	const struct lock_manager_operations___230 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___230 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___230 *);
	int (*lm_grant)(struct file_lock___230 *, int);
	bool (*lm_break)(struct file_lock___230 *);
	int (*lm_change)(struct file_lock___230 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___230 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___230 *);
};

struct fasync_struct___230 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___230 *fa_next;
	struct file___230 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___230 {
	struct inode___230 * (*alloc_inode)(struct super_block___230 *);
	void (*destroy_inode)(struct inode___230 *);
	void (*free_inode)(struct inode___230 *);
	void (*dirty_inode)(struct inode___230 *, int);
	int (*write_inode)(struct inode___230 *, struct writeback_control___112 *);
	int (*drop_inode)(struct inode___230 *);
	void (*evict_inode)(struct inode___230 *);
	void (*put_super)(struct super_block___230 *);
	int (*sync_fs)(struct super_block___230 *, int);
	int (*freeze_super)(struct super_block___230 *);
	int (*freeze_fs)(struct super_block___230 *);
	int (*thaw_super)(struct super_block___230 *);
	int (*unfreeze_fs)(struct super_block___230 *);
	int (*statfs)(struct dentry___230 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___230 *, int *, char *);
	void (*umount_begin)(struct super_block___230 *);
	int (*show_options)(struct seq_file___205 *, struct dentry___230 *);
	int (*show_devname)(struct seq_file___205 *, struct dentry___230 *);
	int (*show_path)(struct seq_file___205 *, struct dentry___230 *);
	int (*show_stats)(struct seq_file___205 *, struct dentry___230 *);
	ssize_t (*quota_read)(struct super_block___230 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___230 *, int, const char *, size_t, loff_t);
	struct dquot___230 ** (*get_dquots)(struct inode___230 *);
	long int (*nr_cached_objects)(struct super_block___230 *, struct shrink_control___103 *);
	long int (*free_cached_objects)(struct super_block___230 *, struct shrink_control___103 *);
	struct file___230 * (*real_loop)(struct file___230 *);
};

struct block_device___126 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___230 *bd_inode;
	struct super_block___230 *bd_super;
	void *bd_claiming;
	struct device___208 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___218 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___126 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___230 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___123(struct bio___123 *);

struct bio_vec___147 {
	struct page___235 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___123;

struct bio___123 {
	struct bio___123 *bi_next;
	struct block_device___126 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___123 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___114 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___123 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___147 *bi_io_vec;
	struct bio_set___123 *bi_pool;
	struct bio_vec___147 bi_inline_vecs[0];
};

struct kernel_param_ops___214 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___214 *);
	int (*get)(char *, const struct kernel_param___214 *);
	void (*free)(void *);
};

struct kparam_array___214;

struct kernel_param___214 {
	const char *name;
	struct module___214 *mod;
	const struct kernel_param_ops___214 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___214 *arr;
	};
};

struct kparam_array___214 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___214 *ops;
	void *elem;
};

struct module_attribute___214 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___214 *, struct module_kobject___215 *, char *);
	ssize_t (*store)(struct module_attribute___214 *, struct module_kobject___215 *, const char *, size_t);
	void (*setup)(struct module___214 *, const char *);
	int (*test)(struct module___214 *);
	void (*free)(struct module___214 *);
};

struct trace_event_class___76;

struct trace_event_call___76 {
	struct list_head list;
	struct trace_event_class___76 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___42 *prog_array;
	int (*perf_perm)(struct trace_event_call___76 *, struct perf_event___82 *);
};

struct acpi_device___19;

struct acpi_hotplug_profile___19 {
	struct kobject___218 kobj;
	int (*scan_dependent)(struct acpi_device___19 *);
	void (*notify_online)(struct acpi_device___19 *);
	bool enabled: 1;
	bool demand_offline: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___19 {
	void (*func)(struct acpi_device_wakeup_context___19 *);
	struct device___208 *dev;
};

struct acpi_device_wakeup___19 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___19 context;
	struct wakeup_source___208 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___19;

struct acpi_hotplug_context___19;

struct acpi_driver___19;

struct acpi_device___19 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___204 fwnode;
	struct acpi_device___19 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___19 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___19 *handler;
	struct acpi_hotplug_context___19 *hp;
	struct acpi_driver___19 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___208 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___19 *);
};

struct acpi_scan_handler___19 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___19 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___19 *);
	void (*bind)(struct device___208 *);
	void (*unbind)(struct device___208 *);
	struct acpi_hotplug_profile___19 hotplug;
};

struct acpi_hotplug_context___19 {
	struct acpi_device___19 *self;
	int (*notify)(struct acpi_device___19 *, u32);
	void (*uevent)(struct acpi_device___19 *, u32);
	void (*fixup)(struct acpi_device___19 *);
};

typedef int (*acpi_op_add___19)(struct acpi_device___19 *);

typedef int (*acpi_op_remove___19)(struct acpi_device___19 *);

typedef void (*acpi_op_notify___19)(struct acpi_device___19 *, u32);

struct acpi_device_ops___19 {
	acpi_op_add___19 add;
	acpi_op_remove___19 remove;
	acpi_op_notify___19 notify;
};

struct acpi_driver___19 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___19 ops;
	struct device_driver___208 drv;
	struct module___214 *owner;
};

struct irq_chip___61 {
	struct device___208 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___61 *);
	void (*irq_shutdown)(struct irq_data___61 *);
	void (*irq_enable)(struct irq_data___61 *);
	void (*irq_disable)(struct irq_data___61 *);
	void (*irq_ack)(struct irq_data___61 *);
	void (*irq_mask)(struct irq_data___61 *);
	void (*irq_mask_ack)(struct irq_data___61 *);
	void (*irq_unmask)(struct irq_data___61 *);
	void (*irq_eoi)(struct irq_data___61 *);
	int (*irq_set_affinity)(struct irq_data___61 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___61 *);
	int (*irq_set_type)(struct irq_data___61 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___61 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___61 *);
	void (*irq_bus_sync_unlock)(struct irq_data___61 *);
	void (*irq_cpu_online)(struct irq_data___61 *);
	void (*irq_cpu_offline)(struct irq_data___61 *);
	void (*irq_suspend)(struct irq_data___61 *);
	void (*irq_resume)(struct irq_data___61 *);
	void (*irq_pm_shutdown)(struct irq_data___61 *);
	void (*irq_calc_mask)(struct irq_data___61 *);
	void (*irq_print_chip)(struct irq_data___61 *, struct seq_file___205 *);
	int (*irq_request_resources)(struct irq_data___61 *);
	void (*irq_release_resources)(struct irq_data___61 *);
	void (*irq_compose_msi_msg)(struct irq_data___61 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___61 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___61 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___61 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___61 *, void *);
	void (*ipi_send_single)(struct irq_data___61 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___61 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___61 *);
	void (*irq_nmi_teardown)(struct irq_data___61 *);
	long unsigned int flags;
};

struct irqaction___43 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___43 *next;
	irq_handler_t thread_fn;
	struct task_struct___237 *thread;
	struct irqaction___43 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___59 {
	struct irq_chip___61 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___61 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___59 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___59 *);
	void (*resume)(struct irq_chip_generic___59 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___59 *domain;
	struct list_head list;
	struct irq_chip_type___59 chip_types[0];
};

struct seq_operations___205 {
	void * (*start)(struct seq_file___205 *, loff_t *);
	void (*stop)(struct seq_file___205 *, void *);
	void * (*next)(struct seq_file___205 *, void *, loff_t *);
	int (*show)(struct seq_file___205 *, void *);
};

struct dev_pagemap_ops___225 {
	void (*page_free)(struct page___235 *);
	void (*kill)(struct dev_pagemap___225 *);
	void (*cleanup)(struct dev_pagemap___225 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___225 *);
};

struct cgroup_namespace___160 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___160 *root_cset;
};

struct cftype___160;

struct cgroup_subsys___160 {
	struct cgroup_subsys_state___160 * (*css_alloc)(struct cgroup_subsys_state___160 *);
	int (*css_online)(struct cgroup_subsys_state___160 *);
	void (*css_offline)(struct cgroup_subsys_state___160 *);
	void (*css_released)(struct cgroup_subsys_state___160 *);
	void (*css_free)(struct cgroup_subsys_state___160 *);
	void (*css_reset)(struct cgroup_subsys_state___160 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___160 *, int);
	int (*css_extra_stat_show)(struct seq_file___205 *, struct cgroup_subsys_state___160 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___237 *, struct css_set___160 *);
	void (*cancel_fork)(struct task_struct___237 *, struct css_set___160 *);
	void (*fork)(struct task_struct___237 *);
	void (*exit)(struct task_struct___237 *);
	void (*release)(struct task_struct___237 *);
	void (*bind)(struct cgroup_subsys_state___160 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___160 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___160 *dfl_cftypes;
	struct cftype___160 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___160 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___160 *updated_children;
	struct cgroup___160 *updated_next;
};

struct cgroup_root___160 {
	struct kernfs_root___218 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___160 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___160 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___160 *ss;
	struct list_head node;
	struct kernfs_ops___218 *kf_ops;
	int (*open)(struct kernfs_open_file___218 *);
	void (*release)(struct kernfs_open_file___218 *);
	u64 (*read_u64)(struct cgroup_subsys_state___160 *, struct cftype___160 *);
	s64 (*read_s64)(struct cgroup_subsys_state___160 *, struct cftype___160 *);
	int (*seq_show)(struct seq_file___205 *, void *);
	void * (*seq_start)(struct seq_file___205 *, loff_t *);
	void * (*seq_next)(struct seq_file___205 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___205 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___160 *, struct cftype___160 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___160 *, struct cftype___160 *, s64);
	ssize_t (*write)(struct kernfs_open_file___218 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___218 *, struct poll_table_struct___155 *);
};

struct block_device_operations___123;

struct gendisk___126 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___126 *part0;
	const struct block_device_operations___123 *fops;
	struct request_queue___123 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___112 *bdi;
	struct kobject___218 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___218 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___123 {
	struct bio___123 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___147 *bip_vec;
	struct bio_vec___147 bip_inline_vecs[0];
};

struct blkcg___114;

struct blkg_policy_data___114;

struct blkcg_gq___114 {
	struct request_queue___123 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___114 *blkcg;
	struct blkcg_gq___114 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___114 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___123 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___123(struct request___123 *);

typedef void integrity_complete_fn___123(struct request___123 *, unsigned int);

struct blk_integrity_profile___123 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___123 *prepare_fn;
	integrity_complete_fn___123 *complete_fn;
	const char *name;
};

struct block_device_operations___123 {
	blk_qc_t (*submit_bio)(struct bio___123 *);
	int (*open)(struct block_device___126 *, fmode_t);
	void (*release)(struct gendisk___126 *, fmode_t);
	int (*rw_page)(struct block_device___126 *, sector_t, struct page___235 *, unsigned int);
	int (*ioctl)(struct block_device___126 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___126 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___126 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___126 *);
	int (*getgeo)(struct block_device___126 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___126 *, bool);
	void (*swap_slot_free_notify)(struct block_device___126 *, long unsigned int);
	int (*report_zones)(struct gendisk___126 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___126 *, umode_t *);
	struct module___214 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___126 *, sector_t *);
};

typedef void rq_end_io_fn___123(struct request___123 *, blk_status_t);

struct request___123 {
	struct request_queue___123 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___120 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___123 *bio;
	struct bio___123 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___147 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___123 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___123 *saved_end_io;
		} flush;
	};
	struct gendisk___126 *rq_disk;
	struct block_device___126 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___123 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___120 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___123 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___218 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___230 *debugfs_dir;
	struct dentry___230 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___123;

struct elevator_mq_ops___123 {
	int (*init_sched)(struct request_queue___123 *, struct elevator_type___123 *);
	void (*exit_sched)(struct elevator_queue___123 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___120 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___120 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___120 *);
	bool (*allow_merge)(struct request_queue___123 *, struct request___123 *, struct bio___123 *);
	bool (*bio_merge)(struct request_queue___123 *, struct bio___123 *, unsigned int);
	int (*request_merge)(struct request_queue___123 *, struct request___123 **, struct bio___123 *);
	void (*request_merged)(struct request_queue___123 *, struct request___123 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___123 *, struct request___123 *, struct request___123 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___123 *);
	void (*finish_request)(struct request___123 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___120 *, struct list_head *, bool);
	struct request___123 * (*dispatch_request)(struct blk_mq_hw_ctx___120 *);
	bool (*has_work)(struct blk_mq_hw_ctx___120 *);
	void (*completed_request)(struct request___123 *, u64);
	void (*requeue_request)(struct request___123 *);
	struct request___123 * (*former_request)(struct request_queue___123 *, struct request___123 *);
	struct request___123 * (*next_request)(struct request_queue___123 *, struct request___123 *);
	void (*init_icq)(struct io_cq___123 *);
	void (*exit_icq)(struct io_cq___123 *);
};

struct elv_fs_entry___123;

struct elevator_type___123 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___123 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___123 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___214 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___123 {
	struct elevator_type___123 *type;
	void *elevator_data;
	struct kobject___218 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___123 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___123 *, char *);
	ssize_t (*store)(struct elevator_queue___123 *, const char *, size_t);
};

struct blk_mq_queue_data___120;

struct blk_mq_ops___120 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___120 *, const struct blk_mq_queue_data___120 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___120 *);
	int (*get_budget)(struct request_queue___123 *);
	void (*put_budget)(struct request_queue___123 *, int);
	void (*set_rq_budget_token)(struct request___123 *, int);
	int (*get_rq_budget_token)(struct request___123 *);
	enum blk_eh_timer_return (*timeout)(struct request___123 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___120 *);
	void (*complete)(struct request___123 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___120 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___120 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___120 *, struct request___123 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___120 *, struct request___123 *, unsigned int);
	void (*initialize_rq_fn)(struct request___123 *);
	void (*cleanup_rq)(struct request___123 *);
	bool (*busy)(struct request_queue___123 *);
	int (*map_queues)(struct blk_mq_tag_set___120 *);
	void (*show_rq)(struct seq_file___205 *, struct request___123 *);
};

struct blk_mq_tag_set___120 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___120 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___120 {
	struct request___123 *rq;
	bool last;
};

struct blkcg_policy_data___114;

struct blkcg___114 {
	struct cgroup_subsys_state___160 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___114 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___114 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___114 {
	struct blkcg___114 *blkcg;
	int plid;
};

struct blkg_policy_data___114 {
	struct blkcg_gq___114 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___103 {
	struct mem_cgroup___103 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___103 {
	struct lruvec___111 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___103 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___103 *memcg;
};

struct obj_cgroup___103 {
	struct percpu_ref refcnt;
	struct mem_cgroup___103 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct i2c_client___4;

typedef int (*i2c_slave_cb_t___3)(struct i2c_client___4 *, enum i2c_slave_event, u8 *);

struct i2c_adapter___3;

struct i2c_client___4 {
	short unsigned int flags;
	short unsigned int addr;
	char name[20];
	struct i2c_adapter___3 *adapter;
	struct device___208 dev;
	int init_irq;
	int irq;
	struct list_head detected;
	i2c_slave_cb_t___3 slave_cb;
	void *devres_group_id;
};

struct i2c_device_identity {
	u16 manufacturer_id;
	u16 part_id;
	u8 die_revision;
};

struct i2c_board_info___3;

struct i2c_driver___3 {
	unsigned int class;
	int (*probe)(struct i2c_client___4 *, const struct i2c_device_id *);
	int (*remove)(struct i2c_client___4 *);
	int (*probe_new)(struct i2c_client___4 *);
	void (*shutdown)(struct i2c_client___4 *);
	void (*alert)(struct i2c_client___4 *, enum i2c_alert_protocol, unsigned int);
	int (*command)(struct i2c_client___4 *, unsigned int, void *);
	struct device_driver___208 driver;
	const struct i2c_device_id *id_table;
	int (*detect)(struct i2c_client___4 *, struct i2c_board_info___3 *);
	const short unsigned int *address_list;
	struct list_head clients;
};

struct i2c_board_info___3 {
	char type[20];
	short unsigned int flags;
	short unsigned int addr;
	const char *dev_name;
	void *platform_data;
	struct device_node___92 *of_node;
	struct fwnode_handle___204 *fwnode;
	const struct software_node *swnode;
	const struct resource *resources;
	unsigned int num_resources;
	int irq;
};

struct i2c_algorithm___3;

struct i2c_lock_operations___3;

struct i2c_bus_recovery_info___3;

struct i2c_adapter___3 {
	struct module___214 *owner;
	unsigned int class;
	const struct i2c_algorithm___3 *algo;
	void *algo_data;
	const struct i2c_lock_operations___3 *lock_ops;
	struct rt_mutex___5 bus_lock;
	struct rt_mutex___5 mux_lock;
	int timeout;
	int retries;
	struct device___208 dev;
	long unsigned int locked_flags;
	int nr;
	char name[48];
	struct completion dev_released;
	struct mutex userspace_clients_lock;
	struct list_head userspace_clients;
	struct i2c_bus_recovery_info___3 *bus_recovery_info;
	const struct i2c_adapter_quirks *quirks;
	struct irq_domain___59 *host_notify_domain;
	struct regulator *bus_regulator;
};

struct i2c_algorithm___3 {
	int (*master_xfer)(struct i2c_adapter___3 *, struct i2c_msg *, int);
	int (*master_xfer_atomic)(struct i2c_adapter___3 *, struct i2c_msg *, int);
	int (*smbus_xfer)(struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	int (*smbus_xfer_atomic)(struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int, union i2c_smbus_data *);
	u32 (*functionality)(struct i2c_adapter___3 *);
	int (*reg_slave)(struct i2c_client___4 *);
	int (*unreg_slave)(struct i2c_client___4 *);
};

struct i2c_lock_operations___3 {
	void (*lock_bus)(struct i2c_adapter___3 *, unsigned int);
	int (*trylock_bus)(struct i2c_adapter___3 *, unsigned int);
	void (*unlock_bus)(struct i2c_adapter___3 *, unsigned int);
};

struct i2c_timings {
	u32 bus_freq_hz;
	u32 scl_rise_ns;
	u32 scl_fall_ns;
	u32 scl_int_delay_ns;
	u32 sda_fall_ns;
	u32 sda_hold_ns;
	u32 digital_filter_width_ns;
	u32 analog_filter_cutoff_freq_hz;
};

struct i2c_bus_recovery_info___3 {
	int (*recover_bus)(struct i2c_adapter___3 *);
	int (*get_scl)(struct i2c_adapter___3 *);
	void (*set_scl)(struct i2c_adapter___3 *, int);
	int (*get_sda)(struct i2c_adapter___3 *);
	void (*set_sda)(struct i2c_adapter___3 *, int);
	int (*get_bus_free)(struct i2c_adapter___3 *);
	void (*prepare_recovery)(struct i2c_adapter___3 *);
	void (*unprepare_recovery)(struct i2c_adapter___3 *);
	struct gpio_desc *scl_gpiod;
	struct gpio_desc *sda_gpiod;
	struct pinctrl___3 *pinctrl;
	struct pinctrl_state *pins_default;
	struct pinctrl_state *pins_gpio;
};

struct i2c_devinfo___2 {
	struct list_head list;
	int busnum;
	struct i2c_board_info___3 board_info;
};

struct perf_cpu_context___82;

struct perf_output_handle___82;

struct pmu___82 {
	struct list_head entry;
	struct module___214 *module;
	struct device___208 *dev;
	const struct attribute_group___218 **attr_groups;
	const struct attribute_group___218 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___82 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___82 *);
	void (*pmu_disable)(struct pmu___82 *);
	int (*event_init)(struct perf_event___82 *);
	void (*event_mapped)(struct perf_event___82 *, struct mm_struct___236 *);
	void (*event_unmapped)(struct perf_event___82 *, struct mm_struct___236 *);
	int (*add)(struct perf_event___82 *, int);
	void (*del)(struct perf_event___82 *, int);
	void (*start)(struct perf_event___82 *, int);
	void (*stop)(struct perf_event___82 *, int);
	void (*read)(struct perf_event___82 *);
	void (*start_txn)(struct pmu___82 *, unsigned int);
	int (*commit_txn)(struct pmu___82 *);
	void (*cancel_txn)(struct pmu___82 *);
	int (*event_idx)(struct perf_event___82 *);
	void (*sched_task)(struct perf_event_context___82 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___82 *, struct perf_event_context___82 *);
	void * (*setup_aux)(struct perf_event___82 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___82 *, struct perf_output_handle___82 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___82 *);
	int (*aux_output_match)(struct perf_event___82 *);
	int (*filter_match)(struct perf_event___82 *);
	int (*check_period)(struct perf_event___82 *, u64);
};

struct perf_cpu_context___82 {
	struct perf_event_context___82 ctx;
	struct perf_event_context___82 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___82 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___82 **heap;
	struct perf_event___82 *heap_default[2];
};

struct perf_output_handle___82 {
	struct perf_event___82 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___82 {
	struct cgroup_subsys_state___160 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___76 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___76 *);
	};
};

struct trace_event_class___76 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___76 *, enum trace_reg, void *);
	struct trace_event_fields___76 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___76 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___76 *);
};

struct trace_event_file___36;

struct trace_event_buffer___35 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___36 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___36 {
	struct list_head list;
	struct trace_event_call___76 *event_call;
	struct event_filter *filter;
	struct dentry___230 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_i2c_write {
	struct trace_entry ent;
	int adapter_nr;
	__u16 msg_nr;
	__u16 addr;
	__u16 flags;
	__u16 len;
	u32 __data_loc_buf;
	char __data[0];
};

struct trace_event_raw_i2c_read {
	struct trace_entry ent;
	int adapter_nr;
	__u16 msg_nr;
	__u16 addr;
	__u16 flags;
	__u16 len;
	char __data[0];
};

struct trace_event_raw_i2c_reply {
	struct trace_entry ent;
	int adapter_nr;
	__u16 msg_nr;
	__u16 addr;
	__u16 flags;
	__u16 len;
	u32 __data_loc_buf;
	char __data[0];
};

struct trace_event_raw_i2c_result {
	struct trace_entry ent;
	int adapter_nr;
	__u16 nr_msgs;
	__s16 ret;
	char __data[0];
};

struct trace_event_data_offsets_i2c_write {
	u32 buf;
};

struct trace_event_data_offsets_i2c_read {};

struct trace_event_data_offsets_i2c_reply {
	u32 buf;
};

struct trace_event_data_offsets_i2c_result {};

typedef void (*btf_trace_i2c_write)(void *, const struct i2c_adapter___3 *, const struct i2c_msg *, int);

typedef void (*btf_trace_i2c_read)(void *, const struct i2c_adapter___3 *, const struct i2c_msg *, int);

typedef void (*btf_trace_i2c_reply)(void *, const struct i2c_adapter___3 *, const struct i2c_msg *, int);

typedef void (*btf_trace_i2c_result)(void *, const struct i2c_adapter___3 *, int, int);

struct class_compat___2;

struct i2c_cmd_arg {
	unsigned int cmd;
	void *arg;
};

struct i2c_smbus_alert_setup {
	int irq;
};

struct trace_event_raw_smbus_write {
	struct trace_entry ent;
	int adapter_nr;
	__u16 addr;
	__u16 flags;
	__u8 command;
	__u8 len;
	__u32 protocol;
	__u8 buf[34];
	char __data[0];
};

struct trace_event_raw_smbus_read {
	struct trace_entry ent;
	int adapter_nr;
	__u16 flags;
	__u16 addr;
	__u8 command;
	__u32 protocol;
	__u8 buf[34];
	char __data[0];
};

struct trace_event_raw_smbus_reply {
	struct trace_entry ent;
	int adapter_nr;
	__u16 addr;
	__u16 flags;
	__u8 command;
	__u8 len;
	__u32 protocol;
	__u8 buf[34];
	char __data[0];
};

struct trace_event_raw_smbus_result {
	struct trace_entry ent;
	int adapter_nr;
	__u16 addr;
	__u16 flags;
	__u8 read_write;
	__u8 command;
	__s16 res;
	__u32 protocol;
	char __data[0];
};

struct trace_event_data_offsets_smbus_write {};

struct trace_event_data_offsets_smbus_read {};

struct trace_event_data_offsets_smbus_reply {};

struct trace_event_data_offsets_smbus_result {};

typedef void (*btf_trace_smbus_write)(void *, const struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int, const union i2c_smbus_data *);

typedef void (*btf_trace_smbus_read)(void *, const struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int);

typedef void (*btf_trace_smbus_reply)(void *, const struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int, const union i2c_smbus_data *, int);

typedef void (*btf_trace_smbus_result)(void *, const struct i2c_adapter___3 *, u16, short unsigned int, char, u8, int, int);

struct i2c_acpi_handler_data {
	struct acpi_connection_info info;
	struct i2c_adapter___3 *adapter;
};

struct gsb_buffer {
	u8 status;
	u8 len;
	union {
		u16 wdata;
		u8 bdata;
		u8 data[0];
	};
};

struct i2c_acpi_lookup {
	struct i2c_board_info___3 *info;
	acpi_handle adapter_handle;
	acpi_handle device_handle;
	acpi_handle search_handle;
	int n;
	int index;
	u32 speed;
	u32 min_speed;
	u32 force_speed;
};

struct of_reconfig_data___3 {
	struct device_node___92 *dn;
	struct property___69 *prop;
	struct property___69 *old_prop;
};

struct i2c_smbus_ioctl_data {
	__u8 read_write;
	__u8 command;
	__u32 size;
	union i2c_smbus_data *data;
};

struct i2c_rdwr_ioctl_data {
	struct i2c_msg *msgs;
	__u32 nmsgs;
};

struct i2c_dev {
	struct list_head list;
	struct i2c_adapter___3 *adap;
	struct device___208 dev;
	struct cdev___62 cdev;
};

struct i2c_smbus_ioctl_data32 {
	u8 read_write;
	u8 command;
	u32 size;
	compat_caddr_t data;
};

struct i2c_msg32 {
	u16 addr;
	u16 flags;
	u16 len;
	compat_caddr_t buf;
};

struct i2c_rdwr_ioctl_data32 {
	compat_caddr_t msgs;
	u32 nmsgs;
};

struct dw_i2c_dev {
	struct device___208 *dev;
	struct regmap *map;
	struct regmap *sysmap;
	void *base;
	void *ext;
	struct completion cmd_complete;
	struct clk *clk;
	struct clk *pclk;
	struct reset_control *rst;
	struct i2c_client___4 *slave;
	u32 (*get_clk_rate_khz)(struct dw_i2c_dev *);
	int cmd_err;
	struct i2c_msg *msgs;
	int msgs_num;
	int msg_write_idx;
	u32 tx_buf_len;
	u8 *tx_buf;
	int msg_read_idx;
	u32 rx_buf_len;
	u8 *rx_buf;
	int msg_err;
	unsigned int status;
	u32 abort_source;
	int irq;
	u32 flags;
	struct i2c_adapter___3 adapter;
	u32 functionality;
	u32 master_cfg;
	u32 slave_cfg;
	unsigned int tx_fifo_depth;
	unsigned int rx_fifo_depth;
	int rx_outstanding;
	struct i2c_timings timings;
	u32 sda_hold_time;
	u16 ss_hcnt;
	u16 ss_lcnt;
	u16 fs_hcnt;
	u16 fs_lcnt;
	u16 fp_hcnt;
	u16 fp_lcnt;
	u16 hs_hcnt;
	u16 hs_lcnt;
	int (*acquire_lock)();
	void (*release_lock)();
	bool shared_with_punit;
	void (*disable)(struct dw_i2c_dev *);
	void (*disable_int)(struct dw_i2c_dev *);
	int (*init)(struct dw_i2c_dev *);
	int (*set_sda_hold_time)(struct dw_i2c_dev *);
	int mode;
	struct i2c_bus_recovery_info___3 rinfo;
	bool suspended;
};

struct dw_i2c_dev___2 {
	struct device___15 *dev;
	struct regmap *map;
	struct regmap *sysmap;
	void *base;
	void *ext;
	struct completion cmd_complete;
	struct clk *clk;
	struct clk *pclk;
	struct reset_control *rst;
	struct i2c_client___2 *slave;
	u32 (*get_clk_rate_khz)(struct dw_i2c_dev___2 *);
	int cmd_err;
	struct i2c_msg *msgs;
	int msgs_num;
	int msg_write_idx;
	u32 tx_buf_len;
	u8 *tx_buf;
	int msg_read_idx;
	u32 rx_buf_len;
	u8 *rx_buf;
	int msg_err;
	unsigned int status;
	u32 abort_source;
	int irq;
	u32 flags;
	struct i2c_adapter adapter;
	u32 functionality;
	u32 master_cfg;
	u32 slave_cfg;
	unsigned int tx_fifo_depth;
	unsigned int rx_fifo_depth;
	int rx_outstanding;
	struct i2c_timings timings;
	u32 sda_hold_time;
	u16 ss_hcnt;
	u16 ss_lcnt;
	u16 fs_hcnt;
	u16 fs_lcnt;
	u16 fp_hcnt;
	u16 fp_lcnt;
	u16 hs_hcnt;
	u16 hs_lcnt;
	int (*acquire_lock)();
	void (*release_lock)();
	bool shared_with_punit;
	void (*disable)(struct dw_i2c_dev___2 *);
	void (*disable_int)(struct dw_i2c_dev___2 *);
	int (*init)(struct dw_i2c_dev___2 *);
	int (*set_sda_hold_time)(struct dw_i2c_dev___2 *);
	int mode;
	struct i2c_bus_recovery_info rinfo;
	bool suspended;
};

struct omap_i2c_bus_platform_data {
	u32 clkrate;
	u32 rev;
	u32 flags;
	void (*set_mpu_wkup_lat)(struct device___208 *, long int);
};

enum {
	OMAP_I2C_REV_REG = 0,
	OMAP_I2C_IE_REG = 1,
	OMAP_I2C_STAT_REG = 2,
	OMAP_I2C_IV_REG = 3,
	OMAP_I2C_WE_REG = 4,
	OMAP_I2C_SYSS_REG = 5,
	OMAP_I2C_BUF_REG = 6,
	OMAP_I2C_CNT_REG = 7,
	OMAP_I2C_DATA_REG = 8,
	OMAP_I2C_SYSC_REG = 9,
	OMAP_I2C_CON_REG = 10,
	OMAP_I2C_OA_REG = 11,
	OMAP_I2C_SA_REG = 12,
	OMAP_I2C_PSC_REG = 13,
	OMAP_I2C_SCLL_REG = 14,
	OMAP_I2C_SCLH_REG = 15,
	OMAP_I2C_SYSTEST_REG = 16,
	OMAP_I2C_BUFSTAT_REG = 17,
	OMAP_I2C_IP_V2_REVNB_LO = 18,
	OMAP_I2C_IP_V2_REVNB_HI = 19,
	OMAP_I2C_IP_V2_IRQSTATUS_RAW = 20,
	OMAP_I2C_IP_V2_IRQENABLE_SET = 21,
	OMAP_I2C_IP_V2_IRQENABLE_CLR = 22,
};

struct omap_i2c_dev {
	struct device___208 *dev;
	void *base;
	int irq;
	int reg_shift;
	struct completion cmd_complete;
	struct resource *ioarea;
	u32 latency;
	void (*set_mpu_wkup_lat)(struct device___208 *, long int);
	u32 speed;
	u32 flags;
	u16 scheme;
	u16 cmd_err;
	u8 *buf;
	u8 *regs;
	size_t buf_len;
	struct i2c_adapter___3 adapter;
	u8 threshold;
	u8 fifo_size;
	u32 rev;
	unsigned int b_hw: 1;
	unsigned int bb_valid: 1;
	unsigned int receiver: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 iestate;
	u16 pscstate;
	u16 scllstate;
	u16 sclhstate;
	u16 syscstate;
	u16 westate;
	u16 errata;
};

struct sprd_i2c {
	struct i2c_adapter___3 adap;
	struct device___208 *dev;
	void *base;
	struct i2c_msg *msg;
	struct clk *clk;
	u32 src_clk;
	u32 bus_freq;
	struct completion complete;
	u8 *buf;
	u32 count;
	int irq;
	int err;
};

typedef struct poll_table_struct___155 poll_table___44;

struct pps_ktime {
	__s64 sec;
	__s32 nsec;
	__u32 flags;
};

struct pps_ktime_compat {
	__s64 sec;
	__s32 nsec;
	__u32 flags;
};

struct pps_kinfo {
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
};

struct pps_kinfo_compat {
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime_compat assert_tu;
	struct pps_ktime_compat clear_tu;
	int current_mode;
} __attribute__((packed));

struct pps_kparams {
	int api_version;
	int mode;
	struct pps_ktime assert_off_tu;
	struct pps_ktime clear_off_tu;
};

struct pps_fdata {
	struct pps_kinfo info;
	struct pps_ktime timeout;
};

struct pps_fdata_compat {
	struct pps_kinfo_compat info;
	struct pps_ktime_compat timeout;
} __attribute__((packed));

struct pps_bind_args {
	int tsformat;
	int edge;
	int consumer;
};

struct pps_device;

struct pps_source_info {
	char name[32];
	char path[32];
	int mode;
	void (*echo)(struct pps_device *, int, void *);
	struct module___214 *owner;
	struct device___208 *dev;
};

struct pps_device {
	struct pps_source_info info;
	struct pps_kparams params;
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
	unsigned int last_ev;
	wait_queue_head_t queue;
	unsigned int id;
	const void *lookup_cookie;
	struct cdev___62 cdev;
	struct device___208 *dev;
	struct fasync_struct___230 *async_queue;
	spinlock_t lock;
};

struct pps_device___2;

struct pps_source_info___2 {
	char name[32];
	char path[32];
	int mode;
	void (*echo)(struct pps_device___2 *, int, void *);
	struct module___200 *owner;
	struct device___194 *dev;
};

struct pps_device___2 {
	struct pps_source_info___2 info;
	struct pps_kparams params;
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
	unsigned int last_ev;
	wait_queue_head_t queue;
	unsigned int id;
	const void *lookup_cookie;
	struct cdev___54 cdev;
	struct device___194 *dev;
	struct fasync_struct___216 *async_queue;
	spinlock_t lock;
};

struct device_attribute___40 {
	struct attribute attr;
	ssize_t (*show)(struct device___48 *, struct device_attribute___40 *, char *);
	ssize_t (*store)(struct device___48 *, struct device_attribute___40 *, const char *, size_t);
};

typedef struct poll_table_struct___39 poll_table___45;

struct posix_clock___2;

struct posix_clock_operations___2 {
	struct module___53 *owner;
	int (*clock_adjtime)(struct posix_clock___2 *, struct __kernel_timex *);
	int (*clock_gettime)(struct posix_clock___2 *, struct timespec64 *);
	int (*clock_getres)(struct posix_clock___2 *, struct timespec64 *);
	int (*clock_settime)(struct posix_clock___2 *, const struct timespec64 *);
	long int (*ioctl)(struct posix_clock___2 *, unsigned int, long unsigned int);
	int (*open)(struct posix_clock___2 *, fmode_t);
	__poll_t (*poll)(struct posix_clock___2 *, struct file___54 *, poll_table___45 *);
	int (*release)(struct posix_clock___2 *);
	ssize_t (*read)(struct posix_clock___2 *, uint, char *, size_t);
};

struct posix_clock___2 {
	struct posix_clock_operations___2 ops;
	struct cdev___19 cdev;
	struct device___48 *dev;
	struct rw_semaphore rwsem;
	bool zombie;
};

struct pps_device___3;

struct pps_source_info___3 {
	char name[32];
	char path[32];
	int mode;
	void (*echo)(struct pps_device___3 *, int, void *);
	struct module___53 *owner;
	struct device___48 *dev;
};

struct pps_device___3 {
	struct pps_source_info___3 info;
	struct pps_kparams params;
	__u32 assert_sequence;
	__u32 clear_sequence;
	struct pps_ktime assert_tu;
	struct pps_ktime clear_tu;
	int current_mode;
	unsigned int last_ev;
	wait_queue_head_t queue;
	unsigned int id;
	const void *lookup_cookie;
	struct cdev___19 cdev;
	struct device___48 *dev;
	struct fasync_struct___53 *async_queue;
	spinlock_t lock;
};

struct kthread_work___7;

typedef void (*kthread_work_func_t___7)(struct kthread_work___7 *);

struct kthread_worker___7;

struct kthread_work___7 {
	struct list_head node;
	kthread_work_func_t___7 func;
	struct kthread_worker___7 *worker;
	int canceling;
};

struct kthread_worker___7 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___59 *task;
	struct kthread_work___7 *current_work;
};

struct kthread_delayed_work___2 {
	struct kthread_work___7 work;
	struct timer_list timer;
};

struct ptp_extts_event {
	struct ptp_clock_time t;
	unsigned int index;
	unsigned int flags;
	unsigned int rsv[2];
};

struct ptp_clock_info___3 {
	struct module___53 *owner;
	char name[32];
	s32 max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int n_pins;
	int pps;
	struct ptp_pin_desc *pin_config;
	int (*adjfine)(struct ptp_clock_info___3 *, long int);
	int (*adjfreq)(struct ptp_clock_info___3 *, s32);
	int (*adjphase)(struct ptp_clock_info___3 *, s32);
	int (*adjtime)(struct ptp_clock_info___3 *, s64);
	int (*gettime64)(struct ptp_clock_info___3 *, struct timespec64 *);
	int (*gettimex64)(struct ptp_clock_info___3 *, struct timespec64 *, struct ptp_system_timestamp *);
	int (*getcrosststamp)(struct ptp_clock_info___3 *, struct system_device_crosststamp *);
	int (*settime64)(struct ptp_clock_info___3 *, const struct timespec64 *);
	int (*enable)(struct ptp_clock_info___3 *, struct ptp_clock_request *, int);
	int (*verify)(struct ptp_clock_info___3 *, unsigned int, enum ptp_pin_function, unsigned int);
	long int (*do_aux_work)(struct ptp_clock_info___3 *);
};

struct timestamp_event_queue {
	struct ptp_extts_event buf[128];
	int head;
	int tail;
	spinlock_t lock;
};

struct ptp_clock___2 {
	struct posix_clock___2 clock;
	struct device___48 dev;
	struct ptp_clock_info___3 *info;
	dev_t devid;
	int index;
	struct pps_device___3 *pps_source;
	long int dialed_frequency;
	struct timestamp_event_queue tsevq;
	struct mutex tsevq_mux;
	struct mutex pincfg_mux;
	wait_queue_head_t tsev_wq;
	int defunct;
	struct device_attribute___40 *pin_dev_attr;
	struct attribute **pin_attr;
	struct attribute_group___54 pin_attr_group;
	const struct attribute_group___54 *pin_attr_groups[2];
	struct kthread_worker___7 *kworker;
	struct kthread_delayed_work___2 aux_work;
	unsigned int max_vclocks;
	unsigned int n_vclocks;
	int *vclock_index;
	struct mutex n_vclocks_mux;
	bool is_virtual_clock;
};

struct ptp_vclock {
	struct ptp_clock___2 *pclock;
	struct ptp_clock_info___3 info;
	struct ptp_clock___2 *clock;
	struct cyclecounter cc;
	struct timecounter tc;
	spinlock_t lock;
};

struct ptp_clock_caps {
	int max_adj;
	int n_alarm;
	int n_ext_ts;
	int n_per_out;
	int pps;
	int n_pins;
	int cross_timestamping;
	int adjust_phase;
	int rsv[12];
};

struct ptp_sys_offset {
	unsigned int n_samples;
	unsigned int rsv[3];
	struct ptp_clock_time ts[51];
};

struct ptp_sys_offset_extended {
	unsigned int n_samples;
	unsigned int rsv[3];
	struct ptp_clock_time ts[75];
};

struct ptp_sys_offset_precise {
	struct ptp_clock_time device;
	struct ptp_clock_time sys_realtime;
	struct ptp_clock_time sys_monoraw;
	unsigned int rsv[4];
};

struct as3722___3 {
	struct device___194 *dev;
	struct regmap *regmap;
	int chip_irq;
	long unsigned int irq_flags;
	bool en_intern_int_pullup;
	bool en_intern_i2c_pullup;
	bool en_ac_ok_pwr_on;
	struct regmap_irq_chip_data *irq_data;
};

struct as3722_poweroff {
	struct device___194 *dev;
	struct as3722___3 *as3722;
};

struct gpio_restart {
	struct gpio_desc *reset_gpio;
	struct notifier_block restart_handler;
	u32 active_delay_ms;
	u32 inactive_delay_ms;
	u32 wait_delay_ms;
};

struct mt6397_chip___2 {
	struct device___194 *dev;
	struct regmap *regmap;
	struct notifier_block pm_nb;
	int irq;
	struct irq_domain___2 *irq_domain;
	struct mutex irqlock;
	u16 wake_mask[2];
	u16 irq_masks_cur[2];
	u16 irq_masks_cache[2];
	u16 int_con[2];
	u16 int_status[2];
	u16 chip_id;
	void *irq_data;
};

struct mt6323_pwrc {
	struct device___194 *dev;
	struct regmap *regmap;
	u32 base;
};

struct reset_props {
	const char *syscon;
	u32 protect_reg;
	u32 vcore_protect;
	u32 if_si_owner_bit;
};

struct ocelot_reset_context {
	void *base;
	struct regmap *cpu_ctrl;
	const struct reset_props *props;
	struct notifier_block restart_handler;
};

struct ltc2952_poweroff {
	struct hrtimer timer_trigger;
	struct hrtimer timer_wde;
	ktime_t trigger_delay;
	ktime_t wde_interval;
	struct device___194 *dev;
	struct gpio_desc *gpio_trigger;
	struct gpio_desc *gpio_watchdog;
	struct gpio_desc *gpio_kill;
	bool kernel_panic;
	struct notifier_block panic_notifier;
};

struct tps65086 {
	struct device___194 *dev;
	struct regmap *regmap;
	int irq;
	struct regmap_irq_chip_data *irq_data;
};

struct tps65086_restart {
	struct notifier_block handler;
	struct device___194 *dev;
};

enum vexpress_reset_func {
	FUNC_RESET = 0,
	FUNC_SHUTDOWN = 1,
	FUNC_REBOOT = 2,
};

struct syscon_reboot_context {
	struct regmap *map;
	u32 offset;
	u32 value;
	u32 mask;
	struct notifier_block restart_handler;
};

typedef void (*dr_release_t___32)(struct device___208 *, void *);

enum power_supply_notifier_events {
	PSY_EVENT_PROP_CHANGED = 0,
};

struct power_supply_battery_ocv_table {
	int ocv;
	int capacity;
};

struct power_supply_resistance_temp_table {
	int temp;
	int resistance;
};

struct power_supply_battery_info {
	unsigned int technology;
	int energy_full_design_uwh;
	int charge_full_design_uah;
	int voltage_min_design_uv;
	int voltage_max_design_uv;
	int tricklecharge_current_ua;
	int precharge_current_ua;
	int precharge_voltage_max_uv;
	int charge_term_current_ua;
	int charge_restart_voltage_uv;
	int overvoltage_limit_uv;
	int constant_charge_current_max_ua;
	int constant_charge_voltage_max_uv;
	int factory_internal_resistance_uohm;
	int ocv_temp[20];
	int temp_ambient_alert_min;
	int temp_ambient_alert_max;
	int temp_alert_min;
	int temp_alert_max;
	int temp_min;
	int temp_max;
	struct power_supply_battery_ocv_table *ocv_table[20];
	int ocv_table_size[20];
	struct power_supply_resistance_temp_table *resist_table;
	int resist_table_size;
};

struct psy_am_i_supplied_data {
	struct power_supply *psy;
	unsigned int count;
};

struct device_attribute___41 {
	struct attribute attr;
	ssize_t (*show)(struct device___39 *, struct device_attribute___41 *, char *);
	ssize_t (*store)(struct device___39 *, struct device_attribute___41 *, const char *, size_t);
};

struct led_trigger___7;

struct led_classdev___7 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___7 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___7 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___7 *);
	int (*blink_set)(struct led_classdev___7 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___7 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___7 *);
	struct device___39 *dev;
	const struct attribute_group___42 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___7 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___7 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___42 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___7 {
	const char *name;
	int (*activate)(struct led_classdev___7 *);
	void (*deactivate)(struct led_classdev___7 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___42 **groups;
};

enum {
	POWER_SUPPLY_CHARGE_TYPE_UNKNOWN = 0,
	POWER_SUPPLY_CHARGE_TYPE_NONE = 1,
	POWER_SUPPLY_CHARGE_TYPE_TRICKLE = 2,
	POWER_SUPPLY_CHARGE_TYPE_FAST = 3,
	POWER_SUPPLY_CHARGE_TYPE_STANDARD = 4,
	POWER_SUPPLY_CHARGE_TYPE_ADAPTIVE = 5,
	POWER_SUPPLY_CHARGE_TYPE_CUSTOM = 6,
	POWER_SUPPLY_CHARGE_TYPE_LONGLIFE = 7,
};

enum {
	POWER_SUPPLY_HEALTH_UNKNOWN = 0,
	POWER_SUPPLY_HEALTH_GOOD = 1,
	POWER_SUPPLY_HEALTH_OVERHEAT = 2,
	POWER_SUPPLY_HEALTH_DEAD = 3,
	POWER_SUPPLY_HEALTH_OVERVOLTAGE = 4,
	POWER_SUPPLY_HEALTH_UNSPEC_FAILURE = 5,
	POWER_SUPPLY_HEALTH_COLD = 6,
	POWER_SUPPLY_HEALTH_WATCHDOG_TIMER_EXPIRE = 7,
	POWER_SUPPLY_HEALTH_SAFETY_TIMER_EXPIRE = 8,
	POWER_SUPPLY_HEALTH_OVERCURRENT = 9,
	POWER_SUPPLY_HEALTH_CALIBRATION_REQUIRED = 10,
	POWER_SUPPLY_HEALTH_WARM = 11,
	POWER_SUPPLY_HEALTH_COOL = 12,
	POWER_SUPPLY_HEALTH_HOT = 13,
};

enum {
	POWER_SUPPLY_SCOPE_UNKNOWN = 0,
	POWER_SUPPLY_SCOPE_SYSTEM = 1,
	POWER_SUPPLY_SCOPE_DEVICE = 2,
};

struct power_supply___4;

struct power_supply_desc___4 {
	const char *name;
	enum power_supply_type type;
	const enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	const enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___4 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___4 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___4 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___4 *);
	void (*set_charged)(struct power_supply___4 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___4 {
	const struct power_supply_desc___4 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___39 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device___3 *tcd;
	struct led_trigger___7 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___7 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___7 *full_trig;
	char *full_trig_name;
	struct led_trigger___7 *online_trig;
	char *online_trig_name;
	struct led_trigger___7 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct power_supply_attr {
	const char *prop_name;
	char attr_name[31];
	struct device_attribute___41 dev_attr;
	const char * const *text_values;
	int text_values_len;
};

enum hwmon_sensor_types {
	hwmon_chip = 0,
	hwmon_temp = 1,
	hwmon_in = 2,
	hwmon_curr = 3,
	hwmon_power = 4,
	hwmon_energy = 5,
	hwmon_humidity = 6,
	hwmon_fan = 7,
	hwmon_pwm = 8,
	hwmon_intrusion = 9,
	hwmon_max = 10,
};

enum hwmon_temp_attributes {
	hwmon_temp_enable = 0,
	hwmon_temp_input = 1,
	hwmon_temp_type = 2,
	hwmon_temp_lcrit = 3,
	hwmon_temp_lcrit_hyst = 4,
	hwmon_temp_min = 5,
	hwmon_temp_min_hyst = 6,
	hwmon_temp_max = 7,
	hwmon_temp_max_hyst = 8,
	hwmon_temp_crit = 9,
	hwmon_temp_crit_hyst = 10,
	hwmon_temp_emergency = 11,
	hwmon_temp_emergency_hyst = 12,
	hwmon_temp_alarm = 13,
	hwmon_temp_lcrit_alarm = 14,
	hwmon_temp_min_alarm = 15,
	hwmon_temp_max_alarm = 16,
	hwmon_temp_crit_alarm = 17,
	hwmon_temp_emergency_alarm = 18,
	hwmon_temp_fault = 19,
	hwmon_temp_offset = 20,
	hwmon_temp_label = 21,
	hwmon_temp_lowest = 22,
	hwmon_temp_highest = 23,
	hwmon_temp_reset_history = 24,
	hwmon_temp_rated_min = 25,
	hwmon_temp_rated_max = 26,
};

enum hwmon_in_attributes {
	hwmon_in_enable = 0,
	hwmon_in_input = 1,
	hwmon_in_min = 2,
	hwmon_in_max = 3,
	hwmon_in_lcrit = 4,
	hwmon_in_crit = 5,
	hwmon_in_average = 6,
	hwmon_in_lowest = 7,
	hwmon_in_highest = 8,
	hwmon_in_reset_history = 9,
	hwmon_in_label = 10,
	hwmon_in_alarm = 11,
	hwmon_in_min_alarm = 12,
	hwmon_in_max_alarm = 13,
	hwmon_in_lcrit_alarm = 14,
	hwmon_in_crit_alarm = 15,
	hwmon_in_rated_min = 16,
	hwmon_in_rated_max = 17,
};

enum hwmon_curr_attributes {
	hwmon_curr_enable = 0,
	hwmon_curr_input = 1,
	hwmon_curr_min = 2,
	hwmon_curr_max = 3,
	hwmon_curr_lcrit = 4,
	hwmon_curr_crit = 5,
	hwmon_curr_average = 6,
	hwmon_curr_lowest = 7,
	hwmon_curr_highest = 8,
	hwmon_curr_reset_history = 9,
	hwmon_curr_label = 10,
	hwmon_curr_alarm = 11,
	hwmon_curr_min_alarm = 12,
	hwmon_curr_max_alarm = 13,
	hwmon_curr_lcrit_alarm = 14,
	hwmon_curr_crit_alarm = 15,
	hwmon_curr_rated_min = 16,
	hwmon_curr_rated_max = 17,
};

struct hwmon_ops {
	umode_t (*is_visible)(const void *, enum hwmon_sensor_types, u32, int);
	int (*read)(struct device___38 *, enum hwmon_sensor_types, u32, int, long int *);
	int (*read_string)(struct device___38 *, enum hwmon_sensor_types, u32, int, const char **);
	int (*write)(struct device___38 *, enum hwmon_sensor_types, u32, int, long int);
};

struct hwmon_channel_info {
	enum hwmon_sensor_types type;
	const u32 *config;
};

struct hwmon_chip_info {
	const struct hwmon_ops *ops;
	const struct hwmon_channel_info **info;
};

struct led_trigger___8;

struct led_classdev___8 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___8 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___8 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___8 *);
	int (*blink_set)(struct led_classdev___8 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___8 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___8 *);
	struct device___38 *dev;
	const struct attribute_group___41 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___8 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___8 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___41 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___8 {
	const char *name;
	int (*activate)(struct led_classdev___8 *);
	void (*deactivate)(struct led_classdev___8 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___41 **groups;
};

struct power_supply___5;

struct power_supply_desc___5 {
	const char *name;
	enum power_supply_type type;
	const enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	const enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___5 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___5 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___5 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___5 *);
	void (*set_charged)(struct power_supply___5 *);
	bool no_thermal;
	int use_for_apm;
};

struct power_supply___5 {
	const struct power_supply_desc___5 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___2 *of_node;
	void *drv_data;
	struct device___38 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device *tzd;
	struct thermal_cooling_device___3 *tcd;
	struct led_trigger___8 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___8 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___8 *full_trig;
	char *full_trig_name;
	struct led_trigger___8 *online_trig;
	char *online_trig_name;
	struct led_trigger___8 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct power_supply_hwmon {
	struct power_supply___5 *psy;
	long unsigned int *props;
};

struct hwmon_type_attr_list {
	const u32 *attrs;
	size_t n_attrs;
};

struct led_trigger___9;

struct led_classdev___9 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___9 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___9 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___9 *);
	int (*blink_set)(struct led_classdev___9 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___9 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___9 *);
	struct device___15 *dev;
	const struct attribute_group___17 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___9 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___9 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___17 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___9 {
	const char *name;
	int (*activate)(struct led_classdev___9 *);
	void (*deactivate)(struct led_classdev___9 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___17 **groups;
};

struct power_supply_config___2 {
	struct device_node___10 *of_node;
	struct fwnode_handle___15 *fwnode;
	void *drv_data;
	const struct attribute_group___17 **attr_grp;
	char **supplied_to;
	size_t num_supplicants;
};

struct power_supply___6;

struct power_supply_desc___6 {
	const char *name;
	enum power_supply_type type;
	const enum power_supply_usb_type *usb_types;
	size_t num_usb_types;
	const enum power_supply_property *properties;
	size_t num_properties;
	int (*get_property)(struct power_supply___6 *, enum power_supply_property, union power_supply_propval *);
	int (*set_property)(struct power_supply___6 *, enum power_supply_property, const union power_supply_propval *);
	int (*property_is_writeable)(struct power_supply___6 *, enum power_supply_property);
	void (*external_power_changed)(struct power_supply___6 *);
	void (*set_charged)(struct power_supply___6 *);
	bool no_thermal;
	int use_for_apm;
};

struct thermal_zone_device___3;

struct thermal_cooling_device___4;

struct power_supply___6 {
	const struct power_supply_desc___6 *desc;
	char **supplied_to;
	size_t num_supplicants;
	char **supplied_from;
	size_t num_supplies;
	struct device_node___10 *of_node;
	void *drv_data;
	struct device___15 dev;
	struct work_struct changed_work;
	struct delayed_work deferred_register_work;
	spinlock_t changed_lock;
	bool changed;
	bool initialized;
	bool removing;
	atomic_t use_cnt;
	struct thermal_zone_device___3 *tzd;
	struct thermal_cooling_device___4 *tcd;
	struct led_trigger___9 *charging_full_trig;
	char *charging_full_trig_name;
	struct led_trigger___9 *charging_trig;
	char *charging_trig_name;
	struct led_trigger___9 *full_trig;
	char *full_trig_name;
	struct led_trigger___9 *online_trig;
	char *online_trig_name;
	struct led_trigger___9 *charging_blink_full_solid_trig;
	char *charging_blink_full_solid_trig_name;
};

struct thermal_zone_device_ops___3;

struct thermal_zone_params___3;

struct thermal_governor___3;

struct thermal_zone_device___3 {
	int id;
	char type[20];
	struct device___15 device;
	struct attribute_group___17 trips_attribute_group;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___3 *ops;
	struct thermal_zone_params___3 *tzp;
	struct thermal_governor___3 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___4;

struct thermal_cooling_device___4 {
	int id;
	char *type;
	struct device___15 device;
	struct device_node___10 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___4 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

enum cm_batt_temp {
	CM_BATT_OK = 0,
	CM_BATT_OVERHEAT = 1,
	CM_BATT_COLD = 2,
};

struct charger_regulator___2;

struct charger_manager___2;

struct charger_cable___2 {
	const char *extcon_name;
	const char *name;
	struct extcon_dev *extcon_dev;
	u64 extcon_type;
	struct work_struct wq;
	struct notifier_block nb;
	bool attached;
	struct charger_regulator___2 *charger;
	int min_uA;
	int max_uA;
	struct charger_manager___2 *cm;
};

struct charger_regulator___2 {
	const char *regulator_name;
	struct regulator *consumer;
	int externally_control;
	struct charger_cable___2 *cables;
	int num_cables;
	struct attribute_group___17 attr_grp;
	struct device_attribute___13 attr_name;
	struct device_attribute___13 attr_state;
	struct device_attribute___13 attr_externally_control;
	struct attribute *attrs[4];
	struct charger_manager___2 *cm;
};

struct charger_desc___2;

struct charger_manager___2 {
	struct list_head entry;
	struct device___15 *dev;
	struct charger_desc___2 *desc;
	struct thermal_zone_device___3 *tzd_batt;
	bool charger_enabled;
	int emergency_stop;
	char psy_name_buf[31];
	struct power_supply_desc___6 charger_psy_desc;
	struct power_supply___6 *charger_psy;
	u64 charging_start_time;
	u64 charging_end_time;
	int battery_status;
};

struct charger_desc___2 {
	const char *psy_name;
	enum polling_modes polling_mode;
	unsigned int polling_interval_ms;
	unsigned int fullbatt_vchkdrop_uV;
	unsigned int fullbatt_uV;
	unsigned int fullbatt_soc;
	unsigned int fullbatt_full_capacity;
	enum data_source battery_present;
	const char **psy_charger_stat;
	int num_charger_regulators;
	struct charger_regulator___2 *charger_regulators;
	const struct attribute_group___17 **sysfs_groups;
	const char *psy_fuel_gauge;
	const char *thermal_zone;
	int temp_min;
	int temp_max;
	int temp_diff;
	bool measure_battery_temp;
	u32 charging_max_duration_ms;
	u32 discharging_max_duration_ms;
};

struct thermal_zone_device_ops___3 {
	int (*bind)(struct thermal_zone_device___3 *, struct thermal_cooling_device___4 *);
	int (*unbind)(struct thermal_zone_device___3 *, struct thermal_cooling_device___4 *);
	int (*get_temp)(struct thermal_zone_device___3 *, int *);
	int (*set_trips)(struct thermal_zone_device___3 *, int, int);
	int (*change_mode)(struct thermal_zone_device___3 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___3 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___3 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___3 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___3 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___3 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___3 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___3 *, int);
	int (*get_trend)(struct thermal_zone_device___3 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___3 *);
	void (*critical)(struct thermal_zone_device___3 *);
};

struct thermal_cooling_device_ops___4 {
	int (*get_max_state)(struct thermal_cooling_device___4 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___4 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___4 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___4 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___4 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___4 *, u32, long unsigned int *);
};

struct thermal_bind_params___3;

struct thermal_zone_params___3 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___3 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___3 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___3 *);
	void (*unbind_from_tz)(struct thermal_zone_device___3 *);
	int (*throttle)(struct thermal_zone_device___3 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___3 {
	struct thermal_cooling_device___4 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___3 *, struct thermal_cooling_device___4 *);
};

typedef int (*dr_match_t___24)(struct device___208 *, void *, void *);

enum hwmon_chip_attributes {
	hwmon_chip_temp_reset_history = 0,
	hwmon_chip_in_reset_history = 1,
	hwmon_chip_curr_reset_history = 2,
	hwmon_chip_power_reset_history = 3,
	hwmon_chip_register_tz = 4,
	hwmon_chip_update_interval = 5,
	hwmon_chip_alarms = 6,
	hwmon_chip_samples = 7,
	hwmon_chip_curr_samples = 8,
	hwmon_chip_in_samples = 9,
	hwmon_chip_power_samples = 10,
	hwmon_chip_temp_samples = 11,
};

enum hwmon_power_attributes {
	hwmon_power_enable = 0,
	hwmon_power_average = 1,
	hwmon_power_average_interval = 2,
	hwmon_power_average_interval_max = 3,
	hwmon_power_average_interval_min = 4,
	hwmon_power_average_highest = 5,
	hwmon_power_average_lowest = 6,
	hwmon_power_average_max = 7,
	hwmon_power_average_min = 8,
	hwmon_power_input = 9,
	hwmon_power_input_highest = 10,
	hwmon_power_input_lowest = 11,
	hwmon_power_reset_history = 12,
	hwmon_power_accuracy = 13,
	hwmon_power_cap = 14,
	hwmon_power_cap_hyst = 15,
	hwmon_power_cap_max = 16,
	hwmon_power_cap_min = 17,
	hwmon_power_min = 18,
	hwmon_power_max = 19,
	hwmon_power_crit = 20,
	hwmon_power_lcrit = 21,
	hwmon_power_label = 22,
	hwmon_power_alarm = 23,
	hwmon_power_cap_alarm = 24,
	hwmon_power_min_alarm = 25,
	hwmon_power_max_alarm = 26,
	hwmon_power_lcrit_alarm = 27,
	hwmon_power_crit_alarm = 28,
	hwmon_power_rated_min = 29,
	hwmon_power_rated_max = 30,
};

enum hwmon_energy_attributes {
	hwmon_energy_enable = 0,
	hwmon_energy_input = 1,
	hwmon_energy_label = 2,
};

enum hwmon_humidity_attributes {
	hwmon_humidity_enable = 0,
	hwmon_humidity_input = 1,
	hwmon_humidity_label = 2,
	hwmon_humidity_min = 3,
	hwmon_humidity_min_hyst = 4,
	hwmon_humidity_max = 5,
	hwmon_humidity_max_hyst = 6,
	hwmon_humidity_alarm = 7,
	hwmon_humidity_fault = 8,
	hwmon_humidity_rated_min = 9,
	hwmon_humidity_rated_max = 10,
};

enum hwmon_fan_attributes {
	hwmon_fan_enable = 0,
	hwmon_fan_input = 1,
	hwmon_fan_label = 2,
	hwmon_fan_min = 3,
	hwmon_fan_max = 4,
	hwmon_fan_div = 5,
	hwmon_fan_pulses = 6,
	hwmon_fan_target = 7,
	hwmon_fan_alarm = 8,
	hwmon_fan_min_alarm = 9,
	hwmon_fan_max_alarm = 10,
	hwmon_fan_fault = 11,
};

enum hwmon_pwm_attributes {
	hwmon_pwm_input = 0,
	hwmon_pwm_enable = 1,
	hwmon_pwm_mode = 2,
	hwmon_pwm_freq = 3,
};

enum hwmon_intrusion_attributes {
	hwmon_intrusion_alarm = 0,
	hwmon_intrusion_beep = 1,
};

struct hwmon_ops___2 {
	umode_t (*is_visible)(const void *, enum hwmon_sensor_types, u32, int);
	int (*read)(struct device___208 *, enum hwmon_sensor_types, u32, int, long int *);
	int (*read_string)(struct device___208 *, enum hwmon_sensor_types, u32, int, const char **);
	int (*write)(struct device___208 *, enum hwmon_sensor_types, u32, int, long int);
};

struct hwmon_chip_info___2 {
	const struct hwmon_ops___2 *ops;
	const struct hwmon_channel_info **info;
};

struct thermal_zone_device___4;

struct thermal_cooling_device___5;

struct thermal_zone_device_ops___4 {
	int (*bind)(struct thermal_zone_device___4 *, struct thermal_cooling_device___5 *);
	int (*unbind)(struct thermal_zone_device___4 *, struct thermal_cooling_device___5 *);
	int (*get_temp)(struct thermal_zone_device___4 *, int *);
	int (*set_trips)(struct thermal_zone_device___4 *, int, int);
	int (*change_mode)(struct thermal_zone_device___4 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___4 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___4 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___4 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___4 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___4 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___4 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___4 *, int);
	int (*get_trend)(struct thermal_zone_device___4 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___4 *);
	void (*critical)(struct thermal_zone_device___4 *);
};

struct thermal_zone_params___4;

struct thermal_governor___4;

struct thermal_zone_device___4 {
	int id;
	char type[20];
	struct device___208 device;
	struct attribute_group___218 trips_attribute_group;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___4 *ops;
	struct thermal_zone_params___4 *tzp;
	struct thermal_governor___4 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___5;

struct thermal_cooling_device___5 {
	int id;
	char *type;
	struct device___208 device;
	struct device_node___92 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___5 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___5 {
	int (*get_max_state)(struct thermal_cooling_device___5 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___5 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___5 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___5 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___5 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___5 *, u32, long unsigned int *);
};

struct thermal_bind_params___4;

struct thermal_zone_params___4 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___4 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___4 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___4 *);
	void (*unbind_from_tz)(struct thermal_zone_device___4 *);
	int (*throttle)(struct thermal_zone_device___4 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___4 {
	struct thermal_cooling_device___5 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___4 *, struct thermal_cooling_device___5 *);
};

struct trace_event_raw_hwmon_attr_class {
	struct trace_entry ent;
	int index;
	u32 __data_loc_attr_name;
	long int val;
	char __data[0];
};

struct trace_event_raw_hwmon_attr_show_string {
	struct trace_entry ent;
	int index;
	u32 __data_loc_attr_name;
	u32 __data_loc_label;
	char __data[0];
};

struct trace_event_data_offsets_hwmon_attr_class {
	u32 attr_name;
};

struct trace_event_data_offsets_hwmon_attr_show_string {
	u32 attr_name;
	u32 label;
};

typedef void (*btf_trace_hwmon_attr_show)(void *, int, const char *, long int);

typedef void (*btf_trace_hwmon_attr_store)(void *, int, const char *, long int);

typedef void (*btf_trace_hwmon_attr_show_string)(void *, int, const char *, const char *);

struct hwmon_device {
	const char *name;
	struct device___208 dev;
	const struct hwmon_chip_info___2 *chip;
	struct list_head tzdata;
	struct attribute_group___218 group;
	const struct attribute_group___218 **groups;
};

struct hwmon_device_attribute {
	struct device_attribute___39 dev_attr;
	const struct hwmon_ops___2 *ops;
	enum hwmon_sensor_types type;
	u32 attr;
	int index;
	char name[32];
};

struct hwmon_thermal_data {
	struct list_head node;
	struct device___208 *dev;
	int index;
	struct thermal_zone_device___4 *tzd;
};

struct device_attribute___42 {
	struct attribute attr;
	ssize_t (*show)(struct device___36 *, struct device_attribute___42 *, char *);
	ssize_t (*store)(struct device___36 *, struct device_attribute___42 *, const char *, size_t);
};

typedef void (*dr_release_t___33)(struct device___36 *, void *);

struct thermal_zone_device___5;

struct thermal_cooling_device___6;

struct thermal_zone_device_ops___5 {
	int (*bind)(struct thermal_zone_device___5 *, struct thermal_cooling_device___6 *);
	int (*unbind)(struct thermal_zone_device___5 *, struct thermal_cooling_device___6 *);
	int (*get_temp)(struct thermal_zone_device___5 *, int *);
	int (*set_trips)(struct thermal_zone_device___5 *, int, int);
	int (*change_mode)(struct thermal_zone_device___5 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___5 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___5 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___5 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___5 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___5 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___5 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___5 *, int);
	int (*get_trend)(struct thermal_zone_device___5 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___5 *);
	void (*critical)(struct thermal_zone_device___5 *);
};

struct thermal_attr___2;

struct thermal_zone_params___5;

struct thermal_governor___5;

struct thermal_zone_device___5 {
	int id;
	char type[20];
	struct device___36 device;
	struct attribute_group___39 trips_attribute_group;
	struct thermal_attr___2 *trip_temp_attrs;
	struct thermal_attr___2 *trip_type_attrs;
	struct thermal_attr___2 *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___5 *ops;
	struct thermal_zone_params___5 *tzp;
	struct thermal_governor___5 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___6;

struct thermal_cooling_device___6 {
	int id;
	char *type;
	struct device___36 device;
	struct device_node___21 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___6 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___6 {
	int (*get_max_state)(struct thermal_cooling_device___6 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___6 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___6 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___6 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___6 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___6 *, u32, long unsigned int *);
};

struct thermal_attr___2 {
	struct device_attribute___42 attr;
	char name[20];
};

struct thermal_bind_params___5;

struct thermal_zone_params___5 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___5 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___5 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___5 *);
	void (*unbind_from_tz)(struct thermal_zone_device___5 *);
	int (*throttle)(struct thermal_zone_device___5 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___5 {
	struct thermal_cooling_device___6 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___5 *, struct thermal_cooling_device___6 *);
};

struct devfreq_dev_status {
	long unsigned int total_time;
	long unsigned int busy_time;
	long unsigned int current_frequency;
	void *private_data;
};

struct trace_event_file___37;

struct trace_event_buffer___36 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___37 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___37 {
	struct list_head list;
	struct trace_event_call___23 *event_call;
	struct event_filter *filter;
	struct dentry___40 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_thermal_temperature {
	struct trace_entry ent;
	u32 __data_loc_thermal_zone;
	int id;
	int temp_prev;
	int temp;
	char __data[0];
};

struct trace_event_raw_cdev_update {
	struct trace_entry ent;
	u32 __data_loc_type;
	long unsigned int target;
	char __data[0];
};

struct trace_event_raw_thermal_zone_trip {
	struct trace_entry ent;
	u32 __data_loc_thermal_zone;
	int id;
	int trip;
	enum thermal_trip_type trip_type;
	char __data[0];
};

struct trace_event_raw_thermal_power_cpu_get_power {
	struct trace_entry ent;
	u32 __data_loc_cpumask;
	long unsigned int freq;
	u32 __data_loc_load;
	size_t load_len;
	u32 dynamic_power;
	char __data[0];
};

struct trace_event_raw_thermal_power_cpu_limit {
	struct trace_entry ent;
	u32 __data_loc_cpumask;
	unsigned int freq;
	long unsigned int cdev_state;
	u32 power;
	char __data[0];
};

struct trace_event_raw_thermal_power_devfreq_get_power {
	struct trace_entry ent;
	u32 __data_loc_type;
	long unsigned int freq;
	u32 busy_time;
	u32 total_time;
	u32 power;
	char __data[0];
};

struct trace_event_raw_thermal_power_devfreq_limit {
	struct trace_entry ent;
	u32 __data_loc_type;
	unsigned int freq;
	long unsigned int cdev_state;
	u32 power;
	char __data[0];
};

struct trace_event_data_offsets_thermal_temperature {
	u32 thermal_zone;
};

struct trace_event_data_offsets_cdev_update {
	u32 type;
};

struct trace_event_data_offsets_thermal_zone_trip {
	u32 thermal_zone;
};

struct trace_event_data_offsets_thermal_power_cpu_get_power {
	u32 cpumask;
	u32 load;
};

struct trace_event_data_offsets_thermal_power_cpu_limit {
	u32 cpumask;
};

struct trace_event_data_offsets_thermal_power_devfreq_get_power {
	u32 type;
};

struct trace_event_data_offsets_thermal_power_devfreq_limit {
	u32 type;
};

typedef void (*btf_trace_thermal_temperature)(void *, struct thermal_zone_device___5 *);

typedef void (*btf_trace_cdev_update)(void *, struct thermal_cooling_device___6 *, long unsigned int);

typedef void (*btf_trace_thermal_zone_trip)(void *, struct thermal_zone_device___5 *, int, enum thermal_trip_type);

typedef void (*btf_trace_thermal_power_cpu_get_power)(void *, const struct cpumask *, long unsigned int, u32 *, size_t, u32);

typedef void (*btf_trace_thermal_power_cpu_limit)(void *, const struct cpumask *, unsigned int, long unsigned int, u32);

typedef void (*btf_trace_thermal_power_devfreq_get_power)(void *, struct thermal_cooling_device___6 *, struct devfreq_dev_status *, long unsigned int, u32);

typedef void (*btf_trace_thermal_power_devfreq_limit)(void *, struct thermal_cooling_device___6 *, long unsigned int, long unsigned int, u32);

struct thermal_instance {
	int id;
	char name[20];
	struct thermal_zone_device___5 *tz;
	struct thermal_cooling_device___6 *cdev;
	int trip;
	bool initialized;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___42 attr;
	char weight_attr_name[20];
	struct device_attribute___42 weight_attr;
	struct list_head tz_node;
	struct list_head cdev_node;
	unsigned int weight;
};

struct thermal_zone_device___6;

struct thermal_cooling_device___7;

struct thermal_zone_device_ops___6 {
	int (*bind)(struct thermal_zone_device___6 *, struct thermal_cooling_device___7 *);
	int (*unbind)(struct thermal_zone_device___6 *, struct thermal_cooling_device___7 *);
	int (*get_temp)(struct thermal_zone_device___6 *, int *);
	int (*set_trips)(struct thermal_zone_device___6 *, int, int);
	int (*change_mode)(struct thermal_zone_device___6 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___6 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___6 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___6 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___6 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___6 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___6 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___6 *, int);
	int (*get_trend)(struct thermal_zone_device___6 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___6 *);
	void (*critical)(struct thermal_zone_device___6 *);
};

struct thermal_attr___3;

struct thermal_zone_params___6;

struct thermal_governor___6;

struct thermal_zone_device___6 {
	int id;
	char type[20];
	struct device___38 device;
	struct attribute_group___41 trips_attribute_group;
	struct thermal_attr___3 *trip_temp_attrs;
	struct thermal_attr___3 *trip_type_attrs;
	struct thermal_attr___3 *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___6 *ops;
	struct thermal_zone_params___6 *tzp;
	struct thermal_governor___6 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___7;

struct thermal_cooling_device___7 {
	int id;
	char *type;
	struct device___38 device;
	struct device_node___22 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___7 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___7 {
	int (*get_max_state)(struct thermal_cooling_device___7 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___7 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___7 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___7 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___7 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___7 *, u32, long unsigned int *);
};

struct thermal_attr___3 {
	struct device_attribute___11 attr;
	char name[20];
};

struct thermal_bind_params___6;

struct thermal_zone_params___6 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___6 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___6 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___6 *);
	void (*unbind_from_tz)(struct thermal_zone_device___6 *);
	int (*throttle)(struct thermal_zone_device___6 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___6 {
	struct thermal_cooling_device___7 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___6 *, struct thermal_cooling_device___7 *);
};

struct thermal_instance___2 {
	int id;
	char name[20];
	struct thermal_zone_device___6 *tz;
	struct thermal_cooling_device___7 *cdev;
	int trip;
	bool initialized;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___11 attr;
	char weight_attr_name[20];
	struct device_attribute___11 weight_attr;
	struct list_head tz_node;
	struct list_head cdev_node;
	unsigned int weight;
};

struct cooling_dev_stats {
	spinlock_t lock;
	unsigned int total_trans;
	long unsigned int state;
	long unsigned int max_states;
	ktime_t last_time;
	ktime_t *time_in_state;
	unsigned int *trans_table;
};

struct device_attribute___43 {
	struct attribute attr;
	ssize_t (*show)(struct device___189 *, struct device_attribute___43 *, char *);
	ssize_t (*store)(struct device___189 *, struct device_attribute___43 *, const char *, size_t);
};

struct thermal_cooling_device_ops___8;

struct thermal_cooling_device___8 {
	int id;
	char *type;
	struct device___189 device;
	struct device_node___81 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___8 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_zone_device___7;

struct thermal_zone_device_ops___7 {
	int (*bind)(struct thermal_zone_device___7 *, struct thermal_cooling_device___8 *);
	int (*unbind)(struct thermal_zone_device___7 *, struct thermal_cooling_device___8 *);
	int (*get_temp)(struct thermal_zone_device___7 *, int *);
	int (*set_trips)(struct thermal_zone_device___7 *, int, int);
	int (*change_mode)(struct thermal_zone_device___7 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___7 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___7 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___7 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___7 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___7 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___7 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___7 *, int);
	int (*get_trend)(struct thermal_zone_device___7 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___7 *);
	void (*critical)(struct thermal_zone_device___7 *);
};

struct thermal_zone_params___7;

struct thermal_governor___7;

struct thermal_zone_device___7 {
	int id;
	char type[20];
	struct device___189 device;
	struct attribute_group___42 trips_attribute_group;
	struct thermal_attr *trip_temp_attrs;
	struct thermal_attr *trip_type_attrs;
	struct thermal_attr *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___7 *ops;
	struct thermal_zone_params___7 *tzp;
	struct thermal_governor___7 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___8 {
	int (*get_max_state)(struct thermal_cooling_device___8 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___8 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___8 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___8 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___8 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___8 *, u32, long unsigned int *);
};

struct thermal_attr {
	struct device_attribute___43 attr;
	char name[20];
};

struct thermal_bind_params___7;

struct thermal_zone_params___7 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___7 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___7 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___7 *);
	void (*unbind_from_tz)(struct thermal_zone_device___7 *);
	int (*throttle)(struct thermal_zone_device___7 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___7 {
	struct thermal_cooling_device___8 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___7 *, struct thermal_cooling_device___8 *);
};

struct thermal_instance___3 {
	int id;
	char name[20];
	struct thermal_zone_device___7 *tz;
	struct thermal_cooling_device___8 *cdev;
	int trip;
	bool initialized;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___43 attr;
	char weight_attr_name[20];
	struct device_attribute___43 weight_attr;
	struct list_head tz_node;
	struct list_head cdev_node;
	unsigned int weight;
};

struct genl_dumpit_info {
	const struct genl_family___2 *family;
	struct genl_ops___2 op;
	struct nlattr **attrs;
};

enum thermal_genl_attr {
	THERMAL_GENL_ATTR_UNSPEC = 0,
	THERMAL_GENL_ATTR_TZ = 1,
	THERMAL_GENL_ATTR_TZ_ID = 2,
	THERMAL_GENL_ATTR_TZ_TEMP = 3,
	THERMAL_GENL_ATTR_TZ_TRIP = 4,
	THERMAL_GENL_ATTR_TZ_TRIP_ID = 5,
	THERMAL_GENL_ATTR_TZ_TRIP_TYPE = 6,
	THERMAL_GENL_ATTR_TZ_TRIP_TEMP = 7,
	THERMAL_GENL_ATTR_TZ_TRIP_HYST = 8,
	THERMAL_GENL_ATTR_TZ_MODE = 9,
	THERMAL_GENL_ATTR_TZ_NAME = 10,
	THERMAL_GENL_ATTR_TZ_CDEV_WEIGHT = 11,
	THERMAL_GENL_ATTR_TZ_GOV = 12,
	THERMAL_GENL_ATTR_TZ_GOV_NAME = 13,
	THERMAL_GENL_ATTR_CDEV = 14,
	THERMAL_GENL_ATTR_CDEV_ID = 15,
	THERMAL_GENL_ATTR_CDEV_CUR_STATE = 16,
	THERMAL_GENL_ATTR_CDEV_MAX_STATE = 17,
	THERMAL_GENL_ATTR_CDEV_NAME = 18,
	THERMAL_GENL_ATTR_GOV_NAME = 19,
	__THERMAL_GENL_ATTR_MAX = 20,
};

enum thermal_genl_sampling {
	THERMAL_GENL_SAMPLING_TEMP = 0,
	__THERMAL_GENL_SAMPLING_MAX = 1,
};

enum thermal_genl_event {
	THERMAL_GENL_EVENT_UNSPEC = 0,
	THERMAL_GENL_EVENT_TZ_CREATE = 1,
	THERMAL_GENL_EVENT_TZ_DELETE = 2,
	THERMAL_GENL_EVENT_TZ_DISABLE = 3,
	THERMAL_GENL_EVENT_TZ_ENABLE = 4,
	THERMAL_GENL_EVENT_TZ_TRIP_UP = 5,
	THERMAL_GENL_EVENT_TZ_TRIP_DOWN = 6,
	THERMAL_GENL_EVENT_TZ_TRIP_CHANGE = 7,
	THERMAL_GENL_EVENT_TZ_TRIP_ADD = 8,
	THERMAL_GENL_EVENT_TZ_TRIP_DELETE = 9,
	THERMAL_GENL_EVENT_CDEV_ADD = 10,
	THERMAL_GENL_EVENT_CDEV_DELETE = 11,
	THERMAL_GENL_EVENT_CDEV_STATE_UPDATE = 12,
	THERMAL_GENL_EVENT_TZ_GOV_CHANGE = 13,
	__THERMAL_GENL_EVENT_MAX = 14,
};

enum thermal_genl_cmd {
	THERMAL_GENL_CMD_UNSPEC = 0,
	THERMAL_GENL_CMD_TZ_GET_ID = 1,
	THERMAL_GENL_CMD_TZ_GET_TRIP = 2,
	THERMAL_GENL_CMD_TZ_GET_TEMP = 3,
	THERMAL_GENL_CMD_TZ_GET_GOV = 4,
	THERMAL_GENL_CMD_TZ_GET_MODE = 5,
	THERMAL_GENL_CMD_CDEV_GET = 6,
	__THERMAL_GENL_CMD_MAX = 7,
};

struct thermal_zone_device___8;

struct thermal_cooling_device___9;

struct thermal_zone_device_ops___8 {
	int (*bind)(struct thermal_zone_device___8 *, struct thermal_cooling_device___9 *);
	int (*unbind)(struct thermal_zone_device___8 *, struct thermal_cooling_device___9 *);
	int (*get_temp)(struct thermal_zone_device___8 *, int *);
	int (*set_trips)(struct thermal_zone_device___8 *, int, int);
	int (*change_mode)(struct thermal_zone_device___8 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___8 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___8 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___8 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___8 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___8 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___8 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___8 *, int);
	int (*get_trend)(struct thermal_zone_device___8 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___8 *);
	void (*critical)(struct thermal_zone_device___8 *);
};

struct thermal_attr___4;

struct thermal_zone_params___8;

struct thermal_governor___8;

struct thermal_zone_device___8 {
	int id;
	char type[20];
	struct device___203 device;
	struct attribute_group___213 trips_attribute_group;
	struct thermal_attr___4 *trip_temp_attrs;
	struct thermal_attr___4 *trip_type_attrs;
	struct thermal_attr___4 *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___8 *ops;
	struct thermal_zone_params___8 *tzp;
	struct thermal_governor___8 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___9;

struct thermal_cooling_device___9 {
	int id;
	char *type;
	struct device___203 device;
	struct device_node___89 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___9 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___9 {
	int (*get_max_state)(struct thermal_cooling_device___9 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___9 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___9 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___9 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___9 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___9 *, u32, long unsigned int *);
};

struct thermal_attr___4 {
	struct device_attribute___37 attr;
	char name[20];
};

struct thermal_bind_params___8;

struct thermal_zone_params___8 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___8 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___8 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___8 *);
	void (*unbind_from_tz)(struct thermal_zone_device___8 *);
	int (*throttle)(struct thermal_zone_device___8 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___8 {
	struct thermal_cooling_device___9 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___8 *, struct thermal_cooling_device___9 *);
};

struct param {
	struct nlattr **attrs;
	struct sk_buff___44 *msg;
	const char *name;
	int tz_id;
	int cdev_id;
	int trip_id;
	int trip_temp;
	int trip_type;
	int trip_hyst;
	int temp;
	int cdev_state;
	int cdev_max_state;
};

typedef int (*cb_t)(struct param *);

struct hwmon_ops___3 {
	umode_t (*is_visible)(const void *, enum hwmon_sensor_types, u32, int);
	int (*read)(struct device___39 *, enum hwmon_sensor_types, u32, int, long int *);
	int (*read_string)(struct device___39 *, enum hwmon_sensor_types, u32, int, const char **);
	int (*write)(struct device___39 *, enum hwmon_sensor_types, u32, int, long int);
};

struct hwmon_chip_info___3 {
	const struct hwmon_ops___3 *ops;
	const struct hwmon_channel_info **info;
};

typedef void (*dr_release_t___34)(struct device___39 *, void *);

struct thermal_hwmon_device {
	char type[20];
	struct device___39 *device;
	int count;
	struct list_head tz_list;
	struct list_head node;
};

struct thermal_hwmon_attr {
	struct device_attribute___43 attr;
	char name[16];
};

struct thermal_hwmon_temp {
	struct list_head hwmon_node;
	struct thermal_zone_device___7 *tz;
	struct thermal_hwmon_attr temp_input;
	struct thermal_hwmon_attr temp_crit;
};

typedef int (*dr_match_t___25)(struct device___39 *, void *, void *);

struct thermal_trip {
	struct device_node___23 *np;
	int temperature;
	int hysteresis;
	enum thermal_trip_type type;
};

struct __thermal_cooling_bind_param {
	struct device_node___23 *cooling_device;
	long unsigned int min;
	long unsigned int max;
};

struct __thermal_bind_params {
	struct __thermal_cooling_bind_param *tcbp;
	unsigned int count;
	unsigned int trip_id;
	unsigned int usage;
};

struct __thermal_zone {
	int passive_delay;
	int polling_delay;
	int slope;
	int offset;
	int ntrips;
	struct thermal_trip *trips;
	int num_tbps;
	struct __thermal_bind_params *tbps;
	void *sensor_data;
	const struct thermal_zone_of_device_ops *ops;
};

struct fwnode_operations___205;

struct device___209;

struct fwnode_handle___205 {
	struct fwnode_handle___205 *secondary;
	const struct fwnode_operations___205 *ops;
	struct device___209 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___205;

struct fwnode_endpoint___205;

struct fwnode_operations___205 {
	struct fwnode_handle___205 * (*get)(struct fwnode_handle___205 *);
	void (*put)(struct fwnode_handle___205 *);
	bool (*device_is_available)(const struct fwnode_handle___205 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___205 *, const struct device___209 *);
	bool (*property_present)(const struct fwnode_handle___205 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___205 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___205 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___205 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*get_parent)(const struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*get_next_child_node)(const struct fwnode_handle___205 *, struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*get_named_child_node)(const struct fwnode_handle___205 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___205 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___205 *);
	struct fwnode_handle___205 * (*graph_get_next_endpoint)(const struct fwnode_handle___205 *, struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*graph_get_remote_endpoint)(const struct fwnode_handle___205 *);
	struct fwnode_handle___205 * (*graph_get_port_parent)(struct fwnode_handle___205 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___205 *, struct fwnode_endpoint___205 *);
	int (*add_links)(struct fwnode_handle___205 *);
};

struct wakeup_source___209;

struct dev_pm_qos___25;

struct dev_pm_info___209 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___209 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___209 *, s32);
	struct dev_pm_qos___25 *qos;
};

struct device_type___209;

struct bus_type___209;

struct device_driver___209;

struct dev_pm_domain___209;

struct device_node___93;

struct class___209;

struct device___209 {
	struct kobject___41 kobj;
	struct device___209 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___209 *type;
	struct bus_type___209 *bus;
	struct device_driver___209 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___209 power;
	struct dev_pm_domain___209 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___93 *of_node;
	struct fwnode_handle___205 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___209 *class;
	const struct attribute_group___41 **groups;
	void (*release)(struct device___209 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___205 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___205 *local_fwnode;
};

struct fwnode_reference_args___205 {
	struct fwnode_handle___205 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___93 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___205 fwnode;
	struct property___19 *properties;
	struct property___19 *deadprops;
	struct device_node___93 *parent;
	struct device_node___93 *child;
	struct device_node___93 *sibling;
	struct kobject___41 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pm_ops___209 {
	int (*prepare)(struct device___209 *);
	void (*complete)(struct device___209 *);
	int (*suspend)(struct device___209 *);
	int (*resume)(struct device___209 *);
	int (*freeze)(struct device___209 *);
	int (*thaw)(struct device___209 *);
	int (*poweroff)(struct device___209 *);
	int (*restore)(struct device___209 *);
	int (*suspend_late)(struct device___209 *);
	int (*resume_early)(struct device___209 *);
	int (*freeze_late)(struct device___209 *);
	int (*thaw_early)(struct device___209 *);
	int (*poweroff_late)(struct device___209 *);
	int (*restore_early)(struct device___209 *);
	int (*suspend_noirq)(struct device___209 *);
	int (*resume_noirq)(struct device___209 *);
	int (*freeze_noirq)(struct device___209 *);
	int (*thaw_noirq)(struct device___209 *);
	int (*poweroff_noirq)(struct device___209 *);
	int (*restore_noirq)(struct device___209 *);
	int (*runtime_suspend)(struct device___209 *);
	int (*runtime_resume)(struct device___209 *);
	int (*runtime_idle)(struct device___209 *);
};

struct wakeup_source___209 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___209 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_qos_request___25;

struct dev_pm_qos___25 {
	struct pm_qos_constraints resume_latency;
	struct pm_qos_constraints latency_tolerance;
	struct freq_constraints freq;
	struct pm_qos_flags flags;
	struct dev_pm_qos_request___25 *resume_latency_req;
	struct dev_pm_qos_request___25 *latency_tolerance_req;
	struct dev_pm_qos_request___25 *flags_req;
};

struct dev_pm_domain___209 {
	struct dev_pm_ops___209 ops;
	int (*start)(struct device___209 *);
	void (*detach)(struct device___209 *, bool);
	int (*activate)(struct device___209 *);
	void (*sync)(struct device___209 *);
	void (*dismiss)(struct device___209 *);
};

struct bus_type___209 {
	const char *name;
	const char *dev_name;
	struct device___209 *dev_root;
	const struct attribute_group___41 **bus_groups;
	const struct attribute_group___41 **dev_groups;
	const struct attribute_group___41 **drv_groups;
	int (*match)(struct device___209 *, struct device_driver___209 *);
	int (*uevent)(struct device___209 *, struct kobj_uevent_env *);
	int (*probe)(struct device___209 *);
	void (*sync_state)(struct device___209 *);
	void (*remove)(struct device___209 *);
	void (*shutdown)(struct device___209 *);
	int (*online)(struct device___209 *);
	int (*offline)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	int (*num_vf)(struct device___209 *);
	int (*dma_configure)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___209 {
	const char *name;
	struct bus_type___209 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___209 *);
	void (*sync_state)(struct device___209 *);
	int (*remove)(struct device___209 *);
	void (*shutdown)(struct device___209 *);
	int (*suspend)(struct device___209 *, pm_message_t);
	int (*resume)(struct device___209 *);
	const struct attribute_group___41 **groups;
	const struct attribute_group___41 **dev_groups;
	const struct dev_pm_ops___209 *pm;
	void (*coredump)(struct device___209 *);
	struct driver_private *p;
};

struct device_type___209 {
	const char *name;
	const struct attribute_group___41 **groups;
	int (*uevent)(struct device___209 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___209 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___209 *);
	const struct dev_pm_ops___209 *pm;
};

struct class___209 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___41 **class_groups;
	const struct attribute_group___41 **dev_groups;
	struct kobject___41 *dev_kobj;
	int (*dev_uevent)(struct device___209 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___209 *, umode_t *);
	void (*class_release)(struct class___209 *);
	void (*dev_release)(struct device___209 *);
	int (*shutdown_pre)(struct device___209 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___209 *);
	void (*get_ownership)(struct device___209 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___209 *pm;
	struct subsys_private *p;
};

struct device_attribute___44 {
	struct attribute attr;
	ssize_t (*show)(struct device___209 *, struct device_attribute___44 *, char *);
	ssize_t (*store)(struct device___209 *, struct device_attribute___44 *, const char *, size_t);
};

struct thermal_zone_device___9;

struct thermal_cooling_device___10;

struct thermal_zone_device_ops___9 {
	int (*bind)(struct thermal_zone_device___9 *, struct thermal_cooling_device___10 *);
	int (*unbind)(struct thermal_zone_device___9 *, struct thermal_cooling_device___10 *);
	int (*get_temp)(struct thermal_zone_device___9 *, int *);
	int (*set_trips)(struct thermal_zone_device___9 *, int, int);
	int (*change_mode)(struct thermal_zone_device___9 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___9 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___9 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___9 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___9 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___9 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___9 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___9 *, int);
	int (*get_trend)(struct thermal_zone_device___9 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___9 *);
	void (*critical)(struct thermal_zone_device___9 *);
};

struct thermal_attr___5;

struct thermal_zone_params___9;

struct thermal_governor___9;

struct thermal_zone_device___9 {
	int id;
	char type[20];
	struct device___209 device;
	struct attribute_group___41 trips_attribute_group;
	struct thermal_attr___5 *trip_temp_attrs;
	struct thermal_attr___5 *trip_type_attrs;
	struct thermal_attr___5 *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___9 *ops;
	struct thermal_zone_params___9 *tzp;
	struct thermal_governor___9 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_cooling_device_ops___10;

struct thermal_cooling_device___10 {
	int id;
	char *type;
	struct device___209 device;
	struct device_node___93 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___10 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct thermal_cooling_device_ops___10 {
	int (*get_max_state)(struct thermal_cooling_device___10 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___10 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___10 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___10 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___10 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___10 *, u32, long unsigned int *);
};

struct thermal_attr___5 {
	struct device_attribute___44 attr;
	char name[20];
};

struct thermal_bind_params___9;

struct thermal_zone_params___9 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___9 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___9 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___9 *);
	void (*unbind_from_tz)(struct thermal_zone_device___9 *);
	int (*throttle)(struct thermal_zone_device___9 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___9 {
	struct thermal_cooling_device___10 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___9 *, struct thermal_cooling_device___10 *);
};

struct dev_pm_qos_request___25 {
	enum dev_pm_qos_req_type type;
	union {
		struct plist_node pnode;
		struct pm_qos_flags_request flr;
		struct freq_qos_request freq;
	} data;
	struct device___209 *dev;
};

struct thermal_instance___4 {
	int id;
	char name[20];
	struct thermal_zone_device___9 *tz;
	struct thermal_cooling_device___10 *cdev;
	int trip;
	bool initialized;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___44 attr;
	char weight_attr_name[20];
	struct device_attribute___44 weight_attr;
	struct list_head tz_node;
	struct list_head cdev_node;
	unsigned int weight;
};

struct thermal_zone_device___10;

struct thermal_zone_device_ops___10 {
	int (*bind)(struct thermal_zone_device___10 *, struct thermal_cooling_device___5 *);
	int (*unbind)(struct thermal_zone_device___10 *, struct thermal_cooling_device___5 *);
	int (*get_temp)(struct thermal_zone_device___10 *, int *);
	int (*set_trips)(struct thermal_zone_device___10 *, int, int);
	int (*change_mode)(struct thermal_zone_device___10 *, enum thermal_device_mode);
	int (*get_trip_type)(struct thermal_zone_device___10 *, int, enum thermal_trip_type *);
	int (*get_trip_temp)(struct thermal_zone_device___10 *, int, int *);
	int (*set_trip_temp)(struct thermal_zone_device___10 *, int, int);
	int (*get_trip_hyst)(struct thermal_zone_device___10 *, int, int *);
	int (*set_trip_hyst)(struct thermal_zone_device___10 *, int, int);
	int (*get_crit_temp)(struct thermal_zone_device___10 *, int *);
	int (*set_emul_temp)(struct thermal_zone_device___10 *, int);
	int (*get_trend)(struct thermal_zone_device___10 *, int, enum thermal_trend *);
	void (*hot)(struct thermal_zone_device___10 *);
	void (*critical)(struct thermal_zone_device___10 *);
};

struct thermal_attr___6;

struct thermal_zone_params___10;

struct thermal_governor___10;

struct thermal_zone_device___10 {
	int id;
	char type[20];
	struct device___208 device;
	struct attribute_group___218 trips_attribute_group;
	struct thermal_attr___6 *trip_temp_attrs;
	struct thermal_attr___6 *trip_type_attrs;
	struct thermal_attr___6 *trip_hyst_attrs;
	enum thermal_device_mode mode;
	void *devdata;
	int trips;
	long unsigned int trips_disabled;
	long unsigned int passive_delay_jiffies;
	long unsigned int polling_delay_jiffies;
	int temperature;
	int last_temperature;
	int emul_temperature;
	int passive;
	int prev_low_trip;
	int prev_high_trip;
	atomic_t need_update;
	struct thermal_zone_device_ops___10 *ops;
	struct thermal_zone_params___10 *tzp;
	struct thermal_governor___10 *governor;
	void *governor_data;
	struct list_head thermal_instances;
	struct ida ida;
	struct mutex lock;
	struct list_head node;
	struct delayed_work poll_queue;
	enum thermal_notify_event notify_event;
};

struct thermal_attr___6 {
	struct device_attribute___39 attr;
	char name[20];
};

struct thermal_bind_params___10;

struct thermal_zone_params___10 {
	char governor_name[20];
	bool no_hwmon;
	int num_tbps;
	struct thermal_bind_params___10 *tbp;
	u32 sustainable_power;
	s32 k_po;
	s32 k_pu;
	s32 k_i;
	s32 k_d;
	s32 integral_cutoff;
	int slope;
	int offset;
};

struct thermal_governor___10 {
	char name[20];
	int (*bind_to_tz)(struct thermal_zone_device___10 *);
	void (*unbind_from_tz)(struct thermal_zone_device___10 *);
	int (*throttle)(struct thermal_zone_device___10 *, int);
	struct list_head governor_list;
};

struct thermal_bind_params___10 {
	struct thermal_cooling_device___5 *cdev;
	int weight;
	int trip_mask;
	long unsigned int *binding_limits;
	int (*match)(struct thermal_zone_device___10 *, struct thermal_cooling_device___5 *);
};

struct trace_event_raw_thermal_power_allocator {
	struct trace_entry ent;
	int tz_id;
	u32 __data_loc_req_power;
	u32 total_req_power;
	u32 __data_loc_granted_power;
	u32 total_granted_power;
	size_t num_actors;
	u32 power_range;
	u32 max_allocatable_power;
	int current_temp;
	s32 delta_temp;
	char __data[0];
};

struct trace_event_raw_thermal_power_allocator_pid {
	struct trace_entry ent;
	int tz_id;
	s32 err;
	s32 err_integral;
	s64 p;
	s64 i;
	s64 d;
	s32 output;
	char __data[0];
};

struct trace_event_data_offsets_thermal_power_allocator {
	u32 req_power;
	u32 granted_power;
};

struct trace_event_data_offsets_thermal_power_allocator_pid {};

typedef void (*btf_trace_thermal_power_allocator)(void *, struct thermal_zone_device___10 *, u32 *, u32, u32 *, u32, size_t, u32, u32, int, s32);

typedef void (*btf_trace_thermal_power_allocator_pid)(void *, struct thermal_zone_device___10 *, s32, s32, s64, s64, s64, s32);

struct thermal_instance___5 {
	int id;
	char name[20];
	struct thermal_zone_device___10 *tz;
	struct thermal_cooling_device___5 *cdev;
	int trip;
	bool initialized;
	long unsigned int upper;
	long unsigned int lower;
	long unsigned int target;
	char attr_name[20];
	struct device_attribute___39 attr;
	char weight_attr_name[20];
	struct device_attribute___39 weight_attr;
	struct list_head tz_node;
	struct list_head cdev_node;
	unsigned int weight;
};

struct power_allocator_params {
	bool allocated_tzp;
	s64 err_integral;
	s32 prev_err;
	int trip_switch_on;
	int trip_max_desired_temperature;
	u32 sustainable_power;
};

struct cpufreq_governor___5;

struct cpufreq_policy___5 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___5 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___42 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___45 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___8 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___5 {
	char name[16];
	int (*init)(struct cpufreq_policy___5 *);
	void (*exit)(struct cpufreq_policy___5 *);
	int (*start)(struct cpufreq_policy___5 *);
	void (*stop)(struct cpufreq_policy___5 *);
	void (*limits)(struct cpufreq_policy___5 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___5 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___5 *, unsigned int);
	struct list_head governor_list;
	struct module___8 *owner;
	u8 flags;
};

struct cpufreq_cooling_device {
	u32 last_load;
	unsigned int cpufreq_state;
	unsigned int max_level;
	struct em_perf_domain *em;
	struct cpufreq_policy___5 *policy;
	struct freq_qos_request qos_req;
};

struct idle_inject_device;

struct cpuidle_cooling_device {
	struct idle_inject_device *ii_dev;
	long unsigned int state;
};

enum devfreq_timer {
	DEVFREQ_TIMER_DEFERRABLE = 0,
	DEVFREQ_TIMER_DELAYED = 1,
	DEVFREQ_TIMER_NUM = 2,
};

struct devfreq_dev_profile {
	long unsigned int initial_freq;
	unsigned int polling_ms;
	enum devfreq_timer timer;
	bool is_cooling_device;
	int (*target)(struct device___189 *, long unsigned int *, u32);
	int (*get_dev_status)(struct device___189 *, struct devfreq_dev_status *);
	int (*get_cur_freq)(struct device___189 *, long unsigned int *);
	void (*exit)(struct device___189 *);
	long unsigned int *freq_table;
	unsigned int max_state;
};

struct devfreq_stats {
	unsigned int total_trans;
	unsigned int *trans_table;
	u64 *time_in_state;
	u64 last_update;
};

struct devfreq_governor;

struct devfreq {
	struct list_head node;
	struct mutex lock;
	struct device___189 dev;
	struct devfreq_dev_profile *profile;
	const struct devfreq_governor *governor;
	struct opp_table *opp_table;
	struct notifier_block nb;
	struct delayed_work work;
	long unsigned int previous_freq;
	struct devfreq_dev_status last_status;
	void *data;
	struct dev_pm_qos_request___23 user_min_freq_req;
	struct dev_pm_qos_request___23 user_max_freq_req;
	long unsigned int scaling_min_freq;
	long unsigned int scaling_max_freq;
	bool stop_polling;
	long unsigned int suspend_freq;
	long unsigned int resume_freq;
	atomic_t suspend_count;
	struct devfreq_stats stats;
	struct srcu_notifier_head transition_notifier_list;
	struct thermal_cooling_device___8 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct devfreq_cooling_power {
	int (*get_real_power)(struct devfreq *, u32 *, long unsigned int, long unsigned int);
};

struct devfreq_cooling_device {
	struct thermal_cooling_device___8 *cdev;
	struct devfreq *devfreq;
	long unsigned int cooling_state;
	u32 *freq_table;
	size_t max_state;
	struct devfreq_cooling_power *power_ops;
	u32 res_util;
	int capped_state;
	struct dev_pm_qos_request___23 req_max_freq;
	struct em_perf_domain *em_pd;
};

struct thermal_trip___2 {
	struct device_node___2 *np;
	int temperature;
	int hysteresis;
	enum thermal_trip_type type;
};

struct armada_thermal_data;

struct armada_thermal_priv {
	struct device___194 *dev;
	struct regmap *syscon;
	char zone_name[20];
	struct mutex update_lock;
	struct armada_thermal_data *data;
	struct thermal_zone_device___5 *overheat_sensor;
	int interrupt_source;
	int current_channel;
	long int current_threshold;
	long int current_hysteresis;
};

struct armada_thermal_data {
	void (*init)(struct platform_device___37 *, struct armada_thermal_priv *);
	s64 coef_b;
	s64 coef_m;
	u32 coef_div;
	bool inverted;
	bool signed_sample;
	unsigned int temp_shift;
	unsigned int temp_mask;
	unsigned int thresh_shift;
	unsigned int hyst_shift;
	unsigned int hyst_mask;
	u32 is_valid_bit;
	unsigned int syscon_control0_off;
	unsigned int syscon_control1_off;
	unsigned int syscon_status_off;
	unsigned int dfx_irq_cause_off;
	unsigned int dfx_irq_mask_off;
	unsigned int dfx_overheat_irq;
	unsigned int dfx_server_irq_mask_off;
	unsigned int dfx_server_irq_en;
	unsigned int cpu_nr;
};

enum drvtype {
	LEGACY = 0,
	SYSCON = 1,
};

struct armada_drvdata {
	enum drvtype type;
	union {
		struct armada_thermal_priv *priv;
		struct thermal_zone_device___5 *tz;
	} data;
};

struct armada_thermal_sensor {
	struct armada_thermal_priv *priv;
	int id;
};

struct watchdog_info {
	__u32 options;
	__u32 firmware_version;
	__u8 identity[32];
};

struct watchdog_device;

struct watchdog_ops {
	struct module___19 *owner;
	int (*start)(struct watchdog_device *);
	int (*stop)(struct watchdog_device *);
	int (*ping)(struct watchdog_device *);
	unsigned int (*status)(struct watchdog_device *);
	int (*set_timeout)(struct watchdog_device *, unsigned int);
	int (*set_pretimeout)(struct watchdog_device *, unsigned int);
	unsigned int (*get_timeleft)(struct watchdog_device *);
	int (*restart)(struct watchdog_device *, long unsigned int, void *);
	long int (*ioctl)(struct watchdog_device *, unsigned int, long unsigned int);
};

struct watchdog_governor;

struct watchdog_core_data;

struct watchdog_device {
	int id;
	struct device___15 *parent;
	const struct attribute_group___17 **groups;
	const struct watchdog_info *info;
	const struct watchdog_ops *ops;
	const struct watchdog_governor *gov;
	unsigned int bootstatus;
	unsigned int timeout;
	unsigned int pretimeout;
	unsigned int min_timeout;
	unsigned int max_timeout;
	unsigned int min_hw_heartbeat_ms;
	unsigned int max_hw_heartbeat_ms;
	struct notifier_block reboot_nb;
	struct notifier_block restart_nb;
	struct notifier_block pm_nb;
	void *driver_data;
	struct watchdog_core_data *wd_data;
	long unsigned int status;
	struct list_head deferred;
};

struct watchdog_governor {
	const char name[20];
	void (*pretimeout)(struct watchdog_device *);
};

struct kthread_work___8;

typedef void (*kthread_work_func_t___8)(struct kthread_work___8 *);

struct kthread_worker___8;

struct kthread_work___8 {
	struct list_head node;
	kthread_work_func_t___8 func;
	struct kthread_worker___8 *worker;
	int canceling;
};

struct watchdog_core_data {
	struct device___15 dev;
	struct cdev___10 cdev;
	struct watchdog_device *wdd;
	struct mutex lock;
	ktime_t last_keepalive;
	ktime_t last_hw_keepalive;
	ktime_t open_deadline;
	struct hrtimer timer;
	struct kthread_work___8 work;
	long unsigned int status;
};

struct kthread_worker___8 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___19 *task;
	struct kthread_work___8 *current_work;
};

struct cdev___63 {
	struct kobject___41 kobj;
	struct module___8 *owner;
	const struct file_operations___185 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct watchdog_device___2;

struct watchdog_ops___2 {
	struct module___8 *owner;
	int (*start)(struct watchdog_device___2 *);
	int (*stop)(struct watchdog_device___2 *);
	int (*ping)(struct watchdog_device___2 *);
	unsigned int (*status)(struct watchdog_device___2 *);
	int (*set_timeout)(struct watchdog_device___2 *, unsigned int);
	int (*set_pretimeout)(struct watchdog_device___2 *, unsigned int);
	unsigned int (*get_timeleft)(struct watchdog_device___2 *);
	int (*restart)(struct watchdog_device___2 *, long unsigned int, void *);
	long int (*ioctl)(struct watchdog_device___2 *, unsigned int, long unsigned int);
};

struct watchdog_governor___2;

struct watchdog_core_data___2;

struct watchdog_device___2 {
	int id;
	struct device___209 *parent;
	const struct attribute_group___41 **groups;
	const struct watchdog_info *info;
	const struct watchdog_ops___2 *ops;
	const struct watchdog_governor___2 *gov;
	unsigned int bootstatus;
	unsigned int timeout;
	unsigned int pretimeout;
	unsigned int min_timeout;
	unsigned int max_timeout;
	unsigned int min_hw_heartbeat_ms;
	unsigned int max_hw_heartbeat_ms;
	struct notifier_block reboot_nb;
	struct notifier_block restart_nb;
	struct notifier_block pm_nb;
	void *driver_data;
	struct watchdog_core_data___2 *wd_data;
	long unsigned int status;
	struct list_head deferred;
};

struct watchdog_governor___2 {
	const char name[20];
	void (*pretimeout)(struct watchdog_device___2 *);
};

struct kthread_work___9;

typedef void (*kthread_work_func_t___9)(struct kthread_work___9 *);

struct kthread_worker___9;

struct kthread_work___9 {
	struct list_head node;
	kthread_work_func_t___9 func;
	struct kthread_worker___9 *worker;
	int canceling;
};

struct watchdog_core_data___2 {
	struct device___209 dev;
	struct cdev___63 cdev;
	struct watchdog_device___2 *wdd;
	struct mutex lock;
	ktime_t last_keepalive;
	ktime_t last_hw_keepalive;
	ktime_t open_deadline;
	struct hrtimer timer;
	struct kthread_work___9 work;
	long unsigned int status;
};

struct kthread_worker___9 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___45 *task;
	struct kthread_work___9 *current_work;
};

struct watchdog_pretimeout {
	struct watchdog_device___2 *wdd;
	struct list_head entry;
};

struct governor_priv {
	struct watchdog_governor___2 *gov;
	struct list_head entry;
};

struct rtd119x_watchdog_device {
	struct watchdog_device___2 wdt_dev;
	void *base;
	struct clk *clk;
};

struct dentry___231;

struct super_block___231;

struct module___215;

struct file_system_type___231 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___231 * (*mount)(struct file_system_type___231 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___231 *);
	struct module___215 *owner;
	struct file_system_type___231 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___231;

struct kiocb___231;

struct iov_iter___151;

struct poll_table_struct___156;

struct vm_area_struct___236;

struct inode___231;

struct file_lock___231;

struct page___236;

struct seq_file___206;

struct file_operations___232 {
	struct module___215 *owner;
	loff_t (*llseek)(struct file___231 *, loff_t, int);
	ssize_t (*read)(struct file___231 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___231 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___231 *, struct iov_iter___151 *);
	ssize_t (*write_iter)(struct kiocb___231 *, struct iov_iter___151 *);
	int (*iopoll)(struct kiocb___231 *, bool);
	int (*iterate)(struct file___231 *, struct dir_context *);
	int (*iterate_shared)(struct file___231 *, struct dir_context *);
	__poll_t (*poll)(struct file___231 *, struct poll_table_struct___156 *);
	long int (*unlocked_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___231 *, struct vm_area_struct___236 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___231 *, struct file___231 *);
	int (*flush)(struct file___231 *, fl_owner_t);
	int (*release)(struct inode___231 *, struct file___231 *);
	int (*fsync)(struct file___231 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___231 *, int);
	int (*lock)(struct file___231 *, int, struct file_lock___231 *);
	ssize_t (*sendpage)(struct file___231 *, struct page___236 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___231 *, long unsigned int);
	int (*flock)(struct file___231 *, int, struct file_lock___231 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___231 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___231 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___231 *, long int, struct file_lock___231 **, void **);
	long int (*fallocate)(struct file___231 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___206 *, struct file___231 *);
	ssize_t (*copy_file_range)(struct file___231 *, loff_t, struct file___231 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___231 *, loff_t, struct file___231 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___231 *, loff_t, loff_t, int);
};

struct vmacache___236 {
	u64 seqnum;
	struct vm_area_struct___236 *vmas[4];
};

struct page_frag___236 {
	struct page___236 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___237;

struct pid___208;

struct nsproxy___217;

struct signal_struct___232;

struct bio_list___124;

struct backing_dev_info___113;

struct io_context___124;

struct css_set___161;

struct request_queue___124;

struct vm_struct___214;

struct task_struct___238 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___238 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___237 *mm;
	struct mm_struct___237 *active_mm;
	struct vmacache___236 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___238 *real_parent;
	struct task_struct___238 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___238 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___208 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___217 *nsproxy;
	struct signal_struct___232 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___238 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___124 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___113 *backing_dev_info;
	struct io_context___124 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___161 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___236 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___124 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___238 *oom_reaper_list;
	struct vm_struct___214 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___82 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___219;

struct kobj_type___219;

struct kernfs_node___219;

struct kobject___219 {
	const char *name;
	struct list_head entry;
	struct kobject___219 *parent;
	struct kset___219 *kset;
	struct kobj_type___219 *ktype;
	struct kernfs_node___219 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___216 {
	struct kobject___219 kobj;
	struct module___215 *mod;
	struct kobject___219 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___215 {
	struct module___215 *mod;
	struct latch_tree_node node;
};

struct module_layout___215 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___215 mtn;
};

struct module_attribute___215;

struct kernel_param___215;

struct module___215 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___216 mkobj;
	struct module_attribute___215 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___219 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___215 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___215 core_layout;
	struct module_layout___215 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___208;

struct upid___208 {
	int nr;
	struct pid_namespace___208 *ns;
};

struct pid_namespace___208 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___238 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___208 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___208 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___208 numbers[1];
};

typedef struct page___236 *pgtable_t___236;

struct address_space___231;

struct dev_pagemap___226;

struct page___236 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___231 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___236 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___236 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___237 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___226 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___226;

struct vm_area_struct___236 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___236 *vm_next;
	struct vm_area_struct___236 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___237 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___226 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___231 *vm_file;
	struct file___231 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___232 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___238 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___238 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___208 *pids[4];
	struct pid___208 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___237 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___236;

struct mm_struct___237 {
	struct {
		struct vm_area_struct___236 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___236 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___238 *owner;
		struct user_namespace___14 *user_ns;
		struct file___231 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___161;

struct nsproxy___217 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___208 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___161 *cgroup_ns;
};

struct bio___124;

struct bio_list___124 {
	struct bio___124 *head;
	struct bio___124 *tail;
};

struct cgroup_subsys_state___161;

struct bdi_writeback___113 {
	struct backing_dev_info___113 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___161 *memcg_css;
	struct cgroup_subsys_state___161 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___210;

struct backing_dev_info___113 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___113 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___210 *dev;
	char dev_name[64];
	struct device___210 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___231 *debug_dir;
};

struct io_cq___124;

struct io_context___124 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___124 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___161;

struct css_set___161 {
	struct cgroup_subsys_state___161 *subsys[14];
	refcount_t refcount;
	struct css_set___161 *dom_cset;
	struct cgroup___161 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___161 *mg_src_cgrp;
	struct cgroup___161 *mg_dst_cgrp;
	struct css_set___161 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___124;

struct blk_integrity___124 {
	const struct blk_integrity_profile___124 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___124 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___124 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___124;

struct elevator_queue___124;

struct blk_mq_ops___121;

struct blk_mq_hw_ctx___121;

struct gendisk___127;

struct blkcg_gq___115;

struct blk_trace___6;

struct blk_mq_tag_set___121;

struct request_queue___124 {
	struct request___124 *last_merge;
	struct elevator_queue___124 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___121 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___121 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___127 *disk;
	struct kobject___219 kobj;
	struct kobject___219 *mq_kobj;
	struct blk_integrity___124 integrity;
	struct device___210 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___115 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___6 *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___121 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___124 bio_split;
	struct dentry___231 *debugfs_dir;
	struct dentry___231 *sched_debugfs_dir;
	struct dentry___231 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___214 {
	struct vm_struct___214 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___236 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___231;

struct address_space___231 {
	struct inode___231 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___231 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___226;

struct dev_pagemap___226 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___226 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___231;

struct path___231 {
	struct vfsmount___231 *mnt;
	struct dentry___231 *dentry;
};

struct fown_struct___208 {
	rwlock_t lock;
	struct pid___208 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___231 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___231 f_path;
	struct inode___231 *f_inode;
	const struct file_operations___232 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___208 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___231 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___226;

struct vm_operations_struct___226 {
	void (*open)(struct vm_area_struct___236 *);
	void (*close)(struct vm_area_struct___236 *);
	int (*may_split)(struct vm_area_struct___236 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___236 *);
	int (*mprotect)(struct vm_area_struct___236 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___226 *);
	vm_fault_t (*huge_fault)(struct vm_fault___226 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___226 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___236 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___226 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___226 *);
	int (*access)(struct vm_area_struct___236 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___236 *);
	int (*set_policy)(struct vm_area_struct___236 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___236 *, long unsigned int);
	struct page___236 * (*find_special_page)(struct vm_area_struct___236 *, long unsigned int);
};

struct core_thread___236 {
	struct task_struct___238 *task;
	struct core_thread___236 *next;
};

struct core_state___236 {
	atomic_t nr_threads;
	struct core_thread___236 dumper;
	struct completion startup;
};

struct vm_fault___226 {
	const struct {
		struct vm_area_struct___236 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___236 *cow_page;
	struct page___236 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___236 prealloc_pte;
};

struct cgroup_subsys___161;

struct cgroup_subsys_state___161 {
	struct cgroup___161 *cgroup;
	struct cgroup_subsys___161 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___161 *parent;
};

struct cgroup_file___161 {
	struct kernfs_node___219 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___161 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___238 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___161;

struct cgroup_rstat_cpu___161;

struct cgroup___161 {
	struct cgroup_subsys_state___161 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___219 *kn;
	struct cgroup_file___161 procs_file;
	struct cgroup_file___161 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___161 *subsys[14];
	struct cgroup_root___161 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___161 *dom_cgrp;
	struct cgroup___161 *old_dom_cgrp;
	struct cgroup_rstat_cpu___161 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___161 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct dentry_operations___231;

struct dentry___231 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___231 *d_parent;
	struct qstr d_name;
	struct inode___231 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___231 *d_op;
	struct super_block___231 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___231;

struct inode___231 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___231 *i_op;
	struct super_block___231 *i_sb;
	struct address_space___231 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___113 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___232 *i_fop;
		void (*free_inode)(struct inode___231 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___231 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___231 {
	int (*d_revalidate)(struct dentry___231 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___231 *, unsigned int);
	int (*d_hash)(const struct dentry___231 *, struct qstr *);
	int (*d_compare)(const struct dentry___231 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___231 *);
	int (*d_init)(struct dentry___231 *);
	void (*d_release)(struct dentry___231 *);
	void (*d_prune)(struct dentry___231 *);
	void (*d_iput)(struct dentry___231 *, struct inode___231 *);
	char * (*d_dname)(struct dentry___231 *, char *, int);
	struct vfsmount___231 * (*d_automount)(struct path___231 *);
	int (*d_manage)(const struct path___231 *, bool);
	struct dentry___231 * (*d_real)(struct dentry___231 *, const struct inode___231 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___231;

struct mem_dqinfo___231 {
	struct quota_format_type___231 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___231;

struct quota_info___231 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___231 *files[3];
	struct mem_dqinfo___231 info[3];
	const struct quota_format_ops___231 *ops[3];
};

struct rcuwait___232 {
	struct task_struct___238 *task;
};

struct percpu_rw_semaphore___232 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___232 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___231 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___232 rw_sem[3];
};

struct super_operations___231;

struct dquot_operations___231;

struct quotactl_ops___231;

struct block_device___127;

struct super_block___231 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___231 *s_type;
	const struct super_operations___231 *s_op;
	const struct dquot_operations___231 *dq_op;
	const struct quotactl_ops___231 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___231 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___127 *s_bdev;
	struct backing_dev_info___113 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___231 s_dquot;
	struct sb_writers___231 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___231 *s_d_op;
	int cleancache_poolid;
	struct shrinker___103 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___231 {
	struct dentry___231 *mnt_root;
	struct super_block___231 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct io_cq___124 {
	struct request_queue___124 *q;
	struct io_context___124 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___109;

struct kiocb___231 {
	struct file___231 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___231 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___109 *ki_waitq;
	};
};

struct iattr___231 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___231 *ia_file;
};

struct dquot___231 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___231 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___231 {
	int qf_fmt_id;
	const struct quota_format_ops___231 *qf_ops;
	struct module___215 *qf_owner;
	struct quota_format_type___231 *qf_next;
};

struct quota_format_ops___231 {
	int (*check_quota_file)(struct super_block___231 *, int);
	int (*read_file_info)(struct super_block___231 *, int);
	int (*write_file_info)(struct super_block___231 *, int);
	int (*free_file_info)(struct super_block___231 *, int);
	int (*read_dqblk)(struct dquot___231 *);
	int (*commit_dqblk)(struct dquot___231 *);
	int (*release_dqblk)(struct dquot___231 *);
	int (*get_next_id)(struct super_block___231 *, struct kqid *);
};

struct dquot_operations___231 {
	int (*write_dquot)(struct dquot___231 *);
	struct dquot___231 * (*alloc_dquot)(struct super_block___231 *, int);
	void (*destroy_dquot)(struct dquot___231 *);
	int (*acquire_dquot)(struct dquot___231 *);
	int (*release_dquot)(struct dquot___231 *);
	int (*mark_dirty)(struct dquot___231 *);
	int (*write_info)(struct super_block___231 *, int);
	qsize_t * (*get_reserved_space)(struct inode___231 *);
	int (*get_projid)(struct inode___231 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___231 *, qsize_t *);
	int (*get_next_id)(struct super_block___231 *, struct kqid *);
};

struct quotactl_ops___231 {
	int (*quota_on)(struct super_block___231 *, int, int, const struct path___231 *);
	int (*quota_off)(struct super_block___231 *, int);
	int (*quota_enable)(struct super_block___231 *, unsigned int);
	int (*quota_disable)(struct super_block___231 *, unsigned int);
	int (*quota_sync)(struct super_block___231 *, int);
	int (*set_info)(struct super_block___231 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___231 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___231 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___231 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___231 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___231 *, unsigned int);
};

struct wait_page_queue___109 {
	struct page___236 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___113;

struct readahead_control___109;

struct address_space_operations___231 {
	int (*writepage)(struct page___236 *, struct writeback_control___113 *);
	int (*readpage)(struct file___231 *, struct page___236 *);
	int (*writepages)(struct address_space___231 *, struct writeback_control___113 *);
	int (*set_page_dirty)(struct page___236 *);
	int (*readpages)(struct file___231 *, struct address_space___231 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___109 *);
	int (*write_begin)(struct file___231 *, struct address_space___231 *, loff_t, unsigned int, unsigned int, struct page___236 **, void **);
	int (*write_end)(struct file___231 *, struct address_space___231 *, loff_t, unsigned int, unsigned int, struct page___236 *, void *);
	sector_t (*bmap)(struct address_space___231 *, sector_t);
	void (*invalidatepage)(struct page___236 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___236 *, gfp_t);
	void (*freepage)(struct page___236 *);
	ssize_t (*direct_IO)(struct kiocb___231 *, struct iov_iter___151 *);
	int (*migratepage)(struct address_space___231 *, struct page___236 *, struct page___236 *, enum migrate_mode);
	bool (*isolate_page)(struct page___236 *, isolate_mode_t);
	void (*putback_page)(struct page___236 *);
	int (*launder_page)(struct page___236 *);
	int (*is_partially_uptodate)(struct page___236 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___236 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___231 *, struct page___236 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___231 *, sector_t *);
	void (*swap_deactivate)(struct file___231 *);
};

struct writeback_control___113 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___113 *wb;
	struct inode___231 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___109 {
	struct file___231 *file;
	struct address_space___231 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___148;

struct iov_iter___151 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___148 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___231 {
	struct dentry___231 * (*lookup)(struct inode___231 *, struct dentry___231 *, unsigned int);
	const char * (*get_link)(struct dentry___231 *, struct inode___231 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___231 *, int);
	struct posix_acl * (*get_acl)(struct inode___231 *, int, bool);
	int (*readlink)(struct dentry___231 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___231 *, struct dentry___231 *, umode_t, bool);
	int (*link)(struct dentry___231 *, struct inode___231 *, struct dentry___231 *);
	int (*unlink)(struct inode___231 *, struct dentry___231 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___231 *, struct dentry___231 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___231 *, struct dentry___231 *, umode_t);
	int (*rmdir)(struct inode___231 *, struct dentry___231 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___231 *, struct dentry___231 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___231 *, struct dentry___231 *, struct inode___231 *, struct dentry___231 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___231 *, struct iattr___231 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___231 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___231 *, char *, size_t);
	int (*fiemap)(struct inode___231 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___231 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___231 *, struct dentry___231 *, struct file___231 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___231 *, struct dentry___231 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___231 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___231 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___231 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___231 {
	void (*fl_copy_lock)(struct file_lock___231 *, struct file_lock___231 *);
	void (*fl_release_private)(struct file_lock___231 *);
};

struct fasync_struct___231;

struct lock_manager_operations___231;

struct file_lock___231 {
	struct file_lock___231 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___231 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___231 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___231 *fl_ops;
	const struct lock_manager_operations___231 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___231 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___231 *);
	int (*lm_grant)(struct file_lock___231 *, int);
	bool (*lm_break)(struct file_lock___231 *);
	int (*lm_change)(struct file_lock___231 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___231 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___231 *);
};

struct fasync_struct___231 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___231 *fa_next;
	struct file___231 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___231 {
	struct inode___231 * (*alloc_inode)(struct super_block___231 *);
	void (*destroy_inode)(struct inode___231 *);
	void (*free_inode)(struct inode___231 *);
	void (*dirty_inode)(struct inode___231 *, int);
	int (*write_inode)(struct inode___231 *, struct writeback_control___113 *);
	int (*drop_inode)(struct inode___231 *);
	void (*evict_inode)(struct inode___231 *);
	void (*put_super)(struct super_block___231 *);
	int (*sync_fs)(struct super_block___231 *, int);
	int (*freeze_super)(struct super_block___231 *);
	int (*freeze_fs)(struct super_block___231 *);
	int (*thaw_super)(struct super_block___231 *);
	int (*unfreeze_fs)(struct super_block___231 *);
	int (*statfs)(struct dentry___231 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___231 *, int *, char *);
	void (*umount_begin)(struct super_block___231 *);
	int (*show_options)(struct seq_file___206 *, struct dentry___231 *);
	int (*show_devname)(struct seq_file___206 *, struct dentry___231 *);
	int (*show_path)(struct seq_file___206 *, struct dentry___231 *);
	int (*show_stats)(struct seq_file___206 *, struct dentry___231 *);
	ssize_t (*quota_read)(struct super_block___231 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___231 *, int, const char *, size_t, loff_t);
	struct dquot___231 ** (*get_dquots)(struct inode___231 *);
	long int (*nr_cached_objects)(struct super_block___231 *, struct shrink_control___103 *);
	long int (*free_cached_objects)(struct super_block___231 *, struct shrink_control___103 *);
	struct file___231 * (*real_loop)(struct file___231 *);
};

struct wakeup_source___210;

struct dev_pm_info___210 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___210 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___210 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___210;

struct bus_type___210;

struct device_driver___210;

struct dev_pm_domain___210;

struct fwnode_handle___206;

struct class___210;

struct attribute_group___219;

struct device___210 {
	struct kobject___219 kobj;
	struct device___210 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___210 *type;
	struct bus_type___210 *bus;
	struct device_driver___210 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___210 power;
	struct dev_pm_domain___210 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___206 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___210 *class;
	const struct attribute_group___219 **groups;
	void (*release)(struct device___210 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___127 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___231 *bd_inode;
	struct super_block___231 *bd_super;
	void *bd_claiming;
	struct device___210 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___219 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___127 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___231 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___163)(struct file___231 *, wait_queue_head_t *, struct poll_table_struct___156 *);

struct poll_table_struct___156 {
	poll_queue_proc___163 _qproc;
	__poll_t _key;
};

struct seq_operations___206;

struct seq_file___206 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___206 *op;
	int poll_event;
	const struct file___231 *file;
	void *private;
};

typedef void bio_end_io_t___124(struct bio___124 *);

struct bio_vec___148 {
	struct page___236 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___124;

struct bio___124 {
	struct bio___124 *bi_next;
	struct block_device___127 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___124 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___115 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___124 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___148 *bi_io_vec;
	struct bio_set___124 *bi_pool;
	struct bio_vec___148 bi_inline_vecs[0];
};

struct dev_pagemap_ops___226 {
	void (*page_free)(struct page___236 *);
	void (*kill)(struct dev_pagemap___226 *);
	void (*cleanup)(struct dev_pagemap___226 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___226 *);
};

struct fwnode_operations___206;

struct fwnode_handle___206 {
	struct fwnode_handle___206 *secondary;
	const struct fwnode_operations___206 *ops;
	struct device___210 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___206;

struct fwnode_endpoint___206;

struct fwnode_operations___206 {
	struct fwnode_handle___206 * (*get)(struct fwnode_handle___206 *);
	void (*put)(struct fwnode_handle___206 *);
	bool (*device_is_available)(const struct fwnode_handle___206 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___206 *, const struct device___210 *);
	bool (*property_present)(const struct fwnode_handle___206 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___206 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___206 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___206 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*get_parent)(const struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*get_next_child_node)(const struct fwnode_handle___206 *, struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*get_named_child_node)(const struct fwnode_handle___206 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___206 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___206 *);
	struct fwnode_handle___206 * (*graph_get_next_endpoint)(const struct fwnode_handle___206 *, struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*graph_get_remote_endpoint)(const struct fwnode_handle___206 *);
	struct fwnode_handle___206 * (*graph_get_port_parent)(struct fwnode_handle___206 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___206 *, struct fwnode_endpoint___206 *);
	int (*add_links)(struct fwnode_handle___206 *);
};

struct fwnode_endpoint___206 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___206 *local_fwnode;
};

struct fwnode_reference_args___206 {
	struct fwnode_handle___206 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___219;

struct kernfs_elem_dir___219 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___219 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___219;

struct kernfs_root___219 {
	struct kernfs_node___219 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___219 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___219 {
	struct kernfs_node___219 *target_kn;
};

struct kernfs_ops___219;

struct kernfs_elem_attr___219 {
	const struct kernfs_ops___219 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___219 *notify_next;
};

struct kernfs_node___219 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___219 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___219 dir;
		struct kernfs_elem_symlink___219 symlink;
		struct kernfs_elem_attr___219 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___219;

struct kernfs_ops___219 {
	int (*open)(struct kernfs_open_file___219 *);
	void (*release)(struct kernfs_open_file___219 *);
	int (*seq_show)(struct seq_file___206 *, void *);
	void * (*seq_start)(struct seq_file___206 *, loff_t *);
	void * (*seq_next)(struct seq_file___206 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___206 *, void *);
	ssize_t (*read)(struct kernfs_open_file___219 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___219 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___219 *, struct poll_table_struct___156 *);
	int (*mmap)(struct kernfs_open_file___219 *, struct vm_area_struct___236 *);
};

struct kernfs_syscall_ops___219 {
	int (*show_options)(struct seq_file___206 *, struct kernfs_root___219 *);
	int (*mkdir)(struct kernfs_node___219 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___219 *);
	int (*rename)(struct kernfs_node___219 *, struct kernfs_node___219 *, const char *);
	int (*show_path)(struct seq_file___206 *, struct kernfs_node___219 *, struct kernfs_root___219 *);
};

struct kernfs_open_file___219 {
	struct kernfs_node___219 *kn;
	struct file___231 *file;
	struct seq_file___206 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___226 *vm_ops;
};

struct bin_attribute___219;

struct attribute_group___219 {
	const char *name;
	umode_t (*is_visible)(struct kobject___219 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___219 *, struct bin_attribute___219 *, int);
	struct attribute **attrs;
	struct bin_attribute___219 **bin_attrs;
};

struct bin_attribute___219 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___231 * (*f_mapping)();
	ssize_t (*read)(struct file___231 *, struct kobject___219 *, struct bin_attribute___219 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___231 *, struct kobject___219 *, struct bin_attribute___219 *, char *, loff_t, size_t);
	int (*mmap)(struct file___231 *, struct kobject___219 *, struct bin_attribute___219 *, struct vm_area_struct___236 *);
};

struct sysfs_ops___219 {
	ssize_t (*show)(struct kobject___219 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___219 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___219;

struct kset___219 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___219 kobj;
	const struct kset_uevent_ops___219 *uevent_ops;
};

struct kobj_type___219 {
	void (*release)(struct kobject___219 *);
	const struct sysfs_ops___219 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___219 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___219 *);
	const void * (*namespace)(struct kobject___219 *);
	void (*get_ownership)(struct kobject___219 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___219 {
	int (* const filter)(struct kset___219 *, struct kobject___219 *);
	const char * (* const name)(struct kset___219 *, struct kobject___219 *);
	int (* const uevent)(struct kset___219 *, struct kobject___219 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___215 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___215 *);
	int (*get)(char *, const struct kernel_param___215 *);
	void (*free)(void *);
};

struct kparam_array___215;

struct kernel_param___215 {
	const char *name;
	struct module___215 *mod;
	const struct kernel_param_ops___215 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___215 *arr;
	};
};

struct kparam_array___215 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___215 *ops;
	void *elem;
};

struct module_attribute___215 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___215 *, struct module_kobject___216 *, char *);
	ssize_t (*store)(struct module_attribute___215 *, struct module_kobject___216 *, const char *, size_t);
	void (*setup)(struct module___215 *, const char *);
	int (*test)(struct module___215 *);
	void (*free)(struct module___215 *);
};

struct cgroup_namespace___161 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___161 *root_cset;
};

struct dev_pm_ops___210 {
	int (*prepare)(struct device___210 *);
	void (*complete)(struct device___210 *);
	int (*suspend)(struct device___210 *);
	int (*resume)(struct device___210 *);
	int (*freeze)(struct device___210 *);
	int (*thaw)(struct device___210 *);
	int (*poweroff)(struct device___210 *);
	int (*restore)(struct device___210 *);
	int (*suspend_late)(struct device___210 *);
	int (*resume_early)(struct device___210 *);
	int (*freeze_late)(struct device___210 *);
	int (*thaw_early)(struct device___210 *);
	int (*poweroff_late)(struct device___210 *);
	int (*restore_early)(struct device___210 *);
	int (*suspend_noirq)(struct device___210 *);
	int (*resume_noirq)(struct device___210 *);
	int (*freeze_noirq)(struct device___210 *);
	int (*thaw_noirq)(struct device___210 *);
	int (*poweroff_noirq)(struct device___210 *);
	int (*restore_noirq)(struct device___210 *);
	int (*runtime_suspend)(struct device___210 *);
	int (*runtime_resume)(struct device___210 *);
	int (*runtime_idle)(struct device___210 *);
};

struct wakeup_source___210 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___210 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___210 {
	struct dev_pm_ops___210 ops;
	int (*start)(struct device___210 *);
	void (*detach)(struct device___210 *, bool);
	int (*activate)(struct device___210 *);
	void (*sync)(struct device___210 *);
	void (*dismiss)(struct device___210 *);
};

struct bus_type___210 {
	const char *name;
	const char *dev_name;
	struct device___210 *dev_root;
	const struct attribute_group___219 **bus_groups;
	const struct attribute_group___219 **dev_groups;
	const struct attribute_group___219 **drv_groups;
	int (*match)(struct device___210 *, struct device_driver___210 *);
	int (*uevent)(struct device___210 *, struct kobj_uevent_env *);
	int (*probe)(struct device___210 *);
	void (*sync_state)(struct device___210 *);
	void (*remove)(struct device___210 *);
	void (*shutdown)(struct device___210 *);
	int (*online)(struct device___210 *);
	int (*offline)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	int (*num_vf)(struct device___210 *);
	int (*dma_configure)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___210 {
	const char *name;
	struct bus_type___210 *bus;
	struct module___215 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___210 *);
	void (*sync_state)(struct device___210 *);
	int (*remove)(struct device___210 *);
	void (*shutdown)(struct device___210 *);
	int (*suspend)(struct device___210 *, pm_message_t);
	int (*resume)(struct device___210 *);
	const struct attribute_group___219 **groups;
	const struct attribute_group___219 **dev_groups;
	const struct dev_pm_ops___210 *pm;
	void (*coredump)(struct device___210 *);
	struct driver_private *p;
};

struct device_type___210 {
	const char *name;
	const struct attribute_group___219 **groups;
	int (*uevent)(struct device___210 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___210 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___210 *);
	const struct dev_pm_ops___210 *pm;
};

struct class___210 {
	const char *name;
	struct module___215 *owner;
	const struct attribute_group___219 **class_groups;
	const struct attribute_group___219 **dev_groups;
	struct kobject___219 *dev_kobj;
	int (*dev_uevent)(struct device___210 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___210 *, umode_t *);
	void (*class_release)(struct class___210 *);
	void (*dev_release)(struct device___210 *);
	int (*shutdown_pre)(struct device___210 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___210 *);
	void (*get_ownership)(struct device___210 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___210 *pm;
	struct subsys_private *p;
};

struct block_device_operations___124;

struct badblocks___3;

struct gendisk___127 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___127 *part0;
	const struct block_device_operations___124 *fops;
	struct request_queue___124 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___113 *bdi;
	struct kobject___219 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___219 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks___3 *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___124 {
	struct bio___124 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___148 *bip_vec;
	struct bio_vec___148 bip_inline_vecs[0];
};

struct blkcg___115;

struct blkg_policy_data___115;

struct blkcg_gq___115 {
	struct request_queue___124 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___115 *blkcg;
	struct blkcg_gq___115 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___115 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___124 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___124(struct request___124 *);

typedef void integrity_complete_fn___124(struct request___124 *, unsigned int);

struct blk_integrity_profile___124 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___124 *prepare_fn;
	integrity_complete_fn___124 *complete_fn;
	const char *name;
};

struct block_device_operations___124 {
	blk_qc_t (*submit_bio)(struct bio___124 *);
	int (*open)(struct block_device___127 *, fmode_t);
	void (*release)(struct gendisk___127 *, fmode_t);
	int (*rw_page)(struct block_device___127 *, sector_t, struct page___236 *, unsigned int);
	int (*ioctl)(struct block_device___127 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___127 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___127 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___127 *);
	int (*getgeo)(struct block_device___127 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___127 *, bool);
	void (*swap_slot_free_notify)(struct block_device___127 *, long unsigned int);
	int (*report_zones)(struct gendisk___127 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___127 *, umode_t *);
	struct module___215 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___127 *, sector_t *);
};

struct badblocks___3 {
	struct device___210 *dev;
	int count;
	int unacked_exist;
	int shift;
	u64 *page;
	int changed;
	seqlock_t lock;
	sector_t sector;
	sector_t size;
};

typedef void rq_end_io_fn___124(struct request___124 *, blk_status_t);

struct request___124 {
	struct request_queue___124 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___121 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___124 *bio;
	struct bio___124 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___148 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___124 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___124 *saved_end_io;
		} flush;
	};
	struct gendisk___127 *rq_disk;
	struct block_device___127 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___124 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___121 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___124 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___219 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___231 *debugfs_dir;
	struct dentry___231 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___124;

struct elevator_mq_ops___124 {
	int (*init_sched)(struct request_queue___124 *, struct elevator_type___124 *);
	void (*exit_sched)(struct elevator_queue___124 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___121 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___121 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___121 *);
	bool (*allow_merge)(struct request_queue___124 *, struct request___124 *, struct bio___124 *);
	bool (*bio_merge)(struct request_queue___124 *, struct bio___124 *, unsigned int);
	int (*request_merge)(struct request_queue___124 *, struct request___124 **, struct bio___124 *);
	void (*request_merged)(struct request_queue___124 *, struct request___124 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___124 *, struct request___124 *, struct request___124 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___124 *);
	void (*finish_request)(struct request___124 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___121 *, struct list_head *, bool);
	struct request___124 * (*dispatch_request)(struct blk_mq_hw_ctx___121 *);
	bool (*has_work)(struct blk_mq_hw_ctx___121 *);
	void (*completed_request)(struct request___124 *, u64);
	void (*requeue_request)(struct request___124 *);
	struct request___124 * (*former_request)(struct request_queue___124 *, struct request___124 *);
	struct request___124 * (*next_request)(struct request_queue___124 *, struct request___124 *);
	void (*init_icq)(struct io_cq___124 *);
	void (*exit_icq)(struct io_cq___124 *);
};

struct elv_fs_entry___124;

struct elevator_type___124 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___124 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___124 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___215 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___124 {
	struct elevator_type___124 *type;
	void *elevator_data;
	struct kobject___219 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___124 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___124 *, char *);
	ssize_t (*store)(struct elevator_queue___124 *, const char *, size_t);
};

struct blk_mq_queue_data___121;

struct blk_mq_ops___121 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___121 *, const struct blk_mq_queue_data___121 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___121 *);
	int (*get_budget)(struct request_queue___124 *);
	void (*put_budget)(struct request_queue___124 *, int);
	void (*set_rq_budget_token)(struct request___124 *, int);
	int (*get_rq_budget_token)(struct request___124 *);
	enum blk_eh_timer_return (*timeout)(struct request___124 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___121 *);
	void (*complete)(struct request___124 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___121 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___121 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___121 *, struct request___124 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___121 *, struct request___124 *, unsigned int);
	void (*initialize_rq_fn)(struct request___124 *);
	void (*cleanup_rq)(struct request___124 *);
	bool (*busy)(struct request_queue___124 *);
	int (*map_queues)(struct blk_mq_tag_set___121 *);
	void (*show_rq)(struct seq_file___206 *, struct request___124 *);
};

struct rchan___7;

struct blk_trace___6 {
	int trace_state;
	struct rchan___7 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___231 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_mq_tag_set___121 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___121 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___206 {
	void * (*start)(struct seq_file___206 *, loff_t *);
	void (*stop)(struct seq_file___206 *, void *);
	void * (*next)(struct seq_file___206 *, void *, loff_t *);
	int (*show)(struct seq_file___206 *, void *);
};

typedef struct poll_table_struct___156 poll_table___46;

struct proc_ops___23 {
	unsigned int proc_flags;
	int (*proc_open)(struct inode___231 *, struct file___231 *);
	ssize_t (*proc_read)(struct file___231 *, char *, size_t, loff_t *);
	ssize_t (*proc_read_iter)(struct kiocb___231 *, struct iov_iter___151 *);
	ssize_t (*proc_write)(struct file___231 *, const char *, size_t, loff_t *);
	loff_t (*proc_lseek)(struct file___231 *, loff_t, int);
	int (*proc_release)(struct inode___231 *, struct file___231 *);
	__poll_t (*proc_poll)(struct file___231 *, struct poll_table_struct___156 *);
	long int (*proc_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	long int (*proc_compat_ioctl)(struct file___231 *, unsigned int, long unsigned int);
	int (*proc_mmap)(struct file___231 *, struct vm_area_struct___236 *);
	long unsigned int (*proc_get_unmapped_area)(struct file___231 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
};

struct mdp_device_descriptor_s {
	__u32 number;
	__u32 major;
	__u32 minor;
	__u32 raid_disk;
	__u32 state;
	__u32 reserved[27];
};

typedef struct mdp_device_descriptor_s mdp_disk_t;

struct mdp_superblock_s {
	__u32 md_magic;
	__u32 major_version;
	__u32 minor_version;
	__u32 patch_version;
	__u32 gvalid_words;
	__u32 set_uuid0;
	__u32 ctime;
	__u32 level;
	__u32 size;
	__u32 nr_disks;
	__u32 raid_disks;
	__u32 md_minor;
	__u32 not_persistent;
	__u32 set_uuid1;
	__u32 set_uuid2;
	__u32 set_uuid3;
	__u32 gstate_creserved[16];
	__u32 utime;
	__u32 state;
	__u32 active_disks;
	__u32 working_disks;
	__u32 failed_disks;
	__u32 spare_disks;
	__u32 sb_csum;
	__u32 events_lo;
	__u32 events_hi;
	__u32 cp_events_lo;
	__u32 cp_events_hi;
	__u32 recovery_cp;
	__u64 reshape_position;
	__u32 new_level;
	__u32 delta_disks;
	__u32 new_layout;
	__u32 new_chunk;
	__u32 gstate_sreserved[14];
	__u32 layout;
	__u32 chunk_size;
	__u32 root_pv;
	__u32 root_block;
	__u32 pstate_reserved[60];
	mdp_disk_t disks[27];
	__u32 reserved[0];
	mdp_disk_t this_disk;
};

typedef struct mdp_superblock_s mdp_super_t;

struct mdp_superblock_1 {
	__le32 magic;
	__le32 major_version;
	__le32 feature_map;
	__le32 pad0;
	__u8 set_uuid[16];
	char set_name[32];
	__le64 ctime;
	__le32 level;
	__le32 layout;
	__le64 size;
	__le32 chunksize;
	__le32 raid_disks;
	union {
		__le32 bitmap_offset;
		struct {
			__le16 offset;
			__le16 size;
		} ppl;
	};
	__le32 new_level;
	__le64 reshape_position;
	__le32 delta_disks;
	__le32 new_layout;
	__le32 new_chunk;
	__le32 new_offset;
	__le64 data_offset;
	__le64 data_size;
	__le64 super_offset;
	union {
		__le64 recovery_offset;
		__le64 journal_tail;
	};
	__le32 dev_number;
	__le32 cnt_corrected_read;
	__u8 device_uuid[16];
	__u8 devflags;
	__u8 bblog_shift;
	__le16 bblog_size;
	__le32 bblog_offset;
	__le64 utime;
	__le64 events;
	__le64 resync_offset;
	__le32 sb_csum;
	__le32 max_dev;
	__u8 pad3[32];
	__le16 dev_roles[0];
};

struct mdu_version_s {
	int major;
	int minor;
	int patchlevel;
};

typedef struct mdu_version_s mdu_version_t;

struct mdu_array_info_s {
	int major_version;
	int minor_version;
	int patch_version;
	unsigned int ctime;
	int level;
	int size;
	int nr_disks;
	int raid_disks;
	int md_minor;
	int not_persistent;
	unsigned int utime;
	int state;
	int active_disks;
	int working_disks;
	int failed_disks;
	int spare_disks;
	int layout;
	int chunk_size;
};

typedef struct mdu_array_info_s mdu_array_info_t;

struct mdu_disk_info_s {
	int number;
	int major;
	int minor;
	int raid_disk;
	int state;
};

typedef struct mdu_disk_info_s mdu_disk_info_t;

struct mdu_bitmap_file_s {
	char pathname[4096];
};

typedef struct mdu_bitmap_file_s mdu_bitmap_file_t;

struct rchan_buf___7 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___7 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___231 *dentry;
	struct kref kref;
	struct page___236 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___7;

struct rchan___7 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___7 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___7 **buf;
	int is_global;
	struct list_head list;
	struct dentry___231 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___7 {
	int (*subbuf_start)(struct rchan_buf___7 *, void *, void *, size_t);
	struct dentry___231 * (*create_buf_file)(const char *, struct dentry___231 *, umode_t, struct rchan_buf___7 *, int *);
	int (*remove_buf_file)(struct dentry___231 *);
};

struct cftype___161;

struct cgroup_subsys___161 {
	struct cgroup_subsys_state___161 * (*css_alloc)(struct cgroup_subsys_state___161 *);
	int (*css_online)(struct cgroup_subsys_state___161 *);
	void (*css_offline)(struct cgroup_subsys_state___161 *);
	void (*css_released)(struct cgroup_subsys_state___161 *);
	void (*css_free)(struct cgroup_subsys_state___161 *);
	void (*css_reset)(struct cgroup_subsys_state___161 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___161 *, int);
	int (*css_extra_stat_show)(struct seq_file___206 *, struct cgroup_subsys_state___161 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___238 *, struct css_set___161 *);
	void (*cancel_fork)(struct task_struct___238 *, struct css_set___161 *);
	void (*fork)(struct task_struct___238 *);
	void (*exit)(struct task_struct___238 *);
	void (*release)(struct task_struct___238 *);
	void (*bind)(struct cgroup_subsys_state___161 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___161 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___161 *dfl_cftypes;
	struct cftype___161 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___161 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___161 *updated_children;
	struct cgroup___161 *updated_next;
};

struct cgroup_root___161 {
	struct kernfs_root___219 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___161 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___161 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___161 *ss;
	struct list_head node;
	struct kernfs_ops___219 *kf_ops;
	int (*open)(struct kernfs_open_file___219 *);
	void (*release)(struct kernfs_open_file___219 *);
	u64 (*read_u64)(struct cgroup_subsys_state___161 *, struct cftype___161 *);
	s64 (*read_s64)(struct cgroup_subsys_state___161 *, struct cftype___161 *);
	int (*seq_show)(struct seq_file___206 *, void *);
	void * (*seq_start)(struct seq_file___206 *, loff_t *);
	void * (*seq_next)(struct seq_file___206 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___206 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___161 *, struct cftype___161 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___161 *, struct cftype___161 *, s64);
	ssize_t (*write)(struct kernfs_open_file___219 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___219 *, struct poll_table_struct___156 *);
};

struct blk_mq_queue_data___121 {
	struct request___124 *rq;
	bool last;
};

struct blkcg_policy_data___115;

struct blkcg___115 {
	struct cgroup_subsys_state___161 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___115 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___115 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___115 {
	struct blkcg___115 *blkcg;
	int plid;
};

struct blkg_policy_data___115 {
	struct blkcg_gq___115 *blkg;
	int plid;
};

struct mddev;

struct md_rdev;

struct md_cluster_operations {
	int (*join)(struct mddev *, int);
	int (*leave)(struct mddev *);
	int (*slot_number)(struct mddev *);
	int (*resync_info_update)(struct mddev *, sector_t, sector_t);
	void (*resync_info_get)(struct mddev *, sector_t *, sector_t *);
	int (*metadata_update_start)(struct mddev *);
	int (*metadata_update_finish)(struct mddev *);
	void (*metadata_update_cancel)(struct mddev *);
	int (*resync_start)(struct mddev *);
	int (*resync_finish)(struct mddev *);
	int (*area_resyncing)(struct mddev *, int, sector_t, sector_t);
	int (*add_new_disk)(struct mddev *, struct md_rdev *);
	void (*add_new_disk_cancel)(struct mddev *);
	int (*new_disk_ack)(struct mddev *, bool);
	int (*remove_disk)(struct mddev *, struct md_rdev *);
	void (*load_bitmaps)(struct mddev *, int);
	int (*gather_bitmaps)(struct md_rdev *);
	int (*resize_bitmaps)(struct mddev *, sector_t, sector_t);
	int (*lock_all_bitmaps)(struct mddev *);
	void (*unlock_all_bitmaps)(struct mddev *);
	void (*update_size)(struct mddev *, sector_t);
};

struct md_cluster_info;

struct md_personality;

struct md_thread;

struct bitmap;

struct mddev {
	void *private;
	struct md_personality *pers;
	dev_t unit;
	int md_minor;
	struct list_head disks;
	long unsigned int flags;
	long unsigned int sb_flags;
	int suspended;
	atomic_t active_io;
	int ro;
	int sysfs_active;
	struct gendisk___127 *gendisk;
	struct kobject___219 kobj;
	int hold_active;
	int major_version;
	int minor_version;
	int patch_version;
	int persistent;
	int external;
	char metadata_type[17];
	int chunk_sectors;
	time64_t ctime;
	time64_t utime;
	int level;
	int layout;
	char clevel[16];
	int raid_disks;
	int max_disks;
	sector_t dev_sectors;
	sector_t array_sectors;
	int external_size;
	__u64 events;
	int can_decrease_events;
	char uuid[16];
	sector_t reshape_position;
	int delta_disks;
	int new_level;
	int new_layout;
	int new_chunk_sectors;
	int reshape_backwards;
	struct md_thread *thread;
	struct md_thread *sync_thread;
	char *last_sync_action;
	sector_t curr_resync;
	sector_t curr_resync_completed;
	long unsigned int resync_mark;
	sector_t resync_mark_cnt;
	sector_t curr_mark_cnt;
	sector_t resync_max_sectors;
	atomic64_t resync_mismatches;
	sector_t suspend_lo;
	sector_t suspend_hi;
	int sync_speed_min;
	int sync_speed_max;
	int parallel_resync;
	int ok_start_degraded;
	long unsigned int recovery;
	int recovery_disabled;
	int in_sync;
	struct mutex open_mutex;
	struct mutex reconfig_mutex;
	atomic_t active;
	atomic_t openers;
	int changed;
	int degraded;
	atomic_t recovery_active;
	wait_queue_head_t recovery_wait;
	sector_t recovery_cp;
	sector_t resync_min;
	sector_t resync_max;
	struct kernfs_node___219 *sysfs_state;
	struct kernfs_node___219 *sysfs_action;
	struct kernfs_node___219 *sysfs_completed;
	struct kernfs_node___219 *sysfs_degraded;
	struct kernfs_node___219 *sysfs_level;
	struct work_struct del_work;
	spinlock_t lock;
	wait_queue_head_t sb_wait;
	atomic_t pending_writes;
	unsigned int safemode;
	unsigned int safemode_delay;
	struct timer_list safemode_timer;
	struct percpu_ref writes_pending;
	int sync_checkers;
	struct request_queue___124 *queue;
	struct bitmap *bitmap;
	struct {
		struct file___231 *file;
		loff_t offset;
		long unsigned int space;
		loff_t default_offset;
		long unsigned int default_space;
		struct mutex mutex;
		long unsigned int chunksize;
		long unsigned int daemon_sleep;
		long unsigned int max_write_behind;
		int external;
		int nodes;
		char cluster_name[64];
	} bitmap_info;
	atomic_t max_corr_read_errors;
	struct list_head all_mddevs;
	const struct attribute_group___219 *to_remove;
	struct bio_set___124 bio_set;
	struct bio_set___124 sync_set;
	struct bio_set___124 io_acct_set;
	struct bio___124 *flush_bio;
	atomic_t flush_pending;
	ktime_t start_flush;
	ktime_t prev_flush_start;
	struct work_struct flush_work;
	struct work_struct event_work;
	mempool_t *serial_info_pool;
	void (*sync_super)(struct mddev *, struct md_rdev *);
	struct md_cluster_info *cluster_info;
	unsigned int good_device_nr;
	unsigned int noio_flag;
	bool has_superblocks: 1;
	bool fail_last_dev: 1;
	bool serialize_policy: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct serial_in_rdev;

struct md_rdev {
	struct list_head same_set;
	sector_t sectors;
	struct mddev *mddev;
	int last_events;
	struct block_device___127 *meta_bdev;
	struct block_device___127 *bdev;
	struct page___236 *sb_page;
	struct page___236 *bb_page;
	int sb_loaded;
	__u64 sb_events;
	sector_t data_offset;
	sector_t new_data_offset;
	sector_t sb_start;
	int sb_size;
	int preferred_minor;
	struct kobject___219 kobj;
	long unsigned int flags;
	wait_queue_head_t blocked_wait;
	int desc_nr;
	int raid_disk;
	int new_raid_disk;
	int saved_raid_disk;
	union {
		sector_t recovery_offset;
		sector_t journal_tail;
	};
	atomic_t nr_pending;
	atomic_t read_errors;
	time64_t last_read_error;
	atomic_t corrected_errors;
	struct serial_in_rdev *serial;
	struct work_struct del_work;
	struct kernfs_node___219 *sysfs_state;
	struct kernfs_node___219 *sysfs_unack_badblocks;
	struct kernfs_node___219 *sysfs_badblocks;
	struct badblocks___3 badblocks;
	struct {
		short int offset;
		unsigned int size;
		sector_t sector;
	} ppl;
};

struct serial_in_rdev {
	struct rb_root_cached serial_rb;
	spinlock_t serial_lock;
	wait_queue_head_t serial_io_wait;
};

enum flag_bits {
	Faulty = 0,
	In_sync = 1,
	Bitmap_sync = 2,
	WriteMostly = 3,
	AutoDetected = 4,
	Blocked = 5,
	WriteErrorSeen = 6,
	FaultRecorded = 7,
	BlockedBadBlocks = 8,
	WantReplacement = 9,
	Replacement = 10,
	Candidate = 11,
	Journal = 12,
	ClusterRemove = 13,
	RemoveSynchronized = 14,
	ExternalBbl = 15,
	FailFast = 16,
	LastDev = 17,
	CollisionCheck = 18,
};

enum mddev_flags {
	MD_ARRAY_FIRST_USE = 0,
	MD_CLOSING = 1,
	MD_JOURNAL_CLEAN = 2,
	MD_HAS_JOURNAL = 3,
	MD_CLUSTER_RESYNC_LOCKED = 4,
	MD_FAILFAST_SUPPORTED = 5,
	MD_HAS_PPL = 6,
	MD_HAS_MULTIPLE_PPLS = 7,
	MD_ALLOW_SB_UPDATE = 8,
	MD_UPDATING_SB = 9,
	MD_NOT_READY = 10,
	MD_BROKEN = 11,
};

enum mddev_sb_flags {
	MD_SB_CHANGE_DEVS = 0,
	MD_SB_CHANGE_CLEAN = 1,
	MD_SB_CHANGE_PENDING = 2,
	MD_SB_NEED_REWRITE = 3,
};

struct md_personality {
	char *name;
	int level;
	struct list_head list;
	struct module___215 *owner;
	bool (*make_request)(struct mddev *, struct bio___124 *);
	int (*run)(struct mddev *);
	int (*start)(struct mddev *);
	void (*free)(struct mddev *, void *);
	void (*status)(struct seq_file___206 *, struct mddev *);
	void (*error_handler)(struct mddev *, struct md_rdev *);
	int (*hot_add_disk)(struct mddev *, struct md_rdev *);
	int (*hot_remove_disk)(struct mddev *, struct md_rdev *);
	int (*spare_active)(struct mddev *);
	sector_t (*sync_request)(struct mddev *, sector_t, int *);
	int (*resize)(struct mddev *, sector_t);
	sector_t (*size)(struct mddev *, sector_t, int);
	int (*check_reshape)(struct mddev *);
	int (*start_reshape)(struct mddev *);
	void (*finish_reshape)(struct mddev *);
	void (*update_reshape_pos)(struct mddev *);
	void (*quiesce)(struct mddev *, int);
	void * (*takeover)(struct mddev *);
	int (*change_consistency_policy)(struct mddev *, const char *);
};

struct md_thread {
	void (*run)(struct md_thread *);
	struct mddev *mddev;
	wait_queue_head_t wqueue;
	long unsigned int flags;
	struct task_struct___238 *tsk;
	long unsigned int timeout;
	void *private;
};

struct bitmap_page;

struct bitmap_counts {
	spinlock_t lock;
	struct bitmap_page *bp;
	long unsigned int pages;
	long unsigned int missing_pages;
	long unsigned int chunkshift;
	long unsigned int chunks;
};

struct bitmap_storage {
	struct file___231 *file;
	struct page___236 *sb_page;
	struct page___236 **filemap;
	long unsigned int *filemap_attr;
	long unsigned int file_pages;
	long unsigned int bytes;
};

struct bitmap {
	struct bitmap_counts counts;
	struct mddev *mddev;
	__u64 events_cleared;
	int need_sync;
	struct bitmap_storage storage;
	long unsigned int flags;
	int allclean;
	atomic_t behind_writes;
	long unsigned int behind_writes_used;
	long unsigned int daemon_lastrun;
	long unsigned int last_end_sync;
	atomic_t pending_writes;
	wait_queue_head_t write_wait;
	wait_queue_head_t overflow_wait;
	wait_queue_head_t behind_wait;
	struct kernfs_node___219 *sysfs_can_clear;
	int cluster_slot;
};

enum recovery_flags {
	MD_RECOVERY_RUNNING = 0,
	MD_RECOVERY_SYNC = 1,
	MD_RECOVERY_RECOVER = 2,
	MD_RECOVERY_INTR = 3,
	MD_RECOVERY_DONE = 4,
	MD_RECOVERY_NEEDED = 5,
	MD_RECOVERY_REQUESTED = 6,
	MD_RECOVERY_CHECK = 7,
	MD_RECOVERY_RESHAPE = 8,
	MD_RECOVERY_FROZEN = 9,
	MD_RECOVERY_ERROR = 10,
	MD_RECOVERY_WAIT = 11,
	MD_RESYNCING_REMOTE = 12,
};

struct md_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct mddev *, char *);
	ssize_t (*store)(struct mddev *, const char *, size_t);
};

struct md_io_acct {
	struct bio___124 *orig_bio;
	long unsigned int start_time;
	struct bio___124 bio_clone;
};

struct bitmap_page {
	char *map;
	unsigned int hijacked: 1;
	unsigned int pending: 1;
	unsigned int count: 30;
	long: 34;
	long: 64;
};

struct super_type {
	char *name;
	struct module___215 *owner;
	int (*load_super)(struct md_rdev *, struct md_rdev *, int);
	int (*validate_super)(struct mddev *, struct md_rdev *);
	void (*sync_super)(struct mddev *, struct md_rdev *);
	long long unsigned int (*rdev_size_change)(struct md_rdev *, sector_t);
	int (*allow_new_offset)(struct md_rdev *, long long unsigned int);
};

struct rdev_sysfs_entry {
	struct attribute attr;
	ssize_t (*show)(struct md_rdev *, char *);
	ssize_t (*store)(struct md_rdev *, const char *, size_t);
};

enum array_state {
	clear = 0,
	inactive = 1,
	suspended = 2,
	readonly = 3,
	read_auto = 4,
	clean = 5,
	active = 6,
	write_pending = 7,
	active_idle = 8,
	broken = 9,
	bad_word = 10,
};

struct detected_devices_node {
	struct list_head list;
	dev_t dev;
};

struct buffer_head___14;

typedef void bh_end_io_t___14(struct buffer_head___14 *, int);

struct buffer_head___14 {
	long unsigned int b_state;
	struct buffer_head___14 *b_this_page;
	struct page___236 *b_page;
	sector_t b_blocknr;
	size_t b_size;
	char *b_data;
	struct block_device___127 *b_bdev;
	bh_end_io_t___14 *b_end_io;
	void *b_private;
	struct list_head b_assoc_buffers;
	struct address_space___231 *b_assoc_map;
	atomic_t b_count;
	spinlock_t b_uptodate_lock;
};

typedef __u16 bitmap_counter_t;

enum bitmap_state {
	BITMAP_STALE = 1,
	BITMAP_WRITE_ERROR = 2,
	BITMAP_HOSTENDIAN = 15,
};

struct bitmap_super_s {
	__le32 magic;
	__le32 version;
	__u8 uuid[16];
	__le64 events;
	__le64 events_cleared;
	__le64 sync_size;
	__le32 state;
	__le32 chunksize;
	__le32 daemon_sleep;
	__le32 write_behind;
	__le32 sectors_reserved;
	__le32 nodes;
	__u8 cluster_name[64];
	__u8 pad[120];
};

typedef struct bitmap_super_s bitmap_super_t;

enum bitmap_page_attr {
	BITMAP_PAGE_DIRTY = 0,
	BITMAP_PAGE_PENDING = 1,
	BITMAP_PAGE_NEEDWRITE = 2,
};

struct bitmap___2;

struct md_personality___2;

struct md_thread___2;

struct md_rdev___2;

struct mddev___2 {
	void *private;
	struct md_personality___2 *pers;
	dev_t unit;
	int md_minor;
	struct list_head disks;
	long unsigned int flags;
	long unsigned int sb_flags;
	int suspended;
	atomic_t active_io;
	int ro;
	int sysfs_active;
	struct gendisk___4 *gendisk;
	struct kobject___8 kobj;
	int hold_active;
	int major_version;
	int minor_version;
	int patch_version;
	int persistent;
	int external;
	char metadata_type[17];
	int chunk_sectors;
	time64_t ctime;
	time64_t utime;
	int level;
	int layout;
	char clevel[16];
	int raid_disks;
	int max_disks;
	sector_t dev_sectors;
	sector_t array_sectors;
	int external_size;
	__u64 events;
	int can_decrease_events;
	char uuid[16];
	sector_t reshape_position;
	int delta_disks;
	int new_level;
	int new_layout;
	int new_chunk_sectors;
	int reshape_backwards;
	struct md_thread___2 *thread;
	struct md_thread___2 *sync_thread;
	char *last_sync_action;
	sector_t curr_resync;
	sector_t curr_resync_completed;
	long unsigned int resync_mark;
	sector_t resync_mark_cnt;
	sector_t curr_mark_cnt;
	sector_t resync_max_sectors;
	atomic64_t resync_mismatches;
	sector_t suspend_lo;
	sector_t suspend_hi;
	int sync_speed_min;
	int sync_speed_max;
	int parallel_resync;
	int ok_start_degraded;
	long unsigned int recovery;
	int recovery_disabled;
	int in_sync;
	struct mutex open_mutex;
	struct mutex reconfig_mutex;
	atomic_t active;
	atomic_t openers;
	int changed;
	int degraded;
	atomic_t recovery_active;
	wait_queue_head_t recovery_wait;
	sector_t recovery_cp;
	sector_t resync_min;
	sector_t resync_max;
	struct kernfs_node___8 *sysfs_state;
	struct kernfs_node___8 *sysfs_action;
	struct kernfs_node___8 *sysfs_completed;
	struct kernfs_node___8 *sysfs_degraded;
	struct kernfs_node___8 *sysfs_level;
	struct work_struct del_work;
	spinlock_t lock;
	wait_queue_head_t sb_wait;
	atomic_t pending_writes;
	unsigned int safemode;
	unsigned int safemode_delay;
	struct timer_list safemode_timer;
	struct percpu_ref writes_pending;
	int sync_checkers;
	struct request_queue___6 *queue;
	struct bitmap___2 *bitmap;
	struct {
		struct file___216 *file;
		loff_t offset;
		long unsigned int space;
		loff_t default_offset;
		long unsigned int default_space;
		struct mutex mutex;
		long unsigned int chunksize;
		long unsigned int daemon_sleep;
		long unsigned int max_write_behind;
		int external;
		int nodes;
		char cluster_name[64];
	} bitmap_info;
	atomic_t max_corr_read_errors;
	struct list_head all_mddevs;
	const struct attribute_group___8 *to_remove;
	struct bio_set___4 bio_set;
	struct bio_set___4 sync_set;
	struct bio_set___4 io_acct_set;
	struct bio___4 *flush_bio;
	atomic_t flush_pending;
	ktime_t start_flush;
	ktime_t prev_flush_start;
	struct work_struct flush_work;
	struct work_struct event_work;
	mempool_t *serial_info_pool;
	void (*sync_super)(struct mddev___2 *, struct md_rdev___2 *);
	struct md_cluster_info *cluster_info;
	unsigned int good_device_nr;
	unsigned int noio_flag;
	bool has_superblocks: 1;
	bool fail_last_dev: 1;
	bool serialize_policy: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct md_rdev___2 {
	struct list_head same_set;
	sector_t sectors;
	struct mddev___2 *mddev;
	int last_events;
	struct block_device___5 *meta_bdev;
	struct block_device___5 *bdev;
	struct page___9 *sb_page;
	struct page___9 *bb_page;
	int sb_loaded;
	__u64 sb_events;
	sector_t data_offset;
	sector_t new_data_offset;
	sector_t sb_start;
	int sb_size;
	int preferred_minor;
	struct kobject___8 kobj;
	long unsigned int flags;
	wait_queue_head_t blocked_wait;
	int desc_nr;
	int raid_disk;
	int new_raid_disk;
	int saved_raid_disk;
	union {
		sector_t recovery_offset;
		sector_t journal_tail;
	};
	atomic_t nr_pending;
	atomic_t read_errors;
	time64_t last_read_error;
	atomic_t corrected_errors;
	struct serial_in_rdev *serial;
	struct work_struct del_work;
	struct kernfs_node___8 *sysfs_state;
	struct kernfs_node___8 *sysfs_unack_badblocks;
	struct kernfs_node___8 *sysfs_badblocks;
	struct badblocks badblocks;
	struct {
		short int offset;
		unsigned int size;
		sector_t sector;
	} ppl;
};

struct md_personality___2 {
	char *name;
	int level;
	struct list_head list;
	struct module___10 *owner;
	bool (*make_request)(struct mddev___2 *, struct bio___4 *);
	int (*run)(struct mddev___2 *);
	int (*start)(struct mddev___2 *);
	void (*free)(struct mddev___2 *, void *);
	void (*status)(struct seq_file___11 *, struct mddev___2 *);
	void (*error_handler)(struct mddev___2 *, struct md_rdev___2 *);
	int (*hot_add_disk)(struct mddev___2 *, struct md_rdev___2 *);
	int (*hot_remove_disk)(struct mddev___2 *, struct md_rdev___2 *);
	int (*spare_active)(struct mddev___2 *);
	sector_t (*sync_request)(struct mddev___2 *, sector_t, int *);
	int (*resize)(struct mddev___2 *, sector_t);
	sector_t (*size)(struct mddev___2 *, sector_t, int);
	int (*check_reshape)(struct mddev___2 *);
	int (*start_reshape)(struct mddev___2 *);
	void (*finish_reshape)(struct mddev___2 *);
	void (*update_reshape_pos)(struct mddev___2 *);
	void (*quiesce)(struct mddev___2 *, int);
	void * (*takeover)(struct mddev___2 *);
	int (*change_consistency_policy)(struct mddev___2 *, const char *);
};

struct md_thread___2 {
	void (*run)(struct md_thread___2 *);
	struct mddev___2 *mddev;
	wait_queue_head_t wqueue;
	long unsigned int flags;
	struct task_struct___10 *tsk;
	long unsigned int timeout;
	void *private;
};

struct md_setup_args {
	int minor;
	int partitioned;
	int level;
	int chunk;
	char *device_names;
};

struct dm_ioctl {
	__u32 version[3];
	__u32 data_size;
	__u32 data_start;
	__u32 target_count;
	__s32 open_count;
	__u32 flags;
	__u32 event_nr;
	__u32 padding;
	__u64 dev;
	char name[128];
	char uuid[129];
	char data[7];
};

struct dm_target_spec {
	__u64 sector_start;
	__u64 length;
	__s32 status;
	__u32 next;
	char target_type[16];
};

struct dm_device {
	struct dm_ioctl dmi;
	struct dm_target_spec *table[256];
	char *target_args_array[256];
	struct list_head list;
};

typedef enum {
	STATUSTYPE_INFO = 0,
	STATUSTYPE_TABLE = 1,
	STATUSTYPE_IMA = 2,
} status_type_t;

union map_info___2 {
	void *ptr;
};

struct dm_target;

typedef int (*dm_ctr_fn)(struct dm_target *, unsigned int, char **);

struct dm_table;

struct target_type;

struct dm_target {
	struct dm_table *table;
	struct target_type *type;
	sector_t begin;
	sector_t len;
	uint32_t max_io_len;
	unsigned int num_flush_bios;
	unsigned int num_discard_bios;
	unsigned int num_secure_erase_bios;
	unsigned int num_write_same_bios;
	unsigned int num_write_zeroes_bios;
	unsigned int per_io_data_size;
	void *private;
	char *error;
	bool flush_supported: 1;
	bool discards_supported: 1;
	bool limit_swap_bios: 1;
	bool emulate_zone_append: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*dm_dtr_fn)(struct dm_target *);

typedef int (*dm_map_fn)(struct dm_target *, struct bio___4 *);

typedef int (*dm_clone_and_map_request_fn)(struct dm_target *, struct request___5 *, union map_info___2 *, struct request___5 **);

typedef void (*dm_release_clone_request_fn)(struct request___5 *, union map_info___2 *);

typedef int (*dm_endio_fn)(struct dm_target *, struct bio___4 *, blk_status_t *);

typedef int (*dm_request_endio_fn)(struct dm_target *, struct request___5 *, blk_status_t, union map_info___2 *);

typedef void (*dm_presuspend_fn)(struct dm_target *);

typedef void (*dm_presuspend_undo_fn)(struct dm_target *);

typedef void (*dm_postsuspend_fn)(struct dm_target *);

typedef int (*dm_preresume_fn)(struct dm_target *);

typedef void (*dm_resume_fn)(struct dm_target *);

typedef void (*dm_status_fn)(struct dm_target *, status_type_t, unsigned int, char *, unsigned int);

typedef int (*dm_message_fn)(struct dm_target *, unsigned int, char **, char *, unsigned int);

typedef int (*dm_prepare_ioctl_fn)(struct dm_target *, struct block_device___5 **);

struct dm_report_zones_args;

typedef int (*dm_report_zones_fn)(struct dm_target *, struct dm_report_zones_args *, unsigned int);

struct dm_report_zones_args {
	struct dm_target *tgt;
	sector_t next_sector;
	void *orig_data;
	report_zones_cb orig_cb;
	unsigned int zone_idx;
	sector_t start;
};

struct dm_dev;

typedef int (*iterate_devices_callout_fn)(struct dm_target *, struct dm_dev *, sector_t, sector_t, void *);

struct dm_dev {
	struct block_device___5 *bdev;
	struct dax_device *dax_dev;
	fmode_t mode;
	char name[16];
};

typedef int (*dm_iterate_devices_fn)(struct dm_target *, iterate_devices_callout_fn, void *);

typedef void (*dm_io_hints_fn)(struct dm_target *, struct queue_limits *);

typedef int (*dm_busy_fn)(struct dm_target *);

typedef long int (*dm_dax_direct_access_fn)(struct dm_target *, long unsigned int, long int, void **, pfn_t *);

typedef size_t (*dm_dax_copy_iter_fn)(struct dm_target *, long unsigned int, void *, size_t, struct iov_iter___5 *);

typedef int (*dm_dax_zero_page_range_fn)(struct dm_target *, long unsigned int, size_t);

struct target_type {
	uint64_t features;
	const char *name;
	struct module___10 *module;
	unsigned int version[3];
	dm_ctr_fn ctr;
	dm_dtr_fn dtr;
	dm_map_fn map;
	dm_clone_and_map_request_fn clone_and_map_rq;
	dm_release_clone_request_fn release_clone_rq;
	dm_endio_fn end_io;
	dm_request_endio_fn rq_end_io;
	dm_presuspend_fn presuspend;
	dm_presuspend_undo_fn presuspend_undo;
	dm_postsuspend_fn postsuspend;
	dm_preresume_fn preresume;
	dm_resume_fn resume;
	dm_status_fn status;
	dm_message_fn message;
	dm_prepare_ioctl_fn prepare_ioctl;
	dm_report_zones_fn report_zones;
	dm_busy_fn busy;
	dm_iterate_devices_fn iterate_devices;
	dm_io_hints_fn io_hints;
	dm_dax_direct_access_fn direct_access;
	dm_dax_copy_iter_fn dax_copy_from_iter;
	dm_dax_copy_iter_fn dax_copy_to_iter;
	dm_dax_zero_page_range_fn dax_zero_page_range;
	struct list_head list;
};

enum dm_uevent_type {
	DM_UEVENT_PATH_FAILED = 0,
	DM_UEVENT_PATH_REINSTATED = 1,
};

struct mapped_device;

struct dm_uevent {
	struct mapped_device *md;
	enum kobject_action action;
	struct kobj_uevent_env ku_env;
	struct list_head elist;
	char name[128];
	char uuid[129];
};

struct dentry___232;

struct super_block___232;

struct module___216;

struct file_system_type___232 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___232 * (*mount)(struct file_system_type___232 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___232 *);
	struct module___216 *owner;
	struct file_system_type___232 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___232;

struct kiocb___232;

struct iov_iter___152;

struct poll_table_struct___157;

struct vm_area_struct___237;

struct inode___232;

struct file_lock___232;

struct page___237;

struct seq_file___207;

struct file_operations___233 {
	struct module___216 *owner;
	loff_t (*llseek)(struct file___232 *, loff_t, int);
	ssize_t (*read)(struct file___232 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___232 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___232 *, struct iov_iter___152 *);
	ssize_t (*write_iter)(struct kiocb___232 *, struct iov_iter___152 *);
	int (*iopoll)(struct kiocb___232 *, bool);
	int (*iterate)(struct file___232 *, struct dir_context *);
	int (*iterate_shared)(struct file___232 *, struct dir_context *);
	__poll_t (*poll)(struct file___232 *, struct poll_table_struct___157 *);
	long int (*unlocked_ioctl)(struct file___232 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___232 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___232 *, struct vm_area_struct___237 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___232 *, struct file___232 *);
	int (*flush)(struct file___232 *, fl_owner_t);
	int (*release)(struct inode___232 *, struct file___232 *);
	int (*fsync)(struct file___232 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___232 *, int);
	int (*lock)(struct file___232 *, int, struct file_lock___232 *);
	ssize_t (*sendpage)(struct file___232 *, struct page___237 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___232 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___232 *, long unsigned int);
	int (*flock)(struct file___232 *, int, struct file_lock___232 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___232 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___232 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___232 *, long int, struct file_lock___232 **, void **);
	long int (*fallocate)(struct file___232 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___207 *, struct file___232 *);
	ssize_t (*copy_file_range)(struct file___232 *, loff_t, struct file___232 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___232 *, loff_t, struct file___232 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___232 *, loff_t, loff_t, int);
};

struct vmacache___237 {
	u64 seqnum;
	struct vm_area_struct___237 *vmas[4];
};

struct page_frag___237 {
	struct page___237 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___238;

struct pid___209;

struct nsproxy___218;

struct signal_struct___233;

struct bio_list___125;

struct backing_dev_info___114;

struct io_context___125;

struct css_set___162;

struct request_queue___125;

struct vm_struct___215;

struct task_struct___239 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___239 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___238 *mm;
	struct mm_struct___238 *active_mm;
	struct vmacache___237 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___239 *real_parent;
	struct task_struct___239 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___239 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___209 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___218 *nsproxy;
	struct signal_struct___233 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___239 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___125 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___114 *backing_dev_info;
	struct io_context___125 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___162 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___237 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___125 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___239 *oom_reaper_list;
	struct vm_struct___215 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___82 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___220;

struct kobj_type___220;

struct kernfs_node___220;

struct kobject___220 {
	const char *name;
	struct list_head entry;
	struct kobject___220 *parent;
	struct kset___220 *kset;
	struct kobj_type___220 *ktype;
	struct kernfs_node___220 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___217 {
	struct kobject___220 kobj;
	struct module___216 *mod;
	struct kobject___220 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___216 {
	struct module___216 *mod;
	struct latch_tree_node node;
};

struct module_layout___216 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___216 mtn;
};

struct module_attribute___216;

struct kernel_param___216;

struct module___216 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___217 mkobj;
	struct module_attribute___216 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___220 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___216 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___216 core_layout;
	struct module_layout___216 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___209;

struct upid___209 {
	int nr;
	struct pid_namespace___209 *ns;
};

struct pid_namespace___209 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___239 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___209 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___209 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___209 numbers[1];
};

typedef struct page___237 *pgtable_t___237;

struct address_space___232;

struct dev_pagemap___227;

struct page___237 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___232 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___237 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___237 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___238 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___227 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___227;

struct vm_area_struct___237 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___237 *vm_next;
	struct vm_area_struct___237 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___238 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___227 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___232 *vm_file;
	struct file___232 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___233 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___239 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___239 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___209 *pids[4];
	struct pid___209 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___238 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___237;

struct mm_struct___238 {
	struct {
		struct vm_area_struct___237 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___232 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___237 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___239 *owner;
		struct user_namespace___14 *user_ns;
		struct file___232 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___162;

struct nsproxy___218 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___209 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___162 *cgroup_ns;
};

struct bio___125;

struct bio_list___125 {
	struct bio___125 *head;
	struct bio___125 *tail;
};

struct cgroup_subsys_state___162;

struct bdi_writeback___114 {
	struct backing_dev_info___114 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___162 *memcg_css;
	struct cgroup_subsys_state___162 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___211;

struct backing_dev_info___114 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___114 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___211 *dev;
	char dev_name[64];
	struct device___211 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___232 *debug_dir;
};

struct io_cq___125;

struct io_context___125 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___125 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___162;

struct css_set___162 {
	struct cgroup_subsys_state___162 *subsys[14];
	refcount_t refcount;
	struct css_set___162 *dom_cset;
	struct cgroup___162 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___162 *mg_src_cgrp;
	struct cgroup___162 *mg_dst_cgrp;
	struct css_set___162 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___125;

struct blk_integrity___125 {
	const struct blk_integrity_profile___125 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___125 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___125 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___125;

struct elevator_queue___125;

struct blk_mq_ops___122;

struct blk_mq_hw_ctx___122;

struct gendisk___128;

struct blk_keyslot_manager___3;

struct blkcg_gq___116;

struct blk_trace___7;

struct blk_mq_tag_set___122;

struct request_queue___125 {
	struct request___125 *last_merge;
	struct elevator_queue___125 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___122 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___122 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___128 *disk;
	struct kobject___220 kobj;
	struct kobject___220 *mq_kobj;
	struct blk_integrity___125 integrity;
	struct device___211 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___3 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___116 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___7 *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___122 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___125 bio_split;
	struct dentry___232 *debugfs_dir;
	struct dentry___232 *sched_debugfs_dir;
	struct dentry___232 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___215 {
	struct vm_struct___215 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___237 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___232;

struct dentry___232 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___232 *d_parent;
	struct qstr d_name;
	struct inode___232 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___232 *d_op;
	struct super_block___232 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___232;

struct address_space___232 {
	struct inode___232 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___232 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___232;

struct inode___232 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___232 *i_op;
	struct super_block___232 *i_sb;
	struct address_space___232 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___114 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___233 *i_fop;
		void (*free_inode)(struct inode___232 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___232 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___232;

struct path___232;

struct dentry_operations___232 {
	int (*d_revalidate)(struct dentry___232 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___232 *, unsigned int);
	int (*d_hash)(const struct dentry___232 *, struct qstr *);
	int (*d_compare)(const struct dentry___232 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___232 *);
	int (*d_init)(struct dentry___232 *);
	void (*d_release)(struct dentry___232 *);
	void (*d_prune)(struct dentry___232 *);
	void (*d_iput)(struct dentry___232 *, struct inode___232 *);
	char * (*d_dname)(struct dentry___232 *, char *, int);
	struct vfsmount___232 * (*d_automount)(struct path___232 *);
	int (*d_manage)(const struct path___232 *, bool);
	struct dentry___232 * (*d_real)(struct dentry___232 *, const struct inode___232 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___232;

struct mem_dqinfo___232 {
	struct quota_format_type___232 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___232;

struct quota_info___232 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___232 *files[3];
	struct mem_dqinfo___232 info[3];
	const struct quota_format_ops___232 *ops[3];
};

struct rcuwait___233 {
	struct task_struct___239 *task;
};

struct percpu_rw_semaphore___233 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___233 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___232 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___233 rw_sem[3];
};

struct super_operations___232;

struct dquot_operations___232;

struct quotactl_ops___232;

struct block_device___128;

struct super_block___232 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___232 *s_type;
	const struct super_operations___232 *s_op;
	const struct dquot_operations___232 *dq_op;
	const struct quotactl_ops___232 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___232 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___128 *s_bdev;
	struct backing_dev_info___114 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___232 s_dquot;
	struct sb_writers___232 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___232 *s_d_op;
	int cleancache_poolid;
	struct shrinker___103 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___232 {
	struct dentry___232 *mnt_root;
	struct super_block___232 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___232 {
	struct vfsmount___232 *mnt;
	struct dentry___232 *dentry;
};

struct dev_pagemap_ops___227;

struct dev_pagemap___227 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___227 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___209 {
	rwlock_t lock;
	struct pid___209 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___232 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___232 f_path;
	struct inode___232 *f_inode;
	const struct file_operations___233 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___209 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___232 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___227;

struct vm_operations_struct___227 {
	void (*open)(struct vm_area_struct___237 *);
	void (*close)(struct vm_area_struct___237 *);
	int (*may_split)(struct vm_area_struct___237 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___237 *);
	int (*mprotect)(struct vm_area_struct___237 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___227 *);
	vm_fault_t (*huge_fault)(struct vm_fault___227 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___227 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___237 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___227 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___227 *);
	int (*access)(struct vm_area_struct___237 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___237 *);
	int (*set_policy)(struct vm_area_struct___237 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___237 *, long unsigned int);
	struct page___237 * (*find_special_page)(struct vm_area_struct___237 *, long unsigned int);
};

struct core_thread___237 {
	struct task_struct___239 *task;
	struct core_thread___237 *next;
};

struct core_state___237 {
	atomic_t nr_threads;
	struct core_thread___237 dumper;
	struct completion startup;
};

struct vm_fault___227 {
	const struct {
		struct vm_area_struct___237 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___237 *cow_page;
	struct page___237 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___237 prealloc_pte;
};

struct cgroup_subsys___162;

struct cgroup_subsys_state___162 {
	struct cgroup___162 *cgroup;
	struct cgroup_subsys___162 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___162 *parent;
};

struct cgroup_file___162 {
	struct kernfs_node___220 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___162 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___239 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___162;

struct cgroup_rstat_cpu___162;

struct cgroup___162 {
	struct cgroup_subsys_state___162 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___220 *kn;
	struct cgroup_file___162 procs_file;
	struct cgroup_file___162 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___162 *subsys[14];
	struct cgroup_root___162 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___162 *dom_cgrp;
	struct cgroup___162 *old_dom_cgrp;
	struct cgroup_rstat_cpu___162 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___162 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___125 {
	struct request_queue___125 *q;
	struct io_context___125 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___110;

struct kiocb___232 {
	struct file___232 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___232 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___110 *ki_waitq;
	};
};

struct iattr___232 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___232 *ia_file;
};

struct dquot___232 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___232 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___232 {
	int qf_fmt_id;
	const struct quota_format_ops___232 *qf_ops;
	struct module___216 *qf_owner;
	struct quota_format_type___232 *qf_next;
};

struct quota_format_ops___232 {
	int (*check_quota_file)(struct super_block___232 *, int);
	int (*read_file_info)(struct super_block___232 *, int);
	int (*write_file_info)(struct super_block___232 *, int);
	int (*free_file_info)(struct super_block___232 *, int);
	int (*read_dqblk)(struct dquot___232 *);
	int (*commit_dqblk)(struct dquot___232 *);
	int (*release_dqblk)(struct dquot___232 *);
	int (*get_next_id)(struct super_block___232 *, struct kqid *);
};

struct dquot_operations___232 {
	int (*write_dquot)(struct dquot___232 *);
	struct dquot___232 * (*alloc_dquot)(struct super_block___232 *, int);
	void (*destroy_dquot)(struct dquot___232 *);
	int (*acquire_dquot)(struct dquot___232 *);
	int (*release_dquot)(struct dquot___232 *);
	int (*mark_dirty)(struct dquot___232 *);
	int (*write_info)(struct super_block___232 *, int);
	qsize_t * (*get_reserved_space)(struct inode___232 *);
	int (*get_projid)(struct inode___232 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___232 *, qsize_t *);
	int (*get_next_id)(struct super_block___232 *, struct kqid *);
};

struct quotactl_ops___232 {
	int (*quota_on)(struct super_block___232 *, int, int, const struct path___232 *);
	int (*quota_off)(struct super_block___232 *, int);
	int (*quota_enable)(struct super_block___232 *, unsigned int);
	int (*quota_disable)(struct super_block___232 *, unsigned int);
	int (*quota_sync)(struct super_block___232 *, int);
	int (*set_info)(struct super_block___232 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___232 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___232 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___232 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___232 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___232 *, unsigned int);
};

struct wait_page_queue___110 {
	struct page___237 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___114;

struct readahead_control___110;

struct address_space_operations___232 {
	int (*writepage)(struct page___237 *, struct writeback_control___114 *);
	int (*readpage)(struct file___232 *, struct page___237 *);
	int (*writepages)(struct address_space___232 *, struct writeback_control___114 *);
	int (*set_page_dirty)(struct page___237 *);
	int (*readpages)(struct file___232 *, struct address_space___232 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___110 *);
	int (*write_begin)(struct file___232 *, struct address_space___232 *, loff_t, unsigned int, unsigned int, struct page___237 **, void **);
	int (*write_end)(struct file___232 *, struct address_space___232 *, loff_t, unsigned int, unsigned int, struct page___237 *, void *);
	sector_t (*bmap)(struct address_space___232 *, sector_t);
	void (*invalidatepage)(struct page___237 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___237 *, gfp_t);
	void (*freepage)(struct page___237 *);
	ssize_t (*direct_IO)(struct kiocb___232 *, struct iov_iter___152 *);
	int (*migratepage)(struct address_space___232 *, struct page___237 *, struct page___237 *, enum migrate_mode);
	bool (*isolate_page)(struct page___237 *, isolate_mode_t);
	void (*putback_page)(struct page___237 *);
	int (*launder_page)(struct page___237 *);
	int (*is_partially_uptodate)(struct page___237 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___237 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___232 *, struct page___237 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___232 *, sector_t *);
	void (*swap_deactivate)(struct file___232 *);
};

struct writeback_control___114 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___114 *wb;
	struct inode___232 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___110 {
	struct file___232 *file;
	struct address_space___232 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___149;

struct iov_iter___152 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___149 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___232 {
	struct dentry___232 * (*lookup)(struct inode___232 *, struct dentry___232 *, unsigned int);
	const char * (*get_link)(struct dentry___232 *, struct inode___232 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___232 *, int);
	struct posix_acl * (*get_acl)(struct inode___232 *, int, bool);
	int (*readlink)(struct dentry___232 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___232 *, struct dentry___232 *, umode_t, bool);
	int (*link)(struct dentry___232 *, struct inode___232 *, struct dentry___232 *);
	int (*unlink)(struct inode___232 *, struct dentry___232 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___232 *, struct dentry___232 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___232 *, struct dentry___232 *, umode_t);
	int (*rmdir)(struct inode___232 *, struct dentry___232 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___232 *, struct dentry___232 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___232 *, struct dentry___232 *, struct inode___232 *, struct dentry___232 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___232 *, struct iattr___232 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___232 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___232 *, char *, size_t);
	int (*fiemap)(struct inode___232 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___232 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___232 *, struct dentry___232 *, struct file___232 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___232 *, struct dentry___232 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___232 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___232 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___232 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___232 {
	void (*fl_copy_lock)(struct file_lock___232 *, struct file_lock___232 *);
	void (*fl_release_private)(struct file_lock___232 *);
};

struct fasync_struct___232;

struct lock_manager_operations___232;

struct file_lock___232 {
	struct file_lock___232 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___232 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___232 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___232 *fl_ops;
	const struct lock_manager_operations___232 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___232 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___232 *);
	int (*lm_grant)(struct file_lock___232 *, int);
	bool (*lm_break)(struct file_lock___232 *);
	int (*lm_change)(struct file_lock___232 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___232 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___232 *);
};

struct fasync_struct___232 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___232 *fa_next;
	struct file___232 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___232 {
	struct inode___232 * (*alloc_inode)(struct super_block___232 *);
	void (*destroy_inode)(struct inode___232 *);
	void (*free_inode)(struct inode___232 *);
	void (*dirty_inode)(struct inode___232 *, int);
	int (*write_inode)(struct inode___232 *, struct writeback_control___114 *);
	int (*drop_inode)(struct inode___232 *);
	void (*evict_inode)(struct inode___232 *);
	void (*put_super)(struct super_block___232 *);
	int (*sync_fs)(struct super_block___232 *, int);
	int (*freeze_super)(struct super_block___232 *);
	int (*freeze_fs)(struct super_block___232 *);
	int (*thaw_super)(struct super_block___232 *);
	int (*unfreeze_fs)(struct super_block___232 *);
	int (*statfs)(struct dentry___232 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___232 *, int *, char *);
	void (*umount_begin)(struct super_block___232 *);
	int (*show_options)(struct seq_file___207 *, struct dentry___232 *);
	int (*show_devname)(struct seq_file___207 *, struct dentry___232 *);
	int (*show_path)(struct seq_file___207 *, struct dentry___232 *);
	int (*show_stats)(struct seq_file___207 *, struct dentry___232 *);
	ssize_t (*quota_read)(struct super_block___232 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___232 *, int, const char *, size_t, loff_t);
	struct dquot___232 ** (*get_dquots)(struct inode___232 *);
	long int (*nr_cached_objects)(struct super_block___232 *, struct shrink_control___103 *);
	long int (*free_cached_objects)(struct super_block___232 *, struct shrink_control___103 *);
	struct file___232 * (*real_loop)(struct file___232 *);
};

struct wakeup_source___211;

struct dev_pm_info___211 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___211 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___211 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___211;

struct bus_type___211;

struct device_driver___211;

struct dev_pm_domain___211;

struct fwnode_handle___207;

struct class___211;

struct attribute_group___220;

struct device___211 {
	struct kobject___220 kobj;
	struct device___211 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___211 *type;
	struct bus_type___211 *bus;
	struct device_driver___211 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___211 power;
	struct dev_pm_domain___211 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___207 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___211 *class;
	const struct attribute_group___220 **groups;
	void (*release)(struct device___211 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___128 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___232 *bd_inode;
	struct super_block___232 *bd_super;
	void *bd_claiming;
	struct device___211 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___220 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___128 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___232 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___164)(struct file___232 *, wait_queue_head_t *, struct poll_table_struct___157 *);

struct poll_table_struct___157 {
	poll_queue_proc___164 _qproc;
	__poll_t _key;
};

struct seq_operations___207;

struct seq_file___207 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___207 *op;
	int poll_event;
	const struct file___232 *file;
	void *private;
};

typedef void bio_end_io_t___125(struct bio___125 *);

struct bio_vec___149 {
	struct page___237 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___125;

struct bio___125 {
	struct bio___125 *bi_next;
	struct block_device___128 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___125 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___116 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___125 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___149 *bi_io_vec;
	struct bio_set___125 *bi_pool;
	struct bio_vec___149 bi_inline_vecs[0];
};

struct dev_pagemap_ops___227 {
	void (*page_free)(struct page___237 *);
	void (*kill)(struct dev_pagemap___227 *);
	void (*cleanup)(struct dev_pagemap___227 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___227 *);
};

struct fwnode_operations___207;

struct fwnode_handle___207 {
	struct fwnode_handle___207 *secondary;
	const struct fwnode_operations___207 *ops;
	struct device___211 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___207;

struct fwnode_endpoint___207;

struct fwnode_operations___207 {
	struct fwnode_handle___207 * (*get)(struct fwnode_handle___207 *);
	void (*put)(struct fwnode_handle___207 *);
	bool (*device_is_available)(const struct fwnode_handle___207 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___207 *, const struct device___211 *);
	bool (*property_present)(const struct fwnode_handle___207 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___207 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___207 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___207 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*get_parent)(const struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*get_next_child_node)(const struct fwnode_handle___207 *, struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*get_named_child_node)(const struct fwnode_handle___207 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___207 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___207 *);
	struct fwnode_handle___207 * (*graph_get_next_endpoint)(const struct fwnode_handle___207 *, struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*graph_get_remote_endpoint)(const struct fwnode_handle___207 *);
	struct fwnode_handle___207 * (*graph_get_port_parent)(struct fwnode_handle___207 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___207 *, struct fwnode_endpoint___207 *);
	int (*add_links)(struct fwnode_handle___207 *);
};

struct fwnode_endpoint___207 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___207 *local_fwnode;
};

struct fwnode_reference_args___207 {
	struct fwnode_handle___207 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___220;

struct kernfs_elem_dir___220 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___220 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___220;

struct kernfs_root___220 {
	struct kernfs_node___220 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___220 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___220 {
	struct kernfs_node___220 *target_kn;
};

struct kernfs_ops___220;

struct kernfs_elem_attr___220 {
	const struct kernfs_ops___220 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___220 *notify_next;
};

struct kernfs_node___220 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___220 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___220 dir;
		struct kernfs_elem_symlink___220 symlink;
		struct kernfs_elem_attr___220 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___220;

struct kernfs_ops___220 {
	int (*open)(struct kernfs_open_file___220 *);
	void (*release)(struct kernfs_open_file___220 *);
	int (*seq_show)(struct seq_file___207 *, void *);
	void * (*seq_start)(struct seq_file___207 *, loff_t *);
	void * (*seq_next)(struct seq_file___207 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___207 *, void *);
	ssize_t (*read)(struct kernfs_open_file___220 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___220 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___220 *, struct poll_table_struct___157 *);
	int (*mmap)(struct kernfs_open_file___220 *, struct vm_area_struct___237 *);
};

struct kernfs_syscall_ops___220 {
	int (*show_options)(struct seq_file___207 *, struct kernfs_root___220 *);
	int (*mkdir)(struct kernfs_node___220 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___220 *);
	int (*rename)(struct kernfs_node___220 *, struct kernfs_node___220 *, const char *);
	int (*show_path)(struct seq_file___207 *, struct kernfs_node___220 *, struct kernfs_root___220 *);
};

struct kernfs_open_file___220 {
	struct kernfs_node___220 *kn;
	struct file___232 *file;
	struct seq_file___207 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___227 *vm_ops;
};

struct bin_attribute___220;

struct attribute_group___220 {
	const char *name;
	umode_t (*is_visible)(struct kobject___220 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___220 *, struct bin_attribute___220 *, int);
	struct attribute **attrs;
	struct bin_attribute___220 **bin_attrs;
};

struct bin_attribute___220 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___232 * (*f_mapping)();
	ssize_t (*read)(struct file___232 *, struct kobject___220 *, struct bin_attribute___220 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___232 *, struct kobject___220 *, struct bin_attribute___220 *, char *, loff_t, size_t);
	int (*mmap)(struct file___232 *, struct kobject___220 *, struct bin_attribute___220 *, struct vm_area_struct___237 *);
};

struct sysfs_ops___220 {
	ssize_t (*show)(struct kobject___220 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___220 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___220;

struct kset___220 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___220 kobj;
	const struct kset_uevent_ops___220 *uevent_ops;
};

struct kobj_type___220 {
	void (*release)(struct kobject___220 *);
	const struct sysfs_ops___220 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___220 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___220 *);
	const void * (*namespace)(struct kobject___220 *);
	void (*get_ownership)(struct kobject___220 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___220 {
	int (* const filter)(struct kset___220 *, struct kobject___220 *);
	const char * (* const name)(struct kset___220 *, struct kobject___220 *);
	int (* const uevent)(struct kset___220 *, struct kobject___220 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___216 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___216 *);
	int (*get)(char *, const struct kernel_param___216 *);
	void (*free)(void *);
};

struct kparam_array___216;

struct kernel_param___216 {
	const char *name;
	struct module___216 *mod;
	const struct kernel_param_ops___216 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___216 *arr;
	};
};

struct kparam_array___216 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___216 *ops;
	void *elem;
};

struct module_attribute___216 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___216 *, struct module_kobject___217 *, char *);
	ssize_t (*store)(struct module_attribute___216 *, struct module_kobject___217 *, const char *, size_t);
	void (*setup)(struct module___216 *, const char *);
	int (*test)(struct module___216 *);
	void (*free)(struct module___216 *);
};

struct cgroup_namespace___162 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___162 *root_cset;
};

struct dev_pm_ops___211 {
	int (*prepare)(struct device___211 *);
	void (*complete)(struct device___211 *);
	int (*suspend)(struct device___211 *);
	int (*resume)(struct device___211 *);
	int (*freeze)(struct device___211 *);
	int (*thaw)(struct device___211 *);
	int (*poweroff)(struct device___211 *);
	int (*restore)(struct device___211 *);
	int (*suspend_late)(struct device___211 *);
	int (*resume_early)(struct device___211 *);
	int (*freeze_late)(struct device___211 *);
	int (*thaw_early)(struct device___211 *);
	int (*poweroff_late)(struct device___211 *);
	int (*restore_early)(struct device___211 *);
	int (*suspend_noirq)(struct device___211 *);
	int (*resume_noirq)(struct device___211 *);
	int (*freeze_noirq)(struct device___211 *);
	int (*thaw_noirq)(struct device___211 *);
	int (*poweroff_noirq)(struct device___211 *);
	int (*restore_noirq)(struct device___211 *);
	int (*runtime_suspend)(struct device___211 *);
	int (*runtime_resume)(struct device___211 *);
	int (*runtime_idle)(struct device___211 *);
};

struct wakeup_source___211 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___211 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___211 {
	struct dev_pm_ops___211 ops;
	int (*start)(struct device___211 *);
	void (*detach)(struct device___211 *, bool);
	int (*activate)(struct device___211 *);
	void (*sync)(struct device___211 *);
	void (*dismiss)(struct device___211 *);
};

struct bus_type___211 {
	const char *name;
	const char *dev_name;
	struct device___211 *dev_root;
	const struct attribute_group___220 **bus_groups;
	const struct attribute_group___220 **dev_groups;
	const struct attribute_group___220 **drv_groups;
	int (*match)(struct device___211 *, struct device_driver___211 *);
	int (*uevent)(struct device___211 *, struct kobj_uevent_env *);
	int (*probe)(struct device___211 *);
	void (*sync_state)(struct device___211 *);
	void (*remove)(struct device___211 *);
	void (*shutdown)(struct device___211 *);
	int (*online)(struct device___211 *);
	int (*offline)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	int (*num_vf)(struct device___211 *);
	int (*dma_configure)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___211 {
	const char *name;
	struct bus_type___211 *bus;
	struct module___216 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___211 *);
	void (*sync_state)(struct device___211 *);
	int (*remove)(struct device___211 *);
	void (*shutdown)(struct device___211 *);
	int (*suspend)(struct device___211 *, pm_message_t);
	int (*resume)(struct device___211 *);
	const struct attribute_group___220 **groups;
	const struct attribute_group___220 **dev_groups;
	const struct dev_pm_ops___211 *pm;
	void (*coredump)(struct device___211 *);
	struct driver_private *p;
};

struct device_type___211 {
	const char *name;
	const struct attribute_group___220 **groups;
	int (*uevent)(struct device___211 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___211 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___211 *);
	const struct dev_pm_ops___211 *pm;
};

struct class___211 {
	const char *name;
	struct module___216 *owner;
	const struct attribute_group___220 **class_groups;
	const struct attribute_group___220 **dev_groups;
	struct kobject___220 *dev_kobj;
	int (*dev_uevent)(struct device___211 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___211 *, umode_t *);
	void (*class_release)(struct class___211 *);
	void (*dev_release)(struct device___211 *);
	int (*shutdown_pre)(struct device___211 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___211 *);
	void (*get_ownership)(struct device___211 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___211 *pm;
	struct subsys_private *p;
};

struct block_device_operations___125;

struct gendisk___128 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___128 *part0;
	const struct block_device_operations___125 *fops;
	struct request_queue___125 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___114 *bdi;
	struct kobject___220 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___220 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___125 {
	struct bio___125 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___149 *bip_vec;
	struct bio_vec___149 bip_inline_vecs[0];
};

struct blkcg___116;

struct blkg_policy_data___116;

struct blkcg_gq___116 {
	struct request_queue___125 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___116 *blkcg;
	struct blkcg_gq___116 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___116 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___125 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___125(struct request___125 *);

typedef void integrity_complete_fn___125(struct request___125 *, unsigned int);

struct blk_integrity_profile___125 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___125 *prepare_fn;
	integrity_complete_fn___125 *complete_fn;
	const char *name;
};

struct block_device_operations___125 {
	blk_qc_t (*submit_bio)(struct bio___125 *);
	int (*open)(struct block_device___128 *, fmode_t);
	void (*release)(struct gendisk___128 *, fmode_t);
	int (*rw_page)(struct block_device___128 *, sector_t, struct page___237 *, unsigned int);
	int (*ioctl)(struct block_device___128 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___128 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___128 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___128 *);
	int (*getgeo)(struct block_device___128 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___128 *, bool);
	void (*swap_slot_free_notify)(struct block_device___128 *, long unsigned int);
	int (*report_zones)(struct gendisk___128 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___128 *, umode_t *);
	struct module___216 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___128 *, sector_t *);
};

typedef void rq_end_io_fn___125(struct request___125 *, blk_status_t);

struct request___125 {
	struct request_queue___125 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___122 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___125 *bio;
	struct bio___125 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___149 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___125 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___125 *saved_end_io;
		} flush;
	};
	struct gendisk___128 *rq_disk;
	struct block_device___128 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___125 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___122 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___125 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___220 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___232 *debugfs_dir;
	struct dentry___232 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___125;

struct elevator_mq_ops___125 {
	int (*init_sched)(struct request_queue___125 *, struct elevator_type___125 *);
	void (*exit_sched)(struct elevator_queue___125 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___122 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___122 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___122 *);
	bool (*allow_merge)(struct request_queue___125 *, struct request___125 *, struct bio___125 *);
	bool (*bio_merge)(struct request_queue___125 *, struct bio___125 *, unsigned int);
	int (*request_merge)(struct request_queue___125 *, struct request___125 **, struct bio___125 *);
	void (*request_merged)(struct request_queue___125 *, struct request___125 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___125 *, struct request___125 *, struct request___125 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___125 *);
	void (*finish_request)(struct request___125 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___122 *, struct list_head *, bool);
	struct request___125 * (*dispatch_request)(struct blk_mq_hw_ctx___122 *);
	bool (*has_work)(struct blk_mq_hw_ctx___122 *);
	void (*completed_request)(struct request___125 *, u64);
	void (*requeue_request)(struct request___125 *);
	struct request___125 * (*former_request)(struct request_queue___125 *, struct request___125 *);
	struct request___125 * (*next_request)(struct request_queue___125 *, struct request___125 *);
	void (*init_icq)(struct io_cq___125 *);
	void (*exit_icq)(struct io_cq___125 *);
};

struct elv_fs_entry___125;

struct elevator_type___125 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___125 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___125 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___216 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___125 {
	struct elevator_type___125 *type;
	void *elevator_data;
	struct kobject___220 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___125 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___125 *, char *);
	ssize_t (*store)(struct elevator_queue___125 *, const char *, size_t);
};

struct blk_mq_queue_data___122;

struct blk_mq_ops___122 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___122 *, const struct blk_mq_queue_data___122 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___122 *);
	int (*get_budget)(struct request_queue___125 *);
	void (*put_budget)(struct request_queue___125 *, int);
	void (*set_rq_budget_token)(struct request___125 *, int);
	int (*get_rq_budget_token)(struct request___125 *);
	enum blk_eh_timer_return (*timeout)(struct request___125 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___122 *);
	void (*complete)(struct request___125 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___122 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___122 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___122 *, struct request___125 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___122 *, struct request___125 *, unsigned int);
	void (*initialize_rq_fn)(struct request___125 *);
	void (*cleanup_rq)(struct request___125 *);
	bool (*busy)(struct request_queue___125 *);
	int (*map_queues)(struct blk_mq_tag_set___122 *);
	void (*show_rq)(struct seq_file___207 *, struct request___125 *);
};

struct blk_ksm_ll_ops___3 {
	int (*keyslot_program)(struct blk_keyslot_manager___3 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___3 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___3 {
	struct blk_ksm_ll_ops___3 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___211 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct rchan___8;

struct blk_trace___7 {
	int trace_state;
	struct rchan___8 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___232 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_mq_tag_set___122 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___122 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___122 {
	struct request___125 *rq;
	bool last;
};

struct rchan_buf___8 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___8 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___232 *dentry;
	struct kref kref;
	struct page___237 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___8;

struct rchan___8 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___8 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___8 **buf;
	int is_global;
	struct list_head list;
	struct dentry___232 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___8 {
	int (*subbuf_start)(struct rchan_buf___8 *, void *, void *, size_t);
	struct dentry___232 * (*create_buf_file)(const char *, struct dentry___232 *, umode_t, struct rchan_buf___8 *, int *);
	int (*remove_buf_file)(struct dentry___232 *);
};

enum dm_queue_mode {
	DM_TYPE_NONE = 0,
	DM_TYPE_BIO_BASED = 1,
	DM_TYPE_REQUEST_BASED = 2,
	DM_TYPE_DAX_BIO_BASED = 3,
};

struct dm_target___2;

typedef int (*dm_ctr_fn___2)(struct dm_target___2 *, unsigned int, char **);

struct target_type___2;

struct dm_target___2 {
	struct dm_table *table;
	struct target_type___2 *type;
	sector_t begin;
	sector_t len;
	uint32_t max_io_len;
	unsigned int num_flush_bios;
	unsigned int num_discard_bios;
	unsigned int num_secure_erase_bios;
	unsigned int num_write_same_bios;
	unsigned int num_write_zeroes_bios;
	unsigned int per_io_data_size;
	void *private;
	char *error;
	bool flush_supported: 1;
	bool discards_supported: 1;
	bool limit_swap_bios: 1;
	bool emulate_zone_append: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*dm_dtr_fn___2)(struct dm_target___2 *);

typedef int (*dm_map_fn___2)(struct dm_target___2 *, struct bio___125 *);

typedef int (*dm_clone_and_map_request_fn___2)(struct dm_target___2 *, struct request___125 *, union map_info___2 *, struct request___125 **);

typedef void (*dm_release_clone_request_fn___2)(struct request___125 *, union map_info___2 *);

typedef int (*dm_endio_fn___2)(struct dm_target___2 *, struct bio___125 *, blk_status_t *);

typedef int (*dm_request_endio_fn___2)(struct dm_target___2 *, struct request___125 *, blk_status_t, union map_info___2 *);

typedef void (*dm_presuspend_fn___2)(struct dm_target___2 *);

typedef void (*dm_presuspend_undo_fn___2)(struct dm_target___2 *);

typedef void (*dm_postsuspend_fn___2)(struct dm_target___2 *);

typedef int (*dm_preresume_fn___2)(struct dm_target___2 *);

typedef void (*dm_resume_fn___2)(struct dm_target___2 *);

typedef void (*dm_status_fn___2)(struct dm_target___2 *, status_type_t, unsigned int, char *, unsigned int);

typedef int (*dm_message_fn___2)(struct dm_target___2 *, unsigned int, char **, char *, unsigned int);

typedef int (*dm_prepare_ioctl_fn___2)(struct dm_target___2 *, struct block_device___128 **);

struct dm_report_zones_args___2;

typedef int (*dm_report_zones_fn___2)(struct dm_target___2 *, struct dm_report_zones_args___2 *, unsigned int);

struct dm_report_zones_args___2 {
	struct dm_target___2 *tgt;
	sector_t next_sector;
	void *orig_data;
	report_zones_cb orig_cb;
	unsigned int zone_idx;
	sector_t start;
};

struct dm_dev___2;

typedef int (*iterate_devices_callout_fn___2)(struct dm_target___2 *, struct dm_dev___2 *, sector_t, sector_t, void *);

struct dm_dev___2 {
	struct block_device___128 *bdev;
	struct dax_device *dax_dev;
	fmode_t mode;
	char name[16];
};

typedef int (*dm_iterate_devices_fn___2)(struct dm_target___2 *, iterate_devices_callout_fn___2, void *);

typedef void (*dm_io_hints_fn___2)(struct dm_target___2 *, struct queue_limits *);

typedef int (*dm_busy_fn___2)(struct dm_target___2 *);

typedef long int (*dm_dax_direct_access_fn___2)(struct dm_target___2 *, long unsigned int, long int, void **, pfn_t *);

typedef size_t (*dm_dax_copy_iter_fn___2)(struct dm_target___2 *, long unsigned int, void *, size_t, struct iov_iter___152 *);

typedef int (*dm_dax_zero_page_range_fn___2)(struct dm_target___2 *, long unsigned int, size_t);

struct target_type___2 {
	uint64_t features;
	const char *name;
	struct module___216 *module;
	unsigned int version[3];
	dm_ctr_fn___2 ctr;
	dm_dtr_fn___2 dtr;
	dm_map_fn___2 map;
	dm_clone_and_map_request_fn___2 clone_and_map_rq;
	dm_release_clone_request_fn___2 release_clone_rq;
	dm_endio_fn___2 end_io;
	dm_request_endio_fn___2 rq_end_io;
	dm_presuspend_fn___2 presuspend;
	dm_presuspend_undo_fn___2 presuspend_undo;
	dm_postsuspend_fn___2 postsuspend;
	dm_preresume_fn___2 preresume;
	dm_resume_fn___2 resume;
	dm_status_fn___2 status;
	dm_message_fn___2 message;
	dm_prepare_ioctl_fn___2 prepare_ioctl;
	dm_report_zones_fn___2 report_zones;
	dm_busy_fn___2 busy;
	dm_iterate_devices_fn___2 iterate_devices;
	dm_io_hints_fn___2 io_hints;
	dm_dax_direct_access_fn___2 direct_access;
	dm_dax_copy_iter_fn___2 dax_copy_from_iter;
	dm_dax_copy_iter_fn___2 dax_copy_to_iter;
	dm_dax_zero_page_range_fn___2 dax_zero_page_range;
	struct list_head list;
};

struct mapped_device___2;

struct dm_md_mempools;

struct dm_table {
	struct mapped_device___2 *md;
	enum dm_queue_mode type;
	unsigned int depth;
	unsigned int counts[16];
	sector_t *index[16];
	unsigned int num_targets;
	unsigned int num_allocated;
	sector_t *highs;
	struct dm_target___2 *targets;
	struct target_type___2 *immutable_target_type;
	bool integrity_supported;
	bool singleton;
	unsigned int integrity_added;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	fmode_t mode;
	struct list_head devices;
	void (*event_fn)(void *);
	void *event_context;
	struct dm_md_mempools *mempools;
	struct blk_keyslot_manager___3 *ksm;
};

struct seq_operations___207 {
	void * (*start)(struct seq_file___207 *, loff_t *);
	void (*stop)(struct seq_file___207 *, void *);
	void * (*next)(struct seq_file___207 *, void *, loff_t *);
	int (*show)(struct seq_file___207 *, void *);
};

struct cftype___162;

struct cgroup_subsys___162 {
	struct cgroup_subsys_state___162 * (*css_alloc)(struct cgroup_subsys_state___162 *);
	int (*css_online)(struct cgroup_subsys_state___162 *);
	void (*css_offline)(struct cgroup_subsys_state___162 *);
	void (*css_released)(struct cgroup_subsys_state___162 *);
	void (*css_free)(struct cgroup_subsys_state___162 *);
	void (*css_reset)(struct cgroup_subsys_state___162 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___162 *, int);
	int (*css_extra_stat_show)(struct seq_file___207 *, struct cgroup_subsys_state___162 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___239 *, struct css_set___162 *);
	void (*cancel_fork)(struct task_struct___239 *, struct css_set___162 *);
	void (*fork)(struct task_struct___239 *);
	void (*exit)(struct task_struct___239 *);
	void (*release)(struct task_struct___239 *);
	void (*bind)(struct cgroup_subsys_state___162 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___162 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___162 *dfl_cftypes;
	struct cftype___162 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___162 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___162 *updated_children;
	struct cgroup___162 *updated_next;
};

struct cgroup_root___162 {
	struct kernfs_root___220 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___162 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___162 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___162 *ss;
	struct list_head node;
	struct kernfs_ops___220 *kf_ops;
	int (*open)(struct kernfs_open_file___220 *);
	void (*release)(struct kernfs_open_file___220 *);
	u64 (*read_u64)(struct cgroup_subsys_state___162 *, struct cftype___162 *);
	s64 (*read_s64)(struct cgroup_subsys_state___162 *, struct cftype___162 *);
	int (*seq_show)(struct seq_file___207 *, void *);
	void * (*seq_start)(struct seq_file___207 *, loff_t *);
	void * (*seq_next)(struct seq_file___207 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___207 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___162 *, struct cftype___162 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___162 *, struct cftype___162 *, s64);
	ssize_t (*write)(struct kernfs_open_file___220 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___220 *, struct poll_table_struct___157 *);
};

struct blkcg_policy_data___116;

struct blkcg___116 {
	struct cgroup_subsys_state___162 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___116 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___116 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___116 {
	struct blkcg___116 *blkcg;
	int plid;
};

struct blkg_policy_data___116 {
	struct blkcg_gq___116 *blkg;
	int plid;
};

struct dm_stats_last_position;

struct dm_stats {
	struct mutex mutex;
	struct list_head list;
	struct dm_stats_last_position *last;
	bool precise_timestamps;
};

struct dm_stats_aux {
	bool merged;
	long long unsigned int duration_ns;
};

struct dm_ima_device_table_metadata {
	char *device_metadata;
	unsigned int device_metadata_len;
	unsigned int num_targets;
	char *hash;
	unsigned int hash_len;
};

struct dm_ima_measurements {
	struct dm_ima_device_table_metadata active_table;
	struct dm_ima_device_table_metadata inactive_table;
	unsigned int dm_version_str_len;
};

struct dm_kobject_holder {
	struct kobject___220 kobj;
	struct completion completion;
};

struct mapped_device___2 {
	struct mutex suspend_lock;
	struct mutex table_devices_lock;
	struct list_head table_devices;
	void *map;
	long unsigned int flags;
	struct mutex type_lock;
	enum dm_queue_mode type;
	int numa_node_id;
	struct request_queue___125 *queue;
	atomic_t holders;
	atomic_t open_count;
	struct dm_target___2 *immutable_target;
	struct target_type___2 *immutable_target_type;
	char name[16];
	struct gendisk___128 *disk;
	struct dax_device *dax_dev;
	long unsigned int *pending_io;
	struct work_struct work;
	wait_queue_head_t wait;
	spinlock_t deferred_lock;
	struct bio_list___125 deferred;
	void *interface_ptr;
	wait_queue_head_t eventq;
	atomic_t event_nr;
	atomic_t uevent_seq;
	struct list_head uevent_list;
	spinlock_t uevent_lock;
	unsigned int internal_suspend_count;
	struct bio_set___125 io_bs;
	struct bio_set___125 bs;
	struct workqueue_struct *wq;
	struct hd_geometry geometry;
	struct dm_kobject_holder kobj_holder;
	int swap_bios;
	struct semaphore swap_bios_semaphore;
	struct mutex swap_bios_lock;
	struct dm_stats stats;
	struct blk_mq_tag_set___122 *tag_set;
	bool init_tio_pdu;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct srcu_struct io_barrier;
	unsigned int nr_zones;
	unsigned int *zwp_offset;
	struct dm_ima_measurements ima;
};

struct dm_io;

struct dm_target_io {
	unsigned int magic;
	struct dm_io *io;
	struct dm_target___2 *ti;
	unsigned int target_bio_nr;
	unsigned int *len_ptr;
	bool inside_dm_io;
	struct bio___125 clone;
};

struct dm_io {
	unsigned int magic;
	struct mapped_device___2 *md;
	blk_status_t status;
	atomic_t io_count;
	struct bio___125 *orig_bio;
	long unsigned int start_time;
	spinlock_t endio_lock;
	struct dm_stats_aux stats_aux;
	struct dm_target_io tio;
};

struct crypto_alg___23;

struct crypto_tfm___23 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___23 *);
	struct crypto_alg___23 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___23 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___23 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___23 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___23 *, u8 *, const u8 *);
};

struct compress_alg___23 {
	int (*coa_compress)(struct crypto_tfm___23 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___23 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___23 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___23 cipher;
		struct compress_alg___23 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___23 *);
	void (*cra_exit)(struct crypto_tfm___23 *);
	void (*cra_destroy)(struct crypto_alg___23 *);
	struct module___216 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___16;

struct shash_desc___13 {
	struct crypto_shash___16 *tfm;
	void *__ctx[0];
};

struct crypto_shash___16 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___23 base;
};

struct shash_alg___8 {
	int (*init)(struct shash_desc___13 *);
	int (*update)(struct shash_desc___13 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___13 *, u8 *);
	int (*finup)(struct shash_desc___13 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___13 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___13 *, void *);
	int (*import)(struct shash_desc___13 *, const void *);
	int (*setkey)(struct crypto_shash___16 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___16 *);
	void (*exit_tfm)(struct crypto_shash___16 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___23 base;
};

struct dentry___233;

struct super_block___233;

struct module___217;

struct file_system_type___233 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___233 * (*mount)(struct file_system_type___233 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___233 *);
	struct module___217 *owner;
	struct file_system_type___233 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___233;

struct kiocb___233;

struct iov_iter___153;

struct poll_table_struct___158;

struct vm_area_struct___238;

struct inode___233;

struct file_lock___233;

struct page___238;

struct seq_file___208;

struct file_operations___234 {
	struct module___217 *owner;
	loff_t (*llseek)(struct file___233 *, loff_t, int);
	ssize_t (*read)(struct file___233 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___233 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___233 *, struct iov_iter___153 *);
	ssize_t (*write_iter)(struct kiocb___233 *, struct iov_iter___153 *);
	int (*iopoll)(struct kiocb___233 *, bool);
	int (*iterate)(struct file___233 *, struct dir_context *);
	int (*iterate_shared)(struct file___233 *, struct dir_context *);
	__poll_t (*poll)(struct file___233 *, struct poll_table_struct___158 *);
	long int (*unlocked_ioctl)(struct file___233 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___233 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___233 *, struct vm_area_struct___238 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___233 *, struct file___233 *);
	int (*flush)(struct file___233 *, fl_owner_t);
	int (*release)(struct inode___233 *, struct file___233 *);
	int (*fsync)(struct file___233 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___233 *, int);
	int (*lock)(struct file___233 *, int, struct file_lock___233 *);
	ssize_t (*sendpage)(struct file___233 *, struct page___238 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___233 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___233 *, long unsigned int);
	int (*flock)(struct file___233 *, int, struct file_lock___233 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___233 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___233 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___233 *, long int, struct file_lock___233 **, void **);
	long int (*fallocate)(struct file___233 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___208 *, struct file___233 *);
	ssize_t (*copy_file_range)(struct file___233 *, loff_t, struct file___233 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___233 *, loff_t, struct file___233 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___233 *, loff_t, loff_t, int);
};

struct vmacache___238 {
	u64 seqnum;
	struct vm_area_struct___238 *vmas[4];
};

struct page_frag___238 {
	struct page___238 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___239;

struct pid___210;

struct nsproxy___219;

struct signal_struct___234;

struct bio_list___126;

struct backing_dev_info___115;

struct io_context___126;

struct css_set___163;

struct request_queue___126;

struct vm_struct___216;

struct task_struct___240 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___240 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___239 *mm;
	struct mm_struct___239 *active_mm;
	struct vmacache___238 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___240 *real_parent;
	struct task_struct___240 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___240 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___210 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___219 *nsproxy;
	struct signal_struct___234 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___240 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___126 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___115 *backing_dev_info;
	struct io_context___126 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___163 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___238 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___126 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___240 *oom_reaper_list;
	struct vm_struct___216 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___82 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___221;

struct kobj_type___221;

struct kernfs_node___221;

struct kobject___221 {
	const char *name;
	struct list_head entry;
	struct kobject___221 *parent;
	struct kset___221 *kset;
	struct kobj_type___221 *ktype;
	struct kernfs_node___221 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___218 {
	struct kobject___221 kobj;
	struct module___217 *mod;
	struct kobject___221 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___217 {
	struct module___217 *mod;
	struct latch_tree_node node;
};

struct module_layout___217 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___217 mtn;
};

struct module_attribute___217;

struct kernel_param___217;

struct module___217 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___218 mkobj;
	struct module_attribute___217 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___221 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___217 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___217 core_layout;
	struct module_layout___217 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___210;

struct upid___210 {
	int nr;
	struct pid_namespace___210 *ns;
};

struct pid_namespace___210 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___240 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___210 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___210 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___210 numbers[1];
};

typedef struct page___238 *pgtable_t___238;

struct address_space___233;

struct dev_pagemap___228;

struct page___238 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___233 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___238 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___238 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___239 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___228 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___228;

struct vm_area_struct___238 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___238 *vm_next;
	struct vm_area_struct___238 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___239 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___228 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___233 *vm_file;
	struct file___233 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___234 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___240 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___240 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___210 *pids[4];
	struct pid___210 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___239 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___238;

struct mm_struct___239 {
	struct {
		struct vm_area_struct___238 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___233 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___238 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___240 *owner;
		struct user_namespace___14 *user_ns;
		struct file___233 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___163;

struct nsproxy___219 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___210 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___163 *cgroup_ns;
};

struct bio___126;

struct bio_list___126 {
	struct bio___126 *head;
	struct bio___126 *tail;
};

struct cgroup_subsys_state___163;

struct bdi_writeback___115 {
	struct backing_dev_info___115 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___163 *memcg_css;
	struct cgroup_subsys_state___163 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___212;

struct backing_dev_info___115 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___115 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___212 *dev;
	char dev_name[64];
	struct device___212 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___233 *debug_dir;
};

struct io_cq___126;

struct io_context___126 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___126 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___163;

struct css_set___163 {
	struct cgroup_subsys_state___163 *subsys[14];
	refcount_t refcount;
	struct css_set___163 *dom_cset;
	struct cgroup___163 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___163 *mg_src_cgrp;
	struct cgroup___163 *mg_dst_cgrp;
	struct css_set___163 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct blk_integrity_profile___126;

struct blk_integrity___126 {
	const struct blk_integrity_profile___126 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___126 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___126 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___126;

struct elevator_queue___126;

struct blk_mq_ops___123;

struct blk_mq_hw_ctx___123;

struct gendisk___129;

struct blk_keyslot_manager___4;

struct blkcg_gq___117;

struct blk_trace___8;

struct blk_mq_tag_set___123;

struct request_queue___126 {
	struct request___126 *last_merge;
	struct elevator_queue___126 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___123 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___123 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___129 *disk;
	struct kobject___221 kobj;
	struct kobject___221 *mq_kobj;
	struct blk_integrity___126 integrity;
	struct device___212 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___4 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___117 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace___8 *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___123 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___126 bio_split;
	struct dentry___233 *debugfs_dir;
	struct dentry___233 *sched_debugfs_dir;
	struct dentry___233 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___216 {
	struct vm_struct___216 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___238 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___233;

struct dentry___233 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___233 *d_parent;
	struct qstr d_name;
	struct inode___233 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___233 *d_op;
	struct super_block___233 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___233;

struct address_space___233 {
	struct inode___233 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___233 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___233;

struct inode___233 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___233 *i_op;
	struct super_block___233 *i_sb;
	struct address_space___233 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___115 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___234 *i_fop;
		void (*free_inode)(struct inode___233 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___233 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___233;

struct path___233;

struct dentry_operations___233 {
	int (*d_revalidate)(struct dentry___233 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___233 *, unsigned int);
	int (*d_hash)(const struct dentry___233 *, struct qstr *);
	int (*d_compare)(const struct dentry___233 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___233 *);
	int (*d_init)(struct dentry___233 *);
	void (*d_release)(struct dentry___233 *);
	void (*d_prune)(struct dentry___233 *);
	void (*d_iput)(struct dentry___233 *, struct inode___233 *);
	char * (*d_dname)(struct dentry___233 *, char *, int);
	struct vfsmount___233 * (*d_automount)(struct path___233 *);
	int (*d_manage)(const struct path___233 *, bool);
	struct dentry___233 * (*d_real)(struct dentry___233 *, const struct inode___233 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___233;

struct mem_dqinfo___233 {
	struct quota_format_type___233 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___233;

struct quota_info___233 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___233 *files[3];
	struct mem_dqinfo___233 info[3];
	const struct quota_format_ops___233 *ops[3];
};

struct rcuwait___234 {
	struct task_struct___240 *task;
};

struct percpu_rw_semaphore___234 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___234 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___233 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___234 rw_sem[3];
};

struct super_operations___233;

struct dquot_operations___233;

struct quotactl_ops___233;

struct block_device___129;

struct super_block___233 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___233 *s_type;
	const struct super_operations___233 *s_op;
	const struct dquot_operations___233 *dq_op;
	const struct quotactl_ops___233 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___233 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___129 *s_bdev;
	struct backing_dev_info___115 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___233 s_dquot;
	struct sb_writers___233 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___233 *s_d_op;
	int cleancache_poolid;
	struct shrinker___103 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___233 {
	struct dentry___233 *mnt_root;
	struct super_block___233 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___233 {
	struct vfsmount___233 *mnt;
	struct dentry___233 *dentry;
};

struct dev_pagemap_ops___228;

struct dev_pagemap___228 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___228 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___210 {
	rwlock_t lock;
	struct pid___210 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___233 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___233 f_path;
	struct inode___233 *f_inode;
	const struct file_operations___234 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___210 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___233 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___228;

struct vm_operations_struct___228 {
	void (*open)(struct vm_area_struct___238 *);
	void (*close)(struct vm_area_struct___238 *);
	int (*may_split)(struct vm_area_struct___238 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___238 *);
	int (*mprotect)(struct vm_area_struct___238 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___228 *);
	vm_fault_t (*huge_fault)(struct vm_fault___228 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___228 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___238 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___228 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___228 *);
	int (*access)(struct vm_area_struct___238 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___238 *);
	int (*set_policy)(struct vm_area_struct___238 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___238 *, long unsigned int);
	struct page___238 * (*find_special_page)(struct vm_area_struct___238 *, long unsigned int);
};

struct core_thread___238 {
	struct task_struct___240 *task;
	struct core_thread___238 *next;
};

struct core_state___238 {
	atomic_t nr_threads;
	struct core_thread___238 dumper;
	struct completion startup;
};

struct vm_fault___228 {
	const struct {
		struct vm_area_struct___238 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___238 *cow_page;
	struct page___238 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___238 prealloc_pte;
};

struct cgroup_subsys___163;

struct cgroup_subsys_state___163 {
	struct cgroup___163 *cgroup;
	struct cgroup_subsys___163 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___163 *parent;
};

struct cgroup_file___163 {
	struct kernfs_node___221 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___163 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___240 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___163;

struct cgroup_rstat_cpu___163;

struct cgroup___163 {
	struct cgroup_subsys_state___163 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___221 *kn;
	struct cgroup_file___163 procs_file;
	struct cgroup_file___163 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___163 *subsys[14];
	struct cgroup_root___163 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___163 *dom_cgrp;
	struct cgroup___163 *old_dom_cgrp;
	struct cgroup_rstat_cpu___163 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___163 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___126 {
	struct request_queue___126 *q;
	struct io_context___126 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___111;

struct kiocb___233 {
	struct file___233 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___233 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___111 *ki_waitq;
	};
};

struct iattr___233 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___233 *ia_file;
};

struct dquot___233 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___233 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___233 {
	int qf_fmt_id;
	const struct quota_format_ops___233 *qf_ops;
	struct module___217 *qf_owner;
	struct quota_format_type___233 *qf_next;
};

struct quota_format_ops___233 {
	int (*check_quota_file)(struct super_block___233 *, int);
	int (*read_file_info)(struct super_block___233 *, int);
	int (*write_file_info)(struct super_block___233 *, int);
	int (*free_file_info)(struct super_block___233 *, int);
	int (*read_dqblk)(struct dquot___233 *);
	int (*commit_dqblk)(struct dquot___233 *);
	int (*release_dqblk)(struct dquot___233 *);
	int (*get_next_id)(struct super_block___233 *, struct kqid *);
};

struct dquot_operations___233 {
	int (*write_dquot)(struct dquot___233 *);
	struct dquot___233 * (*alloc_dquot)(struct super_block___233 *, int);
	void (*destroy_dquot)(struct dquot___233 *);
	int (*acquire_dquot)(struct dquot___233 *);
	int (*release_dquot)(struct dquot___233 *);
	int (*mark_dirty)(struct dquot___233 *);
	int (*write_info)(struct super_block___233 *, int);
	qsize_t * (*get_reserved_space)(struct inode___233 *);
	int (*get_projid)(struct inode___233 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___233 *, qsize_t *);
	int (*get_next_id)(struct super_block___233 *, struct kqid *);
};

struct quotactl_ops___233 {
	int (*quota_on)(struct super_block___233 *, int, int, const struct path___233 *);
	int (*quota_off)(struct super_block___233 *, int);
	int (*quota_enable)(struct super_block___233 *, unsigned int);
	int (*quota_disable)(struct super_block___233 *, unsigned int);
	int (*quota_sync)(struct super_block___233 *, int);
	int (*set_info)(struct super_block___233 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___233 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___233 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___233 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___233 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___233 *, unsigned int);
};

struct wait_page_queue___111 {
	struct page___238 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___115;

struct readahead_control___111;

struct address_space_operations___233 {
	int (*writepage)(struct page___238 *, struct writeback_control___115 *);
	int (*readpage)(struct file___233 *, struct page___238 *);
	int (*writepages)(struct address_space___233 *, struct writeback_control___115 *);
	int (*set_page_dirty)(struct page___238 *);
	int (*readpages)(struct file___233 *, struct address_space___233 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___111 *);
	int (*write_begin)(struct file___233 *, struct address_space___233 *, loff_t, unsigned int, unsigned int, struct page___238 **, void **);
	int (*write_end)(struct file___233 *, struct address_space___233 *, loff_t, unsigned int, unsigned int, struct page___238 *, void *);
	sector_t (*bmap)(struct address_space___233 *, sector_t);
	void (*invalidatepage)(struct page___238 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___238 *, gfp_t);
	void (*freepage)(struct page___238 *);
	ssize_t (*direct_IO)(struct kiocb___233 *, struct iov_iter___153 *);
	int (*migratepage)(struct address_space___233 *, struct page___238 *, struct page___238 *, enum migrate_mode);
	bool (*isolate_page)(struct page___238 *, isolate_mode_t);
	void (*putback_page)(struct page___238 *);
	int (*launder_page)(struct page___238 *);
	int (*is_partially_uptodate)(struct page___238 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___238 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___233 *, struct page___238 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___233 *, sector_t *);
	void (*swap_deactivate)(struct file___233 *);
};

struct writeback_control___115 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___115 *wb;
	struct inode___233 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___111 {
	struct file___233 *file;
	struct address_space___233 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___150;

struct iov_iter___153 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___150 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___233 {
	struct dentry___233 * (*lookup)(struct inode___233 *, struct dentry___233 *, unsigned int);
	const char * (*get_link)(struct dentry___233 *, struct inode___233 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___233 *, int);
	struct posix_acl * (*get_acl)(struct inode___233 *, int, bool);
	int (*readlink)(struct dentry___233 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___233 *, struct dentry___233 *, umode_t, bool);
	int (*link)(struct dentry___233 *, struct inode___233 *, struct dentry___233 *);
	int (*unlink)(struct inode___233 *, struct dentry___233 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___233 *, struct dentry___233 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___233 *, struct dentry___233 *, umode_t);
	int (*rmdir)(struct inode___233 *, struct dentry___233 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___233 *, struct dentry___233 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___233 *, struct dentry___233 *, struct inode___233 *, struct dentry___233 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___233 *, struct iattr___233 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___233 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___233 *, char *, size_t);
	int (*fiemap)(struct inode___233 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___233 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___233 *, struct dentry___233 *, struct file___233 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___233 *, struct dentry___233 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___233 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___233 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___233 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___233 {
	void (*fl_copy_lock)(struct file_lock___233 *, struct file_lock___233 *);
	void (*fl_release_private)(struct file_lock___233 *);
};

struct fasync_struct___233;

struct lock_manager_operations___233;

struct file_lock___233 {
	struct file_lock___233 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___233 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___233 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___233 *fl_ops;
	const struct lock_manager_operations___233 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___233 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___233 *);
	int (*lm_grant)(struct file_lock___233 *, int);
	bool (*lm_break)(struct file_lock___233 *);
	int (*lm_change)(struct file_lock___233 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___233 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___233 *);
};

struct fasync_struct___233 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___233 *fa_next;
	struct file___233 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___233 {
	struct inode___233 * (*alloc_inode)(struct super_block___233 *);
	void (*destroy_inode)(struct inode___233 *);
	void (*free_inode)(struct inode___233 *);
	void (*dirty_inode)(struct inode___233 *, int);
	int (*write_inode)(struct inode___233 *, struct writeback_control___115 *);
	int (*drop_inode)(struct inode___233 *);
	void (*evict_inode)(struct inode___233 *);
	void (*put_super)(struct super_block___233 *);
	int (*sync_fs)(struct super_block___233 *, int);
	int (*freeze_super)(struct super_block___233 *);
	int (*freeze_fs)(struct super_block___233 *);
	int (*thaw_super)(struct super_block___233 *);
	int (*unfreeze_fs)(struct super_block___233 *);
	int (*statfs)(struct dentry___233 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___233 *, int *, char *);
	void (*umount_begin)(struct super_block___233 *);
	int (*show_options)(struct seq_file___208 *, struct dentry___233 *);
	int (*show_devname)(struct seq_file___208 *, struct dentry___233 *);
	int (*show_path)(struct seq_file___208 *, struct dentry___233 *);
	int (*show_stats)(struct seq_file___208 *, struct dentry___233 *);
	ssize_t (*quota_read)(struct super_block___233 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___233 *, int, const char *, size_t, loff_t);
	struct dquot___233 ** (*get_dquots)(struct inode___233 *);
	long int (*nr_cached_objects)(struct super_block___233 *, struct shrink_control___103 *);
	long int (*free_cached_objects)(struct super_block___233 *, struct shrink_control___103 *);
	struct file___233 * (*real_loop)(struct file___233 *);
};

struct wakeup_source___212;

struct dev_pm_info___212 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___212 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___212 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___212;

struct bus_type___212;

struct device_driver___212;

struct dev_pm_domain___212;

struct fwnode_handle___208;

struct class___212;

struct attribute_group___221;

struct device___212 {
	struct kobject___221 kobj;
	struct device___212 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___212 *type;
	struct bus_type___212 *bus;
	struct device_driver___212 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___212 power;
	struct dev_pm_domain___212 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___208 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___212 *class;
	const struct attribute_group___221 **groups;
	void (*release)(struct device___212 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___129 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___233 *bd_inode;
	struct super_block___233 *bd_super;
	void *bd_claiming;
	struct device___212 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___221 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___129 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___233 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___165)(struct file___233 *, wait_queue_head_t *, struct poll_table_struct___158 *);

struct poll_table_struct___158 {
	poll_queue_proc___165 _qproc;
	__poll_t _key;
};

struct seq_operations___208;

struct seq_file___208 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___208 *op;
	int poll_event;
	const struct file___233 *file;
	void *private;
};

typedef void bio_end_io_t___126(struct bio___126 *);

struct bio_vec___150 {
	struct page___238 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___126;

struct bio___126 {
	struct bio___126 *bi_next;
	struct block_device___129 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___126 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___117 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___126 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___150 *bi_io_vec;
	struct bio_set___126 *bi_pool;
	struct bio_vec___150 bi_inline_vecs[0];
};

struct dev_pagemap_ops___228 {
	void (*page_free)(struct page___238 *);
	void (*kill)(struct dev_pagemap___228 *);
	void (*cleanup)(struct dev_pagemap___228 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___228 *);
};

struct fwnode_operations___208;

struct fwnode_handle___208 {
	struct fwnode_handle___208 *secondary;
	const struct fwnode_operations___208 *ops;
	struct device___212 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___208;

struct fwnode_endpoint___208;

struct fwnode_operations___208 {
	struct fwnode_handle___208 * (*get)(struct fwnode_handle___208 *);
	void (*put)(struct fwnode_handle___208 *);
	bool (*device_is_available)(const struct fwnode_handle___208 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___208 *, const struct device___212 *);
	bool (*property_present)(const struct fwnode_handle___208 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___208 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___208 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___208 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*get_parent)(const struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*get_next_child_node)(const struct fwnode_handle___208 *, struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*get_named_child_node)(const struct fwnode_handle___208 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___208 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___208 *);
	struct fwnode_handle___208 * (*graph_get_next_endpoint)(const struct fwnode_handle___208 *, struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*graph_get_remote_endpoint)(const struct fwnode_handle___208 *);
	struct fwnode_handle___208 * (*graph_get_port_parent)(struct fwnode_handle___208 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___208 *, struct fwnode_endpoint___208 *);
	int (*add_links)(struct fwnode_handle___208 *);
};

struct fwnode_endpoint___208 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___208 *local_fwnode;
};

struct fwnode_reference_args___208 {
	struct fwnode_handle___208 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___221;

struct kernfs_elem_dir___221 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___221 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___221;

struct kernfs_root___221 {
	struct kernfs_node___221 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___221 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___221 {
	struct kernfs_node___221 *target_kn;
};

struct kernfs_ops___221;

struct kernfs_elem_attr___221 {
	const struct kernfs_ops___221 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___221 *notify_next;
};

struct kernfs_node___221 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___221 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___221 dir;
		struct kernfs_elem_symlink___221 symlink;
		struct kernfs_elem_attr___221 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___221;

struct kernfs_ops___221 {
	int (*open)(struct kernfs_open_file___221 *);
	void (*release)(struct kernfs_open_file___221 *);
	int (*seq_show)(struct seq_file___208 *, void *);
	void * (*seq_start)(struct seq_file___208 *, loff_t *);
	void * (*seq_next)(struct seq_file___208 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___208 *, void *);
	ssize_t (*read)(struct kernfs_open_file___221 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___221 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___221 *, struct poll_table_struct___158 *);
	int (*mmap)(struct kernfs_open_file___221 *, struct vm_area_struct___238 *);
};

struct kernfs_syscall_ops___221 {
	int (*show_options)(struct seq_file___208 *, struct kernfs_root___221 *);
	int (*mkdir)(struct kernfs_node___221 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___221 *);
	int (*rename)(struct kernfs_node___221 *, struct kernfs_node___221 *, const char *);
	int (*show_path)(struct seq_file___208 *, struct kernfs_node___221 *, struct kernfs_root___221 *);
};

struct kernfs_open_file___221 {
	struct kernfs_node___221 *kn;
	struct file___233 *file;
	struct seq_file___208 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___228 *vm_ops;
};

struct bin_attribute___221;

struct attribute_group___221 {
	const char *name;
	umode_t (*is_visible)(struct kobject___221 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___221 *, struct bin_attribute___221 *, int);
	struct attribute **attrs;
	struct bin_attribute___221 **bin_attrs;
};

struct bin_attribute___221 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___233 * (*f_mapping)();
	ssize_t (*read)(struct file___233 *, struct kobject___221 *, struct bin_attribute___221 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___233 *, struct kobject___221 *, struct bin_attribute___221 *, char *, loff_t, size_t);
	int (*mmap)(struct file___233 *, struct kobject___221 *, struct bin_attribute___221 *, struct vm_area_struct___238 *);
};

struct sysfs_ops___221 {
	ssize_t (*show)(struct kobject___221 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___221 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___221;

struct kset___221 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___221 kobj;
	const struct kset_uevent_ops___221 *uevent_ops;
};

struct kobj_type___221 {
	void (*release)(struct kobject___221 *);
	const struct sysfs_ops___221 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___221 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___221 *);
	const void * (*namespace)(struct kobject___221 *);
	void (*get_ownership)(struct kobject___221 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___221 {
	int (* const filter)(struct kset___221 *, struct kobject___221 *);
	const char * (* const name)(struct kset___221 *, struct kobject___221 *);
	int (* const uevent)(struct kset___221 *, struct kobject___221 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___217 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___217 *);
	int (*get)(char *, const struct kernel_param___217 *);
	void (*free)(void *);
};

struct kparam_array___217;

struct kernel_param___217 {
	const char *name;
	struct module___217 *mod;
	const struct kernel_param_ops___217 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___217 *arr;
	};
};

struct kparam_array___217 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___217 *ops;
	void *elem;
};

struct module_attribute___217 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___217 *, struct module_kobject___218 *, char *);
	ssize_t (*store)(struct module_attribute___217 *, struct module_kobject___218 *, const char *, size_t);
	void (*setup)(struct module___217 *, const char *);
	int (*test)(struct module___217 *);
	void (*free)(struct module___217 *);
};

struct cgroup_namespace___163 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___163 *root_cset;
};

struct dev_pm_ops___212 {
	int (*prepare)(struct device___212 *);
	void (*complete)(struct device___212 *);
	int (*suspend)(struct device___212 *);
	int (*resume)(struct device___212 *);
	int (*freeze)(struct device___212 *);
	int (*thaw)(struct device___212 *);
	int (*poweroff)(struct device___212 *);
	int (*restore)(struct device___212 *);
	int (*suspend_late)(struct device___212 *);
	int (*resume_early)(struct device___212 *);
	int (*freeze_late)(struct device___212 *);
	int (*thaw_early)(struct device___212 *);
	int (*poweroff_late)(struct device___212 *);
	int (*restore_early)(struct device___212 *);
	int (*suspend_noirq)(struct device___212 *);
	int (*resume_noirq)(struct device___212 *);
	int (*freeze_noirq)(struct device___212 *);
	int (*thaw_noirq)(struct device___212 *);
	int (*poweroff_noirq)(struct device___212 *);
	int (*restore_noirq)(struct device___212 *);
	int (*runtime_suspend)(struct device___212 *);
	int (*runtime_resume)(struct device___212 *);
	int (*runtime_idle)(struct device___212 *);
};

struct wakeup_source___212 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___212 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___212 {
	struct dev_pm_ops___212 ops;
	int (*start)(struct device___212 *);
	void (*detach)(struct device___212 *, bool);
	int (*activate)(struct device___212 *);
	void (*sync)(struct device___212 *);
	void (*dismiss)(struct device___212 *);
};

struct bus_type___212 {
	const char *name;
	const char *dev_name;
	struct device___212 *dev_root;
	const struct attribute_group___221 **bus_groups;
	const struct attribute_group___221 **dev_groups;
	const struct attribute_group___221 **drv_groups;
	int (*match)(struct device___212 *, struct device_driver___212 *);
	int (*uevent)(struct device___212 *, struct kobj_uevent_env *);
	int (*probe)(struct device___212 *);
	void (*sync_state)(struct device___212 *);
	void (*remove)(struct device___212 *);
	void (*shutdown)(struct device___212 *);
	int (*online)(struct device___212 *);
	int (*offline)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	int (*num_vf)(struct device___212 *);
	int (*dma_configure)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___212 {
	const char *name;
	struct bus_type___212 *bus;
	struct module___217 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___212 *);
	void (*sync_state)(struct device___212 *);
	int (*remove)(struct device___212 *);
	void (*shutdown)(struct device___212 *);
	int (*suspend)(struct device___212 *, pm_message_t);
	int (*resume)(struct device___212 *);
	const struct attribute_group___221 **groups;
	const struct attribute_group___221 **dev_groups;
	const struct dev_pm_ops___212 *pm;
	void (*coredump)(struct device___212 *);
	struct driver_private *p;
};

struct device_type___212 {
	const char *name;
	const struct attribute_group___221 **groups;
	int (*uevent)(struct device___212 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___212 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___212 *);
	const struct dev_pm_ops___212 *pm;
};

struct class___212 {
	const char *name;
	struct module___217 *owner;
	const struct attribute_group___221 **class_groups;
	const struct attribute_group___221 **dev_groups;
	struct kobject___221 *dev_kobj;
	int (*dev_uevent)(struct device___212 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___212 *, umode_t *);
	void (*class_release)(struct class___212 *);
	void (*dev_release)(struct device___212 *);
	int (*shutdown_pre)(struct device___212 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___212 *);
	void (*get_ownership)(struct device___212 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___212 *pm;
	struct subsys_private *p;
};

struct block_device_operations___126;

struct gendisk___129 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___129 *part0;
	const struct block_device_operations___126 *fops;
	struct request_queue___126 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___115 *bdi;
	struct kobject___221 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___221 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___126 {
	struct bio___126 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___150 *bip_vec;
	struct bio_vec___150 bip_inline_vecs[0];
};

struct blkcg___117;

struct blkg_policy_data___117;

struct blkcg_gq___117 {
	struct request_queue___126 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___117 *blkcg;
	struct blkcg_gq___117 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___117 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___126 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___126(struct request___126 *);

typedef void integrity_complete_fn___126(struct request___126 *, unsigned int);

struct blk_integrity_profile___126 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___126 *prepare_fn;
	integrity_complete_fn___126 *complete_fn;
	const char *name;
};

struct pr_ops___3;

struct block_device_operations___126 {
	blk_qc_t (*submit_bio)(struct bio___126 *);
	int (*open)(struct block_device___129 *, fmode_t);
	void (*release)(struct gendisk___129 *, fmode_t);
	int (*rw_page)(struct block_device___129 *, sector_t, struct page___238 *, unsigned int);
	int (*ioctl)(struct block_device___129 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___129 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___129 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___129 *);
	int (*getgeo)(struct block_device___129 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___129 *, bool);
	void (*swap_slot_free_notify)(struct block_device___129 *, long unsigned int);
	int (*report_zones)(struct gendisk___129 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___129 *, umode_t *);
	struct module___217 *owner;
	const struct pr_ops___3 *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___129 *, sector_t *);
};

typedef void rq_end_io_fn___126(struct request___126 *, blk_status_t);

struct request___126 {
	struct request_queue___126 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___123 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___126 *bio;
	struct bio___126 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___150 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___126 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___126 *saved_end_io;
		} flush;
	};
	struct gendisk___129 *rq_disk;
	struct block_device___129 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___126 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___123 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___126 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___221 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___233 *debugfs_dir;
	struct dentry___233 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___126;

struct elevator_mq_ops___126 {
	int (*init_sched)(struct request_queue___126 *, struct elevator_type___126 *);
	void (*exit_sched)(struct elevator_queue___126 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___123 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___123 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___123 *);
	bool (*allow_merge)(struct request_queue___126 *, struct request___126 *, struct bio___126 *);
	bool (*bio_merge)(struct request_queue___126 *, struct bio___126 *, unsigned int);
	int (*request_merge)(struct request_queue___126 *, struct request___126 **, struct bio___126 *);
	void (*request_merged)(struct request_queue___126 *, struct request___126 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___126 *, struct request___126 *, struct request___126 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___126 *);
	void (*finish_request)(struct request___126 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___123 *, struct list_head *, bool);
	struct request___126 * (*dispatch_request)(struct blk_mq_hw_ctx___123 *);
	bool (*has_work)(struct blk_mq_hw_ctx___123 *);
	void (*completed_request)(struct request___126 *, u64);
	void (*requeue_request)(struct request___126 *);
	struct request___126 * (*former_request)(struct request_queue___126 *, struct request___126 *);
	struct request___126 * (*next_request)(struct request_queue___126 *, struct request___126 *);
	void (*init_icq)(struct io_cq___126 *);
	void (*exit_icq)(struct io_cq___126 *);
};

struct elv_fs_entry___126;

struct elevator_type___126 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___126 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___126 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___217 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___126 {
	struct elevator_type___126 *type;
	void *elevator_data;
	struct kobject___221 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___126 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___126 *, char *);
	ssize_t (*store)(struct elevator_queue___126 *, const char *, size_t);
};

struct blk_mq_queue_data___123;

struct blk_mq_ops___123 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___123 *, const struct blk_mq_queue_data___123 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___123 *);
	int (*get_budget)(struct request_queue___126 *);
	void (*put_budget)(struct request_queue___126 *, int);
	void (*set_rq_budget_token)(struct request___126 *, int);
	int (*get_rq_budget_token)(struct request___126 *);
	enum blk_eh_timer_return (*timeout)(struct request___126 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___123 *);
	void (*complete)(struct request___126 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___123 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___123 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___123 *, struct request___126 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___123 *, struct request___126 *, unsigned int);
	void (*initialize_rq_fn)(struct request___126 *);
	void (*cleanup_rq)(struct request___126 *);
	bool (*busy)(struct request_queue___126 *);
	int (*map_queues)(struct blk_mq_tag_set___123 *);
	void (*show_rq)(struct seq_file___208 *, struct request___126 *);
};

struct blk_ksm_ll_ops___4 {
	int (*keyslot_program)(struct blk_keyslot_manager___4 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___4 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___4 {
	struct blk_ksm_ll_ops___4 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___212 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct rchan___9;

struct blk_trace___8 {
	int trace_state;
	struct rchan___9 *rchan;
	long unsigned int *sequence;
	unsigned char *msg_data;
	u16 act_mask;
	u64 start_lba;
	u64 end_lba;
	u32 pid;
	u32 dev;
	struct dentry___233 *dir;
	struct list_head running_list;
	atomic_t dropped;
};

struct blk_mq_tag_set___123 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___123 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct pr_ops___3 {
	int (*pr_register)(struct block_device___129 *, u64, u64, u32);
	int (*pr_reserve)(struct block_device___129 *, u64, enum pr_type, u32);
	int (*pr_release)(struct block_device___129 *, u64, enum pr_type);
	int (*pr_preempt)(struct block_device___129 *, u64, u64, enum pr_type, bool);
	int (*pr_clear)(struct block_device___129 *, u64);
};

struct blk_mq_queue_data___123 {
	struct request___126 *rq;
	bool last;
};

struct rchan_buf___9 {
	void *start;
	void *data;
	size_t offset;
	size_t subbufs_produced;
	size_t subbufs_consumed;
	struct rchan___9 *chan;
	wait_queue_head_t read_wait;
	struct irq_work wakeup_work;
	struct dentry___233 *dentry;
	struct kref kref;
	struct page___238 **page_array;
	unsigned int page_count;
	unsigned int finalized;
	size_t *padding;
	size_t prev_padding;
	size_t bytes_consumed;
	size_t early_bytes;
	unsigned int cpu;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
};

struct rchan_callbacks___9;

struct rchan___9 {
	u32 version;
	size_t subbuf_size;
	size_t n_subbufs;
	size_t alloc_size;
	const struct rchan_callbacks___9 *cb;
	struct kref kref;
	void *private_data;
	size_t last_toobig;
	struct rchan_buf___9 **buf;
	int is_global;
	struct list_head list;
	struct dentry___233 *parent;
	int has_base_filename;
	char base_filename[255];
};

struct rchan_callbacks___9 {
	int (*subbuf_start)(struct rchan_buf___9 *, void *, void *, size_t);
	struct dentry___233 * (*create_buf_file)(const char *, struct dentry___233 *, umode_t, struct rchan_buf___9 *, int *);
	int (*remove_buf_file)(struct dentry___233 *);
};

struct dm_target___3;

typedef int (*dm_ctr_fn___3)(struct dm_target___3 *, unsigned int, char **);

struct dm_table___2;

struct target_type___3;

struct dm_target___3 {
	struct dm_table___2 *table;
	struct target_type___3 *type;
	sector_t begin;
	sector_t len;
	uint32_t max_io_len;
	unsigned int num_flush_bios;
	unsigned int num_discard_bios;
	unsigned int num_secure_erase_bios;
	unsigned int num_write_same_bios;
	unsigned int num_write_zeroes_bios;
	unsigned int per_io_data_size;
	void *private;
	char *error;
	bool flush_supported: 1;
	bool discards_supported: 1;
	bool limit_swap_bios: 1;
	bool emulate_zone_append: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef void (*dm_dtr_fn___3)(struct dm_target___3 *);

typedef int (*dm_map_fn___3)(struct dm_target___3 *, struct bio___126 *);

typedef int (*dm_clone_and_map_request_fn___3)(struct dm_target___3 *, struct request___126 *, union map_info___2 *, struct request___126 **);

typedef void (*dm_release_clone_request_fn___3)(struct request___126 *, union map_info___2 *);

typedef int (*dm_endio_fn___3)(struct dm_target___3 *, struct bio___126 *, blk_status_t *);

typedef int (*dm_request_endio_fn___3)(struct dm_target___3 *, struct request___126 *, blk_status_t, union map_info___2 *);

typedef void (*dm_presuspend_fn___3)(struct dm_target___3 *);

typedef void (*dm_presuspend_undo_fn___3)(struct dm_target___3 *);

typedef void (*dm_postsuspend_fn___3)(struct dm_target___3 *);

typedef int (*dm_preresume_fn___3)(struct dm_target___3 *);

typedef void (*dm_resume_fn___3)(struct dm_target___3 *);

typedef void (*dm_status_fn___3)(struct dm_target___3 *, status_type_t, unsigned int, char *, unsigned int);

typedef int (*dm_message_fn___3)(struct dm_target___3 *, unsigned int, char **, char *, unsigned int);

typedef int (*dm_prepare_ioctl_fn___3)(struct dm_target___3 *, struct block_device___129 **);

struct dm_report_zones_args___3;

typedef int (*dm_report_zones_fn___3)(struct dm_target___3 *, struct dm_report_zones_args___3 *, unsigned int);

struct dm_report_zones_args___3 {
	struct dm_target___3 *tgt;
	sector_t next_sector;
	void *orig_data;
	report_zones_cb orig_cb;
	unsigned int zone_idx;
	sector_t start;
};

struct dm_dev___3;

typedef int (*iterate_devices_callout_fn___3)(struct dm_target___3 *, struct dm_dev___3 *, sector_t, sector_t, void *);

struct dm_dev___3 {
	struct block_device___129 *bdev;
	struct dax_device *dax_dev;
	fmode_t mode;
	char name[16];
};

typedef int (*dm_iterate_devices_fn___3)(struct dm_target___3 *, iterate_devices_callout_fn___3, void *);

typedef void (*dm_io_hints_fn___3)(struct dm_target___3 *, struct queue_limits *);

typedef int (*dm_busy_fn___3)(struct dm_target___3 *);

typedef long int (*dm_dax_direct_access_fn___3)(struct dm_target___3 *, long unsigned int, long int, void **, pfn_t *);

typedef size_t (*dm_dax_copy_iter_fn___3)(struct dm_target___3 *, long unsigned int, void *, size_t, struct iov_iter___153 *);

typedef int (*dm_dax_zero_page_range_fn___3)(struct dm_target___3 *, long unsigned int, size_t);

struct target_type___3 {
	uint64_t features;
	const char *name;
	struct module___217 *module;
	unsigned int version[3];
	dm_ctr_fn___3 ctr;
	dm_dtr_fn___3 dtr;
	dm_map_fn___3 map;
	dm_clone_and_map_request_fn___3 clone_and_map_rq;
	dm_release_clone_request_fn___3 release_clone_rq;
	dm_endio_fn___3 end_io;
	dm_request_endio_fn___3 rq_end_io;
	dm_presuspend_fn___3 presuspend;
	dm_presuspend_undo_fn___3 presuspend_undo;
	dm_postsuspend_fn___3 postsuspend;
	dm_preresume_fn___3 preresume;
	dm_resume_fn___3 resume;
	dm_status_fn___3 status;
	dm_message_fn___3 message;
	dm_prepare_ioctl_fn___3 prepare_ioctl;
	dm_report_zones_fn___3 report_zones;
	dm_busy_fn___3 busy;
	dm_iterate_devices_fn___3 iterate_devices;
	dm_io_hints_fn___3 io_hints;
	dm_dax_direct_access_fn___3 direct_access;
	dm_dax_copy_iter_fn___3 dax_copy_from_iter;
	dm_dax_copy_iter_fn___3 dax_copy_to_iter;
	dm_dax_zero_page_range_fn___3 dax_zero_page_range;
	struct list_head list;
};

struct mapped_device___3;

struct dm_table___2 {
	struct mapped_device___3 *md;
	enum dm_queue_mode type;
	unsigned int depth;
	unsigned int counts[16];
	sector_t *index[16];
	unsigned int num_targets;
	unsigned int num_allocated;
	sector_t *highs;
	struct dm_target___3 *targets;
	struct target_type___3 *immutable_target_type;
	bool integrity_supported: 1;
	bool singleton: 1;
	unsigned int integrity_added: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	fmode_t mode;
	struct list_head devices;
	void (*event_fn)(void *);
	void *event_context;
	struct dm_md_mempools *mempools;
	struct blk_keyslot_manager___4 *ksm;
};

struct seq_operations___208 {
	void * (*start)(struct seq_file___208 *, loff_t *);
	void (*stop)(struct seq_file___208 *, void *);
	void * (*next)(struct seq_file___208 *, void *, loff_t *);
	int (*show)(struct seq_file___208 *, void *);
};

struct cftype___163;

struct cgroup_subsys___163 {
	struct cgroup_subsys_state___163 * (*css_alloc)(struct cgroup_subsys_state___163 *);
	int (*css_online)(struct cgroup_subsys_state___163 *);
	void (*css_offline)(struct cgroup_subsys_state___163 *);
	void (*css_released)(struct cgroup_subsys_state___163 *);
	void (*css_free)(struct cgroup_subsys_state___163 *);
	void (*css_reset)(struct cgroup_subsys_state___163 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___163 *, int);
	int (*css_extra_stat_show)(struct seq_file___208 *, struct cgroup_subsys_state___163 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___240 *, struct css_set___163 *);
	void (*cancel_fork)(struct task_struct___240 *, struct css_set___163 *);
	void (*fork)(struct task_struct___240 *);
	void (*exit)(struct task_struct___240 *);
	void (*release)(struct task_struct___240 *);
	void (*bind)(struct cgroup_subsys_state___163 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___163 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___163 *dfl_cftypes;
	struct cftype___163 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___163 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___163 *updated_children;
	struct cgroup___163 *updated_next;
};

struct cgroup_root___163 {
	struct kernfs_root___221 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___163 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___163 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___163 *ss;
	struct list_head node;
	struct kernfs_ops___221 *kf_ops;
	int (*open)(struct kernfs_open_file___221 *);
	void (*release)(struct kernfs_open_file___221 *);
	u64 (*read_u64)(struct cgroup_subsys_state___163 *, struct cftype___163 *);
	s64 (*read_s64)(struct cgroup_subsys_state___163 *, struct cftype___163 *);
	int (*seq_show)(struct seq_file___208 *, void *);
	void * (*seq_start)(struct seq_file___208 *, loff_t *);
	void * (*seq_next)(struct seq_file___208 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___208 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___163 *, struct cftype___163 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___163 *, struct cftype___163 *, s64);
	ssize_t (*write)(struct kernfs_open_file___221 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___221 *, struct poll_table_struct___158 *);
};

struct blkcg_policy_data___117;

struct blkcg___117 {
	struct cgroup_subsys_state___163 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___117 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___117 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___117 {
	struct blkcg___117 *blkcg;
	int plid;
};

struct blkg_policy_data___117 {
	struct blkcg_gq___117 *blkg;
	int plid;
};

struct dm_kobject_holder___2 {
	struct kobject___221 kobj;
	struct completion completion;
};

struct mapped_device___3 {
	struct mutex suspend_lock;
	struct mutex table_devices_lock;
	struct list_head table_devices;
	void *map;
	long unsigned int flags;
	struct mutex type_lock;
	enum dm_queue_mode type;
	int numa_node_id;
	struct request_queue___126 *queue;
	atomic_t holders;
	atomic_t open_count;
	struct dm_target___3 *immutable_target;
	struct target_type___3 *immutable_target_type;
	char name[16];
	struct gendisk___129 *disk;
	struct dax_device *dax_dev;
	long unsigned int *pending_io;
	struct work_struct work;
	wait_queue_head_t wait;
	spinlock_t deferred_lock;
	struct bio_list___126 deferred;
	void *interface_ptr;
	wait_queue_head_t eventq;
	atomic_t event_nr;
	atomic_t uevent_seq;
	struct list_head uevent_list;
	spinlock_t uevent_lock;
	unsigned int internal_suspend_count;
	struct bio_set___126 io_bs;
	struct bio_set___126 bs;
	struct workqueue_struct *wq;
	struct hd_geometry geometry;
	struct dm_kobject_holder___2 kobj_holder;
	int swap_bios;
	struct semaphore swap_bios_semaphore;
	struct mutex swap_bios_lock;
	struct dm_stats stats;
	struct blk_mq_tag_set___123 *tag_set;
	bool init_tio_pdu: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct srcu_struct io_barrier;
	unsigned int nr_zones;
	unsigned int *zwp_offset;
	struct dm_ima_measurements ima;
};

struct dm_md_mempools {
	struct bio_set___126 bs;
	struct bio_set___126 io_bs;
};

struct dm_io___2;

struct dm_target_io___2 {
	unsigned int magic;
	struct dm_io___2 *io;
	struct dm_target___3 *ti;
	unsigned int target_bio_nr;
	unsigned int *len_ptr;
	bool inside_dm_io;
	struct bio___126 clone;
};

struct dm_io___2 {
	unsigned int magic;
	struct mapped_device___3 *md;
	blk_status_t status;
	atomic_t io_count;
	struct bio___126 *orig_bio;
	long unsigned int start_time;
	spinlock_t endio_lock;
	struct dm_stats_aux stats_aux;
	struct dm_target_io___2 tio;
};

struct dax_operations___2 {
	long int (*direct_access)(struct dax_device *, long unsigned int, long int, void **, pfn_t *);
	bool (*dax_supported)(struct dax_device *, struct block_device___129 *, int, sector_t, sector_t);
	size_t (*copy_from_iter)(struct dax_device *, long unsigned int, void *, size_t, struct iov_iter___153 *);
	size_t (*copy_to_iter)(struct dax_device *, long unsigned int, void *, size_t, struct iov_iter___153 *);
	int (*zero_page_range)(struct dax_device *, long unsigned int, size_t);
};

struct clone_info {
	struct dm_table___2 *map;
	struct bio___126 *bio;
	struct dm_io___2 *io;
	sector_t sector;
	unsigned int sector_count;
};

struct table_device {
	struct list_head list;
	refcount_t count;
	struct dm_dev___3 dm_dev;
};

struct dm_pr {
	u64 old_key;
	u64 new_key;
	u32 flags;
	bool fail_early;
};

struct dm_arg_set {
	unsigned int argc;
	char **argv;
};

struct dm_arg {
	unsigned int min;
	unsigned int max;
	char *error;
};

struct dm_dev_internal {
	struct list_head list;
	refcount_t count;
	struct dm_dev___2 *dm_dev;
};

struct dm_keyslot_manager {
	struct blk_keyslot_manager___3 ksm;
	struct mapped_device___2 *md;
};

struct dm_keyslot_evict_args {
	const struct blk_crypto_key *key;
	int err;
};

enum suspend_mode {
	PRESUSPEND = 0,
	PRESUSPEND_UNDO = 1,
	POSTSUSPEND = 2,
};

struct linear_c {
	struct dm_dev___2 *dev;
	sector_t start;
};

struct stripe {
	struct dm_dev___2 *dev;
	sector_t physical_start;
	atomic_t error_count;
};

struct stripe_c {
	uint32_t stripes;
	int stripes_shift;
	sector_t stripe_width;
	uint32_t chunk_size;
	int chunk_size_shift;
	struct dm_target___2 *ti;
	struct work_struct trigger_event;
	struct stripe stripe[0];
};

typedef struct poll_table_struct___158 poll_table___47;

struct dm_target_deps {
	__u32 count;
	__u32 padding;
	__u64 dev[0];
};

struct dm_name_list {
	__u64 dev;
	__u32 next;
	char name[0];
};

struct dm_target_versions {
	__u32 next;
	__u32 version[3];
	char name[0];
};

struct dm_target_msg {
	__u64 sector;
	char message[0];
};

enum {
	DM_VERSION_CMD = 0,
	DM_REMOVE_ALL_CMD = 1,
	DM_LIST_DEVICES_CMD = 2,
	DM_DEV_CREATE_CMD = 3,
	DM_DEV_REMOVE_CMD = 4,
	DM_DEV_RENAME_CMD = 5,
	DM_DEV_SUSPEND_CMD = 6,
	DM_DEV_STATUS_CMD = 7,
	DM_DEV_WAIT_CMD = 8,
	DM_TABLE_LOAD_CMD = 9,
	DM_TABLE_CLEAR_CMD = 10,
	DM_TABLE_DEPS_CMD = 11,
	DM_TABLE_STATUS_CMD = 12,
	DM_LIST_VERSIONS_CMD = 13,
	DM_TARGET_MSG_CMD = 14,
	DM_DEV_SET_GEOMETRY_CMD = 15,
	DM_DEV_ARM_POLL_CMD = 16,
	DM_GET_TARGET_VERSION_CMD = 17,
};

struct dm_dev_internal___2 {
	struct list_head list;
	refcount_t count;
	struct dm_dev___3 *dm_dev;
};

struct miscdevice___10 {
	int minor;
	const char *name;
	const struct file_operations___234 *fops;
	struct list_head list;
	struct device___212 *parent;
	struct device___212 *this_device;
	const struct attribute_group___221 **groups;
	const char *nodename;
	umode_t mode;
};

struct dm_file {
	volatile unsigned int global_event_nr;
};

struct hash_cell {
	struct rb_node name_node;
	struct rb_node uuid_node;
	bool name_set;
	bool uuid_set;
	char *name;
	char *uuid;
	struct mapped_device___3 *md;
	struct dm_table___2 *new_map;
};

struct vers_iter {
	size_t param_size;
	struct dm_target_versions *vers;
	struct dm_target_versions *old_vers;
	char *end;
	uint32_t flags;
};

typedef int (*ioctl_fn)(struct file___233 *, struct dm_ioctl *, size_t);

struct dm_io_region {
	struct block_device___128 *bdev;
	sector_t sector;
	sector_t count;
};

struct page_list {
	struct page_list *next;
	struct page___237 *page;
};

typedef void (*io_notify_fn)(long unsigned int, void *);

enum dm_io_mem_type {
	DM_IO_PAGE_LIST = 0,
	DM_IO_BIO = 1,
	DM_IO_VMA = 2,
	DM_IO_KMEM = 3,
};

struct dm_io_memory {
	enum dm_io_mem_type type;
	unsigned int offset;
	union {
		struct page_list *pl;
		struct bio___125 *bio;
		void *vma;
		void *addr;
	} ptr;
};

struct dm_io_notify {
	io_notify_fn fn;
	void *context;
};

struct dm_io_client;

struct dm_io_request {
	int bi_op;
	int bi_op_flags;
	struct dm_io_memory mem;
	struct dm_io_notify notify;
	struct dm_io_client *client;
};

struct dm_io_client {
	mempool_t pool;
	struct bio_set___125 bios;
};

struct io {
	long unsigned int error_bits;
	atomic_t count;
	struct dm_io_client *client;
	io_notify_fn callback;
	void *context;
	void *vma_invalidate_address;
	long unsigned int vma_invalidate_size;
	long: 64;
};

struct dpages {
	void (*get_page)(struct dpages *, struct page___237 **, long unsigned int *, unsigned int *);
	void (*next_page)(struct dpages *);
	union {
		unsigned int context_u;
		struct bvec_iter context_bi;
	};
	void *context_ptr;
	void *vma_invalidate_address;
	long unsigned int vma_invalidate_size;
};

struct sync_io {
	long unsigned int error_bits;
	struct completion wait;
};

struct dm_kcopyd_throttle {
	unsigned int throttle;
	unsigned int num_io_jobs;
	unsigned int io_period;
	unsigned int total_period;
	unsigned int last_jiffies;
};

typedef void (*dm_kcopyd_notify_fn)(int, long unsigned int, void *);

struct dm_kcopyd_client {
	struct page_list *pages;
	unsigned int nr_reserved_pages;
	unsigned int nr_free_pages;
	unsigned int sub_job_size;
	struct dm_io_client *io_client;
	wait_queue_head_t destroyq;
	mempool_t job_pool;
	struct workqueue_struct *kcopyd_wq;
	struct work_struct kcopyd_work;
	struct dm_kcopyd_throttle *throttle;
	atomic_t nr_jobs;
	spinlock_t job_lock;
	struct list_head callback_jobs;
	struct list_head complete_jobs;
	struct list_head io_jobs;
	struct list_head pages_jobs;
};

struct kcopyd_job {
	struct dm_kcopyd_client *kc;
	struct list_head list;
	unsigned int flags;
	int read_err;
	long unsigned int write_err;
	int rw;
	struct dm_io_region source;
	unsigned int num_dests;
	struct dm_io_region dests[8];
	struct page_list *pages;
	dm_kcopyd_notify_fn fn;
	void *context;
	struct mutex lock;
	atomic_t sub_jobs;
	sector_t progress;
	sector_t write_offset;
	struct kcopyd_job *master_job;
};

struct dm_sysfs_attr {
	struct attribute attr;
	ssize_t (*show)(struct mapped_device___2 *, char *);
	ssize_t (*store)(struct mapped_device___2 *, const char *, size_t);
};

struct dm_stats_last_position {
	sector_t last_sector;
	unsigned int last_rw;
};

struct dm_stat_percpu {
	long long unsigned int sectors[2];
	long long unsigned int ios[2];
	long long unsigned int merges[2];
	long long unsigned int ticks[2];
	long long unsigned int io_ticks[2];
	long long unsigned int io_ticks_total;
	long long unsigned int time_in_queue;
	long long unsigned int *histogram;
};

struct dm_stat_shared {
	atomic_t in_flight[2];
	long long unsigned int stamp;
	struct dm_stat_percpu tmp;
};

struct dm_stat {
	struct list_head list_entry;
	int id;
	unsigned int stat_flags;
	size_t n_entries;
	sector_t start;
	sector_t end;
	sector_t step;
	unsigned int n_histogram_entries;
	long long unsigned int *histogram_boundaries;
	const char *program_id;
	const char *aux_data;
	struct callback_head callback_head;
	size_t shared_alloc_size;
	size_t percpu_alloc_size;
	size_t histogram_alloc_size;
	struct dm_stat_percpu *stat_percpu[256];
	struct dm_stat_shared stat_shared[0];
};

struct kthread_work___10;

typedef void (*kthread_work_func_t___10)(struct kthread_work___10 *);

struct kthread_worker___10;

struct kthread_work___10 {
	struct list_head node;
	kthread_work_func_t___10 func;
	struct kthread_worker___10 *worker;
	int canceling;
};

struct kthread_worker___10 {
	unsigned int flags;
	raw_spinlock_t lock;
	struct list_head work_list;
	struct list_head delayed_work_list;
	struct task_struct___239 *task;
	struct kthread_work___10 *current_work;
};

struct dm_rq_target_io;

struct dm_rq_clone_bio_info {
	struct bio___125 *orig;
	struct dm_rq_target_io *tio;
	struct bio___125 clone;
};

struct dm_rq_target_io {
	struct mapped_device___2 *md;
	struct dm_target___2 *ti;
	struct request___125 *orig;
	struct request___125 *clone;
	struct kthread_work___10 work;
	blk_status_t error;
	union map_info___2 info;
	struct dm_stats_aux stats_aux;
	long unsigned int duration_jiffies;
	unsigned int n_sectors;
	unsigned int completed;
};

enum dev_type {
	DEV_UNKNOWN = 0,
	DEV_X1 = 1,
	DEV_X2 = 2,
	DEV_X4 = 3,
	DEV_X8 = 4,
	DEV_X16 = 5,
	DEV_X32 = 6,
	DEV_X64 = 7,
};

enum hw_event_mc_err_type {
	HW_EVENT_ERR_CORRECTED = 0,
	HW_EVENT_ERR_UNCORRECTED = 1,
	HW_EVENT_ERR_DEFERRED = 2,
	HW_EVENT_ERR_FATAL = 3,
	HW_EVENT_ERR_INFO = 4,
};

enum mem_type {
	MEM_EMPTY = 0,
	MEM_RESERVED = 1,
	MEM_UNKNOWN = 2,
	MEM_FPM = 3,
	MEM_EDO = 4,
	MEM_BEDO = 5,
	MEM_SDR = 6,
	MEM_RDR = 7,
	MEM_DDR = 8,
	MEM_RDDR = 9,
	MEM_RMBS = 10,
	MEM_DDR2 = 11,
	MEM_FB_DDR2 = 12,
	MEM_RDDR2 = 13,
	MEM_XDR = 14,
	MEM_DDR3 = 15,
	MEM_RDDR3 = 16,
	MEM_LRDDR3 = 17,
	MEM_LPDDR3 = 18,
	MEM_DDR4 = 19,
	MEM_RDDR4 = 20,
	MEM_LRDDR4 = 21,
	MEM_LPDDR4 = 22,
	MEM_DDR5 = 23,
	MEM_RDDR5 = 24,
	MEM_LRDDR5 = 25,
	MEM_NVDIMM = 26,
	MEM_WIO2 = 27,
	MEM_HBM2 = 28,
};

enum edac_type {
	EDAC_UNKNOWN = 0,
	EDAC_NONE = 1,
	EDAC_RESERVED = 2,
	EDAC_PARITY = 3,
	EDAC_EC = 4,
	EDAC_SECDED = 5,
	EDAC_S2ECD2ED = 6,
	EDAC_S4ECD4ED = 7,
	EDAC_S8ECD8ED = 8,
	EDAC_S16ECD16ED = 9,
};

enum scrub_type {
	SCRUB_UNKNOWN = 0,
	SCRUB_NONE = 1,
	SCRUB_SW_PROG = 2,
	SCRUB_SW_SRC = 3,
	SCRUB_SW_PROG_SRC = 4,
	SCRUB_SW_TUNABLE = 5,
	SCRUB_HW_PROG = 6,
	SCRUB_HW_SRC = 7,
	SCRUB_HW_PROG_SRC = 8,
	SCRUB_HW_TUNABLE = 9,
};

enum edac_mc_layer_type {
	EDAC_MC_LAYER_BRANCH = 0,
	EDAC_MC_LAYER_CHANNEL = 1,
	EDAC_MC_LAYER_SLOT = 2,
	EDAC_MC_LAYER_CHIP_SELECT = 3,
	EDAC_MC_LAYER_ALL_MEM = 4,
};

struct edac_mc_layer {
	enum edac_mc_layer_type type;
	unsigned int size;
	bool is_virt_csrow;
};

struct mem_ctl_info;

struct dimm_info {
	struct device___211 dev;
	char label[32];
	unsigned int location[3];
	struct mem_ctl_info *mci;
	unsigned int idx;
	u32 grain;
	enum dev_type dtype;
	enum mem_type mtype;
	enum edac_type edac_mode;
	u32 nr_pages;
	unsigned int csrow;
	unsigned int cschannel;
	u16 smbios_handle;
	u32 ce_count;
	u32 ue_count;
};

struct mcidev_sysfs_attribute;

struct edac_raw_error_desc {
	char location[256];
	char label[296];
	long int grain;
	u16 error_count;
	enum hw_event_mc_err_type type;
	int top_layer;
	int mid_layer;
	int low_layer;
	long unsigned int page_frame_number;
	long unsigned int offset_in_page;
	long unsigned int syndrome;
	const char *msg;
	const char *other_detail;
};

struct csrow_info;

struct mem_ctl_info {
	struct device___211 dev;
	struct bus_type___211 *bus;
	struct list_head link;
	struct module___216 *owner;
	long unsigned int mtype_cap;
	long unsigned int edac_ctl_cap;
	long unsigned int edac_cap;
	long unsigned int scrub_cap;
	enum scrub_type scrub_mode;
	int (*set_sdram_scrub_rate)(struct mem_ctl_info *, u32);
	int (*get_sdram_scrub_rate)(struct mem_ctl_info *);
	void (*edac_check)(struct mem_ctl_info *);
	long unsigned int (*ctl_page_to_phys)(struct mem_ctl_info *, long unsigned int);
	int mc_idx;
	struct csrow_info **csrows;
	unsigned int nr_csrows;
	unsigned int num_cschannel;
	unsigned int n_layers;
	struct edac_mc_layer *layers;
	bool csbased;
	unsigned int tot_dimms;
	struct dimm_info **dimms;
	struct device___211 *pdev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	u32 ce_noinfo_count;
	u32 ue_noinfo_count;
	u32 ue_mc;
	u32 ce_mc;
	struct completion complete;
	const struct mcidev_sysfs_attribute *mc_driver_sysfs_attributes;
	struct delayed_work work;
	struct edac_raw_error_desc error_desc;
	int op_state;
	struct dentry___232 *debugfs;
	u8 fake_inject_layer[3];
	bool fake_inject_ue;
	u16 fake_inject_count;
};

struct rank_info {
	int chan_idx;
	struct csrow_info *csrow;
	struct dimm_info *dimm;
	u32 ce_count;
};

struct csrow_info {
	struct device___211 dev;
	long unsigned int first_page;
	long unsigned int last_page;
	long unsigned int page_mask;
	int csrow_idx;
	u32 ue_count;
	u32 ce_count;
	struct mem_ctl_info *mci;
	u32 nr_channels;
	struct rank_info **channels;
};

struct edac_device_counter {
	u32 ue_count;
	u32 ce_count;
};

struct edac_device_ctl_info;

struct edac_dev_sysfs_attribute {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_ctl_info *, char *);
	ssize_t (*store)(struct edac_device_ctl_info *, const char *, size_t);
};

struct edac_device_instance;

struct edac_device_ctl_info {
	struct list_head link;
	struct module___216 *owner;
	int dev_idx;
	int log_ue;
	int log_ce;
	int panic_on_ue;
	unsigned int poll_msec;
	long unsigned int delay;
	struct edac_dev_sysfs_attribute *sysfs_attributes;
	struct bus_type___211 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_device_ctl_info *);
	struct device___211 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion removal_complete;
	char name[32];
	u32 nr_instances;
	struct edac_device_instance *instances;
	struct edac_device_counter counters;
	struct kobject___220 kobj;
};

struct edac_device_block;

struct edac_dev_sysfs_block_attribute {
	struct attribute attr;
	ssize_t (*show)(struct kobject___220 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___220 *, struct attribute *, const char *, size_t);
	struct edac_device_block *block;
	unsigned int value;
};

struct edac_device_block {
	struct edac_device_instance *instance;
	char name[32];
	struct edac_device_counter counters;
	int nr_attribs;
	struct edac_dev_sysfs_block_attribute *block_attributes;
	struct kobject___220 kobj;
};

struct edac_device_instance {
	struct edac_device_ctl_info *ctl;
	char name[35];
	struct edac_device_counter counters;
	u32 nr_blocks;
	struct edac_device_block *blocks;
	struct kobject___220 kobj;
};

struct ctl_info_attribute {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_ctl_info *, char *);
	ssize_t (*store)(struct edac_device_ctl_info *, const char *, size_t);
};

struct instance_attribute {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_instance *, char *);
	ssize_t (*store)(struct edac_device_instance *, const char *, size_t);
};

struct edac_pci_counter {
	atomic_t pe_count;
	atomic_t npe_count;
};

struct edac_pci_ctl_info {
	struct list_head link;
	int pci_idx;
	struct bus_type___211 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_pci_ctl_info *);
	struct device___211 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion complete;
	char name[32];
	struct edac_pci_counter counters;
	struct kobject___220 kobj;
};

struct edac_pci_gen_data {
	int edac_idx;
};

struct instance_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct edac_pci_ctl_info *, char *);
	ssize_t (*store)(struct edac_pci_ctl_info *, const char *, size_t);
};

struct edac_pci_dev_attribute {
	struct attribute attr;
	void *value;
	ssize_t (*show)(void *, char *);
	ssize_t (*store)(void *, const char *, size_t);
};

typedef void (*pci_parity_check_fn_t)(struct pci_dev *);

struct mem_ctl_info___2;

struct dimm_info___2 {
	struct device___12 dev;
	char label[32];
	unsigned int location[3];
	struct mem_ctl_info___2 *mci;
	unsigned int idx;
	u32 grain;
	enum dev_type dtype;
	enum mem_type mtype;
	enum edac_type edac_mode;
	u32 nr_pages;
	unsigned int csrow;
	unsigned int cschannel;
	u16 smbios_handle;
	u32 ce_count;
	u32 ue_count;
};

struct csrow_info___2;

struct mem_ctl_info___2 {
	struct device___12 dev;
	struct bus_type___12 *bus;
	struct list_head link;
	struct module___15 *owner;
	long unsigned int mtype_cap;
	long unsigned int edac_ctl_cap;
	long unsigned int edac_cap;
	long unsigned int scrub_cap;
	enum scrub_type scrub_mode;
	int (*set_sdram_scrub_rate)(struct mem_ctl_info___2 *, u32);
	int (*get_sdram_scrub_rate)(struct mem_ctl_info___2 *);
	void (*edac_check)(struct mem_ctl_info___2 *);
	long unsigned int (*ctl_page_to_phys)(struct mem_ctl_info___2 *, long unsigned int);
	int mc_idx;
	struct csrow_info___2 **csrows;
	unsigned int nr_csrows;
	unsigned int num_cschannel;
	unsigned int n_layers;
	struct edac_mc_layer *layers;
	bool csbased;
	unsigned int tot_dimms;
	struct dimm_info___2 **dimms;
	struct device___12 *pdev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	u32 ce_noinfo_count;
	u32 ue_noinfo_count;
	u32 ue_mc;
	u32 ce_mc;
	struct completion complete;
	const struct mcidev_sysfs_attribute *mc_driver_sysfs_attributes;
	struct delayed_work work;
	struct edac_raw_error_desc error_desc;
	int op_state;
	struct dentry___14 *debugfs;
	u8 fake_inject_layer[3];
	bool fake_inject_ue;
	u16 fake_inject_count;
};

struct rank_info___2 {
	int chan_idx;
	struct csrow_info___2 *csrow;
	struct dimm_info___2 *dimm;
	u32 ce_count;
};

struct csrow_info___2 {
	struct device___12 dev;
	long unsigned int first_page;
	long unsigned int last_page;
	long unsigned int page_mask;
	int csrow_idx;
	u32 ue_count;
	u32 ce_count;
	struct mem_ctl_info___2 *mci;
	u32 nr_channels;
	struct rank_info___2 **channels;
};

struct ghes_pvt {
	struct mem_ctl_info___2 *mci;
	char other_detail[400];
	char msg[80];
};

struct ghes_hw_desc {
	int num_dimms;
	struct dimm_info___2 *dimms;
};

struct memdev_dmi_entry {
	u8 type;
	u8 length;
	u16 handle;
	u16 phys_mem_array_handle;
	u16 mem_err_info_handle;
	u16 total_width;
	u16 data_width;
	u16 size;
	u8 form_factor;
	u8 device_set;
	u8 device_locator;
	u8 bank_locator;
	u8 memory_type;
	u16 type_detail;
	u16 speed;
	u8 manufacturer;
	u8 serial_number;
	u8 asset_tag;
	u8 part_number;
	u8 attributes;
	u32 extended_size;
	u16 conf_mem_clk_speed;
} __attribute__((packed));

struct mem_ctl_info___3;

struct dimm_info___3 {
	struct device___12 dev;
	char label[32];
	unsigned int location[3];
	struct mem_ctl_info___3 *mci;
	unsigned int idx;
	u32 grain;
	enum dev_type dtype;
	enum mem_type mtype;
	enum edac_type edac_mode;
	u32 nr_pages;
	unsigned int csrow;
	unsigned int cschannel;
	u16 smbios_handle;
	u32 ce_count;
	u32 ue_count;
};

struct csrow_info___3;

struct mem_ctl_info___3 {
	struct device___12 dev;
	struct bus_type___12 *bus;
	struct list_head link;
	struct module___216 *owner;
	long unsigned int mtype_cap;
	long unsigned int edac_ctl_cap;
	long unsigned int edac_cap;
	long unsigned int scrub_cap;
	enum scrub_type scrub_mode;
	int (*set_sdram_scrub_rate)(struct mem_ctl_info___3 *, u32);
	int (*get_sdram_scrub_rate)(struct mem_ctl_info___3 *);
	void (*edac_check)(struct mem_ctl_info___3 *);
	long unsigned int (*ctl_page_to_phys)(struct mem_ctl_info___3 *, long unsigned int);
	int mc_idx;
	struct csrow_info___3 **csrows;
	unsigned int nr_csrows;
	unsigned int num_cschannel;
	unsigned int n_layers;
	struct edac_mc_layer *layers;
	bool csbased;
	unsigned int tot_dimms;
	struct dimm_info___3 **dimms;
	struct device___12 *pdev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	u32 ce_noinfo_count;
	u32 ue_noinfo_count;
	u32 ue_mc;
	u32 ce_mc;
	struct completion complete;
	const struct mcidev_sysfs_attribute *mc_driver_sysfs_attributes;
	struct delayed_work work;
	struct edac_raw_error_desc error_desc;
	int op_state;
	struct dentry___232 *debugfs;
	u8 fake_inject_layer[3];
	bool fake_inject_ue;
	u16 fake_inject_count;
};

struct rank_info___3 {
	int chan_idx;
	struct csrow_info___3 *csrow;
	struct dimm_info___3 *dimm;
	u32 ce_count;
};

struct csrow_info___3 {
	struct device___12 dev;
	long unsigned int first_page;
	long unsigned int last_page;
	long unsigned int page_mask;
	int csrow_idx;
	u32 ue_count;
	u32 ce_count;
	struct mem_ctl_info___3 *mci;
	u32 nr_channels;
	struct rank_info___3 **channels;
};

struct edac_dev_sysfs_attribute___2;

struct altr_sdram_prv_data {
	int ecc_ctrl_offset;
	int ecc_ctl_en_mask;
	int ecc_cecnt_offset;
	int ecc_uecnt_offset;
	int ecc_stat_offset;
	int ecc_stat_ce_mask;
	int ecc_stat_ue_mask;
	int ecc_saddr_offset;
	int ecc_daddr_offset;
	int ecc_irq_en_offset;
	int ecc_irq_en_mask;
	int ecc_irq_clr_offset;
	int ecc_irq_clr_mask;
	int ecc_cnt_rst_offset;
	int ecc_cnt_rst_mask;
	struct edac_dev_sysfs_attribute___2 *eccmgr_sysfs_attr;
	int ecc_enable_mask;
	int ce_set_mask;
	int ue_set_mask;
	int ce_ue_trgr_offset;
};

struct edac_device_ctl_info___2;

struct edac_dev_sysfs_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct edac_device_ctl_info___2 *, char *);
	ssize_t (*store)(struct edac_device_ctl_info___2 *, const char *, size_t);
};

struct altr_sdram_mc_data {
	struct regmap *mc_vbase;
	int sb_irq;
	int db_irq;
	const struct altr_sdram_prv_data *data;
};

struct altr_edac_device_dev;

struct edac_device_prv_data {
	int (*setup)(struct altr_edac_device_dev *);
	int ce_clear_mask;
	int ue_clear_mask;
	int irq_status_mask;
	void * (*alloc_mem)(size_t, void **);
	void (*free_mem)(void *, size_t, void *);
	int ecc_enable_mask;
	int ecc_en_ofst;
	int ce_set_mask;
	int ue_set_mask;
	int set_err_ofst;
	irqreturn_t (*ecc_irq_handler)(int, void *);
	int trig_alloc_sz;
	const struct file_operations___233 *inject_fops;
	bool panic;
};

struct altr_arria10_edac;

struct altr_edac_device_dev {
	struct list_head next;
	void *base;
	int sb_irq;
	int db_irq;
	const struct edac_device_prv_data *data;
	struct dentry___232 *debugfs_dir;
	char *edac_dev_name;
	struct altr_arria10_edac *edac;
	struct edac_device_ctl_info___2 *edac_dev;
	struct device___12 ddev;
	int edac_idx;
};

struct altr_arria10_edac {
	struct device___12 *dev;
	struct regmap *ecc_mgr_map;
	int sb_irq;
	int db_irq;
	struct irq_domain___7 *domain;
	struct irq_chip___7 irq_chip;
	struct list_head a10_ecc_devices;
	struct notifier_block panic_notifier;
};

struct edac_device_instance___2;

struct edac_device_ctl_info___2 {
	struct list_head link;
	struct module___216 *owner;
	int dev_idx;
	int log_ue;
	int log_ce;
	int panic_on_ue;
	unsigned int poll_msec;
	long unsigned int delay;
	struct edac_dev_sysfs_attribute___2 *sysfs_attributes;
	struct bus_type___12 *edac_subsys;
	int op_state;
	struct delayed_work work;
	void (*edac_check)(struct edac_device_ctl_info___2 *);
	struct device___12 *dev;
	const char *mod_name;
	const char *ctl_name;
	const char *dev_name;
	void *pvt_info;
	long unsigned int start_time;
	struct completion removal_complete;
	char name[32];
	u32 nr_instances;
	struct edac_device_instance___2 *instances;
	struct edac_device_counter counters;
	struct kobject___220 kobj;
};

struct edac_device_block___2;

struct edac_dev_sysfs_block_attribute___2 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___220 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___220 *, struct attribute *, const char *, size_t);
	struct edac_device_block___2 *block;
	unsigned int value;
};

struct edac_device_block___2 {
	struct edac_device_instance___2 *instance;
	char name[32];
	struct edac_device_counter counters;
	int nr_attribs;
	struct edac_dev_sysfs_block_attribute___2 *block_attributes;
	struct kobject___220 kobj;
};

struct edac_device_instance___2 {
	struct edac_device_ctl_info___2 *ctl;
	char name[35];
	struct edac_device_counter counters;
	u32 nr_blocks;
	struct edac_device_block___2 *blocks;
	struct kobject___220 kobj;
};

enum opp_table_access {
	OPP_TABLE_ACCESS_UNKNOWN = 0,
	OPP_TABLE_ACCESS_EXCLUSIVE = 1,
	OPP_TABLE_ACCESS_SHARED = 2,
};

struct icc_path;

struct dev_pm_opp___2;

struct dev_pm_set_opp_data;

struct dev_pm_opp_supply;

struct opp_table___2 {
	struct list_head node;
	struct list_head lazy;
	struct blocking_notifier_head head;
	struct list_head dev_list;
	struct list_head opp_list;
	struct kref kref;
	struct mutex lock;
	struct device_node___92 *np;
	long unsigned int clock_latency_ns_max;
	unsigned int voltage_tolerance_v1;
	unsigned int parsed_static_opps;
	enum opp_table_access shared_opp;
	long unsigned int current_rate;
	struct dev_pm_opp___2 *current_opp;
	struct dev_pm_opp___2 *suspend_opp;
	struct mutex genpd_virt_dev_lock;
	struct device___208 **genpd_virt_devs;
	struct opp_table___2 **required_opp_tables;
	unsigned int required_opp_count;
	unsigned int *supported_hw;
	unsigned int supported_hw_count;
	const char *prop_name;
	struct clk *clk;
	struct regulator **regulators;
	int regulator_count;
	struct icc_path **paths;
	unsigned int path_count;
	bool enabled;
	bool genpd_performance_state;
	bool is_genpd;
	int (*set_opp)(struct dev_pm_set_opp_data *);
	struct dev_pm_opp_supply *sod_supplies;
	struct dev_pm_set_opp_data *set_opp_data;
	struct dentry___230 *dentry;
	char dentry_name[255];
};

struct dev_pm_opp_icc_bw;

struct dev_pm_opp___2 {
	struct list_head node;
	struct kref kref;
	bool available;
	bool dynamic;
	bool turbo;
	bool suspend;
	bool removed;
	unsigned int pstate;
	long unsigned int rate;
	unsigned int level;
	struct dev_pm_opp_supply *supplies;
	struct dev_pm_opp_icc_bw *bandwidth;
	long unsigned int clock_latency_ns;
	struct dev_pm_opp___2 **required_opps;
	struct opp_table___2 *opp_table;
	struct device_node___92 *np;
	struct dentry___230 *dentry;
	const char *of_name;
};

enum dev_pm_opp_event {
	OPP_EVENT_ADD = 0,
	OPP_EVENT_REMOVE = 1,
	OPP_EVENT_ENABLE = 2,
	OPP_EVENT_DISABLE = 3,
	OPP_EVENT_ADJUST_VOLTAGE = 4,
};

struct dev_pm_opp_supply {
	long unsigned int u_volt;
	long unsigned int u_volt_min;
	long unsigned int u_volt_max;
	long unsigned int u_amp;
};

struct dev_pm_opp_icc_bw {
	u32 avg;
	u32 peak;
};

struct dev_pm_opp_info {
	long unsigned int rate;
	struct dev_pm_opp_supply *supplies;
};

struct dev_pm_set_opp_data {
	struct dev_pm_opp_info old_opp;
	struct dev_pm_opp_info new_opp;
	struct regulator **regulators;
	unsigned int regulator_count;
	struct clk *clk;
	struct device___208 *dev;
};

struct opp_device {
	struct list_head node;
	const struct device___208 *dev;
	struct dentry___230 *dentry;
};

struct dev_pm_set_opp_data___2 {
	struct dev_pm_opp_info old_opp;
	struct dev_pm_opp_info new_opp;
	struct regulator **regulators;
	unsigned int regulator_count;
	struct clk *clk;
	struct device___209 *dev;
};

struct opp_table___3;

struct dev_pm_opp___3 {
	struct list_head node;
	struct kref kref;
	bool available;
	bool dynamic;
	bool turbo;
	bool suspend;
	bool removed;
	unsigned int pstate;
	long unsigned int rate;
	unsigned int level;
	struct dev_pm_opp_supply *supplies;
	struct dev_pm_opp_icc_bw *bandwidth;
	long unsigned int clock_latency_ns;
	struct dev_pm_opp___3 **required_opps;
	struct opp_table___3 *opp_table;
	struct device_node___93 *np;
	struct dentry___182 *dentry;
	const char *of_name;
};

struct opp_table___3 {
	struct list_head node;
	struct list_head lazy;
	struct blocking_notifier_head head;
	struct list_head dev_list;
	struct list_head opp_list;
	struct kref kref;
	struct mutex lock;
	struct device_node___93 *np;
	long unsigned int clock_latency_ns_max;
	unsigned int voltage_tolerance_v1;
	unsigned int parsed_static_opps;
	enum opp_table_access shared_opp;
	long unsigned int current_rate;
	struct dev_pm_opp___3 *current_opp;
	struct dev_pm_opp___3 *suspend_opp;
	struct mutex genpd_virt_dev_lock;
	struct device___209 **genpd_virt_devs;
	struct opp_table___3 **required_opp_tables;
	unsigned int required_opp_count;
	unsigned int *supported_hw;
	unsigned int supported_hw_count;
	const char *prop_name;
	struct clk *clk;
	struct regulator **regulators;
	int regulator_count;
	struct icc_path **paths;
	unsigned int path_count;
	bool enabled;
	bool genpd_performance_state;
	bool is_genpd;
	int (*set_opp)(struct dev_pm_set_opp_data___2 *);
	struct dev_pm_opp_supply *sod_supplies;
	struct dev_pm_set_opp_data___2 *set_opp_data;
	struct dentry___182 *dentry;
	char dentry_name[255];
};

struct opp_device___2 {
	struct list_head node;
	const struct device___209 *dev;
	struct dentry___182 *dentry;
};

struct em_data_callback___2 {
	int (*active_power)(long unsigned int *, long unsigned int *, struct device___159 *);
};

struct dev_pm_opp___4;

struct dev_pm_set_opp_data___3;

struct opp_table___4 {
	struct list_head node;
	struct list_head lazy;
	struct blocking_notifier_head head;
	struct list_head dev_list;
	struct list_head opp_list;
	struct kref kref;
	struct mutex lock;
	struct device_node___63 *np;
	long unsigned int clock_latency_ns_max;
	unsigned int voltage_tolerance_v1;
	unsigned int parsed_static_opps;
	enum opp_table_access shared_opp;
	long unsigned int current_rate;
	struct dev_pm_opp___4 *current_opp;
	struct dev_pm_opp___4 *suspend_opp;
	struct mutex genpd_virt_dev_lock;
	struct device___159 **genpd_virt_devs;
	struct opp_table___4 **required_opp_tables;
	unsigned int required_opp_count;
	unsigned int *supported_hw;
	unsigned int supported_hw_count;
	const char *prop_name;
	struct clk *clk;
	struct regulator **regulators;
	int regulator_count;
	struct icc_path **paths;
	unsigned int path_count;
	bool enabled;
	bool genpd_performance_state;
	bool is_genpd;
	int (*set_opp)(struct dev_pm_set_opp_data___3 *);
	struct dev_pm_opp_supply *sod_supplies;
	struct dev_pm_set_opp_data___3 *set_opp_data;
	struct dentry___182 *dentry;
	char dentry_name[255];
};

struct dev_pm_opp___4 {
	struct list_head node;
	struct kref kref;
	bool available;
	bool dynamic;
	bool turbo;
	bool suspend;
	bool removed;
	unsigned int pstate;
	long unsigned int rate;
	unsigned int level;
	struct dev_pm_opp_supply *supplies;
	struct dev_pm_opp_icc_bw *bandwidth;
	long unsigned int clock_latency_ns;
	struct dev_pm_opp___4 **required_opps;
	struct opp_table___4 *opp_table;
	struct device_node___63 *np;
	struct dentry___182 *dentry;
	const char *of_name;
};

struct dev_pm_set_opp_data___3 {
	struct dev_pm_opp_info old_opp;
	struct dev_pm_opp_info new_opp;
	struct regulator **regulators;
	unsigned int regulator_count;
	struct clk *clk;
	struct device___159 *dev;
};

struct dev_pm_set_opp_data___4 {
	struct dev_pm_opp_info old_opp;
	struct dev_pm_opp_info new_opp;
	struct regulator **regulators;
	unsigned int regulator_count;
	struct clk *clk;
	struct device___211 *dev;
};

struct opp_table___5;

struct dev_pm_opp___5 {
	struct list_head node;
	struct kref kref;
	bool available;
	bool dynamic;
	bool turbo;
	bool suspend;
	bool removed;
	unsigned int pstate;
	long unsigned int rate;
	unsigned int level;
	struct dev_pm_opp_supply *supplies;
	struct dev_pm_opp_icc_bw *bandwidth;
	long unsigned int clock_latency_ns;
	struct dev_pm_opp___5 **required_opps;
	struct opp_table___5 *opp_table;
	struct device_node___2 *np;
	struct dentry___232 *dentry;
	const char *of_name;
};

struct opp_table___5 {
	struct list_head node;
	struct list_head lazy;
	struct blocking_notifier_head head;
	struct list_head dev_list;
	struct list_head opp_list;
	struct kref kref;
	struct mutex lock;
	struct device_node___2 *np;
	long unsigned int clock_latency_ns_max;
	unsigned int voltage_tolerance_v1;
	unsigned int parsed_static_opps;
	enum opp_table_access shared_opp;
	long unsigned int current_rate;
	struct dev_pm_opp___5 *current_opp;
	struct dev_pm_opp___5 *suspend_opp;
	struct mutex genpd_virt_dev_lock;
	struct device___211 **genpd_virt_devs;
	struct opp_table___5 **required_opp_tables;
	unsigned int required_opp_count;
	unsigned int *supported_hw;
	unsigned int supported_hw_count;
	const char *prop_name;
	struct clk *clk;
	struct regulator **regulators;
	int regulator_count;
	struct icc_path **paths;
	unsigned int path_count;
	bool enabled;
	bool genpd_performance_state;
	bool is_genpd;
	int (*set_opp)(struct dev_pm_set_opp_data___4 *);
	struct dev_pm_opp_supply *sod_supplies;
	struct dev_pm_set_opp_data___4 *set_opp_data;
	struct dentry___232 *dentry;
	char dentry_name[255];
};

struct opp_device___3 {
	struct list_head node;
	const struct device___211 *dev;
	struct dentry___232 *dentry;
};

struct kobj_attribute___12 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___24 *, struct kobj_attribute___12 *, char *);
	ssize_t (*store)(struct kobject___24 *, struct kobj_attribute___12 *, const char *, size_t);
};

struct subsys_interface___2 {
	const char *name;
	struct bus_type___22 *subsys;
	struct list_head node;
	int (*add_dev)(struct device___22 *, struct subsys_interface___2 *);
	void (*remove_dev)(struct device___22 *, struct subsys_interface___2 *);
};

struct cpufreq_governor___6;

struct thermal_cooling_device___11;

struct cpufreq_policy___6 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___6 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___24 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___26 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___11 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___6 {
	char name[16];
	int (*init)(struct cpufreq_policy___6 *);
	void (*exit)(struct cpufreq_policy___6 *);
	int (*start)(struct cpufreq_policy___6 *);
	void (*stop)(struct cpufreq_policy___6 *);
	void (*limits)(struct cpufreq_policy___6 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___6 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___6 *, unsigned int);
	struct list_head governor_list;
	struct module___26 *owner;
	u8 flags;
};

struct thermal_cooling_device_ops___11;

struct thermal_cooling_device___11 {
	int id;
	char *type;
	struct device___22 device;
	struct device_node___15 *np;
	void *devdata;
	void *stats;
	const struct thermal_cooling_device_ops___11 *ops;
	bool updated;
	struct mutex lock;
	struct list_head thermal_instances;
	struct list_head node;
};

struct cpufreq_policy_data {
	struct cpufreq_cpuinfo cpuinfo;
	struct cpufreq_frequency_table *freq_table;
	unsigned int cpu;
	unsigned int min;
	unsigned int max;
};

struct cpufreq_freqs {
	struct cpufreq_policy___6 *policy;
	unsigned int old;
	unsigned int new;
	u8 flags;
};

struct freq_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___6 *, char *);
	ssize_t (*store)(struct cpufreq_policy___6 *, const char *, size_t);
};

struct cpufreq_driver {
	char name[16];
	u16 flags;
	void *driver_data;
	int (*init)(struct cpufreq_policy___6 *);
	int (*verify)(struct cpufreq_policy_data *);
	int (*setpolicy)(struct cpufreq_policy___6 *);
	int (*target)(struct cpufreq_policy___6 *, unsigned int, unsigned int);
	int (*target_index)(struct cpufreq_policy___6 *, unsigned int);
	unsigned int (*fast_switch)(struct cpufreq_policy___6 *, unsigned int);
	void (*adjust_perf)(unsigned int, long unsigned int, long unsigned int, long unsigned int);
	unsigned int (*get_intermediate)(struct cpufreq_policy___6 *, unsigned int);
	int (*target_intermediate)(struct cpufreq_policy___6 *, unsigned int);
	unsigned int (*get)(unsigned int);
	void (*update_limits)(unsigned int);
	int (*bios_limit)(int, unsigned int *);
	int (*online)(struct cpufreq_policy___6 *);
	int (*offline)(struct cpufreq_policy___6 *);
	int (*exit)(struct cpufreq_policy___6 *);
	int (*suspend)(struct cpufreq_policy___6 *);
	int (*resume)(struct cpufreq_policy___6 *);
	struct freq_attr **attr;
	bool boost_enabled;
	int (*set_boost)(struct cpufreq_policy___6 *, int);
	void (*register_em)(struct cpufreq_policy___6 *);
};

struct thermal_cooling_device_ops___11 {
	int (*get_max_state)(struct thermal_cooling_device___11 *, long unsigned int *);
	int (*get_cur_state)(struct thermal_cooling_device___11 *, long unsigned int *);
	int (*set_cur_state)(struct thermal_cooling_device___11 *, long unsigned int);
	int (*get_requested_power)(struct thermal_cooling_device___11 *, u32 *);
	int (*state2power)(struct thermal_cooling_device___11 *, long unsigned int, u32 *);
	int (*power2state)(struct thermal_cooling_device___11 *, u32, long unsigned int *);
};

struct cpufreq_governor___7;

struct cpufreq_policy___7 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___7 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___100 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___111 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___3 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___7 {
	char name[16];
	int (*init)(struct cpufreq_policy___7 *);
	void (*exit)(struct cpufreq_policy___7 *);
	int (*start)(struct cpufreq_policy___7 *);
	void (*stop)(struct cpufreq_policy___7 *);
	void (*limits)(struct cpufreq_policy___7 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___7 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___7 *, unsigned int);
	struct list_head governor_list;
	struct module___98 *owner;
	u8 flags;
};

struct freq_attr___2 {
	struct attribute attr;
	ssize_t (*show)(struct cpufreq_policy___7 *, char *);
	ssize_t (*store)(struct cpufreq_policy___7 *, const char *, size_t);
};

struct cpufreq_stats {
	unsigned int total_trans;
	long long unsigned int last_time;
	unsigned int max_state;
	unsigned int state_num;
	unsigned int last_index;
	u64 *time_in_state;
	unsigned int *freq_table;
	unsigned int *trans_table;
	unsigned int reset_pending;
	long long unsigned int reset_time;
};

struct cpufreq_governor___8;

struct cpufreq_policy___8 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___8 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___6 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___8 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___3 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___8 {
	char name[16];
	int (*init)(struct cpufreq_policy___8 *);
	void (*exit)(struct cpufreq_policy___8 *);
	int (*start)(struct cpufreq_policy___8 *);
	void (*stop)(struct cpufreq_policy___8 *);
	void (*limits)(struct cpufreq_policy___8 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___8 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___8 *, unsigned int);
	struct list_head governor_list;
	struct module___8 *owner;
	u8 flags;
};

struct gov_attr_set___2 {
	struct kobject___6 kobj;
	struct list_head policy_list;
	struct mutex update_lock;
	int usage_count;
};

struct governor_attr___2 {
	struct attribute attr;
	ssize_t (*show)(struct gov_attr_set___2 *, char *);
	ssize_t (*store)(struct gov_attr_set___2 *, const char *, size_t);
};

enum {
	OD_NORMAL_SAMPLE = 0,
	OD_SUB_SAMPLE = 1,
};

struct dbs_data {
	struct gov_attr_set___2 attr_set;
	void *tuners;
	unsigned int ignore_nice_load;
	unsigned int sampling_rate;
	unsigned int sampling_down_factor;
	unsigned int up_threshold;
	unsigned int io_is_busy;
};

struct policy_dbs_info {
	struct cpufreq_policy___8 *policy;
	struct mutex update_mutex;
	u64 last_sample_time;
	s64 sample_delay_ns;
	atomic_t work_count;
	struct irq_work irq_work;
	struct work_struct work;
	struct dbs_data *dbs_data;
	struct list_head list;
	unsigned int rate_mult;
	unsigned int idle_periods;
	bool is_shared;
	bool work_in_progress;
};

struct dbs_governor {
	struct cpufreq_governor___8 gov;
	struct kobj_type___6 kobj_type;
	struct dbs_data *gdbs_data;
	unsigned int (*gov_dbs_update)(struct cpufreq_policy___8 *);
	struct policy_dbs_info * (*alloc)();
	void (*free)(struct policy_dbs_info *);
	int (*init)(struct dbs_data *);
	void (*exit)(struct dbs_data *);
	void (*start)(struct cpufreq_policy___8 *);
};

struct od_ops {
	unsigned int (*powersave_bias_target)(struct cpufreq_policy___8 *, unsigned int, unsigned int);
};

struct od_policy_dbs_info {
	struct policy_dbs_info policy_dbs;
	unsigned int freq_lo;
	unsigned int freq_lo_delay_us;
	unsigned int freq_hi_delay_us;
	unsigned int sample_type;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct od_dbs_tuners {
	unsigned int powersave_bias;
};

struct cs_policy_dbs_info {
	struct policy_dbs_info policy_dbs;
	unsigned int down_skip;
	unsigned int requested_freq;
};

struct cs_dbs_tuners {
	unsigned int down_threshold;
	unsigned int freq_step;
};

struct cpu_dbs_info {
	u64 prev_cpu_idle;
	u64 prev_update_time;
	u64 prev_cpu_nice;
	unsigned int prev_load;
	struct update_util_data update_util;
	struct policy_dbs_info *policy_dbs;
};

struct cpufreq_dt_platform_data {
	bool have_governor_per_policy;
	unsigned int (*get_intermediate)(struct cpufreq_policy___6 *, unsigned int);
	int (*target_intermediate)(struct cpufreq_policy___6 *, unsigned int);
	int (*suspend)(struct cpufreq_policy___6 *);
	int (*resume)(struct cpufreq_policy___6 *);
};

struct private_data {
	struct list_head node;
	cpumask_var_t cpus;
	struct device___22 *cpu_dev;
	struct opp_table *opp_table;
	struct cpufreq_frequency_table *freq_table;
	bool have_static_opps;
};

struct tegra124_cpufreq_priv {
	struct clk *cpu_clk;
	struct clk *pllp_clk;
	struct clk *pllx_clk;
	struct clk *dfll_clk;
	struct platform_device___37 *cpufreq_dt_pdev;
};

struct cpuidle_driver___5;

struct cpuidle_state___5 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___5 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___5 *, int);
};

struct cpuidle_driver___5 {
	const char *name;
	struct module___41 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___5 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct cpuidle_governor {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver___5 *, struct cpuidle_device___2 *);
	void (*disable)(struct cpuidle_driver___5 *, struct cpuidle_device___2 *);
	int (*select)(struct cpuidle_driver___5 *, struct cpuidle_device___2 *, bool *);
	void (*reflect)(struct cpuidle_device___2 *, int);
};

struct cpuidle_driver___6;

struct cpuidle_state___6 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___6 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___6 *, int);
};

struct cpuidle_driver___6 {
	const char *name;
	struct module___8 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___6 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct cpuidle_governor___2 {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver___6 *, struct cpuidle_device___2 *);
	void (*disable)(struct cpuidle_driver___6 *, struct cpuidle_device___2 *);
	int (*select)(struct cpuidle_driver___6 *, struct cpuidle_device___2 *, bool *);
	void (*reflect)(struct cpuidle_device___2 *, int);
};

struct cpuidle_state_kobj {
	struct cpuidle_state___6 *state;
	struct cpuidle_state_usage *state_usage;
	struct completion kobj_unregister;
	struct kobject___42 kobj;
	struct cpuidle_device___2 *device;
};

struct cpuidle_driver_kobj {
	struct cpuidle_driver___6 *drv;
	struct completion kobj_unregister;
	struct kobject___42 kobj;
};

struct cpuidle_device_kobj {
	struct cpuidle_device___2 *dev;
	struct completion kobj_unregister;
	struct kobject___42 kobj;
};

struct cpuidle_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_device___2 *, char *);
	ssize_t (*store)(struct cpuidle_device___2 *, const char *, size_t);
};

struct cpuidle_state_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_state___6 *, struct cpuidle_state_usage *, char *);
	ssize_t (*store)(struct cpuidle_state___6 *, struct cpuidle_state_usage *, const char *, size_t);
};

struct cpuidle_driver_attr {
	struct attribute attr;
	ssize_t (*show)(struct cpuidle_driver___6 *, char *);
	ssize_t (*store)(struct cpuidle_driver___6 *, const char *, size_t);
};

struct cpuidle_governor___3 {
	char name[16];
	struct list_head governor_list;
	unsigned int rating;
	int (*enable)(struct cpuidle_driver *, struct cpuidle_device *);
	void (*disable)(struct cpuidle_driver *, struct cpuidle_device *);
	int (*select)(struct cpuidle_driver *, struct cpuidle_device *, bool *);
	void (*reflect)(struct cpuidle_device *, int);
};

struct ladder_device_state {
	struct {
		u32 promotion_count;
		u32 demotion_count;
		u64 promotion_time_ns;
		u64 demotion_time_ns;
	} threshold;
	struct {
		int promotion_count;
		int demotion_count;
	} stats;
};

struct ladder_device {
	struct ladder_device_state states[10];
};

struct menu_device {
	int needs_update;
	int tick_wakeup;
	u64 next_timer_ns;
	unsigned int bucket;
	unsigned int correction_factor[12];
	unsigned int intervals[8];
	int interval_ptr;
};

struct teo_bin {
	unsigned int intercepts;
	unsigned int hits;
	unsigned int recent;
};

struct teo_cpu {
	s64 time_span_ns;
	s64 sleep_length_ns;
	struct teo_bin state_bins[10];
	unsigned int total;
	int next_recent_idx;
	int recent_idx[9];
};

struct cpuidle_driver___7;

struct cpuidle_state___7 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___7 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___7 *, int);
};

struct cpuidle_driver___7 {
	const char *name;
	struct module___90 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___7 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct cpuidle_driver___8;

struct cpuidle_state___8 {
	char name[16];
	char desc[32];
	s64 exit_latency_ns;
	s64 target_residency_ns;
	unsigned int flags;
	unsigned int exit_latency;
	int power_usage;
	unsigned int target_residency;
	int (*enter)(struct cpuidle_device___2 *, struct cpuidle_driver___8 *, int);
	int (*enter_dead)(struct cpuidle_device___2 *, int);
	int (*enter_s2idle)(struct cpuidle_device___2 *, struct cpuidle_driver___8 *, int);
};

struct cpuidle_driver___8 {
	const char *name;
	struct module___217 *owner;
	unsigned int bctimer: 1;
	long: 63;
	long: 64;
	long: 64;
	struct cpuidle_state___8 states[10];
	int state_count;
	int safe_state_index;
	struct cpumask *cpumask;
	const char *governor;
};

struct platform_device_info___8 {
	struct device___208 *parent;
	struct fwnode_handle___204 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct psci_cpuidle_data {
	u32 *psci_states;
	struct device___208 *dev;
};

struct psci_pd_provider {
	struct list_head link;
	struct device_node___63 *node;
};

struct dentry___234;

struct super_block___234;

struct module___218;

struct file_system_type___234 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___234 * (*mount)(struct file_system_type___234 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___234 *);
	struct module___218 *owner;
	struct file_system_type___234 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___234;

struct kiocb___234;

struct iov_iter___154;

struct poll_table_struct___159;

struct vm_area_struct___239;

struct inode___234;

struct file_lock___234;

struct page___239;

struct seq_file___209;

struct file_operations___235 {
	struct module___218 *owner;
	loff_t (*llseek)(struct file___234 *, loff_t, int);
	ssize_t (*read)(struct file___234 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___234 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___234 *, struct iov_iter___154 *);
	ssize_t (*write_iter)(struct kiocb___234 *, struct iov_iter___154 *);
	int (*iopoll)(struct kiocb___234 *, bool);
	int (*iterate)(struct file___234 *, struct dir_context *);
	int (*iterate_shared)(struct file___234 *, struct dir_context *);
	__poll_t (*poll)(struct file___234 *, struct poll_table_struct___159 *);
	long int (*unlocked_ioctl)(struct file___234 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___234 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___234 *, struct vm_area_struct___239 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___234 *, struct file___234 *);
	int (*flush)(struct file___234 *, fl_owner_t);
	int (*release)(struct inode___234 *, struct file___234 *);
	int (*fsync)(struct file___234 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___234 *, int);
	int (*lock)(struct file___234 *, int, struct file_lock___234 *);
	ssize_t (*sendpage)(struct file___234 *, struct page___239 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___234 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___234 *, long unsigned int);
	int (*flock)(struct file___234 *, int, struct file_lock___234 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___234 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___234 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___234 *, long int, struct file_lock___234 **, void **);
	long int (*fallocate)(struct file___234 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___209 *, struct file___234 *);
	ssize_t (*copy_file_range)(struct file___234 *, loff_t, struct file___234 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___234 *, loff_t, struct file___234 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___234 *, loff_t, loff_t, int);
};

struct vmacache___239 {
	u64 seqnum;
	struct vm_area_struct___239 *vmas[4];
};

struct page_frag___239 {
	struct page___239 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___83;

struct debug_info___83 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___83 *hbp_break[16];
	struct perf_event___83 *hbp_watch[16];
};

struct thread_struct___83 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___83 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___240;

struct pid___211;

struct nsproxy___220;

struct signal_struct___235;

struct bio_list___127;

struct backing_dev_info___116;

struct io_context___127;

struct css_set___164;

struct perf_event_context___83;

struct mem_cgroup___104;

struct request_queue___127;

struct vm_struct___217;

struct task_struct___241 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___241 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___240 *mm;
	struct mm_struct___240 *active_mm;
	struct vmacache___239 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___241 *real_parent;
	struct task_struct___241 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___241 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___211 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___220 *nsproxy;
	struct signal_struct___235 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___241 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___127 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___116 *backing_dev_info;
	struct io_context___127 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___164 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___83 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___239 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___104 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___104 *active_memcg;
	struct request_queue___127 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___241 *oom_reaper_list;
	struct vm_struct___217 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___222;

struct kobj_type___222;

struct kernfs_node___222;

struct kobject___222 {
	const char *name;
	struct list_head entry;
	struct kobject___222 *parent;
	struct kset___222 *kset;
	struct kobj_type___222 *ktype;
	struct kernfs_node___222 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___219 {
	struct kobject___222 kobj;
	struct module___218 *mod;
	struct kobject___222 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___218 {
	struct module___218 *mod;
	struct latch_tree_node node;
};

struct module_layout___218 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___218 mtn;
};

struct module_attribute___218;

struct kernel_param___218;

struct trace_event_call___77;

struct module___218 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___219 mkobj;
	struct module_attribute___218 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___222 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___218 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___218 core_layout;
	struct module_layout___218 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___77 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___83 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___241 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___83)(struct perf_event___83 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___83;

struct fasync_struct___234;

struct pid_namespace___211;

struct perf_cgroup___83;

struct perf_event___83 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___83 *group_leader;
	struct pmu___83 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___83 hw;
	struct perf_event_context___83 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___83 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___241 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___234 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___83 *aux_event;
	void (*destroy)(struct perf_event___83 *);
	struct callback_head callback_head;
	struct pid_namespace___211 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___83 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___83 orig_overflow_handler;
	struct bpf_prog *prog;
	u64 bpf_cookie;
	struct trace_event_call___77 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___83 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___211 {
	int nr;
	struct pid_namespace___211 *ns;
};

struct pid_namespace___211 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___241 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___211 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___211 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___211 numbers[1];
};

typedef struct page___239 *pgtable_t___239;

struct address_space___234;

struct dev_pagemap___229;

struct page___239 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___234 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___239 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___239 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___240 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___229 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___229;

struct vm_area_struct___239 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___239 *vm_next;
	struct vm_area_struct___239 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___240 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___229 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___234 *vm_file;
	struct file___234 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___235 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___241 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___241 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___211 *pids[4];
	struct pid___211 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___240 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___239;

struct mm_struct___240 {
	struct {
		struct vm_area_struct___239 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___234 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___239 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___241 *owner;
		struct user_namespace___14 *user_ns;
		struct file___234 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cgroup_namespace___164;

struct nsproxy___220 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___211 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___164 *cgroup_ns;
};

struct bio___127;

struct bio_list___127 {
	struct bio___127 *head;
	struct bio___127 *tail;
};

struct cgroup_subsys_state___164;

struct bdi_writeback___116 {
	struct backing_dev_info___116 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___164 *memcg_css;
	struct cgroup_subsys_state___164 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___213;

struct backing_dev_info___116 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___116 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___213 *dev;
	char dev_name[64];
	struct device___213 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___234 *debug_dir;
};

struct io_cq___127;

struct io_context___127 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___127 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___164;

struct css_set___164 {
	struct cgroup_subsys_state___164 *subsys[14];
	refcount_t refcount;
	struct css_set___164 *dom_cset;
	struct cgroup___164 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___164 *mg_src_cgrp;
	struct cgroup___164 *mg_dst_cgrp;
	struct css_set___164 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___83 {
	struct pmu___83 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___241 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___83 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___164;

struct cgroup_subsys_state___164 {
	struct cgroup___164 *cgroup;
	struct cgroup_subsys___164 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___164 *parent;
};

struct cgroup_file___164 {
	struct kernfs_node___222 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___104;

struct mem_cgroup_per_node___104;

struct mem_cgroup___104 {
	struct cgroup_subsys_state___164 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___164 events_file;
	struct cgroup_file___164 events_local_file;
	struct cgroup_file___164 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___104 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___241 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___104 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___127;

struct blk_integrity___127 {
	const struct blk_integrity_profile___127 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___127 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___127 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___127;

struct elevator_queue___127;

struct blk_mq_ops___124;

struct blk_mq_hw_ctx___124;

struct gendisk___130;

struct blk_keyslot_manager___5;

struct blkcg_gq___118;

struct blk_mq_tag_set___124;

struct request_queue___127 {
	struct request___127 *last_merge;
	struct elevator_queue___127 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___124 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___124 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___130 *disk;
	struct kobject___222 kobj;
	struct kobject___222 *mq_kobj;
	struct blk_integrity___127 integrity;
	struct device___213 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___5 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___118 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___124 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___127 bio_split;
	struct dentry___234 *debugfs_dir;
	struct dentry___234 *sched_debugfs_dir;
	struct dentry___234 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___217 {
	struct vm_struct___217 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___239 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___234;

struct address_space___234 {
	struct inode___234 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___234 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___229;

struct dev_pagemap___229 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___229 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___234;

struct path___234 {
	struct vfsmount___234 *mnt;
	struct dentry___234 *dentry;
};

struct fown_struct___211 {
	rwlock_t lock;
	struct pid___211 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___234 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___234 f_path;
	struct inode___234 *f_inode;
	const struct file_operations___235 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___211 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___234 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___229;

struct vm_operations_struct___229 {
	void (*open)(struct vm_area_struct___239 *);
	void (*close)(struct vm_area_struct___239 *);
	int (*may_split)(struct vm_area_struct___239 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___239 *);
	int (*mprotect)(struct vm_area_struct___239 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___229 *);
	vm_fault_t (*huge_fault)(struct vm_fault___229 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___229 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___239 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___229 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___229 *);
	int (*access)(struct vm_area_struct___239 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___239 *);
	int (*set_policy)(struct vm_area_struct___239 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___239 *, long unsigned int);
	struct page___239 * (*find_special_page)(struct vm_area_struct___239 *, long unsigned int);
};

struct core_thread___239 {
	struct task_struct___241 *task;
	struct core_thread___239 *next;
};

struct core_state___239 {
	atomic_t nr_threads;
	struct core_thread___239 dumper;
	struct completion startup;
};

struct vm_fault___229 {
	const struct {
		struct vm_area_struct___239 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___239 *cow_page;
	struct page___239 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___239 prealloc_pte;
};

struct pglist_data___112;

struct lruvec___112 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___112 *pgdat;
};

struct zone___112 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___112 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___112 {
	struct zone___112 *zone;
	int zone_idx;
};

struct zonelist___112 {
	struct zoneref___112 _zonerefs[321];
};

struct pglist_data___112 {
	struct zone___112 node_zones[5];
	struct zonelist___112 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___241 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___241 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___112 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___234;

struct dentry___234 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___234 *d_parent;
	struct qstr d_name;
	struct inode___234 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___234 *d_op;
	struct super_block___234 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___234;

struct inode___234 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___234 *i_op;
	struct super_block___234 *i_sb;
	struct address_space___234 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___116 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___235 *i_fop;
		void (*free_inode)(struct inode___234 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___234 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___234 {
	int (*d_revalidate)(struct dentry___234 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___234 *, unsigned int);
	int (*d_hash)(const struct dentry___234 *, struct qstr *);
	int (*d_compare)(const struct dentry___234 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___234 *);
	int (*d_init)(struct dentry___234 *);
	void (*d_release)(struct dentry___234 *);
	void (*d_prune)(struct dentry___234 *);
	void (*d_iput)(struct dentry___234 *, struct inode___234 *);
	char * (*d_dname)(struct dentry___234 *, char *, int);
	struct vfsmount___234 * (*d_automount)(struct path___234 *);
	int (*d_manage)(const struct path___234 *, bool);
	struct dentry___234 * (*d_real)(struct dentry___234 *, const struct inode___234 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___234;

struct mem_dqinfo___234 {
	struct quota_format_type___234 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___234;

struct quota_info___234 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___234 *files[3];
	struct mem_dqinfo___234 info[3];
	const struct quota_format_ops___234 *ops[3];
};

struct rcuwait___235 {
	struct task_struct___241 *task;
};

struct percpu_rw_semaphore___235 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___235 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___234 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___235 rw_sem[3];
};

struct shrink_control___104;

struct shrinker___104 {
	long unsigned int (*count_objects)(struct shrinker___104 *, struct shrink_control___104 *);
	long unsigned int (*scan_objects)(struct shrinker___104 *, struct shrink_control___104 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___234;

struct dquot_operations___234;

struct quotactl_ops___234;

struct block_device___130;

struct super_block___234 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___234 *s_type;
	const struct super_operations___234 *s_op;
	const struct dquot_operations___234 *dq_op;
	const struct quotactl_ops___234 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___234 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___130 *s_bdev;
	struct backing_dev_info___116 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___234 s_dquot;
	struct sb_writers___234 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___234 *s_d_op;
	int cleancache_poolid;
	struct shrinker___104 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___234 {
	struct dentry___234 *mnt_root;
	struct super_block___234 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___104 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___104 *memcg;
};

struct psi_group___164 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___241 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___164;

struct cgroup_rstat_cpu___164;

struct cgroup___164 {
	struct cgroup_subsys_state___164 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___222 *kn;
	struct cgroup_file___164 procs_file;
	struct cgroup_file___164 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___164 *subsys[14];
	struct cgroup_root___164 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___164 *dom_cgrp;
	struct cgroup___164 *old_dom_cgrp;
	struct cgroup_rstat_cpu___164 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___164 psi;
	struct cgroup_bpf___42 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___127 {
	struct request_queue___127 *q;
	struct io_context___127 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___112;

struct kiocb___234 {
	struct file___234 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___234 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___112 *ki_waitq;
	};
};

struct iattr___234 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___234 *ia_file;
};

struct dquot___234 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___234 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___234 {
	int qf_fmt_id;
	const struct quota_format_ops___234 *qf_ops;
	struct module___218 *qf_owner;
	struct quota_format_type___234 *qf_next;
};

struct quota_format_ops___234 {
	int (*check_quota_file)(struct super_block___234 *, int);
	int (*read_file_info)(struct super_block___234 *, int);
	int (*write_file_info)(struct super_block___234 *, int);
	int (*free_file_info)(struct super_block___234 *, int);
	int (*read_dqblk)(struct dquot___234 *);
	int (*commit_dqblk)(struct dquot___234 *);
	int (*release_dqblk)(struct dquot___234 *);
	int (*get_next_id)(struct super_block___234 *, struct kqid *);
};

struct dquot_operations___234 {
	int (*write_dquot)(struct dquot___234 *);
	struct dquot___234 * (*alloc_dquot)(struct super_block___234 *, int);
	void (*destroy_dquot)(struct dquot___234 *);
	int (*acquire_dquot)(struct dquot___234 *);
	int (*release_dquot)(struct dquot___234 *);
	int (*mark_dirty)(struct dquot___234 *);
	int (*write_info)(struct super_block___234 *, int);
	qsize_t * (*get_reserved_space)(struct inode___234 *);
	int (*get_projid)(struct inode___234 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___234 *, qsize_t *);
	int (*get_next_id)(struct super_block___234 *, struct kqid *);
};

struct quotactl_ops___234 {
	int (*quota_on)(struct super_block___234 *, int, int, const struct path___234 *);
	int (*quota_off)(struct super_block___234 *, int);
	int (*quota_enable)(struct super_block___234 *, unsigned int);
	int (*quota_disable)(struct super_block___234 *, unsigned int);
	int (*quota_sync)(struct super_block___234 *, int);
	int (*set_info)(struct super_block___234 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___234 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___234 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___234 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___234 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___234 *, unsigned int);
};

struct wait_page_queue___112 {
	struct page___239 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___116;

struct readahead_control___112;

struct swap_info_struct___67;

struct address_space_operations___234 {
	int (*writepage)(struct page___239 *, struct writeback_control___116 *);
	int (*readpage)(struct file___234 *, struct page___239 *);
	int (*writepages)(struct address_space___234 *, struct writeback_control___116 *);
	int (*set_page_dirty)(struct page___239 *);
	int (*readpages)(struct file___234 *, struct address_space___234 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___112 *);
	int (*write_begin)(struct file___234 *, struct address_space___234 *, loff_t, unsigned int, unsigned int, struct page___239 **, void **);
	int (*write_end)(struct file___234 *, struct address_space___234 *, loff_t, unsigned int, unsigned int, struct page___239 *, void *);
	sector_t (*bmap)(struct address_space___234 *, sector_t);
	void (*invalidatepage)(struct page___239 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___239 *, gfp_t);
	void (*freepage)(struct page___239 *);
	ssize_t (*direct_IO)(struct kiocb___234 *, struct iov_iter___154 *);
	int (*migratepage)(struct address_space___234 *, struct page___239 *, struct page___239 *, enum migrate_mode);
	bool (*isolate_page)(struct page___239 *, isolate_mode_t);
	void (*putback_page)(struct page___239 *);
	int (*launder_page)(struct page___239 *);
	int (*is_partially_uptodate)(struct page___239 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___239 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___234 *, struct page___239 *);
	int (*swap_activate)(struct swap_info_struct___67 *, struct file___234 *, sector_t *);
	void (*swap_deactivate)(struct file___234 *);
};

struct writeback_control___116 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___116 *wb;
	struct inode___234 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___112 {
	struct file___234 *file;
	struct address_space___234 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___151;

struct iov_iter___154 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___151 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___67 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___130 *bdev;
	struct file___234 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___234 {
	struct dentry___234 * (*lookup)(struct inode___234 *, struct dentry___234 *, unsigned int);
	const char * (*get_link)(struct dentry___234 *, struct inode___234 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___234 *, int);
	struct posix_acl * (*get_acl)(struct inode___234 *, int, bool);
	int (*readlink)(struct dentry___234 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___234 *, struct dentry___234 *, umode_t, bool);
	int (*link)(struct dentry___234 *, struct inode___234 *, struct dentry___234 *);
	int (*unlink)(struct inode___234 *, struct dentry___234 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___234 *, struct dentry___234 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___234 *, struct dentry___234 *, umode_t);
	int (*rmdir)(struct inode___234 *, struct dentry___234 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___234 *, struct dentry___234 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___234 *, struct dentry___234 *, struct inode___234 *, struct dentry___234 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___234 *, struct iattr___234 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___234 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___234 *, char *, size_t);
	int (*fiemap)(struct inode___234 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___234 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___234 *, struct dentry___234 *, struct file___234 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___234 *, struct dentry___234 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___234 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___234 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___234 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___234 {
	void (*fl_copy_lock)(struct file_lock___234 *, struct file_lock___234 *);
	void (*fl_release_private)(struct file_lock___234 *);
};

struct lock_manager_operations___234;

struct file_lock___234 {
	struct file_lock___234 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___234 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___234 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___234 *fl_ops;
	const struct lock_manager_operations___234 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___234 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___234 *);
	int (*lm_grant)(struct file_lock___234 *, int);
	bool (*lm_break)(struct file_lock___234 *);
	int (*lm_change)(struct file_lock___234 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___234 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___234 *);
};

struct fasync_struct___234 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___234 *fa_next;
	struct file___234 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___234 {
	struct inode___234 * (*alloc_inode)(struct super_block___234 *);
	void (*destroy_inode)(struct inode___234 *);
	void (*free_inode)(struct inode___234 *);
	void (*dirty_inode)(struct inode___234 *, int);
	int (*write_inode)(struct inode___234 *, struct writeback_control___116 *);
	int (*drop_inode)(struct inode___234 *);
	void (*evict_inode)(struct inode___234 *);
	void (*put_super)(struct super_block___234 *);
	int (*sync_fs)(struct super_block___234 *, int);
	int (*freeze_super)(struct super_block___234 *);
	int (*freeze_fs)(struct super_block___234 *);
	int (*thaw_super)(struct super_block___234 *);
	int (*unfreeze_fs)(struct super_block___234 *);
	int (*statfs)(struct dentry___234 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___234 *, int *, char *);
	void (*umount_begin)(struct super_block___234 *);
	int (*show_options)(struct seq_file___209 *, struct dentry___234 *);
	int (*show_devname)(struct seq_file___209 *, struct dentry___234 *);
	int (*show_path)(struct seq_file___209 *, struct dentry___234 *);
	int (*show_stats)(struct seq_file___209 *, struct dentry___234 *);
	ssize_t (*quota_read)(struct super_block___234 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___234 *, int, const char *, size_t, loff_t);
	struct dquot___234 ** (*get_dquots)(struct inode___234 *);
	long int (*nr_cached_objects)(struct super_block___234 *, struct shrink_control___104 *);
	long int (*free_cached_objects)(struct super_block___234 *, struct shrink_control___104 *);
	struct file___234 * (*real_loop)(struct file___234 *);
};

struct wakeup_source___213;

struct dev_pm_info___213 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___213 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___213 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___213;

struct bus_type___213;

struct device_driver___213;

struct dev_pm_domain___213;

struct device_node___94;

struct fwnode_handle___209;

struct class___213;

struct attribute_group___222;

struct device___213 {
	struct kobject___222 kobj;
	struct device___213 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___213 *type;
	struct bus_type___213 *bus;
	struct device_driver___213 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___213 power;
	struct dev_pm_domain___213 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___94 *of_node;
	struct fwnode_handle___209 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___213 *class;
	const struct attribute_group___222 **groups;
	void (*release)(struct device___213 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___130 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___234 *bd_inode;
	struct super_block___234 *bd_super;
	void *bd_claiming;
	struct device___213 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___222 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___130 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___234 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___166)(struct file___234 *, wait_queue_head_t *, struct poll_table_struct___159 *);

struct poll_table_struct___159 {
	poll_queue_proc___166 _qproc;
	__poll_t _key;
};

struct seq_operations___209;

struct seq_file___209 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___209 *op;
	int poll_event;
	const struct file___234 *file;
	void *private;
};

typedef void bio_end_io_t___127(struct bio___127 *);

struct bio_vec___151 {
	struct page___239 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___127;

struct bio___127 {
	struct bio___127 *bi_next;
	struct block_device___130 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___127 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___118 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___127 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___151 *bi_io_vec;
	struct bio_set___127 *bi_pool;
	struct bio_vec___151 bi_inline_vecs[0];
};

struct kernfs_root___222;

struct kernfs_elem_dir___222 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___222 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___222;

struct kernfs_root___222 {
	struct kernfs_node___222 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___222 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___222 {
	struct kernfs_node___222 *target_kn;
};

struct kernfs_ops___222;

struct kernfs_elem_attr___222 {
	const struct kernfs_ops___222 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___222 *notify_next;
};

struct kernfs_node___222 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___222 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___222 dir;
		struct kernfs_elem_symlink___222 symlink;
		struct kernfs_elem_attr___222 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___222;

struct kernfs_ops___222 {
	int (*open)(struct kernfs_open_file___222 *);
	void (*release)(struct kernfs_open_file___222 *);
	int (*seq_show)(struct seq_file___209 *, void *);
	void * (*seq_start)(struct seq_file___209 *, loff_t *);
	void * (*seq_next)(struct seq_file___209 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___209 *, void *);
	ssize_t (*read)(struct kernfs_open_file___222 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___222 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___222 *, struct poll_table_struct___159 *);
	int (*mmap)(struct kernfs_open_file___222 *, struct vm_area_struct___239 *);
};

struct kernfs_syscall_ops___222 {
	int (*show_options)(struct seq_file___209 *, struct kernfs_root___222 *);
	int (*mkdir)(struct kernfs_node___222 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___222 *);
	int (*rename)(struct kernfs_node___222 *, struct kernfs_node___222 *, const char *);
	int (*show_path)(struct seq_file___209 *, struct kernfs_node___222 *, struct kernfs_root___222 *);
};

struct kernfs_open_file___222 {
	struct kernfs_node___222 *kn;
	struct file___234 *file;
	struct seq_file___209 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___229 *vm_ops;
};

struct bin_attribute___222;

struct attribute_group___222 {
	const char *name;
	umode_t (*is_visible)(struct kobject___222 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___222 *, struct bin_attribute___222 *, int);
	struct attribute **attrs;
	struct bin_attribute___222 **bin_attrs;
};

struct bin_attribute___222 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___234 * (*f_mapping)();
	ssize_t (*read)(struct file___234 *, struct kobject___222 *, struct bin_attribute___222 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___234 *, struct kobject___222 *, struct bin_attribute___222 *, char *, loff_t, size_t);
	int (*mmap)(struct file___234 *, struct kobject___222 *, struct bin_attribute___222 *, struct vm_area_struct___239 *);
};

struct sysfs_ops___222 {
	ssize_t (*show)(struct kobject___222 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___222 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___222;

struct kset___222 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___222 kobj;
	const struct kset_uevent_ops___222 *uevent_ops;
};

struct kobj_type___222 {
	void (*release)(struct kobject___222 *);
	const struct sysfs_ops___222 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___222 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___222 *);
	const void * (*namespace)(struct kobject___222 *);
	void (*get_ownership)(struct kobject___222 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___222 {
	int (* const filter)(struct kset___222 *, struct kobject___222 *);
	const char * (* const name)(struct kset___222 *, struct kobject___222 *);
	int (* const uevent)(struct kset___222 *, struct kobject___222 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___218 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___218 *);
	int (*get)(char *, const struct kernel_param___218 *);
	void (*free)(void *);
};

struct kparam_array___218;

struct kernel_param___218 {
	const char *name;
	struct module___218 *mod;
	const struct kernel_param_ops___218 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___218 *arr;
	};
};

struct kparam_array___218 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___218 *ops;
	void *elem;
};

struct module_attribute___218 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___218 *, struct module_kobject___219 *, char *);
	ssize_t (*store)(struct module_attribute___218 *, struct module_kobject___219 *, const char *, size_t);
	void (*setup)(struct module___218 *, const char *);
	int (*test)(struct module___218 *);
	void (*free)(struct module___218 *);
};

struct trace_event_class___77;

struct trace_event_call___77 {
	struct list_head list;
	struct trace_event_class___77 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___42 *prog_array;
	int (*perf_perm)(struct trace_event_call___77 *, struct perf_event___83 *);
};

struct fwnode_operations___209;

struct fwnode_handle___209 {
	struct fwnode_handle___209 *secondary;
	const struct fwnode_operations___209 *ops;
	struct device___213 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___209;

struct fwnode_endpoint___209;

struct fwnode_operations___209 {
	struct fwnode_handle___209 * (*get)(struct fwnode_handle___209 *);
	void (*put)(struct fwnode_handle___209 *);
	bool (*device_is_available)(const struct fwnode_handle___209 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___209 *, const struct device___213 *);
	bool (*property_present)(const struct fwnode_handle___209 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___209 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___209 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___209 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*get_parent)(const struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*get_next_child_node)(const struct fwnode_handle___209 *, struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*get_named_child_node)(const struct fwnode_handle___209 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___209 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___209 *);
	struct fwnode_handle___209 * (*graph_get_next_endpoint)(const struct fwnode_handle___209 *, struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*graph_get_remote_endpoint)(const struct fwnode_handle___209 *);
	struct fwnode_handle___209 * (*graph_get_port_parent)(struct fwnode_handle___209 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___209 *, struct fwnode_endpoint___209 *);
	int (*add_links)(struct fwnode_handle___209 *);
};

struct fwnode_endpoint___209 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___209 *local_fwnode;
};

struct fwnode_reference_args___209 {
	struct fwnode_handle___209 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___213 {
	int (*prepare)(struct device___213 *);
	void (*complete)(struct device___213 *);
	int (*suspend)(struct device___213 *);
	int (*resume)(struct device___213 *);
	int (*freeze)(struct device___213 *);
	int (*thaw)(struct device___213 *);
	int (*poweroff)(struct device___213 *);
	int (*restore)(struct device___213 *);
	int (*suspend_late)(struct device___213 *);
	int (*resume_early)(struct device___213 *);
	int (*freeze_late)(struct device___213 *);
	int (*thaw_early)(struct device___213 *);
	int (*poweroff_late)(struct device___213 *);
	int (*restore_early)(struct device___213 *);
	int (*suspend_noirq)(struct device___213 *);
	int (*resume_noirq)(struct device___213 *);
	int (*freeze_noirq)(struct device___213 *);
	int (*thaw_noirq)(struct device___213 *);
	int (*poweroff_noirq)(struct device___213 *);
	int (*restore_noirq)(struct device___213 *);
	int (*runtime_suspend)(struct device___213 *);
	int (*runtime_resume)(struct device___213 *);
	int (*runtime_idle)(struct device___213 *);
};

struct wakeup_source___213 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___213 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___213 {
	struct dev_pm_ops___213 ops;
	int (*start)(struct device___213 *);
	void (*detach)(struct device___213 *, bool);
	int (*activate)(struct device___213 *);
	void (*sync)(struct device___213 *);
	void (*dismiss)(struct device___213 *);
};

struct bus_type___213 {
	const char *name;
	const char *dev_name;
	struct device___213 *dev_root;
	const struct attribute_group___222 **bus_groups;
	const struct attribute_group___222 **dev_groups;
	const struct attribute_group___222 **drv_groups;
	int (*match)(struct device___213 *, struct device_driver___213 *);
	int (*uevent)(struct device___213 *, struct kobj_uevent_env *);
	int (*probe)(struct device___213 *);
	void (*sync_state)(struct device___213 *);
	void (*remove)(struct device___213 *);
	void (*shutdown)(struct device___213 *);
	int (*online)(struct device___213 *);
	int (*offline)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	int (*num_vf)(struct device___213 *);
	int (*dma_configure)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___213 {
	const char *name;
	struct bus_type___213 *bus;
	struct module___218 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___213 *);
	void (*sync_state)(struct device___213 *);
	int (*remove)(struct device___213 *);
	void (*shutdown)(struct device___213 *);
	int (*suspend)(struct device___213 *, pm_message_t);
	int (*resume)(struct device___213 *);
	const struct attribute_group___222 **groups;
	const struct attribute_group___222 **dev_groups;
	const struct dev_pm_ops___213 *pm;
	void (*coredump)(struct device___213 *);
	struct driver_private *p;
};

struct device_type___213 {
	const char *name;
	const struct attribute_group___222 **groups;
	int (*uevent)(struct device___213 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___213 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___213 *);
	const struct dev_pm_ops___213 *pm;
};

struct class___213 {
	const char *name;
	struct module___218 *owner;
	const struct attribute_group___222 **class_groups;
	const struct attribute_group___222 **dev_groups;
	struct kobject___222 *dev_kobj;
	int (*dev_uevent)(struct device___213 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___213 *, umode_t *);
	void (*class_release)(struct class___213 *);
	void (*dev_release)(struct device___213 *);
	int (*shutdown_pre)(struct device___213 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___213 *);
	void (*get_ownership)(struct device___213 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___213 *pm;
	struct subsys_private *p;
};

struct property___70;

struct device_node___94 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___209 fwnode;
	struct property___70 *properties;
	struct property___70 *deadprops;
	struct device_node___94 *parent;
	struct device_node___94 *child;
	struct device_node___94 *sibling;
	struct kobject___222 kobj;
	long unsigned int _flags;
	void *data;
};

struct dev_pagemap_ops___229 {
	void (*page_free)(struct page___239 *);
	void (*kill)(struct dev_pagemap___229 *);
	void (*cleanup)(struct dev_pagemap___229 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___229 *);
};

struct cgroup_namespace___164 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___164 *root_cset;
};

struct led_trigger___10;

struct led_classdev___10 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___10 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___10 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___10 *);
	int (*blink_set)(struct led_classdev___10 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___10 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___10 *);
	struct device___213 *dev;
	const struct attribute_group___222 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___10 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___10 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___222 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___10 {
	const char *name;
	int (*activate)(struct led_classdev___10 *);
	void (*deactivate)(struct led_classdev___10 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___222 **groups;
};

struct seq_operations___209 {
	void * (*start)(struct seq_file___209 *, loff_t *);
	void (*stop)(struct seq_file___209 *, void *);
	void * (*next)(struct seq_file___209 *, void *, loff_t *);
	int (*show)(struct seq_file___209 *, void *);
};

struct cftype___164;

struct cgroup_subsys___164 {
	struct cgroup_subsys_state___164 * (*css_alloc)(struct cgroup_subsys_state___164 *);
	int (*css_online)(struct cgroup_subsys_state___164 *);
	void (*css_offline)(struct cgroup_subsys_state___164 *);
	void (*css_released)(struct cgroup_subsys_state___164 *);
	void (*css_free)(struct cgroup_subsys_state___164 *);
	void (*css_reset)(struct cgroup_subsys_state___164 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___164 *, int);
	int (*css_extra_stat_show)(struct seq_file___209 *, struct cgroup_subsys_state___164 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___241 *, struct css_set___164 *);
	void (*cancel_fork)(struct task_struct___241 *, struct css_set___164 *);
	void (*fork)(struct task_struct___241 *);
	void (*exit)(struct task_struct___241 *);
	void (*release)(struct task_struct___241 *);
	void (*bind)(struct cgroup_subsys_state___164 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___164 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___164 *dfl_cftypes;
	struct cftype___164 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___164 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___164 *updated_children;
	struct cgroup___164 *updated_next;
};

struct cgroup_root___164 {
	struct kernfs_root___222 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___164 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___164 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___164 *ss;
	struct list_head node;
	struct kernfs_ops___222 *kf_ops;
	int (*open)(struct kernfs_open_file___222 *);
	void (*release)(struct kernfs_open_file___222 *);
	u64 (*read_u64)(struct cgroup_subsys_state___164 *, struct cftype___164 *);
	s64 (*read_s64)(struct cgroup_subsys_state___164 *, struct cftype___164 *);
	int (*seq_show)(struct seq_file___209 *, void *);
	void * (*seq_start)(struct seq_file___209 *, loff_t *);
	void * (*seq_next)(struct seq_file___209 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___209 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___164 *, struct cftype___164 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___164 *, struct cftype___164 *, s64);
	ssize_t (*write)(struct kernfs_open_file___222 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___222 *, struct poll_table_struct___159 *);
};

struct block_device_operations___127;

struct gendisk___130 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___130 *part0;
	const struct block_device_operations___127 *fops;
	struct request_queue___127 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___116 *bdi;
	struct kobject___222 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___222 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___127 {
	struct bio___127 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___151 *bip_vec;
	struct bio_vec___151 bip_inline_vecs[0];
};

struct blkcg___118;

struct blkg_policy_data___118;

struct blkcg_gq___118 {
	struct request_queue___127 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___118 *blkcg;
	struct blkcg_gq___118 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___118 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___127 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___127(struct request___127 *);

typedef void integrity_complete_fn___127(struct request___127 *, unsigned int);

struct blk_integrity_profile___127 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___127 *prepare_fn;
	integrity_complete_fn___127 *complete_fn;
	const char *name;
};

struct block_device_operations___127 {
	blk_qc_t (*submit_bio)(struct bio___127 *);
	int (*open)(struct block_device___130 *, fmode_t);
	void (*release)(struct gendisk___130 *, fmode_t);
	int (*rw_page)(struct block_device___130 *, sector_t, struct page___239 *, unsigned int);
	int (*ioctl)(struct block_device___130 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___130 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___130 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___130 *);
	int (*getgeo)(struct block_device___130 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___130 *, bool);
	void (*swap_slot_free_notify)(struct block_device___130 *, long unsigned int);
	int (*report_zones)(struct gendisk___130 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___130 *, umode_t *);
	struct module___218 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___130 *, sector_t *);
};

typedef void rq_end_io_fn___127(struct request___127 *, blk_status_t);

struct request___127 {
	struct request_queue___127 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___124 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___127 *bio;
	struct bio___127 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___151 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___127 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___127 *saved_end_io;
		} flush;
	};
	struct gendisk___130 *rq_disk;
	struct block_device___130 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___127 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___124 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___127 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___222 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___234 *debugfs_dir;
	struct dentry___234 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___127;

struct elevator_mq_ops___127 {
	int (*init_sched)(struct request_queue___127 *, struct elevator_type___127 *);
	void (*exit_sched)(struct elevator_queue___127 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___124 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___124 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___124 *);
	bool (*allow_merge)(struct request_queue___127 *, struct request___127 *, struct bio___127 *);
	bool (*bio_merge)(struct request_queue___127 *, struct bio___127 *, unsigned int);
	int (*request_merge)(struct request_queue___127 *, struct request___127 **, struct bio___127 *);
	void (*request_merged)(struct request_queue___127 *, struct request___127 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___127 *, struct request___127 *, struct request___127 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___127 *);
	void (*finish_request)(struct request___127 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___124 *, struct list_head *, bool);
	struct request___127 * (*dispatch_request)(struct blk_mq_hw_ctx___124 *);
	bool (*has_work)(struct blk_mq_hw_ctx___124 *);
	void (*completed_request)(struct request___127 *, u64);
	void (*requeue_request)(struct request___127 *);
	struct request___127 * (*former_request)(struct request_queue___127 *, struct request___127 *);
	struct request___127 * (*next_request)(struct request_queue___127 *, struct request___127 *);
	void (*init_icq)(struct io_cq___127 *);
	void (*exit_icq)(struct io_cq___127 *);
};

struct elv_fs_entry___127;

struct elevator_type___127 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___127 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___127 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___218 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___127 {
	struct elevator_type___127 *type;
	void *elevator_data;
	struct kobject___222 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___127 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___127 *, char *);
	ssize_t (*store)(struct elevator_queue___127 *, const char *, size_t);
};

struct blk_mq_queue_data___124;

struct blk_mq_ops___124 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___124 *, const struct blk_mq_queue_data___124 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___124 *);
	int (*get_budget)(struct request_queue___127 *);
	void (*put_budget)(struct request_queue___127 *, int);
	void (*set_rq_budget_token)(struct request___127 *, int);
	int (*get_rq_budget_token)(struct request___127 *);
	enum blk_eh_timer_return (*timeout)(struct request___127 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___124 *);
	void (*complete)(struct request___127 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___124 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___124 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___124 *, struct request___127 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___124 *, struct request___127 *, unsigned int);
	void (*initialize_rq_fn)(struct request___127 *);
	void (*cleanup_rq)(struct request___127 *);
	bool (*busy)(struct request_queue___127 *);
	int (*map_queues)(struct blk_mq_tag_set___124 *);
	void (*show_rq)(struct seq_file___209 *, struct request___127 *);
};

struct blk_ksm_ll_ops___5 {
	int (*keyslot_program)(struct blk_keyslot_manager___5 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___5 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___5 {
	struct blk_ksm_ll_ops___5 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___213 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct blk_mq_tag_set___124 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___124 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___124 {
	struct request___127 *rq;
	bool last;
};

struct blkcg_policy_data___118;

struct blkcg___118 {
	struct cgroup_subsys_state___164 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___118 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___118 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___118 {
	struct blkcg___118 *blkcg;
	int plid;
};

struct blkg_policy_data___118 {
	struct blkcg_gq___118 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___104 {
	struct mem_cgroup___104 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___104 {
	struct lruvec___112 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___104 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___104 *memcg;
};

struct obj_cgroup___104 {
	struct percpu_ref refcnt;
	struct mem_cgroup___104 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct property___70 {
	char *name;
	int length;
	void *value;
	struct property___70 *next;
	long unsigned int _flags;
	struct bin_attribute___222 attr;
};

struct mmc_cid {
	unsigned int manfid;
	char prod_name[8];
	unsigned char prv;
	unsigned int serial;
	short unsigned int oemid;
	short unsigned int year;
	unsigned char hwrev;
	unsigned char fwrev;
	unsigned char month;
};

struct mmc_csd {
	unsigned char structure;
	unsigned char mmca_vsn;
	short unsigned int cmdclass;
	short unsigned int taac_clks;
	unsigned int taac_ns;
	unsigned int c_size;
	unsigned int r2w_factor;
	unsigned int max_dtr;
	unsigned int erase_size;
	unsigned int read_blkbits;
	unsigned int write_blkbits;
	unsigned int capacity;
	unsigned int read_partial: 1;
	unsigned int read_misalign: 1;
	unsigned int write_partial: 1;
	unsigned int write_misalign: 1;
	unsigned int dsr_imp: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mmc_ext_csd {
	u8 rev;
	u8 erase_group_def;
	u8 sec_feature_support;
	u8 rel_sectors;
	u8 rel_param;
	bool enhanced_rpmb_supported;
	u8 part_config;
	u8 cache_ctrl;
	u8 rst_n_function;
	u8 max_packed_writes;
	u8 max_packed_reads;
	u8 packed_event_en;
	unsigned int part_time;
	unsigned int sa_timeout;
	unsigned int generic_cmd6_time;
	unsigned int power_off_longtime;
	u8 power_off_notification;
	unsigned int hs_max_dtr;
	unsigned int hs200_max_dtr;
	unsigned int sectors;
	unsigned int hc_erase_size;
	unsigned int hc_erase_timeout;
	unsigned int sec_trim_mult;
	unsigned int sec_erase_mult;
	unsigned int trim_timeout;
	bool partition_setting_completed;
	long long unsigned int enhanced_area_offset;
	unsigned int enhanced_area_size;
	unsigned int cache_size;
	bool hpi_en;
	bool hpi;
	unsigned int hpi_cmd;
	bool bkops;
	bool man_bkops_en;
	bool auto_bkops_en;
	unsigned int data_sector_size;
	unsigned int data_tag_unit_size;
	unsigned int boot_ro_lock;
	bool boot_ro_lockable;
	bool ffu_capable;
	bool cmdq_en;
	bool cmdq_support;
	unsigned int cmdq_depth;
	u8 fwrev[8];
	u8 raw_exception_status;
	u8 raw_partition_support;
	u8 raw_rpmb_size_mult;
	u8 raw_erased_mem_count;
	u8 strobe_support;
	u8 raw_ext_csd_structure;
	u8 raw_card_type;
	u8 raw_driver_strength;
	u8 out_of_int_time;
	u8 raw_pwr_cl_52_195;
	u8 raw_pwr_cl_26_195;
	u8 raw_pwr_cl_52_360;
	u8 raw_pwr_cl_26_360;
	u8 raw_s_a_timeout;
	u8 raw_hc_erase_gap_size;
	u8 raw_erase_timeout_mult;
	u8 raw_hc_erase_grp_size;
	u8 raw_boot_mult;
	u8 raw_sec_trim_mult;
	u8 raw_sec_erase_mult;
	u8 raw_sec_feature_support;
	u8 raw_trim_mult;
	u8 raw_pwr_cl_200_195;
	u8 raw_pwr_cl_200_360;
	u8 raw_pwr_cl_ddr_52_195;
	u8 raw_pwr_cl_ddr_52_360;
	u8 raw_pwr_cl_ddr_200_360;
	u8 raw_bkops_status;
	u8 raw_sectors[4];
	u8 pre_eol_info;
	u8 device_life_time_est_typ_a;
	u8 device_life_time_est_typ_b;
	unsigned int feature_support;
};

struct sd_scr {
	unsigned char sda_vsn;
	unsigned char sda_spec3;
	unsigned char sda_spec4;
	unsigned char sda_specx;
	unsigned char bus_widths;
	unsigned char cmds;
};

struct sd_ssr {
	unsigned int au;
	unsigned int erase_timeout;
	unsigned int erase_offset;
};

struct sd_switch_caps {
	unsigned int hs_max_dtr;
	unsigned int uhs_max_dtr;
	unsigned int sd3_bus_mode;
	unsigned int sd3_drv_type;
	unsigned int sd3_curr_limit;
};

struct sd_ext_reg {
	u8 fno;
	u8 page;
	u16 offset;
	u8 rev;
	u8 feature_enabled;
	u8 feature_support;
};

struct sdio_cccr {
	unsigned int sdio_vsn;
	unsigned int sd_vsn;
	unsigned int multi_block: 1;
	unsigned int low_speed: 1;
	unsigned int wide_bus: 1;
	unsigned int high_power: 1;
	unsigned int high_speed: 1;
	unsigned int disable_cd: 1;
	long: 31;
	long: 64;
};

struct sdio_cis {
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int blksize;
	unsigned int max_dtr;
};

struct mmc_part {
	u64 size;
	unsigned int part_cfg;
	char name[20];
	bool force_ro;
	unsigned int area_type;
};

struct mmc_host;

struct sdio_func;

struct sdio_func_tuple;

struct mmc_card {
	struct mmc_host *host;
	struct device___213 dev;
	u32 ocr;
	unsigned int rca;
	unsigned int type;
	unsigned int state;
	unsigned int quirks;
	unsigned int quirk_max_rate;
	bool reenable_cmdq;
	unsigned int erase_size;
	unsigned int erase_shift;
	unsigned int pref_erase;
	unsigned int eg_boundary;
	unsigned int erase_arg;
	u8 erased_byte;
	u32 raw_cid[4];
	u32 raw_csd[4];
	u32 raw_scr[2];
	u32 raw_ssr[16];
	struct mmc_cid cid;
	struct mmc_csd csd;
	struct mmc_ext_csd ext_csd;
	struct sd_scr scr;
	struct sd_ssr ssr;
	struct sd_switch_caps sw_caps;
	struct sd_ext_reg ext_power;
	struct sd_ext_reg ext_perf;
	unsigned int sdio_funcs;
	atomic_t sdio_funcs_probed;
	struct sdio_cccr cccr;
	struct sdio_cis cis;
	struct sdio_func *sdio_func[7];
	struct sdio_func *sdio_single_irq;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
	unsigned int sd_bus_speed;
	unsigned int mmc_avail_type;
	unsigned int drive_strength;
	struct dentry___234 *debugfs_root;
	struct mmc_part part[7];
	unsigned int nr_parts;
	struct workqueue_struct *complete_wq;
};

typedef unsigned int mmc_pm_flag_t;

struct mmc_ios {
	unsigned int clock;
	short unsigned int vdd;
	unsigned int power_delay_ms;
	unsigned char bus_mode;
	unsigned char chip_select;
	unsigned char power_mode;
	unsigned char bus_width;
	unsigned char timing;
	unsigned char signal_voltage;
	unsigned char drv_type;
	bool enhanced_strobe;
};

struct mmc_ctx {
	struct task_struct___241 *task;
};

struct mmc_slot {
	int cd_irq;
	bool cd_wake_enabled;
	void *handler_priv;
};

struct mmc_supply {
	struct regulator *vmmc;
	struct regulator *vqmmc;
};

struct mmc_host_ops;

struct mmc_pwrseq;

struct mmc_bus_ops;

struct mmc_request;

struct mmc_cqe_ops;

struct mmc_host {
	struct device___213 *parent;
	struct device___213 class_dev;
	int index;
	const struct mmc_host_ops *ops;
	struct mmc_pwrseq *pwrseq;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct wakeup_source___213 *ws;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	int fixed_drv_type;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_busy_timeout;
	spinlock_t lock;
	struct mmc_ios ios;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int doing_init_tune: 1;
	unsigned int can_retune: 1;
	unsigned int doing_retune: 1;
	unsigned int retune_now: 1;
	unsigned int retune_paused: 1;
	unsigned int retune_crc_disable: 1;
	unsigned int can_dma_map_merge: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int rescan_disable;
	int rescan_entered;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct timer_list retune_timer;
	bool trigger_card_event;
	struct mmc_card *card;
	wait_queue_head_t wq;
	struct mmc_ctx *claimer;
	int claim_cnt;
	struct mmc_ctx default_ctx;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops *bus_ops;
	unsigned int sdio_irqs;
	struct task_struct___241 *sdio_irq_thread;
	struct delayed_work sdio_irq_work;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___10 *led;
	bool regulator_enabled;
	struct mmc_supply supply;
	struct dentry___234 *debugfs_root;
	struct mmc_request *ongoing_mrq;
	unsigned int actual_clock;
	unsigned int slotno;
	int dsr_req;
	u32 dsr;
	const struct mmc_cqe_ops *cqe_ops;
	void *cqe_private;
	int cqe_qdepth;
	bool cqe_enabled;
	bool cqe_on;
	struct blk_keyslot_manager___5 ksm;
	bool hsq_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct mmc_data;

struct mmc_command {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	int error;
	unsigned int busy_timeout;
	struct mmc_data *data;
	struct mmc_request *mrq;
};

struct mmc_data {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int blk_addr;
	int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command *stop;
	struct mmc_request *mrq;
	unsigned int sg_len;
	int sg_count;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_request {
	struct mmc_command *sbc;
	struct mmc_command *cmd;
	struct mmc_data *data;
	struct mmc_command *stop;
	struct completion completion;
	struct completion cmd_completion;
	void (*done)(struct mmc_request *);
	void (*recovery_notifier)(struct mmc_request *);
	struct mmc_host *host;
	bool cap_cmd_during_tfr;
	int tag;
	const struct bio_crypt_ctx *crypto_ctx;
	int crypto_key_slot;
};

struct mmc_host_ops {
	void (*post_req)(struct mmc_host *, struct mmc_request *, int);
	void (*pre_req)(struct mmc_host *, struct mmc_request *);
	void (*request)(struct mmc_host *, struct mmc_request *);
	int (*request_atomic)(struct mmc_host *, struct mmc_request *);
	void (*set_ios)(struct mmc_host *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host *);
	int (*get_cd)(struct mmc_host *);
	void (*enable_sdio_irq)(struct mmc_host *, int);
	void (*ack_sdio_irq)(struct mmc_host *);
	void (*init_card)(struct mmc_host *, struct mmc_card *);
	int (*start_signal_voltage_switch)(struct mmc_host *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host *);
	int (*execute_tuning)(struct mmc_host *, u32);
	int (*prepare_hs400_tuning)(struct mmc_host *, struct mmc_ios *);
	int (*hs400_prepare_ddr)(struct mmc_host *);
	void (*hs400_downgrade)(struct mmc_host *);
	void (*hs400_complete)(struct mmc_host *);
	void (*hs400_enhanced_strobe)(struct mmc_host *, struct mmc_ios *);
	int (*select_drive_strength)(struct mmc_card *, unsigned int, int, int, int *);
	void (*hw_reset)(struct mmc_host *);
	void (*card_event)(struct mmc_host *);
	int (*multi_io_quirk)(struct mmc_card *, unsigned int, int);
	int (*init_sd_express)(struct mmc_host *, struct mmc_ios *);
};

struct mmc_cqe_ops {
	int (*cqe_enable)(struct mmc_host *, struct mmc_card *);
	void (*cqe_disable)(struct mmc_host *);
	int (*cqe_request)(struct mmc_host *, struct mmc_request *);
	void (*cqe_post_req)(struct mmc_host *, struct mmc_request *);
	void (*cqe_off)(struct mmc_host *);
	int (*cqe_wait_for_idle)(struct mmc_host *);
	bool (*cqe_timeout)(struct mmc_host *, struct mmc_request *, bool *);
	void (*cqe_recovery_start)(struct mmc_host *);
	void (*cqe_recovery_finish)(struct mmc_host *);
};

struct mmc_pwrseq_ops;

struct mmc_pwrseq {
	const struct mmc_pwrseq_ops *ops;
	struct device___213 *dev;
	struct list_head pwrseq_node;
	struct module___218 *owner;
};

struct mmc_bus_ops {
	void (*remove)(struct mmc_host *);
	void (*detect)(struct mmc_host *);
	int (*pre_suspend)(struct mmc_host *);
	int (*suspend)(struct mmc_host *);
	int (*resume)(struct mmc_host *);
	int (*runtime_suspend)(struct mmc_host *);
	int (*runtime_resume)(struct mmc_host *);
	int (*alive)(struct mmc_host *);
	int (*shutdown)(struct mmc_host *);
	int (*hw_reset)(struct mmc_host *);
	int (*sw_reset)(struct mmc_host *);
	bool (*cache_enabled)(struct mmc_host *);
	int (*flush_cache)(struct mmc_host *);
};

struct perf_cpu_context___83;

struct perf_output_handle___83;

struct pmu___83 {
	struct list_head entry;
	struct module___218 *module;
	struct device___213 *dev;
	const struct attribute_group___222 **attr_groups;
	const struct attribute_group___222 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___83 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___83 *);
	void (*pmu_disable)(struct pmu___83 *);
	int (*event_init)(struct perf_event___83 *);
	void (*event_mapped)(struct perf_event___83 *, struct mm_struct___240 *);
	void (*event_unmapped)(struct perf_event___83 *, struct mm_struct___240 *);
	int (*add)(struct perf_event___83 *, int);
	void (*del)(struct perf_event___83 *, int);
	void (*start)(struct perf_event___83 *, int);
	void (*stop)(struct perf_event___83 *, int);
	void (*read)(struct perf_event___83 *);
	void (*start_txn)(struct pmu___83 *, unsigned int);
	int (*commit_txn)(struct pmu___83 *);
	void (*cancel_txn)(struct pmu___83 *);
	int (*event_idx)(struct perf_event___83 *);
	void (*sched_task)(struct perf_event_context___83 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___83 *, struct perf_event_context___83 *);
	void * (*setup_aux)(struct perf_event___83 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___83 *, struct perf_output_handle___83 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___83 *);
	int (*aux_output_match)(struct perf_event___83 *);
	int (*filter_match)(struct perf_event___83 *);
	int (*check_period)(struct perf_event___83 *, u64);
};

struct perf_cpu_context___83 {
	struct perf_event_context___83 ctx;
	struct perf_event_context___83 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___83 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___83 **heap;
	struct perf_event___83 *heap_default[2];
};

struct perf_output_handle___83 {
	struct perf_event___83 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___83 {
	struct cgroup_subsys_state___164 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___77 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___77 *);
	};
};

struct trace_event_class___77 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___77 *, enum trace_reg, void *);
	struct trace_event_fields___77 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___77 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___77 *);
};

struct trace_event_file___38;

struct trace_event_buffer___37 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___38 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___38 {
	struct list_head list;
	struct trace_event_call___77 *event_call;
	struct event_filter *filter;
	struct dentry___234 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_mmc_request_start {
	struct trace_entry ent;
	u32 cmd_opcode;
	u32 cmd_arg;
	unsigned int cmd_flags;
	unsigned int cmd_retries;
	u32 stop_opcode;
	u32 stop_arg;
	unsigned int stop_flags;
	unsigned int stop_retries;
	u32 sbc_opcode;
	u32 sbc_arg;
	unsigned int sbc_flags;
	unsigned int sbc_retries;
	unsigned int blocks;
	unsigned int blk_addr;
	unsigned int blksz;
	unsigned int data_flags;
	int tag;
	unsigned int can_retune;
	unsigned int doing_retune;
	unsigned int retune_now;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct mmc_request *mrq;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_mmc_request_done {
	struct trace_entry ent;
	u32 cmd_opcode;
	int cmd_err;
	u32 cmd_resp[4];
	unsigned int cmd_retries;
	u32 stop_opcode;
	int stop_err;
	u32 stop_resp[4];
	unsigned int stop_retries;
	u32 sbc_opcode;
	int sbc_err;
	u32 sbc_resp[4];
	unsigned int sbc_retries;
	unsigned int bytes_xfered;
	int data_err;
	int tag;
	unsigned int can_retune;
	unsigned int doing_retune;
	unsigned int retune_now;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct mmc_request *mrq;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_data_offsets_mmc_request_start {
	u32 name;
};

struct trace_event_data_offsets_mmc_request_done {
	u32 name;
};

typedef void (*btf_trace_mmc_request_start)(void *, struct mmc_host *, struct mmc_request *);

typedef void (*btf_trace_mmc_request_done)(void *, struct mmc_host *, struct mmc_request *);

struct mmc_pwrseq_ops {
	void (*pre_power_on)(struct mmc_host *);
	void (*post_power_on)(struct mmc_host *);
	void (*power_off)(struct mmc_host *);
	void (*reset)(struct mmc_host *);
};

enum mmc_busy_cmd {
	MMC_BUSY_CMD6 = 0,
	MMC_BUSY_ERASE = 1,
	MMC_BUSY_HPI = 2,
	MMC_BUSY_EXTR_SINGLE = 3,
	MMC_BUSY_IO = 4,
};

struct mmc_csd___2 {
	unsigned char structure;
	unsigned char mmca_vsn;
	short unsigned int cmdclass;
	short unsigned int taac_clks;
	unsigned int taac_ns;
	unsigned int c_size;
	unsigned int r2w_factor;
	unsigned int max_dtr;
	unsigned int erase_size;
	unsigned int read_blkbits;
	unsigned int write_blkbits;
	unsigned int capacity;
	unsigned int read_partial;
	unsigned int read_misalign;
	unsigned int write_partial;
	unsigned int write_misalign;
	unsigned int dsr_imp;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct mmc_host___2;

struct mmc_card___2 {
	struct mmc_host___2 *host;
	struct device___211 dev;
	u32 ocr;
	unsigned int rca;
	unsigned int type;
	unsigned int state;
	unsigned int quirks;
	unsigned int quirk_max_rate;
	bool reenable_cmdq;
	unsigned int erase_size;
	unsigned int erase_shift;
	unsigned int pref_erase;
	unsigned int eg_boundary;
	unsigned int erase_arg;
	u8 erased_byte;
	u32 raw_cid[4];
	u32 raw_csd[4];
	u32 raw_scr[2];
	u32 raw_ssr[16];
	struct mmc_cid cid;
	struct mmc_csd___2 csd;
	struct mmc_ext_csd ext_csd;
	struct sd_scr scr;
	struct sd_ssr ssr;
	struct sd_switch_caps sw_caps;
	struct sd_ext_reg ext_power;
	struct sd_ext_reg ext_perf;
	unsigned int sdio_funcs;
	atomic_t sdio_funcs_probed;
	struct sdio_cccr cccr;
	struct sdio_cis cis;
	struct sdio_func *sdio_func[7];
	struct sdio_func *sdio_single_irq;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
	unsigned int sd_bus_speed;
	unsigned int mmc_avail_type;
	unsigned int drive_strength;
	struct dentry___232 *debugfs_root;
	struct mmc_part part[7];
	unsigned int nr_parts;
	struct workqueue_struct *complete_wq;
};

struct mmc_ctx___2 {
	struct task_struct___239 *task;
};

struct mmc_host_ops___2;

struct mmc_pwrseq___2;

struct mmc_bus_ops___2;

struct led_trigger___11;

struct mmc_request___2;

struct mmc_cqe_ops___2;

struct mmc_host___2 {
	struct device___211 *parent;
	struct device___211 class_dev;
	int index;
	const struct mmc_host_ops___2 *ops;
	struct mmc_pwrseq___2 *pwrseq;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct wakeup_source___211 *ws;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	int fixed_drv_type;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_busy_timeout;
	spinlock_t lock;
	struct mmc_ios ios;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int doing_init_tune: 1;
	unsigned int can_retune: 1;
	unsigned int doing_retune: 1;
	unsigned int retune_now: 1;
	unsigned int retune_paused: 1;
	unsigned int retune_crc_disable: 1;
	unsigned int can_dma_map_merge: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int rescan_disable;
	int rescan_entered;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct timer_list retune_timer;
	bool trigger_card_event;
	struct mmc_card___2 *card;
	wait_queue_head_t wq;
	struct mmc_ctx___2 *claimer;
	int claim_cnt;
	struct mmc_ctx___2 default_ctx;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops___2 *bus_ops;
	unsigned int sdio_irqs;
	struct task_struct___239 *sdio_irq_thread;
	struct delayed_work sdio_irq_work;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___11 *led;
	bool regulator_enabled;
	struct mmc_supply supply;
	struct dentry___232 *debugfs_root;
	struct mmc_request___2 *ongoing_mrq;
	unsigned int actual_clock;
	unsigned int slotno;
	int dsr_req;
	u32 dsr;
	const struct mmc_cqe_ops___2 *cqe_ops;
	void *cqe_private;
	int cqe_qdepth;
	bool cqe_enabled;
	bool cqe_on;
	struct blk_keyslot_manager___3 ksm;
	bool hsq_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct mmc_data___2;

struct mmc_command___2 {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	int error;
	unsigned int busy_timeout;
	struct mmc_data___2 *data;
	struct mmc_request___2 *mrq;
};

struct mmc_data___2 {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int blk_addr;
	int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command___2 *stop;
	struct mmc_request___2 *mrq;
	unsigned int sg_len;
	int sg_count;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_request___2 {
	struct mmc_command___2 *sbc;
	struct mmc_command___2 *cmd;
	struct mmc_data___2 *data;
	struct mmc_command___2 *stop;
	struct completion completion;
	struct completion cmd_completion;
	void (*done)(struct mmc_request___2 *);
	void (*recovery_notifier)(struct mmc_request___2 *);
	struct mmc_host___2 *host;
	bool cap_cmd_during_tfr;
	int tag;
	const struct bio_crypt_ctx *crypto_ctx;
	int crypto_key_slot;
};

struct mmc_host_ops___2 {
	void (*post_req)(struct mmc_host___2 *, struct mmc_request___2 *, int);
	void (*pre_req)(struct mmc_host___2 *, struct mmc_request___2 *);
	void (*request)(struct mmc_host___2 *, struct mmc_request___2 *);
	int (*request_atomic)(struct mmc_host___2 *, struct mmc_request___2 *);
	void (*set_ios)(struct mmc_host___2 *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host___2 *);
	int (*get_cd)(struct mmc_host___2 *);
	void (*enable_sdio_irq)(struct mmc_host___2 *, int);
	void (*ack_sdio_irq)(struct mmc_host___2 *);
	void (*init_card)(struct mmc_host___2 *, struct mmc_card___2 *);
	int (*start_signal_voltage_switch)(struct mmc_host___2 *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host___2 *);
	int (*execute_tuning)(struct mmc_host___2 *, u32);
	int (*prepare_hs400_tuning)(struct mmc_host___2 *, struct mmc_ios *);
	int (*hs400_prepare_ddr)(struct mmc_host___2 *);
	void (*hs400_downgrade)(struct mmc_host___2 *);
	void (*hs400_complete)(struct mmc_host___2 *);
	void (*hs400_enhanced_strobe)(struct mmc_host___2 *, struct mmc_ios *);
	int (*select_drive_strength)(struct mmc_card___2 *, unsigned int, int, int, int *);
	void (*hw_reset)(struct mmc_host___2 *);
	void (*card_event)(struct mmc_host___2 *);
	int (*multi_io_quirk)(struct mmc_card___2 *, unsigned int, int);
	int (*init_sd_express)(struct mmc_host___2 *, struct mmc_ios *);
};

struct mmc_cqe_ops___2 {
	int (*cqe_enable)(struct mmc_host___2 *, struct mmc_card___2 *);
	void (*cqe_disable)(struct mmc_host___2 *);
	int (*cqe_request)(struct mmc_host___2 *, struct mmc_request___2 *);
	void (*cqe_post_req)(struct mmc_host___2 *, struct mmc_request___2 *);
	void (*cqe_off)(struct mmc_host___2 *);
	int (*cqe_wait_for_idle)(struct mmc_host___2 *);
	bool (*cqe_timeout)(struct mmc_host___2 *, struct mmc_request___2 *, bool *);
	void (*cqe_recovery_start)(struct mmc_host___2 *);
	void (*cqe_recovery_finish)(struct mmc_host___2 *);
};

struct mmc_bus_ops___2 {
	void (*remove)(struct mmc_host___2 *);
	void (*detect)(struct mmc_host___2 *);
	int (*pre_suspend)(struct mmc_host___2 *);
	int (*suspend)(struct mmc_host___2 *);
	int (*resume)(struct mmc_host___2 *);
	int (*runtime_suspend)(struct mmc_host___2 *);
	int (*runtime_resume)(struct mmc_host___2 *);
	int (*alive)(struct mmc_host___2 *);
	int (*shutdown)(struct mmc_host___2 *);
	int (*hw_reset)(struct mmc_host___2 *);
	int (*sw_reset)(struct mmc_host___2 *);
	bool (*cache_enabled)(struct mmc_host___2 *);
	int (*flush_cache)(struct mmc_host___2 *);
};

struct mmc_driver {
	struct device_driver___211 drv;
	int (*probe)(struct mmc_card___2 *);
	void (*remove)(struct mmc_card___2 *);
	void (*shutdown)(struct mmc_card___2 *);
};

struct dentry___235;

struct super_block___235;

struct module___219;

struct file_system_type___235 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___235 * (*mount)(struct file_system_type___235 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___235 *);
	struct module___219 *owner;
	struct file_system_type___235 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___235;

struct kiocb___235;

struct iov_iter___155;

struct vm_area_struct___240;

struct inode___235;

struct file_lock___235;

struct page___240;

struct seq_file___210;

struct file_operations___236 {
	struct module___219 *owner;
	loff_t (*llseek)(struct file___235 *, loff_t, int);
	ssize_t (*read)(struct file___235 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___235 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___235 *, struct iov_iter___155 *);
	ssize_t (*write_iter)(struct kiocb___235 *, struct iov_iter___155 *);
	int (*iopoll)(struct kiocb___235 *, bool);
	int (*iterate)(struct file___235 *, struct dir_context *);
	int (*iterate_shared)(struct file___235 *, struct dir_context *);
	__poll_t (*poll)(struct file___235 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___235 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___235 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___235 *, struct vm_area_struct___240 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___235 *, struct file___235 *);
	int (*flush)(struct file___235 *, fl_owner_t);
	int (*release)(struct inode___235 *, struct file___235 *);
	int (*fsync)(struct file___235 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___235 *, int);
	int (*lock)(struct file___235 *, int, struct file_lock___235 *);
	ssize_t (*sendpage)(struct file___235 *, struct page___240 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___235 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___235 *, long unsigned int);
	int (*flock)(struct file___235 *, int, struct file_lock___235 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___235 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___235 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___235 *, long int, struct file_lock___235 **, void **);
	long int (*fallocate)(struct file___235 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___210 *, struct file___235 *);
	ssize_t (*copy_file_range)(struct file___235 *, loff_t, struct file___235 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___235 *, loff_t, struct file___235 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___235 *, loff_t, loff_t, int);
};

struct vmacache___240 {
	u64 seqnum;
	struct vm_area_struct___240 *vmas[4];
};

struct page_frag___240 {
	struct page___240 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___241;

struct pid___212;

struct nsproxy___221;

struct signal_struct___236;

struct bio_list___128;

struct io_context___128;

struct request_queue___128;

struct vm_struct___218;

struct task_struct___242 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___242 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___241 *mm;
	struct mm_struct___241 *active_mm;
	struct vmacache___240 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___242 *real_parent;
	struct task_struct___242 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___242 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___212 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___221 *nsproxy;
	struct signal_struct___236 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___242 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___128 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___128 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___240 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___128 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___242 *oom_reaper_list;
	struct vm_struct___218 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___223;

struct kobj_type___223;

struct kernfs_node___223;

struct kobject___223 {
	const char *name;
	struct list_head entry;
	struct kobject___223 *parent;
	struct kset___223 *kset;
	struct kobj_type___223 *ktype;
	struct kernfs_node___223 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___220 {
	struct kobject___223 kobj;
	struct module___219 *mod;
	struct kobject___223 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___219 {
	struct module___219 *mod;
	struct latch_tree_node node;
};

struct module_layout___219 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___219 mtn;
};

struct module_attribute___219;

struct kernel_param___219;

struct module___219 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___220 mkobj;
	struct module_attribute___219 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___223 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___219 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___219 core_layout;
	struct module_layout___219 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___212;

struct upid___212 {
	int nr;
	struct pid_namespace___212 *ns;
};

struct pid_namespace___212 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___242 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___212 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___212 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___212 numbers[1];
};

typedef struct page___240 *pgtable_t___240;

struct address_space___235;

struct dev_pagemap___230;

struct page___240 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___235 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___240 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___240 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___241 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___230 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___230;

struct vm_area_struct___240 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___240 *vm_next;
	struct vm_area_struct___240 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___241 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___230 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___235 *vm_file;
	struct file___235 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___236 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___242 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___242 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___212 *pids[4];
	struct pid___212 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___241 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___240;

struct mm_struct___241 {
	struct {
		struct vm_area_struct___240 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___235 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___240 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___242 *owner;
		struct user_namespace *user_ns;
		struct file___235 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___221 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___212 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___128;

struct bio_list___128 {
	struct bio___128 *head;
	struct bio___128 *tail;
};

struct io_cq___128;

struct io_context___128 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___128 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___128;

struct blk_integrity___128 {
	const struct blk_integrity_profile___128 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___128 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___128 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___128;

struct elevator_queue___128;

struct gendisk___131;

struct device___214;

struct blk_keyslot_manager___6;

struct request_queue___128 {
	struct request___128 *last_merge;
	struct elevator_queue___128 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___131 *disk;
	struct kobject___223 kobj;
	struct kobject___223 *mq_kobj;
	struct blk_integrity___128 integrity;
	struct device___214 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___6 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___128 bio_split;
	struct dentry___235 *debugfs_dir;
	struct dentry___235 *sched_debugfs_dir;
	struct dentry___235 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___218 {
	struct vm_struct___218 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___240 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___235;

struct address_space___235 {
	struct inode___235 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___235 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___230;

struct dev_pagemap___230 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___230 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___235;

struct path___235 {
	struct vfsmount___235 *mnt;
	struct dentry___235 *dentry;
};

struct fown_struct___212 {
	rwlock_t lock;
	struct pid___212 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___235 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___235 f_path;
	struct inode___235 *f_inode;
	const struct file_operations___236 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___212 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___235 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___230;

struct vm_operations_struct___230 {
	void (*open)(struct vm_area_struct___240 *);
	void (*close)(struct vm_area_struct___240 *);
	int (*may_split)(struct vm_area_struct___240 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___240 *);
	int (*mprotect)(struct vm_area_struct___240 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___230 *);
	vm_fault_t (*huge_fault)(struct vm_fault___230 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___230 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___240 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___230 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___230 *);
	int (*access)(struct vm_area_struct___240 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___240 *);
	int (*set_policy)(struct vm_area_struct___240 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___240 *, long unsigned int);
	struct page___240 * (*find_special_page)(struct vm_area_struct___240 *, long unsigned int);
};

struct core_thread___240 {
	struct task_struct___242 *task;
	struct core_thread___240 *next;
};

struct core_state___240 {
	atomic_t nr_threads;
	struct core_thread___240 dumper;
	struct completion startup;
};

struct vm_fault___230 {
	const struct {
		struct vm_area_struct___240 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___240 *cow_page;
	struct page___240 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___240 prealloc_pte;
};

struct kernfs_root___223;

struct kernfs_elem_dir___223 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___223 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___223;

struct kernfs_root___223 {
	struct kernfs_node___223 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___223 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___223 {
	struct kernfs_node___223 *target_kn;
};

struct kernfs_ops___223;

struct kernfs_elem_attr___223 {
	const struct kernfs_ops___223 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___223 *notify_next;
};

struct kernfs_node___223 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___223 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___223 dir;
		struct kernfs_elem_symlink___223 symlink;
		struct kernfs_elem_attr___223 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___223;

struct kernfs_ops___223 {
	int (*open)(struct kernfs_open_file___223 *);
	void (*release)(struct kernfs_open_file___223 *);
	int (*seq_show)(struct seq_file___210 *, void *);
	void * (*seq_start)(struct seq_file___210 *, loff_t *);
	void * (*seq_next)(struct seq_file___210 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___210 *, void *);
	ssize_t (*read)(struct kernfs_open_file___223 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___223 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___223 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___223 *, struct vm_area_struct___240 *);
};

struct kernfs_syscall_ops___223 {
	int (*show_options)(struct seq_file___210 *, struct kernfs_root___223 *);
	int (*mkdir)(struct kernfs_node___223 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___223 *);
	int (*rename)(struct kernfs_node___223 *, struct kernfs_node___223 *, const char *);
	int (*show_path)(struct seq_file___210 *, struct kernfs_node___223 *, struct kernfs_root___223 *);
};

struct seq_operations___210;

struct seq_file___210 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___210 *op;
	int poll_event;
	const struct file___235 *file;
	void *private;
};

struct kernfs_open_file___223 {
	struct kernfs_node___223 *kn;
	struct file___235 *file;
	struct seq_file___210 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___230 *vm_ops;
};

struct bin_attribute___223;

struct attribute_group___223 {
	const char *name;
	umode_t (*is_visible)(struct kobject___223 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___223 *, struct bin_attribute___223 *, int);
	struct attribute **attrs;
	struct bin_attribute___223 **bin_attrs;
};

struct bin_attribute___223 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___235 * (*f_mapping)();
	ssize_t (*read)(struct file___235 *, struct kobject___223 *, struct bin_attribute___223 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___235 *, struct kobject___223 *, struct bin_attribute___223 *, char *, loff_t, size_t);
	int (*mmap)(struct file___235 *, struct kobject___223 *, struct bin_attribute___223 *, struct vm_area_struct___240 *);
};

struct sysfs_ops___223 {
	ssize_t (*show)(struct kobject___223 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___223 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___223;

struct kset___223 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___223 kobj;
	const struct kset_uevent_ops___223 *uevent_ops;
};

struct kobj_type___223 {
	void (*release)(struct kobject___223 *);
	const struct sysfs_ops___223 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___223 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___223 *);
	const void * (*namespace)(struct kobject___223 *);
	void (*get_ownership)(struct kobject___223 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___223 {
	int (* const filter)(struct kset___223 *, struct kobject___223 *);
	const char * (* const name)(struct kset___223 *, struct kobject___223 *);
	int (* const uevent)(struct kset___223 *, struct kobject___223 *, struct kobj_uevent_env *);
};

struct wakeup_source___214;

struct dev_pm_info___214 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___214 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___12 *subsys_data;
	void (*set_latency_tolerance)(struct device___214 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___214;

struct bus_type___214;

struct device_driver___214;

struct dev_pm_domain___214;

struct irq_domain___60;

struct device_node___95;

struct fwnode_handle___210;

struct class___214;

struct device___214 {
	struct kobject___223 kobj;
	struct device___214 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___214 *type;
	struct bus_type___214 *bus;
	struct device_driver___214 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___214 power;
	struct dev_pm_domain___214 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___60 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___95 *of_node;
	struct fwnode_handle___210 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___214 *class;
	const struct attribute_group___223 **groups;
	void (*release)(struct device___214 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___214 {
	int (*prepare)(struct device___214 *);
	void (*complete)(struct device___214 *);
	int (*suspend)(struct device___214 *);
	int (*resume)(struct device___214 *);
	int (*freeze)(struct device___214 *);
	int (*thaw)(struct device___214 *);
	int (*poweroff)(struct device___214 *);
	int (*restore)(struct device___214 *);
	int (*suspend_late)(struct device___214 *);
	int (*resume_early)(struct device___214 *);
	int (*freeze_late)(struct device___214 *);
	int (*thaw_early)(struct device___214 *);
	int (*poweroff_late)(struct device___214 *);
	int (*restore_early)(struct device___214 *);
	int (*suspend_noirq)(struct device___214 *);
	int (*resume_noirq)(struct device___214 *);
	int (*freeze_noirq)(struct device___214 *);
	int (*thaw_noirq)(struct device___214 *);
	int (*poweroff_noirq)(struct device___214 *);
	int (*restore_noirq)(struct device___214 *);
	int (*runtime_suspend)(struct device___214 *);
	int (*runtime_resume)(struct device___214 *);
	int (*runtime_idle)(struct device___214 *);
};

struct wakeup_source___214 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___214 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___214 {
	struct dev_pm_ops___214 ops;
	int (*start)(struct device___214 *);
	void (*detach)(struct device___214 *, bool);
	int (*activate)(struct device___214 *);
	void (*sync)(struct device___214 *);
	void (*dismiss)(struct device___214 *);
};

struct bus_type___214 {
	const char *name;
	const char *dev_name;
	struct device___214 *dev_root;
	const struct attribute_group___223 **bus_groups;
	const struct attribute_group___223 **dev_groups;
	const struct attribute_group___223 **drv_groups;
	int (*match)(struct device___214 *, struct device_driver___214 *);
	int (*uevent)(struct device___214 *, struct kobj_uevent_env *);
	int (*probe)(struct device___214 *);
	void (*sync_state)(struct device___214 *);
	void (*remove)(struct device___214 *);
	void (*shutdown)(struct device___214 *);
	int (*online)(struct device___214 *);
	int (*offline)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	int (*num_vf)(struct device___214 *);
	int (*dma_configure)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___214 {
	const char *name;
	struct bus_type___214 *bus;
	struct module___219 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___214 *);
	void (*sync_state)(struct device___214 *);
	int (*remove)(struct device___214 *);
	void (*shutdown)(struct device___214 *);
	int (*suspend)(struct device___214 *, pm_message_t);
	int (*resume)(struct device___214 *);
	const struct attribute_group___223 **groups;
	const struct attribute_group___223 **dev_groups;
	const struct dev_pm_ops___214 *pm;
	void (*coredump)(struct device___214 *);
	struct driver_private *p;
};

struct device_type___214 {
	const char *name;
	const struct attribute_group___223 **groups;
	int (*uevent)(struct device___214 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___214 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___214 *);
	const struct dev_pm_ops___214 *pm;
};

struct class___214 {
	const char *name;
	struct module___219 *owner;
	const struct attribute_group___223 **class_groups;
	const struct attribute_group___223 **dev_groups;
	struct kobject___223 *dev_kobj;
	int (*dev_uevent)(struct device___214 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___214 *, umode_t *);
	void (*class_release)(struct class___214 *);
	void (*dev_release)(struct device___214 *);
	int (*shutdown_pre)(struct device___214 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___214 *);
	void (*get_ownership)(struct device___214 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___214 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___60;

struct irq_domain_chip_generic___60;

struct irq_data___62;

struct irq_domain___60 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___60 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___210 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___60 *gc;
	struct irq_domain___60 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___62 *revmap[0];
};

struct fwnode_operations___210;

struct fwnode_handle___210 {
	struct fwnode_handle___210 *secondary;
	const struct fwnode_operations___210 *ops;
	struct device___214 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___71;

struct device_node___95 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___210 fwnode;
	struct property___71 *properties;
	struct property___71 *deadprops;
	struct device_node___95 *parent;
	struct device_node___95 *child;
	struct device_node___95 *sibling;
	struct kobject___223 kobj;
	long unsigned int _flags;
	void *data;
};

struct fwnode_reference_args___210;

struct fwnode_endpoint___210;

struct fwnode_operations___210 {
	struct fwnode_handle___210 * (*get)(struct fwnode_handle___210 *);
	void (*put)(struct fwnode_handle___210 *);
	bool (*device_is_available)(const struct fwnode_handle___210 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___210 *, const struct device___214 *);
	bool (*property_present)(const struct fwnode_handle___210 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___210 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___210 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___210 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*get_parent)(const struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*get_next_child_node)(const struct fwnode_handle___210 *, struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*get_named_child_node)(const struct fwnode_handle___210 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___210 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___210 *);
	struct fwnode_handle___210 * (*graph_get_next_endpoint)(const struct fwnode_handle___210 *, struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*graph_get_remote_endpoint)(const struct fwnode_handle___210 *);
	struct fwnode_handle___210 * (*graph_get_port_parent)(struct fwnode_handle___210 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___210 *, struct fwnode_endpoint___210 *);
	int (*add_links)(struct fwnode_handle___210 *);
};

struct fwnode_endpoint___210 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___210 *local_fwnode;
};

struct fwnode_reference_args___210 {
	struct fwnode_handle___210 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___71 {
	char *name;
	int length;
	void *value;
	struct property___71 *next;
	long unsigned int _flags;
	struct bin_attribute___223 attr;
};

struct irq_desc___62;

typedef void (*irq_flow_handler_t___62)(struct irq_desc___62 *);

struct irq_chip___62;

struct irq_data___62 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___62 *chip;
	struct irq_domain___60 *domain;
	struct irq_data___62 *parent_data;
	void *chip_data;
};

struct irqaction___44;

struct irq_desc___62 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___62 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___62 handle_irq;
	struct irqaction___44 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___223 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___219 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___62 {
	struct device___214 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___62 *);
	void (*irq_shutdown)(struct irq_data___62 *);
	void (*irq_enable)(struct irq_data___62 *);
	void (*irq_disable)(struct irq_data___62 *);
	void (*irq_ack)(struct irq_data___62 *);
	void (*irq_mask)(struct irq_data___62 *);
	void (*irq_mask_ack)(struct irq_data___62 *);
	void (*irq_unmask)(struct irq_data___62 *);
	void (*irq_eoi)(struct irq_data___62 *);
	int (*irq_set_affinity)(struct irq_data___62 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___62 *);
	int (*irq_set_type)(struct irq_data___62 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___62 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___62 *);
	void (*irq_bus_sync_unlock)(struct irq_data___62 *);
	void (*irq_cpu_online)(struct irq_data___62 *);
	void (*irq_cpu_offline)(struct irq_data___62 *);
	void (*irq_suspend)(struct irq_data___62 *);
	void (*irq_resume)(struct irq_data___62 *);
	void (*irq_pm_shutdown)(struct irq_data___62 *);
	void (*irq_calc_mask)(struct irq_data___62 *);
	void (*irq_print_chip)(struct irq_data___62 *, struct seq_file___210 *);
	int (*irq_request_resources)(struct irq_data___62 *);
	void (*irq_release_resources)(struct irq_data___62 *);
	void (*irq_compose_msi_msg)(struct irq_data___62 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___62 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___62 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___62 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___62 *, void *);
	void (*ipi_send_single)(struct irq_data___62 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___62 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___62 *);
	void (*irq_nmi_teardown)(struct irq_data___62 *);
	long unsigned int flags;
};

struct irqaction___44 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___44 *next;
	irq_handler_t thread_fn;
	struct task_struct___242 *thread;
	struct irqaction___44 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___60 {
	struct irq_chip___62 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___62 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___60 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___60 *);
	void (*resume)(struct irq_chip_generic___60 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___60 *domain;
	struct list_head list;
	struct irq_chip_type___60 chip_types[0];
};

struct irq_domain_chip_generic___60 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___60 *gc[0];
};

struct irq_fwspec___58 {
	struct fwnode_handle___210 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___60 {
	int (*match)(struct irq_domain___60 *, struct device_node___95 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___60 *, struct irq_fwspec___58 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___60 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___60 *, unsigned int);
	int (*xlate)(struct irq_domain___60 *, struct device_node___95 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___60 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___60 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___60 *, struct irq_data___62 *, bool);
	void (*deactivate)(struct irq_domain___60 *, struct irq_data___62 *);
	int (*translate)(struct irq_domain___60 *, struct irq_fwspec___58 *, long unsigned int *, unsigned int *);
};

struct dentry_operations___235;

struct dentry___235 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___235 *d_parent;
	struct qstr d_name;
	struct inode___235 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___235 *d_op;
	struct super_block___235 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___235;

struct inode___235 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___235 *i_op;
	struct super_block___235 *i_sb;
	struct address_space___235 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___236 *i_fop;
		void (*free_inode)(struct inode___235 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___235 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___62 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___235 {
	int (*d_revalidate)(struct dentry___235 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___235 *, unsigned int);
	int (*d_hash)(const struct dentry___235 *, struct qstr *);
	int (*d_compare)(const struct dentry___235 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___235 *);
	int (*d_init)(struct dentry___235 *);
	void (*d_release)(struct dentry___235 *);
	void (*d_prune)(struct dentry___235 *);
	void (*d_iput)(struct dentry___235 *, struct inode___235 *);
	char * (*d_dname)(struct dentry___235 *, char *, int);
	struct vfsmount___235 * (*d_automount)(struct path___235 *);
	int (*d_manage)(const struct path___235 *, bool);
	struct dentry___235 * (*d_real)(struct dentry___235 *, const struct inode___235 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___235;

struct mem_dqinfo___235 {
	struct quota_format_type___235 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___235;

struct quota_info___235 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___235 *files[3];
	struct mem_dqinfo___235 info[3];
	const struct quota_format_ops___235 *ops[3];
};

struct rcuwait___236 {
	struct task_struct___242 *task;
};

struct percpu_rw_semaphore___236 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___236 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___235 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___236 rw_sem[3];
};

struct super_operations___235;

struct dquot_operations___235;

struct quotactl_ops___235;

struct block_device___131;

struct super_block___235 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___235 *s_type;
	const struct super_operations___235 *s_op;
	const struct dquot_operations___235 *dq_op;
	const struct quotactl_ops___235 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___235 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___131 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___235 s_dquot;
	struct sb_writers___235 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___235 *s_d_op;
	int cleancache_poolid;
	struct shrinker___104 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___235 {
	struct dentry___235 *mnt_root;
	struct super_block___235 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___128 {
	struct request_queue___128 *q;
	struct io_context___128 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___113;

struct kiocb___235 {
	struct file___235 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___235 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___113 *ki_waitq;
	};
};

struct iattr___235 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___235 *ia_file;
};

struct dquot___235 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___235 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___235 {
	int qf_fmt_id;
	const struct quota_format_ops___235 *qf_ops;
	struct module___219 *qf_owner;
	struct quota_format_type___235 *qf_next;
};

struct quota_format_ops___235 {
	int (*check_quota_file)(struct super_block___235 *, int);
	int (*read_file_info)(struct super_block___235 *, int);
	int (*write_file_info)(struct super_block___235 *, int);
	int (*free_file_info)(struct super_block___235 *, int);
	int (*read_dqblk)(struct dquot___235 *);
	int (*commit_dqblk)(struct dquot___235 *);
	int (*release_dqblk)(struct dquot___235 *);
	int (*get_next_id)(struct super_block___235 *, struct kqid *);
};

struct dquot_operations___235 {
	int (*write_dquot)(struct dquot___235 *);
	struct dquot___235 * (*alloc_dquot)(struct super_block___235 *, int);
	void (*destroy_dquot)(struct dquot___235 *);
	int (*acquire_dquot)(struct dquot___235 *);
	int (*release_dquot)(struct dquot___235 *);
	int (*mark_dirty)(struct dquot___235 *);
	int (*write_info)(struct super_block___235 *, int);
	qsize_t * (*get_reserved_space)(struct inode___235 *);
	int (*get_projid)(struct inode___235 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___235 *, qsize_t *);
	int (*get_next_id)(struct super_block___235 *, struct kqid *);
};

struct quotactl_ops___235 {
	int (*quota_on)(struct super_block___235 *, int, int, const struct path___235 *);
	int (*quota_off)(struct super_block___235 *, int);
	int (*quota_enable)(struct super_block___235 *, unsigned int);
	int (*quota_disable)(struct super_block___235 *, unsigned int);
	int (*quota_sync)(struct super_block___235 *, int);
	int (*set_info)(struct super_block___235 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___235 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___235 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___235 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___235 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___235 *, unsigned int);
};

struct wait_page_queue___113 {
	struct page___240 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct readahead_control___113;

struct address_space_operations___235 {
	int (*writepage)(struct page___240 *, struct writeback_control___3 *);
	int (*readpage)(struct file___235 *, struct page___240 *);
	int (*writepages)(struct address_space___235 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___240 *);
	int (*readpages)(struct file___235 *, struct address_space___235 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___113 *);
	int (*write_begin)(struct file___235 *, struct address_space___235 *, loff_t, unsigned int, unsigned int, struct page___240 **, void **);
	int (*write_end)(struct file___235 *, struct address_space___235 *, loff_t, unsigned int, unsigned int, struct page___240 *, void *);
	sector_t (*bmap)(struct address_space___235 *, sector_t);
	void (*invalidatepage)(struct page___240 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___240 *, gfp_t);
	void (*freepage)(struct page___240 *);
	ssize_t (*direct_IO)(struct kiocb___235 *, struct iov_iter___155 *);
	int (*migratepage)(struct address_space___235 *, struct page___240 *, struct page___240 *, enum migrate_mode);
	bool (*isolate_page)(struct page___240 *, isolate_mode_t);
	void (*putback_page)(struct page___240 *);
	int (*launder_page)(struct page___240 *);
	int (*is_partially_uptodate)(struct page___240 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___240 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___235 *, struct page___240 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___235 *, sector_t *);
	void (*swap_deactivate)(struct file___235 *);
};

struct readahead_control___113 {
	struct file___235 *file;
	struct address_space___235 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___152;

struct iov_iter___155 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___152 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___235 {
	struct dentry___235 * (*lookup)(struct inode___235 *, struct dentry___235 *, unsigned int);
	const char * (*get_link)(struct dentry___235 *, struct inode___235 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___235 *, int);
	struct posix_acl * (*get_acl)(struct inode___235 *, int, bool);
	int (*readlink)(struct dentry___235 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___235 *, struct dentry___235 *, umode_t, bool);
	int (*link)(struct dentry___235 *, struct inode___235 *, struct dentry___235 *);
	int (*unlink)(struct inode___235 *, struct dentry___235 *);
	int (*symlink)(struct user_namespace *, struct inode___235 *, struct dentry___235 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___235 *, struct dentry___235 *, umode_t);
	int (*rmdir)(struct inode___235 *, struct dentry___235 *);
	int (*mknod)(struct user_namespace *, struct inode___235 *, struct dentry___235 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___235 *, struct dentry___235 *, struct inode___235 *, struct dentry___235 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___235 *, struct iattr___235 *);
	int (*getattr)(struct user_namespace *, const struct path___235 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___235 *, char *, size_t);
	int (*fiemap)(struct inode___235 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___235 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___235 *, struct dentry___235 *, struct file___235 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___235 *, struct dentry___235 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___235 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___235 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___235 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___235 {
	void (*fl_copy_lock)(struct file_lock___235 *, struct file_lock___235 *);
	void (*fl_release_private)(struct file_lock___235 *);
};

struct fasync_struct___235;

struct lock_manager_operations___235;

struct file_lock___235 {
	struct file_lock___235 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___235 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___235 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___235 *fl_ops;
	const struct lock_manager_operations___235 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___235 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___235 *);
	int (*lm_grant)(struct file_lock___235 *, int);
	bool (*lm_break)(struct file_lock___235 *);
	int (*lm_change)(struct file_lock___235 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___235 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___235 *);
};

struct fasync_struct___235 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___235 *fa_next;
	struct file___235 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___235 {
	struct inode___235 * (*alloc_inode)(struct super_block___235 *);
	void (*destroy_inode)(struct inode___235 *);
	void (*free_inode)(struct inode___235 *);
	void (*dirty_inode)(struct inode___235 *, int);
	int (*write_inode)(struct inode___235 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___235 *);
	void (*evict_inode)(struct inode___235 *);
	void (*put_super)(struct super_block___235 *);
	int (*sync_fs)(struct super_block___235 *, int);
	int (*freeze_super)(struct super_block___235 *);
	int (*freeze_fs)(struct super_block___235 *);
	int (*thaw_super)(struct super_block___235 *);
	int (*unfreeze_fs)(struct super_block___235 *);
	int (*statfs)(struct dentry___235 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___235 *, int *, char *);
	void (*umount_begin)(struct super_block___235 *);
	int (*show_options)(struct seq_file___210 *, struct dentry___235 *);
	int (*show_devname)(struct seq_file___210 *, struct dentry___235 *);
	int (*show_path)(struct seq_file___210 *, struct dentry___235 *);
	int (*show_stats)(struct seq_file___210 *, struct dentry___235 *);
	ssize_t (*quota_read)(struct super_block___235 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___235 *, int, const char *, size_t, loff_t);
	struct dquot___235 ** (*get_dquots)(struct inode___235 *);
	long int (*nr_cached_objects)(struct super_block___235 *, struct shrink_control___104 *);
	long int (*free_cached_objects)(struct super_block___235 *, struct shrink_control___104 *);
	struct file___235 * (*real_loop)(struct file___235 *);
};

struct block_device___131 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___235 *bd_inode;
	struct super_block___235 *bd_super;
	void *bd_claiming;
	struct device___214 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___223 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___131 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___235 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___128(struct bio___128 *);

struct bio_vec___152 {
	struct page___240 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___128;

struct bio___128 {
	struct bio___128 *bi_next;
	struct block_device___131 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___128 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___128 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___152 *bi_io_vec;
	struct bio_set___128 *bi_pool;
	struct bio_vec___152 bi_inline_vecs[0];
};

struct seq_operations___210 {
	void * (*start)(struct seq_file___210 *, loff_t *);
	void (*stop)(struct seq_file___210 *, void *);
	void * (*next)(struct seq_file___210 *, void *, loff_t *);
	int (*show)(struct seq_file___210 *, void *);
};

struct dev_pagemap_ops___230 {
	void (*page_free)(struct page___240 *);
	void (*kill)(struct dev_pagemap___230 *);
	void (*cleanup)(struct dev_pagemap___230 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___230 *);
};

struct kernel_param_ops___219 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___219 *);
	int (*get)(char *, const struct kernel_param___219 *);
	void (*free)(void *);
};

struct kparam_array___219;

struct kernel_param___219 {
	const char *name;
	struct module___219 *mod;
	const struct kernel_param_ops___219 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___219 *arr;
	};
};

struct kparam_array___219 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___219 *ops;
	void *elem;
};

struct module_attribute___219 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___219 *, struct module_kobject___220 *, char *);
	ssize_t (*store)(struct module_attribute___219 *, struct module_kobject___220 *, const char *, size_t);
	void (*setup)(struct module___219 *, const char *);
	int (*test)(struct module___219 *);
	void (*free)(struct module___219 *);
};

struct led_classdev___11 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___11 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___11 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___11 *);
	int (*blink_set)(struct led_classdev___11 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___11 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___11 *);
	struct device___214 *dev;
	const struct attribute_group___223 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___11 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___11 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___223 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___11 {
	const char *name;
	int (*activate)(struct led_classdev___11 *);
	void (*deactivate)(struct led_classdev___11 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___223 **groups;
};

struct mmc_data___3;

struct mmc_request___3;

struct mmc_command___3 {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	int error;
	unsigned int busy_timeout;
	struct mmc_data___3 *data;
	struct mmc_request___3 *mrq;
};

struct mmc_data___3 {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int blk_addr;
	int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command___3 *stop;
	struct mmc_request___3 *mrq;
	unsigned int sg_len;
	int sg_count;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_host___3;

struct mmc_request___3 {
	struct mmc_command___3 *sbc;
	struct mmc_command___3 *cmd;
	struct mmc_data___3 *data;
	struct mmc_command___3 *stop;
	struct completion completion;
	struct completion cmd_completion;
	void (*done)(struct mmc_request___3 *);
	void (*recovery_notifier)(struct mmc_request___3 *);
	struct mmc_host___3 *host;
	bool cap_cmd_during_tfr;
	int tag;
	const struct bio_crypt_ctx *crypto_ctx;
	int crypto_key_slot;
};

struct mmc_ctx___3 {
	struct task_struct___242 *task;
};

struct blk_ksm_ll_ops___6 {
	int (*keyslot_program)(struct blk_keyslot_manager___6 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___6 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___6 {
	struct blk_ksm_ll_ops___6 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___214 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct mmc_host_ops___3;

struct mmc_card___3;

struct mmc_bus_ops___3;

struct mmc_cqe_ops___3;

struct mmc_host___3 {
	struct device___214 *parent;
	struct device___214 class_dev;
	int index;
	const struct mmc_host_ops___3 *ops;
	struct mmc_pwrseq___2 *pwrseq;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct wakeup_source___214 *ws;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	int fixed_drv_type;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_busy_timeout;
	spinlock_t lock;
	struct mmc_ios ios;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int doing_init_tune: 1;
	unsigned int can_retune: 1;
	unsigned int doing_retune: 1;
	unsigned int retune_now: 1;
	unsigned int retune_paused: 1;
	unsigned int retune_crc_disable: 1;
	unsigned int can_dma_map_merge: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int rescan_disable;
	int rescan_entered;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct timer_list retune_timer;
	bool trigger_card_event;
	struct mmc_card___3 *card;
	wait_queue_head_t wq;
	struct mmc_ctx___3 *claimer;
	int claim_cnt;
	struct mmc_ctx___3 default_ctx;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops___3 *bus_ops;
	unsigned int sdio_irqs;
	struct task_struct___242 *sdio_irq_thread;
	struct delayed_work sdio_irq_work;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___11 *led;
	bool regulator_enabled;
	struct mmc_supply supply;
	struct dentry___235 *debugfs_root;
	struct mmc_request___3 *ongoing_mrq;
	unsigned int actual_clock;
	unsigned int slotno;
	int dsr_req;
	u32 dsr;
	const struct mmc_cqe_ops___3 *cqe_ops;
	void *cqe_private;
	int cqe_qdepth;
	bool cqe_enabled;
	bool cqe_on;
	struct blk_keyslot_manager___6 ksm;
	bool hsq_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct mmc_card___3 {
	struct mmc_host___3 *host;
	struct device___214 dev;
	u32 ocr;
	unsigned int rca;
	unsigned int type;
	unsigned int state;
	unsigned int quirks;
	unsigned int quirk_max_rate;
	bool reenable_cmdq;
	unsigned int erase_size;
	unsigned int erase_shift;
	unsigned int pref_erase;
	unsigned int eg_boundary;
	unsigned int erase_arg;
	u8 erased_byte;
	u32 raw_cid[4];
	u32 raw_csd[4];
	u32 raw_scr[2];
	u32 raw_ssr[16];
	struct mmc_cid cid;
	struct mmc_csd csd;
	struct mmc_ext_csd ext_csd;
	struct sd_scr scr;
	struct sd_ssr ssr;
	struct sd_switch_caps sw_caps;
	struct sd_ext_reg ext_power;
	struct sd_ext_reg ext_perf;
	unsigned int sdio_funcs;
	atomic_t sdio_funcs_probed;
	struct sdio_cccr cccr;
	struct sdio_cis cis;
	struct sdio_func *sdio_func[7];
	struct sdio_func *sdio_single_irq;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
	unsigned int sd_bus_speed;
	unsigned int mmc_avail_type;
	unsigned int drive_strength;
	struct dentry___235 *debugfs_root;
	struct mmc_part part[7];
	unsigned int nr_parts;
	struct workqueue_struct *complete_wq;
};

struct block_device_operations___128;

struct gendisk___131 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___131 *part0;
	const struct block_device_operations___128 *fops;
	struct request_queue___128 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___223 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___223 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___128 {
	struct bio___128 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___152 *bip_vec;
	struct bio_vec___152 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___128(struct request___128 *);

typedef void integrity_complete_fn___128(struct request___128 *, unsigned int);

struct blk_integrity_profile___128 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___128 *prepare_fn;
	integrity_complete_fn___128 *complete_fn;
	const char *name;
};

struct block_device_operations___128 {
	blk_qc_t (*submit_bio)(struct bio___128 *);
	int (*open)(struct block_device___131 *, fmode_t);
	void (*release)(struct gendisk___131 *, fmode_t);
	int (*rw_page)(struct block_device___131 *, sector_t, struct page___240 *, unsigned int);
	int (*ioctl)(struct block_device___131 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___131 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___131 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___131 *);
	int (*getgeo)(struct block_device___131 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___131 *, bool);
	void (*swap_slot_free_notify)(struct block_device___131 *, long unsigned int);
	int (*report_zones)(struct gendisk___131 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___131 *, umode_t *);
	struct module___219 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___131 *, sector_t *);
};

typedef void rq_end_io_fn___128(struct request___128 *, blk_status_t);

struct request___128 {
	struct request_queue___128 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___128 *bio;
	struct bio___128 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___152 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___128 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___128 *saved_end_io;
		} flush;
	};
	struct gendisk___131 *rq_disk;
	struct block_device___131 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___128 *end_io;
	void *end_io_data;
};

struct elevator_type___128;

struct elevator_mq_ops___128 {
	int (*init_sched)(struct request_queue___128 *, struct elevator_type___128 *);
	void (*exit_sched)(struct elevator_queue___128 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
	bool (*allow_merge)(struct request_queue___128 *, struct request___128 *, struct bio___128 *);
	bool (*bio_merge)(struct request_queue___128 *, struct bio___128 *, unsigned int);
	int (*request_merge)(struct request_queue___128 *, struct request___128 **, struct bio___128 *);
	void (*request_merged)(struct request_queue___128 *, struct request___128 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___128 *, struct request___128 *, struct request___128 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___128 *);
	void (*finish_request)(struct request___128 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___128 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___128 *, u64);
	void (*requeue_request)(struct request___128 *);
	struct request___128 * (*former_request)(struct request_queue___128 *, struct request___128 *);
	struct request___128 * (*next_request)(struct request_queue___128 *, struct request___128 *);
	void (*init_icq)(struct io_cq___128 *);
	void (*exit_icq)(struct io_cq___128 *);
};

struct elv_fs_entry___128;

struct elevator_type___128 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___128 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___128 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___219 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___128 {
	struct elevator_type___128 *type;
	void *elevator_data;
	struct kobject___223 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___128 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___128 *, char *);
	ssize_t (*store)(struct elevator_queue___128 *, const char *, size_t);
};

struct mmc_clk_phase {
	bool valid;
	u16 in_deg;
	u16 out_deg;
};

struct mmc_clk_phase_map {
	struct mmc_clk_phase phase[11];
};

struct mmc_host_ops___3 {
	void (*post_req)(struct mmc_host___3 *, struct mmc_request___3 *, int);
	void (*pre_req)(struct mmc_host___3 *, struct mmc_request___3 *);
	void (*request)(struct mmc_host___3 *, struct mmc_request___3 *);
	int (*request_atomic)(struct mmc_host___3 *, struct mmc_request___3 *);
	void (*set_ios)(struct mmc_host___3 *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host___3 *);
	int (*get_cd)(struct mmc_host___3 *);
	void (*enable_sdio_irq)(struct mmc_host___3 *, int);
	void (*ack_sdio_irq)(struct mmc_host___3 *);
	void (*init_card)(struct mmc_host___3 *, struct mmc_card___3 *);
	int (*start_signal_voltage_switch)(struct mmc_host___3 *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host___3 *);
	int (*execute_tuning)(struct mmc_host___3 *, u32);
	int (*prepare_hs400_tuning)(struct mmc_host___3 *, struct mmc_ios *);
	int (*hs400_prepare_ddr)(struct mmc_host___3 *);
	void (*hs400_downgrade)(struct mmc_host___3 *);
	void (*hs400_complete)(struct mmc_host___3 *);
	void (*hs400_enhanced_strobe)(struct mmc_host___3 *, struct mmc_ios *);
	int (*select_drive_strength)(struct mmc_card___3 *, unsigned int, int, int, int *);
	void (*hw_reset)(struct mmc_host___3 *);
	void (*card_event)(struct mmc_host___3 *);
	int (*multi_io_quirk)(struct mmc_card___3 *, unsigned int, int);
	int (*init_sd_express)(struct mmc_host___3 *, struct mmc_ios *);
};

struct mmc_cqe_ops___3 {
	int (*cqe_enable)(struct mmc_host___3 *, struct mmc_card___3 *);
	void (*cqe_disable)(struct mmc_host___3 *);
	int (*cqe_request)(struct mmc_host___3 *, struct mmc_request___3 *);
	void (*cqe_post_req)(struct mmc_host___3 *, struct mmc_request___3 *);
	void (*cqe_off)(struct mmc_host___3 *);
	int (*cqe_wait_for_idle)(struct mmc_host___3 *);
	bool (*cqe_timeout)(struct mmc_host___3 *, struct mmc_request___3 *, bool *);
	void (*cqe_recovery_start)(struct mmc_host___3 *);
	void (*cqe_recovery_finish)(struct mmc_host___3 *);
};

struct mmc_pwrseq_ops___2;

struct mmc_pwrseq___2 {
	const struct mmc_pwrseq_ops___2 *ops;
	struct device___214 *dev;
	struct list_head pwrseq_node;
	struct module___219 *owner;
};

struct mmc_bus_ops___3 {
	void (*remove)(struct mmc_host___3 *);
	void (*detect)(struct mmc_host___3 *);
	int (*pre_suspend)(struct mmc_host___3 *);
	int (*suspend)(struct mmc_host___3 *);
	int (*resume)(struct mmc_host___3 *);
	int (*runtime_suspend)(struct mmc_host___3 *);
	int (*runtime_resume)(struct mmc_host___3 *);
	int (*alive)(struct mmc_host___3 *);
	int (*shutdown)(struct mmc_host___3 *);
	int (*hw_reset)(struct mmc_host___3 *);
	int (*sw_reset)(struct mmc_host___3 *);
	bool (*cache_enabled)(struct mmc_host___3 *);
	int (*flush_cache)(struct mmc_host___3 *);
};

struct mmc_pwrseq_ops___2 {
	void (*pre_power_on)(struct mmc_host___3 *);
	void (*post_power_on)(struct mmc_host___3 *);
	void (*power_off)(struct mmc_host___3 *);
	void (*reset)(struct mmc_host___3 *);
};

struct device_attribute___45 {
	struct attribute attr;
	ssize_t (*show)(struct device___214 *, struct device_attribute___45 *, char *);
	ssize_t (*store)(struct device___214 *, struct device_attribute___45 *, const char *, size_t);
};

struct mmc_fixup {
	const char *name;
	u64 rev_start;
	u64 rev_end;
	unsigned int manfid;
	short unsigned int oemid;
	u16 cis_vendor;
	u16 cis_device;
	unsigned int ext_csd_rev;
	void (*vendor_fixup)(struct mmc_card___3 *, int);
	int data;
};

struct mmc_busy_data {
	struct mmc_card___3 *card;
	bool retry_crc_err;
	enum mmc_busy_cmd busy_cmd;
};

struct sd_busy_data {
	struct mmc_card___3 *card;
	u8 *reg_buf;
};

typedef void sdio_irq_handler_t(struct sdio_func *);

struct sdio_func {
	struct mmc_card___3 *card;
	struct device___214 dev;
	sdio_irq_handler_t *irq_handler;
	unsigned int num;
	unsigned char class;
	short unsigned int vendor;
	short unsigned int device;
	unsigned int max_blksize;
	unsigned int cur_blksize;
	unsigned int enable_timeout;
	unsigned int state;
	u8 *tmpbuf;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
};

struct sdio_func_tuple {
	struct sdio_func_tuple *next;
	unsigned char code;
	unsigned char size;
	unsigned char data[0];
};

struct dentry___236;

struct super_block___236;

struct module___220;

struct file_system_type___236 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___236 * (*mount)(struct file_system_type___236 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___236 *);
	struct module___220 *owner;
	struct file_system_type___236 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___236;

struct kiocb___236;

struct iov_iter___156;

struct poll_table_struct___160;

struct vm_area_struct___241;

struct inode___236;

struct file_lock___236;

struct page___241;

struct seq_file___211;

struct file_operations___237 {
	struct module___220 *owner;
	loff_t (*llseek)(struct file___236 *, loff_t, int);
	ssize_t (*read)(struct file___236 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___236 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___236 *, struct iov_iter___156 *);
	ssize_t (*write_iter)(struct kiocb___236 *, struct iov_iter___156 *);
	int (*iopoll)(struct kiocb___236 *, bool);
	int (*iterate)(struct file___236 *, struct dir_context *);
	int (*iterate_shared)(struct file___236 *, struct dir_context *);
	__poll_t (*poll)(struct file___236 *, struct poll_table_struct___160 *);
	long int (*unlocked_ioctl)(struct file___236 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___236 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___236 *, struct vm_area_struct___241 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___236 *, struct file___236 *);
	int (*flush)(struct file___236 *, fl_owner_t);
	int (*release)(struct inode___236 *, struct file___236 *);
	int (*fsync)(struct file___236 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___236 *, int);
	int (*lock)(struct file___236 *, int, struct file_lock___236 *);
	ssize_t (*sendpage)(struct file___236 *, struct page___241 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___236 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___236 *, long unsigned int);
	int (*flock)(struct file___236 *, int, struct file_lock___236 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___236 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___236 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___236 *, long int, struct file_lock___236 **, void **);
	long int (*fallocate)(struct file___236 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___211 *, struct file___236 *);
	ssize_t (*copy_file_range)(struct file___236 *, loff_t, struct file___236 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___236 *, loff_t, struct file___236 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___236 *, loff_t, loff_t, int);
};

struct vmacache___241 {
	u64 seqnum;
	struct vm_area_struct___241 *vmas[4];
};

struct page_frag___241 {
	struct page___241 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___242;

struct pid___213;

struct nsproxy___222;

struct signal_struct___237;

struct bio_list___129;

struct io_context___129;

struct request_queue___129;

struct vm_struct___219;

struct task_struct___243 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___243 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___242 *mm;
	struct mm_struct___242 *active_mm;
	struct vmacache___241 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___243 *real_parent;
	struct task_struct___243 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___243 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___213 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___222 *nsproxy;
	struct signal_struct___237 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___243 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___129 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___129 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___241 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___129 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___243 *oom_reaper_list;
	struct vm_struct___219 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___224;

struct kobj_type___224;

struct kernfs_node___224;

struct kobject___224 {
	const char *name;
	struct list_head entry;
	struct kobject___224 *parent;
	struct kset___224 *kset;
	struct kobj_type___224 *ktype;
	struct kernfs_node___224 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___221 {
	struct kobject___224 kobj;
	struct module___220 *mod;
	struct kobject___224 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___220 {
	struct module___220 *mod;
	struct latch_tree_node node;
};

struct module_layout___220 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___220 mtn;
};

struct module_attribute___220;

struct kernel_param___220;

struct module___220 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___221 mkobj;
	struct module_attribute___220 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___224 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___220 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___220 core_layout;
	struct module_layout___220 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___213;

struct upid___213 {
	int nr;
	struct pid_namespace___213 *ns;
};

struct pid_namespace___213 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___243 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___213 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___213 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___213 numbers[1];
};

typedef struct page___241 *pgtable_t___241;

struct address_space___236;

struct dev_pagemap___231;

struct page___241 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___236 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___241 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___241 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___242 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___231 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___231;

struct vm_area_struct___241 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___241 *vm_next;
	struct vm_area_struct___241 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___242 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___231 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___236 *vm_file;
	struct file___236 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___237 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___243 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___243 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___213 *pids[4];
	struct pid___213 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___242 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___241;

struct mm_struct___242 {
	struct {
		struct vm_area_struct___241 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___236 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___241 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___243 *owner;
		struct user_namespace *user_ns;
		struct file___236 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___222 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___213 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___129;

struct bio_list___129 {
	struct bio___129 *head;
	struct bio___129 *tail;
};

struct io_cq___129;

struct io_context___129 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___129 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___129;

struct blk_integrity___129 {
	const struct blk_integrity_profile___129 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___129 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___129 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___129;

struct elevator_queue___129;

struct gendisk___132;

struct device___215;

struct blk_keyslot_manager___7;

struct request_queue___129 {
	struct request___129 *last_merge;
	struct elevator_queue___129 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___3 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___3 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___132 *disk;
	struct kobject___224 kobj;
	struct kobject___224 *mq_kobj;
	struct blk_integrity___129 integrity;
	struct device___215 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___7 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___3 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___129 bio_split;
	struct dentry___236 *debugfs_dir;
	struct dentry___236 *sched_debugfs_dir;
	struct dentry___236 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___219 {
	struct vm_struct___219 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___241 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___236;

struct address_space___236 {
	struct inode___236 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___236 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___231;

struct dev_pagemap___231 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___231 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___236;

struct path___236 {
	struct vfsmount___236 *mnt;
	struct dentry___236 *dentry;
};

struct fown_struct___213 {
	rwlock_t lock;
	struct pid___213 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___236 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___236 f_path;
	struct inode___236 *f_inode;
	const struct file_operations___237 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___213 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___236 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___231;

struct vm_operations_struct___231 {
	void (*open)(struct vm_area_struct___241 *);
	void (*close)(struct vm_area_struct___241 *);
	int (*may_split)(struct vm_area_struct___241 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___241 *);
	int (*mprotect)(struct vm_area_struct___241 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___231 *);
	vm_fault_t (*huge_fault)(struct vm_fault___231 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___231 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___241 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___231 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___231 *);
	int (*access)(struct vm_area_struct___241 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___241 *);
	int (*set_policy)(struct vm_area_struct___241 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___241 *, long unsigned int);
	struct page___241 * (*find_special_page)(struct vm_area_struct___241 *, long unsigned int);
};

struct core_thread___241 {
	struct task_struct___243 *task;
	struct core_thread___241 *next;
};

struct core_state___241 {
	atomic_t nr_threads;
	struct core_thread___241 dumper;
	struct completion startup;
};

struct vm_fault___231 {
	const struct {
		struct vm_area_struct___241 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___241 *cow_page;
	struct page___241 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___241 prealloc_pte;
};

struct kernfs_root___224;

struct kernfs_elem_dir___224 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___224 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___224;

struct kernfs_root___224 {
	struct kernfs_node___224 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___224 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___224 {
	struct kernfs_node___224 *target_kn;
};

struct kernfs_ops___224;

struct kernfs_elem_attr___224 {
	const struct kernfs_ops___224 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___224 *notify_next;
};

struct kernfs_node___224 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___224 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___224 dir;
		struct kernfs_elem_symlink___224 symlink;
		struct kernfs_elem_attr___224 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___224;

struct kernfs_ops___224 {
	int (*open)(struct kernfs_open_file___224 *);
	void (*release)(struct kernfs_open_file___224 *);
	int (*seq_show)(struct seq_file___211 *, void *);
	void * (*seq_start)(struct seq_file___211 *, loff_t *);
	void * (*seq_next)(struct seq_file___211 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___211 *, void *);
	ssize_t (*read)(struct kernfs_open_file___224 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___224 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___224 *, struct poll_table_struct___160 *);
	int (*mmap)(struct kernfs_open_file___224 *, struct vm_area_struct___241 *);
};

struct kernfs_syscall_ops___224 {
	int (*show_options)(struct seq_file___211 *, struct kernfs_root___224 *);
	int (*mkdir)(struct kernfs_node___224 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___224 *);
	int (*rename)(struct kernfs_node___224 *, struct kernfs_node___224 *, const char *);
	int (*show_path)(struct seq_file___211 *, struct kernfs_node___224 *, struct kernfs_root___224 *);
};

struct seq_operations___211;

struct seq_file___211 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___211 *op;
	int poll_event;
	const struct file___236 *file;
	void *private;
};

struct kernfs_open_file___224 {
	struct kernfs_node___224 *kn;
	struct file___236 *file;
	struct seq_file___211 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___231 *vm_ops;
};

typedef void (*poll_queue_proc___167)(struct file___236 *, wait_queue_head_t *, struct poll_table_struct___160 *);

struct poll_table_struct___160 {
	poll_queue_proc___167 _qproc;
	__poll_t _key;
};

struct bin_attribute___224;

struct attribute_group___224 {
	const char *name;
	umode_t (*is_visible)(struct kobject___224 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___224 *, struct bin_attribute___224 *, int);
	struct attribute **attrs;
	struct bin_attribute___224 **bin_attrs;
};

struct bin_attribute___224 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___236 * (*f_mapping)();
	ssize_t (*read)(struct file___236 *, struct kobject___224 *, struct bin_attribute___224 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___236 *, struct kobject___224 *, struct bin_attribute___224 *, char *, loff_t, size_t);
	int (*mmap)(struct file___236 *, struct kobject___224 *, struct bin_attribute___224 *, struct vm_area_struct___241 *);
};

struct sysfs_ops___224 {
	ssize_t (*show)(struct kobject___224 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___224 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___224;

struct kset___224 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___224 kobj;
	const struct kset_uevent_ops___224 *uevent_ops;
};

struct kobj_type___224 {
	void (*release)(struct kobject___224 *);
	const struct sysfs_ops___224 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___224 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___224 *);
	const void * (*namespace)(struct kobject___224 *);
	void (*get_ownership)(struct kobject___224 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___224 {
	int (* const filter)(struct kset___224 *, struct kobject___224 *);
	const char * (* const name)(struct kset___224 *, struct kobject___224 *);
	int (* const uevent)(struct kset___224 *, struct kobject___224 *, struct kobj_uevent_env *);
};

struct wakeup_source___215;

struct pm_subsys_data___13;

struct dev_pm_info___215 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___215 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___215 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___215;

struct bus_type___215;

struct device_driver___215;

struct dev_pm_domain___215;

struct irq_domain___61;

struct device_node___96;

struct fwnode_handle___211;

struct class___215;

struct device___215 {
	struct kobject___224 kobj;
	struct device___215 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___215 *type;
	struct bus_type___215 *bus;
	struct device_driver___215 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___215 power;
	struct dev_pm_domain___215 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___61 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___96 *of_node;
	struct fwnode_handle___211 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___215 *class;
	const struct attribute_group___224 **groups;
	void (*release)(struct device___215 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___215 {
	int (*prepare)(struct device___215 *);
	void (*complete)(struct device___215 *);
	int (*suspend)(struct device___215 *);
	int (*resume)(struct device___215 *);
	int (*freeze)(struct device___215 *);
	int (*thaw)(struct device___215 *);
	int (*poweroff)(struct device___215 *);
	int (*restore)(struct device___215 *);
	int (*suspend_late)(struct device___215 *);
	int (*resume_early)(struct device___215 *);
	int (*freeze_late)(struct device___215 *);
	int (*thaw_early)(struct device___215 *);
	int (*poweroff_late)(struct device___215 *);
	int (*restore_early)(struct device___215 *);
	int (*suspend_noirq)(struct device___215 *);
	int (*resume_noirq)(struct device___215 *);
	int (*freeze_noirq)(struct device___215 *);
	int (*thaw_noirq)(struct device___215 *);
	int (*poweroff_noirq)(struct device___215 *);
	int (*restore_noirq)(struct device___215 *);
	int (*runtime_suspend)(struct device___215 *);
	int (*runtime_resume)(struct device___215 *);
	int (*runtime_idle)(struct device___215 *);
};

struct pm_domain_data___13;

struct pm_subsys_data___13 {
	spinlock_t lock;
	unsigned int refcount;
	unsigned int clock_op_might_sleep;
	struct mutex clock_mutex;
	struct list_head clock_list;
	struct pm_domain_data___13 *domain_data;
};

struct pm_domain_data___13 {
	struct list_head list_node;
	struct device___215 *dev;
};

struct wakeup_source___215 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___215 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___215 {
	struct dev_pm_ops___215 ops;
	int (*start)(struct device___215 *);
	void (*detach)(struct device___215 *, bool);
	int (*activate)(struct device___215 *);
	void (*sync)(struct device___215 *);
	void (*dismiss)(struct device___215 *);
};

struct bus_type___215 {
	const char *name;
	const char *dev_name;
	struct device___215 *dev_root;
	const struct attribute_group___224 **bus_groups;
	const struct attribute_group___224 **dev_groups;
	const struct attribute_group___224 **drv_groups;
	int (*match)(struct device___215 *, struct device_driver___215 *);
	int (*uevent)(struct device___215 *, struct kobj_uevent_env *);
	int (*probe)(struct device___215 *);
	void (*sync_state)(struct device___215 *);
	void (*remove)(struct device___215 *);
	void (*shutdown)(struct device___215 *);
	int (*online)(struct device___215 *);
	int (*offline)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	int (*num_vf)(struct device___215 *);
	int (*dma_configure)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___215 {
	const char *name;
	struct bus_type___215 *bus;
	struct module___220 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___215 *);
	void (*sync_state)(struct device___215 *);
	int (*remove)(struct device___215 *);
	void (*shutdown)(struct device___215 *);
	int (*suspend)(struct device___215 *, pm_message_t);
	int (*resume)(struct device___215 *);
	const struct attribute_group___224 **groups;
	const struct attribute_group___224 **dev_groups;
	const struct dev_pm_ops___215 *pm;
	void (*coredump)(struct device___215 *);
	struct driver_private *p;
};

struct device_type___215 {
	const char *name;
	const struct attribute_group___224 **groups;
	int (*uevent)(struct device___215 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___215 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___215 *);
	const struct dev_pm_ops___215 *pm;
};

struct class___215 {
	const char *name;
	struct module___220 *owner;
	const struct attribute_group___224 **class_groups;
	const struct attribute_group___224 **dev_groups;
	struct kobject___224 *dev_kobj;
	int (*dev_uevent)(struct device___215 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___215 *, umode_t *);
	void (*class_release)(struct class___215 *);
	void (*dev_release)(struct device___215 *);
	int (*shutdown_pre)(struct device___215 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___215 *);
	void (*get_ownership)(struct device___215 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___215 *pm;
	struct subsys_private *p;
};

struct device_attribute___46 {
	struct attribute attr;
	ssize_t (*show)(struct device___215 *, struct device_attribute___46 *, char *);
	ssize_t (*store)(struct device___215 *, struct device_attribute___46 *, const char *, size_t);
};

struct irq_domain_ops___61;

struct irq_domain_chip_generic___61;

struct irq_data___63;

struct irq_domain___61 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___61 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___211 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___61 *gc;
	struct irq_domain___61 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___63 *revmap[0];
};

struct fwnode_operations___211;

struct fwnode_handle___211 {
	struct fwnode_handle___211 *secondary;
	const struct fwnode_operations___211 *ops;
	struct device___215 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___72;

struct device_node___96 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___211 fwnode;
	struct property___72 *properties;
	struct property___72 *deadprops;
	struct device_node___96 *parent;
	struct device_node___96 *child;
	struct device_node___96 *sibling;
	struct kobject___224 kobj;
	long unsigned int _flags;
	void *data;
};

struct sdio_device_id {
	__u8 class;
	__u16 vendor;
	__u16 device;
	kernel_ulong_t driver_data;
};

struct fwnode_reference_args___211;

struct fwnode_endpoint___211;

struct fwnode_operations___211 {
	struct fwnode_handle___211 * (*get)(struct fwnode_handle___211 *);
	void (*put)(struct fwnode_handle___211 *);
	bool (*device_is_available)(const struct fwnode_handle___211 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___211 *, const struct device___215 *);
	bool (*property_present)(const struct fwnode_handle___211 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___211 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___211 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___211 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*get_parent)(const struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*get_next_child_node)(const struct fwnode_handle___211 *, struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*get_named_child_node)(const struct fwnode_handle___211 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___211 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___211 *);
	struct fwnode_handle___211 * (*graph_get_next_endpoint)(const struct fwnode_handle___211 *, struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*graph_get_remote_endpoint)(const struct fwnode_handle___211 *);
	struct fwnode_handle___211 * (*graph_get_port_parent)(struct fwnode_handle___211 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___211 *, struct fwnode_endpoint___211 *);
	int (*add_links)(struct fwnode_handle___211 *);
};

struct fwnode_endpoint___211 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___211 *local_fwnode;
};

struct fwnode_reference_args___211 {
	struct fwnode_handle___211 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct property___72 {
	char *name;
	int length;
	void *value;
	struct property___72 *next;
	long unsigned int _flags;
	struct bin_attribute___224 attr;
};

struct irq_desc___63;

typedef void (*irq_flow_handler_t___63)(struct irq_desc___63 *);

struct irq_chip___63;

struct irq_data___63 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___63 *chip;
	struct irq_domain___61 *domain;
	struct irq_data___63 *parent_data;
	void *chip_data;
};

struct irqaction___45;

struct irq_desc___63 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___63 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___63 handle_irq;
	struct irqaction___45 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___224 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___220 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_fwspec___59 {
	struct fwnode_handle___211 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___61 {
	int (*match)(struct irq_domain___61 *, struct device_node___96 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___61 *, struct irq_fwspec___59 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___61 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___61 *, unsigned int);
	int (*xlate)(struct irq_domain___61 *, struct device_node___96 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___61 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___61 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___61 *, struct irq_data___63 *, bool);
	void (*deactivate)(struct irq_domain___61 *, struct irq_data___63 *);
	int (*translate)(struct irq_domain___61 *, struct irq_fwspec___59 *, long unsigned int *, unsigned int *);
};

struct irq_chip_generic___61;

struct irq_domain_chip_generic___61 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___61 *gc[0];
};

struct dentry_operations___236;

struct dentry___236 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___236 *d_parent;
	struct qstr d_name;
	struct inode___236 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___236 *d_op;
	struct super_block___236 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___236;

struct cdev___64;

struct inode___236 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___236 *i_op;
	struct super_block___236 *i_sb;
	struct address_space___236 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___237 *i_fop;
		void (*free_inode)(struct inode___236 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___236 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___64 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___236 {
	int (*d_revalidate)(struct dentry___236 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___236 *, unsigned int);
	int (*d_hash)(const struct dentry___236 *, struct qstr *);
	int (*d_compare)(const struct dentry___236 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___236 *);
	int (*d_init)(struct dentry___236 *);
	void (*d_release)(struct dentry___236 *);
	void (*d_prune)(struct dentry___236 *);
	void (*d_iput)(struct dentry___236 *, struct inode___236 *);
	char * (*d_dname)(struct dentry___236 *, char *, int);
	struct vfsmount___236 * (*d_automount)(struct path___236 *);
	int (*d_manage)(const struct path___236 *, bool);
	struct dentry___236 * (*d_real)(struct dentry___236 *, const struct inode___236 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___236;

struct mem_dqinfo___236 {
	struct quota_format_type___236 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___236;

struct quota_info___236 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___236 *files[3];
	struct mem_dqinfo___236 info[3];
	const struct quota_format_ops___236 *ops[3];
};

struct rcuwait___237 {
	struct task_struct___243 *task;
};

struct percpu_rw_semaphore___237 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___237 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___236 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___237 rw_sem[3];
};

struct super_operations___236;

struct dquot_operations___236;

struct quotactl_ops___236;

struct block_device___132;

struct super_block___236 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___236 *s_type;
	const struct super_operations___236 *s_op;
	const struct dquot_operations___236 *dq_op;
	const struct quotactl_ops___236 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___236 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___132 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___236 s_dquot;
	struct sb_writers___236 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___236 *s_d_op;
	int cleancache_poolid;
	struct shrinker___104 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___236 {
	struct dentry___236 *mnt_root;
	struct super_block___236 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___129 {
	struct request_queue___129 *q;
	struct io_context___129 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___236 {
	struct file___236 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___236 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___113 *ki_waitq;
	};
};

struct iattr___236 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___236 *ia_file;
};

struct dquot___236 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___236 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___236 {
	int qf_fmt_id;
	const struct quota_format_ops___236 *qf_ops;
	struct module___220 *qf_owner;
	struct quota_format_type___236 *qf_next;
};

struct quota_format_ops___236 {
	int (*check_quota_file)(struct super_block___236 *, int);
	int (*read_file_info)(struct super_block___236 *, int);
	int (*write_file_info)(struct super_block___236 *, int);
	int (*free_file_info)(struct super_block___236 *, int);
	int (*read_dqblk)(struct dquot___236 *);
	int (*commit_dqblk)(struct dquot___236 *);
	int (*release_dqblk)(struct dquot___236 *);
	int (*get_next_id)(struct super_block___236 *, struct kqid *);
};

struct dquot_operations___236 {
	int (*write_dquot)(struct dquot___236 *);
	struct dquot___236 * (*alloc_dquot)(struct super_block___236 *, int);
	void (*destroy_dquot)(struct dquot___236 *);
	int (*acquire_dquot)(struct dquot___236 *);
	int (*release_dquot)(struct dquot___236 *);
	int (*mark_dirty)(struct dquot___236 *);
	int (*write_info)(struct super_block___236 *, int);
	qsize_t * (*get_reserved_space)(struct inode___236 *);
	int (*get_projid)(struct inode___236 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___236 *, qsize_t *);
	int (*get_next_id)(struct super_block___236 *, struct kqid *);
};

struct quotactl_ops___236 {
	int (*quota_on)(struct super_block___236 *, int, int, const struct path___236 *);
	int (*quota_off)(struct super_block___236 *, int);
	int (*quota_enable)(struct super_block___236 *, unsigned int);
	int (*quota_disable)(struct super_block___236 *, unsigned int);
	int (*quota_sync)(struct super_block___236 *, int);
	int (*set_info)(struct super_block___236 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___236 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___236 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___236 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___236 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___236 *, unsigned int);
};

struct address_space_operations___236 {
	int (*writepage)(struct page___241 *, struct writeback_control___3 *);
	int (*readpage)(struct file___236 *, struct page___241 *);
	int (*writepages)(struct address_space___236 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___241 *);
	int (*readpages)(struct file___236 *, struct address_space___236 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___236 *, struct address_space___236 *, loff_t, unsigned int, unsigned int, struct page___241 **, void **);
	int (*write_end)(struct file___236 *, struct address_space___236 *, loff_t, unsigned int, unsigned int, struct page___241 *, void *);
	sector_t (*bmap)(struct address_space___236 *, sector_t);
	void (*invalidatepage)(struct page___241 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___241 *, gfp_t);
	void (*freepage)(struct page___241 *);
	ssize_t (*direct_IO)(struct kiocb___236 *, struct iov_iter___156 *);
	int (*migratepage)(struct address_space___236 *, struct page___241 *, struct page___241 *, enum migrate_mode);
	bool (*isolate_page)(struct page___241 *, isolate_mode_t);
	void (*putback_page)(struct page___241 *);
	int (*launder_page)(struct page___241 *);
	int (*is_partially_uptodate)(struct page___241 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___241 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___236 *, struct page___241 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___236 *, sector_t *);
	void (*swap_deactivate)(struct file___236 *);
};

struct bio_vec___153;

struct iov_iter___156 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___153 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___64 {
	struct kobject___224 kobj;
	struct module___220 *owner;
	const struct file_operations___237 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___236 {
	struct dentry___236 * (*lookup)(struct inode___236 *, struct dentry___236 *, unsigned int);
	const char * (*get_link)(struct dentry___236 *, struct inode___236 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___236 *, int);
	struct posix_acl * (*get_acl)(struct inode___236 *, int, bool);
	int (*readlink)(struct dentry___236 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___236 *, struct dentry___236 *, umode_t, bool);
	int (*link)(struct dentry___236 *, struct inode___236 *, struct dentry___236 *);
	int (*unlink)(struct inode___236 *, struct dentry___236 *);
	int (*symlink)(struct user_namespace *, struct inode___236 *, struct dentry___236 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___236 *, struct dentry___236 *, umode_t);
	int (*rmdir)(struct inode___236 *, struct dentry___236 *);
	int (*mknod)(struct user_namespace *, struct inode___236 *, struct dentry___236 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___236 *, struct dentry___236 *, struct inode___236 *, struct dentry___236 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___236 *, struct iattr___236 *);
	int (*getattr)(struct user_namespace *, const struct path___236 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___236 *, char *, size_t);
	int (*fiemap)(struct inode___236 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___236 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___236 *, struct dentry___236 *, struct file___236 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___236 *, struct dentry___236 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___236 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___236 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___236 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___236 {
	void (*fl_copy_lock)(struct file_lock___236 *, struct file_lock___236 *);
	void (*fl_release_private)(struct file_lock___236 *);
};

struct fasync_struct___236;

struct lock_manager_operations___236;

struct file_lock___236 {
	struct file_lock___236 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___236 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___236 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___236 *fl_ops;
	const struct lock_manager_operations___236 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___236 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___236 *);
	int (*lm_grant)(struct file_lock___236 *, int);
	bool (*lm_break)(struct file_lock___236 *);
	int (*lm_change)(struct file_lock___236 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___236 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___236 *);
};

struct fasync_struct___236 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___236 *fa_next;
	struct file___236 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___236 {
	struct inode___236 * (*alloc_inode)(struct super_block___236 *);
	void (*destroy_inode)(struct inode___236 *);
	void (*free_inode)(struct inode___236 *);
	void (*dirty_inode)(struct inode___236 *, int);
	int (*write_inode)(struct inode___236 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___236 *);
	void (*evict_inode)(struct inode___236 *);
	void (*put_super)(struct super_block___236 *);
	int (*sync_fs)(struct super_block___236 *, int);
	int (*freeze_super)(struct super_block___236 *);
	int (*freeze_fs)(struct super_block___236 *);
	int (*thaw_super)(struct super_block___236 *);
	int (*unfreeze_fs)(struct super_block___236 *);
	int (*statfs)(struct dentry___236 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___236 *, int *, char *);
	void (*umount_begin)(struct super_block___236 *);
	int (*show_options)(struct seq_file___211 *, struct dentry___236 *);
	int (*show_devname)(struct seq_file___211 *, struct dentry___236 *);
	int (*show_path)(struct seq_file___211 *, struct dentry___236 *);
	int (*show_stats)(struct seq_file___211 *, struct dentry___236 *);
	ssize_t (*quota_read)(struct super_block___236 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___236 *, int, const char *, size_t, loff_t);
	struct dquot___236 ** (*get_dquots)(struct inode___236 *);
	long int (*nr_cached_objects)(struct super_block___236 *, struct shrink_control___104 *);
	long int (*free_cached_objects)(struct super_block___236 *, struct shrink_control___104 *);
	struct file___236 * (*real_loop)(struct file___236 *);
};

struct block_device___132 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___236 *bd_inode;
	struct super_block___236 *bd_super;
	void *bd_claiming;
	struct device___215 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___224 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___132 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___236 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___129(struct bio___129 *);

struct bio_vec___153 {
	struct page___241 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___129;

struct bio___129 {
	struct bio___129 *bi_next;
	struct block_device___132 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___129 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___129 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___153 *bi_io_vec;
	struct bio_set___129 *bi_pool;
	struct bio_vec___153 bi_inline_vecs[0];
};

struct kernel_param_ops___220 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___220 *);
	int (*get)(char *, const struct kernel_param___220 *);
	void (*free)(void *);
};

struct kparam_array___220;

struct kernel_param___220 {
	const char *name;
	struct module___220 *mod;
	const struct kernel_param_ops___220 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___220 *arr;
	};
};

struct kparam_array___220 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___220 *ops;
	void *elem;
};

struct module_attribute___220 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___220 *, struct module_kobject___221 *, char *);
	ssize_t (*store)(struct module_attribute___220 *, struct module_kobject___221 *, const char *, size_t);
	void (*setup)(struct module___220 *, const char *);
	int (*test)(struct module___220 *);
	void (*free)(struct module___220 *);
};

struct acpi_device___20;

struct acpi_hotplug_profile___20 {
	struct kobject___224 kobj;
	int (*scan_dependent)(struct acpi_device___20 *);
	void (*notify_online)(struct acpi_device___20 *);
	bool enabled;
	bool demand_offline;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct acpi_device_wakeup_context___20 {
	void (*func)(struct acpi_device_wakeup_context___20 *);
	struct device___215 *dev;
};

struct acpi_device_wakeup___20 {
	acpi_handle gpe_device;
	u64 gpe_number;
	u64 sleep_state;
	struct list_head resources;
	struct acpi_device_wakeup_flags flags;
	struct acpi_device_wakeup_context___20 context;
	struct wakeup_source___215 *ws;
	int prepare_count;
	int enable_count;
};

struct acpi_scan_handler___20;

struct acpi_hotplug_context___20;

struct acpi_driver___20;

struct acpi_device___20 {
	int device_type;
	acpi_handle handle;
	struct fwnode_handle___211 fwnode;
	struct acpi_device___20 *parent;
	struct list_head children;
	struct list_head node;
	struct list_head wakeup_list;
	struct list_head del_list;
	struct acpi_device_status status;
	struct acpi_device_flags flags;
	struct acpi_device_pnp pnp;
	struct acpi_device_power power;
	struct acpi_device_wakeup___20 wakeup;
	struct acpi_device_perf performance;
	struct acpi_device_dir dir;
	struct acpi_device_data data;
	struct acpi_scan_handler___20 *handler;
	struct acpi_hotplug_context___20 *hp;
	struct acpi_driver___20 *driver;
	const struct acpi_gpio_mapping *driver_gpios;
	void *driver_data;
	struct device___215 dev;
	unsigned int physical_node_count;
	unsigned int dep_unmet;
	struct list_head physical_node_list;
	struct mutex physical_node_lock;
	void (*remove)(struct acpi_device___20 *);
};

struct acpi_scan_handler___20 {
	const struct acpi_device_id *ids;
	struct list_head list_node;
	bool (*match)(const char *, const struct acpi_device_id **);
	int (*attach)(struct acpi_device___20 *, const struct acpi_device_id *);
	void (*detach)(struct acpi_device___20 *);
	void (*bind)(struct device___215 *);
	void (*unbind)(struct device___215 *);
	struct acpi_hotplug_profile___20 hotplug;
};

struct acpi_hotplug_context___20 {
	struct acpi_device___20 *self;
	int (*notify)(struct acpi_device___20 *, u32);
	void (*uevent)(struct acpi_device___20 *, u32);
	void (*fixup)(struct acpi_device___20 *);
};

typedef int (*acpi_op_add___20)(struct acpi_device___20 *);

typedef int (*acpi_op_remove___20)(struct acpi_device___20 *);

typedef void (*acpi_op_notify___20)(struct acpi_device___20 *, u32);

struct acpi_device_ops___20 {
	acpi_op_add___20 add;
	acpi_op_remove___20 remove;
	acpi_op_notify___20 notify;
};

struct acpi_driver___20 {
	char name[80];
	char class[80];
	const struct acpi_device_id *ids;
	unsigned int flags;
	struct acpi_device_ops___20 ops;
	struct device_driver___215 drv;
	struct module___220 *owner;
};

struct irq_chip___63 {
	struct device___215 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___63 *);
	void (*irq_shutdown)(struct irq_data___63 *);
	void (*irq_enable)(struct irq_data___63 *);
	void (*irq_disable)(struct irq_data___63 *);
	void (*irq_ack)(struct irq_data___63 *);
	void (*irq_mask)(struct irq_data___63 *);
	void (*irq_mask_ack)(struct irq_data___63 *);
	void (*irq_unmask)(struct irq_data___63 *);
	void (*irq_eoi)(struct irq_data___63 *);
	int (*irq_set_affinity)(struct irq_data___63 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___63 *);
	int (*irq_set_type)(struct irq_data___63 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___63 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___63 *);
	void (*irq_bus_sync_unlock)(struct irq_data___63 *);
	void (*irq_cpu_online)(struct irq_data___63 *);
	void (*irq_cpu_offline)(struct irq_data___63 *);
	void (*irq_suspend)(struct irq_data___63 *);
	void (*irq_resume)(struct irq_data___63 *);
	void (*irq_pm_shutdown)(struct irq_data___63 *);
	void (*irq_calc_mask)(struct irq_data___63 *);
	void (*irq_print_chip)(struct irq_data___63 *, struct seq_file___211 *);
	int (*irq_request_resources)(struct irq_data___63 *);
	void (*irq_release_resources)(struct irq_data___63 *);
	void (*irq_compose_msi_msg)(struct irq_data___63 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___63 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___63 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___63 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___63 *, void *);
	void (*ipi_send_single)(struct irq_data___63 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___63 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___63 *);
	void (*irq_nmi_teardown)(struct irq_data___63 *);
	long unsigned int flags;
};

struct irqaction___45 {
	irq_handler_t handler;
	void *dev_id;
	void *percpu_dev_id;
	struct irqaction___45 *next;
	irq_handler_t thread_fn;
	struct task_struct___243 *thread;
	struct irqaction___45 *secondary;
	unsigned int irq;
	unsigned int flags;
	long unsigned int thread_flags;
	long unsigned int thread_mask;
	const char *name;
	struct proc_dir_entry *dir;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip_type___61 {
	struct irq_chip___63 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___63 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___61 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___61 *);
	void (*resume)(struct irq_chip_generic___61 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___61 *domain;
	struct list_head list;
	struct irq_chip_type___61 chip_types[0];
};

struct seq_operations___211 {
	void * (*start)(struct seq_file___211 *, loff_t *);
	void (*stop)(struct seq_file___211 *, void *);
	void * (*next)(struct seq_file___211 *, void *, loff_t *);
	int (*show)(struct seq_file___211 *, void *);
};

struct dev_pagemap_ops___231 {
	void (*page_free)(struct page___241 *);
	void (*kill)(struct dev_pagemap___231 *);
	void (*cleanup)(struct dev_pagemap___231 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___231 *);
};

struct mmc_host___4;

struct sdio_func___2;

struct mmc_card___4 {
	struct mmc_host___4 *host;
	struct device___215 dev;
	u32 ocr;
	unsigned int rca;
	unsigned int type;
	unsigned int state;
	unsigned int quirks;
	unsigned int quirk_max_rate;
	bool reenable_cmdq;
	unsigned int erase_size;
	unsigned int erase_shift;
	unsigned int pref_erase;
	unsigned int eg_boundary;
	unsigned int erase_arg;
	u8 erased_byte;
	u32 raw_cid[4];
	u32 raw_csd[4];
	u32 raw_scr[2];
	u32 raw_ssr[16];
	struct mmc_cid cid;
	struct mmc_csd___2 csd;
	struct mmc_ext_csd ext_csd;
	struct sd_scr scr;
	struct sd_ssr ssr;
	struct sd_switch_caps sw_caps;
	struct sd_ext_reg ext_power;
	struct sd_ext_reg ext_perf;
	unsigned int sdio_funcs;
	atomic_t sdio_funcs_probed;
	struct sdio_cccr cccr;
	struct sdio_cis cis;
	struct sdio_func___2 *sdio_func[7];
	struct sdio_func___2 *sdio_single_irq;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
	unsigned int sd_bus_speed;
	unsigned int mmc_avail_type;
	unsigned int drive_strength;
	struct dentry___236 *debugfs_root;
	struct mmc_part part[7];
	unsigned int nr_parts;
	struct workqueue_struct *complete_wq;
};

struct mmc_ctx___4 {
	struct task_struct___243 *task;
};

struct blk_ksm_ll_ops___7 {
	int (*keyslot_program)(struct blk_keyslot_manager___7 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___7 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___7 {
	struct blk_ksm_ll_ops___7 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___215 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct mmc_host_ops___4;

struct mmc_bus_ops___4;

struct mmc_request___4;

struct mmc_cqe_ops___4;

struct mmc_host___4 {
	struct device___215 *parent;
	struct device___215 class_dev;
	int index;
	const struct mmc_host_ops___4 *ops;
	struct mmc_pwrseq___2 *pwrseq;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct wakeup_source___215 *ws;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	int fixed_drv_type;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_busy_timeout;
	spinlock_t lock;
	struct mmc_ios ios;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int doing_init_tune: 1;
	unsigned int can_retune: 1;
	unsigned int doing_retune: 1;
	unsigned int retune_now: 1;
	unsigned int retune_paused: 1;
	unsigned int retune_crc_disable: 1;
	unsigned int can_dma_map_merge: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int rescan_disable;
	int rescan_entered;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct timer_list retune_timer;
	bool trigger_card_event;
	struct mmc_card___4 *card;
	wait_queue_head_t wq;
	struct mmc_ctx___4 *claimer;
	int claim_cnt;
	struct mmc_ctx___4 default_ctx;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops___4 *bus_ops;
	unsigned int sdio_irqs;
	struct task_struct___243 *sdio_irq_thread;
	struct delayed_work sdio_irq_work;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___11 *led;
	bool regulator_enabled;
	struct mmc_supply supply;
	struct dentry___236 *debugfs_root;
	struct mmc_request___4 *ongoing_mrq;
	unsigned int actual_clock;
	unsigned int slotno;
	int dsr_req;
	u32 dsr;
	const struct mmc_cqe_ops___4 *cqe_ops;
	void *cqe_private;
	int cqe_qdepth;
	bool cqe_enabled;
	bool cqe_on;
	struct blk_keyslot_manager___7 ksm;
	bool hsq_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

typedef void sdio_irq_handler_t___2(struct sdio_func___2 *);

struct sdio_func___2 {
	struct mmc_card___4 *card;
	struct device___215 dev;
	sdio_irq_handler_t___2 *irq_handler;
	unsigned int num;
	unsigned char class;
	short unsigned int vendor;
	short unsigned int device;
	unsigned int max_blksize;
	unsigned int cur_blksize;
	unsigned int enable_timeout;
	unsigned int state;
	u8 *tmpbuf;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
};

struct mmc_data___4;

struct mmc_command___4 {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	int error;
	unsigned int busy_timeout;
	struct mmc_data___4 *data;
	struct mmc_request___4 *mrq;
};

struct mmc_data___4 {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int blk_addr;
	int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command___4 *stop;
	struct mmc_request___4 *mrq;
	unsigned int sg_len;
	int sg_count;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_request___4 {
	struct mmc_command___4 *sbc;
	struct mmc_command___4 *cmd;
	struct mmc_data___4 *data;
	struct mmc_command___4 *stop;
	struct completion completion;
	struct completion cmd_completion;
	void (*done)(struct mmc_request___4 *);
	void (*recovery_notifier)(struct mmc_request___4 *);
	struct mmc_host___4 *host;
	bool cap_cmd_during_tfr;
	int tag;
	const struct bio_crypt_ctx *crypto_ctx;
	int crypto_key_slot;
};

struct block_device_operations___129;

struct gendisk___132 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___132 *part0;
	const struct block_device_operations___129 *fops;
	struct request_queue___129 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___224 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___224 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___129 {
	struct bio___129 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___153 *bip_vec;
	struct bio_vec___153 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___129(struct request___129 *);

typedef void integrity_complete_fn___129(struct request___129 *, unsigned int);

struct blk_integrity_profile___129 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___129 *prepare_fn;
	integrity_complete_fn___129 *complete_fn;
	const char *name;
};

struct block_device_operations___129 {
	blk_qc_t (*submit_bio)(struct bio___129 *);
	int (*open)(struct block_device___132 *, fmode_t);
	void (*release)(struct gendisk___132 *, fmode_t);
	int (*rw_page)(struct block_device___132 *, sector_t, struct page___241 *, unsigned int);
	int (*ioctl)(struct block_device___132 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___132 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___132 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___132 *);
	int (*getgeo)(struct block_device___132 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___132 *, bool);
	void (*swap_slot_free_notify)(struct block_device___132 *, long unsigned int);
	int (*report_zones)(struct gendisk___132 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___132 *, umode_t *);
	struct module___220 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___132 *, sector_t *);
};

typedef void rq_end_io_fn___129(struct request___129 *, blk_status_t);

struct request___129 {
	struct request_queue___129 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___3 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___129 *bio;
	struct bio___129 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___153 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___129 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___129 *saved_end_io;
		} flush;
	};
	struct gendisk___132 *rq_disk;
	struct block_device___132 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___129 *end_io;
	void *end_io_data;
};

struct elevator_type___129;

struct elevator_mq_ops___129 {
	int (*init_sched)(struct request_queue___129 *, struct elevator_type___129 *);
	void (*exit_sched)(struct elevator_queue___129 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___3 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___3 *);
	bool (*allow_merge)(struct request_queue___129 *, struct request___129 *, struct bio___129 *);
	bool (*bio_merge)(struct request_queue___129 *, struct bio___129 *, unsigned int);
	int (*request_merge)(struct request_queue___129 *, struct request___129 **, struct bio___129 *);
	void (*request_merged)(struct request_queue___129 *, struct request___129 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___129 *, struct request___129 *, struct request___129 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___129 *);
	void (*finish_request)(struct request___129 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___3 *, struct list_head *, bool);
	struct request___129 * (*dispatch_request)(struct blk_mq_hw_ctx___3 *);
	bool (*has_work)(struct blk_mq_hw_ctx___3 *);
	void (*completed_request)(struct request___129 *, u64);
	void (*requeue_request)(struct request___129 *);
	struct request___129 * (*former_request)(struct request_queue___129 *, struct request___129 *);
	struct request___129 * (*next_request)(struct request_queue___129 *, struct request___129 *);
	void (*init_icq)(struct io_cq___129 *);
	void (*exit_icq)(struct io_cq___129 *);
};

struct elv_fs_entry___129;

struct elevator_type___129 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___129 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___129 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___220 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___129 {
	struct elevator_type___129 *type;
	void *elevator_data;
	struct kobject___224 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___129 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___129 *, char *);
	ssize_t (*store)(struct elevator_queue___129 *, const char *, size_t);
};

struct mmc_host_ops___4 {
	void (*post_req)(struct mmc_host___4 *, struct mmc_request___4 *, int);
	void (*pre_req)(struct mmc_host___4 *, struct mmc_request___4 *);
	void (*request)(struct mmc_host___4 *, struct mmc_request___4 *);
	int (*request_atomic)(struct mmc_host___4 *, struct mmc_request___4 *);
	void (*set_ios)(struct mmc_host___4 *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host___4 *);
	int (*get_cd)(struct mmc_host___4 *);
	void (*enable_sdio_irq)(struct mmc_host___4 *, int);
	void (*ack_sdio_irq)(struct mmc_host___4 *);
	void (*init_card)(struct mmc_host___4 *, struct mmc_card___4 *);
	int (*start_signal_voltage_switch)(struct mmc_host___4 *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host___4 *);
	int (*execute_tuning)(struct mmc_host___4 *, u32);
	int (*prepare_hs400_tuning)(struct mmc_host___4 *, struct mmc_ios *);
	int (*hs400_prepare_ddr)(struct mmc_host___4 *);
	void (*hs400_downgrade)(struct mmc_host___4 *);
	void (*hs400_complete)(struct mmc_host___4 *);
	void (*hs400_enhanced_strobe)(struct mmc_host___4 *, struct mmc_ios *);
	int (*select_drive_strength)(struct mmc_card___4 *, unsigned int, int, int, int *);
	void (*hw_reset)(struct mmc_host___4 *);
	void (*card_event)(struct mmc_host___4 *);
	int (*multi_io_quirk)(struct mmc_card___4 *, unsigned int, int);
	int (*init_sd_express)(struct mmc_host___4 *, struct mmc_ios *);
};

struct mmc_cqe_ops___4 {
	int (*cqe_enable)(struct mmc_host___4 *, struct mmc_card___4 *);
	void (*cqe_disable)(struct mmc_host___4 *);
	int (*cqe_request)(struct mmc_host___4 *, struct mmc_request___4 *);
	void (*cqe_post_req)(struct mmc_host___4 *, struct mmc_request___4 *);
	void (*cqe_off)(struct mmc_host___4 *);
	int (*cqe_wait_for_idle)(struct mmc_host___4 *);
	bool (*cqe_timeout)(struct mmc_host___4 *, struct mmc_request___4 *, bool *);
	void (*cqe_recovery_start)(struct mmc_host___4 *);
	void (*cqe_recovery_finish)(struct mmc_host___4 *);
};

struct mmc_bus_ops___4 {
	void (*remove)(struct mmc_host___4 *);
	void (*detect)(struct mmc_host___4 *);
	int (*pre_suspend)(struct mmc_host___4 *);
	int (*suspend)(struct mmc_host___4 *);
	int (*resume)(struct mmc_host___4 *);
	int (*runtime_suspend)(struct mmc_host___4 *);
	int (*runtime_resume)(struct mmc_host___4 *);
	int (*alive)(struct mmc_host___4 *);
	int (*shutdown)(struct mmc_host___4 *);
	int (*hw_reset)(struct mmc_host___4 *);
	int (*sw_reset)(struct mmc_host___4 *);
	bool (*cache_enabled)(struct mmc_host___4 *);
	int (*flush_cache)(struct mmc_host___4 *);
};

struct sdio_driver {
	char *name;
	const struct sdio_device_id *id_table;
	int (*probe)(struct sdio_func___2 *, const struct sdio_device_id *);
	void (*remove)(struct sdio_func___2 *);
	struct device_driver___215 drv;
};

typedef int tpl_parse_t(struct mmc_card___3 *, struct sdio_func *, const unsigned char *, unsigned int);

struct cis_tpl {
	unsigned char code;
	unsigned char min_size;
	tpl_parse_t *parse;
};

struct mmc_gpio {
	struct gpio_desc *ro_gpio;
	struct gpio_desc *cd_gpio;
	irqreturn_t (*cd_gpio_isr)(int, void *);
	char *ro_label;
	char *cd_label;
	u32 cd_debounce_delay_ms;
};

struct mmc_data___5;

struct mmc_request___5;

struct mmc_command___5 {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	int error;
	unsigned int busy_timeout;
	struct mmc_data___5 *data;
	struct mmc_request___5 *mrq;
};

struct mmc_data___5 {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int blk_addr;
	int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command___5 *stop;
	struct mmc_request___5 *mrq;
	unsigned int sg_len;
	int sg_count;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_host___5;

struct mmc_request___5 {
	struct mmc_command___5 *sbc;
	struct mmc_command___5 *cmd;
	struct mmc_data___5 *data;
	struct mmc_command___5 *stop;
	struct completion completion;
	struct completion cmd_completion;
	void (*done)(struct mmc_request___5 *);
	void (*recovery_notifier)(struct mmc_request___5 *);
	struct mmc_host___5 *host;
	bool cap_cmd_during_tfr;
	int tag;
	const struct bio_crypt_ctx *crypto_ctx;
	int crypto_key_slot;
};

struct mmc_host_ops___5;

struct mmc_pwrseq___3;

struct mmc_card___5;

struct mmc_cqe_ops___5;

struct mmc_host___5 {
	struct device___215 *parent;
	struct device___215 class_dev;
	int index;
	const struct mmc_host_ops___5 *ops;
	struct mmc_pwrseq___3 *pwrseq;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct wakeup_source___215 *ws;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	int fixed_drv_type;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_busy_timeout;
	spinlock_t lock;
	struct mmc_ios ios;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int doing_init_tune: 1;
	unsigned int can_retune: 1;
	unsigned int doing_retune: 1;
	unsigned int retune_now: 1;
	unsigned int retune_paused: 1;
	unsigned int retune_crc_disable: 1;
	unsigned int can_dma_map_merge: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int rescan_disable;
	int rescan_entered;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct timer_list retune_timer;
	bool trigger_card_event;
	struct mmc_card___5 *card;
	wait_queue_head_t wq;
	struct mmc_ctx___4 *claimer;
	int claim_cnt;
	struct mmc_ctx___4 default_ctx;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops___3 *bus_ops;
	unsigned int sdio_irqs;
	struct task_struct___243 *sdio_irq_thread;
	struct delayed_work sdio_irq_work;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___11 *led;
	bool regulator_enabled;
	struct mmc_supply supply;
	struct dentry___236 *debugfs_root;
	struct mmc_request___5 *ongoing_mrq;
	unsigned int actual_clock;
	unsigned int slotno;
	int dsr_req;
	u32 dsr;
	const struct mmc_cqe_ops___5 *cqe_ops;
	void *cqe_private;
	int cqe_qdepth;
	bool cqe_enabled;
	bool cqe_on;
	struct blk_keyslot_manager___7 ksm;
	bool hsq_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct mmc_card___5 {
	struct mmc_host___5 *host;
	struct device___215 dev;
	u32 ocr;
	unsigned int rca;
	unsigned int type;
	unsigned int state;
	unsigned int quirks;
	unsigned int quirk_max_rate;
	bool reenable_cmdq;
	unsigned int erase_size;
	unsigned int erase_shift;
	unsigned int pref_erase;
	unsigned int eg_boundary;
	unsigned int erase_arg;
	u8 erased_byte;
	u32 raw_cid[4];
	u32 raw_csd[4];
	u32 raw_scr[2];
	u32 raw_ssr[16];
	struct mmc_cid cid;
	struct mmc_csd___2 csd;
	struct mmc_ext_csd ext_csd;
	struct sd_scr scr;
	struct sd_ssr ssr;
	struct sd_switch_caps sw_caps;
	struct sd_ext_reg ext_power;
	struct sd_ext_reg ext_perf;
	unsigned int sdio_funcs;
	atomic_t sdio_funcs_probed;
	struct sdio_cccr cccr;
	struct sdio_cis cis;
	struct sdio_func *sdio_func[7];
	struct sdio_func *sdio_single_irq;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
	unsigned int sd_bus_speed;
	unsigned int mmc_avail_type;
	unsigned int drive_strength;
	struct dentry___236 *debugfs_root;
	struct mmc_part part[7];
	unsigned int nr_parts;
	struct workqueue_struct *complete_wq;
};

struct mmc_host_ops___5 {
	void (*post_req)(struct mmc_host___5 *, struct mmc_request___5 *, int);
	void (*pre_req)(struct mmc_host___5 *, struct mmc_request___5 *);
	void (*request)(struct mmc_host___5 *, struct mmc_request___5 *);
	int (*request_atomic)(struct mmc_host___5 *, struct mmc_request___5 *);
	void (*set_ios)(struct mmc_host___5 *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host___5 *);
	int (*get_cd)(struct mmc_host___5 *);
	void (*enable_sdio_irq)(struct mmc_host___5 *, int);
	void (*ack_sdio_irq)(struct mmc_host___5 *);
	void (*init_card)(struct mmc_host___5 *, struct mmc_card___5 *);
	int (*start_signal_voltage_switch)(struct mmc_host___5 *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host___5 *);
	int (*execute_tuning)(struct mmc_host___5 *, u32);
	int (*prepare_hs400_tuning)(struct mmc_host___5 *, struct mmc_ios *);
	int (*hs400_prepare_ddr)(struct mmc_host___5 *);
	void (*hs400_downgrade)(struct mmc_host___5 *);
	void (*hs400_complete)(struct mmc_host___5 *);
	void (*hs400_enhanced_strobe)(struct mmc_host___5 *, struct mmc_ios *);
	int (*select_drive_strength)(struct mmc_card___5 *, unsigned int, int, int, int *);
	void (*hw_reset)(struct mmc_host___5 *);
	void (*card_event)(struct mmc_host___5 *);
	int (*multi_io_quirk)(struct mmc_card___5 *, unsigned int, int);
	int (*init_sd_express)(struct mmc_host___5 *, struct mmc_ios *);
};

struct mmc_cqe_ops___5 {
	int (*cqe_enable)(struct mmc_host___5 *, struct mmc_card___5 *);
	void (*cqe_disable)(struct mmc_host___5 *);
	int (*cqe_request)(struct mmc_host___5 *, struct mmc_request___5 *);
	void (*cqe_post_req)(struct mmc_host___5 *, struct mmc_request___5 *);
	void (*cqe_off)(struct mmc_host___5 *);
	int (*cqe_wait_for_idle)(struct mmc_host___5 *);
	bool (*cqe_timeout)(struct mmc_host___5 *, struct mmc_request___5 *, bool *);
	void (*cqe_recovery_start)(struct mmc_host___5 *);
	void (*cqe_recovery_finish)(struct mmc_host___5 *);
};

struct mmc_pwrseq_ops___3;

struct mmc_pwrseq___3 {
	const struct mmc_pwrseq_ops___3 *ops;
	struct device___215 *dev;
	struct list_head pwrseq_node;
	struct module___220 *owner;
};

struct mmc_pwrseq_ops___3 {
	void (*pre_power_on)(struct mmc_host___5 *);
	void (*post_power_on)(struct mmc_host___5 *);
	void (*power_off)(struct mmc_host___5 *);
	void (*reset)(struct mmc_host___5 *);
};

enum mmc_issue_type {
	MMC_ISSUE_SYNC = 0,
	MMC_ISSUE_DCMD = 1,
	MMC_ISSUE_ASYNC = 2,
	MMC_ISSUE_MAX = 3,
};

struct mmc_blk_request {
	struct mmc_request___4 mrq;
	struct mmc_command___4 sbc;
	struct mmc_command___4 cmd;
	struct mmc_command___4 stop;
	struct mmc_data___4 data;
};

enum mmc_drv_op {
	MMC_DRV_OP_IOCTL = 0,
	MMC_DRV_OP_IOCTL_RPMB = 1,
	MMC_DRV_OP_BOOT_WP = 2,
	MMC_DRV_OP_GET_CARD_STATUS = 3,
	MMC_DRV_OP_GET_EXT_CSD = 4,
};

struct mmc_queue_req {
	struct mmc_blk_request brq;
	struct scatterlist *sg;
	enum mmc_drv_op drv_op;
	int drv_op_result;
	void *drv_op_data;
	unsigned int ioc_count;
	int retries;
};

struct dentry___237;

struct super_block___237;

struct module___221;

struct file_system_type___237 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___237 * (*mount)(struct file_system_type___237 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___237 *);
	struct module___221 *owner;
	struct file_system_type___237 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___237;

struct kiocb___237;

struct iov_iter___157;

struct vm_area_struct___242;

struct inode___237;

struct file_lock___237;

struct page___242;

struct seq_file___212;

struct file_operations___238 {
	struct module___221 *owner;
	loff_t (*llseek)(struct file___237 *, loff_t, int);
	ssize_t (*read)(struct file___237 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___237 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___237 *, struct iov_iter___157 *);
	ssize_t (*write_iter)(struct kiocb___237 *, struct iov_iter___157 *);
	int (*iopoll)(struct kiocb___237 *, bool);
	int (*iterate)(struct file___237 *, struct dir_context *);
	int (*iterate_shared)(struct file___237 *, struct dir_context *);
	__poll_t (*poll)(struct file___237 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___237 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___237 *, struct vm_area_struct___242 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___237 *, struct file___237 *);
	int (*flush)(struct file___237 *, fl_owner_t);
	int (*release)(struct inode___237 *, struct file___237 *);
	int (*fsync)(struct file___237 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___237 *, int);
	int (*lock)(struct file___237 *, int, struct file_lock___237 *);
	ssize_t (*sendpage)(struct file___237 *, struct page___242 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___237 *, long unsigned int);
	int (*flock)(struct file___237 *, int, struct file_lock___237 *);
	ssize_t (*splice_write)(struct pipe_inode_info___2 *, struct file___237 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___237 *, loff_t *, struct pipe_inode_info___2 *, size_t, unsigned int);
	int (*setlease)(struct file___237 *, long int, struct file_lock___237 **, void **);
	long int (*fallocate)(struct file___237 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___212 *, struct file___237 *);
	ssize_t (*copy_file_range)(struct file___237 *, loff_t, struct file___237 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___237 *, loff_t, struct file___237 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___237 *, loff_t, loff_t, int);
};

struct kernel_param___221;

struct kernel_param_ops___221 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___221 *);
	int (*get)(char *, const struct kernel_param___221 *);
	void (*free)(void *);
};

struct kparam_array___221;

struct kernel_param___221 {
	const char *name;
	struct module___221 *mod;
	const struct kernel_param_ops___221 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___221 *arr;
	};
};

struct kparam_array___221 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___221 *ops;
	void *elem;
};

struct kset___225;

struct kobj_type___225;

struct kernfs_node___225;

struct kobject___225 {
	const char *name;
	struct list_head entry;
	struct kobject___225 *parent;
	struct kset___225 *kset;
	struct kobj_type___225 *ktype;
	struct kernfs_node___225 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___222 {
	struct kobject___225 kobj;
	struct module___221 *mod;
	struct kobject___225 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___221 {
	struct module___221 *mod;
	struct latch_tree_node node;
};

struct module_layout___221 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___221 mtn;
};

struct module_attribute___221;

struct module___221 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___222 mkobj;
	struct module_attribute___221 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___225 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___221 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___221 core_layout;
	struct module_layout___221 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___242 {
	u64 seqnum;
	struct vm_area_struct___242 *vmas[4];
};

struct page_frag___242 {
	struct page___242 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___243;

struct pid___214;

struct nsproxy___223;

struct signal_struct___238;

struct bio_list___130;

struct io_context___130;

struct request_queue___130;

struct vm_struct___220;

struct task_struct___244 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___244 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___243 *mm;
	struct mm_struct___243 *active_mm;
	struct vmacache___242 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___244 *real_parent;
	struct task_struct___244 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___244 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___214 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___223 *nsproxy;
	struct signal_struct___238 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___244 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___130 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___130 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___2 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	long: 64;
	long: 64;
	struct pipe_inode_info___2 *splice_pipe;
	struct page_frag___242 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___130 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___244 *oom_reaper_list;
	struct vm_struct___220 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___214;

struct upid___214 {
	int nr;
	struct pid_namespace___214 *ns;
};

struct pid_namespace___214 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___244 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___214 *parent;
	struct fs_pin *bacct;
	struct user_namespace *user_ns;
	struct ucounts *ucounts;
	int reboot;
	struct ns_common___15 ns;
};

struct pid___214 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___214 numbers[1];
};

typedef struct page___242 *pgtable_t___242;

struct address_space___237;

struct dev_pagemap___232;

struct page___242 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___237 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___66 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___242 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___242 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___243 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___232 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___232;

struct vm_area_struct___242 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___242 *vm_next;
	struct vm_area_struct___242 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___243 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___232 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___237 *vm_file;
	struct file___237 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___238 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___244 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___244 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___214 *pids[4];
	struct pid___214 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___243 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___242;

struct mm_struct___243 {
	struct {
		struct vm_area_struct___242 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___237 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___242 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___244 *owner;
		struct user_namespace *user_ns;
		struct file___237 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct nsproxy___223 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___214 *pid_ns_for_children;
	struct net *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___2 *cgroup_ns;
};

struct bio___130;

struct bio_list___130 {
	struct bio___130 *head;
	struct bio___130 *tail;
};

struct io_cq___130;

struct io_context___130 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___130 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct blk_integrity_profile___130;

struct blk_integrity___130 {
	const struct blk_integrity_profile___130 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___130 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___130 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___130;

struct elevator_queue___130;

struct blk_mq_ops___125;

struct blk_mq_hw_ctx___125;

struct gendisk___133;

struct device___216;

struct blk_keyslot_manager___8;

struct blk_mq_tag_set___125;

struct request_queue___130 {
	struct request___130 *last_merge;
	struct elevator_queue___130 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___125 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___125 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___133 *disk;
	struct kobject___225 kobj;
	struct kobject___225 *mq_kobj;
	struct blk_integrity___130 integrity;
	struct device___216 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager___8 *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___3 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___125 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___130 bio_split;
	struct dentry___237 *debugfs_dir;
	struct dentry___237 *sched_debugfs_dir;
	struct dentry___237 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___220 {
	struct vm_struct___220 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___242 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___237;

struct address_space___237 {
	struct inode___237 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___237 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct dev_pagemap_ops___232;

struct dev_pagemap___232 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___232 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___237;

struct path___237 {
	struct vfsmount___237 *mnt;
	struct dentry___237 *dentry;
};

struct fown_struct___214 {
	rwlock_t lock;
	struct pid___214 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___237 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	long: 64;
	long: 64;
	struct path___237 f_path;
	struct inode___237 *f_inode;
	const struct file_operations___238 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___214 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___237 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___232;

struct vm_operations_struct___232 {
	void (*open)(struct vm_area_struct___242 *);
	void (*close)(struct vm_area_struct___242 *);
	int (*may_split)(struct vm_area_struct___242 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___242 *);
	int (*mprotect)(struct vm_area_struct___242 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___232 *);
	vm_fault_t (*huge_fault)(struct vm_fault___232 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___232 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___242 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___232 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___232 *);
	int (*access)(struct vm_area_struct___242 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___242 *);
	int (*set_policy)(struct vm_area_struct___242 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___242 *, long unsigned int);
	struct page___242 * (*find_special_page)(struct vm_area_struct___242 *, long unsigned int);
};

struct core_thread___242 {
	struct task_struct___244 *task;
	struct core_thread___242 *next;
};

struct core_state___242 {
	atomic_t nr_threads;
	struct core_thread___242 dumper;
	struct completion startup;
};

struct vm_fault___232 {
	const struct {
		struct vm_area_struct___242 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___242 *cow_page;
	struct page___242 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___242 prealloc_pte;
};

struct dentry_operations___237;

struct dentry___237 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___237 *d_parent;
	struct qstr d_name;
	struct inode___237 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___237 *d_op;
	struct super_block___237 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___237;

struct cdev___65;

struct inode___237 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___237 *i_op;
	struct super_block___237 *i_sb;
	struct address_space___237 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	long: 64;
	long: 64;
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___238 *i_fop;
		void (*free_inode)(struct inode___237 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___237 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___2 *i_pipe;
		struct cdev___65 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___237 {
	int (*d_revalidate)(struct dentry___237 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___237 *, unsigned int);
	int (*d_hash)(const struct dentry___237 *, struct qstr *);
	int (*d_compare)(const struct dentry___237 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___237 *);
	int (*d_init)(struct dentry___237 *);
	void (*d_release)(struct dentry___237 *);
	void (*d_prune)(struct dentry___237 *);
	void (*d_iput)(struct dentry___237 *, struct inode___237 *);
	char * (*d_dname)(struct dentry___237 *, char *, int);
	struct vfsmount___237 * (*d_automount)(struct path___237 *);
	int (*d_manage)(const struct path___237 *, bool);
	struct dentry___237 * (*d_real)(struct dentry___237 *, const struct inode___237 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___237;

struct mem_dqinfo___237 {
	struct quota_format_type___237 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___237;

struct quota_info___237 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___237 *files[3];
	struct mem_dqinfo___237 info[3];
	const struct quota_format_ops___237 *ops[3];
};

struct rcuwait___238 {
	struct task_struct___244 *task;
};

struct percpu_rw_semaphore___238 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___238 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___237 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___238 rw_sem[3];
};

struct super_operations___237;

struct dquot_operations___237;

struct quotactl_ops___237;

struct block_device___133;

struct super_block___237 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___237 *s_type;
	const struct super_operations___237 *s_op;
	const struct dquot_operations___237 *dq_op;
	const struct quotactl_ops___237 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___237 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___133 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___237 s_dquot;
	struct sb_writers___237 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___237 *s_d_op;
	int cleancache_poolid;
	struct shrinker___104 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___237 {
	struct dentry___237 *mnt_root;
	struct super_block___237 *mnt_sb;
	int mnt_flags;
	struct user_namespace *mnt_userns;
};

struct io_cq___130 {
	struct request_queue___130 *q;
	struct io_context___130 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___237 {
	struct file___237 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___237 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___113 *ki_waitq;
	};
};

struct iattr___237 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___237 *ia_file;
};

struct dquot___237 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___237 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___237 {
	int qf_fmt_id;
	const struct quota_format_ops___237 *qf_ops;
	struct module___221 *qf_owner;
	struct quota_format_type___237 *qf_next;
};

struct quota_format_ops___237 {
	int (*check_quota_file)(struct super_block___237 *, int);
	int (*read_file_info)(struct super_block___237 *, int);
	int (*write_file_info)(struct super_block___237 *, int);
	int (*free_file_info)(struct super_block___237 *, int);
	int (*read_dqblk)(struct dquot___237 *);
	int (*commit_dqblk)(struct dquot___237 *);
	int (*release_dqblk)(struct dquot___237 *);
	int (*get_next_id)(struct super_block___237 *, struct kqid *);
};

struct dquot_operations___237 {
	int (*write_dquot)(struct dquot___237 *);
	struct dquot___237 * (*alloc_dquot)(struct super_block___237 *, int);
	void (*destroy_dquot)(struct dquot___237 *);
	int (*acquire_dquot)(struct dquot___237 *);
	int (*release_dquot)(struct dquot___237 *);
	int (*mark_dirty)(struct dquot___237 *);
	int (*write_info)(struct super_block___237 *, int);
	qsize_t * (*get_reserved_space)(struct inode___237 *);
	int (*get_projid)(struct inode___237 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___237 *, qsize_t *);
	int (*get_next_id)(struct super_block___237 *, struct kqid *);
};

struct quotactl_ops___237 {
	int (*quota_on)(struct super_block___237 *, int, int, const struct path___237 *);
	int (*quota_off)(struct super_block___237 *, int);
	int (*quota_enable)(struct super_block___237 *, unsigned int);
	int (*quota_disable)(struct super_block___237 *, unsigned int);
	int (*quota_sync)(struct super_block___237 *, int);
	int (*set_info)(struct super_block___237 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___237 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___237 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___237 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___237 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___237 *, unsigned int);
};

struct address_space_operations___237 {
	int (*writepage)(struct page___242 *, struct writeback_control___3 *);
	int (*readpage)(struct file___237 *, struct page___242 *);
	int (*writepages)(struct address_space___237 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___242 *);
	int (*readpages)(struct file___237 *, struct address_space___237 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___237 *, struct address_space___237 *, loff_t, unsigned int, unsigned int, struct page___242 **, void **);
	int (*write_end)(struct file___237 *, struct address_space___237 *, loff_t, unsigned int, unsigned int, struct page___242 *, void *);
	sector_t (*bmap)(struct address_space___237 *, sector_t);
	void (*invalidatepage)(struct page___242 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___242 *, gfp_t);
	void (*freepage)(struct page___242 *);
	ssize_t (*direct_IO)(struct kiocb___237 *, struct iov_iter___157 *);
	int (*migratepage)(struct address_space___237 *, struct page___242 *, struct page___242 *, enum migrate_mode);
	bool (*isolate_page)(struct page___242 *, isolate_mode_t);
	void (*putback_page)(struct page___242 *);
	int (*launder_page)(struct page___242 *);
	int (*is_partially_uptodate)(struct page___242 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___242 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___237 *, struct page___242 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___237 *, sector_t *);
	void (*swap_deactivate)(struct file___237 *);
};

struct bio_vec___154;

struct iov_iter___157 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___154 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___2 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct cdev___65 {
	struct kobject___225 kobj;
	struct module___221 *owner;
	const struct file_operations___238 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___237 {
	struct dentry___237 * (*lookup)(struct inode___237 *, struct dentry___237 *, unsigned int);
	const char * (*get_link)(struct dentry___237 *, struct inode___237 *, struct delayed_call *);
	int (*permission)(struct user_namespace *, struct inode___237 *, int);
	struct posix_acl * (*get_acl)(struct inode___237 *, int, bool);
	int (*readlink)(struct dentry___237 *, char *, int);
	int (*create)(struct user_namespace *, struct inode___237 *, struct dentry___237 *, umode_t, bool);
	int (*link)(struct dentry___237 *, struct inode___237 *, struct dentry___237 *);
	int (*unlink)(struct inode___237 *, struct dentry___237 *);
	int (*symlink)(struct user_namespace *, struct inode___237 *, struct dentry___237 *, const char *);
	int (*mkdir)(struct user_namespace *, struct inode___237 *, struct dentry___237 *, umode_t);
	int (*rmdir)(struct inode___237 *, struct dentry___237 *);
	int (*mknod)(struct user_namespace *, struct inode___237 *, struct dentry___237 *, umode_t, dev_t);
	int (*rename)(struct user_namespace *, struct inode___237 *, struct dentry___237 *, struct inode___237 *, struct dentry___237 *, unsigned int);
	int (*setattr)(struct user_namespace *, struct dentry___237 *, struct iattr___237 *);
	int (*getattr)(struct user_namespace *, const struct path___237 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___237 *, char *, size_t);
	int (*fiemap)(struct inode___237 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___237 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___237 *, struct dentry___237 *, struct file___237 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace *, struct inode___237 *, struct dentry___237 *, umode_t);
	int (*set_acl)(struct user_namespace *, struct inode___237 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace *, struct dentry___237 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___237 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___237 {
	void (*fl_copy_lock)(struct file_lock___237 *, struct file_lock___237 *);
	void (*fl_release_private)(struct file_lock___237 *);
};

struct fasync_struct___237;

struct lock_manager_operations___237;

struct file_lock___237 {
	struct file_lock___237 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___237 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___237 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___237 *fl_ops;
	const struct lock_manager_operations___237 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___237 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___237 *);
	int (*lm_grant)(struct file_lock___237 *, int);
	bool (*lm_break)(struct file_lock___237 *);
	int (*lm_change)(struct file_lock___237 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___237 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___237 *);
};

struct fasync_struct___237 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___237 *fa_next;
	struct file___237 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___237 {
	struct inode___237 * (*alloc_inode)(struct super_block___237 *);
	void (*destroy_inode)(struct inode___237 *);
	void (*free_inode)(struct inode___237 *);
	void (*dirty_inode)(struct inode___237 *, int);
	int (*write_inode)(struct inode___237 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___237 *);
	void (*evict_inode)(struct inode___237 *);
	void (*put_super)(struct super_block___237 *);
	int (*sync_fs)(struct super_block___237 *, int);
	int (*freeze_super)(struct super_block___237 *);
	int (*freeze_fs)(struct super_block___237 *);
	int (*thaw_super)(struct super_block___237 *);
	int (*unfreeze_fs)(struct super_block___237 *);
	int (*statfs)(struct dentry___237 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___237 *, int *, char *);
	void (*umount_begin)(struct super_block___237 *);
	int (*show_options)(struct seq_file___212 *, struct dentry___237 *);
	int (*show_devname)(struct seq_file___212 *, struct dentry___237 *);
	int (*show_path)(struct seq_file___212 *, struct dentry___237 *);
	int (*show_stats)(struct seq_file___212 *, struct dentry___237 *);
	ssize_t (*quota_read)(struct super_block___237 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___237 *, int, const char *, size_t, loff_t);
	struct dquot___237 ** (*get_dquots)(struct inode___237 *);
	long int (*nr_cached_objects)(struct super_block___237 *, struct shrink_control___104 *);
	long int (*free_cached_objects)(struct super_block___237 *, struct shrink_control___104 *);
	struct file___237 * (*real_loop)(struct file___237 *);
};

struct wakeup_source___216;

struct dev_pm_info___216 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___216 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___216 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___216;

struct bus_type___216;

struct device_driver___216;

struct dev_pm_domain___216;

struct fwnode_handle___212;

struct class___216;

struct attribute_group___225;

struct device___216 {
	struct kobject___225 kobj;
	struct device___216 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___216 *type;
	struct bus_type___216 *bus;
	struct device_driver___216 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___216 power;
	struct dev_pm_domain___216 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___212 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___216 *class;
	const struct attribute_group___225 **groups;
	void (*release)(struct device___216 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___133 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___237 *bd_inode;
	struct super_block___237 *bd_super;
	void *bd_claiming;
	struct device___216 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___225 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___133 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___237 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

struct seq_operations___212;

struct seq_file___212 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___212 *op;
	int poll_event;
	const struct file___237 *file;
	void *private;
};

typedef void bio_end_io_t___130(struct bio___130 *);

struct bio_vec___154 {
	struct page___242 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___130;

struct bio___130 {
	struct bio___130 *bi_next;
	struct block_device___133 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___130 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___3 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___130 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___154 *bi_io_vec;
	struct bio_set___130 *bi_pool;
	struct bio_vec___154 bi_inline_vecs[0];
};

struct kernfs_root___225;

struct kernfs_elem_dir___225 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___225 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___225;

struct kernfs_root___225 {
	struct kernfs_node___225 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___225 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___225 {
	struct kernfs_node___225 *target_kn;
};

struct kernfs_ops___225;

struct kernfs_elem_attr___225 {
	const struct kernfs_ops___225 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___225 *notify_next;
};

struct kernfs_node___225 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___225 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___225 dir;
		struct kernfs_elem_symlink___225 symlink;
		struct kernfs_elem_attr___225 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___225;

struct kernfs_ops___225 {
	int (*open)(struct kernfs_open_file___225 *);
	void (*release)(struct kernfs_open_file___225 *);
	int (*seq_show)(struct seq_file___212 *, void *);
	void * (*seq_start)(struct seq_file___212 *, loff_t *);
	void * (*seq_next)(struct seq_file___212 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___212 *, void *);
	ssize_t (*read)(struct kernfs_open_file___225 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___225 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___225 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___225 *, struct vm_area_struct___242 *);
};

struct kernfs_syscall_ops___225 {
	int (*show_options)(struct seq_file___212 *, struct kernfs_root___225 *);
	int (*mkdir)(struct kernfs_node___225 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___225 *);
	int (*rename)(struct kernfs_node___225 *, struct kernfs_node___225 *, const char *);
	int (*show_path)(struct seq_file___212 *, struct kernfs_node___225 *, struct kernfs_root___225 *);
};

struct kernfs_open_file___225 {
	struct kernfs_node___225 *kn;
	struct file___237 *file;
	struct seq_file___212 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___232 *vm_ops;
};

struct bin_attribute___225;

struct attribute_group___225 {
	const char *name;
	umode_t (*is_visible)(struct kobject___225 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___225 *, struct bin_attribute___225 *, int);
	struct attribute **attrs;
	struct bin_attribute___225 **bin_attrs;
};

struct bin_attribute___225 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___237 * (*f_mapping)();
	ssize_t (*read)(struct file___237 *, struct kobject___225 *, struct bin_attribute___225 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___237 *, struct kobject___225 *, struct bin_attribute___225 *, char *, loff_t, size_t);
	int (*mmap)(struct file___237 *, struct kobject___225 *, struct bin_attribute___225 *, struct vm_area_struct___242 *);
};

struct sysfs_ops___225 {
	ssize_t (*show)(struct kobject___225 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___225 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___225;

struct kset___225 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___225 kobj;
	const struct kset_uevent_ops___225 *uevent_ops;
};

struct kobj_type___225 {
	void (*release)(struct kobject___225 *);
	const struct sysfs_ops___225 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___225 **default_groups;
	const struct kobj_ns_type_operations___35 * (*child_ns_type)(struct kobject___225 *);
	const void * (*namespace)(struct kobject___225 *);
	void (*get_ownership)(struct kobject___225 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___225 {
	int (* const filter)(struct kset___225 *, struct kobject___225 *);
	const char * (* const name)(struct kset___225 *, struct kobject___225 *);
	int (* const uevent)(struct kset___225 *, struct kobject___225 *, struct kobj_uevent_env *);
};

struct module_attribute___221 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___221 *, struct module_kobject___222 *, char *);
	ssize_t (*store)(struct module_attribute___221 *, struct module_kobject___222 *, const char *, size_t);
	void (*setup)(struct module___221 *, const char *);
	int (*test)(struct module___221 *);
	void (*free)(struct module___221 *);
};

struct dev_pagemap_ops___232 {
	void (*page_free)(struct page___242 *);
	void (*kill)(struct dev_pagemap___232 *);
	void (*cleanup)(struct dev_pagemap___232 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___232 *);
};

struct fwnode_operations___212;

struct fwnode_handle___212 {
	struct fwnode_handle___212 *secondary;
	const struct fwnode_operations___212 *ops;
	struct device___216 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___212;

struct fwnode_endpoint___212;

struct fwnode_operations___212 {
	struct fwnode_handle___212 * (*get)(struct fwnode_handle___212 *);
	void (*put)(struct fwnode_handle___212 *);
	bool (*device_is_available)(const struct fwnode_handle___212 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___212 *, const struct device___216 *);
	bool (*property_present)(const struct fwnode_handle___212 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___212 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___212 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___212 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*get_parent)(const struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*get_next_child_node)(const struct fwnode_handle___212 *, struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*get_named_child_node)(const struct fwnode_handle___212 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___212 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___212 *);
	struct fwnode_handle___212 * (*graph_get_next_endpoint)(const struct fwnode_handle___212 *, struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*graph_get_remote_endpoint)(const struct fwnode_handle___212 *);
	struct fwnode_handle___212 * (*graph_get_port_parent)(struct fwnode_handle___212 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___212 *, struct fwnode_endpoint___212 *);
	int (*add_links)(struct fwnode_handle___212 *);
};

struct fwnode_endpoint___212 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___212 *local_fwnode;
};

struct fwnode_reference_args___212 {
	struct fwnode_handle___212 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct dev_pm_ops___216 {
	int (*prepare)(struct device___216 *);
	void (*complete)(struct device___216 *);
	int (*suspend)(struct device___216 *);
	int (*resume)(struct device___216 *);
	int (*freeze)(struct device___216 *);
	int (*thaw)(struct device___216 *);
	int (*poweroff)(struct device___216 *);
	int (*restore)(struct device___216 *);
	int (*suspend_late)(struct device___216 *);
	int (*resume_early)(struct device___216 *);
	int (*freeze_late)(struct device___216 *);
	int (*thaw_early)(struct device___216 *);
	int (*poweroff_late)(struct device___216 *);
	int (*restore_early)(struct device___216 *);
	int (*suspend_noirq)(struct device___216 *);
	int (*resume_noirq)(struct device___216 *);
	int (*freeze_noirq)(struct device___216 *);
	int (*thaw_noirq)(struct device___216 *);
	int (*poweroff_noirq)(struct device___216 *);
	int (*restore_noirq)(struct device___216 *);
	int (*runtime_suspend)(struct device___216 *);
	int (*runtime_resume)(struct device___216 *);
	int (*runtime_idle)(struct device___216 *);
};

struct wakeup_source___216 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___216 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___216 {
	struct dev_pm_ops___216 ops;
	int (*start)(struct device___216 *);
	void (*detach)(struct device___216 *, bool);
	int (*activate)(struct device___216 *);
	void (*sync)(struct device___216 *);
	void (*dismiss)(struct device___216 *);
};

struct bus_type___216 {
	const char *name;
	const char *dev_name;
	struct device___216 *dev_root;
	const struct attribute_group___225 **bus_groups;
	const struct attribute_group___225 **dev_groups;
	const struct attribute_group___225 **drv_groups;
	int (*match)(struct device___216 *, struct device_driver___216 *);
	int (*uevent)(struct device___216 *, struct kobj_uevent_env *);
	int (*probe)(struct device___216 *);
	void (*sync_state)(struct device___216 *);
	void (*remove)(struct device___216 *);
	void (*shutdown)(struct device___216 *);
	int (*online)(struct device___216 *);
	int (*offline)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	int (*num_vf)(struct device___216 *);
	int (*dma_configure)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___216 {
	const char *name;
	struct bus_type___216 *bus;
	struct module___221 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___216 *);
	void (*sync_state)(struct device___216 *);
	int (*remove)(struct device___216 *);
	void (*shutdown)(struct device___216 *);
	int (*suspend)(struct device___216 *, pm_message_t);
	int (*resume)(struct device___216 *);
	const struct attribute_group___225 **groups;
	const struct attribute_group___225 **dev_groups;
	const struct dev_pm_ops___216 *pm;
	void (*coredump)(struct device___216 *);
	struct driver_private *p;
};

struct device_type___216 {
	const char *name;
	const struct attribute_group___225 **groups;
	int (*uevent)(struct device___216 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___216 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___216 *);
	const struct dev_pm_ops___216 *pm;
};

struct class___216 {
	const char *name;
	struct module___221 *owner;
	const struct attribute_group___225 **class_groups;
	const struct attribute_group___225 **dev_groups;
	struct kobject___225 *dev_kobj;
	int (*dev_uevent)(struct device___216 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___216 *, umode_t *);
	void (*class_release)(struct class___216 *);
	void (*dev_release)(struct device___216 *);
	int (*shutdown_pre)(struct device___216 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___216 *);
	void (*get_ownership)(struct device___216 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___216 *pm;
	struct subsys_private *p;
};

struct device_attribute___47 {
	struct attribute attr;
	ssize_t (*show)(struct device___216 *, struct device_attribute___47 *, char *);
	ssize_t (*store)(struct device___216 *, struct device_attribute___47 *, const char *, size_t);
};

struct block_device_operations___130;

struct gendisk___133 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___133 *part0;
	const struct block_device_operations___130 *fops;
	struct request_queue___130 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___2 *bdi;
	struct kobject___225 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___225 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___130 {
	struct bio___130 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___154 *bip_vec;
	struct bio_vec___154 bip_inline_vecs[0];
};

typedef void integrity_prepare_fn___130(struct request___130 *);

typedef void integrity_complete_fn___130(struct request___130 *, unsigned int);

struct blk_integrity_profile___130 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___130 *prepare_fn;
	integrity_complete_fn___130 *complete_fn;
	const char *name;
};

struct block_device_operations___130 {
	blk_qc_t (*submit_bio)(struct bio___130 *);
	int (*open)(struct block_device___133 *, fmode_t);
	void (*release)(struct gendisk___133 *, fmode_t);
	int (*rw_page)(struct block_device___133 *, sector_t, struct page___242 *, unsigned int);
	int (*ioctl)(struct block_device___133 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___133 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___133 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___133 *);
	int (*getgeo)(struct block_device___133 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___133 *, bool);
	void (*swap_slot_free_notify)(struct block_device___133 *, long unsigned int);
	int (*report_zones)(struct gendisk___133 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___133 *, umode_t *);
	struct module___221 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___133 *, sector_t *);
};

typedef void rq_end_io_fn___130(struct request___130 *, blk_status_t);

struct request___130 {
	struct request_queue___130 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___125 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___130 *bio;
	struct bio___130 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___154 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___130 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___130 *saved_end_io;
		} flush;
	};
	struct gendisk___133 *rq_disk;
	struct block_device___133 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___130 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___125 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___130 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___225 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___237 *debugfs_dir;
	struct dentry___237 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___130;

struct elevator_mq_ops___130 {
	int (*init_sched)(struct request_queue___130 *, struct elevator_type___130 *);
	void (*exit_sched)(struct elevator_queue___130 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___125 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___125 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___125 *);
	bool (*allow_merge)(struct request_queue___130 *, struct request___130 *, struct bio___130 *);
	bool (*bio_merge)(struct request_queue___130 *, struct bio___130 *, unsigned int);
	int (*request_merge)(struct request_queue___130 *, struct request___130 **, struct bio___130 *);
	void (*request_merged)(struct request_queue___130 *, struct request___130 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___130 *, struct request___130 *, struct request___130 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___130 *);
	void (*finish_request)(struct request___130 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___125 *, struct list_head *, bool);
	struct request___130 * (*dispatch_request)(struct blk_mq_hw_ctx___125 *);
	bool (*has_work)(struct blk_mq_hw_ctx___125 *);
	void (*completed_request)(struct request___130 *, u64);
	void (*requeue_request)(struct request___130 *);
	struct request___130 * (*former_request)(struct request_queue___130 *, struct request___130 *);
	struct request___130 * (*next_request)(struct request_queue___130 *, struct request___130 *);
	void (*init_icq)(struct io_cq___130 *);
	void (*exit_icq)(struct io_cq___130 *);
};

struct elv_fs_entry___130;

struct elevator_type___130 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___130 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___130 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___221 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___130 {
	struct elevator_type___130 *type;
	void *elevator_data;
	struct kobject___225 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___130 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___130 *, char *);
	ssize_t (*store)(struct elevator_queue___130 *, const char *, size_t);
};

struct blk_mq_queue_data___125;

struct blk_mq_ops___125 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___125 *, const struct blk_mq_queue_data___125 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___125 *);
	int (*get_budget)(struct request_queue___130 *);
	void (*put_budget)(struct request_queue___130 *, int);
	void (*set_rq_budget_token)(struct request___130 *, int);
	int (*get_rq_budget_token)(struct request___130 *);
	enum blk_eh_timer_return (*timeout)(struct request___130 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___125 *);
	void (*complete)(struct request___130 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___125 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___125 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___125 *, struct request___130 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___125 *, struct request___130 *, unsigned int);
	void (*initialize_rq_fn)(struct request___130 *);
	void (*cleanup_rq)(struct request___130 *);
	bool (*busy)(struct request_queue___130 *);
	int (*map_queues)(struct blk_mq_tag_set___125 *);
	void (*show_rq)(struct seq_file___212 *, struct request___130 *);
};

struct blk_ksm_ll_ops___8 {
	int (*keyslot_program)(struct blk_keyslot_manager___8 *, const struct blk_crypto_key *, unsigned int);
	int (*keyslot_evict)(struct blk_keyslot_manager___8 *, const struct blk_crypto_key *, unsigned int);
};

struct blk_keyslot_manager___8 {
	struct blk_ksm_ll_ops___8 ksm_ll_ops;
	unsigned int max_dun_bytes_supported;
	unsigned int crypto_modes_supported[4];
	struct device___216 *dev;
	unsigned int num_slots;
	struct rw_semaphore lock;
	wait_queue_head_t idle_slots_wait_queue;
	struct list_head idle_slots;
	spinlock_t idle_slots_lock;
	struct hlist_head *slot_hashtable;
	unsigned int log_slot_ht_size;
	struct blk_ksm_keyslot *slots;
};

struct blk_mq_tag_set___125 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___125 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct seq_operations___212 {
	void * (*start)(struct seq_file___212 *, loff_t *);
	void (*stop)(struct seq_file___212 *, void *);
	void * (*next)(struct seq_file___212 *, void *, loff_t *);
	int (*show)(struct seq_file___212 *, void *);
};

struct mmc_ioc_cmd {
	int write_flag;
	int is_acmd;
	__u32 opcode;
	__u32 arg;
	__u32 response[4];
	unsigned int flags;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int postsleep_min_us;
	unsigned int postsleep_max_us;
	unsigned int data_timeout_ns;
	unsigned int cmd_timeout_ms;
	__u32 __pad;
	__u64 data_ptr;
};

struct mmc_ioc_multi_cmd {
	__u64 num_of_cmds;
	struct mmc_ioc_cmd cmds[0];
};

struct mmc_host___6;

struct mmc_card___6 {
	struct mmc_host___6 *host;
	struct device___216 dev;
	u32 ocr;
	unsigned int rca;
	unsigned int type;
	unsigned int state;
	unsigned int quirks;
	unsigned int quirk_max_rate;
	bool reenable_cmdq;
	unsigned int erase_size;
	unsigned int erase_shift;
	unsigned int pref_erase;
	unsigned int eg_boundary;
	unsigned int erase_arg;
	u8 erased_byte;
	u32 raw_cid[4];
	u32 raw_csd[4];
	u32 raw_scr[2];
	u32 raw_ssr[16];
	struct mmc_cid cid;
	struct mmc_csd csd;
	struct mmc_ext_csd ext_csd;
	struct sd_scr scr;
	struct sd_ssr ssr;
	struct sd_switch_caps sw_caps;
	struct sd_ext_reg ext_power;
	struct sd_ext_reg ext_perf;
	unsigned int sdio_funcs;
	atomic_t sdio_funcs_probed;
	struct sdio_cccr cccr;
	struct sdio_cis cis;
	struct sdio_func *sdio_func[7];
	struct sdio_func *sdio_single_irq;
	u8 major_rev;
	u8 minor_rev;
	unsigned int num_info;
	const char **info;
	struct sdio_func_tuple *tuples;
	unsigned int sd_bus_speed;
	unsigned int mmc_avail_type;
	unsigned int drive_strength;
	struct dentry___237 *debugfs_root;
	struct mmc_part part[7];
	unsigned int nr_parts;
	struct workqueue_struct *complete_wq;
};

struct mmc_ctx___5 {
	struct task_struct___244 *task;
};

struct mmc_host_ops___6;

struct mmc_bus_ops___5;

struct mmc_request___6;

struct mmc_cqe_ops___6;

struct mmc_host___6 {
	struct device___216 *parent;
	struct device___216 class_dev;
	int index;
	const struct mmc_host_ops___6 *ops;
	struct mmc_pwrseq___2 *pwrseq;
	unsigned int f_min;
	unsigned int f_max;
	unsigned int f_init;
	u32 ocr_avail;
	u32 ocr_avail_sdio;
	u32 ocr_avail_sd;
	u32 ocr_avail_mmc;
	struct wakeup_source___216 *ws;
	u32 max_current_330;
	u32 max_current_300;
	u32 max_current_180;
	u32 caps;
	u32 caps2;
	int fixed_drv_type;
	mmc_pm_flag_t pm_caps;
	unsigned int max_seg_size;
	short unsigned int max_segs;
	short unsigned int unused;
	unsigned int max_req_size;
	unsigned int max_blk_size;
	unsigned int max_blk_count;
	unsigned int max_busy_timeout;
	spinlock_t lock;
	struct mmc_ios ios;
	unsigned int use_spi_crc: 1;
	unsigned int claimed: 1;
	unsigned int doing_init_tune: 1;
	unsigned int can_retune: 1;
	unsigned int doing_retune: 1;
	unsigned int retune_now: 1;
	unsigned int retune_paused: 1;
	unsigned int retune_crc_disable: 1;
	unsigned int can_dma_map_merge: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int rescan_disable;
	int rescan_entered;
	int need_retune;
	int hold_retune;
	unsigned int retune_period;
	struct timer_list retune_timer;
	bool trigger_card_event;
	struct mmc_card___6 *card;
	wait_queue_head_t wq;
	struct mmc_ctx___5 *claimer;
	int claim_cnt;
	struct mmc_ctx___5 default_ctx;
	struct delayed_work detect;
	int detect_change;
	struct mmc_slot slot;
	const struct mmc_bus_ops___5 *bus_ops;
	unsigned int sdio_irqs;
	struct task_struct___244 *sdio_irq_thread;
	struct delayed_work sdio_irq_work;
	bool sdio_irq_pending;
	atomic_t sdio_irq_thread_abort;
	mmc_pm_flag_t pm_flags;
	struct led_trigger___11 *led;
	bool regulator_enabled;
	struct mmc_supply supply;
	struct dentry___237 *debugfs_root;
	struct mmc_request___6 *ongoing_mrq;
	unsigned int actual_clock;
	unsigned int slotno;
	int dsr_req;
	u32 dsr;
	const struct mmc_cqe_ops___6 *cqe_ops;
	void *cqe_private;
	int cqe_qdepth;
	bool cqe_enabled;
	bool cqe_on;
	struct blk_keyslot_manager___8 ksm;
	bool hsq_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int private[0];
};

struct mmc_data___6;

struct mmc_command___6 {
	u32 opcode;
	u32 arg;
	u32 resp[4];
	unsigned int flags;
	unsigned int retries;
	int error;
	unsigned int busy_timeout;
	struct mmc_data___6 *data;
	struct mmc_request___6 *mrq;
};

struct mmc_data___6 {
	unsigned int timeout_ns;
	unsigned int timeout_clks;
	unsigned int blksz;
	unsigned int blocks;
	unsigned int blk_addr;
	int error;
	unsigned int flags;
	unsigned int bytes_xfered;
	struct mmc_command___6 *stop;
	struct mmc_request___6 *mrq;
	unsigned int sg_len;
	int sg_count;
	struct scatterlist *sg;
	s32 host_cookie;
};

struct mmc_request___6 {
	struct mmc_command___6 *sbc;
	struct mmc_command___6 *cmd;
	struct mmc_data___6 *data;
	struct mmc_command___6 *stop;
	struct completion completion;
	struct completion cmd_completion;
	void (*done)(struct mmc_request___6 *);
	void (*recovery_notifier)(struct mmc_request___6 *);
	struct mmc_host___6 *host;
	bool cap_cmd_during_tfr;
	int tag;
	const struct bio_crypt_ctx *crypto_ctx;
	int crypto_key_slot;
};

struct mmc_host_ops___6 {
	void (*post_req)(struct mmc_host___6 *, struct mmc_request___6 *, int);
	void (*pre_req)(struct mmc_host___6 *, struct mmc_request___6 *);
	void (*request)(struct mmc_host___6 *, struct mmc_request___6 *);
	int (*request_atomic)(struct mmc_host___6 *, struct mmc_request___6 *);
	void (*set_ios)(struct mmc_host___6 *, struct mmc_ios *);
	int (*get_ro)(struct mmc_host___6 *);
	int (*get_cd)(struct mmc_host___6 *);
	void (*enable_sdio_irq)(struct mmc_host___6 *, int);
	void (*ack_sdio_irq)(struct mmc_host___6 *);
	void (*init_card)(struct mmc_host___6 *, struct mmc_card___6 *);
	int (*start_signal_voltage_switch)(struct mmc_host___6 *, struct mmc_ios *);
	int (*card_busy)(struct mmc_host___6 *);
	int (*execute_tuning)(struct mmc_host___6 *, u32);
	int (*prepare_hs400_tuning)(struct mmc_host___6 *, struct mmc_ios *);
	int (*hs400_prepare_ddr)(struct mmc_host___6 *);
	void (*hs400_downgrade)(struct mmc_host___6 *);
	void (*hs400_complete)(struct mmc_host___6 *);
	void (*hs400_enhanced_strobe)(struct mmc_host___6 *, struct mmc_ios *);
	int (*select_drive_strength)(struct mmc_card___6 *, unsigned int, int, int, int *);
	void (*hw_reset)(struct mmc_host___6 *);
	void (*card_event)(struct mmc_host___6 *);
	int (*multi_io_quirk)(struct mmc_card___6 *, unsigned int, int);
	int (*init_sd_express)(struct mmc_host___6 *, struct mmc_ios *);
};

struct mmc_cqe_ops___6 {
	int (*cqe_enable)(struct mmc_host___6 *, struct mmc_card___6 *);
	void (*cqe_disable)(struct mmc_host___6 *);
	int (*cqe_request)(struct mmc_host___6 *, struct mmc_request___6 *);
	void (*cqe_post_req)(struct mmc_host___6 *, struct mmc_request___6 *);
	void (*cqe_off)(struct mmc_host___6 *);
	int (*cqe_wait_for_idle)(struct mmc_host___6 *);
	bool (*cqe_timeout)(struct mmc_host___6 *, struct mmc_request___6 *, bool *);
	void (*cqe_recovery_start)(struct mmc_host___6 *);
	void (*cqe_recovery_finish)(struct mmc_host___6 *);
};

struct mmc_bus_ops___5 {
	void (*remove)(struct mmc_host___6 *);
	void (*detect)(struct mmc_host___6 *);
	int (*pre_suspend)(struct mmc_host___6 *);
	int (*suspend)(struct mmc_host___6 *);
	int (*resume)(struct mmc_host___6 *);
	int (*runtime_suspend)(struct mmc_host___6 *);
	int (*runtime_resume)(struct mmc_host___6 *);
	int (*alive)(struct mmc_host___6 *);
	int (*shutdown)(struct mmc_host___6 *);
	int (*hw_reset)(struct mmc_host___6 *);
	int (*sw_reset)(struct mmc_host___6 *);
	bool (*cache_enabled)(struct mmc_host___6 *);
	int (*flush_cache)(struct mmc_host___6 *);
};

struct blk_mq_queue_data___125 {
	struct request___130 *rq;
	bool last;
};

enum mmc_issued {
	MMC_REQ_STARTED = 0,
	MMC_REQ_BUSY = 1,
	MMC_REQ_FAILED_TO_START = 2,
	MMC_REQ_FINISHED = 3,
};

struct mmc_blk_request___2 {
	struct mmc_request___6 mrq;
	struct mmc_command___6 sbc;
	struct mmc_command___6 cmd;
	struct mmc_command___6 stop;
	struct mmc_data___6 data;
};

struct mmc_queue_req___2 {
	struct mmc_blk_request___2 brq;
	struct scatterlist *sg;
	enum mmc_drv_op drv_op;
	int drv_op_result;
	void *drv_op_data;
	unsigned int ioc_count;
	int retries;
};

struct mmc_blk_data;

struct mmc_queue {
	struct mmc_card___6 *card;
	struct mmc_ctx___5 ctx;
	struct blk_mq_tag_set___125 tag_set;
	struct mmc_blk_data *blkdata;
	struct request_queue___130 *queue;
	spinlock_t lock;
	int in_flight[3];
	unsigned int cqe_busy;
	bool busy;
	bool recovery_needed;
	bool in_recovery;
	bool rw_wait;
	bool waiting;
	struct work_struct recovery_work;
	wait_queue_head_t wait;
	struct request___130 *recovery_req;
	struct request___130 *complete_req;
	struct mutex complete_lock;
	struct work_struct complete_work;
};

struct mmc_blk_data {
	struct device___216 *parent;
	struct gendisk___133 *disk;
	struct mmc_queue queue;
	struct list_head part;
	struct list_head rpmbs;
	unsigned int flags;
	struct kref kref;
	unsigned int read_only;
	unsigned int part_type;
	unsigned int reset_done;
	unsigned int part_curr;
	int area_type;
	struct dentry___237 *status_dentry;
	struct dentry___237 *ext_csd_dentry;
};

struct mmc_fixup___2 {
	const char *name;
	u64 rev_start;
	u64 rev_end;
	unsigned int manfid;
	short unsigned int oemid;
	u16 cis_vendor;
	u16 cis_device;
	unsigned int ext_csd_rev;
	void (*vendor_fixup)(struct mmc_card___6 *, int);
	int data;
};

struct mmc_driver___2 {
	struct device_driver___216 drv;
	int (*probe)(struct mmc_card___6 *);
	void (*remove)(struct mmc_card___6 *);
	void (*shutdown)(struct mmc_card___6 *);
};

struct mmc_blk_busy_data {
	struct mmc_card___6 *card;
	u32 status;
};

struct mmc_rpmb_data {
	struct device___216 dev;
	struct cdev___65 chrdev;
	int id;
	unsigned int part_index;
	struct mmc_blk_data *md;
	struct list_head node;
};

struct mmc_blk_ioc_data {
	struct mmc_ioc_cmd ic;
	unsigned char *buf;
	u64 buf_bytes;
	struct mmc_rpmb_data *rpmb;
};

struct mmc_blk_request___3 {
	struct mmc_request___2 mrq;
	struct mmc_command___2 sbc;
	struct mmc_command___2 cmd;
	struct mmc_command___2 stop;
	struct mmc_data___2 data;
};

struct mmc_queue_req___3 {
	struct mmc_blk_request___3 brq;
	struct scatterlist *sg;
	enum mmc_drv_op drv_op;
	int drv_op_result;
	void *drv_op_data;
	unsigned int ioc_count;
	int retries;
};

struct mmc_blk_data___2;

struct mmc_queue___2 {
	struct mmc_card___2 *card;
	struct mmc_ctx___2 ctx;
	struct blk_mq_tag_set___122 tag_set;
	struct mmc_blk_data___2 *blkdata;
	struct request_queue___125 *queue;
	spinlock_t lock;
	int in_flight[3];
	unsigned int cqe_busy;
	bool busy;
	bool recovery_needed;
	bool in_recovery;
	bool rw_wait;
	bool waiting;
	struct work_struct recovery_work;
	wait_queue_head_t wait;
	struct request___125 *recovery_req;
	struct request___125 *complete_req;
	struct mutex complete_lock;
	struct work_struct complete_work;
};

struct sg_mapping_iter___3 {
	struct page___239 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

struct amba_device___4 {
	struct device___213 dev;
	struct resource res;
	struct clk *pclk;
	struct device_dma_parameters dma_parms;
	unsigned int periphid;
	unsigned int cid;
	struct amba_cs_uci_id uci;
	unsigned int irq[9];
	char *driver_override;
};

struct amba_driver___4 {
	struct device_driver___213 drv;
	int (*probe)(struct amba_device___4 *, const struct amba_id *);
	void (*remove)(struct amba_device___4 *);
	void (*shutdown)(struct amba_device___4 *);
	const struct amba_id *id_table;
};

struct dma_router___10 {
	struct device___213 *dev;
	void (*route_free)(struct device___213 *, void *);
};

struct dma_device___10;

struct dma_chan_dev___10;

struct dma_chan___10 {
	struct dma_device___10 *device;
	struct device___213 *slave;
	dma_cookie_t cookie;
	dma_cookie_t completed_cookie;
	int chan_id;
	struct dma_chan_dev___10 *dev;
	const char *name;
	char *dbg_client_name;
	struct list_head device_node;
	struct dma_chan_percpu *local;
	int client_count;
	int table_count;
	struct dma_router___10 *router;
	void *route_data;
	void *private;
};

typedef bool (*dma_filter_fn___10)(struct dma_chan___10 *, void *);

struct dma_filter___10 {
	dma_filter_fn___10 fn;
	int mapcnt;
	const struct dma_slave_map *map;
};

struct dma_async_tx_descriptor___10;

struct dma_device___10 {
	struct kref ref;
	unsigned int chancnt;
	unsigned int privatecnt;
	struct list_head channels;
	struct list_head global_node;
	struct dma_filter___10 filter;
	dma_cap_mask_t cap_mask;
	enum dma_desc_metadata_mode desc_metadata_modes;
	short unsigned int max_xor;
	short unsigned int max_pq;
	enum dmaengine_alignment copy_align;
	enum dmaengine_alignment xor_align;
	enum dmaengine_alignment pq_align;
	enum dmaengine_alignment fill_align;
	int dev_id;
	struct device___213 *dev;
	struct module___218 *owner;
	struct ida chan_ida;
	struct mutex chan_mutex;
	u32 src_addr_widths;
	u32 dst_addr_widths;
	u32 directions;
	u32 min_burst;
	u32 max_burst;
	u32 max_sg_burst;
	bool descriptor_reuse;
	enum dma_residue_granularity residue_granularity;
	int (*device_alloc_chan_resources)(struct dma_chan___10 *);
	int (*device_router_config)(struct dma_chan___10 *);
	void (*device_free_chan_resources)(struct dma_chan___10 *);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_memcpy)(struct dma_chan___10 *, dma_addr_t, dma_addr_t, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_xor)(struct dma_chan___10 *, dma_addr_t, dma_addr_t *, unsigned int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_xor_val)(struct dma_chan___10 *, dma_addr_t *, unsigned int, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_pq)(struct dma_chan___10 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_pq_val)(struct dma_chan___10 *, dma_addr_t *, dma_addr_t *, unsigned int, const unsigned char *, size_t, enum sum_check_flags *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_memset)(struct dma_chan___10 *, dma_addr_t, int, size_t, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_memset_sg)(struct dma_chan___10 *, struct scatterlist *, unsigned int, int, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_interrupt)(struct dma_chan___10 *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_slave_sg)(struct dma_chan___10 *, struct scatterlist *, unsigned int, enum dma_transfer_direction, long unsigned int, void *);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_cyclic)(struct dma_chan___10 *, dma_addr_t, size_t, size_t, enum dma_transfer_direction, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_interleaved_dma)(struct dma_chan___10 *, struct dma_interleaved_template *, long unsigned int);
	struct dma_async_tx_descriptor___10 * (*device_prep_dma_imm_data)(struct dma_chan___10 *, dma_addr_t, u64, long unsigned int);
	void (*device_caps)(struct dma_chan___10 *, struct dma_slave_caps *);
	int (*device_config)(struct dma_chan___10 *, struct dma_slave_config *);
	int (*device_pause)(struct dma_chan___10 *);
	int (*device_resume)(struct dma_chan___10 *);
	int (*device_terminate_all)(struct dma_chan___10 *);
	void (*device_synchronize)(struct dma_chan___10 *);
	enum dma_status (*device_tx_status)(struct dma_chan___10 *, dma_cookie_t, struct dma_tx_state *);
	void (*device_issue_pending)(struct dma_chan___10 *);
	void (*device_release)(struct dma_device___10 *);
	void (*dbg_summary_show)(struct seq_file___209 *, struct dma_device___10 *);
	struct dentry___234 *dbg_dev_root;
};

struct dma_chan_dev___10 {
	struct dma_chan___10 *chan;
	struct device___213 device;
	int dev_id;
	bool chan_dma_dev;
};

struct dmaengine_unmap_data___10 {
	u16 map_cnt;
	u8 to_cnt;
	u8 from_cnt;
	u8 bidi_cnt;
	struct device___213 *dev;
	struct kref kref;
	size_t len;
	dma_addr_t addr[0];
};

struct dma_descriptor_metadata_ops___10 {
	int (*attach)(struct dma_async_tx_descriptor___10 *, void *, size_t);
	void * (*get_ptr)(struct dma_async_tx_descriptor___10 *, size_t *, size_t *);
	int (*set_len)(struct dma_async_tx_descriptor___10 *, size_t);
};

struct dma_async_tx_descriptor___10 {
	dma_cookie_t cookie;
	enum dma_ctrl_flags flags;
	dma_addr_t phys;
	struct dma_chan___10 *chan;
	dma_cookie_t (*tx_submit)(struct dma_async_tx_descriptor___10 *);
	int (*desc_free)(struct dma_async_tx_descriptor___10 *);
	dma_async_tx_callback callback;
	dma_async_tx_callback_result callback_result;
	void *callback_param;
	struct dmaengine_unmap_data___10 *unmap;
	enum dma_desc_metadata_mode desc_metadata_mode;
	struct dma_descriptor_metadata_ops___10 *metadata_ops;
	struct dma_async_tx_descriptor___10 *next;
	struct dma_async_tx_descriptor___10 *parent;
	spinlock_t lock;
};

struct mmci_platform_data {
	unsigned int ocr_mask;
	int (*ios_handler)(struct device___213 *, struct mmc_ios *);
	unsigned int (*status)(struct device___213 *);
};

struct mmci_host;

struct variant_data {
	unsigned int clkreg;
	unsigned int clkreg_enable;
	unsigned int clkreg_8bit_bus_enable;
	unsigned int clkreg_neg_edge_enable;
	unsigned int cmdreg_cpsm_enable;
	unsigned int cmdreg_lrsp_crc;
	unsigned int cmdreg_srsp_crc;
	unsigned int cmdreg_srsp;
	unsigned int cmdreg_stop;
	unsigned int datalength_bits;
	unsigned int fifosize;
	unsigned int fifohalfsize;
	unsigned int data_cmd_enable;
	unsigned int datactrl_mask_ddrmode;
	unsigned int datactrl_mask_sdio;
	unsigned int datactrl_blocksz;
	u8 datactrl_any_blocksz: 1;
	u8 dma_power_of_2: 1;
	u8 datactrl_first: 1;
	u8 datacnt_useless: 1;
	u8 st_sdio: 1;
	u8 st_clkdiv: 1;
	u8 stm32_clkdiv: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pwrreg_powerup;
	u32 f_max;
	u8 signal_direction: 1;
	u8 pwrreg_clkgate: 1;
	u8 busy_detect: 1;
	u8 busy_timeout: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 busy_dpsm_flag;
	u32 busy_detect_flag;
	u32 busy_detect_mask;
	u8 pwrreg_nopower: 1;
	u8 explicit_mclk_control: 1;
	u8 qcom_fifo: 1;
	u8 qcom_dml: 1;
	u8 reversed_irq_handling: 1;
	u8 mmcimask1: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq_pio_mask;
	u32 start_err;
	u32 opendrain;
	u8 dma_lli: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 stm32_idmabsize_mask;
	void (*init)(struct mmci_host *);
};

struct mmci_host_ops;

struct mmci_host {
	phys_addr_t phybase;
	void *base;
	struct mmc_request *mrq;
	struct mmc_command *cmd;
	struct mmc_command stop_abort;
	struct mmc_data *data;
	struct mmc_host *mmc;
	struct clk *clk;
	u8 singleirq: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct reset_control *rst;
	spinlock_t lock;
	unsigned int mclk;
	unsigned int clock_cache;
	unsigned int cclk;
	u32 pwr_reg;
	u32 pwr_reg_add;
	u32 clk_reg;
	u32 clk_reg_add;
	u32 datactrl_reg;
	u32 busy_status;
	u32 mask1_reg;
	u8 vqmmc_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mmci_platform_data *plat;
	struct mmc_host_ops *mmc_ops;
	struct mmci_host_ops *ops;
	struct variant_data *variant;
	void *variant_priv;
	struct pinctrl___3 *pinctrl;
	struct pinctrl_state *pins_opendrain;
	u8 hw_designer;
	u8 hw_revision: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct timer_list timer;
	unsigned int oldstat;
	u32 irq_action;
	struct sg_mapping_iter___3 sg_miter;
	unsigned int size;
	int (*get_rx_fifocnt)(struct mmci_host *, u32, int);
	u8 use_dma: 1;
	u8 dma_in_progress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *dma_priv;
	s32 next_cookie;
};

struct mmci_host_ops {
	int (*validate_data)(struct mmci_host *, struct mmc_data *);
	int (*prep_data)(struct mmci_host *, struct mmc_data *, bool);
	void (*unprep_data)(struct mmci_host *, struct mmc_data *, int);
	u32 (*get_datactrl_cfg)(struct mmci_host *);
	void (*get_next_data)(struct mmci_host *, struct mmc_data *);
	int (*dma_setup)(struct mmci_host *);
	void (*dma_release)(struct mmci_host *);
	int (*dma_start)(struct mmci_host *, unsigned int *);
	void (*dma_finalize)(struct mmci_host *, struct mmc_data *);
	void (*dma_error)(struct mmci_host *);
	void (*set_clkreg)(struct mmci_host *, unsigned int);
	void (*set_pwrreg)(struct mmci_host *, unsigned int);
	bool (*busy_complete)(struct mmci_host *, u32, u32);
	void (*pre_sig_volt_switch)(struct mmci_host *);
	int (*post_sig_volt_switch)(struct mmci_host *, struct mmc_ios *);
};

struct mmci_dmae_next {
	struct dma_async_tx_descriptor___10 *desc;
	struct dma_chan___10 *chan;
};

struct mmci_dmae_priv {
	struct dma_chan___10 *cur;
	struct dma_chan___10 *rx_channel;
	struct dma_chan___10 *tx_channel;
	struct dma_async_tx_descriptor___10 *desc_current;
	struct mmci_dmae_next next_data;
};

struct sg_mapping_iter___4 {
	struct page___241 *page;
	void *addr;
	size_t length;
	size_t consumed;
	struct sg_page_iter piter;
	unsigned int __offset;
	unsigned int __remaining;
	unsigned int __flags;
};

struct mmci_host___2;

struct variant_data___2 {
	unsigned int clkreg;
	unsigned int clkreg_enable;
	unsigned int clkreg_8bit_bus_enable;
	unsigned int clkreg_neg_edge_enable;
	unsigned int cmdreg_cpsm_enable;
	unsigned int cmdreg_lrsp_crc;
	unsigned int cmdreg_srsp_crc;
	unsigned int cmdreg_srsp;
	unsigned int cmdreg_stop;
	unsigned int datalength_bits;
	unsigned int fifosize;
	unsigned int fifohalfsize;
	unsigned int data_cmd_enable;
	unsigned int datactrl_mask_ddrmode;
	unsigned int datactrl_mask_sdio;
	unsigned int datactrl_blocksz;
	u8 datactrl_any_blocksz: 1;
	u8 dma_power_of_2: 1;
	u8 datactrl_first: 1;
	u8 datacnt_useless: 1;
	u8 st_sdio: 1;
	u8 st_clkdiv: 1;
	u8 stm32_clkdiv: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pwrreg_powerup;
	u32 f_max;
	u8 signal_direction: 1;
	u8 pwrreg_clkgate: 1;
	u8 busy_detect: 1;
	u8 busy_timeout: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 busy_dpsm_flag;
	u32 busy_detect_flag;
	u32 busy_detect_mask;
	u8 pwrreg_nopower: 1;
	u8 explicit_mclk_control: 1;
	u8 qcom_fifo: 1;
	u8 qcom_dml: 1;
	u8 reversed_irq_handling: 1;
	u8 mmcimask1: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int irq_pio_mask;
	u32 start_err;
	u32 opendrain;
	u8 dma_lli: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 stm32_idmabsize_mask;
	void (*init)(struct mmci_host___2 *);
};

struct mmci_host_ops___2;

struct mmci_host___2 {
	phys_addr_t phybase;
	void *base;
	struct mmc_request___5 *mrq;
	struct mmc_command___5 *cmd;
	struct mmc_command___5 stop_abort;
	struct mmc_data___5 *data;
	struct mmc_host___5 *mmc;
	struct clk *clk;
	u8 singleirq: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct reset_control *rst;
	spinlock_t lock;
	unsigned int mclk;
	unsigned int clock_cache;
	unsigned int cclk;
	u32 pwr_reg;
	u32 pwr_reg_add;
	u32 clk_reg;
	u32 clk_reg_add;
	u32 datactrl_reg;
	u32 busy_status;
	u32 mask1_reg;
	u8 vqmmc_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mmci_platform_data *plat;
	struct mmc_host_ops___5 *mmc_ops;
	struct mmci_host_ops___2 *ops;
	struct variant_data___2 *variant;
	void *variant_priv;
	struct pinctrl___3 *pinctrl;
	struct pinctrl_state *pins_opendrain;
	u8 hw_designer;
	u8 hw_revision: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct timer_list timer;
	unsigned int oldstat;
	u32 irq_action;
	struct sg_mapping_iter___4 sg_miter;
	unsigned int size;
	int (*get_rx_fifocnt)(struct mmci_host___2 *, u32, int);
	u8 use_dma: 1;
	u8 dma_in_progress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *dma_priv;
	s32 next_cookie;
};

struct mmci_host_ops___2 {
	int (*validate_data)(struct mmci_host___2 *, struct mmc_data___5 *);
	int (*prep_data)(struct mmci_host___2 *, struct mmc_data___5 *, bool);
	void (*unprep_data)(struct mmci_host___2 *, struct mmc_data___5 *, int);
	u32 (*get_datactrl_cfg)(struct mmci_host___2 *);
	void (*get_next_data)(struct mmci_host___2 *, struct mmc_data___5 *);
	int (*dma_setup)(struct mmci_host___2 *);
	void (*dma_release)(struct mmci_host___2 *);
	int (*dma_start)(struct mmci_host___2 *, unsigned int *);
	void (*dma_finalize)(struct mmci_host___2 *, struct mmc_data___5 *);
	void (*dma_error)(struct mmci_host___2 *);
	void (*set_clkreg)(struct mmci_host___2 *, unsigned int);
	void (*set_pwrreg)(struct mmci_host___2 *, unsigned int);
	bool (*busy_complete)(struct mmci_host___2 *, u32, u32);
	void (*pre_sig_volt_switch)(struct mmci_host___2 *);
	int (*post_sig_volt_switch)(struct mmci_host___2 *, struct mmc_ios *);
};

struct sdmmc_lli_desc {
	u32 idmalar;
	u32 idmabase;
	u32 idmasize;
};

struct sdmmc_idma {
	dma_addr_t sg_dma;
	void *sg_cpu;
};

struct sdmmc_dlyb {
	void *base;
	u32 unit;
	u32 max;
};

struct pci_dev___21;

struct sdhci_pci_data {
	struct pci_dev___21 *pdev;
	int slotno;
	int rst_n_gpio;
	int cd_gpio;
	int (*setup)(struct sdhci_pci_data *);
	void (*cleanup)(struct sdhci_pci_data *);
};

enum led_default_state {
	LEDS_DEFSTATE_OFF = 0,
	LEDS_DEFSTATE_ON = 1,
	LEDS_DEFSTATE_KEEP = 2,
};

struct led_init_data {
	struct fwnode_handle___211 *fwnode;
	const char *default_label;
	const char *devicename;
	bool devname_mandatory;
};

struct led_properties {
	u32 color;
	bool color_present;
	const char *function;
	u32 func_enum;
	bool func_enum_present;
	const char *label;
};

typedef void (*dr_release_t___35)(struct device___214 *, void *);

typedef int (*dr_match_t___26)(struct device___214 *, void *, void *);

struct led_init_data___2 {
	struct fwnode_handle___210 *fwnode;
	const char *default_label;
	const char *devicename;
	bool devname_mandatory;
};

typedef void (*dr_release_t___36)(struct device___215 *, void *);

struct led_init_data___3 {
	struct fwnode_handle___205 *fwnode;
	const char *default_label;
	const char *devicename;
	bool devname_mandatory;
};

struct led_trigger___12;

struct led_classdev___12 {
	const char *name;
	unsigned int brightness;
	unsigned int max_brightness;
	int flags;
	long unsigned int work_flags;
	void (*brightness_set)(struct led_classdev___12 *, enum led_brightness);
	int (*brightness_set_blocking)(struct led_classdev___12 *, enum led_brightness);
	enum led_brightness (*brightness_get)(struct led_classdev___12 *);
	int (*blink_set)(struct led_classdev___12 *, long unsigned int *, long unsigned int *);
	int (*pattern_set)(struct led_classdev___12 *, struct led_pattern *, u32, int);
	int (*pattern_clear)(struct led_classdev___12 *);
	struct device___209 *dev;
	const struct attribute_group___41 **groups;
	struct list_head node;
	const char *default_trigger;
	long unsigned int blink_delay_on;
	long unsigned int blink_delay_off;
	struct timer_list blink_timer;
	int blink_brightness;
	int new_blink_brightness;
	void (*flash_resume)(struct led_classdev___12 *);
	struct work_struct set_brightness_work;
	int delayed_set_value;
	struct rw_semaphore trigger_lock;
	struct led_trigger___12 *trigger;
	struct list_head trig_list;
	void *trigger_data;
	bool activated;
	struct led_hw_trigger_type *trigger_type;
	int brightness_hw_changed;
	struct kernfs_node___41 *brightness_hw_changed_kn;
	struct mutex led_access;
};

struct led_trigger___12 {
	const char *name;
	int (*activate)(struct led_classdev___12 *);
	void (*deactivate)(struct led_classdev___12 *);
	struct led_hw_trigger_type *trigger_type;
	rwlock_t leddev_list_lock;
	struct list_head led_cdevs;
	struct list_head next_trig;
	const struct attribute_group___41 **groups;
};

struct syscon_led {
	struct led_classdev___12 cdev;
	struct regmap *map;
	u32 offset;
	u32 mask;
	bool state;
};

enum cpu_led_event {
	CPU_LED_IDLE_START = 0,
	CPU_LED_IDLE_END = 1,
	CPU_LED_START = 2,
	CPU_LED_STOP = 3,
	CPU_LED_HALTED = 4,
};

struct led_trigger_cpu {
	bool is_active;
	char name[8];
	struct led_trigger___12 *_trig;
};

struct sdei_registered_event___3 {
	struct pt_regs interrupted_regs;
	sdei_event_callback___2 *callback;
	void *callback_arg;
	u32 event_num;
	u8 priority;
};

struct platform_device_info___9 {
	struct device___11 *parent;
	struct fwnode_handle___11 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct sdei_event {
	struct list_head list;
	bool reregister;
	bool reenable;
	u32 event_num;
	u8 type;
	u8 priority;
	union {
		struct sdei_registered_event___3 *registered;
		struct sdei_registered_event___3 *private_registered;
	};
};

struct sdei_crosscall_args {
	struct sdei_event *event;
	atomic_t errors;
	int first_error;
};

struct dmi_memdev_info {
	const char *device;
	const char *bank;
	u64 size;
	u16 handle;
	u8 type;
};

struct dmi_device_attribute {
	struct device_attribute___46 dev_attr;
	int field;
};

struct mafield {
	const char *prefix;
	int field;
};

struct firmware_map_entry {
	u64 start;
	u64 end;
	const char *type;
	struct list_head list;
	struct kobject___103 kobj;
};

struct memmap_attribute {
	struct attribute attr;
	ssize_t (*show)(struct firmware_map_entry *, char *);
};

enum rpi_firmware_property_status {
	RPI_FIRMWARE_STATUS_REQUEST = 0,
	RPI_FIRMWARE_STATUS_SUCCESS = 2147483648,
	RPI_FIRMWARE_STATUS_ERROR = 2147483649,
};

struct rpi_firmware_property_tag_header {
	u32 tag;
	u32 buf_size;
	u32 req_resp_size;
};

struct rpi_firmware___2 {
	struct mbox_client___4 cl;
	struct mbox_chan___2 *chan;
	struct completion c;
	u32 enabled;
	struct kref consumers;
};

struct qcom_scm_hdcp_req {
	u32 addr;
	u32 val;
};

struct qcom_scm_vmperm {
	int vmid;
	int perm;
};

enum qcom_scm_ocmem_client {
	QCOM_SCM_OCMEM_UNUSED_ID = 0,
	QCOM_SCM_OCMEM_GRAPHICS_ID = 1,
	QCOM_SCM_OCMEM_VIDEO_ID = 2,
	QCOM_SCM_OCMEM_LP_AUDIO_ID = 3,
	QCOM_SCM_OCMEM_SENSORS_ID = 4,
	QCOM_SCM_OCMEM_OTHER_OS_ID = 5,
	QCOM_SCM_OCMEM_DEBUG_ID = 6,
};

enum qcom_scm_ice_cipher {
	QCOM_SCM_ICE_CIPHER_AES_128_XTS = 0,
	QCOM_SCM_ICE_CIPHER_AES_128_CBC = 1,
	QCOM_SCM_ICE_CIPHER_AES_256_XTS = 3,
	QCOM_SCM_ICE_CIPHER_AES_256_CBC = 4,
};

enum qcom_scm_convention {
	SMC_CONVENTION_UNKNOWN = 0,
	SMC_CONVENTION_LEGACY = 1,
	SMC_CONVENTION_ARM_32 = 2,
	SMC_CONVENTION_ARM_64 = 3,
};

enum qcom_scm_arg_types {
	QCOM_SCM_VAL = 0,
	QCOM_SCM_RO = 1,
	QCOM_SCM_RW = 2,
	QCOM_SCM_BUFVAL = 3,
};

struct qcom_scm_desc {
	u32 svc;
	u32 cmd;
	u32 arginfo;
	u64 args[10];
	u32 owner;
};

struct qcom_scm_res {
	u64 result[3];
};

struct qcom_scm {
	struct device___215 *dev;
	struct clk *core_clk;
	struct clk *iface_clk;
	struct clk *bus_clk;
	struct reset_controller_dev___3 reset;
	u64 dload_mode_addr;
};

struct qcom_scm_current_perm_info {
	__le32 vmid;
	__le32 perm;
	__le64 ctx;
	__le32 ctx_size;
	__le32 unused;
};

struct qcom_scm_mem_map_info {
	__le64 mem_addr;
	__le64 mem_size;
};

struct qcom_scm_wb_entry {
	int flag;
	void *entry;
};

struct arm_smccc_args {
	long unsigned int args[8];
};

struct scm_legacy_command {
	__le32 len;
	__le32 buf_offset;
	__le32 resp_hdr_offset;
	__le32 id;
	__le32 buf[0];
};

struct scm_legacy_response {
	__le32 len;
	__le32 buf_offset;
	__le32 is_complete;
};

struct simplefb_platform_data {
	u32 width;
	u32 height;
	u32 stride;
	const char *format;
};

struct simplefb_format {
	const char *name;
	u32 bits_per_pixel;
	struct fb_bitfield red;
	struct fb_bitfield green;
	struct fb_bitfield blue;
	struct fb_bitfield transp;
	u32 fourcc;
};

struct ti_msgmgr_message {
	size_t len;
	u8 *buf;
};

struct ti_sci_msg_hdr {
	u16 type;
	u8 host;
	u8 seq;
	u32 flags;
};

struct ti_sci_msg_resp_version {
	struct ti_sci_msg_hdr hdr;
	char firmware_description[32];
	u16 firmware_revision;
	u8 abi_major;
	u8 abi_minor;
};

struct ti_sci_msg_req_reboot {
	struct ti_sci_msg_hdr hdr;
};

struct ti_sci_msg_req_set_device_state {
	struct ti_sci_msg_hdr hdr;
	u32 id;
	u32 reserved;
	u8 state;
} __attribute__((packed));

struct ti_sci_msg_req_get_device_state {
	struct ti_sci_msg_hdr hdr;
	u32 id;
};

struct ti_sci_msg_resp_get_device_state {
	struct ti_sci_msg_hdr hdr;
	u32 context_loss_count;
	u32 resets;
	u8 programmed_state;
	u8 current_state;
} __attribute__((packed));

struct ti_sci_msg_req_set_device_resets {
	struct ti_sci_msg_hdr hdr;
	u32 id;
	u32 resets;
};

struct ti_sci_msg_req_set_clock_state {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u8 clk_id;
	u8 request_state;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_req_get_clock_state {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u8 clk_id;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_resp_get_clock_state {
	struct ti_sci_msg_hdr hdr;
	u8 programmed_state;
	u8 current_state;
} __attribute__((packed));

struct ti_sci_msg_req_set_clock_parent {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u8 clk_id;
	u8 parent_id;
	u32 clk_id_32;
	u32 parent_id_32;
} __attribute__((packed));

struct ti_sci_msg_req_get_clock_parent {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u8 clk_id;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_resp_get_clock_parent {
	struct ti_sci_msg_hdr hdr;
	u8 parent_id;
	u32 parent_id_32;
} __attribute__((packed));

struct ti_sci_msg_req_get_clock_num_parents {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u8 clk_id;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_resp_get_clock_num_parents {
	struct ti_sci_msg_hdr hdr;
	u8 num_parents;
	u32 num_parents_32;
} __attribute__((packed));

struct ti_sci_msg_req_query_clock_freq {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u64 min_freq_hz;
	u64 target_freq_hz;
	u64 max_freq_hz;
	u8 clk_id;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_resp_query_clock_freq {
	struct ti_sci_msg_hdr hdr;
	u64 freq_hz;
};

struct ti_sci_msg_req_set_clock_freq {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u64 min_freq_hz;
	u64 target_freq_hz;
	u64 max_freq_hz;
	u8 clk_id;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_req_get_clock_freq {
	struct ti_sci_msg_hdr hdr;
	u32 dev_id;
	u8 clk_id;
	u32 clk_id_32;
} __attribute__((packed));

struct ti_sci_msg_resp_get_clock_freq {
	struct ti_sci_msg_hdr hdr;
	u64 freq_hz;
};

struct ti_sci_msg_req_get_resource_range {
	struct ti_sci_msg_hdr hdr;
	u16 type;
	u8 subtype;
	u8 secondary_host;
};

struct ti_sci_msg_resp_get_resource_range {
	struct ti_sci_msg_hdr hdr;
	u16 range_start;
	u16 range_num;
	u16 range_start_sec;
	u16 range_num_sec;
};

struct ti_sci_msg_req_manage_irq {
	struct ti_sci_msg_hdr hdr;
	u32 valid_params;
	u16 src_id;
	u16 src_index;
	u16 dst_id;
	u16 dst_host_irq;
	u16 ia_id;
	u16 vint;
	u16 global_event;
	u8 vint_status_bit;
	u8 secondary_host;
};

struct ti_sci_msg_rm_ring_cfg_req {
	struct ti_sci_msg_hdr hdr;
	u32 valid_params;
	u16 nav_id;
	u16 index;
	u32 addr_lo;
	u32 addr_hi;
	u32 count;
	u8 mode;
	u8 size;
	u8 order_id;
	u16 virtid;
	u8 asel;
} __attribute__((packed));

struct ti_sci_msg_psil_pair {
	struct ti_sci_msg_hdr hdr;
	u32 nav_id;
	u32 src_thread;
	u32 dst_thread;
};

struct ti_sci_msg_psil_unpair {
	struct ti_sci_msg_hdr hdr;
	u32 nav_id;
	u32 src_thread;
	u32 dst_thread;
};

struct ti_sci_msg_rm_udmap_tx_ch_cfg_req {
	struct ti_sci_msg_hdr hdr;
	u32 valid_params;
	u16 nav_id;
	u16 index;
	u8 tx_pause_on_err;
	u8 tx_filt_einfo;
	u8 tx_filt_pswords;
	u8 tx_atype;
	u8 tx_chan_type;
	u8 tx_supr_tdpkt;
	u16 tx_fetch_size;
	u8 tx_credit_count;
	u16 txcq_qnum;
	u8 tx_priority;
	u8 tx_qos;
	u8 tx_orderid;
	u16 fdepth;
	u8 tx_sched_priority;
	u8 tx_burst_size;
	u8 tx_tdtype;
	u8 extended_ch_type;
} __attribute__((packed));

struct ti_sci_msg_rm_udmap_rx_ch_cfg_req {
	struct ti_sci_msg_hdr hdr;
	u32 valid_params;
	u16 nav_id;
	u16 index;
	u16 rx_fetch_size;
	u16 rxcq_qnum;
	u8 rx_priority;
	u8 rx_qos;
	u8 rx_orderid;
	u8 rx_sched_priority;
	u16 flowid_start;
	u16 flowid_cnt;
	u8 rx_pause_on_err;
	u8 rx_atype;
	u8 rx_chan_type;
	u8 rx_ignore_short;
	u8 rx_ignore_long;
	u8 rx_burst_size;
} __attribute__((packed));

struct ti_sci_msg_rm_udmap_flow_cfg_req {
	struct ti_sci_msg_hdr hdr;
	u32 valid_params;
	u16 nav_id;
	u16 flow_index;
	u8 rx_einfo_present;
	u8 rx_psinfo_present;
	u8 rx_error_handling;
	u8 rx_desc_type;
	u16 rx_sop_offset;
	u16 rx_dest_qnum;
	u8 rx_src_tag_hi;
	u8 rx_src_tag_lo;
	u8 rx_dest_tag_hi;
	u8 rx_dest_tag_lo;
	u8 rx_src_tag_hi_sel;
	u8 rx_src_tag_lo_sel;
	u8 rx_dest_tag_hi_sel;
	u8 rx_dest_tag_lo_sel;
	u16 rx_fdq0_sz0_qnum;
	u16 rx_fdq1_qnum;
	u16 rx_fdq2_qnum;
	u16 rx_fdq3_qnum;
	u8 rx_ps_location;
} __attribute__((packed));

struct ti_sci_msg_req_proc_request {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
} __attribute__((packed));

struct ti_sci_msg_req_proc_release {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
} __attribute__((packed));

struct ti_sci_msg_req_proc_handover {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
	u8 host_id;
} __attribute__((packed));

struct ti_sci_msg_req_set_config {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
	u32 bootvector_low;
	u32 bootvector_high;
	u32 config_flags_set;
	u32 config_flags_clear;
} __attribute__((packed));

struct ti_sci_msg_req_set_ctrl {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
	u32 control_flags_set;
	u32 control_flags_clear;
} __attribute__((packed));

struct ti_sci_msg_req_get_status {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
} __attribute__((packed));

struct ti_sci_msg_resp_get_status {
	struct ti_sci_msg_hdr hdr;
	u8 processor_id;
	u32 bootvector_low;
	u32 bootvector_high;
	u32 config_flags;
	u32 control_flags;
	u32 status_flags;
} __attribute__((packed));

struct ti_sci_xfer {
	struct ti_msgmgr_message tx_message;
	u8 rx_len;
	u8 *xfer_buf;
	struct completion done;
};

struct ti_sci_xfers_info {
	struct semaphore sem_xfer_count;
	struct ti_sci_xfer *xfer_block;
	long unsigned int *xfer_alloc_table;
	spinlock_t xfer_lock;
};

struct ti_sci_desc {
	u8 default_host_id;
	int max_rx_timeout_ms;
	int max_msgs;
	int max_msg_size;
};

struct ti_sci_info {
	struct device___214 *dev;
	struct notifier_block nb;
	const struct ti_sci_desc *desc;
	struct dentry___237 *d;
	void *debug_region;
	char *debug_buffer;
	size_t debug_region_size;
	struct ti_sci_handle handle;
	struct mbox_client cl;
	struct mbox_chan___2 *chan_tx;
	struct mbox_chan___2 *chan_rx;
	struct ti_sci_xfers_info minfo;
	struct list_head node;
	u8 host_id;
	int users;
};

struct scmi_revision_info {
	u16 major_ver;
	u16 minor_ver;
	u8 num_protocols;
	u8 num_agents;
	u32 impl_ver;
	char vendor_id[16];
	char sub_vendor_id[16];
};

struct scmi_xfer_ops;

struct scmi_protocol_handle {
	struct device___216 *dev;
	const struct scmi_xfer_ops *xops;
	int (*set_priv)(const struct scmi_protocol_handle *, void *);
	void * (*get_priv)(const struct scmi_protocol_handle *);
};

struct scmi_device;

struct scmi_handle;

struct scmi_notify_ops {
	int (*devm_event_notifier_register)(struct scmi_device *, u8, u8, const u32 *, struct notifier_block *);
	int (*devm_event_notifier_unregister)(struct scmi_device *, u8, u8, const u32 *, struct notifier_block *);
	int (*event_notifier_register)(const struct scmi_handle *, u8, u8, const u32 *, struct notifier_block *);
	int (*event_notifier_unregister)(const struct scmi_handle *, u8, u8, const u32 *, struct notifier_block *);
};

struct scmi_device {
	u32 id;
	u8 protocol_id;
	const char *name;
	struct device___216 dev;
	struct scmi_handle *handle;
};

struct scmi_handle {
	struct device___216 *dev;
	struct scmi_revision_info *version;
	const void * (*devm_protocol_get)(struct scmi_device *, u8, struct scmi_protocol_handle **);
	void (*devm_protocol_put)(struct scmi_device *, u8);
	const struct scmi_notify_ops *notify_ops;
};

struct scmi_device_id {
	u8 protocol_id;
	const char *name;
};

struct scmi_driver {
	const char *name;
	int (*probe)(struct scmi_device *);
	void (*remove)(struct scmi_device *);
	const struct scmi_device_id *id_table;
	struct device_driver___216 driver;
};

struct scmi_event {
	u8 id;
	size_t max_payld_sz;
	size_t max_report_sz;
};

struct scmi_event_ops {
	int (*get_num_sources)(const struct scmi_protocol_handle *);
	int (*set_notify_enabled)(const struct scmi_protocol_handle *, u8, u32, bool);
	void * (*fill_custom_report)(const struct scmi_protocol_handle *, u8, ktime_t, const void *, size_t, void *, u32 *);
};

struct scmi_protocol_events {
	size_t queue_sz;
	const struct scmi_event_ops *ops;
	const struct scmi_event *evts;
	unsigned int num_events;
	unsigned int num_sources;
};

struct scmi_msg_hdr {
	u8 id;
	u8 protocol_id;
	u8 type;
	u16 seq;
	u32 status;
	bool poll_completion;
};

struct scmi_msg {
	void *buf;
	size_t len;
};

struct scmi_xfer {
	int transfer_id;
	struct scmi_msg_hdr hdr;
	struct scmi_msg tx;
	struct scmi_msg rx;
	struct completion done;
	struct completion *async_done;
	bool pending;
	struct hlist_node node;
	refcount_t users;
	atomic_t busy;
	int state;
	spinlock_t lock;
	void *priv;
};

struct scmi_xfer_ops {
	int (*version_get)(const struct scmi_protocol_handle *, u32 *);
	int (*xfer_get_init)(const struct scmi_protocol_handle *, u8, size_t, size_t, struct scmi_xfer **);
	void (*reset_rx_to_maxsz)(const struct scmi_protocol_handle *, struct scmi_xfer *);
	int (*do_xfer)(const struct scmi_protocol_handle *, struct scmi_xfer *);
	int (*do_xfer_with_response)(const struct scmi_protocol_handle *, struct scmi_xfer *);
	void (*xfer_put)(const struct scmi_protocol_handle *, struct scmi_xfer *);
};

typedef int (*scmi_prot_init_ph_fn_t)(const struct scmi_protocol_handle *);

struct scmi_protocol {
	const u8 id;
	struct module___221 *owner;
	const scmi_prot_init_ph_fn_t instance_init;
	const scmi_prot_init_ph_fn_t instance_deinit;
	const void *ops;
	const struct scmi_protocol_events *events;
};

typedef void (*dr_release_t___37)(struct device___213 *, void *);

typedef int (*dr_match_t___27)(struct device___213 *, void *, void *);

struct platform_device___42 {
	const char *name;
	int id;
	bool id_auto;
	struct device___213 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___36 {
	int (*probe)(struct platform_device___42 *);
	int (*remove)(struct platform_device___42 *);
	void (*shutdown)(struct platform_device___42 *);
	int (*suspend)(struct platform_device___42 *, pm_message_t);
	int (*resume)(struct platform_device___42 *);
	struct device_driver___213 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

struct scmi_xfer_ops___2;

struct scmi_protocol_handle___2 {
	struct device___213 *dev;
	const struct scmi_xfer_ops___2 *xops;
	int (*set_priv)(const struct scmi_protocol_handle___2 *, void *);
	void * (*get_priv)(const struct scmi_protocol_handle___2 *);
};

struct scmi_device___2;

struct scmi_handle___2;

struct scmi_notify_ops___2 {
	int (*devm_event_notifier_register)(struct scmi_device___2 *, u8, u8, const u32 *, struct notifier_block *);
	int (*devm_event_notifier_unregister)(struct scmi_device___2 *, u8, u8, const u32 *, struct notifier_block *);
	int (*event_notifier_register)(const struct scmi_handle___2 *, u8, u8, const u32 *, struct notifier_block *);
	int (*event_notifier_unregister)(const struct scmi_handle___2 *, u8, u8, const u32 *, struct notifier_block *);
};

struct scmi_device___2 {
	u32 id;
	u8 protocol_id;
	const char *name;
	struct device___213 dev;
	struct scmi_handle___2 *handle;
};

struct scmi_handle___2 {
	struct device___213 *dev;
	struct scmi_revision_info *version;
	const void * (*devm_protocol_get)(struct scmi_device___2 *, u8, struct scmi_protocol_handle___2 **);
	void (*devm_protocol_put)(struct scmi_device___2 *, u8);
	const struct scmi_notify_ops___2 *notify_ops;
};

enum scmi_std_protocol {
	SCMI_PROTOCOL_BASE = 16,
	SCMI_PROTOCOL_POWER = 17,
	SCMI_PROTOCOL_SYSTEM = 18,
	SCMI_PROTOCOL_PERF = 19,
	SCMI_PROTOCOL_CLOCK = 20,
	SCMI_PROTOCOL_SENSOR = 21,
	SCMI_PROTOCOL_RESET = 22,
	SCMI_PROTOCOL_VOLTAGE = 23,
};

struct scmi_event_ops___2 {
	int (*get_num_sources)(const struct scmi_protocol_handle___2 *);
	int (*set_notify_enabled)(const struct scmi_protocol_handle___2 *, u8, u32, bool);
	void * (*fill_custom_report)(const struct scmi_protocol_handle___2 *, u8, ktime_t, const void *, size_t, void *, u32 *);
};

struct scmi_protocol_events___2 {
	size_t queue_sz;
	const struct scmi_event_ops___2 *ops;
	const struct scmi_event *evts;
	unsigned int num_events;
	unsigned int num_sources;
};

enum scmi_common_cmd {
	PROTOCOL_VERSION = 0,
	PROTOCOL_ATTRIBUTES = 1,
	PROTOCOL_MESSAGE_ATTRIBUTES = 2,
};

struct scmi_xfer_ops___2 {
	int (*version_get)(const struct scmi_protocol_handle___2 *, u32 *);
	int (*xfer_get_init)(const struct scmi_protocol_handle___2 *, u8, size_t, size_t, struct scmi_xfer **);
	void (*reset_rx_to_maxsz)(const struct scmi_protocol_handle___2 *, struct scmi_xfer *);
	int (*do_xfer)(const struct scmi_protocol_handle___2 *, struct scmi_xfer *);
	int (*do_xfer_with_response)(const struct scmi_protocol_handle___2 *, struct scmi_xfer *);
	void (*xfer_put)(const struct scmi_protocol_handle___2 *, struct scmi_xfer *);
};

typedef int (*scmi_prot_init_ph_fn_t___2)(const struct scmi_protocol_handle___2 *);

struct scmi_protocol___2 {
	const u8 id;
	struct module___218 *owner;
	const scmi_prot_init_ph_fn_t___2 instance_init;
	const scmi_prot_init_ph_fn_t___2 instance_deinit;
	const void *ops;
	const struct scmi_protocol_events___2 *events;
};

struct scmi_chan_info {
	struct device___213 *dev;
	struct scmi_handle___2 *handle;
	void *transport_info;
};

struct scmi_transport_ops {
	int (*link_supplier)(struct device___213 *);
	bool (*chan_available)(struct device___213 *, int);
	int (*chan_setup)(struct scmi_chan_info *, struct device___213 *, bool);
	int (*chan_free)(int, void *, void *);
	unsigned int (*get_max_msg)(struct scmi_chan_info *);
	int (*send_message)(struct scmi_chan_info *, struct scmi_xfer *);
	void (*mark_txdone)(struct scmi_chan_info *, int);
	void (*fetch_response)(struct scmi_chan_info *, struct scmi_xfer *);
	void (*fetch_notification)(struct scmi_chan_info *, size_t, struct scmi_xfer *);
	void (*clear_channel)(struct scmi_chan_info *);
	bool (*poll_done)(struct scmi_chan_info *, struct scmi_xfer *);
};

struct scmi_desc {
	int (*transport_init)();
	void (*transport_exit)();
	const struct scmi_transport_ops *ops;
	int max_rx_timeout_ms;
	int max_msg;
	int max_msg_size;
};

struct trace_event_raw_scmi_xfer_begin {
	struct trace_entry ent;
	int transfer_id;
	u8 msg_id;
	u8 protocol_id;
	u16 seq;
	bool poll;
	char __data[0];
};

struct trace_event_raw_scmi_xfer_end {
	struct trace_entry ent;
	int transfer_id;
	u8 msg_id;
	u8 protocol_id;
	u16 seq;
	int status;
	char __data[0];
};

struct trace_event_raw_scmi_rx_done {
	struct trace_entry ent;
	int transfer_id;
	u8 msg_id;
	u8 protocol_id;
	u16 seq;
	u8 msg_type;
	char __data[0];
};

struct trace_event_data_offsets_scmi_xfer_begin {};

struct trace_event_data_offsets_scmi_xfer_end {};

struct trace_event_data_offsets_scmi_rx_done {};

typedef void (*btf_trace_scmi_xfer_begin)(void *, int, u8, u8, u16, bool);

typedef void (*btf_trace_scmi_xfer_end)(void *, int, u8, u8, u16, int);

typedef void (*btf_trace_scmi_rx_done)(void *, int, u8, u8, u16, u8);

enum scmi_error_codes {
	SCMI_SUCCESS = 0,
	SCMI_ERR_SUPPORT = 4294967295,
	SCMI_ERR_PARAMS = 4294967294,
	SCMI_ERR_ACCESS = 4294967293,
	SCMI_ERR_ENTRY = 4294967292,
	SCMI_ERR_RANGE = 4294967291,
	SCMI_ERR_BUSY = 4294967290,
	SCMI_ERR_COMMS = 4294967289,
	SCMI_ERR_GENERIC = 4294967288,
	SCMI_ERR_HARDWARE = 4294967287,
	SCMI_ERR_PROTOCOL = 4294967286,
};

struct scmi_requested_dev {
	const struct scmi_device_id *id_table;
	struct list_head node;
};

struct scmi_xfers_info {
	long unsigned int *xfer_alloc_table;
	spinlock_t xfer_lock;
	int max_msg;
	struct hlist_head free_xfers;
	struct hlist_head pending_xfers[512];
};

struct scmi_protocol_instance {
	const struct scmi_handle___2 *handle;
	const struct scmi_protocol___2 *proto;
	void *gid;
	refcount_t users;
	void *priv;
	struct scmi_protocol_handle___2 ph;
};

struct scmi_info {
	struct device___213 *dev;
	const struct scmi_desc *desc;
	struct scmi_revision_info version;
	struct scmi_handle___2 handle;
	struct scmi_xfers_info tx_minfo;
	struct scmi_xfers_info rx_minfo;
	struct idr tx_idr;
	struct idr rx_idr;
	struct idr protocols;
	struct mutex protocols_mtx;
	u8 *protocols_imp;
	struct idr active_protocols;
	void *notify_priv;
	struct list_head node;
	int users;
};

struct scmi_protocol_devres {
	const struct scmi_handle___2 *handle;
	u8 protocol_id;
};

typedef void (*dr_release_t___38)(struct device___216 *, void *);

typedef int (*dr_match_t___28)(struct device___216 *, void *, void *);

struct scmi_registered_events_desc;

struct scmi_notify_instance {
	void *gid;
	struct scmi_handle___2 *handle;
	struct work_struct init_work;
	struct workqueue_struct *notify_wq;
	struct mutex pending_mtx;
	struct scmi_registered_events_desc **registered_protocols;
	struct hlist_head pending_events_handlers[16];
};

struct events_queue {
	size_t sz;
	struct kfifo kfifo;
	struct work_struct notify_work;
	struct workqueue_struct *wq;
};

struct scmi_event_header;

struct scmi_registered_event;

struct scmi_registered_events_desc {
	u8 id;
	const struct scmi_event_ops___2 *ops;
	struct events_queue equeue;
	struct scmi_notify_instance *ni;
	struct scmi_event_header *eh;
	size_t eh_sz;
	void *in_flight;
	int num_events;
	struct scmi_registered_event **registered_events;
	struct mutex registered_mtx;
	const struct scmi_protocol_handle___2 *ph;
	struct hlist_head registered_events_handlers[64];
};

struct scmi_event_header {
	ktime_t timestamp;
	size_t payld_sz;
	unsigned char evt_id;
	unsigned char payld[0];
};

struct scmi_registered_event {
	struct scmi_registered_events_desc *proto;
	const struct scmi_event *evt;
	void *report;
	u32 num_sources;
	refcount_t *sources;
	struct mutex sources_mtx;
};

struct scmi_event_handler {
	u32 key;
	refcount_t users;
	struct scmi_registered_event *r_evt;
	struct blocking_notifier_head chain;
	struct hlist_node hash;
	bool enabled;
};

struct scmi_notifier_devres {
	const struct scmi_handle___2 *handle;
	u8 proto_id;
	u8 evt_id;
	u32 __src_id;
	u32 *src_id;
	struct notifier_block *nb;
};

enum scmi_notification_events {
	SCMI_EVENT_POWER_STATE_CHANGED = 0,
	SCMI_EVENT_PERFORMANCE_LIMITS_CHANGED = 0,
	SCMI_EVENT_PERFORMANCE_LEVEL_CHANGED = 1,
	SCMI_EVENT_SENSOR_TRIP_POINT_EVENT = 0,
	SCMI_EVENT_SENSOR_UPDATE = 1,
	SCMI_EVENT_RESET_ISSUED = 0,
	SCMI_EVENT_BASE_ERROR_EVENT = 0,
	SCMI_EVENT_SYSTEM_POWER_STATE_NOTIFIER = 0,
};

struct scmi_base_error_report {
	ktime_t timestamp;
	unsigned int agent_id;
	bool fatal;
	unsigned int cmd_count;
	long long unsigned int reports[0];
};

enum scmi_base_protocol_cmd {
	BASE_DISCOVER_VENDOR = 3,
	BASE_DISCOVER_SUB_VENDOR = 4,
	BASE_DISCOVER_IMPLEMENT_VERSION = 5,
	BASE_DISCOVER_LIST_PROTOCOLS = 6,
	BASE_DISCOVER_AGENT = 7,
	BASE_NOTIFY_ERRORS = 8,
	BASE_SET_DEVICE_PERMISSIONS = 9,
	BASE_SET_PROTOCOL_PERMISSIONS = 10,
	BASE_RESET_AGENT_CONFIGURATION = 11,
};

struct scmi_msg_resp_base_attributes {
	u8 num_protocols;
	u8 num_agents;
	__le16 reserved;
};

struct scmi_msg_resp_base_discover_agent {
	__le32 agent_id;
	u8 name[16];
};

struct scmi_msg_base_error_notify {
	__le32 event_control;
};

struct scmi_base_error_notify_payld {
	__le32 agent_id;
	__le32 error_status;
	__le64 msg_reports[1024];
};

struct scmi_clock_info {
	char name[16];
	bool rate_discrete;
	union {
		struct {
			int num_rates;
			u64 rates[16];
		} list;
		struct {
			u64 min_rate;
			u64 max_rate;
			u64 step_size;
		} range;
	};
};

struct scmi_clk_proto_ops {
	int (*count_get)(const struct scmi_protocol_handle___2 *);
	const struct scmi_clock_info * (*info_get)(const struct scmi_protocol_handle___2 *, u32);
	int (*rate_get)(const struct scmi_protocol_handle___2 *, u32, u64 *);
	int (*rate_set)(const struct scmi_protocol_handle___2 *, u32, u64);
	int (*enable)(const struct scmi_protocol_handle___2 *, u32);
	int (*disable)(const struct scmi_protocol_handle___2 *, u32);
};

enum scmi_clock_protocol_cmd {
	CLOCK_ATTRIBUTES = 3,
	CLOCK_DESCRIBE_RATES = 4,
	CLOCK_RATE_SET = 5,
	CLOCK_RATE_GET = 6,
	CLOCK_CONFIG_SET = 7,
};

struct scmi_msg_resp_clock_protocol_attributes {
	__le16 num_clocks;
	u8 max_async_req;
	u8 reserved;
};

struct scmi_msg_resp_clock_attributes {
	__le32 attributes;
	u8 name[16];
};

struct scmi_clock_set_config {
	__le32 id;
	__le32 attributes;
};

struct scmi_msg_clock_describe_rates {
	__le32 id;
	__le32 rate_index;
};

struct scmi_msg_resp_clock_describe_rates {
	__le32 num_rates_flags;
	struct {
		__le32 value_low;
		__le32 value_high;
	} rate[0];
};

struct scmi_clock_set_rate {
	__le32 flags;
	__le32 id;
	__le32 value_low;
	__le32 value_high;
};

struct clock_info {
	u32 version;
	int num_clocks;
	int max_async_req;
	atomic_t cur_async_req;
	struct scmi_clock_info *clk;
};

struct scmi_perf_proto_ops {
	int (*limits_set)(const struct scmi_protocol_handle___2 *, u32, u32, u32);
	int (*limits_get)(const struct scmi_protocol_handle___2 *, u32, u32 *, u32 *);
	int (*level_set)(const struct scmi_protocol_handle___2 *, u32, u32, bool);
	int (*level_get)(const struct scmi_protocol_handle___2 *, u32, u32 *, bool);
	int (*device_domain_id)(struct device___214 *);
	int (*transition_latency_get)(const struct scmi_protocol_handle___2 *, struct device___214 *);
	int (*device_opps_add)(const struct scmi_protocol_handle___2 *, struct device___214 *);
	int (*freq_set)(const struct scmi_protocol_handle___2 *, u32, long unsigned int, bool);
	int (*freq_get)(const struct scmi_protocol_handle___2 *, u32, long unsigned int *, bool);
	int (*est_power_get)(const struct scmi_protocol_handle___2 *, u32, long unsigned int *, long unsigned int *);
	bool (*fast_switch_possible)(const struct scmi_protocol_handle___2 *, struct device___214 *);
	bool (*power_scale_mw_get)(const struct scmi_protocol_handle___2 *);
};

struct scmi_perf_limits_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int domain_id;
	unsigned int range_max;
	unsigned int range_min;
};

struct scmi_perf_level_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int domain_id;
	unsigned int performance_level;
};

enum scmi_performance_protocol_cmd {
	PERF_DOMAIN_ATTRIBUTES = 3,
	PERF_DESCRIBE_LEVELS = 4,
	PERF_LIMITS_SET = 5,
	PERF_LIMITS_GET = 6,
	PERF_LEVEL_SET = 7,
	PERF_LEVEL_GET = 8,
	PERF_NOTIFY_LIMITS = 9,
	PERF_NOTIFY_LEVEL = 10,
	PERF_DESCRIBE_FASTCHANNEL = 11,
};

struct scmi_opp {
	u32 perf;
	u32 power;
	u32 trans_latency_us;
};

struct scmi_msg_resp_perf_attributes {
	__le16 num_domains;
	__le16 flags;
	__le32 stats_addr_low;
	__le32 stats_addr_high;
	__le32 stats_size;
};

struct scmi_msg_resp_perf_domain_attributes {
	__le32 flags;
	__le32 rate_limit_us;
	__le32 sustained_freq_khz;
	__le32 sustained_perf_level;
	u8 name[16];
};

struct scmi_msg_perf_describe_levels {
	__le32 domain;
	__le32 level_index;
};

struct scmi_perf_set_limits {
	__le32 domain;
	__le32 max_level;
	__le32 min_level;
};

struct scmi_perf_get_limits {
	__le32 max_level;
	__le32 min_level;
};

struct scmi_perf_set_level {
	__le32 domain;
	__le32 level;
};

struct scmi_perf_notify_level_or_limits {
	__le32 domain;
	__le32 notify_enable;
};

struct scmi_perf_limits_notify_payld {
	__le32 agent_id;
	__le32 domain_id;
	__le32 range_max;
	__le32 range_min;
};

struct scmi_perf_level_notify_payld {
	__le32 agent_id;
	__le32 domain_id;
	__le32 performance_level;
};

struct scmi_msg_resp_perf_describe_levels {
	__le16 num_returned;
	__le16 num_remaining;
	struct {
		__le32 perf_val;
		__le32 power;
		__le16 transition_latency_us;
		__le16 reserved;
	} opp[0];
};

struct scmi_perf_get_fc_info {
	__le32 domain;
	__le32 message_id;
};

struct scmi_msg_resp_perf_desc_fc {
	__le32 attr;
	__le32 rate_limit;
	__le32 chan_addr_low;
	__le32 chan_addr_high;
	__le32 chan_size;
	__le32 db_addr_low;
	__le32 db_addr_high;
	__le32 db_set_lmask;
	__le32 db_set_hmask;
	__le32 db_preserve_lmask;
	__le32 db_preserve_hmask;
};

struct scmi_fc_db_info {
	int width;
	u64 set;
	u64 mask;
	void *addr;
};

struct scmi_fc_info {
	void *level_set_addr;
	void *limit_set_addr;
	void *level_get_addr;
	void *limit_get_addr;
	struct scmi_fc_db_info *level_set_db;
	struct scmi_fc_db_info *limit_set_db;
};

struct perf_dom_info {
	bool set_limits;
	bool set_perf;
	bool perf_limit_notify;
	bool perf_level_notify;
	bool perf_fastchannels;
	u32 opp_count;
	u32 sustained_freq_khz;
	u32 sustained_perf_level;
	u32 mult_factor;
	char name[16];
	struct scmi_opp opp[16];
	struct scmi_fc_info *fc_info;
};

struct scmi_perf_info {
	u32 version;
	int num_domains;
	bool power_scale_mw;
	u64 stats_addr;
	u32 stats_size;
	struct perf_dom_info *dom_info;
};

struct scmi_power_proto_ops {
	int (*num_domains_get)(const struct scmi_protocol_handle___2 *);
	char * (*name_get)(const struct scmi_protocol_handle___2 *, u32);
	int (*state_set)(const struct scmi_protocol_handle___2 *, u32, u32);
	int (*state_get)(const struct scmi_protocol_handle___2 *, u32, u32 *);
};

struct scmi_power_state_changed_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int domain_id;
	unsigned int power_state;
};

enum scmi_power_protocol_cmd {
	POWER_DOMAIN_ATTRIBUTES = 3,
	POWER_STATE_SET = 4,
	POWER_STATE_GET = 5,
	POWER_STATE_NOTIFY = 6,
};

struct scmi_msg_resp_power_attributes {
	__le16 num_domains;
	__le16 reserved;
	__le32 stats_addr_low;
	__le32 stats_addr_high;
	__le32 stats_size;
};

struct scmi_msg_resp_power_domain_attributes {
	__le32 flags;
	u8 name[16];
};

struct scmi_power_set_state {
	__le32 flags;
	__le32 domain;
	__le32 state;
};

struct scmi_power_state_notify {
	__le32 domain;
	__le32 notify_enable;
};

struct scmi_power_state_notify_payld {
	__le32 agent_id;
	__le32 domain_id;
	__le32 power_state;
};

struct power_dom_info {
	bool state_set_sync;
	bool state_set_async;
	bool state_set_notify;
	char name[16];
};

struct scmi_power_info {
	u32 version;
	int num_domains;
	u64 stats_addr;
	u32 stats_size;
	struct power_dom_info *dom_info;
};

struct scmi_reset_proto_ops {
	int (*num_domains_get)(const struct scmi_protocol_handle___2 *);
	char * (*name_get)(const struct scmi_protocol_handle___2 *, u32);
	int (*latency_get)(const struct scmi_protocol_handle___2 *, u32);
	int (*reset)(const struct scmi_protocol_handle___2 *, u32);
	int (*assert)(const struct scmi_protocol_handle___2 *, u32);
	int (*deassert)(const struct scmi_protocol_handle___2 *, u32);
};

struct scmi_reset_issued_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int domain_id;
	unsigned int reset_state;
};

enum scmi_reset_protocol_cmd {
	RESET_DOMAIN_ATTRIBUTES = 3,
	RESET = 4,
	RESET_NOTIFY = 5,
};

struct scmi_msg_resp_reset_domain_attributes {
	__le32 attributes;
	__le32 latency;
	u8 name[16];
};

struct scmi_msg_reset_domain_reset {
	__le32 domain_id;
	__le32 flags;
	__le32 reset_state;
};

struct scmi_msg_reset_notify {
	__le32 id;
	__le32 event_control;
};

struct scmi_reset_issued_notify_payld {
	__le32 agent_id;
	__le32 domain_id;
	__le32 reset_state;
};

struct reset_dom_info {
	bool async_reset;
	bool reset_notify;
	u32 latency_us;
	char name[16];
};

struct scmi_reset_info {
	u32 version;
	int num_domains;
	struct reset_dom_info *dom_info;
};

struct scmi_sensor_reading {
	long long int value;
	long long unsigned int timestamp;
};

struct scmi_range_attrs {
	long long int min_range;
	long long int max_range;
};

struct scmi_sensor_axis_info {
	unsigned int id;
	unsigned int type;
	int scale;
	char name[16];
	bool extended_attrs;
	unsigned int resolution;
	int exponent;
	struct scmi_range_attrs attrs;
};

struct scmi_sensor_intervals_info {
	bool segmented;
	unsigned int count;
	unsigned int *desc;
	unsigned int prealloc_pool[16];
};

struct scmi_sensor_info {
	unsigned int id;
	unsigned int type;
	int scale;
	unsigned int num_trip_points;
	bool async;
	bool update;
	bool timestamped;
	int tstamp_scale;
	unsigned int num_axis;
	struct scmi_sensor_axis_info *axis;
	struct scmi_sensor_intervals_info intervals;
	unsigned int sensor_config;
	char name[16];
	bool extended_scalar_attrs;
	unsigned int sensor_power;
	unsigned int resolution;
	int exponent;
	struct scmi_range_attrs scalar_attrs;
};

struct scmi_sensor_proto_ops {
	int (*count_get)(const struct scmi_protocol_handle___2 *);
	const struct scmi_sensor_info * (*info_get)(const struct scmi_protocol_handle___2 *, u32);
	int (*trip_point_config)(const struct scmi_protocol_handle___2 *, u32, u8, u64);
	int (*reading_get)(const struct scmi_protocol_handle___2 *, u32, u64 *);
	int (*reading_get_timestamped)(const struct scmi_protocol_handle___2 *, u32, u8, struct scmi_sensor_reading *);
	int (*config_get)(const struct scmi_protocol_handle___2 *, u32, u32 *);
	int (*config_set)(const struct scmi_protocol_handle___2 *, u32, u32);
};

struct scmi_sensor_trip_point_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int sensor_id;
	unsigned int trip_point_desc;
};

struct scmi_sensor_update_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int sensor_id;
	unsigned int readings_count;
	struct scmi_sensor_reading readings[0];
};

enum scmi_sensor_protocol_cmd {
	SENSOR_DESCRIPTION_GET = 3,
	SENSOR_TRIP_POINT_NOTIFY = 4,
	SENSOR_TRIP_POINT_CONFIG = 5,
	SENSOR_READING_GET = 6,
	SENSOR_AXIS_DESCRIPTION_GET = 7,
	SENSOR_LIST_UPDATE_INTERVALS = 8,
	SENSOR_CONFIG_GET = 9,
	SENSOR_CONFIG_SET = 10,
	SENSOR_CONTINUOUS_UPDATE_NOTIFY = 11,
};

struct scmi_msg_resp_sensor_attributes {
	__le16 num_sensors;
	u8 max_requests;
	u8 reserved;
	__le32 reg_addr_low;
	__le32 reg_addr_high;
	__le32 reg_size;
};

struct scmi_msg_resp_attrs {
	__le32 min_range_low;
	__le32 min_range_high;
	__le32 max_range_low;
	__le32 max_range_high;
};

struct scmi_sensor_descriptor {
	__le32 id;
	__le32 attributes_low;
	__le32 attributes_high;
	u8 name[16];
	__le32 power;
	__le32 resolution;
	struct scmi_msg_resp_attrs scalar_attrs;
};

struct scmi_msg_resp_sensor_description {
	__le16 num_returned;
	__le16 num_remaining;
	struct scmi_sensor_descriptor desc[0];
};

struct scmi_msg_sensor_axis_description_get {
	__le32 id;
	__le32 axis_desc_index;
};

struct scmi_axis_descriptor {
	__le32 id;
	__le32 attributes_low;
	__le32 attributes_high;
	u8 name[16];
	__le32 resolution;
	struct scmi_msg_resp_attrs attrs;
};

struct scmi_msg_resp_sensor_axis_description {
	__le32 num_axis_flags;
	struct scmi_axis_descriptor desc[0];
};

struct scmi_msg_sensor_list_update_intervals {
	__le32 id;
	__le32 index;
};

struct scmi_msg_resp_sensor_list_update_intervals {
	__le32 num_intervals_flags;
	__le32 intervals[0];
};

struct scmi_msg_sensor_request_notify {
	__le32 id;
	__le32 event_control;
};

struct scmi_msg_set_sensor_trip_point {
	__le32 id;
	__le32 event_control;
	__le32 value_low;
	__le32 value_high;
};

struct scmi_msg_sensor_config_set {
	__le32 id;
	__le32 sensor_config;
};

struct scmi_msg_sensor_reading_get {
	__le32 id;
	__le32 flags;
};

struct scmi_resp_sensor_reading_complete {
	__le32 id;
	__le32 readings_low;
	__le32 readings_high;
};

struct scmi_sensor_reading_resp {
	__le32 sensor_value_low;
	__le32 sensor_value_high;
	__le32 timestamp_low;
	__le32 timestamp_high;
};

struct scmi_resp_sensor_reading_complete_v3 {
	__le32 id;
	struct scmi_sensor_reading_resp readings[0];
};

struct scmi_sensor_trip_notify_payld {
	__le32 agent_id;
	__le32 sensor_id;
	__le32 trip_point_desc;
};

struct scmi_sensor_update_notify_payld {
	__le32 agent_id;
	__le32 sensor_id;
	struct scmi_sensor_reading_resp readings[0];
};

struct sensors_info {
	u32 version;
	int num_sensors;
	int max_requests;
	u64 reg_addr;
	u32 reg_size;
	struct scmi_sensor_info *sensors;
};

struct scmi_system_power_state_notifier_report {
	ktime_t timestamp;
	unsigned int agent_id;
	unsigned int flags;
	unsigned int system_state;
};

enum scmi_system_protocol_cmd {
	SYSTEM_POWER_STATE_NOTIFY = 5,
};

struct scmi_system_power_state_notify {
	__le32 notify_enable;
};

struct scmi_system_power_state_notifier_payld {
	__le32 agent_id;
	__le32 flags;
	__le32 system_state;
};

struct scmi_system_info {
	u32 version;
};

struct scmi_voltage_info {
	unsigned int id;
	bool segmented;
	bool negative_volts_allowed;
	unsigned int attributes;
	char name[16];
	unsigned int num_levels;
	int *levels_uv;
};

struct scmi_voltage_proto_ops {
	int (*num_domains_get)(const struct scmi_protocol_handle___2 *);
	const struct scmi_voltage_info * (*info_get)(const struct scmi_protocol_handle___2 *, u32);
	int (*config_set)(const struct scmi_protocol_handle___2 *, u32, u32);
	int (*config_get)(const struct scmi_protocol_handle___2 *, u32, u32 *);
	int (*level_set)(const struct scmi_protocol_handle___2 *, u32, u32, s32);
	int (*level_get)(const struct scmi_protocol_handle___2 *, u32, s32 *);
};

enum scmi_voltage_protocol_cmd {
	VOLTAGE_DOMAIN_ATTRIBUTES = 3,
	VOLTAGE_DESCRIBE_LEVELS = 4,
	VOLTAGE_CONFIG_SET = 5,
	VOLTAGE_CONFIG_GET = 6,
	VOLTAGE_LEVEL_SET = 7,
	VOLTAGE_LEVEL_GET = 8,
};

struct scmi_msg_resp_domain_attributes {
	__le32 attr;
	u8 name[16];
};

struct scmi_msg_cmd_describe_levels {
	__le32 domain_id;
	__le32 level_index;
};

struct scmi_msg_resp_describe_levels {
	__le32 flags;
	__le32 voltage[0];
};

struct scmi_msg_cmd_config_set {
	__le32 domain_id;
	__le32 config;
};

struct scmi_msg_cmd_level_set {
	__le32 domain_id;
	__le32 flags;
	__le32 voltage_level;
};

struct voltage_info {
	unsigned int version;
	unsigned int num_domains;
	struct scmi_voltage_info *domains;
};

struct scmi_xfer___2 {
	int transfer_id;
	struct scmi_msg_hdr hdr;
	struct scmi_msg tx;
	struct scmi_msg rx;
	struct completion___2 done;
	struct completion___2 *async_done;
	bool pending;
	struct hlist_node node;
	refcount_t users;
	atomic_t busy;
	int state;
	spinlock_t___2 lock;
	void *priv;
};

struct scmi_shared_mem {
	__le32 reserved;
	__le32 channel_status;
	__le32 reserved1[2];
	__le32 flags;
	__le32 length;
	__le32 msg_header;
	u8 msg_payload[0];
};

struct scmi_xfer_ops___3;

struct scmi_protocol_handle___3 {
	struct device___215 *dev;
	const struct scmi_xfer_ops___3 *xops;
	int (*set_priv)(const struct scmi_protocol_handle___3 *, void *);
	void * (*get_priv)(const struct scmi_protocol_handle___3 *);
};

struct scmi_device___3;

struct scmi_handle___3;

struct scmi_notify_ops___3 {
	int (*devm_event_notifier_register)(struct scmi_device___3 *, u8, u8, const u32 *, struct notifier_block *);
	int (*devm_event_notifier_unregister)(struct scmi_device___3 *, u8, u8, const u32 *, struct notifier_block *);
	int (*event_notifier_register)(const struct scmi_handle___3 *, u8, u8, const u32 *, struct notifier_block *);
	int (*event_notifier_unregister)(const struct scmi_handle___3 *, u8, u8, const u32 *, struct notifier_block *);
};

struct scmi_device___3 {
	u32 id;
	u8 protocol_id;
	const char *name;
	struct device___215 dev;
	struct scmi_handle___3 *handle;
};

struct scmi_handle___3 {
	struct device___215 *dev;
	struct scmi_revision_info *version;
	const void * (*devm_protocol_get)(struct scmi_device___3 *, u8, struct scmi_protocol_handle___3 **);
	void (*devm_protocol_put)(struct scmi_device___3 *, u8);
	const struct scmi_notify_ops___3 *notify_ops;
};

struct scmi_xfer_ops___3 {
	int (*version_get)(const struct scmi_protocol_handle___3 *, u32 *);
	int (*xfer_get_init)(const struct scmi_protocol_handle___3 *, u8, size_t, size_t, struct scmi_xfer **);
	void (*reset_rx_to_maxsz)(const struct scmi_protocol_handle___3 *, struct scmi_xfer *);
	int (*do_xfer)(const struct scmi_protocol_handle___3 *, struct scmi_xfer *);
	int (*do_xfer_with_response)(const struct scmi_protocol_handle___3 *, struct scmi_xfer *);
	void (*xfer_put)(const struct scmi_protocol_handle___3 *, struct scmi_xfer *);
};

struct scmi_chan_info___2 {
	struct device___215 *dev;
	struct scmi_handle___3 *handle;
	void *transport_info;
};

struct scmi_transport_ops___2 {
	int (*link_supplier)(struct device___215 *);
	bool (*chan_available)(struct device___215 *, int);
	int (*chan_setup)(struct scmi_chan_info___2 *, struct device___215 *, bool);
	int (*chan_free)(int, void *, void *);
	unsigned int (*get_max_msg)(struct scmi_chan_info___2 *);
	int (*send_message)(struct scmi_chan_info___2 *, struct scmi_xfer *);
	void (*mark_txdone)(struct scmi_chan_info___2 *, int);
	void (*fetch_response)(struct scmi_chan_info___2 *, struct scmi_xfer *);
	void (*fetch_notification)(struct scmi_chan_info___2 *, size_t, struct scmi_xfer *);
	void (*clear_channel)(struct scmi_chan_info___2 *);
	bool (*poll_done)(struct scmi_chan_info___2 *, struct scmi_xfer *);
};

struct scmi_desc___2 {
	int (*transport_init)();
	void (*transport_exit)();
	const struct scmi_transport_ops___2 *ops;
	int max_rx_timeout_ms;
	int max_msg;
	int max_msg_size;
};

struct scmi_shared_mem___2;

struct scmi_mailbox {
	struct mbox_client___4 cl;
	struct mbox_chan___2 *chan;
	struct scmi_chan_info___2 *cinfo;
	struct scmi_shared_mem___2 *shmem;
};

struct scmi_smc {
	struct scmi_chan_info___2 *cinfo;
	struct scmi_shared_mem___2 *shmem;
	struct mutex shmem_lock;
	u32 func_id;
	int irq;
	struct completion tx_complete;
};

struct scmi_msg_payld {
	__le32 msg_header;
	__le32 msg_payload[0];
};

struct scmi_vio_channel {
	struct virtqueue *vqueue;
	struct scmi_chan_info___2 *cinfo;
	struct list_head free_list;
	bool is_rx;
	bool ready;
	unsigned int max_msg;
	spinlock_t lock;
	spinlock_t ready_lock;
};

struct scmi_msg_payld___2;

struct scmi_vio_msg {
	struct scmi_msg_payld___2 *request;
	struct scmi_msg_payld___2 *input;
	struct list_head list;
	unsigned int rx_len;
};

struct meson_sm_cmd {
	unsigned int index;
	u32 smc_id;
};

struct meson_sm_chip {
	unsigned int shmem_size;
	u32 cmd_shmem_in_base;
	u32 cmd_shmem_out_base;
	struct meson_sm_cmd cmd[0];
};

struct meson_sm_firmware___2 {
	const struct meson_sm_chip *chip;
	void *sm_shmem_in_base;
	void *sm_shmem_out_base;
};

struct acpi_table_bgrt___2 {
	struct acpi_table_header header;
	u16 version;
	u8 status;
	u8 image_type;
	u64 image_address;
	u32 image_offset_x;
	u32 image_offset_y;
};

struct efi_memory_map___2 {
	phys_addr_t phys_map;
	void *map;
	void *map_end;
	int nr_map;
	long unsigned int desc_version;
	long unsigned int desc_size;
	long unsigned int flags;
};

struct efi___2 {
	const efi_runtime_services_t *runtime;
	unsigned int runtime_version;
	unsigned int runtime_supported_mask;
	long unsigned int acpi;
	long unsigned int acpi20;
	long unsigned int smbios;
	long unsigned int smbios3;
	long unsigned int esrt;
	long unsigned int tpm_log;
	long unsigned int tpm_final_log;
	long unsigned int mokvar_table;
	efi_get_time_t *get_time;
	efi_set_time_t *set_time;
	efi_get_wakeup_time_t *get_wakeup_time;
	efi_set_wakeup_time_t *set_wakeup_time;
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_set_variable_t *set_variable_nonblocking;
	efi_query_variable_info_t *query_variable_info;
	efi_query_variable_info_t *query_variable_info_nonblocking;
	efi_update_capsule_t *update_capsule;
	efi_query_capsule_caps_t *query_capsule_caps;
	efi_get_next_high_mono_count_t *get_next_high_mono_count;
	efi_reset_system_t *reset_system;
	struct efi_memory_map___2 memmap;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int flags;
};

struct bmp_header {
	u16 id;
	u32 size;
} __attribute__((packed));

struct kobj_attribute___13 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___53 *, struct kobj_attribute___13 *, char *);
	ssize_t (*store)(struct kobject___53 *, struct kobj_attribute___13 *, const char *, size_t);
};

typedef efi_status_t efi_query_variable_store_t(u32, long unsigned int, bool);

typedef struct {
	efi_guid_t guid;
	u64 table;
} efi_config_table_64_t;

typedef struct {
	efi_guid_t guid;
	u32 table;
} efi_config_table_32_t;

typedef union {
	struct {
		efi_guid_t guid;
		void *table;
	};
	efi_config_table_32_t mixed_mode;
} efi_config_table_t;

typedef struct {
	efi_guid_t guid;
	long unsigned int *ptr;
	const char name[16];
} efi_config_table_type_t;

typedef struct {
	u16 version;
	u16 length;
	u32 runtime_services_supported;
} efi_rt_properties_table_t;

struct efivar_operations {
	efi_get_variable_t *get_variable;
	efi_get_next_variable_t *get_next_variable;
	efi_set_variable_t *set_variable;
	efi_set_variable_t *set_variable_nonblocking;
	efi_query_variable_store_t *query_variable_store;
};

struct efivars {
	struct kset___53 *kset;
	struct kobject___53 *kobject;
	const struct efivar_operations *ops;
};

struct efivar_entry___3 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___53 kobj;
	bool scanning;
	bool deleting;
};

struct linux_efi_random_seed {
	u32 size;
	u8 bits[0];
};

struct linux_efi_memreserve {
	int size;
	atomic_t count;
	phys_addr_t next;
	struct {
		phys_addr_t base;
		phys_addr_t size;
	} entry[0];
};

struct platform_device_info___10 {
	struct device___24 *parent;
	struct fwnode_handle___24 *fwnode;
	bool of_node_reused;
	const char *name;
	int id;
	const struct resource *res;
	unsigned int num_res;
	const void *data;
	size_t size_data;
	u64 dma_mask;
	const struct property_entry *properties;
};

struct efi_error_code {
	efi_status_t status;
	int errno;
	const char *description;
};

struct efi_generic_dev_path {
	u8 type;
	u8 sub_type;
	u16 length;
};

struct efivars___2 {
	struct kset___14 *kset;
	struct kobject___14 *kobject;
	const struct efivar_operations *ops;
};

struct efivar_entry___4 {
	struct efi_variable var;
	struct list_head list;
	struct kobject___14 kobj;
	bool scanning;
	bool deleting;
};

struct variable_validate {
	efi_guid_t vendor;
	char *name;
	bool (*validate)(efi_char16_t *, int, u8 *, long unsigned int);
};

typedef struct {
	u32 version;
	u32 num_entries;
	u32 desc_size;
	u32 reserved;
	efi_memory_desc_t entry[0];
} efi_memory_attributes_table_t;

typedef int (*efi_memattr_perm_setter)(struct mm_struct___15 *, efi_memory_desc_t *);

struct efi_memory_map_data {
	phys_addr_t phys_map;
	long unsigned int size;
	long unsigned int desc_version;
	long unsigned int desc_size;
	long unsigned int flags;
};

struct efi_mem_range {
	struct range range;
	u64 attribute;
};

typedef u64 efi_physical_addr_t;

typedef struct {
	u64 length;
	u64 data;
} efi_capsule_block_desc_t;

enum efi_secureboot_mode {
	efi_secureboot_mode_unset = 0,
	efi_secureboot_mode_unknown = 1,
	efi_secureboot_mode_disabled = 2,
	efi_secureboot_mode_enabled = 3,
};

enum {
	SYSTAB = 0,
	MMBASE = 1,
	MMSIZE = 2,
	DCSIZE = 3,
	DCVERS = 4,
	SCBOOT = 5,
	PARAMCOUNT = 6,
};

struct kobj_attribute___14 {
	struct attribute attr;
	ssize_t (*show)(struct kobject___131 *, struct kobj_attribute___14 *, char *);
	ssize_t (*store)(struct kobject___131 *, struct kobj_attribute___14 *, const char *, size_t);
};

struct efi_system_resource_entry_v1 {
	efi_guid_t fw_class;
	u32 fw_type;
	u32 fw_version;
	u32 lowest_supported_fw_version;
	u32 capsule_flags;
	u32 last_attempt_version;
	u32 last_attempt_status;
};

struct efi_system_resource_table {
	u32 fw_resource_count;
	u32 fw_resource_count_max;
	u64 fw_resource_version;
	u8 entries[0];
};

struct esre_entry {
	union {
		struct efi_system_resource_entry_v1 *esre1;
	} esre;
	struct kobject___131 kobj;
	struct list_head list;
};

struct esre_attribute {
	struct attribute attr;
	ssize_t (*show)(struct esre_entry *, char *);
	ssize_t (*store)(struct esre_entry *, const char *, size_t);
};

struct cper_sec_proc_generic {
	u64 validation_bits;
	u8 proc_type;
	u8 proc_isa;
	u8 proc_error_type;
	u8 operation;
	u8 flags;
	u8 level;
	u16 reserved;
	u64 cpu_version;
	char cpu_brand[128];
	u64 proc_id;
	u64 target_addr;
	u64 requestor_id;
	u64 responder_id;
	u64 ip;
};

struct cper_mem_err_compact {
	u64 validation_bits;
	u16 node;
	u16 card;
	u16 module;
	u16 bank;
	u16 device;
	u16 row;
	u16 column;
	u16 bit_pos;
	u64 requestor_id;
	u64 responder_id;
	u64 target_id;
	u16 rank;
	u16 mem_array_handle;
	u16 mem_dev_handle;
	u8 extended;
} __attribute__((packed));

struct cper_sec_fw_err_rec_ref {
	u8 record_type;
	u8 revision;
	u8 reserved[6];
	u64 record_identifier;
	guid_t record_identifier_guid;
};

enum efi_rts_ids {
	EFI_NONE = 0,
	EFI_GET_TIME = 1,
	EFI_SET_TIME = 2,
	EFI_GET_WAKEUP_TIME = 3,
	EFI_SET_WAKEUP_TIME = 4,
	EFI_GET_VARIABLE = 5,
	EFI_GET_NEXT_VARIABLE = 6,
	EFI_SET_VARIABLE = 7,
	EFI_QUERY_VARIABLE_INFO = 8,
	EFI_GET_NEXT_HIGH_MONO_COUNT = 9,
	EFI_RESET_SYSTEM = 10,
	EFI_UPDATE_CAPSULE = 11,
	EFI_QUERY_CAPSULE_CAPS = 12,
};

struct efi_runtime_work {
	void *arg1;
	void *arg2;
	void *arg3;
	void *arg4;
	void *arg5;
	efi_status_t status;
	struct work_struct work;
	enum efi_rts_ids efi_rts_id;
	struct completion efi_rts_comp;
};

struct efi_mokvar_sysfs_attr {
	struct bin_attribute___14 bin_attr;
	struct list_head node;
};

struct of_pci_range_parser___2 {
	struct device_node___10 *node;
	struct of_bus *bus;
	const __be32 *range;
	const __be32 *end;
	int na;
	int ns;
	int pna;
	bool dma;
};

struct pci_bus___21;

struct pci_slot___21 {
	struct pci_bus___21 *bus;
	struct list_head list;
	struct hotplug_slot *hotplug;
	unsigned char number;
	struct kobject___17 kobj;
};

struct pci_dev___22;

struct pci_ops___21;

struct pci_bus___21 {
	struct list_head node;
	struct pci_bus___21 *parent;
	struct list_head children;
	struct list_head devices;
	struct pci_dev___22 *self;
	struct list_head slots;
	struct resource *resource[4];
	struct list_head resources;
	struct resource busn_res;
	struct pci_ops___21 *ops;
	void *sysdata;
	struct proc_dir_entry *procdir;
	unsigned char number;
	unsigned char primary;
	unsigned char max_bus_speed;
	unsigned char cur_bus_speed;
	int domain_nr;
	char name[48];
	short unsigned int bridge_ctl;
	pci_bus_flags_t bus_flags;
	struct device___15 *bridge;
	struct device___15 dev;
	struct bin_attribute___17 *legacy_io;
	struct bin_attribute___17 *legacy_mem;
	unsigned int is_added: 1;
	unsigned int unsafe_warn: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pci_driver___21;

struct pci_dev___22 {
	struct list_head bus_list;
	struct pci_bus___21 *bus;
	struct pci_bus___21 *subordinate;
	void *sysdata;
	struct proc_dir_entry *procent;
	struct pci_slot___21 *slot;
	unsigned int devfn;
	short unsigned int vendor;
	short unsigned int device;
	short unsigned int subsystem_vendor;
	short unsigned int subsystem_device;
	unsigned int class;
	u8 revision;
	u8 hdr_type;
	u16 aer_cap;
	struct aer_stats *aer_stats;
	struct rcec_ea *rcec_ea;
	struct pci_dev___22 *rcec;
	u32 devcap;
	u8 pcie_cap;
	u8 msi_cap;
	u8 msix_cap;
	u8 pcie_mpss: 3;
	long: 61;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 rom_base_reg;
	u8 pin;
	u16 pcie_flags_reg;
	long unsigned int *dma_alias_mask;
	struct pci_driver___21 *driver;
	u64 dma_mask;
	struct device_dma_parameters dma_parms;
	pci_power_t current_state;
	unsigned int imm_ready: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 pm_cap;
	unsigned int pme_support: 5;
	unsigned int pme_poll: 1;
	unsigned int d1_support: 1;
	unsigned int d2_support: 1;
	unsigned int no_d1d2: 1;
	unsigned int no_d3cold: 1;
	unsigned int bridge_d3: 1;
	unsigned int d3cold_allowed: 1;
	unsigned int mmio_always_on: 1;
	unsigned int wakeup_prepared: 1;
	unsigned int runtime_d3cold: 1;
	unsigned int skip_bus_pm: 1;
	unsigned int ignore_hotplug: 1;
	unsigned int hotplug_user_indicators: 1;
	unsigned int clear_retrain_link: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int d3hot_delay;
	unsigned int d3cold_delay;
	struct pcie_link_state *link_state;
	unsigned int ltr_path: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 l1ss;
	unsigned int pasid_no_tlp: 1;
	unsigned int eetlp_prefix_path: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_channel_state_t error_state;
	struct device___15 dev;
	int cfg_size;
	unsigned int irq;
	struct resource resource[17];
	bool match_driver;
	unsigned int transparent: 1;
	unsigned int io_window: 1;
	unsigned int pref_window: 1;
	unsigned int pref_64_window: 1;
	unsigned int multifunction: 1;
	unsigned int is_busmaster: 1;
	unsigned int no_msi: 1;
	unsigned int no_64bit_msi: 1;
	unsigned int block_cfg_access: 1;
	unsigned int broken_parity_status: 1;
	unsigned int irq_reroute_variant: 2;
	unsigned int msi_enabled: 1;
	unsigned int msix_enabled: 1;
	unsigned int ari_enabled: 1;
	unsigned int ats_enabled: 1;
	unsigned int pasid_enabled: 1;
	unsigned int pri_enabled: 1;
	unsigned int is_managed: 1;
	unsigned int needs_freset: 1;
	unsigned int state_saved: 1;
	unsigned int is_physfn: 1;
	unsigned int is_virtfn: 1;
	unsigned int is_hotplug_bridge: 1;
	unsigned int shpc_managed: 1;
	unsigned int is_thunderbolt: 1;
	unsigned int untrusted: 1;
	unsigned int external_facing: 1;
	unsigned int broken_intx_masking: 1;
	unsigned int io_window_1k: 1;
	unsigned int irq_managed: 1;
	unsigned int non_compliant_bars: 1;
	unsigned int is_probed: 1;
	unsigned int link_active_reporting: 1;
	unsigned int no_vf_scan: 1;
	unsigned int no_command_memory: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	pci_dev_flags_t dev_flags;
	atomic_t enable_cnt;
	u32 saved_config_space[16];
	struct hlist_head saved_cap_space;
	int rom_attr_enabled;
	struct bin_attribute___17 *res_attr[17];
	struct bin_attribute___17 *res_attr_wc[17];
	unsigned int broken_cmd_compl: 1;
	unsigned int ptm_root: 1;
	unsigned int ptm_enabled: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 ptm_granularity;
	const struct attribute_group___17 **msi_irq_groups;
	struct pci_vpd vpd;
	u16 dpc_cap;
	unsigned int dpc_rp_extensions: 1;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 dpc_rp_log_size;
	union {
		struct pci_sriov *sriov;
		struct pci_dev___22 *physfn;
	};
	u16 ats_cap;
	u8 ats_stu;
	u16 pri_cap;
	u32 pri_reqs_alloc;
	unsigned int pasid_required: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u16 pasid_cap;
	u16 pasid_features;
	u16 acs_cap;
	phys_addr_t rom;
	size_t romlen;
	char *driver_override;
	long unsigned int priv_flags;
	u8 reset_methods[7];
};

struct pci_error_handlers___21;

struct pci_driver___21 {
	struct list_head node;
	const char *name;
	const struct pci_device_id *id_table;
	int (*probe)(struct pci_dev___22 *, const struct pci_device_id *);
	void (*remove)(struct pci_dev___22 *);
	int (*suspend)(struct pci_dev___22 *, pm_message_t);
	int (*resume)(struct pci_dev___22 *);
	void (*shutdown)(struct pci_dev___22 *);
	int (*sriov_configure)(struct pci_dev___22 *, int);
	int (*sriov_set_msix_vec_count)(struct pci_dev___22 *, int);
	u32 (*sriov_get_vf_total_msix)(struct pci_dev___22 *);
	const struct pci_error_handlers___21 *err_handler;
	const struct attribute_group___17 **groups;
	const struct attribute_group___17 **dev_groups;
	struct device_driver___15 driver;
	struct pci_dynids dynids;
};

struct pci_ops___21 {
	int (*add_bus)(struct pci_bus___21 *);
	void (*remove_bus)(struct pci_bus___21 *);
	void * (*map_bus)(struct pci_bus___21 *, unsigned int, int);
	int (*read)(struct pci_bus___21 *, unsigned int, int, int, u32 *);
	int (*write)(struct pci_bus___21 *, unsigned int, int, int, u32);
};

struct pci_error_handlers___21 {
	pci_ers_result_t (*error_detected)(struct pci_dev___22 *, pci_channel_state_t);
	pci_ers_result_t (*mmio_enabled)(struct pci_dev___22 *);
	pci_ers_result_t (*slot_reset)(struct pci_dev___22 *);
	void (*reset_prepare)(struct pci_dev___22 *);
	void (*reset_done)(struct pci_dev___22 *);
	void (*resume)(struct pci_dev___22 *);
};

enum {
	M_I17 = 0,
	M_I20 = 1,
	M_I20_SR = 2,
	M_I24 = 3,
	M_I24_8_1 = 4,
	M_I24_10_1 = 5,
	M_I27_11_1 = 6,
	M_MINI = 7,
	M_MINI_3_1 = 8,
	M_MINI_4_1 = 9,
	M_MB = 10,
	M_MB_2 = 11,
	M_MB_3 = 12,
	M_MB_5_1 = 13,
	M_MB_6_1 = 14,
	M_MB_7_1 = 15,
	M_MB_SR = 16,
	M_MBA = 17,
	M_MBA_3 = 18,
	M_MBP = 19,
	M_MBP_2 = 20,
	M_MBP_2_2 = 21,
	M_MBP_SR = 22,
	M_MBP_4 = 23,
	M_MBP_5_1 = 24,
	M_MBP_5_2 = 25,
	M_MBP_5_3 = 26,
	M_MBP_6_1 = 27,
	M_MBP_6_2 = 28,
	M_MBP_7_1 = 29,
	M_MBP_8_2 = 30,
	M_UNKNOWN = 31,
};

struct efifb_dmi_info {
	char *optname;
	long unsigned int base;
	int stride;
	int width;
	int height;
	int flags;
};

enum {
	OVERRIDE_NONE = 0,
	OVERRIDE_BASE = 1,
	OVERRIDE_STRIDE = 2,
	OVERRIDE_HEIGHT = 4,
	OVERRIDE_WIDTH = 8,
};

typedef void *efi_event_t;

typedef void (*efi_event_notify_t)(efi_event_t, void *);

typedef enum {
	EfiTimerCancel = 0,
	EfiTimerPeriodic = 1,
	EfiTimerRelative = 2,
} EFI_TIMER_DELAY;

typedef void *efi_handle_t;

typedef struct efi_generic_dev_path efi_device_path_protocol_t;

union efi_boot_services {
	struct {
		efi_table_hdr_t hdr;
		void *raise_tpl;
		void *restore_tpl;
		efi_status_t (*allocate_pages)(int, int, long unsigned int, efi_physical_addr_t *);
		efi_status_t (*free_pages)(efi_physical_addr_t, long unsigned int);
		efi_status_t (*get_memory_map)(long unsigned int *, void *, long unsigned int *, long unsigned int *, u32 *);
		efi_status_t (*allocate_pool)(int, long unsigned int, void **);
		efi_status_t (*free_pool)(void *);
		efi_status_t (*create_event)(u32, long unsigned int, efi_event_notify_t, void *, efi_event_t *);
		efi_status_t (*set_timer)(efi_event_t, EFI_TIMER_DELAY, u64);
		efi_status_t (*wait_for_event)(long unsigned int, efi_event_t *, long unsigned int *);
		void *signal_event;
		efi_status_t (*close_event)(efi_event_t);
		void *check_event;
		void *install_protocol_interface;
		void *reinstall_protocol_interface;
		void *uninstall_protocol_interface;
		efi_status_t (*handle_protocol)(efi_handle_t, efi_guid_t *, void **);
		void *__reserved;
		void *register_protocol_notify;
		efi_status_t (*locate_handle)(int, efi_guid_t *, void *, long unsigned int *, efi_handle_t *);
		efi_status_t (*locate_device_path)(efi_guid_t *, efi_device_path_protocol_t **, efi_handle_t *);
		efi_status_t (*install_configuration_table)(efi_guid_t *, void *);
		void *load_image;
		void *start_image;
		efi_status_t (*exit)(efi_handle_t, efi_status_t, long unsigned int, efi_char16_t *);
		void *unload_image;
		efi_status_t (*exit_boot_services)(efi_handle_t, long unsigned int);
		void *get_next_monotonic_count;
		efi_status_t (*stall)(long unsigned int);
		void *set_watchdog_timer;
		void *connect_controller;
		efi_status_t (*disconnect_controller)(efi_handle_t, efi_handle_t, efi_handle_t);
		void *open_protocol;
		void *close_protocol;
		void *open_protocol_information;
		void *protocols_per_handle;
		void *locate_handle_buffer;
		efi_status_t (*locate_protocol)(efi_guid_t *, void *, void **);
		void *install_multiple_protocol_interfaces;
		void *uninstall_multiple_protocol_interfaces;
		void *calculate_crc32;
		void *copy_mem;
		void *set_mem;
		void *create_event_ex;
	};
	struct {
		efi_table_hdr_t hdr;
		u32 raise_tpl;
		u32 restore_tpl;
		u32 allocate_pages;
		u32 free_pages;
		u32 get_memory_map;
		u32 allocate_pool;
		u32 free_pool;
		u32 create_event;
		u32 set_timer;
		u32 wait_for_event;
		u32 signal_event;
		u32 close_event;
		u32 check_event;
		u32 install_protocol_interface;
		u32 reinstall_protocol_interface;
		u32 uninstall_protocol_interface;
		u32 handle_protocol;
		u32 __reserved;
		u32 register_protocol_notify;
		u32 locate_handle;
		u32 locate_device_path;
		u32 install_configuration_table;
		u32 load_image;
		u32 start_image;
		u32 exit;
		u32 unload_image;
		u32 exit_boot_services;
		u32 get_next_monotonic_count;
		u32 stall;
		u32 set_watchdog_timer;
		u32 connect_controller;
		u32 disconnect_controller;
		u32 open_protocol;
		u32 close_protocol;
		u32 open_protocol_information;
		u32 protocols_per_handle;
		u32 locate_handle_buffer;
		u32 locate_protocol;
		u32 install_multiple_protocol_interfaces;
		u32 uninstall_multiple_protocol_interfaces;
		u32 calculate_crc32;
		u32 copy_mem;
		u32 set_mem;
		u32 create_event_ex;
	} mixed_mode;
};

typedef union efi_boot_services efi_boot_services_t;

typedef struct {
	efi_table_hdr_t hdr;
	u32 fw_vendor;
	u32 fw_revision;
	u32 con_in_handle;
	u32 con_in;
	u32 con_out_handle;
	u32 con_out;
	u32 stderr_handle;
	u32 stderr;
	u32 runtime;
	u32 boottime;
	u32 nr_tables;
	u32 tables;
} efi_system_table_32_t;

typedef struct {
	u16 scan_code;
	efi_char16_t unicode_char;
} efi_input_key_t;

union efi_simple_text_input_protocol;

typedef union efi_simple_text_input_protocol efi_simple_text_input_protocol_t;

union efi_simple_text_input_protocol {
	struct {
		void *reset;
		efi_status_t (*read_keystroke)(efi_simple_text_input_protocol_t *, efi_input_key_t *);
		efi_event_t wait_for_key;
	};
	struct {
		u32 reset;
		u32 read_keystroke;
		u32 wait_for_key;
	} mixed_mode;
};

union efi_simple_text_output_protocol;

typedef union efi_simple_text_output_protocol efi_simple_text_output_protocol_t;

union efi_simple_text_output_protocol {
	struct {
		void *reset;
		efi_status_t (*output_string)(efi_simple_text_output_protocol_t *, efi_char16_t *);
		void *test_string;
	};
	struct {
		u32 reset;
		u32 output_string;
		u32 test_string;
	} mixed_mode;
};

typedef union {
	struct {
		efi_table_hdr_t hdr;
		long unsigned int fw_vendor;
		u32 fw_revision;
		long unsigned int con_in_handle;
		efi_simple_text_input_protocol_t *con_in;
		long unsigned int con_out_handle;
		efi_simple_text_output_protocol_t *con_out;
		long unsigned int stderr_handle;
		long unsigned int stderr;
		efi_runtime_services_t *runtime;
		efi_boot_services_t *boottime;
		long unsigned int nr_tables;
		long unsigned int tables;
	};
	efi_system_table_32_t mixed_mode;
} efi_system_table_t;

typedef void (*poll_queue_proc___168)(struct file___236 *, wait_queue_head_t *, struct poll_table_struct___10 *);

struct cper_arm_ctx_info {
	u16 version;
	u16 type;
	u32 size;
};

enum imx_misc_func {
	IMX_SC_MISC_FUNC_UNKNOWN = 0,
	IMX_SC_MISC_FUNC_SET_CONTROL = 1,
	IMX_SC_MISC_FUNC_GET_CONTROL = 2,
	IMX_SC_MISC_FUNC_SET_MAX_DMA_GROUP = 4,
	IMX_SC_MISC_FUNC_SET_DMA_GROUP = 5,
	IMX_SC_MISC_FUNC_SECO_IMAGE_LOAD = 8,
	IMX_SC_MISC_FUNC_SECO_AUTHENTICATE = 9,
	IMX_SC_MISC_FUNC_DEBUG_OUT = 10,
	IMX_SC_MISC_FUNC_WAVEFORM_CAPTURE = 6,
	IMX_SC_MISC_FUNC_BUILD_INFO = 15,
	IMX_SC_MISC_FUNC_UNIQUE_ID = 19,
	IMX_SC_MISC_FUNC_SET_ARI = 3,
	IMX_SC_MISC_FUNC_BOOT_STATUS = 7,
	IMX_SC_MISC_FUNC_BOOT_DONE = 14,
	IMX_SC_MISC_FUNC_OTP_FUSE_READ = 11,
	IMX_SC_MISC_FUNC_OTP_FUSE_WRITE = 17,
	IMX_SC_MISC_FUNC_SET_TEMP = 12,
	IMX_SC_MISC_FUNC_GET_TEMP = 13,
	IMX_SC_MISC_FUNC_GET_BOOT_DEV = 16,
	IMX_SC_MISC_FUNC_GET_BUTTON_STATUS = 18,
};

struct imx_sc_ipc___2;

struct imx_sc_chan {
	struct imx_sc_ipc___2 *sc_ipc;
	struct mbox_client cl;
	struct mbox_chan___2 *ch;
	int idx;
	struct completion tx_done;
};

struct imx_sc_ipc___2 {
	struct imx_sc_chan chans[8];
	struct device___214 *dev;
	struct mutex lock;
	struct completion done;
	bool fast_ipc;
	u32 *msg;
	u8 rx_size;
	u8 count;
};

enum imx_sc_error_codes {
	IMX_SC_ERR_NONE = 0,
	IMX_SC_ERR_VERSION = 1,
	IMX_SC_ERR_CONFIG = 2,
	IMX_SC_ERR_PARM = 3,
	IMX_SC_ERR_NOACCESS = 4,
	IMX_SC_ERR_LOCKED = 5,
	IMX_SC_ERR_UNAVAILABLE = 6,
	IMX_SC_ERR_NOTFOUND = 7,
	IMX_SC_ERR_NOPOWER = 8,
	IMX_SC_ERR_IPC = 9,
	IMX_SC_ERR_BUSY = 10,
	IMX_SC_ERR_FAIL = 11,
	IMX_SC_ERR_LAST = 12,
};

struct imx_sc_msg_req_misc_set_ctrl {
	struct imx_sc_rpc_msg hdr;
	u32 ctrl;
	u32 val;
	u16 resource;
};

struct imx_sc_msg_req_cpu_start {
	struct imx_sc_rpc_msg hdr;
	u32 address_hi;
	u32 address_lo;
	u16 resource;
	u8 enable;
};

struct imx_sc_msg_req_misc_get_ctrl {
	struct imx_sc_rpc_msg hdr;
	u32 ctrl;
	u16 resource;
};

struct imx_sc_msg_resp_misc_get_ctrl {
	struct imx_sc_rpc_msg hdr;
	u32 val;
};

struct imx_sc_msg_irq_get_status {
	struct imx_sc_rpc_msg hdr;
	union {
		struct {
			u16 resource;
			u8 group;
			u8 reserved;
		} req;
		struct {
			u32 status;
		} resp;
	} data;
};

struct imx_sc_msg_irq_enable {
	struct imx_sc_rpc_msg hdr;
	u32 mask;
	u16 resource;
	u8 group;
	u8 enable;
};

enum imx_sc_rm_func {
	IMX_SC_RM_FUNC_UNKNOWN = 0,
	IMX_SC_RM_FUNC_PARTITION_ALLOC = 1,
	IMX_SC_RM_FUNC_SET_CONFIDENTIAL = 31,
	IMX_SC_RM_FUNC_PARTITION_FREE = 2,
	IMX_SC_RM_FUNC_GET_DID = 26,
	IMX_SC_RM_FUNC_PARTITION_STATIC = 3,
	IMX_SC_RM_FUNC_PARTITION_LOCK = 4,
	IMX_SC_RM_FUNC_GET_PARTITION = 5,
	IMX_SC_RM_FUNC_SET_PARENT = 6,
	IMX_SC_RM_FUNC_MOVE_ALL = 7,
	IMX_SC_RM_FUNC_ASSIGN_RESOURCE = 8,
	IMX_SC_RM_FUNC_SET_RESOURCE_MOVABLE = 9,
	IMX_SC_RM_FUNC_SET_SUBSYS_RSRC_MOVABLE = 28,
	IMX_SC_RM_FUNC_SET_MASTER_ATTRIBUTES = 10,
	IMX_SC_RM_FUNC_SET_MASTER_SID = 11,
	IMX_SC_RM_FUNC_SET_PERIPHERAL_PERMISSIONS = 12,
	IMX_SC_RM_FUNC_IS_RESOURCE_OWNED = 13,
	IMX_SC_RM_FUNC_GET_RESOURCE_OWNER = 33,
	IMX_SC_RM_FUNC_IS_RESOURCE_MASTER = 14,
	IMX_SC_RM_FUNC_IS_RESOURCE_PERIPHERAL = 15,
	IMX_SC_RM_FUNC_GET_RESOURCE_INFO = 16,
	IMX_SC_RM_FUNC_MEMREG_ALLOC = 17,
	IMX_SC_RM_FUNC_MEMREG_SPLIT = 29,
	IMX_SC_RM_FUNC_MEMREG_FRAG = 32,
	IMX_SC_RM_FUNC_MEMREG_FREE = 18,
	IMX_SC_RM_FUNC_FIND_MEMREG = 30,
	IMX_SC_RM_FUNC_ASSIGN_MEMREG = 19,
	IMX_SC_RM_FUNC_SET_MEMREG_PERMISSIONS = 20,
	IMX_SC_RM_FUNC_IS_MEMREG_OWNED = 21,
	IMX_SC_RM_FUNC_GET_MEMREG_INFO = 22,
	IMX_SC_RM_FUNC_ASSIGN_PAD = 23,
	IMX_SC_RM_FUNC_SET_PAD_MOVABLE = 24,
	IMX_SC_RM_FUNC_IS_PAD_OWNED = 25,
	IMX_SC_RM_FUNC_DUMP = 27,
};

struct imx_sc_msg_rm_rsrc_owned {
	struct imx_sc_rpc_msg hdr;
	u16 resource;
	short: 16;
};

struct imx_sc_msg_misc_get_soc_id {
	struct imx_sc_rpc_msg hdr;
	union {
		struct {
			u32 control;
			u16 resource;
		} __attribute__((packed)) req;
		struct {
			u32 id;
		} resp;
	} data;
};

struct imx_sc_msg_misc_get_soc_uid {
	struct imx_sc_rpc_msg hdr;
	u32 uid_low;
	u32 uid_high;
};

typedef struct generic_pm_domain * (*genpd_xlate_t___6)(struct of_phandle_args___3 *, void *);

struct imx_sc_msg_req_set_resource_power_mode {
	struct imx_sc_rpc_msg hdr;
	u16 resource;
	u8 mode;
};

struct imx_sc_pm_domain {
	struct generic_pm_domain pd;
	char name[20];
	u32 rsrc;
};

struct imx_sc_pd_range {
	char *name;
	u32 rsrc;
	u8 num;
	bool postfix;
	u8 start_from;
};

struct imx_sc_pd_soc {
	const struct imx_sc_pd_range *pd_ranges;
	u8 num_ranges;
};

typedef long unsigned int psci_fn(long unsigned int, long unsigned int, long unsigned int, long unsigned int);

typedef int (*psci_initcall_t)(const struct device_node___10 *);

struct soc_device_attribute___6 {
	const char *machine;
	const char *family;
	const char *revision;
	const char *serial_number;
	const char *soc_id;
	const void *data;
	const struct attribute_group___103 *custom_attr_group;
};

typedef struct generic_pm_domain___2 * (*genpd_xlate_t___7)(struct of_phandle_args___3 *, void *);

struct reset_controller_dev___10;

struct reset_control_ops___10 {
	int (*reset)(struct reset_controller_dev___10 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___10 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___10 *, long unsigned int);
	int (*status)(struct reset_controller_dev___10 *, long unsigned int);
};

struct reset_controller_dev___10 {
	const struct reset_control_ops___10 *ops;
	struct module___221 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___214 *dev;
	struct device_node___53 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___10 *, const struct of_phandle_args___3 *);
	unsigned int nr_resets;
};

struct mrq_ping_request {
	uint32_t challenge;
};

struct mrq_ping_response {
	uint32_t reply;
};

struct mrq_query_tag_request {
	uint32_t addr;
};

struct mrq_query_fw_tag_response {
	uint8_t tag[32];
};

struct mrq_query_abi_request {
	uint32_t mrq;
};

struct mrq_query_abi_response {
	int32_t status;
};

struct tegra_ivc___2;

struct tegra_bpmp_channel {
	struct tegra_bpmp *bpmp;
	struct tegra_bpmp_mb_data *ib;
	struct tegra_bpmp_mb_data *ob;
	struct completion completion;
	struct tegra_ivc___2 *ivc;
	unsigned int index;
};

struct tegra_bpmp {
	const struct tegra_bpmp_soc *soc;
	struct device___214 *dev;
	void *priv;
	struct {
		struct mbox_client client;
		struct mbox_chan___2 *channel;
	} mbox;
	spinlock_t atomic_tx_lock;
	struct tegra_bpmp_channel *tx_channel;
	struct tegra_bpmp_channel *rx_channel;
	struct tegra_bpmp_channel *threaded_channels;
	struct {
		long unsigned int *allocated;
		long unsigned int *busy;
		unsigned int count;
		struct semaphore lock;
	} threaded;
	struct list_head mrqs;
	spinlock_t lock;
	struct tegra_bpmp_clk___2 **clocks;
	unsigned int num_clocks;
	struct reset_controller_dev___10 rstc;
	struct genpd_onecell_data___5 genpd;
	struct dentry___237 *debugfs_mirror;
};

struct tegra_ivc_header;

struct tegra_ivc___2 {
	struct device___214 *peer;
	struct {
		struct tegra_ivc_header *channel;
		unsigned int position;
		dma_addr_t phys;
	} rx;
	struct {
		struct tegra_ivc_header *channel;
		unsigned int position;
		dma_addr_t phys;
	} tx;
	void (*notify)(struct tegra_ivc___2 *, void *);
	void *notify_data;
	unsigned int num_frames;
	size_t frame_size;
};

typedef void (*tegra_bpmp_mrq_handler_t)(unsigned int, struct tegra_bpmp_channel *, void *);

struct tegra_bpmp_mrq {
	struct list_head list;
	unsigned int mrq;
	tegra_bpmp_mrq_handler_t handler;
	void *data;
};

struct irq_chip___64;

struct irq_data___64 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___64 *chip;
	struct irq_domain___2 *domain;
	struct irq_data___64 *parent_data;
	void *chip_data;
};

struct irq_chip___64 {
	struct device___160 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___64 *);
	void (*irq_shutdown)(struct irq_data___64 *);
	void (*irq_enable)(struct irq_data___64 *);
	void (*irq_disable)(struct irq_data___64 *);
	void (*irq_ack)(struct irq_data___64 *);
	void (*irq_mask)(struct irq_data___64 *);
	void (*irq_mask_ack)(struct irq_data___64 *);
	void (*irq_unmask)(struct irq_data___64 *);
	void (*irq_eoi)(struct irq_data___64 *);
	int (*irq_set_affinity)(struct irq_data___64 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___64 *);
	int (*irq_set_type)(struct irq_data___64 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___64 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___64 *);
	void (*irq_bus_sync_unlock)(struct irq_data___64 *);
	void (*irq_cpu_online)(struct irq_data___64 *);
	void (*irq_cpu_offline)(struct irq_data___64 *);
	void (*irq_suspend)(struct irq_data___64 *);
	void (*irq_resume)(struct irq_data___64 *);
	void (*irq_pm_shutdown)(struct irq_data___64 *);
	void (*irq_calc_mask)(struct irq_data___64 *);
	void (*irq_print_chip)(struct irq_data___64 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___64 *);
	void (*irq_release_resources)(struct irq_data___64 *);
	void (*irq_compose_msi_msg)(struct irq_data___64 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___64 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___64 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___64 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___64 *, void *);
	void (*ipi_send_single)(struct irq_data___64 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___64 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___64 *);
	void (*irq_nmi_teardown)(struct irq_data___64 *);
	long unsigned int flags;
};

struct tegra_bpmp_ops___2;

struct tegra_bpmp_soc___2 {
	struct {
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} cpu_tx;
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} thread;
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} cpu_rx;
	} channels;
	const struct tegra_bpmp_ops___2 *ops;
	unsigned int num_resets;
};

struct tegra_bpmp___5;

struct tegra_bpmp_channel___5;

struct tegra_bpmp_ops___2 {
	int (*init)(struct tegra_bpmp___5 *);
	void (*deinit)(struct tegra_bpmp___5 *);
	bool (*is_response_ready)(struct tegra_bpmp_channel___5 *);
	bool (*is_request_ready)(struct tegra_bpmp_channel___5 *);
	int (*ack_response)(struct tegra_bpmp_channel___5 *);
	int (*ack_request)(struct tegra_bpmp_channel___5 *);
	bool (*is_response_channel_free)(struct tegra_bpmp_channel___5 *);
	bool (*is_request_channel_free)(struct tegra_bpmp_channel___5 *);
	int (*post_response)(struct tegra_bpmp_channel___5 *);
	int (*post_request)(struct tegra_bpmp_channel___5 *);
	int (*ring_doorbell)(struct tegra_bpmp___5 *);
	int (*resume)(struct tegra_bpmp___5 *);
};

struct tegra_bpmp_channel___5 {
	struct tegra_bpmp___5 *bpmp;
	struct tegra_bpmp_mb_data *ib;
	struct tegra_bpmp_mb_data *ob;
	struct completion completion;
	struct tegra_ivc *ivc;
	unsigned int index;
};

struct tegra_bpmp___5 {
	const struct tegra_bpmp_soc___2 *soc;
	struct device___160 *dev;
	void *priv;
	struct {
		struct mbox_client___5 client;
		struct mbox_chan___2 *channel;
	} mbox;
	spinlock_t atomic_tx_lock;
	struct tegra_bpmp_channel___5 *tx_channel;
	struct tegra_bpmp_channel___5 *rx_channel;
	struct tegra_bpmp_channel___5 *threaded_channels;
	struct {
		long unsigned int *allocated;
		long unsigned int *busy;
		unsigned int count;
		struct semaphore lock;
	} threaded;
	struct list_head mrqs;
	spinlock_t lock;
	struct tegra_bpmp_clk___2 **clocks;
	unsigned int num_clocks;
	struct reset_controller_dev___7 rstc;
	struct genpd_onecell_data___4 genpd;
	struct dentry___182 *debugfs_mirror;
};

struct tegra210_bpmp {
	void *atomics;
	void *arb_sema;
	struct irq_data___64 *tx_irq_data;
};

struct of_phandle_args___40 {
	struct device_node___96 *np;
	int args_count;
	uint32_t args[16];
};

struct mbox_client___6 {
	struct device___215 *dev;
	bool tx_block;
	long unsigned int tx_tout;
	bool knows_txdone;
	void (*rx_callback)(struct mbox_client___6 *, void *);
	void (*tx_prepare)(struct mbox_client___6 *, void *);
	void (*tx_done)(struct mbox_client___6 *, void *, int);
};

typedef struct generic_pm_domain___4 * (*genpd_xlate_t___8)(struct of_phandle_args___40 *, void *);

struct reset_controller_dev___11;

struct reset_control_ops___11 {
	int (*reset)(struct reset_controller_dev___11 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___11 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___11 *, long unsigned int);
	int (*status)(struct reset_controller_dev___11 *, long unsigned int);
};

struct reset_controller_dev___11 {
	const struct reset_control_ops___11 *ops;
	struct module___8 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___215 *dev;
	struct device_node___96 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___11 *, const struct of_phandle_args___40 *);
	unsigned int nr_resets;
};

struct tegra_bpmp_ops___3;

struct tegra_bpmp_soc___3 {
	struct {
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} cpu_tx;
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} thread;
		struct {
			unsigned int offset;
			unsigned int count;
			unsigned int timeout;
		} cpu_rx;
	} channels;
	const struct tegra_bpmp_ops___3 *ops;
	unsigned int num_resets;
};

struct tegra_bpmp___6;

struct tegra_bpmp_channel___6;

struct tegra_bpmp_ops___3 {
	int (*init)(struct tegra_bpmp___6 *);
	void (*deinit)(struct tegra_bpmp___6 *);
	bool (*is_response_ready)(struct tegra_bpmp_channel___6 *);
	bool (*is_request_ready)(struct tegra_bpmp_channel___6 *);
	int (*ack_response)(struct tegra_bpmp_channel___6 *);
	int (*ack_request)(struct tegra_bpmp_channel___6 *);
	bool (*is_response_channel_free)(struct tegra_bpmp_channel___6 *);
	bool (*is_request_channel_free)(struct tegra_bpmp_channel___6 *);
	int (*post_response)(struct tegra_bpmp_channel___6 *);
	int (*post_request)(struct tegra_bpmp_channel___6 *);
	int (*ring_doorbell)(struct tegra_bpmp___6 *);
	int (*resume)(struct tegra_bpmp___6 *);
};

struct tegra_bpmp_channel___6 {
	struct tegra_bpmp___6 *bpmp;
	struct tegra_bpmp_mb_data *ib;
	struct tegra_bpmp_mb_data *ob;
	struct completion completion;
	struct tegra_ivc *ivc;
	unsigned int index;
};

struct tegra_bpmp___6 {
	const struct tegra_bpmp_soc___3 *soc;
	struct device___215 *dev;
	void *priv;
	struct {
		struct mbox_client___6 client;
		struct mbox_chan___2 *channel;
	} mbox;
	spinlock_t atomic_tx_lock;
	struct tegra_bpmp_channel___6 *tx_channel;
	struct tegra_bpmp_channel___6 *rx_channel;
	struct tegra_bpmp_channel___6 *threaded_channels;
	struct {
		long unsigned int *allocated;
		long unsigned int *busy;
		unsigned int count;
		struct semaphore lock;
	} threaded;
	struct list_head mrqs;
	spinlock_t lock;
	struct tegra_bpmp_clk___2 **clocks;
	unsigned int num_clocks;
	struct reset_controller_dev___11 rstc;
	struct genpd_onecell_data___3 genpd;
	struct dentry___236 *debugfs_mirror;
};

struct tegra_ivc {
	struct device___215 *peer;
	struct {
		struct tegra_ivc_header *channel;
		unsigned int position;
		dma_addr_t phys;
	} rx;
	struct {
		struct tegra_ivc_header *channel;
		unsigned int position;
		dma_addr_t phys;
	} tx;
	void (*notify)(struct tegra_ivc *, void *);
	void *notify_data;
	unsigned int num_frames;
	size_t frame_size;
};

struct tegra186_bpmp {
	struct tegra_bpmp___6 *parent;
	struct {
		struct gen_pool *pool;
		dma_addr_t phys;
		void *virt;
	} tx;
	struct {
		struct gen_pool *pool;
		dma_addr_t phys;
		void *virt;
	} rx;
	struct {
		struct mbox_client___6 client;
		struct mbox_chan___2 *channel;
	} mbox;
};

struct dev_power_governor___7 {
	bool (*power_down_ok)(struct dev_pm_domain___215 *);
	bool (*suspend_ok)(struct device___215 *);
};

struct gpd_dev_ops___7 {
	int (*start)(struct device___215 *);
	int (*stop)(struct device___215 *);
};

struct genpd_power_state___7 {
	s64 power_off_latency_ns;
	s64 power_on_latency_ns;
	s64 residency_ns;
	u64 usage;
	u64 rejected;
	struct fwnode_handle___211 *fwnode;
	ktime_t idle_time;
	void *data;
};

struct generic_pm_domain___7 {
	struct device___215 dev;
	struct dev_pm_domain___215 domain;
	struct list_head gpd_list_node;
	struct list_head parent_links;
	struct list_head child_links;
	struct list_head dev_list;
	struct dev_power_governor___7 *gov;
	struct work_struct power_off_work;
	struct fwnode_handle___211 *provider;
	bool has_provider;
	const char *name;
	atomic_t sd_count;
	enum gpd_status status;
	unsigned int device_count;
	unsigned int suspended_count;
	unsigned int prepared_count;
	unsigned int performance_state;
	cpumask_var_t cpus;
	int (*power_off)(struct generic_pm_domain___7 *);
	int (*power_on)(struct generic_pm_domain___7 *);
	struct raw_notifier_head power_notifiers;
	struct opp_table *opp_table;
	unsigned int (*opp_to_performance_state)(struct generic_pm_domain___7 *, struct dev_pm_opp *);
	int (*set_performance_state)(struct generic_pm_domain___7 *, unsigned int);
	struct gpd_dev_ops___7 dev_ops;
	s64 max_off_time_ns;
	ktime_t next_wakeup;
	bool max_off_time_changed;
	bool cached_power_down_ok;
	bool cached_power_down_state_idx;
	int (*attach_dev)(struct generic_pm_domain___7 *, struct device___215 *);
	void (*detach_dev)(struct generic_pm_domain___7 *, struct device___215 *);
	unsigned int flags;
	struct genpd_power_state___7 *states;
	void (*free_states)(struct genpd_power_state___7 *, unsigned int);
	unsigned int state_count;
	unsigned int state_idx;
	ktime_t on_time;
	ktime_t accounting_time;
	const struct genpd_lock_ops *lock_ops;
	union {
		struct mutex mlock;
		struct {
			spinlock_t slock;
			long unsigned int lock_flags;
		};
	};
};

typedef struct generic_pm_domain___7 * (*genpd_xlate_t___9)(struct of_phandle_args___40 *, void *);

struct genpd_onecell_data___6 {
	struct generic_pm_domain___7 **domains;
	unsigned int num_domains;
	genpd_xlate_t___9 xlate;
};

enum mrq_debugfs_commands {
	CMD_DEBUGFS_READ = 1,
	CMD_DEBUGFS_WRITE = 2,
	CMD_DEBUGFS_DUMPDIR = 3,
	CMD_DEBUGFS_MAX = 4,
};

struct cmd_debugfs_fileop_request {
	uint32_t fnameaddr;
	uint32_t fnamelen;
	uint32_t dataaddr;
	uint32_t datalen;
};

struct cmd_debugfs_dumpdir_request {
	uint32_t dataaddr;
	uint32_t datalen;
};

struct cmd_debugfs_fileop_response {
	uint32_t reserved;
	uint32_t nbytes;
};

struct cmd_debugfs_dumpdir_response {
	uint32_t reserved;
	uint32_t nbytes;
};

struct mrq_debugfs_request {
	uint32_t cmd;
	union {
		struct cmd_debugfs_fileop_request fop;
		struct cmd_debugfs_dumpdir_request dumpdir;
	};
};

struct mrq_debugfs_response {
	int32_t reserved;
	union {
		struct cmd_debugfs_fileop_response fop;
		struct cmd_debugfs_dumpdir_response dumpdir;
	};
};

enum mrq_debug_commands {
	CMD_DEBUG_OPEN_RO = 0,
	CMD_DEBUG_OPEN_WO = 1,
	CMD_DEBUG_READ = 2,
	CMD_DEBUG_WRITE = 3,
	CMD_DEBUG_CLOSE = 4,
	CMD_DEBUG_MAX = 5,
};

struct cmd_debug_fopen_request {
	char name[116];
};

struct cmd_debug_fopen_response {
	uint32_t fd;
	uint32_t datalen;
};

struct cmd_debug_fread_request {
	uint32_t fd;
};

struct cmd_debug_fread_response {
	uint32_t readlen;
	char data[116];
};

struct cmd_debug_fwrite_request {
	uint32_t fd;
	uint32_t datalen;
	char data[108];
};

struct cmd_debug_fclose_request {
	uint32_t fd;
};

struct mrq_debug_request {
	uint32_t cmd;
	union {
		struct cmd_debug_fopen_request fop;
		struct cmd_debug_fread_request frd;
		struct cmd_debug_fwrite_request fwr;
		struct cmd_debug_fclose_request fcl;
	};
};

struct mrq_debug_response {
	union {
		struct cmd_debug_fopen_response fop;
		struct cmd_debug_fread_response frd;
	};
};

struct seqbuf {
	char *buf;
	size_t pos;
	size_t size;
};

struct tegra_ivc_header {
	union {
		struct {
			u32 count;
			u32 state;
		};
		u8 pad[64];
	} tx;
	union {
		u32 count;
		u8 pad[64];
	} rx;
};

enum tegra_ivc_state {
	TEGRA_IVC_STATE_ESTABLISHED = 0,
	TEGRA_IVC_STATE_SYNC = 1,
	TEGRA_IVC_STATE_ACK = 2,
};

enum pm_api_id {
	PM_GET_API_VERSION = 1,
	PM_SYSTEM_SHUTDOWN = 12,
	PM_REQUEST_NODE = 13,
	PM_RELEASE_NODE = 14,
	PM_SET_REQUIREMENT = 15,
	PM_RESET_ASSERT = 17,
	PM_RESET_GET_STATUS = 18,
	PM_PM_INIT_FINALIZE = 21,
	PM_FPGA_LOAD = 22,
	PM_FPGA_GET_STATUS = 23,
	PM_GET_CHIPID = 24,
	PM_PINCTRL_REQUEST = 28,
	PM_PINCTRL_RELEASE = 29,
	PM_PINCTRL_GET_FUNCTION = 30,
	PM_PINCTRL_SET_FUNCTION = 31,
	PM_PINCTRL_CONFIG_PARAM_GET = 32,
	PM_PINCTRL_CONFIG_PARAM_SET = 33,
	PM_IOCTL = 34,
	PM_QUERY_DATA = 35,
	PM_CLOCK_ENABLE = 36,
	PM_CLOCK_DISABLE = 37,
	PM_CLOCK_GETSTATE = 38,
	PM_CLOCK_SETDIVIDER = 39,
	PM_CLOCK_GETDIVIDER = 40,
	PM_CLOCK_SETRATE = 41,
	PM_CLOCK_GETRATE = 42,
	PM_CLOCK_SETPARENT = 43,
	PM_CLOCK_GETPARENT = 44,
	PM_SECURE_AES = 47,
	PM_FEATURE_CHECK = 63,
};

enum pm_ret_status {
	XST_PM_SUCCESS = 0,
	XST_PM_NO_FEATURE = 19,
	XST_PM_INTERNAL = 2000,
	XST_PM_CONFLICT = 2001,
	XST_PM_NO_ACCESS = 2002,
	XST_PM_INVALID_NODE = 2003,
	XST_PM_DOUBLE_REQ = 2004,
	XST_PM_ABORT_SUSPEND = 2005,
	XST_PM_MULT_USER = 2008,
};

enum pm_ioctl_id {
	IOCTL_SD_DLL_RESET = 6,
	IOCTL_SET_SD_TAPDELAY = 7,
	IOCTL_SET_PLL_FRAC_MODE = 8,
	IOCTL_GET_PLL_FRAC_MODE = 9,
	IOCTL_SET_PLL_FRAC_DATA = 10,
	IOCTL_GET_PLL_FRAC_DATA = 11,
	IOCTL_WRITE_GGS = 12,
	IOCTL_READ_GGS = 13,
	IOCTL_WRITE_PGGS = 14,
	IOCTL_READ_PGGS = 15,
	IOCTL_SET_BOOT_HEALTH_STATUS = 17,
};

enum zynqmp_pm_shutdown_type {
	ZYNQMP_PM_SHUTDOWN_TYPE_SHUTDOWN = 0,
	ZYNQMP_PM_SHUTDOWN_TYPE_RESET = 1,
	ZYNQMP_PM_SHUTDOWN_TYPE_SETSCOPE_ONLY = 2,
};

enum zynqmp_pm_shutdown_subtype {
	ZYNQMP_PM_SHUTDOWN_SUBTYPE_SUBSYSTEM = 0,
	ZYNQMP_PM_SHUTDOWN_SUBTYPE_PS_ONLY = 1,
	ZYNQMP_PM_SHUTDOWN_SUBTYPE_SYSTEM = 2,
};

struct pm_api_feature_data {
	u32 pm_api_id;
	int feature_status;
	struct hlist_node hentry;
};

struct zynqmp_pm_shutdown_scope {
	const enum zynqmp_pm_shutdown_subtype subtype;
	const char *name;
};

struct of_timer_irq {
	int irq;
	int index;
	int percpu;
	const char *name;
	long unsigned int flags;
	irq_handler_t handler;
};

struct of_timer_base {
	void *base;
	const char *name;
	int index;
};

struct of_timer_clk {
	struct clk *clk;
	const char *name;
	int index;
	long unsigned int rate;
	long unsigned int period;
};

struct timer_of {
	unsigned int flags;
	struct device_node___24 *np;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device___2 clkevt;
	struct of_timer_base of_base;
	struct of_timer_irq of_irq;
	struct of_timer_clk of_clk;
	void *private_data;
	long: 64;
	long: 64;
};

typedef int (*of_init_fn_1_ret)(struct device_node___96 *);

struct platform_device___43 {
	const char *name;
	int id;
	bool id_auto;
	struct device___215 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct sh_timer_config {
	unsigned int channels_mask;
};

enum sh_cmt_model {
	SH_CMT_16BIT = 0,
	SH_CMT_32BIT = 1,
	SH_CMT_48BIT = 2,
	SH_CMT0_RCAR_GEN2 = 3,
	SH_CMT1_RCAR_GEN2 = 4,
};

struct sh_cmt_info {
	enum sh_cmt_model model;
	unsigned int channels_mask;
	long unsigned int width;
	u32 overflow_bit;
	u32 clear_bits;
	u32 (*read_control)(void *, long unsigned int);
	void (*write_control)(void *, long unsigned int, u32);
	u32 (*read_count)(void *, long unsigned int);
	void (*write_count)(void *, long unsigned int, u32);
};

struct sh_cmt_device;

struct sh_cmt_channel {
	struct sh_cmt_device *cmt;
	unsigned int index;
	unsigned int hwidx;
	void *iostart;
	void *ioctrl;
	unsigned int timer_bit;
	long unsigned int flags;
	u32 match_value;
	u32 next_match_value;
	u32 max_match_value;
	raw_spinlock_t lock;
	struct clock_event_device ced;
	struct clocksource___3 cs;
	u64 total_cycles;
	bool cs_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
};

struct sh_cmt_device {
	struct platform_device___43 *pdev;
	const struct sh_cmt_info *info;
	void *mapbase;
	struct clk *clk;
	long unsigned int rate;
	raw_spinlock_t lock;
	struct sh_cmt_channel *channels;
	unsigned int num_channels;
	unsigned int hw_channels;
	bool has_clockevent;
	bool has_clocksource;
};

enum sh_tmu_model {
	SH_TMU = 0,
	SH_TMU_SH3 = 1,
};

struct sh_tmu_device;

struct sh_tmu_channel {
	struct sh_tmu_device *tmu;
	unsigned int index;
	void *base;
	int irq;
	long unsigned int periodic;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device ced;
	struct clocksource___3 cs;
	bool cs_enabled;
	unsigned int enable_count;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sh_tmu_device {
	struct platform_device___43 *pdev;
	void *mapbase;
	struct clk *clk;
	long unsigned int rate;
	enum sh_tmu_model model;
	raw_spinlock_t lock;
	struct sh_tmu_channel *channels;
	unsigned int num_channels;
	bool has_clockevent;
	bool has_clocksource;
};

struct clocksource_mmio {
	void *reg;
	struct clocksource___3 clksrc;
};

struct dw_apb_timer {
	void *base;
	long unsigned int freq;
	int irq;
};

struct dw_apb_clock_event_device {
	struct clock_event_device___2 ced;
	struct dw_apb_timer timer;
	void (*eoi)(struct dw_apb_timer *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dw_apb_clocksource {
	struct dw_apb_timer timer;
	struct clocksource___3 cs;
};

typedef int (*of_init_fn_1_ret___2)(struct device_node___56 *);

typedef int (*of_init_fn_1_ret___3)(struct device_node___24 *);

struct rk_timer {
	void *base;
	void *ctrl;
	struct clk *clk;
	struct clk *pclk;
	u32 freq;
	int irq;
};

struct rk_clkevt {
	struct clock_event_device___2 ce;
	struct rk_timer timer;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*of_init_fn_1_ret___4)(struct device_node___22 *);

struct timer_of___2 {
	unsigned int flags;
	struct device_node___22 *np;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device___2 clkevt;
	struct of_timer_base of_base;
	struct of_timer_irq of_irq;
	struct of_timer_clk of_clk;
	void *private_data;
	long: 64;
	long: 64;
};

enum arch_timer_reg {
	ARCH_TIMER_REG_CTRL = 0,
	ARCH_TIMER_REG_TVAL = 1,
};

enum arch_timer_spi_nr {
	ARCH_TIMER_PHYS_SPI = 0,
	ARCH_TIMER_VIRT_SPI = 1,
	ARCH_TIMER_MAX_TIMER_SPI = 2,
};

enum arch_timer_erratum_match_type {
	ate_match_dt = 0,
	ate_match_local_cap_id = 1,
	ate_match_acpi_oem_info = 2,
};

struct clock_event_device___3;

struct arch_timer_erratum_workaround {
	enum arch_timer_erratum_match_type match_type;
	const void *id;
	const char *desc;
	u32 (*read_cntp_tval_el0)();
	u32 (*read_cntv_tval_el0)();
	u64 (*read_cntpct_el0)();
	u64 (*read_cntvct_el0)();
	int (*set_next_event_phys)(long unsigned int, struct clock_event_device___3 *);
	int (*set_next_event_virt)(long unsigned int, struct clock_event_device___3 *);
	bool disable_compat_vdso;
};

struct clock_event_device___3 {
	void (*event_handler)(struct clock_event_device___3 *);
	int (*set_next_event)(long unsigned int, struct clock_event_device___3 *);
	int (*set_next_ktime)(ktime_t, struct clock_event_device___3 *);
	ktime_t next_event;
	u64 max_delta_ns;
	u64 min_delta_ns;
	u32 mult;
	u32 shift;
	enum clock_event_state state_use_accessors;
	unsigned int features;
	long unsigned int retries;
	int (*set_state_periodic)(struct clock_event_device___3 *);
	int (*set_state_oneshot)(struct clock_event_device___3 *);
	int (*set_state_oneshot_stopped)(struct clock_event_device___3 *);
	int (*set_state_shutdown)(struct clock_event_device___3 *);
	int (*tick_resume)(struct clock_event_device___3 *);
	void (*broadcast)(const struct cpumask *);
	void (*suspend)(struct clock_event_device___3 *);
	void (*resume)(struct clock_event_device___3 *);
	long unsigned int min_delta_ticks;
	long unsigned int max_delta_ticks;
	const char *name;
	int rating;
	int irq;
	int bound_on;
	const struct cpumask *cpumask;
	struct list_head list;
	struct module___214 *owner;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct clocksource___4 {
	u64 (*read)(struct clocksource___4 *);
	u64 mask;
	u32 mult;
	u32 shift;
	u64 max_idle_ns;
	u32 maxadj;
	u32 uncertainty_margin;
	u64 max_cycles;
	const char *name;
	struct list_head list;
	int rating;
	enum clocksource_ids id;
	enum vdso_clock_mode vdso_clock_mode;
	long unsigned int flags;
	int (*enable)(struct clocksource___4 *);
	void (*disable)(struct clocksource___4 *);
	void (*suspend)(struct clocksource___4 *);
	void (*resume)(struct clocksource___4 *);
	void (*mark_unstable)(struct clocksource___4 *);
	void (*tick_stable)(struct clocksource___4 *);
	struct module___214 *owner;
};

typedef int (*of_init_fn_1_ret___5)(struct device_node___92 *);

struct arch_timer {
	void *base;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device___3 evt;
};

struct ate_acpi_oem_info {
	char oem_id[7];
	char oem_table_id[9];
	u32 oem_revision;
};

typedef bool (*ate_match_fn_t)(const struct arch_timer_erratum_workaround *, const void *);

struct sp804_timer {
	int load;
	int load_h;
	int value;
	int value_h;
	int ctrl;
	int intclr;
	int ris;
	int mis;
	int bgload;
	int bgload_h;
	int timer_base[2];
	int width;
};

struct sp804_clkevt {
	void *base;
	void *load;
	void *load_h;
	void *value;
	void *value_h;
	void *ctrl;
	void *intclr;
	void *ris;
	void *mis;
	void *bgload;
	void *bgload_h;
	long unsigned int reload;
	int width;
};

struct mchp_pit64b_timer {
	void *base;
	struct clk *pclk;
	struct clk *gclk;
	u32 mode;
};

struct mchp_pit64b_clkevt {
	struct mchp_pit64b_timer timer;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct clock_event_device___3 clkevt;
};

struct mchp_pit64b_clksrc {
	struct mchp_pit64b_timer timer;
	struct clocksource___4 clksrc;
};

struct alias_prop {
	struct list_head link;
	const char *alias;
	struct device_node___95 *np;
	int id;
	char stem[0];
};

struct platform_device___44 {
	const char *name;
	int id;
	bool id_auto;
	struct device___158 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct alias_prop___2 {
	struct list_head link;
	const char *alias;
	struct device_node___61 *np;
	int id;
	char stem[0];
};

struct fwnode_operations___213;

struct device___217;

struct fwnode_handle___213 {
	struct fwnode_handle___213 *secondary;
	const struct fwnode_operations___213 *ops;
	struct device___217 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___213;

struct fwnode_endpoint___213;

struct fwnode_operations___213 {
	struct fwnode_handle___213 * (*get)(struct fwnode_handle___213 *);
	void (*put)(struct fwnode_handle___213 *);
	bool (*device_is_available)(const struct fwnode_handle___213 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___213 *, const struct device___217 *);
	bool (*property_present)(const struct fwnode_handle___213 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___213 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___213 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___213 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*get_parent)(const struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*get_next_child_node)(const struct fwnode_handle___213 *, struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*get_named_child_node)(const struct fwnode_handle___213 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___213 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___213 *);
	struct fwnode_handle___213 * (*graph_get_next_endpoint)(const struct fwnode_handle___213 *, struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*graph_get_remote_endpoint)(const struct fwnode_handle___213 *);
	struct fwnode_handle___213 * (*graph_get_port_parent)(struct fwnode_handle___213 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___213 *, struct fwnode_endpoint___213 *);
	int (*add_links)(struct fwnode_handle___213 *);
};

struct wakeup_source___217;

struct dev_pm_info___217 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___217 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___217 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___217;

struct bus_type___217;

struct device_driver___217;

struct dev_pm_domain___217;

struct irq_domain___62;

struct device_node___97;

struct class___217;

struct device___217 {
	struct kobject___42 kobj;
	struct device___217 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___217 *type;
	struct bus_type___217 *bus;
	struct device_driver___217 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___217 power;
	struct dev_pm_domain___217 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___62 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___97 *of_node;
	struct fwnode_handle___213 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___217 *class;
	const struct attribute_group___42 **groups;
	void (*release)(struct device___217 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___213 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___213 *local_fwnode;
};

struct fwnode_reference_args___213 {
	struct fwnode_handle___213 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct device_node___97 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___213 fwnode;
	struct property___20 *properties;
	struct property___20 *deadprops;
	struct device_node___97 *parent;
	struct device_node___97 *child;
	struct device_node___97 *sibling;
	struct kobject___42 kobj;
	long unsigned int _flags;
	void *data;
};

struct of_phandle_args___41 {
	struct device_node___97 *np;
	int args_count;
	uint32_t args[16];
};

struct dev_pm_ops___217 {
	int (*prepare)(struct device___217 *);
	void (*complete)(struct device___217 *);
	int (*suspend)(struct device___217 *);
	int (*resume)(struct device___217 *);
	int (*freeze)(struct device___217 *);
	int (*thaw)(struct device___217 *);
	int (*poweroff)(struct device___217 *);
	int (*restore)(struct device___217 *);
	int (*suspend_late)(struct device___217 *);
	int (*resume_early)(struct device___217 *);
	int (*freeze_late)(struct device___217 *);
	int (*thaw_early)(struct device___217 *);
	int (*poweroff_late)(struct device___217 *);
	int (*restore_early)(struct device___217 *);
	int (*suspend_noirq)(struct device___217 *);
	int (*resume_noirq)(struct device___217 *);
	int (*freeze_noirq)(struct device___217 *);
	int (*thaw_noirq)(struct device___217 *);
	int (*poweroff_noirq)(struct device___217 *);
	int (*restore_noirq)(struct device___217 *);
	int (*runtime_suspend)(struct device___217 *);
	int (*runtime_resume)(struct device___217 *);
	int (*runtime_idle)(struct device___217 *);
};

struct wakeup_source___217 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___217 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___217 {
	struct dev_pm_ops___217 ops;
	int (*start)(struct device___217 *);
	void (*detach)(struct device___217 *, bool);
	int (*activate)(struct device___217 *);
	void (*sync)(struct device___217 *);
	void (*dismiss)(struct device___217 *);
};

struct bus_type___217 {
	const char *name;
	const char *dev_name;
	struct device___217 *dev_root;
	const struct attribute_group___42 **bus_groups;
	const struct attribute_group___42 **dev_groups;
	const struct attribute_group___42 **drv_groups;
	int (*match)(struct device___217 *, struct device_driver___217 *);
	int (*uevent)(struct device___217 *, struct kobj_uevent_env *);
	int (*probe)(struct device___217 *);
	void (*sync_state)(struct device___217 *);
	void (*remove)(struct device___217 *);
	void (*shutdown)(struct device___217 *);
	int (*online)(struct device___217 *);
	int (*offline)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	int (*num_vf)(struct device___217 *);
	int (*dma_configure)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___217 {
	const char *name;
	struct bus_type___217 *bus;
	struct module___8 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___217 *);
	void (*sync_state)(struct device___217 *);
	int (*remove)(struct device___217 *);
	void (*shutdown)(struct device___217 *);
	int (*suspend)(struct device___217 *, pm_message_t);
	int (*resume)(struct device___217 *);
	const struct attribute_group___42 **groups;
	const struct attribute_group___42 **dev_groups;
	const struct dev_pm_ops___217 *pm;
	void (*coredump)(struct device___217 *);
	struct driver_private *p;
};

struct device_type___217 {
	const char *name;
	const struct attribute_group___42 **groups;
	int (*uevent)(struct device___217 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___217 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___217 *);
	const struct dev_pm_ops___217 *pm;
};

struct class___217 {
	const char *name;
	struct module___8 *owner;
	const struct attribute_group___42 **class_groups;
	const struct attribute_group___42 **dev_groups;
	struct kobject___42 *dev_kobj;
	int (*dev_uevent)(struct device___217 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___217 *, umode_t *);
	void (*class_release)(struct class___217 *);
	void (*dev_release)(struct device___217 *);
	int (*shutdown_pre)(struct device___217 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___217 *);
	void (*get_ownership)(struct device___217 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___217 *pm;
	struct subsys_private *p;
};

struct irq_domain_ops___62;

struct irq_domain_chip_generic___62;

struct irq_data___65;

struct irq_domain___62 {
	struct list_head link;
	const char *name;
	const struct irq_domain_ops___62 *ops;
	void *host_data;
	unsigned int flags;
	unsigned int mapcount;
	struct fwnode_handle___213 *fwnode;
	enum irq_domain_bus_token bus_token;
	struct irq_domain_chip_generic___62 *gc;
	struct irq_domain___62 *parent;
	irq_hw_number_t hwirq_max;
	unsigned int revmap_size;
	struct xarray revmap_tree;
	struct mutex revmap_mutex;
	struct irq_data___65 *revmap[0];
};

struct of_endpoint {
	unsigned int port;
	unsigned int id;
	const struct device_node___97 *local_node;
};

struct irq_desc___64;

typedef void (*irq_flow_handler_t___64)(struct irq_desc___64 *);

struct irq_chip___65;

struct irq_data___65 {
	u32 mask;
	unsigned int irq;
	long unsigned int hwirq;
	struct irq_common_data___2 *common;
	struct irq_chip___65 *chip;
	struct irq_domain___62 *domain;
	struct irq_data___65 *parent_data;
	void *chip_data;
};

struct irq_desc___64 {
	struct irq_common_data___2 irq_common_data;
	struct irq_data___65 irq_data;
	unsigned int *kstat_irqs;
	irq_flow_handler_t___64 handle_irq;
	struct irqaction___3 *action;
	unsigned int status_use_accessors;
	unsigned int core_internal_state__do_not_mess_with_it;
	unsigned int depth;
	unsigned int wake_depth;
	unsigned int tot_count;
	unsigned int irq_count;
	long unsigned int last_unhandled;
	unsigned int irqs_unhandled;
	atomic_t threads_handled;
	int threads_handled_last;
	raw_spinlock_t lock;
	struct cpumask *percpu_enabled;
	const struct cpumask *percpu_affinity;
	const struct cpumask *affinity_hint;
	struct irq_affinity_notify *affinity_notify;
	long unsigned int threads_oneshot;
	atomic_t threads_active;
	wait_queue_head_t wait_for_threads;
	unsigned int nr_actions;
	unsigned int no_suspend_depth;
	unsigned int cond_suspend_depth;
	unsigned int force_resume_depth;
	struct proc_dir_entry *dir;
	struct callback_head rcu;
	struct kobject___42 kobj;
	struct mutex request_mutex;
	int parent_irq;
	struct module___8 *owner;
	const char *name;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct irq_chip___65 {
	struct device___217 *parent_device;
	const char *name;
	unsigned int (*irq_startup)(struct irq_data___65 *);
	void (*irq_shutdown)(struct irq_data___65 *);
	void (*irq_enable)(struct irq_data___65 *);
	void (*irq_disable)(struct irq_data___65 *);
	void (*irq_ack)(struct irq_data___65 *);
	void (*irq_mask)(struct irq_data___65 *);
	void (*irq_mask_ack)(struct irq_data___65 *);
	void (*irq_unmask)(struct irq_data___65 *);
	void (*irq_eoi)(struct irq_data___65 *);
	int (*irq_set_affinity)(struct irq_data___65 *, const struct cpumask *, bool);
	int (*irq_retrigger)(struct irq_data___65 *);
	int (*irq_set_type)(struct irq_data___65 *, unsigned int);
	int (*irq_set_wake)(struct irq_data___65 *, unsigned int);
	void (*irq_bus_lock)(struct irq_data___65 *);
	void (*irq_bus_sync_unlock)(struct irq_data___65 *);
	void (*irq_cpu_online)(struct irq_data___65 *);
	void (*irq_cpu_offline)(struct irq_data___65 *);
	void (*irq_suspend)(struct irq_data___65 *);
	void (*irq_resume)(struct irq_data___65 *);
	void (*irq_pm_shutdown)(struct irq_data___65 *);
	void (*irq_calc_mask)(struct irq_data___65 *);
	void (*irq_print_chip)(struct irq_data___65 *, struct seq_file___9 *);
	int (*irq_request_resources)(struct irq_data___65 *);
	void (*irq_release_resources)(struct irq_data___65 *);
	void (*irq_compose_msi_msg)(struct irq_data___65 *, struct msi_msg *);
	void (*irq_write_msi_msg)(struct irq_data___65 *, struct msi_msg *);
	int (*irq_get_irqchip_state)(struct irq_data___65 *, enum irqchip_irq_state, bool *);
	int (*irq_set_irqchip_state)(struct irq_data___65 *, enum irqchip_irq_state, bool);
	int (*irq_set_vcpu_affinity)(struct irq_data___65 *, void *);
	void (*ipi_send_single)(struct irq_data___65 *, unsigned int);
	void (*ipi_send_mask)(struct irq_data___65 *, const struct cpumask *);
	int (*irq_nmi_setup)(struct irq_data___65 *);
	void (*irq_nmi_teardown)(struct irq_data___65 *);
	long unsigned int flags;
};

struct irq_chip_type___62 {
	struct irq_chip___65 chip;
	struct irq_chip_regs regs;
	irq_flow_handler_t___64 handler;
	u32 type;
	u32 mask_cache_priv;
	u32 *mask_cache;
};

struct irq_chip_generic___62 {
	raw_spinlock_t lock;
	void *reg_base;
	u32 (*reg_readl)(void *);
	void (*reg_writel)(u32, void *);
	void (*suspend)(struct irq_chip_generic___62 *);
	void (*resume)(struct irq_chip_generic___62 *);
	unsigned int irq_base;
	unsigned int irq_cnt;
	u32 mask_cache;
	u32 type_cache;
	u32 polarity_cache;
	u32 wake_enabled;
	u32 wake_active;
	unsigned int num_ct;
	void *private;
	long unsigned int installed;
	long unsigned int unused;
	struct irq_domain___62 *domain;
	struct list_head list;
	struct irq_chip_type___62 chip_types[0];
};

struct irq_domain_chip_generic___62 {
	unsigned int irqs_per_chip;
	unsigned int num_chips;
	unsigned int irq_flags_to_clear;
	unsigned int irq_flags_to_set;
	enum irq_gc_flags gc_flags;
	struct irq_chip_generic___62 *gc[0];
};

struct irq_fwspec___60 {
	struct fwnode_handle___213 *fwnode;
	int param_count;
	u32 param[16];
};

struct irq_domain_ops___62 {
	int (*match)(struct irq_domain___62 *, struct device_node___97 *, enum irq_domain_bus_token);
	int (*select)(struct irq_domain___62 *, struct irq_fwspec___60 *, enum irq_domain_bus_token);
	int (*map)(struct irq_domain___62 *, unsigned int, irq_hw_number_t);
	void (*unmap)(struct irq_domain___62 *, unsigned int);
	int (*xlate)(struct irq_domain___62 *, struct device_node___97 *, const u32 *, unsigned int, long unsigned int *, unsigned int *);
	int (*alloc)(struct irq_domain___62 *, unsigned int, unsigned int, void *);
	void (*free)(struct irq_domain___62 *, unsigned int, unsigned int);
	int (*activate)(struct irq_domain___62 *, struct irq_data___65 *, bool);
	void (*deactivate)(struct irq_domain___62 *, struct irq_data___65 *);
	int (*translate)(struct irq_domain___62 *, struct irq_fwspec___60 *, long unsigned int *, unsigned int *);
};

struct supplier_bindings {
	struct device_node___97 * (*parse_prop)(struct device_node___97 *, const char *, int);
	bool optional;
	bool node_not_dev;
};

struct of_reconfig_data___4 {
	struct device_node___62 *dn;
	struct property___48 *prop;
	struct property___48 *old_prop;
};

struct of_changeset_entry {
	struct list_head node;
	long unsigned int action;
	struct device_node___62 *np;
	struct property___48 *prop;
	struct property___48 *old_prop;
};

struct of_changeset {
	struct list_head entries;
};

struct of_bus___2 {
	void (*count_cells)(const void *, int, int *, int *);
	u64 (*map)(__be32 *, const __be32 *, int, int, int);
	int (*translate)(__be32 *, u64, int);
};

struct logic_pio_hwaddr___3 {
	struct list_head list;
	struct fwnode_handle___158 *fwnode;
	resource_size_t hw_start;
	resource_size_t io_start;
	resource_size_t size;
	long unsigned int flags;
	void *hostdata;
	const struct logic_pio_host_ops *ops;
};

struct of_phandle_args___42 {
	struct device_node___61 *np;
	int args_count;
	uint32_t args[16];
};

struct of_bus___3;

struct of_pci_range_parser___3 {
	struct device_node___61 *node;
	struct of_bus___3 *bus;
	const __be32 *range;
	const __be32 *end;
	int na;
	int ns;
	int pna;
	bool dma;
};

struct of_bus___3 {
	const char *name;
	const char *addresses;
	int (*match)(struct device_node___61 *);
	void (*count_cells)(struct device_node___61 *, int *, int *);
	u64 (*map)(__be32 *, const __be32 *, int, int, int);
	int (*translate)(__be32 *, u64, int);
	bool has_flags;
	unsigned int (*get_flags)(const __be32 *);
};

typedef int (*of_irq_init_cb_t___2)(struct device_node___95 *, struct device_node___95 *);

struct of_intc_desc {
	struct list_head list;
	of_irq_init_cb_t___2 irq_init_cb;
	struct device_node___95 *dev;
	struct device_node___95 *interrupt_parent;
};

struct rmem_assigned_device {
	struct device___214 *dev;
	struct reserved_mem *rmem;
	struct list_head list;
};

struct of_changeset_entry___2 {
	struct list_head node;
	long unsigned int action;
	struct device_node___95 *np;
	struct property___71 *prop;
	struct property___71 *old_prop;
};

enum of_overlay_notify_action {
	OF_OVERLAY_PRE_APPLY = 0,
	OF_OVERLAY_POST_APPLY = 1,
	OF_OVERLAY_PRE_REMOVE = 2,
	OF_OVERLAY_POST_REMOVE = 3,
};

struct of_overlay_notify_data {
	struct device_node___95 *overlay;
	struct device_node___95 *target;
};

struct target {
	struct device_node___95 *np;
	bool in_livetree;
};

struct fragment {
	struct device_node___95 *overlay;
	struct device_node___95 *target;
};

struct overlay_changeset {
	int id;
	struct list_head ovcs_list;
	const void *fdt;
	struct device_node___95 *overlay_tree;
	int count;
	struct fragment *fragments;
	bool symbols_fragment;
	struct of_changeset cset;
};

struct property___73 {
	char *name;
	int length;
	void *value;
	struct property___73 *next;
	long unsigned int _flags;
	struct bin_attribute___84 attr;
};

struct device_node___98 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___213 fwnode;
	struct property___73 *properties;
	struct property___73 *deadprops;
	struct device_node___98 *parent;
	struct device_node___98 *child;
	struct device_node___98 *sibling;
	struct kobject___84 kobj;
	long unsigned int _flags;
	void *data;
};

enum ec_status {
	EC_RES_SUCCESS = 0,
	EC_RES_INVALID_COMMAND = 1,
	EC_RES_ERROR = 2,
	EC_RES_INVALID_PARAM = 3,
	EC_RES_ACCESS_DENIED = 4,
	EC_RES_INVALID_RESPONSE = 5,
	EC_RES_INVALID_VERSION = 6,
	EC_RES_INVALID_CHECKSUM = 7,
	EC_RES_IN_PROGRESS = 8,
	EC_RES_UNAVAILABLE = 9,
	EC_RES_TIMEOUT = 10,
	EC_RES_OVERFLOW = 11,
	EC_RES_INVALID_HEADER = 12,
	EC_RES_REQUEST_TRUNCATED = 13,
	EC_RES_RESPONSE_TOO_BIG = 14,
	EC_RES_BUS_ERROR = 15,
	EC_RES_BUSY = 16,
	EC_RES_INVALID_HEADER_VERSION = 17,
	EC_RES_INVALID_HEADER_CRC = 18,
	EC_RES_INVALID_DATA_CRC = 19,
	EC_RES_DUP_UNAVAILABLE = 20,
};

enum host_event_code {
	EC_HOST_EVENT_LID_CLOSED = 1,
	EC_HOST_EVENT_LID_OPEN = 2,
	EC_HOST_EVENT_POWER_BUTTON = 3,
	EC_HOST_EVENT_AC_CONNECTED = 4,
	EC_HOST_EVENT_AC_DISCONNECTED = 5,
	EC_HOST_EVENT_BATTERY_LOW = 6,
	EC_HOST_EVENT_BATTERY_CRITICAL = 7,
	EC_HOST_EVENT_BATTERY = 8,
	EC_HOST_EVENT_THERMAL_THRESHOLD = 9,
	EC_HOST_EVENT_DEVICE = 10,
	EC_HOST_EVENT_THERMAL = 11,
	EC_HOST_EVENT_USB_CHARGER = 12,
	EC_HOST_EVENT_KEY_PRESSED = 13,
	EC_HOST_EVENT_INTERFACE_READY = 14,
	EC_HOST_EVENT_KEYBOARD_RECOVERY = 15,
	EC_HOST_EVENT_THERMAL_SHUTDOWN = 16,
	EC_HOST_EVENT_BATTERY_SHUTDOWN = 17,
	EC_HOST_EVENT_THROTTLE_START = 18,
	EC_HOST_EVENT_THROTTLE_STOP = 19,
	EC_HOST_EVENT_HANG_DETECT = 20,
	EC_HOST_EVENT_HANG_REBOOT = 21,
	EC_HOST_EVENT_PD_MCU = 22,
	EC_HOST_EVENT_BATTERY_STATUS = 23,
	EC_HOST_EVENT_PANIC = 24,
	EC_HOST_EVENT_KEYBOARD_FASTBOOT = 25,
	EC_HOST_EVENT_RTC = 26,
	EC_HOST_EVENT_MKBP = 27,
	EC_HOST_EVENT_USB_MUX = 28,
	EC_HOST_EVENT_MODE_CHANGE = 29,
	EC_HOST_EVENT_KEYBOARD_RECOVERY_HW_REINIT = 30,
	EC_HOST_EVENT_WOV = 31,
	EC_HOST_EVENT_INVALID = 32,
};

struct ec_host_request {
	uint8_t struct_version;
	uint8_t checksum;
	uint16_t command;
	uint8_t command_version;
	uint8_t reserved;
	uint16_t data_len;
};

struct ec_params_hello {
	uint32_t in_data;
};

struct ec_response_hello {
	uint32_t out_data;
};

struct ec_params_get_cmd_versions {
	uint8_t cmd;
};

struct ec_response_get_cmd_versions {
	uint32_t version_mask;
};

enum ec_comms_status {
	EC_COMMS_STATUS_PROCESSING = 1,
};

struct ec_response_get_comms_status {
	uint32_t flags;
};

struct ec_response_get_protocol_info {
	uint32_t protocol_versions;
	uint16_t max_request_packet_size;
	uint16_t max_response_packet_size;
	uint32_t flags;
};

enum ec_led_colors {
	EC_LED_COLOR_RED = 0,
	EC_LED_COLOR_GREEN = 1,
	EC_LED_COLOR_BLUE = 2,
	EC_LED_COLOR_YELLOW = 3,
	EC_LED_COLOR_WHITE = 4,
	EC_LED_COLOR_AMBER = 5,
	EC_LED_COLOR_COUNT = 6,
};

enum motionsense_command {
	MOTIONSENSE_CMD_DUMP = 0,
	MOTIONSENSE_CMD_INFO = 1,
	MOTIONSENSE_CMD_EC_RATE = 2,
	MOTIONSENSE_CMD_SENSOR_ODR = 3,
	MOTIONSENSE_CMD_SENSOR_RANGE = 4,
	MOTIONSENSE_CMD_KB_WAKE_ANGLE = 5,
	MOTIONSENSE_CMD_DATA = 6,
	MOTIONSENSE_CMD_FIFO_INFO = 7,
	MOTIONSENSE_CMD_FIFO_FLUSH = 8,
	MOTIONSENSE_CMD_FIFO_READ = 9,
	MOTIONSENSE_CMD_PERFORM_CALIB = 10,
	MOTIONSENSE_CMD_SENSOR_OFFSET = 11,
	MOTIONSENSE_CMD_LIST_ACTIVITIES = 12,
	MOTIONSENSE_CMD_SET_ACTIVITY = 13,
	MOTIONSENSE_CMD_LID_ANGLE = 14,
	MOTIONSENSE_CMD_FIFO_INT_ENABLE = 15,
	MOTIONSENSE_CMD_SPOOF = 16,
	MOTIONSENSE_CMD_TABLET_MODE_LID_ANGLE = 17,
	MOTIONSENSE_CMD_SENSOR_SCALE = 18,
	MOTIONSENSE_NUM_CMDS = 19,
};

struct ec_response_motion_sensor_data {
	uint8_t flags;
	uint8_t sensor_num;
	union {
		int16_t data[3];
		struct {
			uint16_t reserved;
			uint32_t timestamp;
		} __attribute__((packed));
		struct {
			uint8_t activity;
			uint8_t state;
			int16_t add_info[2];
		};
	};
} __attribute__((packed));

struct ec_response_motion_sense_fifo_info {
	uint16_t size;
	uint16_t count;
	uint32_t timestamp;
	uint16_t total_lost;
	uint16_t lost[0];
} __attribute__((packed));

struct ec_response_motion_sense_fifo_data {
	uint32_t number_data;
	struct ec_response_motion_sensor_data data[0];
};

struct ec_motion_sense_activity {
	uint8_t sensor_num;
	uint8_t activity;
	uint8_t enable;
	uint8_t reserved;
	uint16_t parameters[3];
};

struct ec_params_motion_sense {
	uint8_t cmd;
	union {
		struct {
			uint8_t max_sensor_count;
		} dump;
		struct {
			int16_t data;
		} kb_wake_angle;
		struct {
			uint8_t sensor_num;
		} info;
		struct {
			uint8_t sensor_num;
		} info_3;
		struct {
			uint8_t sensor_num;
		} data;
		struct {
			uint8_t sensor_num;
		} fifo_flush;
		struct {
			uint8_t sensor_num;
		} perform_calib;
		struct {
			uint8_t sensor_num;
		} list_activities;
		struct {
			uint8_t sensor_num;
			uint8_t roundup;
			uint16_t reserved;
			int32_t data;
		} ec_rate;
		struct {
			uint8_t sensor_num;
			uint8_t roundup;
			uint16_t reserved;
			int32_t data;
		} sensor_odr;
		struct {
			uint8_t sensor_num;
			uint8_t roundup;
			uint16_t reserved;
			int32_t data;
		} sensor_range;
		struct {
			uint8_t sensor_num;
			uint16_t flags;
			int16_t temp;
			int16_t offset[3];
		} __attribute__((packed)) sensor_offset;
		struct {
			uint8_t sensor_num;
			uint16_t flags;
			int16_t temp;
			uint16_t scale[3];
		} __attribute__((packed)) sensor_scale;
		struct {
			uint32_t max_data_vector;
		} fifo_read;
		struct ec_motion_sense_activity set_activity;
		struct {
			int8_t enable;
		} fifo_int_enable;
		struct {
			uint8_t sensor_id;
			uint8_t spoof_enable;
			uint8_t reserved;
			int16_t components[3];
		} __attribute__((packed)) spoof;
		struct {
			int16_t lid_angle;
			int16_t hys_degree;
		} tablet_mode_threshold;
	};
} __attribute__((packed));

struct ec_response_motion_sense {
	union {
		struct {
			uint8_t module_flags;
			uint8_t sensor_count;
			struct ec_response_motion_sensor_data sensor[0];
		} __attribute__((packed)) dump;
		struct {
			uint8_t type;
			uint8_t location;
			uint8_t chip;
		} info;
		struct {
			uint8_t type;
			uint8_t location;
			uint8_t chip;
			uint32_t min_frequency;
			uint32_t max_frequency;
			uint32_t fifo_max_event_count;
		} info_3;
		struct ec_response_motion_sensor_data data;
		struct {
			int32_t ret;
		} ec_rate;
		struct {
			int32_t ret;
		} sensor_odr;
		struct {
			int32_t ret;
		} sensor_range;
		struct {
			int32_t ret;
		} kb_wake_angle;
		struct {
			int32_t ret;
		} fifo_int_enable;
		struct {
			int32_t ret;
		} spoof;
		struct {
			int16_t temp;
			int16_t offset[3];
		} sensor_offset;
		struct {
			int16_t temp;
			int16_t offset[3];
		} perform_calib;
		struct {
			int16_t temp;
			uint16_t scale[3];
		} sensor_scale;
		struct ec_response_motion_sense_fifo_info fifo_info;
		struct ec_response_motion_sense_fifo_info fifo_flush;
		struct ec_response_motion_sense_fifo_data fifo_read;
		struct {
			uint16_t reserved;
			uint32_t enabled;
			uint32_t disabled;
		} __attribute__((packed)) list_activities;
		struct {
			uint16_t value;
		} lid_angle;
		struct {
			uint16_t lid_angle;
			uint16_t hys_degree;
		} tablet_mode_threshold;
	};
};

enum ec_temp_thresholds {
	EC_TEMP_THRESH_WARN = 0,
	EC_TEMP_THRESH_HIGH = 1,
	EC_TEMP_THRESH_HALT = 2,
	EC_TEMP_THRESH_COUNT = 3,
};

enum ec_mkbp_event {
	EC_MKBP_EVENT_KEY_MATRIX = 0,
	EC_MKBP_EVENT_HOST_EVENT = 1,
	EC_MKBP_EVENT_SENSOR_FIFO = 2,
	EC_MKBP_EVENT_BUTTON = 3,
	EC_MKBP_EVENT_SWITCH = 4,
	EC_MKBP_EVENT_FINGERPRINT = 5,
	EC_MKBP_EVENT_SYSRQ = 6,
	EC_MKBP_EVENT_HOST_EVENT64 = 7,
	EC_MKBP_EVENT_CEC_EVENT = 8,
	EC_MKBP_EVENT_CEC_MESSAGE = 9,
	EC_MKBP_EVENT_COUNT = 10,
};

union ec_response_get_next_data_v1 {
	uint8_t key_matrix[16];
	uint32_t host_event;
	uint64_t host_event64;
	struct {
		uint8_t reserved[3];
		struct ec_response_motion_sense_fifo_info info;
	} __attribute__((packed)) sensor_fifo;
	uint32_t buttons;
	uint32_t switches;
	uint32_t fp_events;
	uint32_t sysrq;
	uint32_t cec_events;
	uint8_t cec_message[16];
};

struct ec_response_get_next_event_v1 {
	uint8_t event_type;
	union ec_response_get_next_data_v1 data;
} __attribute__((packed));

struct ec_response_host_event_mask {
	uint32_t mask;
};

enum {
	EC_MSG_TX_HEADER_BYTES = 3,
	EC_MSG_TX_TRAILER_BYTES = 1,
	EC_MSG_TX_PROTO_BYTES = 4,
	EC_MSG_RX_PROTO_BYTES = 3,
	EC_PROTO2_MSG_BYTES = 256,
	EC_MAX_MSG_BYTES = 65536,
};

struct cros_ec_command {
	uint32_t version;
	uint32_t command;
	uint32_t outsize;
	uint32_t insize;
	uint32_t result;
	uint8_t data[0];
};

struct cros_ec_device {
	const char *phys_name;
	struct device___216 *dev;
	bool was_wake_device;
	struct class___216 *cros_class;
	int (*cmd_readmem)(struct cros_ec_device *, unsigned int, unsigned int, void *);
	u16 max_request;
	u16 max_response;
	u16 max_passthru;
	u16 proto_version;
	void *priv;
	int irq;
	u8 *din;
	u8 *dout;
	int din_size;
	int dout_size;
	bool wake_enabled;
	bool suspended;
	int (*cmd_xfer)(struct cros_ec_device *, struct cros_ec_command *);
	int (*pkt_xfer)(struct cros_ec_device *, struct cros_ec_command *);
	struct mutex lock;
	u8 mkbp_event_supported;
	bool host_sleep_v1;
	struct blocking_notifier_head event_notifier;
	struct ec_response_get_next_event_v1 event_data;
	int event_size;
	u32 host_event_wake_mask;
	u32 last_resume_result;
	ktime_t last_event_time;
	struct notifier_block notifier_ready;
	struct platform_device___33 *ec;
	struct platform_device___33 *pd;
};

struct cros_ec_debugfs;

struct cros_ec_dev {
	struct device___216 class_dev;
	struct cros_ec_device *ec_dev;
	struct device___216 *dev;
	struct cros_ec_debugfs *debug_info;
	bool has_kb_wake_angle;
	u16 cmd_offset;
	u32 features[2];
};

struct trace_event_raw_cros_ec_request_start {
	struct trace_entry ent;
	uint32_t version;
	uint32_t offset;
	uint32_t command;
	uint32_t outsize;
	uint32_t insize;
	char __data[0];
};

struct trace_event_raw_cros_ec_request_done {
	struct trace_entry ent;
	uint32_t version;
	uint32_t offset;
	uint32_t command;
	uint32_t outsize;
	uint32_t insize;
	uint32_t result;
	int retval;
	char __data[0];
};

struct trace_event_data_offsets_cros_ec_request_start {};

struct trace_event_data_offsets_cros_ec_request_done {};

typedef void (*btf_trace_cros_ec_request_start)(void *, struct cros_ec_command *);

typedef void (*btf_trace_cros_ec_request_done)(void *, struct cros_ec_command *, int);

struct rockchip_mbox_msg {
	u32 cmd;
	int rx_size;
};

struct rockchip_mbox_data {
	int num_chans;
};

struct rockchip_mbox;

struct rockchip_mbox_chan {
	int idx;
	int irq;
	struct rockchip_mbox_msg *msg;
	struct rockchip_mbox *mb;
};

struct rockchip_mbox {
	struct mbox_controller mbox;
	struct clk *pclk;
	void *mbox_base;
	u32 buf_size;
	struct rockchip_mbox_chan *chans;
};

struct acpi_table_pcct {
	struct acpi_table_header header;
	u32 flags;
	u64 reserved;
};

enum acpi_pcct_type {
	ACPI_PCCT_TYPE_GENERIC_SUBSPACE = 0,
	ACPI_PCCT_TYPE_HW_REDUCED_SUBSPACE = 1,
	ACPI_PCCT_TYPE_HW_REDUCED_SUBSPACE_TYPE2 = 2,
	ACPI_PCCT_TYPE_EXT_PCC_MASTER_SUBSPACE = 3,
	ACPI_PCCT_TYPE_EXT_PCC_SLAVE_SUBSPACE = 4,
	ACPI_PCCT_TYPE_HW_REG_COMM_SUBSPACE = 5,
	ACPI_PCCT_TYPE_RESERVED = 6,
};

struct acpi_pcct_subspace {
	struct acpi_subtable_header header;
	u8 reserved[6];
	u64 base_address;
	u64 length;
	struct acpi_generic_address doorbell_register;
	u64 preserve_mask;
	u64 write_mask;
	u32 latency;
	u32 max_access_rate;
	u16 min_turnaround_time;
} __attribute__((packed));

struct acpi_pcct_hw_reduced_type2 {
	struct acpi_subtable_header header;
	u32 platform_interrupt;
	u8 flags;
	u8 reserved;
	u64 base_address;
	u64 length;
	struct acpi_generic_address doorbell_register;
	u64 preserve_mask;
	u64 write_mask;
	u32 latency;
	u32 max_access_rate;
	u16 min_turnaround_time;
	struct acpi_generic_address platform_ack_register;
	u64 ack_preserve_mask;
	u64 ack_write_mask;
} __attribute__((packed));

struct bcm2835_mbox {
	void *regs;
	spinlock_t lock;
	struct mbox_controller controller;
};

struct ti_msgmgr_valid_queue_desc {
	u8 queue_id;
	u8 proxy_id;
	bool is_tx;
};

struct ti_msgmgr_desc {
	u8 queue_count;
	u8 max_message_size;
	u8 max_messages;
	u8 data_first_reg;
	u8 data_last_reg;
	u32 status_cnt_mask;
	u32 status_err_mask;
	bool tx_polled;
	int tx_poll_timeout_ms;
	const struct ti_msgmgr_valid_queue_desc *valid_queues;
	const char *data_region_name;
	const char *status_region_name;
	const char *ctrl_region_name;
	int num_valid_queues;
	bool is_sproxy;
};

struct ti_queue_inst {
	char name[30];
	u8 queue_id;
	u8 proxy_id;
	int irq;
	bool is_tx;
	void *queue_buff_start;
	void *queue_buff_end;
	void *queue_state;
	void *queue_ctrl;
	struct mbox_chan *chan;
	u32 *rx_buff;
};

struct ti_msgmgr_inst {
	struct device___214 *dev;
	const struct ti_msgmgr_desc *desc;
	void *queue_proxy_region;
	void *queue_state_debug_region;
	void *queue_ctrl_region;
	u8 num_valid_queues;
	struct ti_queue_inst *qinsts;
	struct mbox_controller mbox;
	struct mbox_chan *chans;
};

struct mbox_chan___3;

struct mbox_chan_ops___2 {
	int (*send_data)(struct mbox_chan___3 *, void *);
	int (*flush)(struct mbox_chan___3 *, long unsigned int);
	int (*startup)(struct mbox_chan___3 *);
	void (*shutdown)(struct mbox_chan___3 *);
	bool (*last_tx_done)(struct mbox_chan___3 *);
	bool (*peek_data)(struct mbox_chan___3 *);
};

struct mbox_controller___2;

struct mbox_chan___3 {
	struct mbox_controller___2 *mbox;
	unsigned int txdone_method;
	struct mbox_client *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller___2 {
	struct device___217 *dev;
	const struct mbox_chan_ops___2 *ops;
	struct mbox_chan___3 *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan___3 * (*of_xlate)(struct mbox_controller___2 *, const struct of_phandle_args___41 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct tegra_hsp;

struct tegra_hsp_channel {
	struct tegra_hsp *hsp;
	struct mbox_chan___3 *chan;
	void *regs;
};

struct tegra_hsp_soc;

struct tegra_hsp_mailbox;

struct tegra_hsp {
	struct device___217 *dev;
	const struct tegra_hsp_soc *soc;
	struct mbox_controller___2 mbox_db;
	struct mbox_controller___2 mbox_sm;
	void *regs;
	unsigned int doorbell_irq;
	unsigned int *shared_irqs;
	unsigned int shared_irq;
	unsigned int num_sm;
	unsigned int num_as;
	unsigned int num_ss;
	unsigned int num_db;
	unsigned int num_si;
	spinlock_t lock;
	struct lock_class_key lock_key;
	struct list_head doorbells;
	struct tegra_hsp_mailbox *mailboxes;
	long unsigned int mask;
};

struct tegra_hsp_doorbell {
	struct tegra_hsp_channel channel;
	struct list_head list;
	const char *name;
	unsigned int master;
	unsigned int index;
};

struct tegra_hsp_mailbox {
	struct tegra_hsp_channel channel;
	unsigned int index;
	bool producer;
};

struct tegra_hsp_db_map {
	const char *name;
	unsigned int master;
	unsigned int index;
};

struct tegra_hsp_soc {
	const struct tegra_hsp_db_map *map;
	bool has_per_mb_ie;
};

struct mbox_chan___4;

struct mbox_chan_ops___3 {
	int (*send_data)(struct mbox_chan___4 *, void *);
	int (*flush)(struct mbox_chan___4 *, long unsigned int);
	int (*startup)(struct mbox_chan___4 *);
	void (*shutdown)(struct mbox_chan___4 *);
	bool (*last_tx_done)(struct mbox_chan___4 *);
	bool (*peek_data)(struct mbox_chan___4 *);
};

struct mbox_controller___3;

struct mbox_chan___4 {
	struct mbox_controller___3 *mbox;
	unsigned int txdone_method;
	struct mbox_client *cl;
	struct completion tx_complete;
	void *active_req;
	unsigned int msg_count;
	unsigned int msg_free;
	void *msg_data[20];
	spinlock_t lock;
	void *con_priv;
};

struct mbox_controller___3 {
	struct device___215 *dev;
	const struct mbox_chan_ops___3 *ops;
	struct mbox_chan___4 *chans;
	int num_chans;
	bool txdone_irq;
	bool txdone_poll;
	unsigned int txpoll_period;
	struct mbox_chan___4 * (*of_xlate)(struct mbox_controller___3 *, const struct of_phandle_args___40 *);
	struct hrtimer poll_hrt;
	struct list_head node;
};

struct zynqmp_ipi_mchan {
	int is_opened;
	void *req_buf;
	void *resp_buf;
	void *rx_buf;
	size_t req_buf_size;
	size_t resp_buf_size;
	unsigned int chan_type;
};

struct zynqmp_ipi_pdata;

struct zynqmp_ipi_mbox {
	struct zynqmp_ipi_pdata *pdata;
	struct device___215 dev;
	u32 remote_id;
	struct mbox_controller___3 mbox;
	struct zynqmp_ipi_mchan mchans[2];
};

struct zynqmp_ipi_pdata {
	struct device___215 *dev;
	int irq;
	unsigned int method;
	u32 local_id;
	int num_mboxes;
	struct zynqmp_ipi_mbox *ipi_mboxes;
};

struct sun6i_msgbox {
	struct mbox_controller controller;
	struct clk *clk;
	spinlock_t lock;
	void *regs;
};

struct qcom_ipcc_chan_info {
	u16 client_id;
	u16 signal_id;
};

struct qcom_ipcc {
	struct device___215 *dev;
	void *base;
	struct irq_domain___61 *irq_domain;
	struct mbox_chan___4 chan[48];
	struct qcom_ipcc_chan_info mchan[48];
	struct mbox_controller___3 mbox;
	int irq;
};

typedef int (*dr_match_t___29)(struct device___215 *, void *, void *);

struct hwspinlock___2;

struct hwspinlock_ops {
	int (*trylock)(struct hwspinlock___2 *);
	void (*unlock)(struct hwspinlock___2 *);
	void (*relax)(struct hwspinlock___2 *);
};

struct hwspinlock_device;

struct hwspinlock___2 {
	struct hwspinlock_device *bank;
	spinlock_t lock;
	void *priv;
};

struct hwspinlock_device {
	struct device___215 *dev;
	const struct hwspinlock_ops *ops;
	int base_id;
	int num_locks;
	struct hwspinlock___2 lock[0];
};

struct wakeup_source___218;

struct device___218;

struct dev_pm_info___218 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___218 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___218 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___218;

struct bus_type___218;

struct device_driver___218;

struct dev_pm_domain___218;

struct dma_map_ops___13;

struct device_node___99;

struct fwnode_handle___214;

struct class___218;

struct dev_iommu___13;

struct device___218 {
	struct kobject___225 kobj;
	struct device___218 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___218 *type;
	struct bus_type___218 *bus;
	struct device_driver___218 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___218 power;
	struct dev_pm_domain___218 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops___13 *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem___4 *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___99 *of_node;
	struct fwnode_handle___214 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___218 *class;
	const struct attribute_group___225 **groups;
	void (*release)(struct device___218 *);
	struct iommu_group *iommu_group;
	struct dev_iommu___13 *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___218 {
	int (*prepare)(struct device___218 *);
	void (*complete)(struct device___218 *);
	int (*suspend)(struct device___218 *);
	int (*resume)(struct device___218 *);
	int (*freeze)(struct device___218 *);
	int (*thaw)(struct device___218 *);
	int (*poweroff)(struct device___218 *);
	int (*restore)(struct device___218 *);
	int (*suspend_late)(struct device___218 *);
	int (*resume_early)(struct device___218 *);
	int (*freeze_late)(struct device___218 *);
	int (*thaw_early)(struct device___218 *);
	int (*poweroff_late)(struct device___218 *);
	int (*restore_early)(struct device___218 *);
	int (*suspend_noirq)(struct device___218 *);
	int (*resume_noirq)(struct device___218 *);
	int (*freeze_noirq)(struct device___218 *);
	int (*thaw_noirq)(struct device___218 *);
	int (*poweroff_noirq)(struct device___218 *);
	int (*restore_noirq)(struct device___218 *);
	int (*runtime_suspend)(struct device___218 *);
	int (*runtime_resume)(struct device___218 *);
	int (*runtime_idle)(struct device___218 *);
};

struct wakeup_source___218 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___218 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___218 {
	struct dev_pm_ops___218 ops;
	int (*start)(struct device___218 *);
	void (*detach)(struct device___218 *, bool);
	int (*activate)(struct device___218 *);
	void (*sync)(struct device___218 *);
	void (*dismiss)(struct device___218 *);
};

struct iommu_ops___13;

struct bus_type___218 {
	const char *name;
	const char *dev_name;
	struct device___218 *dev_root;
	const struct attribute_group___225 **bus_groups;
	const struct attribute_group___225 **dev_groups;
	const struct attribute_group___225 **drv_groups;
	int (*match)(struct device___218 *, struct device_driver___218 *);
	int (*uevent)(struct device___218 *, struct kobj_uevent_env *);
	int (*probe)(struct device___218 *);
	void (*sync_state)(struct device___218 *);
	void (*remove)(struct device___218 *);
	void (*shutdown)(struct device___218 *);
	int (*online)(struct device___218 *);
	int (*offline)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	int (*num_vf)(struct device___218 *);
	int (*dma_configure)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
	const struct iommu_ops___13 *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___218 {
	const char *name;
	struct bus_type___218 *bus;
	struct module___221 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___218 *);
	void (*sync_state)(struct device___218 *);
	int (*remove)(struct device___218 *);
	void (*shutdown)(struct device___218 *);
	int (*suspend)(struct device___218 *, pm_message_t);
	int (*resume)(struct device___218 *);
	const struct attribute_group___225 **groups;
	const struct attribute_group___225 **dev_groups;
	const struct dev_pm_ops___218 *pm;
	void (*coredump)(struct device___218 *);
	struct driver_private *p;
};

struct iommu_domain___13;

struct iommu_device___13;

struct of_phandle_args___43;

struct iommu_sva___13;

struct iommu_ops___13 {
	bool (*capable)(enum iommu_cap);
	struct iommu_domain___13 * (*domain_alloc)(unsigned int);
	void (*domain_free)(struct iommu_domain___13 *);
	int (*attach_dev)(struct iommu_domain___13 *, struct device___218 *);
	void (*detach_dev)(struct iommu_domain___13 *, struct device___218 *);
	int (*map)(struct iommu_domain___13 *, long unsigned int, phys_addr_t, size_t, int, gfp_t);
	int (*map_pages)(struct iommu_domain___13 *, long unsigned int, phys_addr_t, size_t, size_t, int, gfp_t, size_t *);
	size_t (*unmap)(struct iommu_domain___13 *, long unsigned int, size_t, struct iommu_iotlb_gather___4 *);
	size_t (*unmap_pages)(struct iommu_domain___13 *, long unsigned int, size_t, size_t, struct iommu_iotlb_gather___4 *);
	void (*flush_iotlb_all)(struct iommu_domain___13 *);
	void (*iotlb_sync_map)(struct iommu_domain___13 *, long unsigned int, size_t);
	void (*iotlb_sync)(struct iommu_domain___13 *, struct iommu_iotlb_gather___4 *);
	phys_addr_t (*iova_to_phys)(struct iommu_domain___13 *, dma_addr_t);
	struct iommu_device___13 * (*probe_device)(struct device___218 *);
	void (*release_device)(struct device___218 *);
	void (*probe_finalize)(struct device___218 *);
	struct iommu_group * (*device_group)(struct device___218 *);
	int (*enable_nesting)(struct iommu_domain___13 *);
	int (*set_pgtable_quirks)(struct iommu_domain___13 *, long unsigned int);
	void (*get_resv_regions)(struct device___218 *, struct list_head *);
	void (*put_resv_regions)(struct device___218 *, struct list_head *);
	void (*apply_resv_region)(struct device___218 *, struct iommu_domain___13 *, struct iommu_resv_region *);
	int (*of_xlate)(struct device___218 *, struct of_phandle_args___43 *);
	bool (*is_attach_deferred)(struct iommu_domain___13 *, struct device___218 *);
	bool (*dev_has_feat)(struct device___218 *, enum iommu_dev_features);
	bool (*dev_feat_enabled)(struct device___218 *, enum iommu_dev_features);
	int (*dev_enable_feat)(struct device___218 *, enum iommu_dev_features);
	int (*dev_disable_feat)(struct device___218 *, enum iommu_dev_features);
	int (*aux_attach_dev)(struct iommu_domain___13 *, struct device___218 *);
	void (*aux_detach_dev)(struct iommu_domain___13 *, struct device___218 *);
	int (*aux_get_pasid)(struct iommu_domain___13 *, struct device___218 *);
	struct iommu_sva___13 * (*sva_bind)(struct device___218 *, struct mm_struct___243 *, void *);
	void (*sva_unbind)(struct iommu_sva___13 *);
	u32 (*sva_get_pasid)(struct iommu_sva___13 *);
	int (*page_response)(struct device___218 *, struct iommu_fault_event *, struct iommu_page_response *);
	int (*cache_invalidate)(struct iommu_domain___13 *, struct device___218 *, struct iommu_cache_invalidate_info *);
	int (*sva_bind_gpasid)(struct iommu_domain___13 *, struct device___218 *, struct iommu_gpasid_bind_data *);
	int (*sva_unbind_gpasid)(struct device___218 *, u32);
	int (*def_domain_type)(struct device___218 *);
	long unsigned int pgsize_bitmap;
	struct module___221 *owner;
};

struct device_type___218 {
	const char *name;
	const struct attribute_group___225 **groups;
	int (*uevent)(struct device___218 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___218 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___218 *);
	const struct dev_pm_ops___218 *pm;
};

struct class___218 {
	const char *name;
	struct module___221 *owner;
	const struct attribute_group___225 **class_groups;
	const struct attribute_group___225 **dev_groups;
	struct kobject___225 *dev_kobj;
	int (*dev_uevent)(struct device___218 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___218 *, umode_t *);
	void (*class_release)(struct class___218 *);
	void (*dev_release)(struct device___218 *);
	int (*shutdown_pre)(struct device___218 *);
	const struct kobj_ns_type_operations___35 *ns_type;
	const void * (*namespace)(struct device___218 *);
	void (*get_ownership)(struct device___218 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___218 *pm;
	struct subsys_private *p;
};

typedef void (*dr_release_t___39)(struct device___218 *, void *);

struct dma_map_ops___13 {
	void * (*alloc)(struct device___218 *, size_t, dma_addr_t *, gfp_t, long unsigned int);
	void (*free)(struct device___218 *, size_t, void *, dma_addr_t, long unsigned int);
	struct page___242 * (*alloc_pages)(struct device___218 *, size_t, dma_addr_t *, enum dma_data_direction, gfp_t);
	void (*free_pages)(struct device___218 *, size_t, struct page___242 *, dma_addr_t, enum dma_data_direction);
	struct sg_table * (*alloc_noncontiguous)(struct device___218 *, size_t, enum dma_data_direction, gfp_t, long unsigned int);
	void (*free_noncontiguous)(struct device___218 *, size_t, struct sg_table *, enum dma_data_direction);
	int (*mmap)(struct device___218 *, struct vm_area_struct___242 *, void *, dma_addr_t, size_t, long unsigned int);
	int (*get_sgtable)(struct device___218 *, struct sg_table *, void *, dma_addr_t, size_t, long unsigned int);
	dma_addr_t (*map_page)(struct device___218 *, struct page___242 *, long unsigned int, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_page)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	int (*map_sg)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	void (*unmap_sg)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction, long unsigned int);
	dma_addr_t (*map_resource)(struct device___218 *, phys_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*unmap_resource)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction, long unsigned int);
	void (*sync_single_for_cpu)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_single_for_device)(struct device___218 *, dma_addr_t, size_t, enum dma_data_direction);
	void (*sync_sg_for_cpu)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction);
	void (*sync_sg_for_device)(struct device___218 *, struct scatterlist *, int, enum dma_data_direction);
	void (*cache_sync)(struct device___218 *, void *, size_t, enum dma_data_direction);
	int (*dma_supported)(struct device___218 *, u64);
	u64 (*get_required_mask)(struct device___218 *);
	size_t (*max_mapping_size)(struct device___218 *);
	long unsigned int (*get_merge_boundary)(struct device___218 *);
};

struct fwnode_operations___214;

struct fwnode_handle___214 {
	struct fwnode_handle___214 *secondary;
	const struct fwnode_operations___214 *ops;
	struct device___218 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct device_node___99 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___214 fwnode;
	struct property___69 *properties;
	struct property___69 *deadprops;
	struct device_node___99 *parent;
	struct device_node___99 *child;
	struct device_node___99 *sibling;
	struct kobject___225 kobj;
	long unsigned int _flags;
	void *data;
};

struct iommu_fwspec___13;

struct dev_iommu___13 {
	struct mutex lock;
	struct iommu_fault_param *fault_param;
	struct iopf_device_param *iopf_param;
	struct iommu_fwspec___13 *fwspec;
	struct iommu_device___13 *iommu_dev;
	void *priv;
};

struct fwnode_reference_args___214;

struct fwnode_endpoint___214;

struct fwnode_operations___214 {
	struct fwnode_handle___214 * (*get)(struct fwnode_handle___214 *);
	void (*put)(struct fwnode_handle___214 *);
	bool (*device_is_available)(const struct fwnode_handle___214 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___214 *, const struct device___218 *);
	bool (*property_present)(const struct fwnode_handle___214 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___214 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___214 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___214 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*get_parent)(const struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*get_next_child_node)(const struct fwnode_handle___214 *, struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*get_named_child_node)(const struct fwnode_handle___214 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___214 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___214 *);
	struct fwnode_handle___214 * (*graph_get_next_endpoint)(const struct fwnode_handle___214 *, struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*graph_get_remote_endpoint)(const struct fwnode_handle___214 *);
	struct fwnode_handle___214 * (*graph_get_port_parent)(struct fwnode_handle___214 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___214 *, struct fwnode_endpoint___214 *);
	int (*add_links)(struct fwnode_handle___214 *);
};

struct fwnode_endpoint___214 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___214 *local_fwnode;
};

struct fwnode_reference_args___214 {
	struct fwnode_handle___214 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct virtio_device___7;

struct virtqueue___7 {
	struct list_head list;
	void (*callback)(struct virtqueue___7 *);
	const char *name;
	struct virtio_device___7 *vdev;
	unsigned int index;
	unsigned int num_free;
	void *priv;
};

struct virtio_config_ops___7;

struct virtio_device___7 {
	int index;
	bool failed;
	bool config_enabled;
	bool config_change_pending;
	spinlock_t config_lock;
	spinlock_t vqs_list_lock;
	struct device___218 dev;
	struct virtio_device_id id;
	const struct virtio_config_ops___7 *config;
	const struct vringh_config_ops *vringh_config;
	struct list_head vqs;
	u64 features;
	void *priv;
};

typedef void vq_callback_t___7(struct virtqueue___7 *);

struct virtio_config_ops___7 {
	void (*get)(struct virtio_device___7 *, unsigned int, void *, unsigned int);
	void (*set)(struct virtio_device___7 *, unsigned int, const void *, unsigned int);
	u32 (*generation)(struct virtio_device___7 *);
	u8 (*get_status)(struct virtio_device___7 *);
	void (*set_status)(struct virtio_device___7 *, u8);
	void (*reset)(struct virtio_device___7 *);
	int (*find_vqs)(struct virtio_device___7 *, unsigned int, struct virtqueue___7 **, vq_callback_t___7 **, const char * const *, const bool *, struct irq_affinity *);
	void (*del_vqs)(struct virtio_device___7 *);
	u64 (*get_features)(struct virtio_device___7 *);
	int (*finalize_features)(struct virtio_device___7 *);
	const char * (*bus_name)(struct virtio_device___7 *);
	int (*set_vq_affinity)(struct virtqueue___7 *, const struct cpumask *);
	const struct cpumask * (*get_vq_affinity)(struct virtio_device___7 *, int);
	bool (*get_shm_region)(struct virtio_device___7 *, struct virtio_shm_region *, u8);
};

struct of_phandle_args___43 {
	struct device_node___99 *np;
	int args_count;
	uint32_t args[16];
};

struct resource_table {
	u32 ver;
	u32 num;
	u32 reserved[2];
	u32 offset[0];
};

struct fw_rsc_hdr {
	u32 type;
	u8 data[0];
};

enum fw_resource_type {
	RSC_CARVEOUT = 0,
	RSC_DEVMEM = 1,
	RSC_TRACE = 2,
	RSC_VDEV = 3,
	RSC_LAST = 4,
	RSC_VENDOR_START = 128,
	RSC_VENDOR_END = 512,
};

struct fw_rsc_carveout {
	u32 da;
	u32 pa;
	u32 len;
	u32 flags;
	u32 reserved;
	u8 name[32];
};

struct fw_rsc_devmem {
	u32 da;
	u32 pa;
	u32 len;
	u32 flags;
	u32 reserved;
	u8 name[32];
};

struct fw_rsc_trace {
	u32 da;
	u32 len;
	u32 reserved;
	u8 name[32];
};

struct fw_rsc_vdev_vring {
	u32 da;
	u32 align;
	u32 num;
	u32 notifyid;
	u32 pa;
};

struct fw_rsc_vdev {
	u32 id;
	u32 notifyid;
	u32 dfeatures;
	u32 gfeatures;
	u32 config_len;
	u8 status;
	u8 num_of_vrings;
	u8 reserved[2];
	struct fw_rsc_vdev_vring vring[0];
};

struct rproc;

struct rproc_mem_entry {
	void *va;
	bool is_iomem;
	dma_addr_t dma;
	size_t len;
	u32 da;
	void *priv;
	char name[32];
	struct list_head node;
	u32 rsc_offset;
	u32 flags;
	u32 of_resm_idx;
	int (*alloc)(struct rproc *, struct rproc_mem_entry *);
	int (*release)(struct rproc *, struct rproc_mem_entry *);
};

enum rproc_dump_mechanism {
	RPROC_COREDUMP_DISABLED = 0,
	RPROC_COREDUMP_ENABLED = 1,
	RPROC_COREDUMP_INLINE = 2,
};

struct rproc_ops;

struct rproc {
	struct list_head node;
	struct iommu_domain___13 *domain;
	const char *name;
	const char *firmware;
	void *priv;
	struct rproc_ops *ops;
	struct device___218 dev;
	atomic_t power;
	unsigned int state;
	enum rproc_dump_mechanism dump_conf;
	struct mutex lock;
	struct dentry___237 *dbg_dir;
	struct list_head traces;
	int num_traces;
	struct list_head carveouts;
	struct list_head mappings;
	u64 bootaddr;
	struct list_head rvdevs;
	struct list_head subdevs;
	struct idr notifyids;
	int index;
	struct work_struct crash_handler;
	unsigned int crash_cnt;
	bool recovery_disabled;
	int max_notifyid;
	struct resource_table *table_ptr;
	struct resource_table *clean_table;
	struct resource_table *cached_table;
	size_t table_sz;
	bool has_iommu;
	bool auto_boot;
	struct list_head dump_segments;
	int nb_vdev;
	u8 elf_class;
	u16 elf_machine;
	struct cdev___65 cdev;
	bool cdev_put_on_release;
};

enum rsc_handling_status {
	RSC_HANDLED = 0,
	RSC_IGNORED = 1,
};

struct rproc_ops {
	int (*prepare)(struct rproc *);
	int (*unprepare)(struct rproc *);
	int (*start)(struct rproc *);
	int (*stop)(struct rproc *);
	int (*attach)(struct rproc *);
	int (*detach)(struct rproc *);
	void (*kick)(struct rproc *, int);
	void * (*da_to_va)(struct rproc *, u64, size_t, bool *);
	int (*parse_fw)(struct rproc *, const struct firmware *);
	int (*handle_rsc)(struct rproc *, u32, void *, int, int);
	struct resource_table * (*find_loaded_rsc_table)(struct rproc *, const struct firmware *);
	struct resource_table * (*get_loaded_rsc_table)(struct rproc *, size_t *);
	int (*load)(struct rproc *, const struct firmware *);
	int (*sanity_check)(struct rproc *, const struct firmware *);
	u64 (*get_boot_addr)(struct rproc *, const struct firmware *);
	long unsigned int (*panic)(struct rproc *);
	void (*coredump)(struct rproc *);
};

enum rproc_state {
	RPROC_OFFLINE = 0,
	RPROC_SUSPENDED = 1,
	RPROC_RUNNING = 2,
	RPROC_CRASHED = 3,
	RPROC_DELETED = 4,
	RPROC_ATTACHED = 5,
	RPROC_DETACHED = 6,
	RPROC_LAST = 7,
};

enum rproc_crash_type {
	RPROC_MMUFAULT = 0,
	RPROC_WATCHDOG = 1,
	RPROC_FATAL_ERROR = 2,
};

typedef int (*iommu_fault_handler_t___13)(struct iommu_domain___13 *, struct device___218 *, long unsigned int, int, void *);

struct iommu_domain___13 {
	unsigned int type;
	const struct iommu_ops___13 *ops;
	long unsigned int pgsize_bitmap;
	iommu_fault_handler_t___13 handler;
	void *handler_token;
	struct iommu_domain_geometry geometry;
	struct iommu_dma_cookie *iova_cookie;
};

struct rproc_subdev {
	struct list_head node;
	int (*prepare)(struct rproc_subdev *);
	int (*start)(struct rproc_subdev *);
	void (*stop)(struct rproc_subdev *, bool);
	void (*unprepare)(struct rproc_subdev *);
};

struct rproc_vdev;

struct rproc_vring {
	void *va;
	int len;
	u32 da;
	u32 align;
	int notifyid;
	struct rproc_vdev *rvdev;
	struct virtqueue___7 *vq;
};

struct rproc_vdev {
	struct kref refcount;
	struct rproc_subdev subdev;
	struct device___218 dev;
	unsigned int id;
	struct list_head node;
	struct rproc *rproc;
	struct rproc_vring vring[2];
	u32 rsc_offset;
	u32 index;
};

struct iommu_device___13 {
	struct list_head list;
	const struct iommu_ops___13 *ops;
	struct fwnode_handle___214 *fwnode;
	struct device___218 *dev;
};

struct iommu_sva___13 {
	struct device___218 *dev;
};

struct iommu_fwspec___13 {
	const struct iommu_ops___13 *ops;
	struct fwnode_handle___214 *iommu_fwnode;
	u32 flags;
	unsigned int num_ids;
	u32 ids[0];
};

struct rproc_debug_trace {
	struct rproc *rproc;
	struct dentry___237 *tfile;
	struct list_head node;
	struct rproc_mem_entry trace_mem;
};

typedef int (*rproc_handle_resource_t)(struct rproc *, void *, int, int);

struct rproc_ops___2;

struct rproc___2 {
	struct list_head node;
	struct iommu_domain___13 *domain;
	const char *name;
	const char *firmware;
	void *priv;
	struct rproc_ops___2 *ops;
	struct device___215 dev;
	atomic_t power;
	unsigned int state;
	enum rproc_dump_mechanism dump_conf;
	struct mutex lock;
	struct dentry___236 *dbg_dir;
	struct list_head traces;
	int num_traces;
	struct list_head carveouts;
	struct list_head mappings;
	u64 bootaddr;
	struct list_head rvdevs;
	struct list_head subdevs;
	struct idr notifyids;
	int index;
	struct work_struct crash_handler;
	unsigned int crash_cnt;
	bool recovery_disabled;
	int max_notifyid;
	struct resource_table *table_ptr;
	struct resource_table *clean_table;
	struct resource_table *cached_table;
	size_t table_sz;
	bool has_iommu;
	bool auto_boot;
	struct list_head dump_segments;
	int nb_vdev;
	u8 elf_class;
	u16 elf_machine;
	struct cdev___64 cdev;
	bool cdev_put_on_release;
};

struct rproc_ops___2 {
	int (*prepare)(struct rproc___2 *);
	int (*unprepare)(struct rproc___2 *);
	int (*start)(struct rproc___2 *);
	int (*stop)(struct rproc___2 *);
	int (*attach)(struct rproc___2 *);
	int (*detach)(struct rproc___2 *);
	void (*kick)(struct rproc___2 *, int);
	void * (*da_to_va)(struct rproc___2 *, u64, size_t, bool *);
	int (*parse_fw)(struct rproc___2 *, const struct firmware *);
	int (*handle_rsc)(struct rproc___2 *, u32, void *, int, int);
	struct resource_table * (*find_loaded_rsc_table)(struct rproc___2 *, const struct firmware *);
	struct resource_table * (*get_loaded_rsc_table)(struct rproc___2 *, size_t *);
	int (*load)(struct rproc___2 *, const struct firmware *);
	int (*sanity_check)(struct rproc___2 *, const struct firmware *);
	u64 (*get_boot_addr)(struct rproc___2 *, const struct firmware *);
	long unsigned int (*panic)(struct rproc___2 *);
	void (*coredump)(struct rproc___2 *);
};

struct rproc_dump_segment {
	struct list_head node;
	dma_addr_t da;
	size_t size;
	void *priv;
	void (*dump)(struct rproc___2 *, struct rproc_dump_segment *, void *, size_t, size_t);
	loff_t offset;
};

struct rproc_coredump_state {
	struct rproc___2 *rproc;
	void *header;
	struct completion dump_done;
};

struct rproc_mem_entry___2 {
	void *va;
	bool is_iomem;
	dma_addr_t dma;
	size_t len;
	u32 da;
	void *priv;
	char name[32];
	struct list_head node;
	u32 rsc_offset;
	u32 flags;
	u32 of_resm_idx;
	int (*alloc)(struct rproc___2 *, struct rproc_mem_entry___2 *);
	int (*release)(struct rproc___2 *, struct rproc_mem_entry___2 *);
};

struct rproc_debug_trace___2 {
	struct rproc___2 *rproc;
	struct dentry___236 *tfile;
	struct list_head node;
	struct rproc_mem_entry___2 trace_mem;
};

typedef void (*dr_release_t___40)(struct device___83 *, void *);

typedef int (*dr_match_t___30)(struct device___83 *, void *, void *);

struct devfreq_dev_profile___2 {
	long unsigned int initial_freq;
	unsigned int polling_ms;
	enum devfreq_timer timer;
	bool is_cooling_device;
	int (*target)(struct device___83 *, long unsigned int *, u32);
	int (*get_dev_status)(struct device___83 *, struct devfreq_dev_status *);
	int (*get_cur_freq)(struct device___83 *, long unsigned int *);
	void (*exit)(struct device___83 *);
	long unsigned int *freq_table;
	unsigned int max_state;
};

struct devfreq_governor___2;

struct devfreq___2 {
	struct list_head node;
	struct mutex lock;
	struct device___83 dev;
	struct devfreq_dev_profile___2 *profile;
	const struct devfreq_governor___2 *governor;
	struct opp_table *opp_table;
	struct notifier_block nb;
	struct delayed_work work;
	long unsigned int previous_freq;
	struct devfreq_dev_status last_status;
	void *data;
	struct dev_pm_qos_request user_min_freq_req;
	struct dev_pm_qos_request user_max_freq_req;
	long unsigned int scaling_min_freq;
	long unsigned int scaling_max_freq;
	bool stop_polling;
	long unsigned int suspend_freq;
	long unsigned int resume_freq;
	atomic_t suspend_count;
	struct devfreq_stats stats;
	struct srcu_notifier_head transition_notifier_list;
	struct thermal_cooling_device___6 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct devfreq_governor___2 {
	struct list_head node;
	const char name[16];
	const u64 attrs;
	const u64 flags;
	int (*get_target_freq)(struct devfreq___2 *, long unsigned int *);
	int (*event_handler)(struct devfreq___2 *, unsigned int, void *);
};

struct devfreq_freqs {
	long unsigned int old;
	long unsigned int new;
};

struct devfreq_passive_data {
	struct devfreq___2 *parent;
	int (*get_target_freq)(struct devfreq___2 *, long unsigned int *);
	struct devfreq___2 *this;
	struct notifier_block nb;
};

struct devfreq_cooling_power___2 {
	int (*get_real_power)(struct devfreq___2 *, u32 *, long unsigned int, long unsigned int);
};

struct trace_event_raw_devfreq_frequency {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	long unsigned int freq;
	long unsigned int prev_freq;
	long unsigned int busy_time;
	long unsigned int total_time;
	char __data[0];
};

struct trace_event_raw_devfreq_monitor {
	struct trace_entry ent;
	long unsigned int freq;
	long unsigned int busy_time;
	long unsigned int total_time;
	unsigned int polling_ms;
	u32 __data_loc_dev_name;
	char __data[0];
};

struct trace_event_data_offsets_devfreq_frequency {
	u32 dev_name;
};

struct trace_event_data_offsets_devfreq_monitor {
	u32 dev_name;
};

typedef void (*btf_trace_devfreq_frequency)(void *, struct devfreq___2 *, long unsigned int, long unsigned int);

typedef void (*btf_trace_devfreq_monitor)(void *, struct devfreq___2 *);

struct devfreq_notifier_devres {
	struct devfreq___2 *devfreq;
	struct notifier_block *nb;
	unsigned int list;
};

typedef void (*dr_release_t___41)(struct device___209 *, void *);

typedef int (*dr_match_t___31)(struct device___209 *, void *, void *);

struct devfreq_event_desc;

struct devfreq_event_dev {
	struct list_head node;
	struct device___209 dev;
	struct mutex lock;
	u32 enable_count;
	const struct devfreq_event_desc *desc;
};

struct devfreq_event_ops;

struct devfreq_event_desc {
	const char *name;
	u32 event_type;
	void *driver_data;
	const struct devfreq_event_ops *ops;
};

struct devfreq_event_data {
	long unsigned int load_count;
	long unsigned int total_count;
};

struct devfreq_event_ops {
	int (*enable)(struct devfreq_event_dev *);
	int (*disable)(struct devfreq_event_dev *);
	int (*reset)(struct devfreq_event_dev *);
	int (*set_event)(struct devfreq_event_dev *);
	int (*get_event)(struct devfreq_event_dev *, struct devfreq_event_data *);
};

struct devfreq_simple_ondemand_data {
	unsigned int upthreshold;
	unsigned int downdifferential;
};

struct userspace_data {
	long unsigned int user_frequency;
	bool valid;
};

union extcon_property_value {
	int intval;
};

struct extcon_cable;

struct extcon_dev___2 {
	const char *name;
	const unsigned int *supported_cable;
	const u32 *mutually_exclusive;
	struct device___218 dev;
	struct raw_notifier_head nh_all;
	struct raw_notifier_head *nh;
	struct list_head entry;
	int max_supported;
	spinlock_t lock;
	u32 state;
	struct device_type___218 extcon_dev_type;
	struct extcon_cable *cables;
	struct attribute_group___225 attr_g_muex;
	struct attribute **attrs_muex;
	struct device_attribute___45 *d_attrs_muex;
};

struct extcon_cable {
	struct extcon_dev___2 *edev;
	int cable_index;
	struct attribute_group___225 attr_g;
	struct device_attribute___45 attr_name;
	struct device_attribute___45 attr_state;
	struct attribute *attrs[3];
	union extcon_property_value usb_propval[3];
	union extcon_property_value chg_propval[1];
	union extcon_property_value jack_propval[1];
	union extcon_property_value disp_propval[2];
	long unsigned int usb_bits[1];
	long unsigned int chg_bits[1];
	long unsigned int jack_bits[1];
	long unsigned int disp_bits[1];
};

struct __extcon_info {
	unsigned int type;
	unsigned int id;
	const char *name;
};

struct extcon_cable___2;

struct extcon_dev___3 {
	const char *name;
	const unsigned int *supported_cable;
	const u32 *mutually_exclusive;
	struct device___209 dev;
	struct raw_notifier_head nh_all;
	struct raw_notifier_head *nh;
	struct list_head entry;
	int max_supported;
	spinlock_t lock;
	u32 state;
	struct device_type___209 extcon_dev_type;
	struct extcon_cable___2 *cables;
	struct attribute_group___41 attr_g_muex;
	struct attribute **attrs_muex;
	struct device_attribute___44 *d_attrs_muex;
};

struct extcon_dev_notifier_devres {
	struct extcon_dev___3 *edev;
	unsigned int id;
	struct notifier_block *nb;
};

enum dpfe_msg_fields {
	MSG_HEADER = 0,
	MSG_COMMAND = 1,
	MSG_ARG_COUNT = 2,
	MSG_ARG0 = 3,
	MSG_FIELD_MAX = 16,
};

enum dpfe_commands {
	DPFE_CMD_GET_INFO = 0,
	DPFE_CMD_GET_REFRESH = 1,
	DPFE_CMD_GET_VENDOR = 2,
	DPFE_CMD_MAX = 3,
};

struct dpfe_firmware_header {
	u32 magic;
	u32 sequence;
	u32 version;
	u32 imem_size;
	u32 dmem_size;
};

struct init_data {
	unsigned int dmem_len;
	unsigned int imem_len;
	unsigned int chksum;
	bool is_big_endian;
};

struct dpfe_api {
	int version;
	const char *fw_name;
	const struct attribute_group___224 **sysfs_attrs;
	u32 command[48];
};

struct brcmstb_dpfe_priv {
	void *regs;
	void *dmem;
	void *imem;
	struct device___215 *dev;
	const struct dpfe_api *dpfe_api;
	struct mutex lock;
};

struct fsl_ifc_nand {
	__be32 ncfgr;
	u32 res1[4];
	__be32 nand_fcr0;
	__be32 nand_fcr1;
	u32 res2[8];
	__be32 row0;
	u32 res3;
	__be32 col0;
	u32 res4;
	__be32 row1;
	u32 res5;
	__be32 col1;
	u32 res6;
	__be32 row2;
	u32 res7;
	__be32 col2;
	u32 res8;
	__be32 row3;
	u32 res9;
	__be32 col3;
	u32 res10[36];
	__be32 nand_fbcr;
	u32 res11;
	__be32 nand_fir0;
	__be32 nand_fir1;
	__be32 nand_fir2;
	u32 res12[16];
	__be32 nand_csel;
	u32 res13;
	__be32 nandseq_strt;
	u32 res14;
	__be32 nand_evter_stat;
	u32 res15;
	__be32 pgrdcmpl_evt_stat;
	u32 res16[2];
	__be32 nand_evter_en;
	u32 res17[2];
	__be32 nand_evter_intr_en;
	__be32 nand_vol_addr_stat;
	u32 res18;
	__be32 nand_erattr0;
	__be32 nand_erattr1;
	u32 res19[16];
	__be32 nand_fsr;
	u32 res20;
	__be32 nand_eccstat[8];
	u32 res21[28];
	__be32 nanndcr;
	u32 res22[2];
	__be32 nand_autoboot_trgr;
	u32 res23;
	__be32 nand_mdr;
	u32 res24[28];
	__be32 nand_dll_lowcfg0;
	__be32 nand_dll_lowcfg1;
	u32 res25;
	__be32 nand_dll_lowstat;
	u32 res26[60];
};

struct fsl_ifc_nor {
	__be32 nor_evter_stat;
	u32 res1[2];
	__be32 nor_evter_en;
	u32 res2[2];
	__be32 nor_evter_intr_en;
	u32 res3[2];
	__be32 nor_erattr0;
	__be32 nor_erattr1;
	__be32 nor_erattr2;
	u32 res4[4];
	__be32 norcr;
	u32 res5[239];
};

struct fsl_ifc_gpcm {
	__be32 gpcm_evter_stat;
	u32 res1[2];
	__be32 gpcm_evter_en;
	u32 res2[2];
	__be32 gpcm_evter_intr_en;
	u32 res3[2];
	__be32 gpcm_erattr0;
	__be32 gpcm_erattr1;
	__be32 gpcm_erattr2;
	__be32 gpcm_stat;
};

struct fsl_ifc_global {
	__be32 ifc_rev;
	u32 res1[2];
	struct {
		__be32 cspr_ext;
		__be32 cspr;
		u32 res2;
	} cspr_cs[8];
	u32 res3[13];
	struct {
		__be32 amask;
		u32 res4[2];
	} amask_cs[8];
	u32 res5[12];
	struct {
		__be32 csor;
		__be32 csor_ext;
		u32 res6;
	} csor_cs[8];
	u32 res7[12];
	struct {
		__be32 ftim[4];
		u32 res8[8];
	} ftim_cs[8];
	u32 res9[48];
	__be32 rb_stat;
	__be32 rb_map;
	__be32 wb_map;
	__be32 ifc_gcr;
	u32 res10[2];
	__be32 cm_evter_stat;
	u32 res11[2];
	__be32 cm_evter_en;
	u32 res12[2];
	__be32 cm_evter_intr_en;
	u32 res13[2];
	__be32 cm_erattr0;
	__be32 cm_erattr1;
	u32 res14[2];
	__be32 ifc_ccr;
	__be32 ifc_csr;
	__be32 ddr_ccr_low;
};

struct fsl_ifc_runtime {
	struct fsl_ifc_nand ifc_nand;
	struct fsl_ifc_nor ifc_nor;
	struct fsl_ifc_gpcm ifc_gpcm;
};

struct fsl_ifc_ctrl {
	struct device___214 *dev;
	struct fsl_ifc_global *gregs;
	struct fsl_ifc_runtime *rregs;
	int irq;
	int nand_irq;
	spinlock_t lock;
	void *nand;
	int version;
	int banks;
	u32 nand_stat;
	wait_queue_head_t nand_wait;
	bool little_endian;
};

struct icc_node___3;

struct icc_node_data___3 {
	struct icc_node___3 *node;
	u32 tag;
};

struct icc_provider___3;

struct icc_node___3 {
	int id;
	const char *name;
	struct icc_node___3 **links;
	size_t num_links;
	struct icc_provider___3 *provider;
	struct list_head node_list;
	struct list_head search_list;
	struct icc_node___3 *reverse;
	u8 is_traversed;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head req_list;
	u32 avg_bw;
	u32 peak_bw;
	u32 init_avg;
	u32 init_peak;
	void *data;
};

struct icc_provider___3 {
	struct list_head provider_list;
	struct list_head nodes;
	int (*set)(struct icc_node___3 *, struct icc_node___3 *);
	int (*aggregate)(struct icc_node___3 *, u32, u32, u32, u32 *, u32 *);
	void (*pre_aggregate)(struct icc_node___3 *);
	int (*get_bw)(struct icc_node___3 *, u32 *, u32 *);
	struct icc_node___3 * (*xlate)(struct of_phandle_args___40 *, void *);
	struct icc_node_data___3 * (*xlate_extended)(struct of_phandle_args___40 *, void *);
	struct device___215 *dev;
	int users;
	bool inter_set;
	void *data;
};

struct reset_controller_dev___12;

struct reset_control_ops___12 {
	int (*reset)(struct reset_controller_dev___12 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___12 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___12 *, long unsigned int);
	int (*status)(struct reset_controller_dev___12 *, long unsigned int);
};

struct reset_controller_dev___12 {
	const struct reset_control_ops___12 *ops;
	struct module___220 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___215 *dev;
	struct device_node___96 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___12 *, const struct of_phandle_args___40 *);
	unsigned int nr_resets;
};

struct tegra_mc___3;

struct tegra_mc_reset_ops___3 {
	int (*hotreset_assert)(struct tegra_mc___3 *, const struct tegra_mc_reset *);
	int (*hotreset_deassert)(struct tegra_mc___3 *, const struct tegra_mc_reset *);
	int (*block_dma)(struct tegra_mc___3 *, const struct tegra_mc_reset *);
	bool (*dma_idling)(struct tegra_mc___3 *, const struct tegra_mc_reset *);
	int (*unblock_dma)(struct tegra_mc___3 *, const struct tegra_mc_reset *);
	int (*reset_status)(struct tegra_mc___3 *, const struct tegra_mc_reset *);
};

struct tegra_mc_soc___3;

struct tegra_mc___3 {
	struct device___215 *dev;
	struct tegra_smmu *smmu;
	struct gart_device *gart;
	void *regs;
	struct clk *clk;
	int irq;
	const struct tegra_mc_soc___3 *soc;
	long unsigned int tick;
	struct tegra_mc_timing *timings;
	unsigned int num_timings;
	struct reset_controller_dev___12 reset;
	struct icc_provider___3 provider;
	spinlock_t lock;
	struct {
		struct dentry___236 *root;
	} debugfs;
};

struct tegra_mc_icc_ops___3 {
	int (*set)(struct icc_node___3 *, struct icc_node___3 *);
	int (*aggregate)(struct icc_node___3 *, u32, u32, u32, u32 *, u32 *);
	struct icc_node_data___3 * (*xlate_extended)(struct of_phandle_args___40 *, void *);
};

struct tegra_mc_ops___3 {
	int (*probe)(struct tegra_mc___3 *);
	void (*remove)(struct tegra_mc___3 *);
	int (*suspend)(struct tegra_mc___3 *);
	int (*resume)(struct tegra_mc___3 *);
	irqreturn_t (*handle_irq)(int, void *);
	int (*probe_device)(struct tegra_mc___3 *, struct device___215 *);
};

struct tegra_mc_soc___3 {
	const struct tegra_mc_client *clients;
	unsigned int num_clients;
	const long unsigned int *emem_regs;
	unsigned int num_emem_regs;
	unsigned int num_address_bits;
	unsigned int atom_size;
	u8 client_id_mask;
	const struct tegra_smmu_soc *smmu;
	u32 intmask;
	const struct tegra_mc_reset_ops___3 *reset_ops;
	const struct tegra_mc_reset *resets;
	unsigned int num_resets;
	const struct tegra_mc_icc_ops___3 *icc_ops;
	const struct tegra_mc_ops___3 *ops;
};

struct tegra_mc___4;

struct tegra_mc_reset_ops___4 {
	int (*hotreset_assert)(struct tegra_mc___4 *, const struct tegra_mc_reset *);
	int (*hotreset_deassert)(struct tegra_mc___4 *, const struct tegra_mc_reset *);
	int (*block_dma)(struct tegra_mc___4 *, const struct tegra_mc_reset *);
	bool (*dma_idling)(struct tegra_mc___4 *, const struct tegra_mc_reset *);
	int (*unblock_dma)(struct tegra_mc___4 *, const struct tegra_mc_reset *);
	int (*reset_status)(struct tegra_mc___4 *, const struct tegra_mc_reset *);
};

struct tegra_mc_soc___4;

struct tegra_mc___4 {
	struct device___9 *dev;
	struct tegra_smmu *smmu;
	struct gart_device *gart;
	void *regs;
	struct clk *clk;
	int irq;
	const struct tegra_mc_soc___4 *soc;
	long unsigned int tick;
	struct tegra_mc_timing *timings;
	unsigned int num_timings;
	struct reset_controller_dev___12 reset;
	struct icc_provider___3 provider;
	spinlock_t lock;
	struct {
		struct dentry___100 *root;
	} debugfs;
};

struct tegra_mc_ops___4 {
	int (*probe)(struct tegra_mc___4 *);
	void (*remove)(struct tegra_mc___4 *);
	int (*suspend)(struct tegra_mc___4 *);
	int (*resume)(struct tegra_mc___4 *);
	irqreturn_t (*handle_irq)(int, void *);
	int (*probe_device)(struct tegra_mc___4 *, struct device___9 *);
};

struct tegra_mc_soc___4 {
	const struct tegra_mc_client *clients;
	unsigned int num_clients;
	const long unsigned int *emem_regs;
	unsigned int num_emem_regs;
	unsigned int num_address_bits;
	unsigned int atom_size;
	u8 client_id_mask;
	const struct tegra_smmu_soc *smmu;
	u32 intmask;
	const struct tegra_mc_reset_ops___4 *reset_ops;
	const struct tegra_mc_reset *resets;
	unsigned int num_resets;
	const struct tegra_mc_icc_ops___3 *icc_ops;
	const struct tegra_mc_ops___4 *ops;
};

struct icc_node___4;

struct icc_node_data___4 {
	struct icc_node___4 *node;
	u32 tag;
};

struct icc_provider___4;

struct icc_node___4 {
	int id;
	const char *name;
	struct icc_node___4 **links;
	size_t num_links;
	struct icc_provider___4 *provider;
	struct list_head node_list;
	struct list_head search_list;
	struct icc_node___4 *reverse;
	u8 is_traversed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head req_list;
	u32 avg_bw;
	u32 peak_bw;
	u32 init_avg;
	u32 init_peak;
	void *data;
};

struct icc_provider___4 {
	struct list_head provider_list;
	struct list_head nodes;
	int (*set)(struct icc_node___4 *, struct icc_node___4 *);
	int (*aggregate)(struct icc_node___4 *, u32, u32, u32, u32 *, u32 *);
	void (*pre_aggregate)(struct icc_node___4 *);
	int (*get_bw)(struct icc_node___4 *, u32 *, u32 *);
	struct icc_node___4 * (*xlate)(struct of_phandle_args___43 *, void *);
	struct icc_node_data___4 * (*xlate_extended)(struct of_phandle_args___43 *, void *);
	struct device___218 *dev;
	int users;
	bool inter_set;
	void *data;
};

struct reset_controller_dev___13;

struct reset_control_ops___13 {
	int (*reset)(struct reset_controller_dev___13 *, long unsigned int);
	int (*assert)(struct reset_controller_dev___13 *, long unsigned int);
	int (*deassert)(struct reset_controller_dev___13 *, long unsigned int);
	int (*status)(struct reset_controller_dev___13 *, long unsigned int);
};

struct reset_controller_dev___13 {
	const struct reset_control_ops___13 *ops;
	struct module___221 *owner;
	struct list_head list;
	struct list_head reset_control_head;
	struct device___218 *dev;
	struct device_node___99 *of_node;
	int of_reset_n_cells;
	int (*of_xlate)(struct reset_controller_dev___13 *, const struct of_phandle_args___43 *);
	unsigned int nr_resets;
};

struct tegra_mc___5;

struct tegra_mc_reset_ops___5 {
	int (*hotreset_assert)(struct tegra_mc___5 *, const struct tegra_mc_reset *);
	int (*hotreset_deassert)(struct tegra_mc___5 *, const struct tegra_mc_reset *);
	int (*block_dma)(struct tegra_mc___5 *, const struct tegra_mc_reset *);
	bool (*dma_idling)(struct tegra_mc___5 *, const struct tegra_mc_reset *);
	int (*unblock_dma)(struct tegra_mc___5 *, const struct tegra_mc_reset *);
	int (*reset_status)(struct tegra_mc___5 *, const struct tegra_mc_reset *);
};

struct tegra_mc_soc___5;

struct tegra_mc___5 {
	struct device___218 *dev;
	struct tegra_smmu *smmu;
	struct gart_device *gart;
	void *regs;
	struct clk *clk;
	int irq;
	const struct tegra_mc_soc___5 *soc;
	long unsigned int tick;
	struct tegra_mc_timing *timings;
	unsigned int num_timings;
	struct reset_controller_dev___13 reset;
	struct icc_provider___4 provider;
	spinlock_t lock;
	struct {
		struct dentry___237 *root;
	} debugfs;
};

struct tegra_mc_icc_ops___4 {
	int (*set)(struct icc_node___4 *, struct icc_node___4 *);
	int (*aggregate)(struct icc_node___4 *, u32, u32, u32, u32 *, u32 *);
	struct icc_node_data___4 * (*xlate_extended)(struct of_phandle_args___43 *, void *);
};

struct tegra_mc_ops___5 {
	int (*probe)(struct tegra_mc___5 *);
	void (*remove)(struct tegra_mc___5 *);
	int (*suspend)(struct tegra_mc___5 *);
	int (*resume)(struct tegra_mc___5 *);
	irqreturn_t (*handle_irq)(int, void *);
	int (*probe_device)(struct tegra_mc___5 *, struct device___218 *);
};

struct tegra_mc_soc___5 {
	const struct tegra_mc_client *clients;
	unsigned int num_clients;
	const long unsigned int *emem_regs;
	unsigned int num_emem_regs;
	unsigned int num_address_bits;
	unsigned int atom_size;
	u8 client_id_mask;
	const struct tegra_smmu_soc *smmu;
	u32 intmask;
	const struct tegra_mc_reset_ops___5 *reset_ops;
	const struct tegra_mc_reset *resets;
	unsigned int num_resets;
	const struct tegra_mc_icc_ops___4 *icc_ops;
	const struct tegra_mc_ops___5 *ops;
};

struct reserved_mem_ops___5;

struct reserved_mem___5 {
	const char *name;
	long unsigned int fdt_node;
	long unsigned int phandle;
	const struct reserved_mem_ops___5 *ops;
	phys_addr_t base;
	phys_addr_t size;
	void *priv;
};

struct reserved_mem_ops___5 {
	int (*device_init)(struct reserved_mem___5 *, struct device___217 *);
	void (*device_release)(struct reserved_mem___5 *, struct device___217 *);
};

typedef int (*reservedmem_of_init_fn___5)(struct reserved_mem___5 *);

struct tegra210_clk_emc_provider___2 {
	struct module___8 *owner;
	struct device___217 *dev;
	struct tegra210_clk_emc_config *configs;
	unsigned int num_configs;
	int (*set_rate)(struct device___217 *, const struct tegra210_clk_emc_config *);
};

enum {
	C0D0U0 = 0,
	C0D0U1 = 1,
	C0D1U0 = 2,
	C0D1U1 = 3,
	C1D0U0 = 4,
	C1D0U1 = 5,
	C1D1U0 = 6,
	C1D1U1 = 7,
	DRAM_CLKTREE_NUM = 8,
};

struct tegra210_emc_per_channel_regs {
	u16 bank;
	u16 offset;
};

struct tegra210_emc_table_register_offsets {
	u16 burst[221];
	u16 trim[138];
	u16 burst_mc[33];
	u16 la_scale[24];
	struct tegra210_emc_per_channel_regs burst_per_channel[8];
	struct tegra210_emc_per_channel_regs trim_per_channel[10];
	struct tegra210_emc_per_channel_regs vref_per_channel[4];
};

struct tegra210_emc_timing {
	u32 revision;
	const char dvfs_ver[60];
	u32 rate;
	u32 min_volt;
	u32 gpu_min_volt;
	const char clock_src[32];
	u32 clk_src_emc;
	u32 needs_training;
	u32 training_pattern;
	u32 trained;
	u32 periodic_training;
	u32 trained_dram_clktree[8];
	u32 current_dram_clktree[8];
	u32 run_clocks;
	u32 tree_margin;
	u32 num_burst;
	u32 num_burst_per_ch;
	u32 num_trim;
	u32 num_trim_per_ch;
	u32 num_mc_regs;
	u32 num_up_down;
	u32 vref_num;
	u32 training_mod_num;
	u32 dram_timing_num;
	u32 ptfv_list[12];
	u32 burst_regs[221];
	u32 burst_reg_per_ch[8];
	u32 shadow_regs_ca_train[221];
	u32 shadow_regs_quse_train[221];
	u32 shadow_regs_rdwr_train[221];
	u32 trim_regs[138];
	u32 trim_perch_regs[10];
	u32 vref_perch_regs[4];
	u32 dram_timings[5];
	u32 training_mod_regs[20];
	u32 save_restore_mod_regs[12];
	u32 burst_mc_regs[33];
	u32 la_scale_regs[24];
	u32 min_mrs_wait;
	u32 emc_mrw;
	u32 emc_mrw2;
	u32 emc_mrw3;
	u32 emc_mrw4;
	u32 emc_mrw9;
	u32 emc_mrs;
	u32 emc_emrs;
	u32 emc_emrs2;
	u32 emc_auto_cal_config;
	u32 emc_auto_cal_config2;
	u32 emc_auto_cal_config3;
	u32 emc_auto_cal_config4;
	u32 emc_auto_cal_config5;
	u32 emc_auto_cal_config6;
	u32 emc_auto_cal_config7;
	u32 emc_auto_cal_config8;
	u32 emc_cfg_2;
	u32 emc_sel_dpd_ctrl;
	u32 emc_fdpd_ctrl_cmd_no_ramp;
	u32 dll_clk_src;
	u32 clk_out_enb_x_0_clk_enb_emc_dll;
	u32 latency;
};

enum tegra210_emc_refresh {
	TEGRA210_EMC_REFRESH_NOMINAL = 0,
	TEGRA210_EMC_REFRESH_2X = 1,
	TEGRA210_EMC_REFRESH_4X = 2,
	TEGRA210_EMC_REFRESH_THROTTLE = 3,
};

struct tegra_mc___6;

struct tegra210_emc_sequence;

struct tegra210_emc {
	struct tegra_mc___6 *mc;
	struct device___217 *dev;
	struct clk *clk;
	struct tegra210_emc_timing *nominal;
	struct tegra210_emc_timing *derated;
	struct tegra210_emc_timing *timings;
	unsigned int num_timings;
	const struct tegra210_emc_table_register_offsets *offsets;
	const struct tegra210_emc_sequence *sequence;
	spinlock_t lock;
	void *regs;
	void *channel[2];
	unsigned int num_channels;
	unsigned int num_devices;
	unsigned int dram_type;
	struct tegra210_emc_timing *last;
	struct tegra210_emc_timing *next;
	unsigned int training_interval;
	struct timer_list training;
	enum tegra210_emc_refresh refresh;
	unsigned int refresh_poll_interval;
	struct timer_list refresh_timer;
	unsigned int temperature;
	atomic_t refresh_poll;
	ktime_t clkchange_time;
	int clkchange_delay;
	long unsigned int resume_rate;
	struct {
		struct dentry___182 *root;
		long unsigned int min_rate;
		long unsigned int max_rate;
		unsigned int temperature;
	} debugfs;
	struct tegra210_clk_emc_provider___2 provider;
};

struct tegra210_emc_sequence {
	u8 revision;
	void (*set_clock)(struct tegra210_emc *, u32);
	u32 (*periodic_compensation)(struct tegra210_emc *);
};

typedef struct generic_pm_domain___2 * (*genpd_xlate_t___10)(struct of_phandle_args___43 *, void *);

struct emc_dvfs_latency {
	uint32_t freq;
	uint32_t latency;
};

struct mrq_emc_dvfs_latency_response {
	uint32_t num_pairs;
	struct emc_dvfs_latency pairs[14];
};

struct tegra186_emc_dvfs {
	long unsigned int latency;
	long unsigned int rate;
};

struct tegra186_emc {
	struct tegra_bpmp *bpmp;
	struct device___218 *dev;
	struct clk *clk;
	struct tegra186_emc_dvfs *dvfs;
	unsigned int num_dvfs;
	struct {
		struct dentry___237 *root;
		long unsigned int min_rate;
		long unsigned int max_rate;
	} debugfs;
};

enum vme_resource_type {
	VME_MASTER = 0,
	VME_SLAVE = 1,
	VME_DMA = 2,
	VME_LM = 3,
};

struct vme_dma_attr {
	u32 type;
	void *private;
};

struct vme_resource {
	enum vme_resource_type type;
	struct list_head *entry;
};

struct vme_bridge;

struct vme_dev {
	int num;
	struct vme_bridge *bridge;
	struct device___83 dev;
	struct list_head drv_list;
	struct list_head bridge_list;
};

struct vme_callback {
	void (*func)(int, int, void *);
	void *priv_data;
};

struct vme_irq {
	int count;
	struct vme_callback callback[256];
};

struct vme_slave_resource;

struct vme_master_resource;

struct vme_dma_list;

struct vme_lm_resource;

struct vme_bridge {
	char name[16];
	int num;
	struct list_head master_resources;
	struct list_head slave_resources;
	struct list_head dma_resources;
	struct list_head lm_resources;
	struct list_head vme_error_handlers;
	struct list_head devices;
	struct device___83 *parent;
	void *driver_priv;
	struct list_head bus_list;
	struct vme_irq irq[7];
	struct mutex irq_mtx;
	int (*slave_get)(struct vme_slave_resource *, int *, long long unsigned int *, long long unsigned int *, dma_addr_t *, u32 *, u32 *);
	int (*slave_set)(struct vme_slave_resource *, int, long long unsigned int, long long unsigned int, dma_addr_t, u32, u32);
	int (*master_get)(struct vme_master_resource *, int *, long long unsigned int *, long long unsigned int *, u32 *, u32 *, u32 *);
	int (*master_set)(struct vme_master_resource *, int, long long unsigned int, long long unsigned int, u32, u32, u32);
	ssize_t (*master_read)(struct vme_master_resource *, void *, size_t, loff_t);
	ssize_t (*master_write)(struct vme_master_resource *, void *, size_t, loff_t);
	unsigned int (*master_rmw)(struct vme_master_resource *, unsigned int, unsigned int, unsigned int, loff_t);
	int (*dma_list_add)(struct vme_dma_list *, struct vme_dma_attr *, struct vme_dma_attr *, size_t);
	int (*dma_list_exec)(struct vme_dma_list *);
	int (*dma_list_empty)(struct vme_dma_list *);
	void (*irq_set)(struct vme_bridge *, int, int, int);
	int (*irq_generate)(struct vme_bridge *, int, int);
	int (*lm_set)(struct vme_lm_resource *, long long unsigned int, u32, u32);
	int (*lm_get)(struct vme_lm_resource *, long long unsigned int *, u32 *, u32 *);
	int (*lm_attach)(struct vme_lm_resource *, int, void (*)(void *), void *);
	int (*lm_detach)(struct vme_lm_resource *, int);
	int (*slot_get)(struct vme_bridge *);
	void * (*alloc_consistent)(struct device___83 *, size_t, dma_addr_t *);
	void (*free_consistent)(struct device___83 *, size_t, void *, dma_addr_t);
};

struct vme_driver {
	const char *name;
	int (*match)(struct vme_dev *);
	int (*probe)(struct vme_dev *);
	void (*remove)(struct vme_dev *);
	struct device_driver___83 driver;
	struct list_head devices;
};

struct vme_master_resource {
	struct list_head list;
	struct vme_bridge *parent;
	spinlock_t lock;
	int locked;
	int number;
	u32 address_attr;
	u32 cycle_attr;
	u32 width_attr;
	struct resource bus_resource;
	void *kern_base;
};

struct vme_slave_resource {
	struct list_head list;
	struct vme_bridge *parent;
	struct mutex mtx;
	int locked;
	int number;
	u32 address_attr;
	u32 cycle_attr;
};

struct vme_dma_pattern {
	u32 pattern;
	u32 type;
};

struct vme_dma_pci {
	dma_addr_t address;
};

struct vme_dma_vme {
	long long unsigned int address;
	u32 aspace;
	u32 cycle;
	u32 dwidth;
};

struct vme_dma_resource;

struct vme_dma_list {
	struct list_head list;
	struct vme_dma_resource *parent;
	struct list_head entries;
	struct mutex mtx;
};

struct vme_dma_resource {
	struct list_head list;
	struct vme_bridge *parent;
	struct mutex mtx;
	int locked;
	int number;
	struct list_head pending;
	struct list_head running;
	u32 route_attr;
};

struct vme_lm_resource {
	struct list_head list;
	struct vme_bridge *parent;
	struct mutex mtx;
	int locked;
	int number;
	int monitors;
};

struct vme_error_handler {
	struct list_head list;
	long long unsigned int start;
	long long unsigned int end;
	long long unsigned int first_error;
	u32 aspace;
	unsigned int num_errors;
};

struct powercap_control_type;

struct powercap_control_type_ops {
	int (*set_enable)(struct powercap_control_type *, bool);
	int (*get_enable)(struct powercap_control_type *, bool *);
	int (*release)(struct powercap_control_type *);
};

struct powercap_control_type {
	struct device___217 dev;
	struct idr idr;
	int nr_zones;
	const struct powercap_control_type_ops *ops;
	struct mutex lock;
	bool allocated;
	struct list_head node;
};

struct powercap_zone;

struct powercap_zone_ops {
	int (*get_max_energy_range_uj)(struct powercap_zone *, u64 *);
	int (*get_energy_uj)(struct powercap_zone *, u64 *);
	int (*reset_energy_uj)(struct powercap_zone *);
	int (*get_max_power_range_uw)(struct powercap_zone *, u64 *);
	int (*get_power_uw)(struct powercap_zone *, u64 *);
	int (*set_enable)(struct powercap_zone *, bool);
	int (*get_enable)(struct powercap_zone *, bool *);
	int (*release)(struct powercap_zone *);
};

struct powercap_zone_constraint;

struct powercap_zone {
	int id;
	char *name;
	void *control_type_inst;
	const struct powercap_zone_ops *ops;
	struct device___217 dev;
	int const_id_cnt;
	struct idr idr;
	struct idr *parent_idr;
	void *private_data;
	struct attribute **zone_dev_attrs;
	int zone_attr_count;
	struct attribute_group___42 dev_zone_attr_group;
	const struct attribute_group___42 *dev_attr_groups[2];
	bool allocated;
	struct powercap_zone_constraint *constraints;
};

struct powercap_zone_constraint_ops;

struct powercap_zone_constraint {
	int id;
	struct powercap_zone *power_zone;
	const struct powercap_zone_constraint_ops *ops;
};

struct powercap_zone_constraint_ops {
	int (*set_power_limit_uw)(struct powercap_zone *, int, u64);
	int (*get_power_limit_uw)(struct powercap_zone *, int, u64 *);
	int (*set_time_window_us)(struct powercap_zone *, int, u64);
	int (*get_time_window_us)(struct powercap_zone *, int, u64 *);
	int (*get_max_power_uw)(struct powercap_zone *, int, u64 *);
	int (*get_min_power_uw)(struct powercap_zone *, int, u64 *);
	int (*get_max_time_window_us)(struct powercap_zone *, int, u64 *);
	int (*get_min_time_window_us)(struct powercap_zone *, int, u64 *);
	const char * (*get_name)(struct powercap_zone *, int);
};

struct dtpm_ops;

struct dtpm {
	struct powercap_zone zone;
	struct dtpm *parent;
	struct list_head sibling;
	struct list_head children;
	struct dtpm_ops *ops;
	long unsigned int flags;
	u64 power_limit;
	u64 power_max;
	u64 power_min;
	int weight;
	void *private;
};

struct dtpm_ops {
	u64 (*set_power_uw)(struct dtpm *, u64);
	u64 (*get_power_uw)(struct dtpm *);
	void (*release)(struct dtpm *);
};

struct dtpm_descr;

typedef int (*dtpm_init_t)(struct dtpm_descr *);

struct dtpm_descr {
	struct dtpm *parent;
	const char *name;
	dtpm_init_t init;
};

struct cpufreq_governor___9;

struct cpufreq_policy___9 {
	cpumask_var_t cpus;
	cpumask_var_t related_cpus;
	cpumask_var_t real_cpus;
	unsigned int shared_type;
	unsigned int cpu;
	struct clk *clk;
	struct cpufreq_cpuinfo cpuinfo;
	unsigned int min;
	unsigned int max;
	unsigned int cur;
	unsigned int suspend_freq;
	unsigned int policy;
	unsigned int last_policy;
	struct cpufreq_governor___9 *governor;
	void *governor_data;
	char last_governor[16];
	struct work_struct update;
	struct freq_constraints constraints;
	struct freq_qos_request *min_freq_req;
	struct freq_qos_request *max_freq_req;
	struct cpufreq_frequency_table *freq_table;
	enum cpufreq_table_sorting freq_table_sorted;
	struct list_head policy_list;
	struct kobject___41 kobj;
	struct completion kobj_unregister;
	struct rw_semaphore rwsem;
	bool fast_switch_possible;
	bool fast_switch_enabled;
	bool strict_target;
	unsigned int transition_delay_us;
	bool dvfs_possible_from_any_cpu;
	unsigned int cached_target_freq;
	unsigned int cached_resolved_idx;
	bool transition_ongoing;
	spinlock_t transition_lock;
	wait_queue_head_t transition_wait;
	struct task_struct___45 *transition_task;
	struct cpufreq_stats *stats;
	void *driver_data;
	struct thermal_cooling_device___3 *cdev;
	struct notifier_block nb_min;
	struct notifier_block nb_max;
};

struct cpufreq_governor___9 {
	char name[16];
	int (*init)(struct cpufreq_policy___9 *);
	void (*exit)(struct cpufreq_policy___9 *);
	int (*start)(struct cpufreq_policy___9 *);
	void (*stop)(struct cpufreq_policy___9 *);
	void (*limits)(struct cpufreq_policy___9 *);
	ssize_t (*show_setspeed)(struct cpufreq_policy___9 *, char *);
	int (*store_setspeed)(struct cpufreq_policy___9 *, unsigned int);
	struct list_head governor_list;
	struct module___8 *owner;
	u8 flags;
};

struct powercap_zone___2;

struct powercap_zone_ops___2 {
	int (*get_max_energy_range_uj)(struct powercap_zone___2 *, u64 *);
	int (*get_energy_uj)(struct powercap_zone___2 *, u64 *);
	int (*reset_energy_uj)(struct powercap_zone___2 *);
	int (*get_max_power_range_uw)(struct powercap_zone___2 *, u64 *);
	int (*get_power_uw)(struct powercap_zone___2 *, u64 *);
	int (*set_enable)(struct powercap_zone___2 *, bool);
	int (*get_enable)(struct powercap_zone___2 *, bool *);
	int (*release)(struct powercap_zone___2 *);
};

struct powercap_zone_constraint___2;

struct powercap_zone___2 {
	int id;
	char *name;
	void *control_type_inst;
	const struct powercap_zone_ops___2 *ops;
	struct device___209 dev;
	int const_id_cnt;
	struct idr idr;
	struct idr *parent_idr;
	void *private_data;
	struct attribute **zone_dev_attrs;
	int zone_attr_count;
	struct attribute_group___41 dev_zone_attr_group;
	const struct attribute_group___41 *dev_attr_groups[2];
	bool allocated;
	struct powercap_zone_constraint___2 *constraints;
};

struct powercap_zone_constraint_ops___2;

struct powercap_zone_constraint___2 {
	int id;
	struct powercap_zone___2 *power_zone;
	const struct powercap_zone_constraint_ops___2 *ops;
};

struct powercap_zone_constraint_ops___2 {
	int (*set_power_limit_uw)(struct powercap_zone___2 *, int, u64);
	int (*get_power_limit_uw)(struct powercap_zone___2 *, int, u64 *);
	int (*set_time_window_us)(struct powercap_zone___2 *, int, u64);
	int (*get_time_window_us)(struct powercap_zone___2 *, int, u64 *);
	int (*get_max_power_uw)(struct powercap_zone___2 *, int, u64 *);
	int (*get_min_power_uw)(struct powercap_zone___2 *, int, u64 *);
	int (*get_max_time_window_us)(struct powercap_zone___2 *, int, u64 *);
	int (*get_min_time_window_us)(struct powercap_zone___2 *, int, u64 *);
	const char * (*get_name)(struct powercap_zone___2 *, int);
};

struct dtpm_ops___2;

struct dtpm___2 {
	struct powercap_zone___2 zone;
	struct dtpm___2 *parent;
	struct list_head sibling;
	struct list_head children;
	struct dtpm_ops___2 *ops;
	long unsigned int flags;
	u64 power_limit;
	u64 power_max;
	u64 power_min;
	int weight;
	void *private;
};

struct dtpm_ops___2 {
	u64 (*set_power_uw)(struct dtpm___2 *, u64);
	u64 (*get_power_uw)(struct dtpm___2 *);
	void (*release)(struct dtpm___2 *);
};

struct dtpm_cpu {
	struct freq_qos_request qos_req;
	int cpu;
};

struct powercap_control_type___2;

struct powercap_control_type_ops___2 {
	int (*set_enable)(struct powercap_control_type___2 *, bool);
	int (*get_enable)(struct powercap_control_type___2 *, bool *);
	int (*release)(struct powercap_control_type___2 *);
};

struct powercap_control_type___2 {
	struct device___215 dev;
	struct idr idr;
	int nr_zones;
	const struct powercap_control_type_ops___2 *ops;
	struct mutex lock;
	bool allocated;
	struct list_head node;
};

struct powercap_zone___3;

struct powercap_zone_ops___3 {
	int (*get_max_energy_range_uj)(struct powercap_zone___3 *, u64 *);
	int (*get_energy_uj)(struct powercap_zone___3 *, u64 *);
	int (*reset_energy_uj)(struct powercap_zone___3 *);
	int (*get_max_power_range_uw)(struct powercap_zone___3 *, u64 *);
	int (*get_power_uw)(struct powercap_zone___3 *, u64 *);
	int (*set_enable)(struct powercap_zone___3 *, bool);
	int (*get_enable)(struct powercap_zone___3 *, bool *);
	int (*release)(struct powercap_zone___3 *);
};

struct powercap_zone_constraint___3;

struct powercap_zone___3 {
	int id;
	char *name;
	void *control_type_inst;
	const struct powercap_zone_ops___3 *ops;
	struct device___215 dev;
	int const_id_cnt;
	struct idr idr;
	struct idr *parent_idr;
	void *private_data;
	struct attribute **zone_dev_attrs;
	int zone_attr_count;
	struct attribute_group___224 dev_zone_attr_group;
	const struct attribute_group___224 *dev_attr_groups[2];
	bool allocated;
	struct powercap_zone_constraint___3 *constraints;
};

struct powercap_zone_constraint_ops___3;

struct powercap_zone_constraint___3 {
	int id;
	struct powercap_zone___3 *power_zone;
	const struct powercap_zone_constraint_ops___3 *ops;
};

struct powercap_zone_constraint_ops___3 {
	int (*set_power_limit_uw)(struct powercap_zone___3 *, int, u64);
	int (*get_power_limit_uw)(struct powercap_zone___3 *, int, u64 *);
	int (*set_time_window_us)(struct powercap_zone___3 *, int, u64);
	int (*get_time_window_us)(struct powercap_zone___3 *, int, u64 *);
	int (*get_max_power_uw)(struct powercap_zone___3 *, int, u64 *);
	int (*get_min_power_uw)(struct powercap_zone___3 *, int, u64 *);
	int (*get_max_time_window_us)(struct powercap_zone___3 *, int, u64 *);
	int (*get_min_time_window_us)(struct powercap_zone___3 *, int, u64 *);
	const char * (*get_name)(struct powercap_zone___3 *, int);
};

struct powercap_constraint_attr {
	struct device_attribute___46 power_limit_attr;
	struct device_attribute___46 time_window_attr;
	struct device_attribute___46 max_power_attr;
	struct device_attribute___46 min_power_attr;
	struct device_attribute___46 max_time_window_attr;
	struct device_attribute___46 min_time_window_attr;
	struct device_attribute___46 name_attr;
};

struct idle_inject_thread {
	struct task_struct___38 *tsk;
	int should_run;
};

struct idle_inject_device___2 {
	struct hrtimer timer;
	unsigned int idle_duration_us;
	unsigned int run_duration_us;
	unsigned int latency_us;
	long unsigned int cpumask[0];
};

struct dev_ext_attribute___4 {
	struct device_attribute___39 attr;
	void *var;
};

struct platform_device___45 {
	const char *name;
	int id;
	bool id_auto;
	struct device___208 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

struct platform_driver___37 {
	int (*probe)(struct platform_device___45 *);
	int (*remove)(struct platform_device___45 *);
	void (*shutdown)(struct platform_device___45 *);
	int (*suspend)(struct platform_device___45 *, pm_message_t);
	int (*resume)(struct platform_device___45 *);
	struct device_driver___208 driver;
	const struct platform_device_id *id_table;
	bool prevent_deferred_probe;
};

enum {
	CCI_IF_SLAVE = 0,
	CCI_IF_MASTER = 1,
	CCI_IF_GLOBAL = 2,
	CCI_IF_MAX = 3,
};

struct event_range {
	u32 min;
	u32 max;
};

struct cci_pmu_hw_events {
	struct perf_event___82 **events;
	long unsigned int *used_mask;
	raw_spinlock_t pmu_lock;
};

struct cci_pmu;

struct cci_pmu_model {
	char *name;
	u32 fixed_hw_cntrs;
	u32 num_hw_cntrs;
	u32 cntr_size;
	struct attribute **format_attrs;
	struct attribute **event_attrs;
	struct event_range event_ranges[3];
	int (*validate_hw_event)(struct cci_pmu *, long unsigned int);
	int (*get_event_idx)(struct cci_pmu *, struct cci_pmu_hw_events *, long unsigned int);
	void (*write_counters)(struct cci_pmu *, long unsigned int *);
};

struct cci_pmu {
	void *base;
	void *ctrl_base;
	struct pmu___82 pmu;
	int cpu;
	int nr_irqs;
	int *irqs;
	long unsigned int active_irqs;
	const struct cci_pmu_model *model;
	struct cci_pmu_hw_events hw_events;
	struct platform_device___45 *plat_device;
	int num_cntrs;
	atomic_t active_events;
	struct mutex reserve_mutex;
};

enum cci_models {
	CCI400_R0 = 0,
	CCI400_R1 = 1,
	CCI500_R0 = 2,
	CCI550_R0 = 3,
	CCI_MODEL_MAX = 4,
};

enum cci400_perf_events {
	CCI400_PMU_CYCLES = 255,
};

struct arm_ccn_component {
	void *base;
	u32 type;
	long unsigned int pmu_events_mask[1];
	union {
		struct {
			long unsigned int dt_cmp_mask[1];
		} xp;
	};
};

struct arm_ccn_dt {
	int id;
	void *base;
	spinlock_t config_lock;
	long unsigned int pmu_counters_mask[1];
	struct {
		struct arm_ccn_component *source;
		struct perf_event___83 *event;
	} pmu_counters[9];
	struct {
		u64 l;
		u64 h;
	} cmp_mask[12];
	struct hrtimer hrtimer;
	unsigned int cpu;
	struct hlist_node node;
	struct pmu___83 pmu;
};

struct arm_ccn {
	struct device___213 *dev;
	void *base;
	unsigned int irq;
	unsigned int sbas_present: 1;
	unsigned int sbsx_present: 1;
	long: 63;
	long: 64;
	long: 64;
	int num_nodes;
	struct arm_ccn_component *node;
	int num_xps;
	struct arm_ccn_component *xp;
	struct arm_ccn_dt dt;
	int mn_id;
};

struct arm_ccn_pmu_event {
	struct device_attribute___39 attr;
	u32 type;
	u32 event;
	int num_ports;
	int num_vcs;
	const char *def;
	int mask;
};

struct pmu_irq_ops {
	void (*enable_pmuirq)(unsigned int);
	void (*disable_pmuirq)(unsigned int);
	void (*free_pmuirq)(unsigned int, int, void *);
};

struct perf_pmu_events_attr___3 {
	struct device_attribute___39 attr;
	u64 id;
	const char *event_str;
};

struct cluster_pmu;

struct l2cache_pmu {
	struct hlist_node node;
	u32 num_pmus;
	struct pmu___82 pmu;
	int num_counters;
	cpumask_t cpumask;
	struct platform_device___45 *pdev;
	struct cluster_pmu **pmu_cluster;
	struct list_head clusters;
};

struct cluster_pmu {
	struct list_head next;
	struct perf_event___82 *events[9];
	struct l2cache_pmu *l2cache_pmu;
	long unsigned int used_counters[1];
	long unsigned int used_groups[1];
	int irq;
	int cluster_id;
	int on_cpu;
	cpumask_t cluster_cpus;
	spinlock_t pmu_lock;
};

struct dev_ext_attribute___5 {
	struct device_attribute___2 attr;
	void *var;
};

struct l3cache_pmu {
	struct pmu___8 pmu;
	struct hlist_node node;
	void *regs;
	struct perf_event___8 *events[8];
	long unsigned int used_mask[1];
	cpumask_t cpumask;
};

struct l3cache_event_ops {
	void (*start)(struct perf_event___8 *);
	void (*stop)(struct perf_event___8 *, int);
	void (*update)(struct perf_event___8 *);
};

struct hw_pmu_info {
	u32 type;
	u32 enable_mask;
	void *csr;
};

struct xgene_pmu;

struct xgene_pmu_dev {
	struct hw_pmu_info *inf;
	struct xgene_pmu *parent;
	struct pmu___8 pmu;
	u8 max_counters;
	long unsigned int cntr_assign_mask[1];
	u64 max_period;
	const struct attribute_group___13 **attr_groups;
	struct perf_event___8 *pmu_counter_event[4];
};

struct xgene_pmu_ops;

struct xgene_pmu {
	struct device___11 *dev;
	struct hlist_node node;
	int version;
	void *pcppmu_csr;
	u32 mcb_active_mask;
	u32 mc_active_mask;
	u32 l3c_active_mask;
	cpumask_t cpu;
	int irq;
	raw_spinlock_t lock;
	const struct xgene_pmu_ops *ops;
	struct list_head l3cpmus;
	struct list_head iobpmus;
	struct list_head mcbpmus;
	struct list_head mcpmus;
};

struct xgene_pmu_ops {
	void (*mask_int)(struct xgene_pmu *);
	void (*unmask_int)(struct xgene_pmu *);
	u64 (*read_counter)(struct xgene_pmu_dev *, int);
	void (*write_counter)(struct xgene_pmu_dev *, int, u64);
	void (*write_evttype)(struct xgene_pmu_dev *, int, u32);
	void (*write_agentmsk)(struct xgene_pmu_dev *, u32);
	void (*write_agent1msk)(struct xgene_pmu_dev *, u32);
	void (*enable_counter)(struct xgene_pmu_dev *, int);
	void (*disable_counter)(struct xgene_pmu_dev *, int);
	void (*enable_counter_int)(struct xgene_pmu_dev *, int);
	void (*disable_counter_int)(struct xgene_pmu_dev *, int);
	void (*reset_counters)(struct xgene_pmu_dev *);
	void (*start_counters)(struct xgene_pmu_dev *);
	void (*stop_counters)(struct xgene_pmu_dev *);
};

struct xgene_pmu_dev_ctx {
	char *name;
	struct list_head next;
	struct xgene_pmu_dev *pmu_dev;
	struct hw_pmu_info inf;
};

struct xgene_pmu_data {
	int id;
	u32 data;
};

enum xgene_pmu_version {
	PCP_PMU_V1 = 1,
	PCP_PMU_V2 = 2,
	PCP_PMU_V3 = 3,
};

enum xgene_pmu_dev_type {
	PMU_TYPE_L3C = 0,
	PMU_TYPE_IOB = 1,
	PMU_TYPE_IOB_SLOW = 2,
	PMU_TYPE_MCB = 3,
	PMU_TYPE_MC = 4,
};

struct trace_event_raw_mc_event {
	struct trace_entry ent;
	unsigned int error_type;
	u32 __data_loc_msg;
	u32 __data_loc_label;
	u16 error_count;
	u8 mc_index;
	s8 top_layer;
	s8 middle_layer;
	s8 lower_layer;
	long int address;
	u8 grain_bits;
	long int syndrome;
	u32 __data_loc_driver_detail;
	char __data[0];
};

struct trace_event_raw_arm_event {
	struct trace_entry ent;
	u64 mpidr;
	u64 midr;
	u32 running_state;
	u32 psci_state;
	u8 affinity;
	char __data[0];
};

struct trace_event_raw_non_standard_event {
	struct trace_entry ent;
	char sec_type[16];
	char fru_id[16];
	u32 __data_loc_fru_text;
	u8 sev;
	u32 len;
	u32 __data_loc_buf;
	char __data[0];
};

struct trace_event_raw_aer_event {
	struct trace_entry ent;
	u32 __data_loc_dev_name;
	u32 status;
	u8 severity;
	u8 tlp_header_valid;
	u32 tlp_header[4];
	char __data[0];
};

struct trace_event_raw_memory_failure_event {
	struct trace_entry ent;
	long unsigned int pfn;
	int type;
	int result;
	char __data[0];
};

struct trace_event_data_offsets_mc_event {
	u32 msg;
	u32 label;
	u32 driver_detail;
};

struct trace_event_data_offsets_arm_event {};

struct trace_event_data_offsets_non_standard_event {
	u32 fru_text;
	u32 buf;
};

struct trace_event_data_offsets_aer_event {
	u32 dev_name;
};

struct trace_event_data_offsets_memory_failure_event {};

typedef void (*btf_trace_mc_event)(void *, const unsigned int, const char *, const char *, const int, const u8, const s8, const s8, const s8, long unsigned int, const u8, long unsigned int, const char *);

typedef void (*btf_trace_arm_event)(void *, const struct cper_sec_proc_arm *);

typedef void (*btf_trace_non_standard_event)(void *, const guid_t *, const guid_t *, const char *, const u8, const u8 *, const u32);

typedef void (*btf_trace_aer_event)(void *, const char *, const u32, const u8, const u8, struct aer_header_log_regs *);

typedef void (*btf_trace_memory_failure_event)(void *, long unsigned int, int, int);

typedef int (*dr_match_t___32)(struct device___218 *, void *, void *);

enum {
	NVMEM_ADD = 1,
	NVMEM_REMOVE = 2,
	NVMEM_CELL_ADD = 3,
	NVMEM_CELL_REMOVE = 4,
};

struct nvmem_config___3 {
	struct device___218 *dev;
	const char *name;
	int id;
	struct module___221 *owner;
	struct gpio_desc *wp_gpio;
	const struct nvmem_cell_info *cells;
	int ncells;
	const struct nvmem_keepout *keepout;
	unsigned int nkeepout;
	enum nvmem_type type;
	bool read_only;
	bool root_only;
	bool ignore_wp;
	struct device_node___99 *of_node;
	bool no_of_node;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	int size;
	int word_size;
	int stride;
	void *priv;
	bool compat;
	struct device___218 *base_dev;
};

struct nvmem_cell_table {
	const char *nvmem_name;
	const struct nvmem_cell_info *cells;
	size_t ncells;
	struct list_head node;
};

struct nvmem_device___2 {
	struct module___221 *owner;
	struct device___218 dev;
	int stride;
	int word_size;
	int id;
	struct kref refcnt;
	size_t size;
	bool read_only;
	bool root_only;
	int flags;
	enum nvmem_type type;
	struct bin_attribute___225 eeprom;
	struct device___218 *base_dev;
	struct list_head cells;
	const struct nvmem_keepout *keepout;
	unsigned int nkeepout;
	nvmem_reg_read_t reg_read;
	nvmem_reg_write_t reg_write;
	struct gpio_desc *wp_gpio;
	void *priv;
};

struct nvmem_cell {
	const char *name;
	int offset;
	int bytes;
	int bit_offset;
	int nbits;
	struct device_node___99 *np;
	struct nvmem_device___2 *nvmem;
	struct list_head node;
};

struct zynqmp_nvmem_data {
	struct device___218 *dev;
	struct nvmem_device *nvmem;
};

struct icc_node___5;

struct icc_req {
	struct hlist_node req_node;
	struct icc_node___5 *node;
	struct device___213 *dev;
	bool enabled;
	u32 tag;
	u32 avg_bw;
	u32 peak_bw;
};

struct icc_path___2 {
	const char *name;
	size_t num_nodes;
	struct icc_req reqs[0];
};

struct icc_node_data___5 {
	struct icc_node___5 *node;
	u32 tag;
};

struct icc_provider___5;

struct icc_node___5 {
	int id;
	const char *name;
	struct icc_node___5 **links;
	size_t num_links;
	struct icc_provider___5 *provider;
	struct list_head node_list;
	struct list_head search_list;
	struct icc_node___5 *reverse;
	u8 is_traversed: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head req_list;
	u32 avg_bw;
	u32 peak_bw;
	u32 init_avg;
	u32 init_peak;
	void *data;
};

struct icc_onecell_data {
	unsigned int num_nodes;
	struct icc_node___5 *nodes[0];
};

struct icc_provider___5 {
	struct list_head provider_list;
	struct list_head nodes;
	int (*set)(struct icc_node___5 *, struct icc_node___5 *);
	int (*aggregate)(struct icc_node___5 *, u32, u32, u32, u32 *, u32 *);
	void (*pre_aggregate)(struct icc_node___5 *);
	int (*get_bw)(struct icc_node___5 *, u32 *, u32 *);
	struct icc_node___5 * (*xlate)(struct of_phandle_args___14 *, void *);
	struct icc_node_data___5 * (*xlate_extended)(struct of_phandle_args___14 *, void *);
	struct device___213 *dev;
	int users;
	bool inter_set;
	void *data;
};

struct trace_event_raw_icc_set_bw {
	struct trace_entry ent;
	u32 __data_loc_path_name;
	u32 __data_loc_dev;
	u32 __data_loc_node_name;
	u32 avg_bw;
	u32 peak_bw;
	u32 node_avg_bw;
	u32 node_peak_bw;
	char __data[0];
};

struct trace_event_raw_icc_set_bw_end {
	struct trace_entry ent;
	u32 __data_loc_path_name;
	u32 __data_loc_dev;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_icc_set_bw {
	u32 path_name;
	u32 dev;
	u32 node_name;
};

struct trace_event_data_offsets_icc_set_bw_end {
	u32 path_name;
	u32 dev;
};

typedef void (*btf_trace_icc_set_bw)(void *, struct icc_path___2 *, struct icc_node___5 *, int, u32, u32);

typedef void (*btf_trace_icc_set_bw_end)(void *, struct icc_path___2 *, int);

struct icc_bulk_data {
	struct icc_path *path;
	const char *name;
	u32 avg_bw;
	u32 peak_bw;
};

typedef void (*dr_release_t___42)(struct device___203 *, void *);

typedef int (*dr_match_t___33)(struct device___203 *, void *, void *);

struct net_device_devres {
	struct net_device___45 *ndev;
};

struct __kernel_old_timespec {
	__kernel_old_time_t tv_sec;
	long int tv_nsec;
};

struct __kernel_sock_timeval {
	__s64 tv_sec;
	__s64 tv_usec;
};

struct mmsghdr {
	struct user_msghdr msg_hdr;
	unsigned int msg_len;
};

struct scm_timestamping_internal {
	struct timespec64 ts[3];
};

struct ifconf {
	int ifc_len;
	union {
		char *ifcu_buf;
		struct ifreq *ifcu_req;
	} ifc_ifcu;
};

struct compat_ifmap {
	compat_ulong_t mem_start;
	compat_ulong_t mem_end;
	short unsigned int base_addr;
	unsigned char irq;
	unsigned char dma;
	unsigned char port;
};

struct compat_if_settings {
	unsigned int type;
	unsigned int size;
	compat_uptr_t ifs_ifsu;
};

struct compat_ifreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union {
		struct sockaddr ifru_addr;
		struct sockaddr ifru_dstaddr;
		struct sockaddr ifru_broadaddr;
		struct sockaddr ifru_netmask;
		struct sockaddr ifru_hwaddr;
		short int ifru_flags;
		compat_int_t ifru_ivalue;
		compat_int_t ifru_mtu;
		struct compat_ifmap ifru_map;
		char ifru_slave[16];
		char ifru_newname[16];
		compat_caddr_t ifru_data;
		struct compat_if_settings ifru_settings;
	} ifr_ifru;
};

enum sock_shutdown_cmd {
	SHUT_RD = 0,
	SHUT_WR = 1,
	SHUT_RDWR = 2,
};

struct net_proto_family {
	int family;
	int (*create)(struct net___30 *, struct socket___18 *, int, int);
	struct module___141 *owner;
};

enum {
	SOCK_WAKE_IO = 0,
	SOCK_WAKE_WAITD = 1,
	SOCK_WAKE_SPACE = 2,
	SOCK_WAKE_URG = 3,
};

typedef struct bio_vec___83 skb_frag_t___7;

struct skb_shared_info___7 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___26 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___7 frags[17];
};

struct fd___29 {
	struct file___156 *file;
	unsigned int flags;
};

struct libipw_device;

struct iw_spy_data;

struct iw_public_data {
	struct iw_spy_data *spy_data;
	struct libipw_device *libipw;
};

struct pseudo_fs_context___11 {
	const struct super_operations___156 *ops;
	const struct xattr_handler___21 **xattr;
	const struct dentry_operations___156 *dops;
	long unsigned int magic;
};

struct syscall_metadata___36 {
	const char *name;
	int syscall_nr;
	int nb_args;
	const char **types;
	const char **args;
	struct list_head enter_fields;
	struct trace_event_call___64 *enter_event;
	struct trace_event_call___64 *exit_event;
};

struct iw_param {
	__s32 value;
	__u8 fixed;
	__u8 disabled;
	__u16 flags;
};

struct iw_point {
	void *pointer;
	__u16 length;
	__u16 flags;
};

struct iw_freq {
	__s32 m;
	__s16 e;
	__u8 i;
	__u8 flags;
};

struct iw_quality {
	__u8 qual;
	__u8 level;
	__u8 noise;
	__u8 updated;
};

struct iw_discarded {
	__u32 nwid;
	__u32 code;
	__u32 fragment;
	__u32 retries;
	__u32 misc;
};

struct iw_missed {
	__u32 beacon;
};

struct iw_statistics {
	__u16 status;
	struct iw_quality qual;
	struct iw_discarded discard;
	struct iw_missed miss;
};

union iwreq_data {
	char name[16];
	struct iw_point essid;
	struct iw_param nwid;
	struct iw_freq freq;
	struct iw_param sens;
	struct iw_param bitrate;
	struct iw_param txpower;
	struct iw_param rts;
	struct iw_param frag;
	__u32 mode;
	struct iw_param retry;
	struct iw_point encoding;
	struct iw_param power;
	struct iw_quality qual;
	struct sockaddr ap_addr;
	struct sockaddr addr;
	struct iw_param param;
	struct iw_point data;
};

struct iw_priv_args {
	__u32 cmd;
	__u16 set_args;
	__u16 get_args;
	char name[16];
};

struct compat_mmsghdr {
	struct compat_msghdr msg_hdr;
	compat_uint_t msg_len;
};

struct iw_request_info {
	__u16 cmd;
	__u16 flags;
};

struct iw_spy_data {
	int spy_number;
	u_char spy_address[48];
	struct iw_quality spy_stat[8];
	struct iw_quality spy_thr_low;
	struct iw_quality spy_thr_high;
	u_char spy_thr_under[8];
};

struct scm_ts_pktinfo {
	__u32 if_index;
	__u32 pkt_length;
	__u32 reserved[2];
};

struct sock_skb_cb {
	u32 dropcount;
};

struct sock_ee_data_rfc4884 {
	__u16 len;
	__u8 flags;
	__u8 reserved;
};

struct sock_extended_err {
	__u32 ee_errno;
	__u8 ee_origin;
	__u8 ee_type;
	__u8 ee_code;
	__u8 ee_pad;
	__u32 ee_info;
	union {
		__u32 ee_data;
		struct sock_ee_data_rfc4884 ee_rfc4884;
	};
};

struct sock_exterr_skb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	struct sock_extended_err ee;
	u16 addr_offset;
	__be16 port;
	u8 opt_stats: 1;
	u8 unused: 7;
	long: 57;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_bridge;

struct used_address {
	struct __kernel_sockaddr_storage name;
	unsigned int name_len;
};

struct dentry___238;

struct super_block___238;

struct module___222;

struct file_system_type___238 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___238 * (*mount)(struct file_system_type___238 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___238 *);
	struct module___222 *owner;
	struct file_system_type___238 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___238;

struct kiocb___238;

struct iov_iter___158;

struct poll_table_struct___161;

struct vm_area_struct___243;

struct inode___238;

struct file_lock___238;

struct page___243;

struct pipe_inode_info___79;

struct seq_file___213;

struct file_operations___239 {
	struct module___222 *owner;
	loff_t (*llseek)(struct file___238 *, loff_t, int);
	ssize_t (*read)(struct file___238 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___238 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___238 *, struct iov_iter___158 *);
	ssize_t (*write_iter)(struct kiocb___238 *, struct iov_iter___158 *);
	int (*iopoll)(struct kiocb___238 *, bool);
	int (*iterate)(struct file___238 *, struct dir_context *);
	int (*iterate_shared)(struct file___238 *, struct dir_context *);
	__poll_t (*poll)(struct file___238 *, struct poll_table_struct___161 *);
	long int (*unlocked_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___238 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___238 *, struct vm_area_struct___243 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___238 *, struct file___238 *);
	int (*flush)(struct file___238 *, fl_owner_t);
	int (*release)(struct inode___238 *, struct file___238 *);
	int (*fsync)(struct file___238 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___238 *, int);
	int (*lock)(struct file___238 *, int, struct file_lock___238 *);
	ssize_t (*sendpage)(struct file___238 *, struct page___243 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___238 *, long unsigned int);
	int (*flock)(struct file___238 *, int, struct file_lock___238 *);
	ssize_t (*splice_write)(struct pipe_inode_info___79 *, struct file___238 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___238 *, loff_t *, struct pipe_inode_info___79 *, size_t, unsigned int);
	int (*setlease)(struct file___238 *, long int, struct file_lock___238 **, void **);
	long int (*fallocate)(struct file___238 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___213 *, struct file___238 *);
	ssize_t (*copy_file_range)(struct file___238 *, loff_t, struct file___238 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___238 *, loff_t, struct file___238 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___238 *, loff_t, loff_t, int);
};

struct vmacache___243 {
	u64 seqnum;
	struct vm_area_struct___243 *vmas[4];
};

struct page_frag___243 {
	struct page___243 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___244;

struct pid___215;

struct nsproxy___224;

struct signal_struct___239;

struct bio_list___131;

struct backing_dev_info___117;

struct io_context___131;

struct css_set___165;

struct mem_cgroup___105;

struct request_queue___131;

struct vm_struct___221;

struct bpf_local_storage___7;

struct task_struct___245 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___245 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___244 *mm;
	struct mm_struct___244 *active_mm;
	struct vmacache___243 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___245 *real_parent;
	struct task_struct___245 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___245 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___215 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___224 *nsproxy;
	struct signal_struct___239 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___245 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___131 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___117 *backing_dev_info;
	struct io_context___131 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___165 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___79 *splice_pipe;
	struct page_frag___243 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___105 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___105 *active_memcg;
	struct request_queue___131 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___245 *oom_reaper_list;
	struct vm_struct___221 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___7 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___226;

struct kobj_type___226;

struct kernfs_node___226;

struct kobject___226 {
	const char *name;
	struct list_head entry;
	struct kobject___226 *parent;
	struct kset___226 *kset;
	struct kobj_type___226 *ktype;
	struct kernfs_node___226 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___223 {
	struct kobject___226 kobj;
	struct module___222 *mod;
	struct kobject___226 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___222 {
	struct module___222 *mod;
	struct latch_tree_node node;
};

struct module_layout___222 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___222 mtn;
};

struct module_attribute___222;

struct kernel_param___222;

struct module___222 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___223 mkobj;
	struct module_attribute___222 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___226 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___222 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___222 core_layout;
	struct module_layout___222 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___238;

struct dentry___238 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___238 *d_parent;
	struct qstr d_name;
	struct inode___238 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___238 *d_op;
	struct super_block___238 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___238;

struct address_space___238 {
	struct inode___238 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___238 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___238;

struct bdi_writeback___117;

struct inode___238 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___238 *i_op;
	struct super_block___238 *i_sb;
	struct address_space___238 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___117 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___239 *i_fop;
		void (*free_inode)(struct inode___238 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___238 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___79 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___238;

struct path___238;

struct dentry_operations___238 {
	int (*d_revalidate)(struct dentry___238 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___238 *, unsigned int);
	int (*d_hash)(const struct dentry___238 *, struct qstr *);
	int (*d_compare)(const struct dentry___238 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___238 *);
	int (*d_init)(struct dentry___238 *);
	void (*d_release)(struct dentry___238 *);
	void (*d_prune)(struct dentry___238 *);
	void (*d_iput)(struct dentry___238 *, struct inode___238 *);
	char * (*d_dname)(struct dentry___238 *, char *, int);
	struct vfsmount___238 * (*d_automount)(struct path___238 *);
	int (*d_manage)(const struct path___238 *, bool);
	struct dentry___238 * (*d_real)(struct dentry___238 *, const struct inode___238 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___238;

struct mem_dqinfo___238 {
	struct quota_format_type___238 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___238;

struct quota_info___238 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___238 *files[3];
	struct mem_dqinfo___238 info[3];
	const struct quota_format_ops___238 *ops[3];
};

struct rcuwait___239 {
	struct task_struct___245 *task;
};

struct percpu_rw_semaphore___239 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___239 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___238 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___239 rw_sem[3];
};

struct shrink_control___105;

struct shrinker___105 {
	long unsigned int (*count_objects)(struct shrinker___105 *, struct shrink_control___105 *);
	long unsigned int (*scan_objects)(struct shrinker___105 *, struct shrink_control___105 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___238;

struct dquot_operations___238;

struct quotactl_ops___238;

struct block_device___134;

struct super_block___238 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___238 *s_type;
	const struct super_operations___238 *s_op;
	const struct dquot_operations___238 *dq_op;
	const struct quotactl_ops___238 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___238 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___134 *s_bdev;
	struct backing_dev_info___117 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___238 s_dquot;
	struct sb_writers___238 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___238 *s_d_op;
	int cleancache_poolid;
	struct shrinker___105 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___238 {
	struct dentry___238 *mnt_root;
	struct super_block___238 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct path___238 {
	struct vfsmount___238 *mnt;
	struct dentry___238 *dentry;
};

struct pid_namespace___215;

struct upid___215 {
	int nr;
	struct pid_namespace___215 *ns;
};

struct pid_namespace___215 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___245 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___215 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___215 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___215 numbers[1];
};

typedef struct page___243 *pgtable_t___243;

struct page_pool___67;

struct dev_pagemap___233;

struct page___243 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___238 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___67 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___243 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___243 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___244 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___233 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___233;

struct vm_area_struct___243 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___243 *vm_next;
	struct vm_area_struct___243 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___244 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___233 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___238 *vm_file;
	struct file___238 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___239 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___245 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___245 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___215 *pids[4];
	struct pid___215 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___244 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___243;

struct mm_struct___244 {
	struct {
		struct vm_area_struct___243 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___238 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___243 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___245 *owner;
		struct user_namespace___14 *user_ns;
		struct file___238 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___52;

struct cgroup_namespace___165;

struct nsproxy___224 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___215 *pid_ns_for_children;
	struct net___52 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___165 *cgroup_ns;
};

struct bio___131;

struct bio_list___131 {
	struct bio___131 *head;
	struct bio___131 *tail;
};

struct cgroup_subsys_state___165;

struct bdi_writeback___117 {
	struct backing_dev_info___117 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___165 *memcg_css;
	struct cgroup_subsys_state___165 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___219;

struct backing_dev_info___117 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___117 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___219 *dev;
	char dev_name[64];
	struct device___219 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___238 *debug_dir;
};

struct io_cq___131;

struct io_context___131 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___131 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___165;

struct css_set___165 {
	struct cgroup_subsys_state___165 *subsys[14];
	refcount_t refcount;
	struct css_set___165 *dom_cset;
	struct cgroup___165 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___165 *mg_src_cgrp;
	struct cgroup___165 *mg_dst_cgrp;
	struct css_set___165 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___238;

struct pipe_buffer___79;

struct pipe_inode_info___79 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___243 *tmp_page;
	struct fasync_struct___238 *fasync_readers;
	struct fasync_struct___238 *fasync_writers;
	struct pipe_buffer___79 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___165;

struct cgroup_subsys_state___165 {
	struct cgroup___165 *cgroup;
	struct cgroup_subsys___165 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___165 *parent;
};

struct cgroup_file___165 {
	struct kernfs_node___226 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___105;

struct mem_cgroup_per_node___105;

struct mem_cgroup___105 {
	struct cgroup_subsys_state___165 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___165 events_file;
	struct cgroup_file___165 events_local_file;
	struct cgroup_file___165 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___105 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___245 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___105 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___131;

struct blk_integrity___131 {
	const struct blk_integrity_profile___131 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___131 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___131 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___131;

struct elevator_queue___131;

struct blk_mq_ops___126;

struct blk_mq_hw_ctx___126;

struct gendisk___134;

struct blkcg_gq___119;

struct blk_mq_tag_set___126;

struct request_queue___131 {
	struct request___131 *last_merge;
	struct elevator_queue___131 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___126 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___126 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___134 *disk;
	struct kobject___226 kobj;
	struct kobject___226 *mq_kobj;
	struct blk_integrity___131 integrity;
	struct device___219 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___119 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___126 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___131 bio_split;
	struct dentry___238 *debugfs_dir;
	struct dentry___238 *sched_debugfs_dir;
	struct dentry___238 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___221 {
	struct vm_struct___221 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___243 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___7;

struct bpf_local_storage___7 {
	struct bpf_local_storage_data___7 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct shrink_control___105 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___105 *memcg;
};

struct page_pool_params___67 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___219 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___67 {
	u32 count;
	struct page___243 *cache[128];
};

struct page_pool___67 {
	struct page_pool_params___67 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___243 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___67 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___233;

struct dev_pagemap___233 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___233 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___215 {
	rwlock_t lock;
	struct pid___215 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___238 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___238 f_path;
	struct inode___238 *f_inode;
	const struct file_operations___239 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___215 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___238 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___233;

struct vm_operations_struct___233 {
	void (*open)(struct vm_area_struct___243 *);
	void (*close)(struct vm_area_struct___243 *);
	int (*may_split)(struct vm_area_struct___243 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___243 *);
	int (*mprotect)(struct vm_area_struct___243 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___233 *);
	vm_fault_t (*huge_fault)(struct vm_fault___233 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___233 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___243 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___233 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___233 *);
	int (*access)(struct vm_area_struct___243 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___243 *);
	int (*set_policy)(struct vm_area_struct___243 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___243 *, long unsigned int);
	struct page___243 * (*find_special_page)(struct vm_area_struct___243 *, long unsigned int);
};

struct core_thread___243 {
	struct task_struct___245 *task;
	struct core_thread___243 *next;
};

struct core_state___243 {
	atomic_t nr_threads;
	struct core_thread___243 dumper;
	struct completion startup;
};

struct vm_fault___233 {
	const struct {
		struct vm_area_struct___243 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___243 *cow_page;
	struct page___243 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___243 prealloc_pte;
};

struct pglist_data___113;

struct lruvec___113 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___113 *pgdat;
};

struct zone___113 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___113 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___113 {
	struct zone___113 *zone;
	int zone_idx;
};

struct zonelist___113 {
	struct zoneref___113 _zonerefs[321];
};

struct pglist_data___113 {
	struct zone___113 node_zones[5];
	struct zonelist___113 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___245 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___245 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___113 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___165 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___245 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___43;

struct cgroup_bpf___43 {
	struct bpf_prog_array___43 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___43 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___165;

struct cgroup_rstat_cpu___165;

struct cgroup___165 {
	struct cgroup_subsys_state___165 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___226 *kn;
	struct cgroup_file___165 procs_file;
	struct cgroup_file___165 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___165 *subsys[14];
	struct cgroup_root___165 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___165 *dom_cgrp;
	struct cgroup___165 *old_dom_cgrp;
	struct cgroup_rstat_cpu___165 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___165 psi;
	struct cgroup_bpf___43 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___131 {
	struct request_queue___131 *q;
	struct io_context___131 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___238 {
	struct file___238 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___238 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___113 *ki_waitq;
	};
};

struct iattr___238 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___238 *ia_file;
};

struct dquot___238 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___238 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___238 {
	int qf_fmt_id;
	const struct quota_format_ops___238 *qf_ops;
	struct module___222 *qf_owner;
	struct quota_format_type___238 *qf_next;
};

struct quota_format_ops___238 {
	int (*check_quota_file)(struct super_block___238 *, int);
	int (*read_file_info)(struct super_block___238 *, int);
	int (*write_file_info)(struct super_block___238 *, int);
	int (*free_file_info)(struct super_block___238 *, int);
	int (*read_dqblk)(struct dquot___238 *);
	int (*commit_dqblk)(struct dquot___238 *);
	int (*release_dqblk)(struct dquot___238 *);
	int (*get_next_id)(struct super_block___238 *, struct kqid *);
};

struct dquot_operations___238 {
	int (*write_dquot)(struct dquot___238 *);
	struct dquot___238 * (*alloc_dquot)(struct super_block___238 *, int);
	void (*destroy_dquot)(struct dquot___238 *);
	int (*acquire_dquot)(struct dquot___238 *);
	int (*release_dquot)(struct dquot___238 *);
	int (*mark_dirty)(struct dquot___238 *);
	int (*write_info)(struct super_block___238 *, int);
	qsize_t * (*get_reserved_space)(struct inode___238 *);
	int (*get_projid)(struct inode___238 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___238 *, qsize_t *);
	int (*get_next_id)(struct super_block___238 *, struct kqid *);
};

struct quotactl_ops___238 {
	int (*quota_on)(struct super_block___238 *, int, int, const struct path___238 *);
	int (*quota_off)(struct super_block___238 *, int);
	int (*quota_enable)(struct super_block___238 *, unsigned int);
	int (*quota_disable)(struct super_block___238 *, unsigned int);
	int (*quota_sync)(struct super_block___238 *, int);
	int (*set_info)(struct super_block___238 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___238 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___238 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___238 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___238 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___238 *, unsigned int);
};

struct writeback_control___117;

struct address_space_operations___238 {
	int (*writepage)(struct page___243 *, struct writeback_control___117 *);
	int (*readpage)(struct file___238 *, struct page___243 *);
	int (*writepages)(struct address_space___238 *, struct writeback_control___117 *);
	int (*set_page_dirty)(struct page___243 *);
	int (*readpages)(struct file___238 *, struct address_space___238 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___238 *, struct address_space___238 *, loff_t, unsigned int, unsigned int, struct page___243 **, void **);
	int (*write_end)(struct file___238 *, struct address_space___238 *, loff_t, unsigned int, unsigned int, struct page___243 *, void *);
	sector_t (*bmap)(struct address_space___238 *, sector_t);
	void (*invalidatepage)(struct page___243 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___243 *, gfp_t);
	void (*freepage)(struct page___243 *);
	ssize_t (*direct_IO)(struct kiocb___238 *, struct iov_iter___158 *);
	int (*migratepage)(struct address_space___238 *, struct page___243 *, struct page___243 *, enum migrate_mode);
	bool (*isolate_page)(struct page___243 *, isolate_mode_t);
	void (*putback_page)(struct page___243 *);
	int (*launder_page)(struct page___243 *);
	int (*is_partially_uptodate)(struct page___243 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___243 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___238 *, struct page___243 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___238 *, sector_t *);
	void (*swap_deactivate)(struct file___238 *);
};

struct writeback_control___117 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___117 *wb;
	struct inode___238 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___155;

struct iov_iter___158 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___155 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___79 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___238 {
	struct dentry___238 * (*lookup)(struct inode___238 *, struct dentry___238 *, unsigned int);
	const char * (*get_link)(struct dentry___238 *, struct inode___238 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___238 *, int);
	struct posix_acl * (*get_acl)(struct inode___238 *, int, bool);
	int (*readlink)(struct dentry___238 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___238 *, struct dentry___238 *, umode_t, bool);
	int (*link)(struct dentry___238 *, struct inode___238 *, struct dentry___238 *);
	int (*unlink)(struct inode___238 *, struct dentry___238 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___238 *, struct dentry___238 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___238 *, struct dentry___238 *, umode_t);
	int (*rmdir)(struct inode___238 *, struct dentry___238 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___238 *, struct dentry___238 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___238 *, struct dentry___238 *, struct inode___238 *, struct dentry___238 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___238 *, struct iattr___238 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___238 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___238 *, char *, size_t);
	int (*fiemap)(struct inode___238 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___238 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___238 *, struct dentry___238 *, struct file___238 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___238 *, struct dentry___238 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___238 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___238 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___238 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___238 {
	void (*fl_copy_lock)(struct file_lock___238 *, struct file_lock___238 *);
	void (*fl_release_private)(struct file_lock___238 *);
};

struct lock_manager_operations___238;

struct file_lock___238 {
	struct file_lock___238 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___238 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___238 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___238 *fl_ops;
	const struct lock_manager_operations___238 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___238 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___238 *);
	int (*lm_grant)(struct file_lock___238 *, int);
	bool (*lm_break)(struct file_lock___238 *);
	int (*lm_change)(struct file_lock___238 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___238 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___238 *);
};

struct fasync_struct___238 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___238 *fa_next;
	struct file___238 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___238 {
	struct inode___238 * (*alloc_inode)(struct super_block___238 *);
	void (*destroy_inode)(struct inode___238 *);
	void (*free_inode)(struct inode___238 *);
	void (*dirty_inode)(struct inode___238 *, int);
	int (*write_inode)(struct inode___238 *, struct writeback_control___117 *);
	int (*drop_inode)(struct inode___238 *);
	void (*evict_inode)(struct inode___238 *);
	void (*put_super)(struct super_block___238 *);
	int (*sync_fs)(struct super_block___238 *, int);
	int (*freeze_super)(struct super_block___238 *);
	int (*freeze_fs)(struct super_block___238 *);
	int (*thaw_super)(struct super_block___238 *);
	int (*unfreeze_fs)(struct super_block___238 *);
	int (*statfs)(struct dentry___238 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___238 *, int *, char *);
	void (*umount_begin)(struct super_block___238 *);
	int (*show_options)(struct seq_file___213 *, struct dentry___238 *);
	int (*show_devname)(struct seq_file___213 *, struct dentry___238 *);
	int (*show_path)(struct seq_file___213 *, struct dentry___238 *);
	int (*show_stats)(struct seq_file___213 *, struct dentry___238 *);
	ssize_t (*quota_read)(struct super_block___238 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___238 *, int, const char *, size_t, loff_t);
	struct dquot___238 ** (*get_dquots)(struct inode___238 *);
	long int (*nr_cached_objects)(struct super_block___238 *, struct shrink_control___105 *);
	long int (*free_cached_objects)(struct super_block___238 *, struct shrink_control___105 *);
	struct file___238 * (*real_loop)(struct file___238 *);
};

struct wakeup_source___219;

struct dev_pm_info___219 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___219 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___219 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___219;

struct bus_type___219;

struct device_driver___219;

struct dev_pm_domain___219;

struct fwnode_handle___215;

struct class___219;

struct attribute_group___226;

struct device___219 {
	struct kobject___226 kobj;
	struct device___219 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___219 *type;
	struct bus_type___219 *bus;
	struct device_driver___219 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___219 power;
	struct dev_pm_domain___219 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___215 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___219 *class;
	const struct attribute_group___226 **groups;
	void (*release)(struct device___219 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___134 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___238 *bd_inode;
	struct super_block___238 *bd_super;
	void *bd_claiming;
	struct device___219 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___226 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___134 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___238 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___169)(struct file___238 *, wait_queue_head_t *, struct poll_table_struct___161 *);

struct poll_table_struct___161 {
	poll_queue_proc___169 _qproc;
	__poll_t _key;
};

struct seq_operations___213;

struct seq_file___213 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___213 *op;
	int poll_event;
	const struct file___238 *file;
	void *private;
};

typedef void bio_end_io_t___131(struct bio___131 *);

struct bio_vec___155 {
	struct page___243 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___131;

struct bio___131 {
	struct bio___131 *bi_next;
	struct block_device___134 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___131 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___119 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___131 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___155 *bi_io_vec;
	struct bio_set___131 *bi_pool;
	struct bio_vec___155 bi_inline_vecs[0];
};

struct dev_pagemap_ops___233 {
	void (*page_free)(struct page___243 *);
	void (*kill)(struct dev_pagemap___233 *);
	void (*cleanup)(struct dev_pagemap___233 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___233 *);
};

struct fwnode_operations___215;

struct fwnode_handle___215 {
	struct fwnode_handle___215 *secondary;
	const struct fwnode_operations___215 *ops;
	struct device___219 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___215;

struct fwnode_endpoint___215;

struct fwnode_operations___215 {
	struct fwnode_handle___215 * (*get)(struct fwnode_handle___215 *);
	void (*put)(struct fwnode_handle___215 *);
	bool (*device_is_available)(const struct fwnode_handle___215 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___215 *, const struct device___219 *);
	bool (*property_present)(const struct fwnode_handle___215 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___215 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___215 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___215 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*get_parent)(const struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*get_next_child_node)(const struct fwnode_handle___215 *, struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*get_named_child_node)(const struct fwnode_handle___215 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___215 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___215 *);
	struct fwnode_handle___215 * (*graph_get_next_endpoint)(const struct fwnode_handle___215 *, struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*graph_get_remote_endpoint)(const struct fwnode_handle___215 *);
	struct fwnode_handle___215 * (*graph_get_port_parent)(struct fwnode_handle___215 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___215 *, struct fwnode_endpoint___215 *);
	int (*add_links)(struct fwnode_handle___215 *);
};

struct fwnode_endpoint___215 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___215 *local_fwnode;
};

struct fwnode_reference_args___215 {
	struct fwnode_handle___215 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___226;

struct kernfs_elem_dir___226 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___226 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___226;

struct kernfs_root___226 {
	struct kernfs_node___226 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___226 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___226 {
	struct kernfs_node___226 *target_kn;
};

struct kernfs_ops___226;

struct kernfs_elem_attr___226 {
	const struct kernfs_ops___226 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___226 *notify_next;
};

struct kernfs_node___226 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___226 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___226 dir;
		struct kernfs_elem_symlink___226 symlink;
		struct kernfs_elem_attr___226 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___226;

struct kernfs_ops___226 {
	int (*open)(struct kernfs_open_file___226 *);
	void (*release)(struct kernfs_open_file___226 *);
	int (*seq_show)(struct seq_file___213 *, void *);
	void * (*seq_start)(struct seq_file___213 *, loff_t *);
	void * (*seq_next)(struct seq_file___213 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___213 *, void *);
	ssize_t (*read)(struct kernfs_open_file___226 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___226 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___226 *, struct poll_table_struct___161 *);
	int (*mmap)(struct kernfs_open_file___226 *, struct vm_area_struct___243 *);
};

struct kernfs_syscall_ops___226 {
	int (*show_options)(struct seq_file___213 *, struct kernfs_root___226 *);
	int (*mkdir)(struct kernfs_node___226 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___226 *);
	int (*rename)(struct kernfs_node___226 *, struct kernfs_node___226 *, const char *);
	int (*show_path)(struct seq_file___213 *, struct kernfs_node___226 *, struct kernfs_root___226 *);
};

struct kernfs_open_file___226 {
	struct kernfs_node___226 *kn;
	struct file___238 *file;
	struct seq_file___213 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___233 *vm_ops;
};

struct sock___37;

struct kobj_ns_type_operations___36 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___37 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___52 *net;
} possible_net_t___47;

struct proto___36;

struct sock_common___36 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___36 *skc_prot;
	possible_net_t___47 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___37 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___48;

struct sk_buff_head___47 {
	struct sk_buff___48 *next;
	struct sk_buff___48 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___36 {
	struct cgroup___165 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___36;

struct socket_wq___37;

struct xfrm_policy___2;

struct dst_entry___36;

struct socket___38;

struct net_device___49;

struct sock_reuseport___7;

struct sock___37 {
	struct sock_common___36 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___47 sk_error_queue;
	struct sk_buff___48 *sk_rx_skb_cache;
	struct sk_buff_head___47 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___48 *head;
		struct sk_buff___48 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___36 *sk_filter;
	union {
		struct socket_wq___37 *sk_wq;
		struct socket_wq___37 *sk_wq_raw;
	};
	struct xfrm_policy___2 *sk_policy[2];
	struct dst_entry___36 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___36 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___48 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___48 *sk_tx_skb_cache;
	struct sk_buff_head___47 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___243 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___36 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___215 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___38 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___36 sk_cgrp_data;
	struct mem_cgroup___105 *sk_memcg;
	void (*sk_state_change)(struct sock___37 *);
	void (*sk_data_ready)(struct sock___37 *);
	void (*sk_write_space)(struct sock___37 *);
	void (*sk_error_report)(struct sock___37 *);
	int (*sk_backlog_rcv)(struct sock___37 *, struct sk_buff___48 *);
	struct sk_buff___48 * (*sk_validate_xmit_skb)(struct sock___37 *, struct net_device___49 *, struct sk_buff___48 *);
	void (*sk_destruct)(struct sock___37 *);
	struct sock_reuseport___7 *sk_reuseport_cb;
	struct bpf_local_storage___7 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___226;

struct attribute_group___226 {
	const char *name;
	umode_t (*is_visible)(struct kobject___226 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___226 *, struct bin_attribute___226 *, int);
	struct attribute **attrs;
	struct bin_attribute___226 **bin_attrs;
};

struct bin_attribute___226 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___238 * (*f_mapping)();
	ssize_t (*read)(struct file___238 *, struct kobject___226 *, struct bin_attribute___226 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___238 *, struct kobject___226 *, struct bin_attribute___226 *, char *, loff_t, size_t);
	int (*mmap)(struct file___238 *, struct kobject___226 *, struct bin_attribute___226 *, struct vm_area_struct___243 *);
};

struct sysfs_ops___226 {
	ssize_t (*show)(struct kobject___226 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___226 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___226;

struct kset___226 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___226 kobj;
	const struct kset_uevent_ops___226 *uevent_ops;
};

struct kobj_type___226 {
	void (*release)(struct kobject___226 *);
	const struct sysfs_ops___226 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___226 **default_groups;
	const struct kobj_ns_type_operations___36 * (*child_ns_type)(struct kobject___226 *);
	const void * (*namespace)(struct kobject___226 *);
	void (*get_ownership)(struct kobject___226 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___226 {
	int (* const filter)(struct kset___226 *, struct kobject___226 *);
	const char * (* const name)(struct kset___226 *, struct kobject___226 *);
	int (* const uevent)(struct kset___226 *, struct kobject___226 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___222 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___222 *);
	int (*get)(char *, const struct kernel_param___222 *);
	void (*free)(void *);
};

struct kparam_array___222;

struct kernel_param___222 {
	const char *name;
	struct module___222 *mod;
	const struct kernel_param_ops___222 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___222 *arr;
	};
};

struct kparam_array___222 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___222 *ops;
	void *elem;
};

struct module_attribute___222 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___222 *, struct module_kobject___223 *, char *);
	ssize_t (*store)(struct module_attribute___222 *, struct module_kobject___223 *, const char *, size_t);
	void (*setup)(struct module___222 *, const char *);
	int (*test)(struct module___222 *);
	void (*free)(struct module___222 *);
};

struct ip_ra_chain___18;

struct fib_rules_ops___36;

struct fqdir___52;

struct tcp_congestion_ops___6;

struct fib_notifier_ops___36;

struct netns_ipv4___52 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___18 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___36 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___37 *fibnl;
	struct sock___37 **icmp_sk;
	struct sock___37 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___37 **tcp_sk;
	struct fqdir___52 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___6 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___36 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___36 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___36 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___36;

struct dst_ops___52 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___52 *);
	struct dst_entry___36 * (*check)(struct dst_entry___36 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___36 *);
	unsigned int (*mtu)(const struct dst_entry___36 *);
	u32 * (*cow_metrics)(struct dst_entry___36 *, long unsigned int);
	void (*destroy)(struct dst_entry___36 *);
	void (*ifdown)(struct dst_entry___36 *, struct net_device___49 *, int);
	struct dst_entry___36 * (*negative_advice)(struct dst_entry___36 *);
	void (*link_failure)(struct sk_buff___48 *);
	void (*update_pmtu)(struct dst_entry___36 *, struct sock___37 *, struct sk_buff___48 *, u32, bool);
	void (*redirect)(struct dst_entry___36 *, struct sock___37 *, struct sk_buff___48 *);
	int (*local_out)(struct net___52 *, struct sock___37 *, struct sk_buff___48 *);
	struct neighbour___36 * (*neigh_lookup)(const struct dst_entry___36 *, struct sk_buff___48 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___36 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___3;

struct rt6_info___3;

struct fib6_table___3;

struct netns_ipv6___52 {
	struct dst_ops___52 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___52 *fqdir;
	struct fib6_info___3 *fib6_null_entry;
	struct rt6_info___3 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___3 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___3 *ip6_prohibit_entry;
	struct rt6_info___3 *ip6_blk_hole_entry;
	struct fib6_table___3 *fib6_local_tbl;
	struct fib_rules_ops___36 *fib6_rules_ops;
	struct sock___37 **icmp_sk;
	struct sock___37 *ndisc_sk;
	struct sock___37 *tcp_sk;
	struct sock___37 *igmp_sk;
	struct sock___37 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___36 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___36 *notifier_ops;
	struct fib_notifier_ops___36 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___52 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___52 *fqdir;
};

struct netns_sctp___36 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___37 *ctl_sock;
	struct sock___37 *udp4_sock;
	struct sock___37 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___43;

struct netns_bpf___43 {
	struct bpf_prog_array___43 *run_array[2];
	struct bpf_prog___43 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___52 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___37 *nlsk;
	struct sock___37 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___52 xfrm4_dst_ops;
	struct dst_ops___52 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___52 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___37 *rtnl;
	struct sock___37 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___49 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___52 ipv4;
	struct netns_ipv6___52 ipv6;
	struct netns_ieee802154_lowpan___52 ieee802154_lowpan;
	struct netns_sctp___36 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___47 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___43 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___52 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___37 *crypto_nlsk;
	struct sock___37 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___165 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___165 *root_cset;
};

struct linger {
	int l_onoff;
	int l_linger;
};

struct msghdr___38 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___158 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___238 *msg_iocb;
};

struct cmsghdr {
	__kernel_size_t cmsg_len;
	int cmsg_level;
	int cmsg_type;
};

struct ucred {
	__u32 pid;
	__u32 uid;
	__u32 gid;
};

struct socket_wq___37 {
	wait_queue_head_t wait;
	struct fasync_struct___238 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___37;

struct socket___38 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___238 *file;
	struct sock___37 *sk;
	const struct proto_ops___37 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___37 wq;
};

typedef int (*sk_read_actor_t___36)(read_descriptor_t *, struct sk_buff___48 *, unsigned int, size_t);

struct proto_ops___37 {
	int family;
	struct module___222 *owner;
	int (*release)(struct socket___38 *);
	int (*bind)(struct socket___38 *, struct sockaddr *, int);
	int (*connect)(struct socket___38 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___38 *, struct socket___38 *);
	int (*accept)(struct socket___38 *, struct socket___38 *, int, bool);
	int (*getname)(struct socket___38 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___238 *, struct socket___38 *, struct poll_table_struct___161 *);
	int (*ioctl)(struct socket___38 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___38 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___38 *, void *, bool, bool);
	int (*listen)(struct socket___38 *, int);
	int (*shutdown)(struct socket___38 *, int);
	int (*setsockopt)(struct socket___38 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___38 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___213 *, struct socket___38 *);
	int (*sendmsg)(struct socket___38 *, struct msghdr___38 *, size_t);
	int (*recvmsg)(struct socket___38 *, struct msghdr___38 *, size_t, int);
	int (*mmap)(struct file___238 *, struct socket___38 *, struct vm_area_struct___243 *);
	ssize_t (*sendpage)(struct socket___38 *, struct page___243 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___38 *, loff_t *, struct pipe_inode_info___79 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___37 *, int);
	int (*peek_len)(struct socket___38 *);
	int (*read_sock)(struct sock___37 *, read_descriptor_t *, sk_read_actor_t___36);
	int (*sendpage_locked)(struct sock___37 *, struct page___243 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___37 *, struct msghdr___38 *, size_t);
	int (*set_rcvlowat)(struct sock___37 *, int);
};

struct sk_buff___48 {
	union {
		struct {
			struct sk_buff___48 *next;
			struct sk_buff___48 *prev;
			union {
				struct net_device___49 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___37 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___48 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___219 {
	int (*prepare)(struct device___219 *);
	void (*complete)(struct device___219 *);
	int (*suspend)(struct device___219 *);
	int (*resume)(struct device___219 *);
	int (*freeze)(struct device___219 *);
	int (*thaw)(struct device___219 *);
	int (*poweroff)(struct device___219 *);
	int (*restore)(struct device___219 *);
	int (*suspend_late)(struct device___219 *);
	int (*resume_early)(struct device___219 *);
	int (*freeze_late)(struct device___219 *);
	int (*thaw_early)(struct device___219 *);
	int (*poweroff_late)(struct device___219 *);
	int (*restore_early)(struct device___219 *);
	int (*suspend_noirq)(struct device___219 *);
	int (*resume_noirq)(struct device___219 *);
	int (*freeze_noirq)(struct device___219 *);
	int (*thaw_noirq)(struct device___219 *);
	int (*poweroff_noirq)(struct device___219 *);
	int (*restore_noirq)(struct device___219 *);
	int (*runtime_suspend)(struct device___219 *);
	int (*runtime_resume)(struct device___219 *);
	int (*runtime_idle)(struct device___219 *);
};

struct wakeup_source___219 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___219 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___219 {
	struct dev_pm_ops___219 ops;
	int (*start)(struct device___219 *);
	void (*detach)(struct device___219 *, bool);
	int (*activate)(struct device___219 *);
	void (*sync)(struct device___219 *);
	void (*dismiss)(struct device___219 *);
};

struct bus_type___219 {
	const char *name;
	const char *dev_name;
	struct device___219 *dev_root;
	const struct attribute_group___226 **bus_groups;
	const struct attribute_group___226 **dev_groups;
	const struct attribute_group___226 **drv_groups;
	int (*match)(struct device___219 *, struct device_driver___219 *);
	int (*uevent)(struct device___219 *, struct kobj_uevent_env *);
	int (*probe)(struct device___219 *);
	void (*sync_state)(struct device___219 *);
	void (*remove)(struct device___219 *);
	void (*shutdown)(struct device___219 *);
	int (*online)(struct device___219 *);
	int (*offline)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	int (*num_vf)(struct device___219 *);
	int (*dma_configure)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___219 {
	const char *name;
	struct bus_type___219 *bus;
	struct module___222 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___219 *);
	void (*sync_state)(struct device___219 *);
	int (*remove)(struct device___219 *);
	void (*shutdown)(struct device___219 *);
	int (*suspend)(struct device___219 *, pm_message_t);
	int (*resume)(struct device___219 *);
	const struct attribute_group___226 **groups;
	const struct attribute_group___226 **dev_groups;
	const struct dev_pm_ops___219 *pm;
	void (*coredump)(struct device___219 *);
	struct driver_private *p;
};

struct device_type___219 {
	const char *name;
	const struct attribute_group___226 **groups;
	int (*uevent)(struct device___219 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___219 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___219 *);
	const struct dev_pm_ops___219 *pm;
};

struct class___219 {
	const char *name;
	struct module___222 *owner;
	const struct attribute_group___226 **class_groups;
	const struct attribute_group___226 **dev_groups;
	struct kobject___226 *dev_kobj;
	int (*dev_uevent)(struct device___219 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___219 *, umode_t *);
	void (*class_release)(struct class___219 *);
	void (*dev_release)(struct device___219 *);
	int (*shutdown_pre)(struct device___219 *);
	const struct kobj_ns_type_operations___36 *ns_type;
	const void * (*namespace)(struct device___219 *);
	void (*get_ownership)(struct device___219 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___219 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___79;

struct pipe_buffer___79 {
	struct page___243 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___79 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___79 {
	int (*confirm)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
	void (*release)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
	bool (*try_steal)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
	bool (*get)(struct pipe_inode_info___79 *, struct pipe_buffer___79 *);
};

typedef rx_handler_result_t rx_handler_func_t___47(struct sk_buff___48 **);

struct bpf_xdp_entity___43 {
	struct bpf_prog___43 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___47;

struct net_device_ops___47;

struct ethtool_ops___22;

struct l3mdev_ops___36;

struct ndisc_ops___24;

struct xfrmdev_ops___47;

struct header_ops___47;

struct inet6_dev___24;

struct netdev_rx_queue___47;

struct mini_Qdisc___43;

struct netdev_queue___47;

struct Qdisc___43;

struct rtnl_link_ops___43;

struct dcbnl_rtnl_ops___47;

struct net_device___49 {
	char name[16];
	struct netdev_name_node___47 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___47 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___22 *ethtool_ops;
	const struct l3mdev_ops___36 *l3mdev_ops;
	const struct ndisc_ops___24 *ndisc_ops;
	const struct xfrmdev_ops___47 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___47 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___226 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___24 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___47 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___43 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___47 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___43 *miniq_ingress;
	struct netdev_queue___47 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___47 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___43 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___43 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___47 = 0,
		NETREG_REGISTERED___47 = 1,
		NETREG_UNREGISTERING___47 = 2,
		NETREG_UNREGISTERED___47 = 3,
		NETREG_RELEASED___47 = 4,
		NETREG_DUMMY___47 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___47 = 0,
		RTNL_LINK_INITIALIZING___47 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___49 *);
	struct netpoll_info *npinfo;
	possible_net_t___47 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___219 dev;
	const struct attribute_group___226 *sysfs_groups[4];
	const struct attribute_group___226 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___43 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___47 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___43 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___155 skb_frag_t___8;

struct ubuf_info___2 {
	void (*callback)(struct sk_buff___48 *, struct ubuf_info___2 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___8 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___48 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___8 frags[17];
};

struct prot_inuse {
	int val[64];
};

struct inet_frags___52;

struct fqdir___52 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___52 *f;
	struct net___52 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___52;

struct inet_frags___52 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___52 *, const void *);
	void (*destructor)(struct inet_frag_queue___52 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___52 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___48 *fragments_tail;
	struct sk_buff___48 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___52 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___18 {
	struct ip_ra_chain___18 *next;
	struct sock___37 *sk;
	union {
		void (*destructor)(struct sock___37 *);
		struct sock___37 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___36;

struct fib_lookup_arg___36;

struct fib_rules_ops___36 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___36 *, struct flowi *, int, struct fib_lookup_arg___36 *);
	bool (*suppress)(struct fib_rule___36 *, int, struct fib_lookup_arg___36 *);
	int (*match)(struct fib_rule___36 *, struct flowi *, int);
	int (*configure)(struct fib_rule___36 *, struct sk_buff___48 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___36 *);
	int (*compare)(struct fib_rule___36 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___36 *, struct sk_buff___48 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___36 *);
	void (*flush_cache)(struct fib_rules_ops___36 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___222 *owner;
	struct net___52 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___6 {
	u32 (*ssthresh)(struct sock___37 *);
	void (*cong_avoid)(struct sock___37 *, u32, u32);
	void (*set_state)(struct sock___37 *, u8);
	void (*cwnd_event)(struct sock___37 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___37 *, u32);
	void (*pkts_acked)(struct sock___37 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___37 *);
	void (*cong_control)(struct sock___37 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___37 *);
	u32 (*sndbuf_expand)(struct sock___37 *);
	size_t (*get_info)(struct sock___37 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___222 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___37 *);
	void (*release)(struct sock___37 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___36 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___52 *);
	int (*fib_dump)(struct net___52 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___222 *owner;
	struct callback_head rcu;
};

struct xfrm_state___2;

struct lwtunnel_state___19;

struct dst_entry___36 {
	struct net_device___49 *dev;
	struct dst_ops___52 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___2 *xfrm;
	int (*input)(struct sk_buff___48 *);
	int (*output)(struct net___52 *, struct sock___37 *, struct sk_buff___48 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___19 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___36;

struct neigh_parms___36;

struct neigh_ops___36;

struct neighbour___36 {
	struct neighbour___36 *next;
	struct neigh_table___36 *tbl;
	struct neigh_parms___36 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___47 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___36 *, struct sk_buff___48 *);
	const struct neigh_ops___36 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___49 *dev;
	u8 primary_key[0];
};

struct rtable___3;

struct fnhe_hash_bucket___3;

struct fib_nh_common___3 {
	struct net_device___49 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___19 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___3 **nhc_pcpu_rth_output;
	struct rtable___3 *nhc_rth_input;
	struct fnhe_hash_bucket___3 *nhc_exceptions;
};

struct fib6_nh___3 {
	struct fib_nh_common___3 nh_common;
	long unsigned int last_probe;
	struct rt6_info___3 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___3;

struct fib6_info___3 {
	struct fib6_table___3 *fib6_table;
	struct fib6_info___3 *fib6_next;
	struct fib6_node___3 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___3 fib6_nh[0];
};

struct rt6_info___3 {
	struct dst_entry___36 dst;
	struct fib6_info___3 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___24 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___3 {
	struct fib6_node___3 *parent;
	struct fib6_node___3 *left;
	struct fib6_node___3 *right;
	struct fib6_node___3 *subtree;
	struct fib6_info___3 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___3 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___3 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___3 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___43 {
	struct bpf_prog___43 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___43 {
	struct callback_head rcu;
	struct bpf_prog_array_item___43 items[0];
};

struct bpf_prog_aux___50;

struct bpf_prog___43 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___50 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___213 {
	void * (*start)(struct seq_file___213 *, loff_t *);
	void (*stop)(struct seq_file___213 *, void *);
	void * (*next)(struct seq_file___213 *, void *, loff_t *);
	int (*show)(struct seq_file___213 *, void *);
};

struct seq_net_private___2 {
	struct net___52 *net;
};

struct pernet_operations___8 {
	struct list_head list;
	int (*init)(struct net___52 *);
	void (*pre_exit)(struct net___52 *);
	void (*exit)(struct net___52 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___47 {
	int (*ieee_getets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___49 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___49 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___49 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___49 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___49 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___49 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___49 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___49 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___49 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___49 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___49 *);
	u8 (*setstate)(struct net_device___49 *, u8);
	void (*getpermhwaddr)(struct net_device___49 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___49 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___49 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___49 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___49 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___49 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___49 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___49 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___49 *, int, u8 *);
	void (*setpfccfg)(struct net_device___49 *, int, u8);
	void (*getpfccfg)(struct net_device___49 *, int, u8 *);
	u8 (*setall)(struct net_device___49 *);
	u8 (*getcap)(struct net_device___49 *, int, u8 *);
	int (*getnumtcs)(struct net_device___49 *, int, u8 *);
	int (*setnumtcs)(struct net_device___49 *, int, u8);
	u8 (*getpfcstate)(struct net_device___49 *);
	void (*setpfcstate)(struct net_device___49 *, u8);
	void (*getbcncfg)(struct net_device___49 *, int, u32 *);
	void (*setbcncfg)(struct net_device___49 *, int, u32);
	void (*getbcnrp)(struct net_device___49 *, int, u8 *);
	void (*setbcnrp)(struct net_device___49 *, int, u8);
	int (*setapp)(struct net_device___49 *, u8, u16, u8);
	int (*getapp)(struct net_device___49 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___49 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___49 *, int, u8);
	u8 (*getdcbx)(struct net_device___49 *);
	u8 (*setdcbx)(struct net_device___49 *, u8);
	int (*peer_getappinfo)(struct net_device___49 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___49 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___49 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___49 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___49 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___49 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___50;

typedef int (*bpf_iter_init_seq_priv_t___49)(void *, struct bpf_iter_aux_info___50 *);

struct bpf_map___50;

struct bpf_iter_aux_info___50 {
	struct bpf_map___50 *map;
};

struct bpf_iter_seq_info___49 {
	const struct seq_operations___213 *seq_ops;
	bpf_iter_init_seq_priv_t___49 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_local_storage_map___7;

struct bpf_map_ops___49 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___50 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___50 *, struct file___238 *);
	void (*map_free)(struct bpf_map___50 *);
	int (*map_get_next_key)(struct bpf_map___50 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___50 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___50 *, void *);
	int (*map_lookup_batch)(struct bpf_map___50 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___50 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___50 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___50 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___50 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___50 *, void *);
	int (*map_update_elem)(struct bpf_map___50 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___50 *, void *);
	int (*map_push_elem)(struct bpf_map___50 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___50 *, void *);
	int (*map_peek_elem)(struct bpf_map___50 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___50 *, struct file___238 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___50 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___50 *, void *, struct seq_file___213 *);
	int (*map_check_btf)(const struct bpf_map___50 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___50 *, struct bpf_prog_aux___50 *);
	void (*map_poke_untrack)(struct bpf_map___50 *, struct bpf_prog_aux___50 *);
	void (*map_poke_run)(struct bpf_map___50 *, u32, struct bpf_prog___43 *, struct bpf_prog___43 *);
	int (*map_direct_value_addr)(const struct bpf_map___50 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___50 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___50 *, struct vm_area_struct___243 *);
	__poll_t (*map_poll)(struct bpf_map___50 *, struct file___238 *, struct poll_table_struct___161 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___7 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___7 *, void *, u32);
	struct bpf_local_storage___7 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___50 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___50 *, const struct bpf_map___50 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___50 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___49 *iter_seq_info;
};

struct bpf_map___50 {
	const struct bpf_map_ops___49 *ops;
	struct bpf_map___50 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___105 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___49;

struct bpf_jit_poke_descriptor___49;

struct bpf_prog_ops___43;

struct btf_mod_pair___49;

struct bpf_prog_offload___47;

struct bpf_prog_aux___50 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___43 *dst_prog;
	struct bpf_trampoline___49 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___43 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___49 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___43 *ops;
	struct bpf_map___50 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___49 *used_btfs;
	struct bpf_prog___43 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___50 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___47 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_local_storage_map___7 {
	struct bpf_map___50 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___47;

struct bpf_map_dev_ops___47 {
	int (*map_get_next_key)(struct bpf_offloaded_map___47 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___47 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___47 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___47 *, void *);
};

struct bpf_offloaded_map___47 {
	struct bpf_map___50 map;
	struct net_device___49 *netdev;
	const struct bpf_map_dev_ops___47 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___43 {
	int (*test_run)(struct bpf_prog___43 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___47 {
	struct bpf_prog___43 *prog;
	struct net_device___49 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___49 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___43 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___222 *mod;
};

struct bpf_jit_poke_descriptor___49 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___50 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___49 {
	struct btf *btf;
	struct module___222 *module;
};

struct cftype___165;

struct cgroup_subsys___165 {
	struct cgroup_subsys_state___165 * (*css_alloc)(struct cgroup_subsys_state___165 *);
	int (*css_online)(struct cgroup_subsys_state___165 *);
	void (*css_offline)(struct cgroup_subsys_state___165 *);
	void (*css_released)(struct cgroup_subsys_state___165 *);
	void (*css_free)(struct cgroup_subsys_state___165 *);
	void (*css_reset)(struct cgroup_subsys_state___165 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___165 *, int);
	int (*css_extra_stat_show)(struct seq_file___213 *, struct cgroup_subsys_state___165 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___245 *, struct css_set___165 *);
	void (*cancel_fork)(struct task_struct___245 *, struct css_set___165 *);
	void (*fork)(struct task_struct___245 *);
	void (*exit)(struct task_struct___245 *);
	void (*release)(struct task_struct___245 *);
	void (*bind)(struct cgroup_subsys_state___165 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___165 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___165 *dfl_cftypes;
	struct cftype___165 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___165 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___165 *updated_children;
	struct cgroup___165 *updated_next;
};

struct cgroup_root___165 {
	struct kernfs_root___226 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___165 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___165 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___165 *ss;
	struct list_head node;
	struct kernfs_ops___226 *kf_ops;
	int (*open)(struct kernfs_open_file___226 *);
	void (*release)(struct kernfs_open_file___226 *);
	u64 (*read_u64)(struct cgroup_subsys_state___165 *, struct cftype___165 *);
	s64 (*read_s64)(struct cgroup_subsys_state___165 *, struct cftype___165 *);
	int (*seq_show)(struct seq_file___213 *, void *);
	void * (*seq_start)(struct seq_file___213 *, loff_t *);
	void * (*seq_next)(struct seq_file___213 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___213 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___165 *, struct cftype___165 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___165 *, struct cftype___165 *, s64);
	ssize_t (*write)(struct kernfs_open_file___226 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___226 *, struct poll_table_struct___161 *);
};

struct xdp_rxq_info___47 {
	struct net_device___49 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___47 {
	struct net_device___49 *dev;
};

struct xdp_buff___47 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___47 *rxq;
	struct xdp_txq_info___47 *txq;
	u32 frame_sz;
};

struct xdp_frame___47 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___49 *dev_rx;
};

struct netlink_callback___47 {
	struct sk_buff___48 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___48 *, struct netlink_callback___47 *);
	int (*done)(struct netlink_callback___47 *);
	void *data;
	struct module___222 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___47 {
	int (*create)(struct sk_buff___48 *, struct net_device___49 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___48 *, unsigned char *);
	int (*cache)(const struct neighbour___36 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___49 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___48 *);
};

struct napi_struct___6 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___6 *, int);
	int poll_owner;
	struct net_device___49 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___48 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___245 *thread;
};

struct netdev_queue___47 {
	struct net_device___49 *dev;
	struct Qdisc___43 *qdisc;
	struct Qdisc___43 *qdisc_sleeping;
	struct kobject___226 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___49 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___43 {
	struct sk_buff___48 *head;
	struct sk_buff___48 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___43;

struct Qdisc___43 {
	int (*enqueue)(struct sk_buff___48 *, struct Qdisc___43 *, struct sk_buff___48 **);
	struct sk_buff___48 * (*dequeue)(struct Qdisc___43 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___43 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___47 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___47 gso_skb;
	struct qdisc_skb_head___43 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___43 *next_sched;
	struct sk_buff_head___47 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___47 {
	struct xdp_rxq_info___47 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___226 kobj;
	struct net_device___49 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___47 {
	enum net_device_path_type type;
	const struct net_device___49 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___47 = 0,
				DEV_PATH_BR_VLAN_TAG___47 = 1,
				DEV_PATH_BR_VLAN_UNTAG___47 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___47 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___47 {
	const struct net_device___49 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___47 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___43 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___47 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___47 {
	int (*xdo_dev_state_add)(struct xfrm_state___2 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___2 *);
	void (*xdo_dev_state_free)(struct xfrm_state___2 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___48 *, struct xfrm_state___2 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___2 *);
};

struct xfrm_state_offload___2 {
	struct net_device___49 *dev;
	struct net_device___49 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___2;

struct xfrm_type_offload___2;

struct xfrm_state___2 {
	possible_net_t___47 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___37 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___2 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___2 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___243 xfrag;
	const struct xfrm_type___2 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___2 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___47 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___49 *dev;
	const char *name;
};

struct net_device_ops___47 {
	int (*ndo_init)(struct net_device___49 *);
	void (*ndo_uninit)(struct net_device___49 *);
	int (*ndo_open)(struct net_device___49 *);
	int (*ndo_stop)(struct net_device___49 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___48 *, struct net_device___49 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___48 *, struct net_device___49 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___49 *, struct sk_buff___48 *, struct net_device___49 *);
	void (*ndo_change_rx_flags)(struct net_device___49 *, int);
	void (*ndo_set_rx_mode)(struct net_device___49 *);
	int (*ndo_set_mac_address)(struct net_device___49 *, void *);
	int (*ndo_validate_addr)(struct net_device___49 *);
	int (*ndo_do_ioctl)(struct net_device___49 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___49 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___49 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___49 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___49 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___49 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___49 *, int);
	int (*ndo_neigh_setup)(struct net_device___49 *, struct neigh_parms___36 *);
	void (*ndo_tx_timeout)(struct net_device___49 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___49 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___49 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___49 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___49 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___49 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___49 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___49 *);
	int (*ndo_netpoll_setup)(struct net_device___49 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___49 *);
	int (*ndo_set_vf_mac)(struct net_device___49 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___49 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___49 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___49 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___49 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___49 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___49 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___49 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___49 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___49 *, int, struct sk_buff___48 *);
	int (*ndo_get_vf_guid)(struct net_device___49 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___49 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___49 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___49 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___49 *);
	int (*ndo_fcoe_disable)(struct net_device___49 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___49 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___49 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___49 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___49 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___49 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___49 *, const struct sk_buff___48 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___49 *, struct net_device___49 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___49 *, struct net_device___49 *);
	struct net_device___49 * (*ndo_get_xmit_slave)(struct net_device___49 *, struct sk_buff___48 *, bool);
	struct net_device___49 * (*ndo_sk_get_lower_dev)(struct net_device___49 *, struct sock___37 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___49 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___49 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___49 *, struct neighbour___36 *);
	void (*ndo_neigh_destroy)(struct net_device___49 *, struct neighbour___36 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___48 *, struct netlink_callback___47 *, struct net_device___49 *, struct net_device___49 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___48 *, struct nlattr **, struct net_device___49 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___49 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___48 *, u32, u32, struct net_device___49 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___49 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___49 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___49 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___49 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___49 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___49 *, struct net_device___49 *);
	void (*ndo_dfwd_del_station)(struct net_device___49 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___49 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___49 *);
	int (*ndo_change_proto_down)(struct net_device___49 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___49 *, struct sk_buff___48 *);
	void (*ndo_set_rx_headroom)(struct net_device___49 *, int);
	int (*ndo_bpf)(struct net_device___49 *, struct netdev_bpf___47 *);
	int (*ndo_xdp_xmit)(struct net_device___49 *, int, struct xdp_frame___47 **, u32);
	struct net_device___49 * (*ndo_xdp_get_xmit_slave)(struct net_device___49 *, struct xdp_buff___47 *);
	int (*ndo_xsk_wakeup)(struct net_device___49 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___49 *);
	int (*ndo_tunnel_ctl)(struct net_device___49 *, struct ip_tunnel_parm *, int);
	struct net_device___49 * (*ndo_get_peer_dev)(struct net_device___49 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___47 *, struct net_device_path___47 *);
};

struct neigh_parms___36 {
	possible_net_t___47 net;
	struct net_device___49 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___36 *);
	struct neigh_table___36 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___22 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___49 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___49 *);
	void (*get_regs)(struct net_device___49 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___49 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___49 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___49 *);
	void (*set_msglevel)(struct net_device___49 *, u32);
	int (*nway_reset)(struct net_device___49 *);
	u32 (*get_link)(struct net_device___49 *);
	int (*get_link_ext_state)(struct net_device___49 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___49 *);
	int (*get_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___49 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___49 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___49 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___49 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___49 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___49 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___49 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___49 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___49 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___49 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___49 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___49 *);
	void (*complete)(struct net_device___49 *);
	u32 (*get_priv_flags)(struct net_device___49 *);
	int (*set_priv_flags)(struct net_device___49 *, u32);
	int (*get_sset_count)(struct net_device___49 *, int);
	int (*get_rxnfc)(struct net_device___49 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___49 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___49 *, struct ethtool_flash *);
	int (*reset)(struct net_device___49 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___49 *);
	u32 (*get_rxfh_indir_size)(struct net_device___49 *);
	int (*get_rxfh)(struct net_device___49 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___49 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___49 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___49 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___49 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___49 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___49 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___49 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___49 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___49 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___49 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___49 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___49 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___49 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___49 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___49 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___49 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___49 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___49 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___49 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___49 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___49 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___49 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___49 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___49 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___49 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___49 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___49 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___49 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___49 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___49 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___36 {
	u32 (*l3mdev_fib_table)(const struct net_device___49 *);
	struct sk_buff___48 * (*l3mdev_l3_rcv)(struct net_device___49 *, struct sk_buff___48 *, u16);
	struct sk_buff___48 * (*l3mdev_l3_out)(struct net_device___49 *, struct sock___37 *, struct sk_buff___48 *, u16);
	struct dst_entry___36 * (*l3mdev_link_scope_lookup)(const struct net_device___49 *, struct flowi6 *);
};

struct ndisc_ops___24 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___49 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___49 *, struct neighbour___36 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___49 *, u8, struct neighbour___36 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___49 *, struct sk_buff___48 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___52 *, struct net_device___49 *, const struct prefix_info *, struct inet6_dev___24 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___24;

struct ifacaddr6___3;

struct inet6_dev___24 {
	struct net_device___49 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___24 *mc_list;
	struct ifmcaddr6___24 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___47 mc_query_queue;
	struct sk_buff_head___47 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___3 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___36 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___43;

struct tcf_block___43;

struct mini_Qdisc___43 {
	struct tcf_proto___43 *filter_list;
	struct tcf_block___43 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___43 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___49 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___49 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___52 *, struct net_device___49 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___49 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___49 *, struct list_head *);
	size_t (*get_size)(const struct net_device___49 *);
	int (*fill_info)(struct sk_buff___48 *, const struct net_device___49 *);
	size_t (*get_xstats_size)(const struct net_device___49 *);
	int (*fill_xstats)(struct sk_buff___48 *, const struct net_device___49 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___49 *, struct net_device___49 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___49 *, const struct net_device___49 *);
	int (*fill_slave_info)(struct sk_buff___48 *, const struct net_device___49 *, const struct net_device___49 *);
	struct net___52 * (*get_link_net)(const struct net_device___49 *);
	size_t (*get_linkxstats_size)(const struct net_device___49 *, int);
	int (*fill_linkxstats)(struct sk_buff___48 *, const struct net_device___49 *, int *, int);
};

struct sd_flow_limit {
	u64 count;
	unsigned int num_buckets;
	unsigned int history_head;
	u16 history[128];
	u8 buckets[0];
};

struct softnet_data {
	struct list_head poll_list;
	struct sk_buff_head___47 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___43 *output_queue;
	struct Qdisc___43 **output_queue_tailp;
	struct sk_buff___48 *completion_queue;
	struct sk_buff_head___47 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___47 input_pkt_queue;
	struct napi_struct___6 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device_operations___131;

struct gendisk___134 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___134 *part0;
	const struct block_device_operations___131 *fops;
	struct request_queue___131 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___117 *bdi;
	struct kobject___226 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___226 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___131 {
	struct bio___131 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___155 *bip_vec;
	struct bio_vec___155 bip_inline_vecs[0];
};

struct blkcg___119;

struct blkg_policy_data___119;

struct blkcg_gq___119 {
	struct request_queue___131 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___119 *blkcg;
	struct blkcg_gq___119 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___119 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___131 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___131(struct request___131 *);

typedef void integrity_complete_fn___131(struct request___131 *, unsigned int);

struct blk_integrity_profile___131 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___131 *prepare_fn;
	integrity_complete_fn___131 *complete_fn;
	const char *name;
};

struct block_device_operations___131 {
	blk_qc_t (*submit_bio)(struct bio___131 *);
	int (*open)(struct block_device___134 *, fmode_t);
	void (*release)(struct gendisk___134 *, fmode_t);
	int (*rw_page)(struct block_device___134 *, sector_t, struct page___243 *, unsigned int);
	int (*ioctl)(struct block_device___134 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___134 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___134 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___134 *);
	int (*getgeo)(struct block_device___134 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___134 *, bool);
	void (*swap_slot_free_notify)(struct block_device___134 *, long unsigned int);
	int (*report_zones)(struct gendisk___134 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___134 *, umode_t *);
	struct module___222 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___134 *, sector_t *);
};

typedef void rq_end_io_fn___131(struct request___131 *, blk_status_t);

struct request___131 {
	struct request_queue___131 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___126 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___131 *bio;
	struct bio___131 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___155 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___131 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___131 *saved_end_io;
		} flush;
	};
	struct gendisk___134 *rq_disk;
	struct block_device___134 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___131 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___126 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___131 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___226 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___238 *debugfs_dir;
	struct dentry___238 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___131;

struct elevator_mq_ops___131 {
	int (*init_sched)(struct request_queue___131 *, struct elevator_type___131 *);
	void (*exit_sched)(struct elevator_queue___131 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___126 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___126 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___126 *);
	bool (*allow_merge)(struct request_queue___131 *, struct request___131 *, struct bio___131 *);
	bool (*bio_merge)(struct request_queue___131 *, struct bio___131 *, unsigned int);
	int (*request_merge)(struct request_queue___131 *, struct request___131 **, struct bio___131 *);
	void (*request_merged)(struct request_queue___131 *, struct request___131 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___131 *, struct request___131 *, struct request___131 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___131 *);
	void (*finish_request)(struct request___131 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___126 *, struct list_head *, bool);
	struct request___131 * (*dispatch_request)(struct blk_mq_hw_ctx___126 *);
	bool (*has_work)(struct blk_mq_hw_ctx___126 *);
	void (*completed_request)(struct request___131 *, u64);
	void (*requeue_request)(struct request___131 *);
	struct request___131 * (*former_request)(struct request_queue___131 *, struct request___131 *);
	struct request___131 * (*next_request)(struct request_queue___131 *, struct request___131 *);
	void (*init_icq)(struct io_cq___131 *);
	void (*exit_icq)(struct io_cq___131 *);
};

struct elv_fs_entry___131;

struct elevator_type___131 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___131 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___131 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___222 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___131 {
	struct elevator_type___131 *type;
	void *elevator_data;
	struct kobject___226 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___131 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___131 *, char *);
	ssize_t (*store)(struct elevator_queue___131 *, const char *, size_t);
};

struct blk_mq_queue_data___126;

struct blk_mq_ops___126 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___126 *, const struct blk_mq_queue_data___126 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___126 *);
	int (*get_budget)(struct request_queue___131 *);
	void (*put_budget)(struct request_queue___131 *, int);
	void (*set_rq_budget_token)(struct request___131 *, int);
	int (*get_rq_budget_token)(struct request___131 *);
	enum blk_eh_timer_return (*timeout)(struct request___131 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___126 *);
	void (*complete)(struct request___131 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___126 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___126 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___126 *, struct request___131 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___126 *, struct request___131 *, unsigned int);
	void (*initialize_rq_fn)(struct request___131 *);
	void (*cleanup_rq)(struct request___131 *);
	bool (*busy)(struct request_queue___131 *);
	int (*map_queues)(struct blk_mq_tag_set___126 *);
	void (*show_rq)(struct seq_file___213 *, struct request___131 *);
};

struct blk_mq_tag_set___126 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___126 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___126 {
	struct request___131 *rq;
	bool last;
};

struct blkcg_policy_data___119;

struct blkcg___119 {
	struct cgroup_subsys_state___165 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___119 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___119 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___119 {
	struct blkcg___119 *blkcg;
	int plid;
};

struct blkg_policy_data___119 {
	struct blkcg_gq___119 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___105 {
	struct mem_cgroup___105 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___105 {
	struct lruvec___113 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___105 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___105 *memcg;
};

struct obj_cgroup___105 {
	struct percpu_ref refcnt;
	struct mem_cgroup___105 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___43 {
	spinlock_t *lock;
	struct sk_buff___48 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___43;

struct Qdisc_ops___43 {
	struct Qdisc_ops___43 *next;
	const struct Qdisc_class_ops___43 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___48 *, struct Qdisc___43 *, struct sk_buff___48 **);
	struct sk_buff___48 * (*dequeue)(struct Qdisc___43 *);
	struct sk_buff___48 * (*peek)(struct Qdisc___43 *);
	int (*init)(struct Qdisc___43 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___43 *);
	void (*destroy)(struct Qdisc___43 *);
	int (*change)(struct Qdisc___43 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___43 *);
	int (*change_tx_queue_len)(struct Qdisc___43 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___43 *, unsigned int);
	int (*dump)(struct Qdisc___43 *, struct sk_buff___48 *);
	int (*dump_stats)(struct Qdisc___43 *, struct gnet_dump___43 *);
	void (*ingress_block_set)(struct Qdisc___43 *, u32);
	void (*egress_block_set)(struct Qdisc___43 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___43 *);
	u32 (*egress_block_get)(struct Qdisc___43 *);
	struct module___222 *owner;
};

struct Qdisc_class_ops___43 {
	unsigned int flags;
	struct netdev_queue___47 * (*select_queue)(struct Qdisc___43 *, struct tcmsg *);
	int (*graft)(struct Qdisc___43 *, long unsigned int, struct Qdisc___43 *, struct Qdisc___43 **, struct netlink_ext_ack *);
	struct Qdisc___43 * (*leaf)(struct Qdisc___43 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___43 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___43 *, u32);
	int (*change)(struct Qdisc___43 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___43 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___43 *, struct qdisc_walker *);
	struct tcf_block___43 * (*tcf_block)(struct Qdisc___43 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___43 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___43 *, long unsigned int);
	int (*dump)(struct Qdisc___43 *, long unsigned int, struct sk_buff___48 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___43 *, long unsigned int, struct gnet_dump___43 *);
};

struct tcf_chain___43;

struct tcf_block___43 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___52 *net;
	struct Qdisc___43 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___43 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___43;

struct tcf_proto_ops___43;

struct tcf_proto___43 {
	struct tcf_proto___43 *next;
	void *root;
	int (*classify)(struct sk_buff___48 *, const struct tcf_proto___43 *, struct tcf_result___43 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___43 *ops;
	struct tcf_chain___43 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___43 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___43 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___43 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___48 *, const struct tcf_proto___43 *, struct tcf_result___43 *);
	int (*init)(struct tcf_proto___43 *);
	void (*destroy)(struct tcf_proto___43 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___43 *, u32);
	void (*put)(struct tcf_proto___43 *, void *);
	int (*change)(struct net___52 *, struct sk_buff___48 *, struct tcf_proto___43 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___43 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___43 *);
	void (*walk)(struct tcf_proto___43 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___43 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___43 *, void *);
	void (*hw_del)(struct tcf_proto___43 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___52 *, struct tcf_chain___43 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___52 *, struct tcf_proto___43 *, void *, struct sk_buff___48 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___52 *, struct tcf_proto___43 *, void *, struct sk_buff___48 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___48 *, struct net___52 *, void *);
	struct module___222 *owner;
	int flags;
};

struct tcf_chain___43 {
	struct mutex filter_chain_lock;
	struct tcf_proto___43 *filter_chain;
	struct list_head list;
	struct tcf_block___43 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___43 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___36 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___43 *prog;
};

struct pneigh_entry___36;

struct neigh_hash_table___36;

struct neigh_table___36 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___49 *, __u32 *);
	bool (*key_eq)(const struct neighbour___36 *, const void *);
	int (*constructor)(struct neighbour___36 *);
	int (*pconstructor)(struct pneigh_entry___36 *);
	void (*pdestructor)(struct pneigh_entry___36 *);
	void (*proxy_redo)(struct sk_buff___48 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___49 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___36 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___47 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___36 *nht;
	struct pneigh_entry___36 **phash_buckets;
};

struct neigh_ops___36 {
	int family;
	void (*solicit)(struct neighbour___36 *, struct sk_buff___48 *);
	void (*error_report)(struct neighbour___36 *, struct sk_buff___48 *);
	int (*output)(struct neighbour___36 *, struct sk_buff___48 *);
	int (*connected_output)(struct neighbour___36 *, struct sk_buff___48 *);
};

struct pneigh_entry___36 {
	struct pneigh_entry___36 *next;
	possible_net_t___47 net;
	struct net_device___49 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___36 {
	struct neighbour___36 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___19 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___52 *, struct sock___37 *, struct sk_buff___48 *);
	int (*orig_input)(struct sk_buff___48 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct so_timestamping {
	int flags;
	int bind_phc;
};

enum txtime_flags {
	SOF_TXTIME_DEADLINE_MODE = 1,
	SOF_TXTIME_REPORT_ERRORS = 2,
	SOF_TXTIME_FLAGS_LAST = 2,
	SOF_TXTIME_FLAGS_MASK = 3,
};

struct sock_txtime {
	__kernel_clockid_t clockid;
	__u32 flags;
};

struct fib_rule___36 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___36 *ctarget;
	struct net___52 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___36 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___36 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___26;

struct timewait_sock_ops___26;

struct proto___36 {
	void (*close)(struct sock___37 *, long int);
	int (*pre_connect)(struct sock___37 *, struct sockaddr *, int);
	int (*connect)(struct sock___37 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___37 *, int);
	struct sock___37 * (*accept)(struct sock___37 *, int, int *, bool);
	int (*ioctl)(struct sock___37 *, int, long unsigned int);
	int (*init)(struct sock___37 *);
	void (*destroy)(struct sock___37 *);
	void (*shutdown)(struct sock___37 *, int);
	int (*setsockopt)(struct sock___37 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___37 *, int, int, char *, int *);
	void (*keepalive)(struct sock___37 *, int);
	int (*compat_ioctl)(struct sock___37 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___37 *, struct msghdr___38 *, size_t);
	int (*recvmsg)(struct sock___37 *, struct msghdr___38 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___37 *, struct page___243 *, int, size_t, int);
	int (*bind)(struct sock___37 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___37 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___37 *, struct sk_buff___48 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___37 *);
	int (*hash)(struct sock___37 *);
	void (*unhash)(struct sock___37 *);
	void (*rehash)(struct sock___37 *);
	int (*get_port)(struct sock___37 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___37 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___37 *, int);
	bool (*sock_is_readable)(struct sock___37 *);
	void (*enter_memory_pressure)(struct sock___37 *);
	void (*leave_memory_pressure)(struct sock___37 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___26 *rsk_prot;
	struct timewait_sock_ops___26 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___222 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___37 *, int);
};

struct xfrm_policy_queue___2 {
	struct sk_buff_head___47 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___2 {
	possible_net_t___47 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___2 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___7 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___43 *prog;
	struct sock___37 *socks[0];
};

enum sk_pacing {
	SK_PACING_NONE = 0,
	SK_PACING_NEEDED = 1,
	SK_PACING_FQ = 2,
};

struct request_sock___27;

struct request_sock_ops___26 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___37 *, struct request_sock___27 *);
	void (*send_ack)(const struct sock___37 *, struct sk_buff___48 *, struct request_sock___27 *);
	void (*send_reset)(const struct sock___37 *, struct sk_buff___48 *);
	void (*destructor)(struct request_sock___27 *);
	void (*syn_ack_timeout)(const struct request_sock___27 *);
};

struct timewait_sock_ops___26 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___37 *, struct sock___37 *, void *);
	void (*twsk_destructor)(struct sock___37 *);
};

struct socket_alloc___3 {
	struct socket___38 socket;
	struct inode___238 vfs_inode;
	long: 64;
};

struct sockcm_cookie {
	u64 transmit_time;
	u32 mark;
	u16 tsflags;
};

struct request_sock___27 {
	struct sock_common___36 __req_common;
	struct request_sock___27 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___26 *rsk_ops;
	struct sock___37 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue {
	struct request_sock___27 *rskq_rst_head;
	struct request_sock___27 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___27 *rskq_accept_head;
	struct request_sock___27 *rskq_accept_tail;
	struct fastopen_queue fastopenq;
};

struct inet_cork___2 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___36 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___2 {
	struct inet_cork___2 base;
	struct flowi fl;
};

struct ipv6_pinfo___2;

struct inet_sock___2 {
	struct sock___37 sk;
	struct ipv6_pinfo___2 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___2 cork;
};

struct ipv6_fl_socklist___2;

struct ipv6_pinfo___2 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___2 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___48 *pktoptions;
	struct sk_buff___48 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops {
	int (*queue_xmit)(struct sock___37 *, struct sk_buff___48 *, struct flowi *);
	void (*send_check)(struct sock___37 *, struct sk_buff___48 *);
	int (*rebuild_header)(struct sock___37 *);
	void (*sk_rx_dst_set)(struct sock___37 *, const struct sk_buff___48 *);
	int (*conn_request)(struct sock___37 *, struct sk_buff___48 *);
	struct sock___37 * (*syn_recv_sock)(const struct sock___37 *, struct sk_buff___48 *, struct request_sock___27 *, struct dst_entry___36 *, struct request_sock___27 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___37 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___37 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___37 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___37 *);
};

struct inet_bind_bucket;

struct tcp_ulp_ops;

struct inet_connection_sock {
	struct inet_sock___2 icsk_inet;
	struct request_sock_queue icsk_accept_queue;
	struct inet_bind_bucket *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___6 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops *icsk_af_ops;
	const struct tcp_ulp_ops *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___37 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___37 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket {
	possible_net_t___47 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops {
	struct list_head list;
	int (*init)(struct sock___37 *);
	void (*update)(struct sock___37 *, struct proto___36 *, void (*)(struct sock___37 *));
	void (*release)(struct sock___37 *);
	int (*get_info)(const struct sock___37 *, struct sk_buff___48 *);
	size_t (*get_info_size)(const struct sock___37 *);
	void (*clone)(const struct request_sock___27 *, struct sock___37 *, const gfp_t);
	char name[16];
	struct module___222 *owner;
};

struct tcp_fastopen_cookie {
	__le64 val[2];
	s8 len;
	bool exp;
};

struct tcp_sack_block {
	u32 start_seq;
	u32 end_seq;
};

struct tcp_options_received {
	int ts_recent_stamp;
	u32 ts_recent;
	u32 rcv_tsval;
	u32 rcv_tsecr;
	u16 saw_tstamp: 1;
	u16 tstamp_ok: 1;
	u16 dsack: 1;
	u16 wscale_ok: 1;
	u16 sack_ok: 3;
	u16 smc_ok: 1;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u8 saw_unknown: 1;
	u8 unused: 7;
	long: 17;
	long: 64;
	long: 64;
	u8 num_sacks;
	u16 user_mss;
	u16 mss_clamp;
};

struct tcp_rack {
	u64 mstamp;
	u32 rtt_us;
	u32 end_seq;
	u32 last_delivered;
	u8 reo_wnd_steps;
	u8 reo_wnd_persist: 5;
	u8 dsack_seen: 1;
	u8 advanced: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct tcp_sock_af_ops;

struct tcp_md5sig_info;

struct tcp_fastopen_request;

struct tcp_sock {
	struct inet_connection_sock inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___48 *lost_skb_hint;
	struct sk_buff___48 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___48 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___48 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request *fastopen_req;
	struct request_sock___27 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_md5sig_key;

struct tcp_sock_af_ops {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___37 *, const struct sock___37 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___37 *, const struct sk_buff___48 *);
	int (*md5_parse)(struct sock___37 *, int, sockptr_t, int);
};

struct tcp_md5sig_info {
	struct hlist_head head;
	struct callback_head rcu;
};

struct tcp_fastopen_request {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___38 *data;
	size_t size;
	int copied;
	struct ubuf_info___2 *uarg;
};

union tcp_md5_addr {
	struct in_addr a4;
	struct in6_addr a6;
};

struct tcp_md5sig_key {
	struct hlist_node node;
	u8 keylen;
	u8 family;
	u8 prefixlen;
	u8 flags;
	union tcp_md5_addr addr;
	int l3index;
	u8 key[80];
	struct callback_head rcu;
};

struct ip6_flowlabel___2;

struct ipv6_fl_socklist___2 {
	struct ipv6_fl_socklist___2 *next;
	struct ip6_flowlabel___2 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___24 {
	struct in6_addr mca_addr;
	struct inet6_dev___24 *idev;
	struct ifmcaddr6___24 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___3 {
	struct in6_addr aca_addr;
	struct fib6_info___3 *aca_rt;
	struct ifacaddr6___3 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___2 {
	struct ip6_flowlabel___2 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___215 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___52 *fl_net;
};

struct fib_nh_exception___3 {
	struct fib_nh_exception___3 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___3 *fnhe_rth_input;
	struct rtable___3 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___3 {
	struct dst_entry___36 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___3 {
	struct fib_nh_exception___3 *chain;
};

struct net_protocol {
	int (*early_demux)(struct sk_buff___48 *);
	int (*early_demux_handler)(struct sk_buff___48 *);
	int (*handler)(struct sk_buff___48 *);
	int (*err_handler)(struct sk_buff___48 *, u32);
	unsigned int no_policy: 1;
	unsigned int icmp_strict_tag_validation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xfrm_type___2 {
	struct module___222 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___2 *);
	void (*destructor)(struct xfrm_state___2 *);
	int (*input)(struct xfrm_state___2 *, struct sk_buff___48 *);
	int (*output)(struct xfrm_state___2 *, struct sk_buff___48 *);
	int (*reject)(struct xfrm_state___2 *, struct sk_buff___48 *, const struct flowi *);
};

struct xfrm_type_offload___2 {
	struct module___222 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___2 *, struct sk_buff___48 *);
	int (*input_tail)(struct xfrm_state___2 *, struct sk_buff___48 *);
	int (*xmit)(struct xfrm_state___2 *, struct sk_buff___48 *, netdev_features_t);
};

struct xfrm_dst___2 {
	union {
		struct dst_entry___36 dst;
		struct rtable___3 rt;
		struct rt6_info___3 rt6;
	} u;
	struct dst_entry___36 *route;
	struct dst_entry___36 *child;
	struct dst_entry___36 *path;
	struct xfrm_policy___2 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct cgroup_cls_state {
	struct cgroup_subsys_state___165 css;
	u32 classid;
};

enum {
	SK_MEMINFO_RMEM_ALLOC = 0,
	SK_MEMINFO_RCVBUF = 1,
	SK_MEMINFO_WMEM_ALLOC = 2,
	SK_MEMINFO_SNDBUF = 3,
	SK_MEMINFO_FWD_ALLOC = 4,
	SK_MEMINFO_WMEM_QUEUED = 5,
	SK_MEMINFO_OPTMEM = 6,
	SK_MEMINFO_BACKLOG = 7,
	SK_MEMINFO_DROPS = 8,
	SK_MEMINFO_VARS = 9,
};

enum sknetlink_groups {
	SKNLGRP_NONE = 0,
	SKNLGRP_INET_TCP_DESTROY = 1,
	SKNLGRP_INET_UDP_DESTROY = 2,
	SKNLGRP_INET6_TCP_DESTROY = 3,
	SKNLGRP_INET6_UDP_DESTROY = 4,
	__SKNLGRP_MAX = 5,
};

struct bpf_local_storage_data___7 {
	struct bpf_local_storage_map___7 *smap;
	u8 data[0];
};

struct ipv6_txoptions___2;

struct inet_request_sock {
	struct request_sock___27 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions___2 *ipv6_opt;
			struct sk_buff___48 *pktopts;
		};
	};
};

struct tcp_request_sock_ops;

struct tcp_request_sock {
	struct inet_request_sock req;
	const struct tcp_request_sock_ops *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_sock_af_ops___2;

struct tcp_md5sig_info___2;

struct tcp_fastopen_request___2;

struct tcp_sock___2 {
	struct inet_connection_sock inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___48 *lost_skb_hint;
	struct sk_buff___48 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___48 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___48 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___2 *af_specific;
	struct tcp_md5sig_info___2 *md5sig_info;
	struct tcp_fastopen_request___2 *fastopen_req;
	struct request_sock___27 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct dentry___239;

struct super_block___239;

struct module___223;

struct file_system_type___239 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___239 * (*mount)(struct file_system_type___239 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___239 *);
	struct module___223 *owner;
	struct file_system_type___239 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___239;

struct kiocb___239;

struct iov_iter___159;

struct poll_table_struct___162;

struct vm_area_struct___244;

struct inode___239;

struct file_lock___239;

struct page___244;

struct pipe_inode_info___80;

struct seq_file___214;

struct file_operations___240 {
	struct module___223 *owner;
	loff_t (*llseek)(struct file___239 *, loff_t, int);
	ssize_t (*read)(struct file___239 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___239 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___239 *, struct iov_iter___159 *);
	ssize_t (*write_iter)(struct kiocb___239 *, struct iov_iter___159 *);
	int (*iopoll)(struct kiocb___239 *, bool);
	int (*iterate)(struct file___239 *, struct dir_context *);
	int (*iterate_shared)(struct file___239 *, struct dir_context *);
	__poll_t (*poll)(struct file___239 *, struct poll_table_struct___162 *);
	long int (*unlocked_ioctl)(struct file___239 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___239 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___239 *, struct vm_area_struct___244 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___239 *, struct file___239 *);
	int (*flush)(struct file___239 *, fl_owner_t);
	int (*release)(struct inode___239 *, struct file___239 *);
	int (*fsync)(struct file___239 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___239 *, int);
	int (*lock)(struct file___239 *, int, struct file_lock___239 *);
	ssize_t (*sendpage)(struct file___239 *, struct page___244 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___239 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___239 *, long unsigned int);
	int (*flock)(struct file___239 *, int, struct file_lock___239 *);
	ssize_t (*splice_write)(struct pipe_inode_info___80 *, struct file___239 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___239 *, loff_t *, struct pipe_inode_info___80 *, size_t, unsigned int);
	int (*setlease)(struct file___239 *, long int, struct file_lock___239 **, void **);
	long int (*fallocate)(struct file___239 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___214 *, struct file___239 *);
	ssize_t (*copy_file_range)(struct file___239 *, loff_t, struct file___239 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___239 *, loff_t, struct file___239 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___239 *, loff_t, loff_t, int);
};

struct vmacache___244 {
	u64 seqnum;
	struct vm_area_struct___244 *vmas[4];
};

struct page_frag___244 {
	struct page___244 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___245;

struct pid___216;

struct nsproxy___225;

struct signal_struct___240;

struct bio_list___132;

struct backing_dev_info___118;

struct io_context___132;

struct css_set___166;

struct mem_cgroup___106;

struct request_queue___132;

struct vm_struct___222;

struct task_struct___246 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___246 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___245 *mm;
	struct mm_struct___245 *active_mm;
	struct vmacache___244 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___246 *real_parent;
	struct task_struct___246 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___246 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___216 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___225 *nsproxy;
	struct signal_struct___240 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___246 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___132 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___118 *backing_dev_info;
	struct io_context___132 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___166 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___80 *splice_pipe;
	struct page_frag___244 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___106 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___106 *active_memcg;
	struct request_queue___132 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___246 *oom_reaper_list;
	struct vm_struct___222 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___227;

struct kobj_type___227;

struct kernfs_node___227;

struct kobject___227 {
	const char *name;
	struct list_head entry;
	struct kobject___227 *parent;
	struct kset___227 *kset;
	struct kobj_type___227 *ktype;
	struct kernfs_node___227 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___224 {
	struct kobject___227 kobj;
	struct module___223 *mod;
	struct kobject___227 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___223 {
	struct module___223 *mod;
	struct latch_tree_node node;
};

struct module_layout___223 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___223 mtn;
};

struct module_attribute___223;

struct kernel_param___223;

struct module___223 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___224 mkobj;
	struct module_attribute___223 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___227 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___223 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___223 core_layout;
	struct module_layout___223 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___216;

struct upid___216 {
	int nr;
	struct pid_namespace___216 *ns;
};

struct pid_namespace___216 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___246 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___216 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___216 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___216 numbers[1];
};

typedef struct page___244 *pgtable_t___244;

struct address_space___239;

struct page_pool___68;

struct dev_pagemap___234;

struct page___244 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___239 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___68 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___244 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___244 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___245 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___234 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___234;

struct vm_area_struct___244 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___244 *vm_next;
	struct vm_area_struct___244 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___245 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___234 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___239 *vm_file;
	struct file___239 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___240 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___246 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___246 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___216 *pids[4];
	struct pid___216 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___245 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___244;

struct mm_struct___245 {
	struct {
		struct vm_area_struct___244 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___239 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___244 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___246 *owner;
		struct user_namespace___14 *user_ns;
		struct file___239 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___53;

struct cgroup_namespace___166;

struct nsproxy___225 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___216 *pid_ns_for_children;
	struct net___53 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___166 *cgroup_ns;
};

struct bio___132;

struct bio_list___132 {
	struct bio___132 *head;
	struct bio___132 *tail;
};

struct cgroup_subsys_state___166;

struct bdi_writeback___118 {
	struct backing_dev_info___118 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___166 *memcg_css;
	struct cgroup_subsys_state___166 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___220;

struct backing_dev_info___118 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___118 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___220 *dev;
	char dev_name[64];
	struct device___220 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___239 *debug_dir;
};

struct io_cq___132;

struct io_context___132 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___132 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___166;

struct css_set___166 {
	struct cgroup_subsys_state___166 *subsys[14];
	refcount_t refcount;
	struct css_set___166 *dom_cset;
	struct cgroup___166 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___166 *mg_src_cgrp;
	struct cgroup___166 *mg_dst_cgrp;
	struct css_set___166 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___239;

struct pipe_buffer___80;

struct pipe_inode_info___80 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___244 *tmp_page;
	struct fasync_struct___239 *fasync_readers;
	struct fasync_struct___239 *fasync_writers;
	struct pipe_buffer___80 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___166;

struct cgroup_subsys_state___166 {
	struct cgroup___166 *cgroup;
	struct cgroup_subsys___166 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___166 *parent;
};

struct cgroup_file___166 {
	struct kernfs_node___227 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___106;

struct mem_cgroup_per_node___106;

struct mem_cgroup___106 {
	struct cgroup_subsys_state___166 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___166 events_file;
	struct cgroup_file___166 events_local_file;
	struct cgroup_file___166 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___106 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___246 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___106 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___132;

struct blk_integrity___132 {
	const struct blk_integrity_profile___132 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___132 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___132 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___132;

struct elevator_queue___132;

struct blk_mq_ops___127;

struct blk_mq_hw_ctx___127;

struct gendisk___135;

struct blkcg_gq___120;

struct blk_mq_tag_set___127;

struct request_queue___132 {
	struct request___132 *last_merge;
	struct elevator_queue___132 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___127 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___127 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___135 *disk;
	struct kobject___227 kobj;
	struct kobject___227 *mq_kobj;
	struct blk_integrity___132 integrity;
	struct device___220 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___120 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___127 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___132 bio_split;
	struct dentry___239 *debugfs_dir;
	struct dentry___239 *sched_debugfs_dir;
	struct dentry___239 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___222 {
	struct vm_struct___222 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___244 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___239;

struct address_space___239 {
	struct inode___239 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___239 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___68 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___220 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___68 {
	u32 count;
	struct page___244 *cache[128];
};

struct page_pool___68 {
	struct page_pool_params___68 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___244 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___68 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___234;

struct dev_pagemap___234 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___234 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___239;

struct path___239 {
	struct vfsmount___239 *mnt;
	struct dentry___239 *dentry;
};

struct fown_struct___216 {
	rwlock_t lock;
	struct pid___216 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___239 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___239 f_path;
	struct inode___239 *f_inode;
	const struct file_operations___240 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___216 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___239 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___234;

struct vm_operations_struct___234 {
	void (*open)(struct vm_area_struct___244 *);
	void (*close)(struct vm_area_struct___244 *);
	int (*may_split)(struct vm_area_struct___244 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___244 *);
	int (*mprotect)(struct vm_area_struct___244 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___234 *);
	vm_fault_t (*huge_fault)(struct vm_fault___234 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___234 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___244 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___234 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___234 *);
	int (*access)(struct vm_area_struct___244 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___244 *);
	int (*set_policy)(struct vm_area_struct___244 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___244 *, long unsigned int);
	struct page___244 * (*find_special_page)(struct vm_area_struct___244 *, long unsigned int);
};

struct core_thread___244 {
	struct task_struct___246 *task;
	struct core_thread___244 *next;
};

struct core_state___244 {
	atomic_t nr_threads;
	struct core_thread___244 dumper;
	struct completion startup;
};

struct vm_fault___234 {
	const struct {
		struct vm_area_struct___244 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___244 *cow_page;
	struct page___244 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___244 prealloc_pte;
};

struct pglist_data___114;

struct lruvec___114 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___114 *pgdat;
};

struct zone___114 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___114 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___114 {
	struct zone___114 *zone;
	int zone_idx;
};

struct zonelist___114 {
	struct zoneref___114 _zonerefs[321];
};

struct pglist_data___114 {
	struct zone___114 node_zones[5];
	struct zonelist___114 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___246 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___246 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___114 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___239;

struct dentry___239 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___239 *d_parent;
	struct qstr d_name;
	struct inode___239 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___239 *d_op;
	struct super_block___239 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___239;

struct inode___239 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___239 *i_op;
	struct super_block___239 *i_sb;
	struct address_space___239 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___118 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___240 *i_fop;
		void (*free_inode)(struct inode___239 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___239 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___80 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___239 {
	int (*d_revalidate)(struct dentry___239 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___239 *, unsigned int);
	int (*d_hash)(const struct dentry___239 *, struct qstr *);
	int (*d_compare)(const struct dentry___239 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___239 *);
	int (*d_init)(struct dentry___239 *);
	void (*d_release)(struct dentry___239 *);
	void (*d_prune)(struct dentry___239 *);
	void (*d_iput)(struct dentry___239 *, struct inode___239 *);
	char * (*d_dname)(struct dentry___239 *, char *, int);
	struct vfsmount___239 * (*d_automount)(struct path___239 *);
	int (*d_manage)(const struct path___239 *, bool);
	struct dentry___239 * (*d_real)(struct dentry___239 *, const struct inode___239 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___239;

struct mem_dqinfo___239 {
	struct quota_format_type___239 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___239;

struct quota_info___239 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___239 *files[3];
	struct mem_dqinfo___239 info[3];
	const struct quota_format_ops___239 *ops[3];
};

struct rcuwait___240 {
	struct task_struct___246 *task;
};

struct percpu_rw_semaphore___240 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___240 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___239 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___240 rw_sem[3];
};

struct shrink_control___106;

struct shrinker___106 {
	long unsigned int (*count_objects)(struct shrinker___106 *, struct shrink_control___106 *);
	long unsigned int (*scan_objects)(struct shrinker___106 *, struct shrink_control___106 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___239;

struct dquot_operations___239;

struct quotactl_ops___239;

struct block_device___135;

struct super_block___239 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___239 *s_type;
	const struct super_operations___239 *s_op;
	const struct dquot_operations___239 *dq_op;
	const struct quotactl_ops___239 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___239 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___135 *s_bdev;
	struct backing_dev_info___118 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___239 s_dquot;
	struct sb_writers___239 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___239 *s_d_op;
	int cleancache_poolid;
	struct shrinker___106 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___239 {
	struct dentry___239 *mnt_root;
	struct super_block___239 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___106 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___106 *memcg;
};

struct psi_group___166 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___246 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___44;

struct cgroup_bpf___44 {
	struct bpf_prog_array___44 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___44 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___166;

struct cgroup_rstat_cpu___166;

struct cgroup___166 {
	struct cgroup_subsys_state___166 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___227 *kn;
	struct cgroup_file___166 procs_file;
	struct cgroup_file___166 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___166 *subsys[14];
	struct cgroup_root___166 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___166 *dom_cgrp;
	struct cgroup___166 *old_dom_cgrp;
	struct cgroup_rstat_cpu___166 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___166 psi;
	struct cgroup_bpf___44 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___132 {
	struct request_queue___132 *q;
	struct io_context___132 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___239 {
	struct file___239 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___239 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___113 *ki_waitq;
	};
};

struct iattr___239 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___239 *ia_file;
};

struct dquot___239 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___239 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___239 {
	int qf_fmt_id;
	const struct quota_format_ops___239 *qf_ops;
	struct module___223 *qf_owner;
	struct quota_format_type___239 *qf_next;
};

struct quota_format_ops___239 {
	int (*check_quota_file)(struct super_block___239 *, int);
	int (*read_file_info)(struct super_block___239 *, int);
	int (*write_file_info)(struct super_block___239 *, int);
	int (*free_file_info)(struct super_block___239 *, int);
	int (*read_dqblk)(struct dquot___239 *);
	int (*commit_dqblk)(struct dquot___239 *);
	int (*release_dqblk)(struct dquot___239 *);
	int (*get_next_id)(struct super_block___239 *, struct kqid *);
};

struct dquot_operations___239 {
	int (*write_dquot)(struct dquot___239 *);
	struct dquot___239 * (*alloc_dquot)(struct super_block___239 *, int);
	void (*destroy_dquot)(struct dquot___239 *);
	int (*acquire_dquot)(struct dquot___239 *);
	int (*release_dquot)(struct dquot___239 *);
	int (*mark_dirty)(struct dquot___239 *);
	int (*write_info)(struct super_block___239 *, int);
	qsize_t * (*get_reserved_space)(struct inode___239 *);
	int (*get_projid)(struct inode___239 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___239 *, qsize_t *);
	int (*get_next_id)(struct super_block___239 *, struct kqid *);
};

struct quotactl_ops___239 {
	int (*quota_on)(struct super_block___239 *, int, int, const struct path___239 *);
	int (*quota_off)(struct super_block___239 *, int);
	int (*quota_enable)(struct super_block___239 *, unsigned int);
	int (*quota_disable)(struct super_block___239 *, unsigned int);
	int (*quota_sync)(struct super_block___239 *, int);
	int (*set_info)(struct super_block___239 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___239 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___239 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___239 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___239 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___239 *, unsigned int);
};

struct writeback_control___118;

struct address_space_operations___239 {
	int (*writepage)(struct page___244 *, struct writeback_control___118 *);
	int (*readpage)(struct file___239 *, struct page___244 *);
	int (*writepages)(struct address_space___239 *, struct writeback_control___118 *);
	int (*set_page_dirty)(struct page___244 *);
	int (*readpages)(struct file___239 *, struct address_space___239 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___239 *, struct address_space___239 *, loff_t, unsigned int, unsigned int, struct page___244 **, void **);
	int (*write_end)(struct file___239 *, struct address_space___239 *, loff_t, unsigned int, unsigned int, struct page___244 *, void *);
	sector_t (*bmap)(struct address_space___239 *, sector_t);
	void (*invalidatepage)(struct page___244 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___244 *, gfp_t);
	void (*freepage)(struct page___244 *);
	ssize_t (*direct_IO)(struct kiocb___239 *, struct iov_iter___159 *);
	int (*migratepage)(struct address_space___239 *, struct page___244 *, struct page___244 *, enum migrate_mode);
	bool (*isolate_page)(struct page___244 *, isolate_mode_t);
	void (*putback_page)(struct page___244 *);
	int (*launder_page)(struct page___244 *);
	int (*is_partially_uptodate)(struct page___244 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___244 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___239 *, struct page___244 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___239 *, sector_t *);
	void (*swap_deactivate)(struct file___239 *);
};

struct writeback_control___118 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___118 *wb;
	struct inode___239 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___156;

struct iov_iter___159 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___156 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___80 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___239 {
	struct dentry___239 * (*lookup)(struct inode___239 *, struct dentry___239 *, unsigned int);
	const char * (*get_link)(struct dentry___239 *, struct inode___239 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___239 *, int);
	struct posix_acl * (*get_acl)(struct inode___239 *, int, bool);
	int (*readlink)(struct dentry___239 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___239 *, struct dentry___239 *, umode_t, bool);
	int (*link)(struct dentry___239 *, struct inode___239 *, struct dentry___239 *);
	int (*unlink)(struct inode___239 *, struct dentry___239 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___239 *, struct dentry___239 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___239 *, struct dentry___239 *, umode_t);
	int (*rmdir)(struct inode___239 *, struct dentry___239 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___239 *, struct dentry___239 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___239 *, struct dentry___239 *, struct inode___239 *, struct dentry___239 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___239 *, struct iattr___239 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___239 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___239 *, char *, size_t);
	int (*fiemap)(struct inode___239 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___239 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___239 *, struct dentry___239 *, struct file___239 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___239 *, struct dentry___239 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___239 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___239 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___239 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___239 {
	void (*fl_copy_lock)(struct file_lock___239 *, struct file_lock___239 *);
	void (*fl_release_private)(struct file_lock___239 *);
};

struct lock_manager_operations___239;

struct file_lock___239 {
	struct file_lock___239 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___239 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___239 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___239 *fl_ops;
	const struct lock_manager_operations___239 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___239 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___239 *);
	int (*lm_grant)(struct file_lock___239 *, int);
	bool (*lm_break)(struct file_lock___239 *);
	int (*lm_change)(struct file_lock___239 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___239 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___239 *);
};

struct fasync_struct___239 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___239 *fa_next;
	struct file___239 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___239 {
	struct inode___239 * (*alloc_inode)(struct super_block___239 *);
	void (*destroy_inode)(struct inode___239 *);
	void (*free_inode)(struct inode___239 *);
	void (*dirty_inode)(struct inode___239 *, int);
	int (*write_inode)(struct inode___239 *, struct writeback_control___118 *);
	int (*drop_inode)(struct inode___239 *);
	void (*evict_inode)(struct inode___239 *);
	void (*put_super)(struct super_block___239 *);
	int (*sync_fs)(struct super_block___239 *, int);
	int (*freeze_super)(struct super_block___239 *);
	int (*freeze_fs)(struct super_block___239 *);
	int (*thaw_super)(struct super_block___239 *);
	int (*unfreeze_fs)(struct super_block___239 *);
	int (*statfs)(struct dentry___239 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___239 *, int *, char *);
	void (*umount_begin)(struct super_block___239 *);
	int (*show_options)(struct seq_file___214 *, struct dentry___239 *);
	int (*show_devname)(struct seq_file___214 *, struct dentry___239 *);
	int (*show_path)(struct seq_file___214 *, struct dentry___239 *);
	int (*show_stats)(struct seq_file___214 *, struct dentry___239 *);
	ssize_t (*quota_read)(struct super_block___239 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___239 *, int, const char *, size_t, loff_t);
	struct dquot___239 ** (*get_dquots)(struct inode___239 *);
	long int (*nr_cached_objects)(struct super_block___239 *, struct shrink_control___106 *);
	long int (*free_cached_objects)(struct super_block___239 *, struct shrink_control___106 *);
	struct file___239 * (*real_loop)(struct file___239 *);
};

struct wakeup_source___220;

struct dev_pm_info___220 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___220 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___220 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___220;

struct bus_type___220;

struct device_driver___220;

struct dev_pm_domain___220;

struct fwnode_handle___216;

struct class___220;

struct attribute_group___227;

struct device___220 {
	struct kobject___227 kobj;
	struct device___220 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___220 *type;
	struct bus_type___220 *bus;
	struct device_driver___220 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___220 power;
	struct dev_pm_domain___220 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___216 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___220 *class;
	const struct attribute_group___227 **groups;
	void (*release)(struct device___220 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___135 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___239 *bd_inode;
	struct super_block___239 *bd_super;
	void *bd_claiming;
	struct device___220 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___227 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___135 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___239 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___170)(struct file___239 *, wait_queue_head_t *, struct poll_table_struct___162 *);

struct poll_table_struct___162 {
	poll_queue_proc___170 _qproc;
	__poll_t _key;
};

struct seq_operations___214;

struct seq_file___214 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___214 *op;
	int poll_event;
	const struct file___239 *file;
	void *private;
};

typedef void bio_end_io_t___132(struct bio___132 *);

struct bio_vec___156 {
	struct page___244 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___132;

struct bio___132 {
	struct bio___132 *bi_next;
	struct block_device___135 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___132 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___120 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___132 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___156 *bi_io_vec;
	struct bio_set___132 *bi_pool;
	struct bio_vec___156 bi_inline_vecs[0];
};

struct kernfs_root___227;

struct kernfs_elem_dir___227 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___227 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___227;

struct kernfs_root___227 {
	struct kernfs_node___227 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___227 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___227 {
	struct kernfs_node___227 *target_kn;
};

struct kernfs_ops___227;

struct kernfs_elem_attr___227 {
	const struct kernfs_ops___227 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___227 *notify_next;
};

struct kernfs_node___227 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___227 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___227 dir;
		struct kernfs_elem_symlink___227 symlink;
		struct kernfs_elem_attr___227 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___227;

struct kernfs_ops___227 {
	int (*open)(struct kernfs_open_file___227 *);
	void (*release)(struct kernfs_open_file___227 *);
	int (*seq_show)(struct seq_file___214 *, void *);
	void * (*seq_start)(struct seq_file___214 *, loff_t *);
	void * (*seq_next)(struct seq_file___214 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___214 *, void *);
	ssize_t (*read)(struct kernfs_open_file___227 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___227 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___227 *, struct poll_table_struct___162 *);
	int (*mmap)(struct kernfs_open_file___227 *, struct vm_area_struct___244 *);
};

struct kernfs_syscall_ops___227 {
	int (*show_options)(struct seq_file___214 *, struct kernfs_root___227 *);
	int (*mkdir)(struct kernfs_node___227 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___227 *);
	int (*rename)(struct kernfs_node___227 *, struct kernfs_node___227 *, const char *);
	int (*show_path)(struct seq_file___214 *, struct kernfs_node___227 *, struct kernfs_root___227 *);
};

struct kernfs_open_file___227 {
	struct kernfs_node___227 *kn;
	struct file___239 *file;
	struct seq_file___214 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___234 *vm_ops;
};

struct sock___38;

struct kobj_ns_type_operations___37 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___38 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___53 *net;
} possible_net_t___48;

struct proto___37;

struct sock_common___37 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___37 *skc_prot;
	possible_net_t___48 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___38 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___49;

struct sk_buff_head___48 {
	struct sk_buff___49 *next;
	struct sk_buff___49 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___37 {
	struct cgroup___166 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___37;

struct socket_wq___38;

struct xfrm_policy___3;

struct dst_entry___37;

struct socket___39;

struct net_device___50;

struct sock_reuseport___8;

struct sock___38 {
	struct sock_common___37 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___48 sk_error_queue;
	struct sk_buff___49 *sk_rx_skb_cache;
	struct sk_buff_head___48 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___49 *head;
		struct sk_buff___49 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___37 *sk_filter;
	union {
		struct socket_wq___38 *sk_wq;
		struct socket_wq___38 *sk_wq_raw;
	};
	struct xfrm_policy___3 *sk_policy[2];
	struct dst_entry___37 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___37 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___49 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___49 *sk_tx_skb_cache;
	struct sk_buff_head___48 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___244 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___37 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___216 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___39 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___37 sk_cgrp_data;
	struct mem_cgroup___106 *sk_memcg;
	void (*sk_state_change)(struct sock___38 *);
	void (*sk_data_ready)(struct sock___38 *);
	void (*sk_write_space)(struct sock___38 *);
	void (*sk_error_report)(struct sock___38 *);
	int (*sk_backlog_rcv)(struct sock___38 *, struct sk_buff___49 *);
	struct sk_buff___49 * (*sk_validate_xmit_skb)(struct sock___38 *, struct net_device___50 *, struct sk_buff___49 *);
	void (*sk_destruct)(struct sock___38 *);
	struct sock_reuseport___8 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___227;

struct attribute_group___227 {
	const char *name;
	umode_t (*is_visible)(struct kobject___227 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___227 *, struct bin_attribute___227 *, int);
	struct attribute **attrs;
	struct bin_attribute___227 **bin_attrs;
};

struct bin_attribute___227 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___239 * (*f_mapping)();
	ssize_t (*read)(struct file___239 *, struct kobject___227 *, struct bin_attribute___227 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___239 *, struct kobject___227 *, struct bin_attribute___227 *, char *, loff_t, size_t);
	int (*mmap)(struct file___239 *, struct kobject___227 *, struct bin_attribute___227 *, struct vm_area_struct___244 *);
};

struct sysfs_ops___227 {
	ssize_t (*show)(struct kobject___227 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___227 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___227;

struct kset___227 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___227 kobj;
	const struct kset_uevent_ops___227 *uevent_ops;
};

struct kobj_type___227 {
	void (*release)(struct kobject___227 *);
	const struct sysfs_ops___227 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___227 **default_groups;
	const struct kobj_ns_type_operations___37 * (*child_ns_type)(struct kobject___227 *);
	const void * (*namespace)(struct kobject___227 *);
	void (*get_ownership)(struct kobject___227 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___227 {
	int (* const filter)(struct kset___227 *, struct kobject___227 *);
	const char * (* const name)(struct kset___227 *, struct kobject___227 *);
	int (* const uevent)(struct kset___227 *, struct kobject___227 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___223 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___223 *);
	int (*get)(char *, const struct kernel_param___223 *);
	void (*free)(void *);
};

struct kparam_array___223;

struct kernel_param___223 {
	const char *name;
	struct module___223 *mod;
	const struct kernel_param_ops___223 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___223 *arr;
	};
};

struct kparam_array___223 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___223 *ops;
	void *elem;
};

struct module_attribute___223 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___223 *, struct module_kobject___224 *, char *);
	ssize_t (*store)(struct module_attribute___223 *, struct module_kobject___224 *, const char *, size_t);
	void (*setup)(struct module___223 *, const char *);
	int (*test)(struct module___223 *);
	void (*free)(struct module___223 *);
};

struct dev_pagemap_ops___234 {
	void (*page_free)(struct page___244 *);
	void (*kill)(struct dev_pagemap___234 *);
	void (*cleanup)(struct dev_pagemap___234 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___234 *);
};

struct fwnode_operations___216;

struct fwnode_handle___216 {
	struct fwnode_handle___216 *secondary;
	const struct fwnode_operations___216 *ops;
	struct device___220 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___216;

struct fwnode_endpoint___216;

struct fwnode_operations___216 {
	struct fwnode_handle___216 * (*get)(struct fwnode_handle___216 *);
	void (*put)(struct fwnode_handle___216 *);
	bool (*device_is_available)(const struct fwnode_handle___216 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___216 *, const struct device___220 *);
	bool (*property_present)(const struct fwnode_handle___216 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___216 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___216 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___216 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*get_parent)(const struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*get_next_child_node)(const struct fwnode_handle___216 *, struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*get_named_child_node)(const struct fwnode_handle___216 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___216 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___216 *);
	struct fwnode_handle___216 * (*graph_get_next_endpoint)(const struct fwnode_handle___216 *, struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*graph_get_remote_endpoint)(const struct fwnode_handle___216 *);
	struct fwnode_handle___216 * (*graph_get_port_parent)(struct fwnode_handle___216 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___216 *, struct fwnode_endpoint___216 *);
	int (*add_links)(struct fwnode_handle___216 *);
};

struct fwnode_endpoint___216 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___216 *local_fwnode;
};

struct fwnode_reference_args___216 {
	struct fwnode_handle___216 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msghdr___39 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___159 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___239 *msg_iocb;
};

struct sk_buff___49 {
	union {
		struct {
			struct sk_buff___49 *next;
			struct sk_buff___49 *prev;
			union {
				struct net_device___50 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___38 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___49 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___53;

struct fqdir___53 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___53 *f;
	struct net___53 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___53;

struct inet_frags___53 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___53 *, const void *);
	void (*destructor)(struct inet_frag_queue___53 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___19;

struct fib_rules_ops___37;

struct tcp_congestion_ops___7;

struct fib_notifier_ops___37;

struct netns_ipv4___53 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___19 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___37 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___38 *fibnl;
	struct sock___38 **icmp_sk;
	struct sock___38 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___38 **tcp_sk;
	struct fqdir___53 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___7 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___37 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___37 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___37 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___37;

struct dst_ops___53 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___53 *);
	struct dst_entry___37 * (*check)(struct dst_entry___37 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___37 *);
	unsigned int (*mtu)(const struct dst_entry___37 *);
	u32 * (*cow_metrics)(struct dst_entry___37 *, long unsigned int);
	void (*destroy)(struct dst_entry___37 *);
	void (*ifdown)(struct dst_entry___37 *, struct net_device___50 *, int);
	struct dst_entry___37 * (*negative_advice)(struct dst_entry___37 *);
	void (*link_failure)(struct sk_buff___49 *);
	void (*update_pmtu)(struct dst_entry___37 *, struct sock___38 *, struct sk_buff___49 *, u32, bool);
	void (*redirect)(struct dst_entry___37 *, struct sock___38 *, struct sk_buff___49 *);
	int (*local_out)(struct net___53 *, struct sock___38 *, struct sk_buff___49 *);
	struct neighbour___37 * (*neigh_lookup)(const struct dst_entry___37 *, struct sk_buff___49 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___37 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___4;

struct rt6_info___4;

struct fib6_table___4;

struct netns_ipv6___53 {
	struct dst_ops___53 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___53 *fqdir;
	struct fib6_info___4 *fib6_null_entry;
	struct rt6_info___4 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___4 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___4 *ip6_prohibit_entry;
	struct rt6_info___4 *ip6_blk_hole_entry;
	struct fib6_table___4 *fib6_local_tbl;
	struct fib_rules_ops___37 *fib6_rules_ops;
	struct sock___38 **icmp_sk;
	struct sock___38 *ndisc_sk;
	struct sock___38 *tcp_sk;
	struct sock___38 *igmp_sk;
	struct sock___38 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___37 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___37 *notifier_ops;
	struct fib_notifier_ops___37 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___53 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___53 *fqdir;
};

struct netns_sctp___37 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___38 *ctl_sock;
	struct sock___38 *udp4_sock;
	struct sock___38 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___44;

struct netns_bpf___44 {
	struct bpf_prog_array___44 *run_array[2];
	struct bpf_prog___44 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___53 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___38 *nlsk;
	struct sock___38 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___53 xfrm4_dst_ops;
	struct dst_ops___53 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___53 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___38 *rtnl;
	struct sock___38 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___50 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___53 ipv4;
	struct netns_ipv6___53 ipv6;
	struct netns_ieee802154_lowpan___53 ieee802154_lowpan;
	struct netns_sctp___37 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___48 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___44 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___53 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___38 *crypto_nlsk;
	struct sock___38 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___53 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___49 *fragments_tail;
	struct sk_buff___49 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___53 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___19 {
	struct ip_ra_chain___19 *next;
	struct sock___38 *sk;
	union {
		void (*destructor)(struct sock___38 *);
		struct sock___38 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___37;

struct fib_lookup_arg___37;

struct fib_rules_ops___37 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___37 *, struct flowi *, int, struct fib_lookup_arg___37 *);
	bool (*suppress)(struct fib_rule___37 *, int, struct fib_lookup_arg___37 *);
	int (*match)(struct fib_rule___37 *, struct flowi *, int);
	int (*configure)(struct fib_rule___37 *, struct sk_buff___49 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___37 *);
	int (*compare)(struct fib_rule___37 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___37 *, struct sk_buff___49 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___37 *);
	void (*flush_cache)(struct fib_rules_ops___37 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___223 *owner;
	struct net___53 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___7 {
	u32 (*ssthresh)(struct sock___38 *);
	void (*cong_avoid)(struct sock___38 *, u32, u32);
	void (*set_state)(struct sock___38 *, u8);
	void (*cwnd_event)(struct sock___38 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___38 *, u32);
	void (*pkts_acked)(struct sock___38 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___38 *);
	void (*cong_control)(struct sock___38 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___38 *);
	u32 (*sndbuf_expand)(struct sock___38 *);
	size_t (*get_info)(struct sock___38 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___223 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___38 *);
	void (*release)(struct sock___38 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___37 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___53 *);
	int (*fib_dump)(struct net___53 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___223 *owner;
	struct callback_head rcu;
};

struct xfrm_state___3;

struct lwtunnel_state___20;

struct dst_entry___37 {
	struct net_device___50 *dev;
	struct dst_ops___53 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___3 *xfrm;
	int (*input)(struct sk_buff___49 *);
	int (*output)(struct net___53 *, struct sock___38 *, struct sk_buff___49 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___20 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___48(struct sk_buff___49 **);

struct bpf_xdp_entity___44 {
	struct bpf_prog___44 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___48;

struct net_device_ops___48;

struct l3mdev_ops___37;

struct ndisc_ops___25;

struct xfrmdev_ops___48;

struct header_ops___48;

struct inet6_dev___25;

struct netdev_rx_queue___48;

struct mini_Qdisc___44;

struct netdev_queue___48;

struct Qdisc___44;

struct rtnl_link_ops___44;

struct dcbnl_rtnl_ops___48;

struct net_device___50 {
	char name[16];
	struct netdev_name_node___48 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___48 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___37 *l3mdev_ops;
	const struct ndisc_ops___25 *ndisc_ops;
	const struct xfrmdev_ops___48 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___48 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___227 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___25 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___48 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___44 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___48 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___44 *miniq_ingress;
	struct netdev_queue___48 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___48 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___44 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___44 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___48 = 0,
		NETREG_REGISTERED___48 = 1,
		NETREG_UNREGISTERING___48 = 2,
		NETREG_UNREGISTERED___48 = 3,
		NETREG_RELEASED___48 = 4,
		NETREG_DUMMY___48 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___48 = 0,
		RTNL_LINK_INITIALIZING___48 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___50 *);
	struct netpoll_info *npinfo;
	possible_net_t___48 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___220 dev;
	const struct attribute_group___227 *sysfs_groups[4];
	const struct attribute_group___227 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___44 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___48 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___44 xdp_state[3];
	long: 64;
};

struct neigh_table___37;

struct neigh_parms___37;

struct neigh_ops___37;

struct neighbour___37 {
	struct neighbour___37 *next;
	struct neigh_table___37 *tbl;
	struct neigh_parms___37 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___48 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___37 *, struct sk_buff___49 *);
	const struct neigh_ops___37 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___50 *dev;
	u8 primary_key[0];
};

struct rtable___4;

struct fnhe_hash_bucket___4;

struct fib_nh_common___4 {
	struct net_device___50 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___20 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___4 **nhc_pcpu_rth_output;
	struct rtable___4 *nhc_rth_input;
	struct fnhe_hash_bucket___4 *nhc_exceptions;
};

struct fib6_nh___4 {
	struct fib_nh_common___4 nh_common;
	long unsigned int last_probe;
	struct rt6_info___4 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___4;

struct fib6_info___4 {
	struct fib6_table___4 *fib6_table;
	struct fib6_info___4 *fib6_next;
	struct fib6_node___4 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___4 fib6_nh[0];
};

struct rt6_info___4 {
	struct dst_entry___37 dst;
	struct fib6_info___4 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___25 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___4 {
	struct fib6_node___4 *parent;
	struct fib6_node___4 *left;
	struct fib6_node___4 *right;
	struct fib6_node___4 *subtree;
	struct fib6_info___4 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___4 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___4 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___4 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___44 {
	struct bpf_prog___44 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___44 {
	struct callback_head rcu;
	struct bpf_prog_array_item___44 items[0];
};

struct bpf_prog_aux___51;

struct bpf_prog___44 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___51 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct cgroup_namespace___166 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___166 *root_cset;
};

struct socket_wq___38 {
	wait_queue_head_t wait;
	struct fasync_struct___239 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___38;

struct socket___39 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___239 *file;
	struct sock___38 *sk;
	const struct proto_ops___38 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___38 wq;
};

typedef int (*sk_read_actor_t___37)(read_descriptor_t *, struct sk_buff___49 *, unsigned int, size_t);

struct proto_ops___38 {
	int family;
	struct module___223 *owner;
	int (*release)(struct socket___39 *);
	int (*bind)(struct socket___39 *, struct sockaddr *, int);
	int (*connect)(struct socket___39 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___39 *, struct socket___39 *);
	int (*accept)(struct socket___39 *, struct socket___39 *, int, bool);
	int (*getname)(struct socket___39 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___239 *, struct socket___39 *, struct poll_table_struct___162 *);
	int (*ioctl)(struct socket___39 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___39 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___39 *, void *, bool, bool);
	int (*listen)(struct socket___39 *, int);
	int (*shutdown)(struct socket___39 *, int);
	int (*setsockopt)(struct socket___39 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___39 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___214 *, struct socket___39 *);
	int (*sendmsg)(struct socket___39 *, struct msghdr___39 *, size_t);
	int (*recvmsg)(struct socket___39 *, struct msghdr___39 *, size_t, int);
	int (*mmap)(struct file___239 *, struct socket___39 *, struct vm_area_struct___244 *);
	ssize_t (*sendpage)(struct socket___39 *, struct page___244 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___39 *, loff_t *, struct pipe_inode_info___80 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___38 *, int);
	int (*peek_len)(struct socket___39 *);
	int (*read_sock)(struct sock___38 *, read_descriptor_t *, sk_read_actor_t___37);
	int (*sendpage_locked)(struct sock___38 *, struct page___244 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___38 *, struct msghdr___39 *, size_t);
	int (*set_rcvlowat)(struct sock___38 *, int);
};

struct ts_config___2;

struct ts_ops___2 {
	const char *name;
	struct ts_config___2 * (*init)(const void *, unsigned int, gfp_t, int);
	unsigned int (*find)(struct ts_config___2 *, struct ts_state *);
	void (*destroy)(struct ts_config___2 *);
	void * (*get_pattern)(struct ts_config___2 *);
	unsigned int (*get_pattern_len)(struct ts_config___2 *);
	struct module___223 *owner;
	struct list_head list;
};

struct ts_config___2 {
	struct ts_ops___2 *ops;
	int flags;
	unsigned int (*get_next_block)(unsigned int, const u8 **, struct ts_config___2 *, struct ts_state *);
	void (*finish)(struct ts_config___2 *, struct ts_state *);
};

struct dev_pm_ops___220 {
	int (*prepare)(struct device___220 *);
	void (*complete)(struct device___220 *);
	int (*suspend)(struct device___220 *);
	int (*resume)(struct device___220 *);
	int (*freeze)(struct device___220 *);
	int (*thaw)(struct device___220 *);
	int (*poweroff)(struct device___220 *);
	int (*restore)(struct device___220 *);
	int (*suspend_late)(struct device___220 *);
	int (*resume_early)(struct device___220 *);
	int (*freeze_late)(struct device___220 *);
	int (*thaw_early)(struct device___220 *);
	int (*poweroff_late)(struct device___220 *);
	int (*restore_early)(struct device___220 *);
	int (*suspend_noirq)(struct device___220 *);
	int (*resume_noirq)(struct device___220 *);
	int (*freeze_noirq)(struct device___220 *);
	int (*thaw_noirq)(struct device___220 *);
	int (*poweroff_noirq)(struct device___220 *);
	int (*restore_noirq)(struct device___220 *);
	int (*runtime_suspend)(struct device___220 *);
	int (*runtime_resume)(struct device___220 *);
	int (*runtime_idle)(struct device___220 *);
};

struct wakeup_source___220 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___220 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___220 {
	struct dev_pm_ops___220 ops;
	int (*start)(struct device___220 *);
	void (*detach)(struct device___220 *, bool);
	int (*activate)(struct device___220 *);
	void (*sync)(struct device___220 *);
	void (*dismiss)(struct device___220 *);
};

struct bus_type___220 {
	const char *name;
	const char *dev_name;
	struct device___220 *dev_root;
	const struct attribute_group___227 **bus_groups;
	const struct attribute_group___227 **dev_groups;
	const struct attribute_group___227 **drv_groups;
	int (*match)(struct device___220 *, struct device_driver___220 *);
	int (*uevent)(struct device___220 *, struct kobj_uevent_env *);
	int (*probe)(struct device___220 *);
	void (*sync_state)(struct device___220 *);
	void (*remove)(struct device___220 *);
	void (*shutdown)(struct device___220 *);
	int (*online)(struct device___220 *);
	int (*offline)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	int (*num_vf)(struct device___220 *);
	int (*dma_configure)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___220 {
	const char *name;
	struct bus_type___220 *bus;
	struct module___223 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___220 *);
	void (*sync_state)(struct device___220 *);
	int (*remove)(struct device___220 *);
	void (*shutdown)(struct device___220 *);
	int (*suspend)(struct device___220 *, pm_message_t);
	int (*resume)(struct device___220 *);
	const struct attribute_group___227 **groups;
	const struct attribute_group___227 **dev_groups;
	const struct dev_pm_ops___220 *pm;
	void (*coredump)(struct device___220 *);
	struct driver_private *p;
};

struct device_type___220 {
	const char *name;
	const struct attribute_group___227 **groups;
	int (*uevent)(struct device___220 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___220 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___220 *);
	const struct dev_pm_ops___220 *pm;
};

struct class___220 {
	const char *name;
	struct module___223 *owner;
	const struct attribute_group___227 **class_groups;
	const struct attribute_group___227 **dev_groups;
	struct kobject___227 *dev_kobj;
	int (*dev_uevent)(struct device___220 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___220 *, umode_t *);
	void (*class_release)(struct class___220 *);
	void (*dev_release)(struct device___220 *);
	int (*shutdown_pre)(struct device___220 *);
	const struct kobj_ns_type_operations___37 *ns_type;
	const void * (*namespace)(struct device___220 *);
	void (*get_ownership)(struct device___220 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___220 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___80;

struct pipe_buffer___80 {
	struct page___244 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___80 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___80 {
	int (*confirm)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
	void (*release)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
	bool (*try_steal)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
	bool (*get)(struct pipe_inode_info___80 *, struct pipe_buffer___80 *);
};

struct splice_pipe_desc___4 {
	struct page___244 **pages;
	struct partial_page *partial;
	int nr_pages;
	unsigned int nr_pages_max;
	const struct pipe_buf_operations___80 *ops;
	void (*spd_release)(struct splice_pipe_desc___4 *, unsigned int);
};

typedef struct bio_vec___156 skb_frag_t___9;

struct ubuf_info___3 {
	void (*callback)(struct sk_buff___49 *, struct ubuf_info___3 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___9 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___49 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___9 frags[17];
};

enum {
	SKB_FCLONE_UNAVAILABLE = 0,
	SKB_FCLONE_ORIG = 1,
	SKB_FCLONE_CLONE = 2,
};

struct sk_buff_fclones {
	struct sk_buff___49 skb1;
	struct sk_buff___49 skb2;
	refcount_t fclone_ref;
};

struct skb_seq_state {
	__u32 lower_offset;
	__u32 upper_offset;
	__u32 frag_idx;
	__u32 stepped_offset;
	struct sk_buff___49 *root_skb;
	struct sk_buff___49 *cur_skb;
	__u8 *frag_data;
	__u32 frag_off;
};

struct skb_checksum_ops {
	__wsum (*update)(const void *, int, __wsum);
	__wsum (*combine)(__wsum, __wsum, int, int);
};

struct skb_gso_cb {
	union {
		int mac_offset;
		int data_offset;
	};
	int encap_level;
	__wsum csum;
	__u16 csum_start;
};

struct seq_operations___214 {
	void * (*start)(struct seq_file___214 *, loff_t *);
	void (*stop)(struct seq_file___214 *, void *);
	void * (*next)(struct seq_file___214 *, void *, loff_t *);
	int (*show)(struct seq_file___214 *, void *);
};

struct dcbnl_rtnl_ops___48 {
	int (*ieee_getets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___50 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___50 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___50 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___50 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___50 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___50 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___50 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___50 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___50 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___50 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___50 *);
	u8 (*setstate)(struct net_device___50 *, u8);
	void (*getpermhwaddr)(struct net_device___50 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___50 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___50 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___50 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___50 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___50 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___50 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___50 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___50 *, int, u8 *);
	void (*setpfccfg)(struct net_device___50 *, int, u8);
	void (*getpfccfg)(struct net_device___50 *, int, u8 *);
	u8 (*setall)(struct net_device___50 *);
	u8 (*getcap)(struct net_device___50 *, int, u8 *);
	int (*getnumtcs)(struct net_device___50 *, int, u8 *);
	int (*setnumtcs)(struct net_device___50 *, int, u8);
	u8 (*getpfcstate)(struct net_device___50 *);
	void (*setpfcstate)(struct net_device___50 *, u8);
	void (*getbcncfg)(struct net_device___50 *, int, u32 *);
	void (*setbcncfg)(struct net_device___50 *, int, u32);
	void (*getbcnrp)(struct net_device___50 *, int, u8 *);
	void (*setbcnrp)(struct net_device___50 *, int, u8);
	int (*setapp)(struct net_device___50 *, u8, u16, u8);
	int (*getapp)(struct net_device___50 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___50 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___50 *, int, u8);
	u8 (*getdcbx)(struct net_device___50 *);
	u8 (*setdcbx)(struct net_device___50 *, u8);
	int (*peer_getappinfo)(struct net_device___50 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___50 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___50 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___50 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___50 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___50 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___51;

typedef int (*bpf_iter_init_seq_priv_t___50)(void *, struct bpf_iter_aux_info___51 *);

struct bpf_map___51;

struct bpf_iter_aux_info___51 {
	struct bpf_map___51 *map;
};

struct bpf_iter_seq_info___50 {
	const struct seq_operations___214 *seq_ops;
	bpf_iter_init_seq_priv_t___50 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___50 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___51 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___51 *, struct file___239 *);
	void (*map_free)(struct bpf_map___51 *);
	int (*map_get_next_key)(struct bpf_map___51 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___51 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___51 *, void *);
	int (*map_lookup_batch)(struct bpf_map___51 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___51 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___51 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___51 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___51 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___51 *, void *);
	int (*map_update_elem)(struct bpf_map___51 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___51 *, void *);
	int (*map_push_elem)(struct bpf_map___51 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___51 *, void *);
	int (*map_peek_elem)(struct bpf_map___51 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___51 *, struct file___239 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___51 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___51 *, void *, struct seq_file___214 *);
	int (*map_check_btf)(const struct bpf_map___51 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___51 *, struct bpf_prog_aux___51 *);
	void (*map_poke_untrack)(struct bpf_map___51 *, struct bpf_prog_aux___51 *);
	void (*map_poke_run)(struct bpf_map___51 *, u32, struct bpf_prog___44 *, struct bpf_prog___44 *);
	int (*map_direct_value_addr)(const struct bpf_map___51 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___51 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___51 *, struct vm_area_struct___244 *);
	__poll_t (*map_poll)(struct bpf_map___51 *, struct file___239 *, struct poll_table_struct___162 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___51 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___51 *, const struct bpf_map___51 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___51 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___50 *iter_seq_info;
};

struct bpf_map___51 {
	const struct bpf_map_ops___50 *ops;
	struct bpf_map___51 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___106 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___50;

struct bpf_jit_poke_descriptor___50;

struct bpf_prog_ops___44;

struct btf_mod_pair___50;

struct bpf_prog_offload___48;

struct bpf_prog_aux___51 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___44 *dst_prog;
	struct bpf_trampoline___50 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___44 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___50 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___44 *ops;
	struct bpf_map___51 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___50 *used_btfs;
	struct bpf_prog___44 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___51 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___48 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___48;

struct bpf_map_dev_ops___48 {
	int (*map_get_next_key)(struct bpf_offloaded_map___48 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___48 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___48 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___48 *, void *);
};

struct bpf_offloaded_map___48 {
	struct bpf_map___51 map;
	struct net_device___50 *netdev;
	const struct bpf_map_dev_ops___48 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___44 {
	int (*test_run)(struct bpf_prog___44 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___48 {
	struct bpf_prog___44 *prog;
	struct net_device___50 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___50 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___44 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___223 *mod;
};

struct bpf_jit_poke_descriptor___50 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___51 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___50 {
	struct btf *btf;
	struct module___223 *module;
};

struct cftype___166;

struct cgroup_subsys___166 {
	struct cgroup_subsys_state___166 * (*css_alloc)(struct cgroup_subsys_state___166 *);
	int (*css_online)(struct cgroup_subsys_state___166 *);
	void (*css_offline)(struct cgroup_subsys_state___166 *);
	void (*css_released)(struct cgroup_subsys_state___166 *);
	void (*css_free)(struct cgroup_subsys_state___166 *);
	void (*css_reset)(struct cgroup_subsys_state___166 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___166 *, int);
	int (*css_extra_stat_show)(struct seq_file___214 *, struct cgroup_subsys_state___166 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___246 *, struct css_set___166 *);
	void (*cancel_fork)(struct task_struct___246 *, struct css_set___166 *);
	void (*fork)(struct task_struct___246 *);
	void (*exit)(struct task_struct___246 *);
	void (*release)(struct task_struct___246 *);
	void (*bind)(struct cgroup_subsys_state___166 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___166 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___166 *dfl_cftypes;
	struct cftype___166 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___166 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___166 *updated_children;
	struct cgroup___166 *updated_next;
};

struct cgroup_root___166 {
	struct kernfs_root___227 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___166 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___166 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___166 *ss;
	struct list_head node;
	struct kernfs_ops___227 *kf_ops;
	int (*open)(struct kernfs_open_file___227 *);
	void (*release)(struct kernfs_open_file___227 *);
	u64 (*read_u64)(struct cgroup_subsys_state___166 *, struct cftype___166 *);
	s64 (*read_s64)(struct cgroup_subsys_state___166 *, struct cftype___166 *);
	int (*seq_show)(struct seq_file___214 *, void *);
	void * (*seq_start)(struct seq_file___214 *, loff_t *);
	void * (*seq_next)(struct seq_file___214 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___214 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___166 *, struct cftype___166 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___166 *, struct cftype___166 *, s64);
	ssize_t (*write)(struct kernfs_open_file___227 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___227 *, struct poll_table_struct___162 *);
};

struct xdp_rxq_info___48 {
	struct net_device___50 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___48 {
	struct net_device___50 *dev;
};

struct xdp_buff___48 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___48 *rxq;
	struct xdp_txq_info___48 *txq;
	u32 frame_sz;
};

struct xdp_frame___48 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___50 *dev_rx;
};

struct netlink_callback___48 {
	struct sk_buff___49 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___49 *, struct netlink_callback___48 *);
	int (*done)(struct netlink_callback___48 *);
	void *data;
	struct module___223 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___48 {
	int (*create)(struct sk_buff___49 *, struct net_device___50 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___49 *, unsigned char *);
	int (*cache)(const struct neighbour___37 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___50 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___49 *);
};

struct napi_struct___7 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___7 *, int);
	int poll_owner;
	struct net_device___50 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___49 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___246 *thread;
};

struct netdev_queue___48 {
	struct net_device___50 *dev;
	struct Qdisc___44 *qdisc;
	struct Qdisc___44 *qdisc_sleeping;
	struct kobject___227 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___50 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___44 {
	struct sk_buff___49 *head;
	struct sk_buff___49 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___44;

struct Qdisc___44 {
	int (*enqueue)(struct sk_buff___49 *, struct Qdisc___44 *, struct sk_buff___49 **);
	struct sk_buff___49 * (*dequeue)(struct Qdisc___44 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___44 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___48 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___48 gso_skb;
	struct qdisc_skb_head___44 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___44 *next_sched;
	struct sk_buff_head___48 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___48 {
	struct xdp_rxq_info___48 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___227 kobj;
	struct net_device___50 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___48 {
	enum net_device_path_type type;
	const struct net_device___50 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___48 = 0,
				DEV_PATH_BR_VLAN_TAG___48 = 1,
				DEV_PATH_BR_VLAN_UNTAG___48 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___48 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___48 {
	const struct net_device___50 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___48 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___44 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___48 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___48 {
	int (*xdo_dev_state_add)(struct xfrm_state___3 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___3 *);
	void (*xdo_dev_state_free)(struct xfrm_state___3 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___49 *, struct xfrm_state___3 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___3 *);
};

struct xfrm_state_offload___3 {
	struct net_device___50 *dev;
	struct net_device___50 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___3;

struct xfrm_type_offload___3;

struct xfrm_state___3 {
	possible_net_t___48 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___38 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___3 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___3 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___244 xfrag;
	const struct xfrm_type___3 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___3 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___48 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___50 *dev;
	const char *name;
};

struct net_device_ops___48 {
	int (*ndo_init)(struct net_device___50 *);
	void (*ndo_uninit)(struct net_device___50 *);
	int (*ndo_open)(struct net_device___50 *);
	int (*ndo_stop)(struct net_device___50 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___49 *, struct net_device___50 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___49 *, struct net_device___50 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___50 *, struct sk_buff___49 *, struct net_device___50 *);
	void (*ndo_change_rx_flags)(struct net_device___50 *, int);
	void (*ndo_set_rx_mode)(struct net_device___50 *);
	int (*ndo_set_mac_address)(struct net_device___50 *, void *);
	int (*ndo_validate_addr)(struct net_device___50 *);
	int (*ndo_do_ioctl)(struct net_device___50 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___50 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___50 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___50 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___50 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___50 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___50 *, int);
	int (*ndo_neigh_setup)(struct net_device___50 *, struct neigh_parms___37 *);
	void (*ndo_tx_timeout)(struct net_device___50 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___50 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___50 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___50 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___50 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___50 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___50 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___50 *);
	int (*ndo_netpoll_setup)(struct net_device___50 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___50 *);
	int (*ndo_set_vf_mac)(struct net_device___50 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___50 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___50 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___50 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___50 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___50 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___50 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___50 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___50 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___50 *, int, struct sk_buff___49 *);
	int (*ndo_get_vf_guid)(struct net_device___50 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___50 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___50 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___50 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___50 *);
	int (*ndo_fcoe_disable)(struct net_device___50 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___50 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___50 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___50 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___50 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___50 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___50 *, const struct sk_buff___49 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___50 *, struct net_device___50 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___50 *, struct net_device___50 *);
	struct net_device___50 * (*ndo_get_xmit_slave)(struct net_device___50 *, struct sk_buff___49 *, bool);
	struct net_device___50 * (*ndo_sk_get_lower_dev)(struct net_device___50 *, struct sock___38 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___50 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___50 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___50 *, struct neighbour___37 *);
	void (*ndo_neigh_destroy)(struct net_device___50 *, struct neighbour___37 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___49 *, struct netlink_callback___48 *, struct net_device___50 *, struct net_device___50 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___49 *, struct nlattr **, struct net_device___50 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___50 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___49 *, u32, u32, struct net_device___50 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___50 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___50 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___50 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___50 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___50 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___50 *, struct net_device___50 *);
	void (*ndo_dfwd_del_station)(struct net_device___50 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___50 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___50 *);
	int (*ndo_change_proto_down)(struct net_device___50 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___50 *, struct sk_buff___49 *);
	void (*ndo_set_rx_headroom)(struct net_device___50 *, int);
	int (*ndo_bpf)(struct net_device___50 *, struct netdev_bpf___48 *);
	int (*ndo_xdp_xmit)(struct net_device___50 *, int, struct xdp_frame___48 **, u32);
	struct net_device___50 * (*ndo_xdp_get_xmit_slave)(struct net_device___50 *, struct xdp_buff___48 *);
	int (*ndo_xsk_wakeup)(struct net_device___50 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___50 *);
	int (*ndo_tunnel_ctl)(struct net_device___50 *, struct ip_tunnel_parm *, int);
	struct net_device___50 * (*ndo_get_peer_dev)(struct net_device___50 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___48 *, struct net_device_path___48 *);
};

struct neigh_parms___37 {
	possible_net_t___48 net;
	struct net_device___50 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___37 *);
	struct neigh_table___37 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___37 {
	u32 (*l3mdev_fib_table)(const struct net_device___50 *);
	struct sk_buff___49 * (*l3mdev_l3_rcv)(struct net_device___50 *, struct sk_buff___49 *, u16);
	struct sk_buff___49 * (*l3mdev_l3_out)(struct net_device___50 *, struct sock___38 *, struct sk_buff___49 *, u16);
	struct dst_entry___37 * (*l3mdev_link_scope_lookup)(const struct net_device___50 *, struct flowi6 *);
};

struct ndisc_ops___25 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___50 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___50 *, struct neighbour___37 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___50 *, u8, struct neighbour___37 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___50 *, struct sk_buff___49 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___53 *, struct net_device___50 *, const struct prefix_info *, struct inet6_dev___25 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___25;

struct ifacaddr6___4;

struct inet6_dev___25 {
	struct net_device___50 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___25 *mc_list;
	struct ifmcaddr6___25 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___48 mc_query_queue;
	struct sk_buff_head___48 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___4 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___37 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___44;

struct tcf_block___44;

struct mini_Qdisc___44 {
	struct tcf_proto___44 *filter_list;
	struct tcf_block___44 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___44 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___50 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___50 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___53 *, struct net_device___50 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___50 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___50 *, struct list_head *);
	size_t (*get_size)(const struct net_device___50 *);
	int (*fill_info)(struct sk_buff___49 *, const struct net_device___50 *);
	size_t (*get_xstats_size)(const struct net_device___50 *);
	int (*fill_xstats)(struct sk_buff___49 *, const struct net_device___50 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___50 *, struct net_device___50 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___50 *, const struct net_device___50 *);
	int (*fill_slave_info)(struct sk_buff___49 *, const struct net_device___50 *, const struct net_device___50 *);
	struct net___53 * (*get_link_net)(const struct net_device___50 *);
	size_t (*get_linkxstats_size)(const struct net_device___50 *, int);
	int (*fill_linkxstats)(struct sk_buff___49 *, const struct net_device___50 *, int *, int);
};

struct napi_gro_cb {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___49 *last;
};

struct block_device_operations___132;

struct gendisk___135 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___135 *part0;
	const struct block_device_operations___132 *fops;
	struct request_queue___132 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___118 *bdi;
	struct kobject___227 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___227 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___132 {
	struct bio___132 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___156 *bip_vec;
	struct bio_vec___156 bip_inline_vecs[0];
};

struct blkcg___120;

struct blkg_policy_data___120;

struct blkcg_gq___120 {
	struct request_queue___132 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___120 *blkcg;
	struct blkcg_gq___120 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___120 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___132 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___132(struct request___132 *);

typedef void integrity_complete_fn___132(struct request___132 *, unsigned int);

struct blk_integrity_profile___132 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___132 *prepare_fn;
	integrity_complete_fn___132 *complete_fn;
	const char *name;
};

struct block_device_operations___132 {
	blk_qc_t (*submit_bio)(struct bio___132 *);
	int (*open)(struct block_device___135 *, fmode_t);
	void (*release)(struct gendisk___135 *, fmode_t);
	int (*rw_page)(struct block_device___135 *, sector_t, struct page___244 *, unsigned int);
	int (*ioctl)(struct block_device___135 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___135 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___135 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___135 *);
	int (*getgeo)(struct block_device___135 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___135 *, bool);
	void (*swap_slot_free_notify)(struct block_device___135 *, long unsigned int);
	int (*report_zones)(struct gendisk___135 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___135 *, umode_t *);
	struct module___223 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___135 *, sector_t *);
};

typedef void rq_end_io_fn___132(struct request___132 *, blk_status_t);

struct request___132 {
	struct request_queue___132 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___127 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___132 *bio;
	struct bio___132 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___156 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___132 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___132 *saved_end_io;
		} flush;
	};
	struct gendisk___135 *rq_disk;
	struct block_device___135 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___132 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___127 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___132 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___227 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___239 *debugfs_dir;
	struct dentry___239 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___132;

struct elevator_mq_ops___132 {
	int (*init_sched)(struct request_queue___132 *, struct elevator_type___132 *);
	void (*exit_sched)(struct elevator_queue___132 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___127 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___127 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___127 *);
	bool (*allow_merge)(struct request_queue___132 *, struct request___132 *, struct bio___132 *);
	bool (*bio_merge)(struct request_queue___132 *, struct bio___132 *, unsigned int);
	int (*request_merge)(struct request_queue___132 *, struct request___132 **, struct bio___132 *);
	void (*request_merged)(struct request_queue___132 *, struct request___132 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___132 *, struct request___132 *, struct request___132 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___132 *);
	void (*finish_request)(struct request___132 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___127 *, struct list_head *, bool);
	struct request___132 * (*dispatch_request)(struct blk_mq_hw_ctx___127 *);
	bool (*has_work)(struct blk_mq_hw_ctx___127 *);
	void (*completed_request)(struct request___132 *, u64);
	void (*requeue_request)(struct request___132 *);
	struct request___132 * (*former_request)(struct request_queue___132 *, struct request___132 *);
	struct request___132 * (*next_request)(struct request_queue___132 *, struct request___132 *);
	void (*init_icq)(struct io_cq___132 *);
	void (*exit_icq)(struct io_cq___132 *);
};

struct elv_fs_entry___132;

struct elevator_type___132 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___132 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___132 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___223 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___132 {
	struct elevator_type___132 *type;
	void *elevator_data;
	struct kobject___227 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___132 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___132 *, char *);
	ssize_t (*store)(struct elevator_queue___132 *, const char *, size_t);
};

struct blk_mq_queue_data___127;

struct blk_mq_ops___127 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___127 *, const struct blk_mq_queue_data___127 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___127 *);
	int (*get_budget)(struct request_queue___132 *);
	void (*put_budget)(struct request_queue___132 *, int);
	void (*set_rq_budget_token)(struct request___132 *, int);
	int (*get_rq_budget_token)(struct request___132 *);
	enum blk_eh_timer_return (*timeout)(struct request___132 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___127 *);
	void (*complete)(struct request___132 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___127 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___127 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___127 *, struct request___132 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___127 *, struct request___132 *, unsigned int);
	void (*initialize_rq_fn)(struct request___132 *);
	void (*cleanup_rq)(struct request___132 *);
	bool (*busy)(struct request_queue___132 *);
	int (*map_queues)(struct blk_mq_tag_set___127 *);
	void (*show_rq)(struct seq_file___214 *, struct request___132 *);
};

struct blk_mq_tag_set___127 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___127 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___127 {
	struct request___132 *rq;
	bool last;
};

struct blkcg_policy_data___120;

struct blkcg___120 {
	struct cgroup_subsys_state___166 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___120 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___120 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___120 {
	struct blkcg___120 *blkcg;
	int plid;
};

struct blkg_policy_data___120 {
	struct blkcg_gq___120 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___106 {
	struct mem_cgroup___106 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___106 {
	struct lruvec___114 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___106 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___106 *memcg;
};

struct obj_cgroup___106 {
	struct percpu_ref refcnt;
	struct mem_cgroup___106 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___44 {
	spinlock_t *lock;
	struct sk_buff___49 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___44;

struct Qdisc_ops___44 {
	struct Qdisc_ops___44 *next;
	const struct Qdisc_class_ops___44 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___49 *, struct Qdisc___44 *, struct sk_buff___49 **);
	struct sk_buff___49 * (*dequeue)(struct Qdisc___44 *);
	struct sk_buff___49 * (*peek)(struct Qdisc___44 *);
	int (*init)(struct Qdisc___44 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___44 *);
	void (*destroy)(struct Qdisc___44 *);
	int (*change)(struct Qdisc___44 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___44 *);
	int (*change_tx_queue_len)(struct Qdisc___44 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___44 *, unsigned int);
	int (*dump)(struct Qdisc___44 *, struct sk_buff___49 *);
	int (*dump_stats)(struct Qdisc___44 *, struct gnet_dump___44 *);
	void (*ingress_block_set)(struct Qdisc___44 *, u32);
	void (*egress_block_set)(struct Qdisc___44 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___44 *);
	u32 (*egress_block_get)(struct Qdisc___44 *);
	struct module___223 *owner;
};

struct qdisc_walker___2;

struct Qdisc_class_ops___44 {
	unsigned int flags;
	struct netdev_queue___48 * (*select_queue)(struct Qdisc___44 *, struct tcmsg *);
	int (*graft)(struct Qdisc___44 *, long unsigned int, struct Qdisc___44 *, struct Qdisc___44 **, struct netlink_ext_ack *);
	struct Qdisc___44 * (*leaf)(struct Qdisc___44 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___44 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___44 *, u32);
	int (*change)(struct Qdisc___44 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___44 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___44 *, struct qdisc_walker___2 *);
	struct tcf_block___44 * (*tcf_block)(struct Qdisc___44 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___44 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___44 *, long unsigned int);
	int (*dump)(struct Qdisc___44 *, long unsigned int, struct sk_buff___49 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___44 *, long unsigned int, struct gnet_dump___44 *);
};

struct qdisc_walker___2 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___44 *, long unsigned int, struct qdisc_walker___2 *);
};

struct tcf_chain___44;

struct tcf_block___44 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___53 *net;
	struct Qdisc___44 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___44 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___44;

struct tcf_proto_ops___44;

struct tcf_proto___44 {
	struct tcf_proto___44 *next;
	void *root;
	int (*classify)(struct sk_buff___49 *, const struct tcf_proto___44 *, struct tcf_result___44 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___44 *ops;
	struct tcf_chain___44 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___44 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___44 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___44 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___49 *, const struct tcf_proto___44 *, struct tcf_result___44 *);
	int (*init)(struct tcf_proto___44 *);
	void (*destroy)(struct tcf_proto___44 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___44 *, u32);
	void (*put)(struct tcf_proto___44 *, void *);
	int (*change)(struct net___53 *, struct sk_buff___49 *, struct tcf_proto___44 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___44 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___44 *);
	void (*walk)(struct tcf_proto___44 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___44 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___44 *, void *);
	void (*hw_del)(struct tcf_proto___44 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___53 *, struct tcf_chain___44 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___53 *, struct tcf_proto___44 *, void *, struct sk_buff___49 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___53 *, struct tcf_proto___44 *, void *, struct sk_buff___49 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___49 *, struct net___53 *, void *);
	struct module___223 *owner;
	int flags;
};

struct tcf_chain___44 {
	struct mutex filter_chain_lock;
	struct tcf_proto___44 *filter_chain;
	struct list_head list;
	struct tcf_block___44 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___44 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___37 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___44 *prog;
};

struct pneigh_entry___37;

struct neigh_hash_table___37;

struct neigh_table___37 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___50 *, __u32 *);
	bool (*key_eq)(const struct neighbour___37 *, const void *);
	int (*constructor)(struct neighbour___37 *);
	int (*pconstructor)(struct pneigh_entry___37 *);
	void (*pdestructor)(struct pneigh_entry___37 *);
	void (*proxy_redo)(struct sk_buff___49 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___50 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___37 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___48 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___37 *nht;
	struct pneigh_entry___37 **phash_buckets;
};

struct neigh_ops___37 {
	int family;
	void (*solicit)(struct neighbour___37 *, struct sk_buff___49 *);
	void (*error_report)(struct neighbour___37 *, struct sk_buff___49 *);
	int (*output)(struct neighbour___37 *, struct sk_buff___49 *);
	int (*connected_output)(struct neighbour___37 *, struct sk_buff___49 *);
};

struct pneigh_entry___37 {
	struct pneigh_entry___37 *next;
	possible_net_t___48 net;
	struct net_device___50 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___37 {
	struct neighbour___37 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___20 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___53 *, struct sock___38 *, struct sk_buff___49 *);
	int (*orig_input)(struct sk_buff___49 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___37 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___37 *ctarget;
	struct net___53 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___37 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___37 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___27;

struct timewait_sock_ops___27;

struct proto___37 {
	void (*close)(struct sock___38 *, long int);
	int (*pre_connect)(struct sock___38 *, struct sockaddr *, int);
	int (*connect)(struct sock___38 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___38 *, int);
	struct sock___38 * (*accept)(struct sock___38 *, int, int *, bool);
	int (*ioctl)(struct sock___38 *, int, long unsigned int);
	int (*init)(struct sock___38 *);
	void (*destroy)(struct sock___38 *);
	void (*shutdown)(struct sock___38 *, int);
	int (*setsockopt)(struct sock___38 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___38 *, int, int, char *, int *);
	void (*keepalive)(struct sock___38 *, int);
	int (*compat_ioctl)(struct sock___38 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___38 *, struct msghdr___39 *, size_t);
	int (*recvmsg)(struct sock___38 *, struct msghdr___39 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___38 *, struct page___244 *, int, size_t, int);
	int (*bind)(struct sock___38 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___38 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___38 *, struct sk_buff___49 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___38 *);
	int (*hash)(struct sock___38 *);
	void (*unhash)(struct sock___38 *);
	void (*rehash)(struct sock___38 *);
	int (*get_port)(struct sock___38 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___38 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___38 *, int);
	bool (*sock_is_readable)(struct sock___38 *);
	void (*enter_memory_pressure)(struct sock___38 *);
	void (*leave_memory_pressure)(struct sock___38 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___27 *rsk_prot;
	struct timewait_sock_ops___27 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___223 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___38 *, int);
};

struct xfrm_policy_queue___3 {
	struct sk_buff_head___48 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___3 {
	possible_net_t___48 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___3 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___8 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___44 *prog;
	struct sock___38 *socks[0];
};

struct request_sock___28;

struct request_sock_ops___27 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___38 *, struct request_sock___28 *);
	void (*send_ack)(const struct sock___38 *, struct sk_buff___49 *, struct request_sock___28 *);
	void (*send_reset)(const struct sock___38 *, struct sk_buff___49 *);
	void (*destructor)(struct request_sock___28 *);
	void (*syn_ack_timeout)(const struct request_sock___28 *);
};

struct timewait_sock_ops___27 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___38 *, struct sock___38 *, void *);
	void (*twsk_destructor)(struct sock___38 *);
};

struct request_sock___28 {
	struct sock_common___37 __req_common;
	struct request_sock___28 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___27 *rsk_ops;
	struct sock___38 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ip_auth_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__be16 reserved;
	__be32 spi;
	__be32 seq_no;
	__u8 auth_data[0];
};

struct ifmcaddr6___25 {
	struct in6_addr mca_addr;
	struct inet6_dev___25 *idev;
	struct ifmcaddr6___25 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___4 {
	struct in6_addr aca_addr;
	struct fib6_info___4 *aca_rt;
	struct ifacaddr6___4 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct frag_hdr {
	__u8 nexthdr;
	__u8 reserved;
	__be16 frag_off;
	__be32 identification;
};

struct fib_nh_exception___4 {
	struct fib_nh_exception___4 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___4 *fnhe_rth_input;
	struct rtable___4 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___4 {
	struct dst_entry___37 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___4 {
	struct fib_nh_exception___4 *chain;
};

enum {
	SCM_TSTAMP_SND = 0,
	SCM_TSTAMP_SCHED = 1,
	SCM_TSTAMP_ACK = 2,
};

struct xfrm_type___3 {
	struct module___223 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___3 *);
	void (*destructor)(struct xfrm_state___3 *);
	int (*input)(struct xfrm_state___3 *, struct sk_buff___49 *);
	int (*output)(struct xfrm_state___3 *, struct sk_buff___49 *);
	int (*reject)(struct xfrm_state___3 *, struct sk_buff___49 *, const struct flowi *);
};

struct xfrm_type_offload___3 {
	struct module___223 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___3 *, struct sk_buff___49 *);
	int (*input_tail)(struct xfrm_state___3 *, struct sk_buff___49 *);
	int (*xmit)(struct xfrm_state___3 *, struct sk_buff___49 *, netdev_features_t);
};

struct sec_path___2 {
	int len;
	int olen;
	struct xfrm_state___3 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct mpls_shim_hdr {
	__be32 label_stack_entry;
};

struct napi_alloc_cache {
	struct page_frag_cache page;
	unsigned int skb_count;
	void *skb_cache[64];
};

typedef int (*sendmsg_func)(struct sock___38 *, struct msghdr___39 *, struct kvec *, size_t, size_t);

typedef int (*sendpage_func)(struct sock___38 *, struct page___244 *, int, size_t, int);

struct dentry___240;

struct super_block___240;

struct module___224;

struct file_system_type___240 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___240 * (*mount)(struct file_system_type___240 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___240 *);
	struct module___224 *owner;
	struct file_system_type___240 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___240;

struct kiocb___240;

struct iov_iter___160;

struct poll_table_struct___163;

struct vm_area_struct___245;

struct inode___240;

struct file_lock___240;

struct page___245;

struct pipe_inode_info___81;

struct seq_file___215;

struct file_operations___241 {
	struct module___224 *owner;
	loff_t (*llseek)(struct file___240 *, loff_t, int);
	ssize_t (*read)(struct file___240 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___240 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___240 *, struct iov_iter___160 *);
	ssize_t (*write_iter)(struct kiocb___240 *, struct iov_iter___160 *);
	int (*iopoll)(struct kiocb___240 *, bool);
	int (*iterate)(struct file___240 *, struct dir_context *);
	int (*iterate_shared)(struct file___240 *, struct dir_context *);
	__poll_t (*poll)(struct file___240 *, struct poll_table_struct___163 *);
	long int (*unlocked_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___240 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___240 *, struct vm_area_struct___245 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___240 *, struct file___240 *);
	int (*flush)(struct file___240 *, fl_owner_t);
	int (*release)(struct inode___240 *, struct file___240 *);
	int (*fsync)(struct file___240 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___240 *, int);
	int (*lock)(struct file___240 *, int, struct file_lock___240 *);
	ssize_t (*sendpage)(struct file___240 *, struct page___245 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___240 *, long unsigned int);
	int (*flock)(struct file___240 *, int, struct file_lock___240 *);
	ssize_t (*splice_write)(struct pipe_inode_info___81 *, struct file___240 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___240 *, loff_t *, struct pipe_inode_info___81 *, size_t, unsigned int);
	int (*setlease)(struct file___240 *, long int, struct file_lock___240 **, void **);
	long int (*fallocate)(struct file___240 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___215 *, struct file___240 *);
	ssize_t (*copy_file_range)(struct file___240 *, loff_t, struct file___240 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___240 *, loff_t, struct file___240 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___240 *, loff_t, loff_t, int);
};

struct vmacache___245 {
	u64 seqnum;
	struct vm_area_struct___245 *vmas[4];
};

struct page_frag___245 {
	struct page___245 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___246;

struct pid___217;

struct nsproxy___226;

struct signal_struct___241;

struct bio_list___133;

struct backing_dev_info___119;

struct io_context___133;

struct css_set___167;

struct mem_cgroup___107;

struct request_queue___133;

struct vm_struct___223;

struct task_struct___247 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___247 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___246 *mm;
	struct mm_struct___246 *active_mm;
	struct vmacache___245 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___247 *real_parent;
	struct task_struct___247 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___247 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___217 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___13 *ptracer_cred;
	const struct cred___13 *real_cred;
	const struct cred___13 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___226 *nsproxy;
	struct signal_struct___241 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___247 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___133 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___119 *backing_dev_info;
	struct io_context___133 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___167 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___81 *splice_pipe;
	struct page_frag___245 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___107 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___107 *active_memcg;
	struct request_queue___133 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___247 *oom_reaper_list;
	struct vm_struct___223 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___228;

struct kobj_type___228;

struct kernfs_node___228;

struct kobject___228 {
	const char *name;
	struct list_head entry;
	struct kobject___228 *parent;
	struct kset___228 *kset;
	struct kobj_type___228 *ktype;
	struct kernfs_node___228 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___225 {
	struct kobject___228 kobj;
	struct module___224 *mod;
	struct kobject___228 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___224 {
	struct module___224 *mod;
	struct latch_tree_node node;
};

struct module_layout___224 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___224 mtn;
};

struct module_attribute___224;

struct kernel_param___224;

struct module___224 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___225 mkobj;
	struct module_attribute___224 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___228 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___224 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___224 core_layout;
	struct module_layout___224 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___217;

struct upid___217 {
	int nr;
	struct pid_namespace___217 *ns;
};

struct pid_namespace___217 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___247 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___217 *parent;
	struct fs_pin *bacct;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	int reboot;
	struct ns_common___14 ns;
};

struct pid___217 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___217 numbers[1];
};

typedef struct page___245 *pgtable_t___245;

struct address_space___240;

struct page_pool___69;

struct dev_pagemap___235;

struct page___245 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___240 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___69 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___245 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___245 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___246 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___235 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___235;

struct vm_area_struct___245 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___245 *vm_next;
	struct vm_area_struct___245 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___246 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___235 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___240 *vm_file;
	struct file___240 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___241 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___247 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___247 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___217 *pids[4];
	struct pid___217 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___246 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___245;

struct mm_struct___246 {
	struct {
		struct vm_area_struct___245 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___240 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___245 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___247 *owner;
		struct user_namespace___14 *user_ns;
		struct file___240 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___54;

struct cgroup_namespace___167;

struct nsproxy___226 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___217 *pid_ns_for_children;
	struct net___54 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___167 *cgroup_ns;
};

struct bio___133;

struct bio_list___133 {
	struct bio___133 *head;
	struct bio___133 *tail;
};

struct cgroup_subsys_state___167;

struct bdi_writeback___119 {
	struct backing_dev_info___119 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___167 *memcg_css;
	struct cgroup_subsys_state___167 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___221;

struct backing_dev_info___119 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___119 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___221 *dev;
	char dev_name[64];
	struct device___221 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___240 *debug_dir;
};

struct io_cq___133;

struct io_context___133 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___133 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___167;

struct css_set___167 {
	struct cgroup_subsys_state___167 *subsys[14];
	refcount_t refcount;
	struct css_set___167 *dom_cset;
	struct cgroup___167 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___167 *mg_src_cgrp;
	struct cgroup___167 *mg_dst_cgrp;
	struct css_set___167 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___240;

struct pipe_buffer___81;

struct pipe_inode_info___81 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___245 *tmp_page;
	struct fasync_struct___240 *fasync_readers;
	struct fasync_struct___240 *fasync_writers;
	struct pipe_buffer___81 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___167;

struct cgroup_subsys_state___167 {
	struct cgroup___167 *cgroup;
	struct cgroup_subsys___167 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___167 *parent;
};

struct cgroup_file___167 {
	struct kernfs_node___228 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___107;

struct mem_cgroup_per_node___107;

struct mem_cgroup___107 {
	struct cgroup_subsys_state___167 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___167 events_file;
	struct cgroup_file___167 events_local_file;
	struct cgroup_file___167 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___107 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___247 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___107 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___133;

struct blk_integrity___133 {
	const struct blk_integrity_profile___133 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___133 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___133 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___133;

struct elevator_queue___133;

struct blk_mq_ops___128;

struct blk_mq_hw_ctx___128;

struct gendisk___136;

struct blkcg_gq___121;

struct blk_mq_tag_set___128;

struct request_queue___133 {
	struct request___133 *last_merge;
	struct elevator_queue___133 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___128 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___128 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___136 *disk;
	struct kobject___228 kobj;
	struct kobject___228 *mq_kobj;
	struct blk_integrity___133 integrity;
	struct device___221 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___121 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___128 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___133 bio_split;
	struct dentry___240 *debugfs_dir;
	struct dentry___240 *sched_debugfs_dir;
	struct dentry___240 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___223 {
	struct vm_struct___223 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___245 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___240;

struct address_space___240 {
	struct inode___240 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___240 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___69 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___221 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___69 {
	u32 count;
	struct page___245 *cache[128];
};

struct page_pool___69 {
	struct page_pool_params___69 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___245 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___69 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___235;

struct dev_pagemap___235 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___235 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___240;

struct path___240 {
	struct vfsmount___240 *mnt;
	struct dentry___240 *dentry;
};

struct fown_struct___217 {
	rwlock_t lock;
	struct pid___217 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___240 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___240 f_path;
	struct inode___240 *f_inode;
	const struct file_operations___241 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___217 f_owner;
	const struct cred___13 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___240 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___235;

struct vm_operations_struct___235 {
	void (*open)(struct vm_area_struct___245 *);
	void (*close)(struct vm_area_struct___245 *);
	int (*may_split)(struct vm_area_struct___245 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___245 *);
	int (*mprotect)(struct vm_area_struct___245 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___235 *);
	vm_fault_t (*huge_fault)(struct vm_fault___235 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___235 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___245 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___235 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___235 *);
	int (*access)(struct vm_area_struct___245 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___245 *);
	int (*set_policy)(struct vm_area_struct___245 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___245 *, long unsigned int);
	struct page___245 * (*find_special_page)(struct vm_area_struct___245 *, long unsigned int);
};

struct core_thread___245 {
	struct task_struct___247 *task;
	struct core_thread___245 *next;
};

struct core_state___245 {
	atomic_t nr_threads;
	struct core_thread___245 dumper;
	struct completion startup;
};

struct vm_fault___235 {
	const struct {
		struct vm_area_struct___245 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___245 *cow_page;
	struct page___245 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___245 prealloc_pte;
};

struct pglist_data___115;

struct lruvec___115 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___115 *pgdat;
};

struct zone___115 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___115 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___115 {
	struct zone___115 *zone;
	int zone_idx;
};

struct zonelist___115 {
	struct zoneref___115 _zonerefs[321];
};

struct pglist_data___115 {
	struct zone___115 node_zones[5];
	struct zonelist___115 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___247 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___247 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___115 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___240;

struct dentry___240 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___240 *d_parent;
	struct qstr d_name;
	struct inode___240 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___240 *d_op;
	struct super_block___240 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___240;

struct inode___240 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___240 *i_op;
	struct super_block___240 *i_sb;
	struct address_space___240 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___119 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___241 *i_fop;
		void (*free_inode)(struct inode___240 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___240 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___81 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___240 {
	int (*d_revalidate)(struct dentry___240 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___240 *, unsigned int);
	int (*d_hash)(const struct dentry___240 *, struct qstr *);
	int (*d_compare)(const struct dentry___240 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___240 *);
	int (*d_init)(struct dentry___240 *);
	void (*d_release)(struct dentry___240 *);
	void (*d_prune)(struct dentry___240 *);
	void (*d_iput)(struct dentry___240 *, struct inode___240 *);
	char * (*d_dname)(struct dentry___240 *, char *, int);
	struct vfsmount___240 * (*d_automount)(struct path___240 *);
	int (*d_manage)(const struct path___240 *, bool);
	struct dentry___240 * (*d_real)(struct dentry___240 *, const struct inode___240 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___240;

struct mem_dqinfo___240 {
	struct quota_format_type___240 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___240;

struct quota_info___240 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___240 *files[3];
	struct mem_dqinfo___240 info[3];
	const struct quota_format_ops___240 *ops[3];
};

struct rcuwait___241 {
	struct task_struct___247 *task;
};

struct percpu_rw_semaphore___241 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___241 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___240 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___241 rw_sem[3];
};

struct shrink_control___107;

struct shrinker___107 {
	long unsigned int (*count_objects)(struct shrinker___107 *, struct shrink_control___107 *);
	long unsigned int (*scan_objects)(struct shrinker___107 *, struct shrink_control___107 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___240;

struct dquot_operations___240;

struct quotactl_ops___240;

struct block_device___136;

struct super_block___240 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___240 *s_type;
	const struct super_operations___240 *s_op;
	const struct dquot_operations___240 *dq_op;
	const struct quotactl_ops___240 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___240 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___136 *s_bdev;
	struct backing_dev_info___119 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___240 s_dquot;
	struct sb_writers___240 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___240 *s_d_op;
	int cleancache_poolid;
	struct shrinker___107 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___14 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___240 {
	struct dentry___240 *mnt_root;
	struct super_block___240 *mnt_sb;
	int mnt_flags;
	struct user_namespace___14 *mnt_userns;
};

struct shrink_control___107 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___107 *memcg;
};

struct psi_group___167 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___247 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___45;

struct cgroup_bpf___45 {
	struct bpf_prog_array___45 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___45 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___167;

struct cgroup_rstat_cpu___167;

struct cgroup___167 {
	struct cgroup_subsys_state___167 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___228 *kn;
	struct cgroup_file___167 procs_file;
	struct cgroup_file___167 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___167 *subsys[14];
	struct cgroup_root___167 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___167 *dom_cgrp;
	struct cgroup___167 *old_dom_cgrp;
	struct cgroup_rstat_cpu___167 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___167 psi;
	struct cgroup_bpf___45 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___133 {
	struct request_queue___133 *q;
	struct io_context___133 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___114;

struct kiocb___240 {
	struct file___240 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___240 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___240 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___240 *ia_file;
};

struct dquot___240 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___240 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___240 {
	int qf_fmt_id;
	const struct quota_format_ops___240 *qf_ops;
	struct module___224 *qf_owner;
	struct quota_format_type___240 *qf_next;
};

struct quota_format_ops___240 {
	int (*check_quota_file)(struct super_block___240 *, int);
	int (*read_file_info)(struct super_block___240 *, int);
	int (*write_file_info)(struct super_block___240 *, int);
	int (*free_file_info)(struct super_block___240 *, int);
	int (*read_dqblk)(struct dquot___240 *);
	int (*commit_dqblk)(struct dquot___240 *);
	int (*release_dqblk)(struct dquot___240 *);
	int (*get_next_id)(struct super_block___240 *, struct kqid *);
};

struct dquot_operations___240 {
	int (*write_dquot)(struct dquot___240 *);
	struct dquot___240 * (*alloc_dquot)(struct super_block___240 *, int);
	void (*destroy_dquot)(struct dquot___240 *);
	int (*acquire_dquot)(struct dquot___240 *);
	int (*release_dquot)(struct dquot___240 *);
	int (*mark_dirty)(struct dquot___240 *);
	int (*write_info)(struct super_block___240 *, int);
	qsize_t * (*get_reserved_space)(struct inode___240 *);
	int (*get_projid)(struct inode___240 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___240 *, qsize_t *);
	int (*get_next_id)(struct super_block___240 *, struct kqid *);
};

struct quotactl_ops___240 {
	int (*quota_on)(struct super_block___240 *, int, int, const struct path___240 *);
	int (*quota_off)(struct super_block___240 *, int);
	int (*quota_enable)(struct super_block___240 *, unsigned int);
	int (*quota_disable)(struct super_block___240 *, unsigned int);
	int (*quota_sync)(struct super_block___240 *, int);
	int (*set_info)(struct super_block___240 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___240 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___240 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___240 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___240 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___240 *, unsigned int);
};

struct wait_page_queue___114 {
	struct page___245 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___119;

struct readahead_control___114;

struct address_space_operations___240 {
	int (*writepage)(struct page___245 *, struct writeback_control___119 *);
	int (*readpage)(struct file___240 *, struct page___245 *);
	int (*writepages)(struct address_space___240 *, struct writeback_control___119 *);
	int (*set_page_dirty)(struct page___245 *);
	int (*readpages)(struct file___240 *, struct address_space___240 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___114 *);
	int (*write_begin)(struct file___240 *, struct address_space___240 *, loff_t, unsigned int, unsigned int, struct page___245 **, void **);
	int (*write_end)(struct file___240 *, struct address_space___240 *, loff_t, unsigned int, unsigned int, struct page___245 *, void *);
	sector_t (*bmap)(struct address_space___240 *, sector_t);
	void (*invalidatepage)(struct page___245 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___245 *, gfp_t);
	void (*freepage)(struct page___245 *);
	ssize_t (*direct_IO)(struct kiocb___240 *, struct iov_iter___160 *);
	int (*migratepage)(struct address_space___240 *, struct page___245 *, struct page___245 *, enum migrate_mode);
	bool (*isolate_page)(struct page___245 *, isolate_mode_t);
	void (*putback_page)(struct page___245 *);
	int (*launder_page)(struct page___245 *);
	int (*is_partially_uptodate)(struct page___245 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___245 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___240 *, struct page___245 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___240 *, sector_t *);
	void (*swap_deactivate)(struct file___240 *);
};

struct writeback_control___119 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___119 *wb;
	struct inode___240 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___114 {
	struct file___240 *file;
	struct address_space___240 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___157;

struct iov_iter___160 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___157 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___81 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___240 {
	struct dentry___240 * (*lookup)(struct inode___240 *, struct dentry___240 *, unsigned int);
	const char * (*get_link)(struct dentry___240 *, struct inode___240 *, struct delayed_call *);
	int (*permission)(struct user_namespace___14 *, struct inode___240 *, int);
	struct posix_acl * (*get_acl)(struct inode___240 *, int, bool);
	int (*readlink)(struct dentry___240 *, char *, int);
	int (*create)(struct user_namespace___14 *, struct inode___240 *, struct dentry___240 *, umode_t, bool);
	int (*link)(struct dentry___240 *, struct inode___240 *, struct dentry___240 *);
	int (*unlink)(struct inode___240 *, struct dentry___240 *);
	int (*symlink)(struct user_namespace___14 *, struct inode___240 *, struct dentry___240 *, const char *);
	int (*mkdir)(struct user_namespace___14 *, struct inode___240 *, struct dentry___240 *, umode_t);
	int (*rmdir)(struct inode___240 *, struct dentry___240 *);
	int (*mknod)(struct user_namespace___14 *, struct inode___240 *, struct dentry___240 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___14 *, struct inode___240 *, struct dentry___240 *, struct inode___240 *, struct dentry___240 *, unsigned int);
	int (*setattr)(struct user_namespace___14 *, struct dentry___240 *, struct iattr___240 *);
	int (*getattr)(struct user_namespace___14 *, const struct path___240 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___240 *, char *, size_t);
	int (*fiemap)(struct inode___240 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___240 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___240 *, struct dentry___240 *, struct file___240 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___14 *, struct inode___240 *, struct dentry___240 *, umode_t);
	int (*set_acl)(struct user_namespace___14 *, struct inode___240 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___14 *, struct dentry___240 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___240 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___240 {
	void (*fl_copy_lock)(struct file_lock___240 *, struct file_lock___240 *);
	void (*fl_release_private)(struct file_lock___240 *);
};

struct lock_manager_operations___240;

struct file_lock___240 {
	struct file_lock___240 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___240 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___240 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___240 *fl_ops;
	const struct lock_manager_operations___240 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___240 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___240 *);
	int (*lm_grant)(struct file_lock___240 *, int);
	bool (*lm_break)(struct file_lock___240 *);
	int (*lm_change)(struct file_lock___240 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___240 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___240 *);
};

struct fasync_struct___240 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___240 *fa_next;
	struct file___240 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___240 {
	struct inode___240 * (*alloc_inode)(struct super_block___240 *);
	void (*destroy_inode)(struct inode___240 *);
	void (*free_inode)(struct inode___240 *);
	void (*dirty_inode)(struct inode___240 *, int);
	int (*write_inode)(struct inode___240 *, struct writeback_control___119 *);
	int (*drop_inode)(struct inode___240 *);
	void (*evict_inode)(struct inode___240 *);
	void (*put_super)(struct super_block___240 *);
	int (*sync_fs)(struct super_block___240 *, int);
	int (*freeze_super)(struct super_block___240 *);
	int (*freeze_fs)(struct super_block___240 *);
	int (*thaw_super)(struct super_block___240 *);
	int (*unfreeze_fs)(struct super_block___240 *);
	int (*statfs)(struct dentry___240 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___240 *, int *, char *);
	void (*umount_begin)(struct super_block___240 *);
	int (*show_options)(struct seq_file___215 *, struct dentry___240 *);
	int (*show_devname)(struct seq_file___215 *, struct dentry___240 *);
	int (*show_path)(struct seq_file___215 *, struct dentry___240 *);
	int (*show_stats)(struct seq_file___215 *, struct dentry___240 *);
	ssize_t (*quota_read)(struct super_block___240 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___240 *, int, const char *, size_t, loff_t);
	struct dquot___240 ** (*get_dquots)(struct inode___240 *);
	long int (*nr_cached_objects)(struct super_block___240 *, struct shrink_control___107 *);
	long int (*free_cached_objects)(struct super_block___240 *, struct shrink_control___107 *);
	struct file___240 * (*real_loop)(struct file___240 *);
};

struct wakeup_source___221;

struct dev_pm_info___221 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___221 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___221 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___221;

struct bus_type___221;

struct device_driver___221;

struct dev_pm_domain___221;

struct fwnode_handle___217;

struct class___221;

struct attribute_group___228;

struct device___221 {
	struct kobject___228 kobj;
	struct device___221 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___221 *type;
	struct bus_type___221 *bus;
	struct device_driver___221 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___221 power;
	struct dev_pm_domain___221 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___217 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___221 *class;
	const struct attribute_group___228 **groups;
	void (*release)(struct device___221 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___136 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___240 *bd_inode;
	struct super_block___240 *bd_super;
	void *bd_claiming;
	struct device___221 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___228 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___136 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___240 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___171)(struct file___240 *, wait_queue_head_t *, struct poll_table_struct___163 *);

struct poll_table_struct___163 {
	poll_queue_proc___171 _qproc;
	__poll_t _key;
};

struct seq_operations___215;

struct seq_file___215 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___215 *op;
	int poll_event;
	const struct file___240 *file;
	void *private;
};

typedef void bio_end_io_t___133(struct bio___133 *);

struct bio_vec___157 {
	struct page___245 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___133;

struct bio___133 {
	struct bio___133 *bi_next;
	struct block_device___136 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___133 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___121 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___133 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___157 *bi_io_vec;
	struct bio_set___133 *bi_pool;
	struct bio_vec___157 bi_inline_vecs[0];
};

struct kernfs_root___228;

struct kernfs_elem_dir___228 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___228 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___228;

struct kernfs_root___228 {
	struct kernfs_node___228 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___228 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___228 {
	struct kernfs_node___228 *target_kn;
};

struct kernfs_ops___228;

struct kernfs_elem_attr___228 {
	const struct kernfs_ops___228 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___228 *notify_next;
};

struct kernfs_node___228 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___228 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___228 dir;
		struct kernfs_elem_symlink___228 symlink;
		struct kernfs_elem_attr___228 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___228;

struct kernfs_ops___228 {
	int (*open)(struct kernfs_open_file___228 *);
	void (*release)(struct kernfs_open_file___228 *);
	int (*seq_show)(struct seq_file___215 *, void *);
	void * (*seq_start)(struct seq_file___215 *, loff_t *);
	void * (*seq_next)(struct seq_file___215 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___215 *, void *);
	ssize_t (*read)(struct kernfs_open_file___228 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___228 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___228 *, struct poll_table_struct___163 *);
	int (*mmap)(struct kernfs_open_file___228 *, struct vm_area_struct___245 *);
};

struct kernfs_syscall_ops___228 {
	int (*show_options)(struct seq_file___215 *, struct kernfs_root___228 *);
	int (*mkdir)(struct kernfs_node___228 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___228 *);
	int (*rename)(struct kernfs_node___228 *, struct kernfs_node___228 *, const char *);
	int (*show_path)(struct seq_file___215 *, struct kernfs_node___228 *, struct kernfs_root___228 *);
};

struct kernfs_open_file___228 {
	struct kernfs_node___228 *kn;
	struct file___240 *file;
	struct seq_file___215 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___235 *vm_ops;
};

struct sock___39;

struct kobj_ns_type_operations___38 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___39 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___54 *net;
} possible_net_t___49;

struct proto___38;

struct sock_common___38 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___38 *skc_prot;
	possible_net_t___49 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___39 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___50;

struct sk_buff_head___49 {
	struct sk_buff___50 *next;
	struct sk_buff___50 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___38 {
	struct cgroup___167 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___38;

struct socket_wq___39;

struct dst_entry___38;

struct socket___40;

struct net_device___51;

struct sock___39 {
	struct sock_common___38 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___49 sk_error_queue;
	struct sk_buff___50 *sk_rx_skb_cache;
	struct sk_buff_head___49 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___50 *head;
		struct sk_buff___50 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___38 *sk_filter;
	union {
		struct socket_wq___39 *sk_wq;
		struct socket_wq___39 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___38 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___38 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___50 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___50 *sk_tx_skb_cache;
	struct sk_buff_head___49 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___245 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___38 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___217 *sk_peer_pid;
	const struct cred___13 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___40 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___38 sk_cgrp_data;
	struct mem_cgroup___107 *sk_memcg;
	void (*sk_state_change)(struct sock___39 *);
	void (*sk_data_ready)(struct sock___39 *);
	void (*sk_write_space)(struct sock___39 *);
	void (*sk_error_report)(struct sock___39 *);
	int (*sk_backlog_rcv)(struct sock___39 *, struct sk_buff___50 *);
	struct sk_buff___50 * (*sk_validate_xmit_skb)(struct sock___39 *, struct net_device___51 *, struct sk_buff___50 *);
	void (*sk_destruct)(struct sock___39 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___228;

struct attribute_group___228 {
	const char *name;
	umode_t (*is_visible)(struct kobject___228 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___228 *, struct bin_attribute___228 *, int);
	struct attribute **attrs;
	struct bin_attribute___228 **bin_attrs;
};

struct bin_attribute___228 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___240 * (*f_mapping)();
	ssize_t (*read)(struct file___240 *, struct kobject___228 *, struct bin_attribute___228 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___240 *, struct kobject___228 *, struct bin_attribute___228 *, char *, loff_t, size_t);
	int (*mmap)(struct file___240 *, struct kobject___228 *, struct bin_attribute___228 *, struct vm_area_struct___245 *);
};

struct sysfs_ops___228 {
	ssize_t (*show)(struct kobject___228 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___228 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___228;

struct kset___228 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___228 kobj;
	const struct kset_uevent_ops___228 *uevent_ops;
};

struct kobj_type___228 {
	void (*release)(struct kobject___228 *);
	const struct sysfs_ops___228 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___228 **default_groups;
	const struct kobj_ns_type_operations___38 * (*child_ns_type)(struct kobject___228 *);
	const void * (*namespace)(struct kobject___228 *);
	void (*get_ownership)(struct kobject___228 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___228 {
	int (* const filter)(struct kset___228 *, struct kobject___228 *);
	const char * (* const name)(struct kset___228 *, struct kobject___228 *);
	int (* const uevent)(struct kset___228 *, struct kobject___228 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___224 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___224 *);
	int (*get)(char *, const struct kernel_param___224 *);
	void (*free)(void *);
};

struct kparam_array___224;

struct kernel_param___224 {
	const char *name;
	struct module___224 *mod;
	const struct kernel_param_ops___224 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___224 *arr;
	};
};

struct kparam_array___224 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___224 *ops;
	void *elem;
};

struct module_attribute___224 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___224 *, struct module_kobject___225 *, char *);
	ssize_t (*store)(struct module_attribute___224 *, struct module_kobject___225 *, const char *, size_t);
	void (*setup)(struct module___224 *, const char *);
	int (*test)(struct module___224 *);
	void (*free)(struct module___224 *);
};

struct dev_pagemap_ops___235 {
	void (*page_free)(struct page___245 *);
	void (*kill)(struct dev_pagemap___235 *);
	void (*cleanup)(struct dev_pagemap___235 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___235 *);
};

struct fwnode_operations___217;

struct fwnode_handle___217 {
	struct fwnode_handle___217 *secondary;
	const struct fwnode_operations___217 *ops;
	struct device___221 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___217;

struct fwnode_endpoint___217;

struct fwnode_operations___217 {
	struct fwnode_handle___217 * (*get)(struct fwnode_handle___217 *);
	void (*put)(struct fwnode_handle___217 *);
	bool (*device_is_available)(const struct fwnode_handle___217 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___217 *, const struct device___221 *);
	bool (*property_present)(const struct fwnode_handle___217 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___217 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___217 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___217 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*get_parent)(const struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*get_next_child_node)(const struct fwnode_handle___217 *, struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*get_named_child_node)(const struct fwnode_handle___217 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___217 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___217 *);
	struct fwnode_handle___217 * (*graph_get_next_endpoint)(const struct fwnode_handle___217 *, struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*graph_get_remote_endpoint)(const struct fwnode_handle___217 *);
	struct fwnode_handle___217 * (*graph_get_port_parent)(struct fwnode_handle___217 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___217 *, struct fwnode_endpoint___217 *);
	int (*add_links)(struct fwnode_handle___217 *);
};

struct fwnode_endpoint___217 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___217 *local_fwnode;
};

struct fwnode_reference_args___217 {
	struct fwnode_handle___217 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct msghdr___40 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___160 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___240 *msg_iocb;
};

struct sk_buff___50 {
	union {
		struct {
			struct sk_buff___50 *next;
			struct sk_buff___50 *prev;
			union {
				struct net_device___51 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___39 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___50 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___54;

struct fqdir___54 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___54 *f;
	struct net___54 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___54;

struct inet_frags___54 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___54 *, const void *);
	void (*destructor)(struct inet_frag_queue___54 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___20;

struct fib_rules_ops___38;

struct fib_notifier_ops___38;

struct netns_ipv4___54 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___20 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___38 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___39 *fibnl;
	struct sock___39 **icmp_sk;
	struct sock___39 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___39 **tcp_sk;
	struct fqdir___54 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___38 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___38 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___38 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___38;

struct dst_ops___54 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___54 *);
	struct dst_entry___38 * (*check)(struct dst_entry___38 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___38 *);
	unsigned int (*mtu)(const struct dst_entry___38 *);
	u32 * (*cow_metrics)(struct dst_entry___38 *, long unsigned int);
	void (*destroy)(struct dst_entry___38 *);
	void (*ifdown)(struct dst_entry___38 *, struct net_device___51 *, int);
	struct dst_entry___38 * (*negative_advice)(struct dst_entry___38 *);
	void (*link_failure)(struct sk_buff___50 *);
	void (*update_pmtu)(struct dst_entry___38 *, struct sock___39 *, struct sk_buff___50 *, u32, bool);
	void (*redirect)(struct dst_entry___38 *, struct sock___39 *, struct sk_buff___50 *);
	int (*local_out)(struct net___54 *, struct sock___39 *, struct sk_buff___50 *);
	struct neighbour___38 * (*neigh_lookup)(const struct dst_entry___38 *, struct sk_buff___50 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___38 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___54 {
	struct dst_ops___54 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___54 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___38 *fib6_rules_ops;
	struct sock___39 **icmp_sk;
	struct sock___39 *ndisc_sk;
	struct sock___39 *tcp_sk;
	struct sock___39 *igmp_sk;
	struct sock___39 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___38 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___38 *notifier_ops;
	struct fib_notifier_ops___38 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___54 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___54 *fqdir;
};

struct netns_sctp___38 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___39 *ctl_sock;
	struct sock___39 *udp4_sock;
	struct sock___39 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___45;

struct netns_bpf___45 {
	struct bpf_prog_array___45 *run_array[2];
	struct bpf_prog___45 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___54 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___39 *nlsk;
	struct sock___39 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___54 xfrm4_dst_ops;
	struct dst_ops___54 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___54 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct idr netns_ids;
	struct ns_common___14 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___39 *rtnl;
	struct sock___39 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___51 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___54 ipv4;
	struct netns_ipv6___54 ipv6;
	struct netns_ieee802154_lowpan___54 ieee802154_lowpan;
	struct netns_sctp___38 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___49 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___45 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___54 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___39 *crypto_nlsk;
	struct sock___39 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___54 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___50 *fragments_tail;
	struct sk_buff___50 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___54 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___20 {
	struct ip_ra_chain___20 *next;
	struct sock___39 *sk;
	union {
		void (*destructor)(struct sock___39 *);
		struct sock___39 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___38;

struct fib_lookup_arg___38;

struct fib_rules_ops___38 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___38 *, struct flowi *, int, struct fib_lookup_arg___38 *);
	bool (*suppress)(struct fib_rule___38 *, int, struct fib_lookup_arg___38 *);
	int (*match)(struct fib_rule___38 *, struct flowi *, int);
	int (*configure)(struct fib_rule___38 *, struct sk_buff___50 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___38 *);
	int (*compare)(struct fib_rule___38 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___38 *, struct sk_buff___50 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___38 *);
	void (*flush_cache)(struct fib_rules_ops___38 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___224 *owner;
	struct net___54 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___38 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___54 *);
	int (*fib_dump)(struct net___54 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___224 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___21;

struct dst_entry___38 {
	struct net_device___51 *dev;
	struct dst_ops___54 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___50 *);
	int (*output)(struct net___54 *, struct sock___39 *, struct sk_buff___50 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___21 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___49(struct sk_buff___50 **);

struct bpf_xdp_entity___45 {
	struct bpf_prog___45 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___49;

struct net_device_ops___49;

struct l3mdev_ops___38;

struct ndisc_ops___26;

struct xfrmdev_ops___49;

struct header_ops___49;

struct inet6_dev___26;

struct netdev_rx_queue___49;

struct mini_Qdisc___45;

struct netdev_queue___49;

struct Qdisc___45;

struct rtnl_link_ops___45;

struct dcbnl_rtnl_ops___49;

struct net_device___51 {
	char name[16];
	struct netdev_name_node___49 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___49 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___38 *l3mdev_ops;
	const struct ndisc_ops___26 *ndisc_ops;
	const struct xfrmdev_ops___49 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___49 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___228 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___26 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___49 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___45 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___49 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___45 *miniq_ingress;
	struct netdev_queue___49 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___49 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___45 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___45 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___49 = 0,
		NETREG_REGISTERED___49 = 1,
		NETREG_UNREGISTERING___49 = 2,
		NETREG_UNREGISTERED___49 = 3,
		NETREG_RELEASED___49 = 4,
		NETREG_DUMMY___49 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___49 = 0,
		RTNL_LINK_INITIALIZING___49 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___51 *);
	struct netpoll_info *npinfo;
	possible_net_t___49 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___221 dev;
	const struct attribute_group___228 *sysfs_groups[4];
	const struct attribute_group___228 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___45 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___49 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___45 xdp_state[3];
	long: 64;
};

struct neigh_table___38;

struct neigh_parms___38;

struct neigh_ops___38;

struct neighbour___38 {
	struct neighbour___38 *next;
	struct neigh_table___38 *tbl;
	struct neigh_parms___38 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___49 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___38 *, struct sk_buff___50 *);
	const struct neigh_ops___38 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___51 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___45 {
	struct bpf_prog___45 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___45 {
	struct callback_head rcu;
	struct bpf_prog_array_item___45 items[0];
};

struct bpf_prog_aux___52;

struct bpf_prog___45 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___52 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct cgroup_namespace___167 {
	struct ns_common___14 ns;
	struct user_namespace___14 *user_ns;
	struct ucounts___14 *ucounts;
	struct css_set___167 *root_cset;
};

struct socket_wq___39 {
	wait_queue_head_t wait;
	struct fasync_struct___240 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___39;

struct socket___40 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___240 *file;
	struct sock___39 *sk;
	const struct proto_ops___39 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___39 wq;
};

typedef int (*sk_read_actor_t___38)(read_descriptor_t *, struct sk_buff___50 *, unsigned int, size_t);

struct proto_ops___39 {
	int family;
	struct module___224 *owner;
	int (*release)(struct socket___40 *);
	int (*bind)(struct socket___40 *, struct sockaddr *, int);
	int (*connect)(struct socket___40 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___40 *, struct socket___40 *);
	int (*accept)(struct socket___40 *, struct socket___40 *, int, bool);
	int (*getname)(struct socket___40 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___240 *, struct socket___40 *, struct poll_table_struct___163 *);
	int (*ioctl)(struct socket___40 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___40 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___40 *, void *, bool, bool);
	int (*listen)(struct socket___40 *, int);
	int (*shutdown)(struct socket___40 *, int);
	int (*setsockopt)(struct socket___40 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___40 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___215 *, struct socket___40 *);
	int (*sendmsg)(struct socket___40 *, struct msghdr___40 *, size_t);
	int (*recvmsg)(struct socket___40 *, struct msghdr___40 *, size_t, int);
	int (*mmap)(struct file___240 *, struct socket___40 *, struct vm_area_struct___245 *);
	ssize_t (*sendpage)(struct socket___40 *, struct page___245 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___40 *, loff_t *, struct pipe_inode_info___81 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___39 *, int);
	int (*peek_len)(struct socket___40 *);
	int (*read_sock)(struct sock___39 *, read_descriptor_t *, sk_read_actor_t___38);
	int (*sendpage_locked)(struct sock___39 *, struct page___245 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___39 *, struct msghdr___40 *, size_t);
	int (*set_rcvlowat)(struct sock___39 *, int);
};

struct dev_pm_ops___221 {
	int (*prepare)(struct device___221 *);
	void (*complete)(struct device___221 *);
	int (*suspend)(struct device___221 *);
	int (*resume)(struct device___221 *);
	int (*freeze)(struct device___221 *);
	int (*thaw)(struct device___221 *);
	int (*poweroff)(struct device___221 *);
	int (*restore)(struct device___221 *);
	int (*suspend_late)(struct device___221 *);
	int (*resume_early)(struct device___221 *);
	int (*freeze_late)(struct device___221 *);
	int (*thaw_early)(struct device___221 *);
	int (*poweroff_late)(struct device___221 *);
	int (*restore_early)(struct device___221 *);
	int (*suspend_noirq)(struct device___221 *);
	int (*resume_noirq)(struct device___221 *);
	int (*freeze_noirq)(struct device___221 *);
	int (*thaw_noirq)(struct device___221 *);
	int (*poweroff_noirq)(struct device___221 *);
	int (*restore_noirq)(struct device___221 *);
	int (*runtime_suspend)(struct device___221 *);
	int (*runtime_resume)(struct device___221 *);
	int (*runtime_idle)(struct device___221 *);
};

struct wakeup_source___221 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___221 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___221 {
	struct dev_pm_ops___221 ops;
	int (*start)(struct device___221 *);
	void (*detach)(struct device___221 *, bool);
	int (*activate)(struct device___221 *);
	void (*sync)(struct device___221 *);
	void (*dismiss)(struct device___221 *);
};

struct bus_type___221 {
	const char *name;
	const char *dev_name;
	struct device___221 *dev_root;
	const struct attribute_group___228 **bus_groups;
	const struct attribute_group___228 **dev_groups;
	const struct attribute_group___228 **drv_groups;
	int (*match)(struct device___221 *, struct device_driver___221 *);
	int (*uevent)(struct device___221 *, struct kobj_uevent_env *);
	int (*probe)(struct device___221 *);
	void (*sync_state)(struct device___221 *);
	void (*remove)(struct device___221 *);
	void (*shutdown)(struct device___221 *);
	int (*online)(struct device___221 *);
	int (*offline)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	int (*num_vf)(struct device___221 *);
	int (*dma_configure)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___221 {
	const char *name;
	struct bus_type___221 *bus;
	struct module___224 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___221 *);
	void (*sync_state)(struct device___221 *);
	int (*remove)(struct device___221 *);
	void (*shutdown)(struct device___221 *);
	int (*suspend)(struct device___221 *, pm_message_t);
	int (*resume)(struct device___221 *);
	const struct attribute_group___228 **groups;
	const struct attribute_group___228 **dev_groups;
	const struct dev_pm_ops___221 *pm;
	void (*coredump)(struct device___221 *);
	struct driver_private *p;
};

struct device_type___221 {
	const char *name;
	const struct attribute_group___228 **groups;
	int (*uevent)(struct device___221 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___221 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___221 *);
	const struct dev_pm_ops___221 *pm;
};

struct class___221 {
	const char *name;
	struct module___224 *owner;
	const struct attribute_group___228 **class_groups;
	const struct attribute_group___228 **dev_groups;
	struct kobject___228 *dev_kobj;
	int (*dev_uevent)(struct device___221 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___221 *, umode_t *);
	void (*class_release)(struct class___221 *);
	void (*dev_release)(struct device___221 *);
	int (*shutdown_pre)(struct device___221 *);
	const struct kobj_ns_type_operations___38 *ns_type;
	const void * (*namespace)(struct device___221 *);
	void (*get_ownership)(struct device___221 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___221 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___81;

struct pipe_buffer___81 {
	struct page___245 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___81 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___81 {
	int (*confirm)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
	void (*release)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
	bool (*try_steal)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
	bool (*get)(struct pipe_inode_info___81 *, struct pipe_buffer___81 *);
};

typedef struct bio_vec___157 skb_frag_t___10;

struct skb_shared_info___10 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___50 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___10 frags[17];
};

struct seq_operations___215 {
	void * (*start)(struct seq_file___215 *, loff_t *);
	void (*stop)(struct seq_file___215 *, void *);
	void * (*next)(struct seq_file___215 *, void *, loff_t *);
	int (*show)(struct seq_file___215 *, void *);
};

struct dcbnl_rtnl_ops___49 {
	int (*ieee_getets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___51 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___51 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___51 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___51 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___51 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___51 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___51 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___51 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___51 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___51 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___51 *);
	u8 (*setstate)(struct net_device___51 *, u8);
	void (*getpermhwaddr)(struct net_device___51 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___51 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___51 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___51 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___51 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___51 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___51 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___51 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___51 *, int, u8 *);
	void (*setpfccfg)(struct net_device___51 *, int, u8);
	void (*getpfccfg)(struct net_device___51 *, int, u8 *);
	u8 (*setall)(struct net_device___51 *);
	u8 (*getcap)(struct net_device___51 *, int, u8 *);
	int (*getnumtcs)(struct net_device___51 *, int, u8 *);
	int (*setnumtcs)(struct net_device___51 *, int, u8);
	u8 (*getpfcstate)(struct net_device___51 *);
	void (*setpfcstate)(struct net_device___51 *, u8);
	void (*getbcncfg)(struct net_device___51 *, int, u32 *);
	void (*setbcncfg)(struct net_device___51 *, int, u32);
	void (*getbcnrp)(struct net_device___51 *, int, u8 *);
	void (*setbcnrp)(struct net_device___51 *, int, u8);
	int (*setapp)(struct net_device___51 *, u8, u16, u8);
	int (*getapp)(struct net_device___51 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___51 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___51 *, int, u8);
	u8 (*getdcbx)(struct net_device___51 *);
	u8 (*setdcbx)(struct net_device___51 *, u8);
	int (*peer_getappinfo)(struct net_device___51 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___51 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___51 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___51 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___51 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___51 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___52;

typedef int (*bpf_iter_init_seq_priv_t___51)(void *, struct bpf_iter_aux_info___52 *);

struct bpf_map___52;

struct bpf_iter_aux_info___52 {
	struct bpf_map___52 *map;
};

struct bpf_iter_seq_info___51 {
	const struct seq_operations___215 *seq_ops;
	bpf_iter_init_seq_priv_t___51 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___51 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___52 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___52 *, struct file___240 *);
	void (*map_free)(struct bpf_map___52 *);
	int (*map_get_next_key)(struct bpf_map___52 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___52 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___52 *, void *);
	int (*map_lookup_batch)(struct bpf_map___52 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___52 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___52 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___52 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___52 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___52 *, void *);
	int (*map_update_elem)(struct bpf_map___52 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___52 *, void *);
	int (*map_push_elem)(struct bpf_map___52 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___52 *, void *);
	int (*map_peek_elem)(struct bpf_map___52 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___52 *, struct file___240 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___52 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___52 *, void *, struct seq_file___215 *);
	int (*map_check_btf)(const struct bpf_map___52 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___52 *, struct bpf_prog_aux___52 *);
	void (*map_poke_untrack)(struct bpf_map___52 *, struct bpf_prog_aux___52 *);
	void (*map_poke_run)(struct bpf_map___52 *, u32, struct bpf_prog___45 *, struct bpf_prog___45 *);
	int (*map_direct_value_addr)(const struct bpf_map___52 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___52 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___52 *, struct vm_area_struct___245 *);
	__poll_t (*map_poll)(struct bpf_map___52 *, struct file___240 *, struct poll_table_struct___163 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___52 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___52 *, const struct bpf_map___52 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___52 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___51 *iter_seq_info;
};

struct bpf_map___52 {
	const struct bpf_map_ops___51 *ops;
	struct bpf_map___52 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___107 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___51;

struct bpf_jit_poke_descriptor___51;

struct bpf_prog_ops___45;

struct btf_mod_pair___51;

struct bpf_prog_offload___49;

struct bpf_prog_aux___52 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___45 *dst_prog;
	struct bpf_trampoline___51 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___45 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___51 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___45 *ops;
	struct bpf_map___52 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___51 *used_btfs;
	struct bpf_prog___45 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___52 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___49 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___49;

struct bpf_map_dev_ops___49 {
	int (*map_get_next_key)(struct bpf_offloaded_map___49 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___49 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___49 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___49 *, void *);
};

struct bpf_offloaded_map___49 {
	struct bpf_map___52 map;
	struct net_device___51 *netdev;
	const struct bpf_map_dev_ops___49 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___45 {
	int (*test_run)(struct bpf_prog___45 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___49 {
	struct bpf_prog___45 *prog;
	struct net_device___51 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___51 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___45 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___224 *mod;
};

struct bpf_jit_poke_descriptor___51 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___52 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___51 {
	struct btf *btf;
	struct module___224 *module;
};

struct cftype___167;

struct cgroup_subsys___167 {
	struct cgroup_subsys_state___167 * (*css_alloc)(struct cgroup_subsys_state___167 *);
	int (*css_online)(struct cgroup_subsys_state___167 *);
	void (*css_offline)(struct cgroup_subsys_state___167 *);
	void (*css_released)(struct cgroup_subsys_state___167 *);
	void (*css_free)(struct cgroup_subsys_state___167 *);
	void (*css_reset)(struct cgroup_subsys_state___167 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___167 *, int);
	int (*css_extra_stat_show)(struct seq_file___215 *, struct cgroup_subsys_state___167 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___247 *, struct css_set___167 *);
	void (*cancel_fork)(struct task_struct___247 *, struct css_set___167 *);
	void (*fork)(struct task_struct___247 *);
	void (*exit)(struct task_struct___247 *);
	void (*release)(struct task_struct___247 *);
	void (*bind)(struct cgroup_subsys_state___167 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___167 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___167 *dfl_cftypes;
	struct cftype___167 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___167 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___167 *updated_children;
	struct cgroup___167 *updated_next;
};

struct cgroup_root___167 {
	struct kernfs_root___228 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___167 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___167 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___167 *ss;
	struct list_head node;
	struct kernfs_ops___228 *kf_ops;
	int (*open)(struct kernfs_open_file___228 *);
	void (*release)(struct kernfs_open_file___228 *);
	u64 (*read_u64)(struct cgroup_subsys_state___167 *, struct cftype___167 *);
	s64 (*read_s64)(struct cgroup_subsys_state___167 *, struct cftype___167 *);
	int (*seq_show)(struct seq_file___215 *, void *);
	void * (*seq_start)(struct seq_file___215 *, loff_t *);
	void * (*seq_next)(struct seq_file___215 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___215 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___167 *, struct cftype___167 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___167 *, struct cftype___167 *, s64);
	ssize_t (*write)(struct kernfs_open_file___228 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___228 *, struct poll_table_struct___163 *);
};

struct xdp_rxq_info___49 {
	struct net_device___51 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___49 {
	struct net_device___51 *dev;
};

struct xdp_buff___49 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___49 *rxq;
	struct xdp_txq_info___49 *txq;
	u32 frame_sz;
};

struct xdp_frame___49 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___51 *dev_rx;
};

struct netlink_callback___49 {
	struct sk_buff___50 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___50 *, struct netlink_callback___49 *);
	int (*done)(struct netlink_callback___49 *);
	void *data;
	struct module___224 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___49 {
	int (*create)(struct sk_buff___50 *, struct net_device___51 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___50 *, unsigned char *);
	int (*cache)(const struct neighbour___38 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___51 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___50 *);
};

struct netdev_queue___49 {
	struct net_device___51 *dev;
	struct Qdisc___45 *qdisc;
	struct Qdisc___45 *qdisc_sleeping;
	struct kobject___228 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___51 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___45 {
	struct sk_buff___50 *head;
	struct sk_buff___50 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___45;

struct Qdisc___45 {
	int (*enqueue)(struct sk_buff___50 *, struct Qdisc___45 *, struct sk_buff___50 **);
	struct sk_buff___50 * (*dequeue)(struct Qdisc___45 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___45 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___49 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___49 gso_skb;
	struct qdisc_skb_head___45 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___45 *next_sched;
	struct sk_buff_head___49 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___49 {
	struct xdp_rxq_info___49 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___228 kobj;
	struct net_device___51 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___49 {
	enum net_device_path_type type;
	const struct net_device___51 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___49 = 0,
				DEV_PATH_BR_VLAN_TAG___49 = 1,
				DEV_PATH_BR_VLAN_UNTAG___49 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___49 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___49 {
	const struct net_device___51 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___49 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___45 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___49 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___49 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___50 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___49 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___51 *dev;
	const char *name;
};

struct net_device_ops___49 {
	int (*ndo_init)(struct net_device___51 *);
	void (*ndo_uninit)(struct net_device___51 *);
	int (*ndo_open)(struct net_device___51 *);
	int (*ndo_stop)(struct net_device___51 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___50 *, struct net_device___51 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___50 *, struct net_device___51 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___51 *, struct sk_buff___50 *, struct net_device___51 *);
	void (*ndo_change_rx_flags)(struct net_device___51 *, int);
	void (*ndo_set_rx_mode)(struct net_device___51 *);
	int (*ndo_set_mac_address)(struct net_device___51 *, void *);
	int (*ndo_validate_addr)(struct net_device___51 *);
	int (*ndo_do_ioctl)(struct net_device___51 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___51 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___51 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___51 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___51 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___51 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___51 *, int);
	int (*ndo_neigh_setup)(struct net_device___51 *, struct neigh_parms___38 *);
	void (*ndo_tx_timeout)(struct net_device___51 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___51 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___51 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___51 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___51 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___51 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___51 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___51 *);
	int (*ndo_netpoll_setup)(struct net_device___51 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___51 *);
	int (*ndo_set_vf_mac)(struct net_device___51 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___51 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___51 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___51 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___51 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___51 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___51 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___51 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___51 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___51 *, int, struct sk_buff___50 *);
	int (*ndo_get_vf_guid)(struct net_device___51 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___51 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___51 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___51 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___51 *);
	int (*ndo_fcoe_disable)(struct net_device___51 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___51 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___51 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___51 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___51 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___51 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___51 *, const struct sk_buff___50 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___51 *, struct net_device___51 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___51 *, struct net_device___51 *);
	struct net_device___51 * (*ndo_get_xmit_slave)(struct net_device___51 *, struct sk_buff___50 *, bool);
	struct net_device___51 * (*ndo_sk_get_lower_dev)(struct net_device___51 *, struct sock___39 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___51 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___51 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___51 *, struct neighbour___38 *);
	void (*ndo_neigh_destroy)(struct net_device___51 *, struct neighbour___38 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___50 *, struct netlink_callback___49 *, struct net_device___51 *, struct net_device___51 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___50 *, struct nlattr **, struct net_device___51 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___51 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___50 *, u32, u32, struct net_device___51 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___51 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___51 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___51 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___51 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___51 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___51 *, struct net_device___51 *);
	void (*ndo_dfwd_del_station)(struct net_device___51 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___51 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___51 *);
	int (*ndo_change_proto_down)(struct net_device___51 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___51 *, struct sk_buff___50 *);
	void (*ndo_set_rx_headroom)(struct net_device___51 *, int);
	int (*ndo_bpf)(struct net_device___51 *, struct netdev_bpf___49 *);
	int (*ndo_xdp_xmit)(struct net_device___51 *, int, struct xdp_frame___49 **, u32);
	struct net_device___51 * (*ndo_xdp_get_xmit_slave)(struct net_device___51 *, struct xdp_buff___49 *);
	int (*ndo_xsk_wakeup)(struct net_device___51 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___51 *);
	int (*ndo_tunnel_ctl)(struct net_device___51 *, struct ip_tunnel_parm *, int);
	struct net_device___51 * (*ndo_get_peer_dev)(struct net_device___51 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___49 *, struct net_device_path___49 *);
};

struct neigh_parms___38 {
	possible_net_t___49 net;
	struct net_device___51 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___38 *);
	struct neigh_table___38 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___38 {
	u32 (*l3mdev_fib_table)(const struct net_device___51 *);
	struct sk_buff___50 * (*l3mdev_l3_rcv)(struct net_device___51 *, struct sk_buff___50 *, u16);
	struct sk_buff___50 * (*l3mdev_l3_out)(struct net_device___51 *, struct sock___39 *, struct sk_buff___50 *, u16);
	struct dst_entry___38 * (*l3mdev_link_scope_lookup)(const struct net_device___51 *, struct flowi6 *);
};

struct ndisc_ops___26 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___51 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___51 *, struct neighbour___38 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___51 *, u8, struct neighbour___38 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___51 *, struct sk_buff___50 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___54 *, struct net_device___51 *, const struct prefix_info *, struct inet6_dev___26 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___26;

struct inet6_dev___26 {
	struct net_device___51 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___26 *mc_list;
	struct ifmcaddr6___26 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___49 mc_query_queue;
	struct sk_buff_head___49 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___4 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___38 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___45;

struct tcf_block___45;

struct mini_Qdisc___45 {
	struct tcf_proto___45 *filter_list;
	struct tcf_block___45 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___45 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___51 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___51 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___54 *, struct net_device___51 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___51 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___51 *, struct list_head *);
	size_t (*get_size)(const struct net_device___51 *);
	int (*fill_info)(struct sk_buff___50 *, const struct net_device___51 *);
	size_t (*get_xstats_size)(const struct net_device___51 *);
	int (*fill_xstats)(struct sk_buff___50 *, const struct net_device___51 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___51 *, struct net_device___51 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___51 *, const struct net_device___51 *);
	int (*fill_slave_info)(struct sk_buff___50 *, const struct net_device___51 *, const struct net_device___51 *);
	struct net___54 * (*get_link_net)(const struct net_device___51 *);
	size_t (*get_linkxstats_size)(const struct net_device___51 *, int);
	int (*fill_linkxstats)(struct sk_buff___50 *, const struct net_device___51 *, int *, int);
};

typedef struct poll_table_struct___163 poll_table___48;

struct block_device_operations___133;

struct gendisk___136 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___136 *part0;
	const struct block_device_operations___133 *fops;
	struct request_queue___133 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___119 *bdi;
	struct kobject___228 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___228 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___133 {
	struct bio___133 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___157 *bip_vec;
	struct bio_vec___157 bip_inline_vecs[0];
};

struct blkcg___121;

struct blkg_policy_data___121;

struct blkcg_gq___121 {
	struct request_queue___133 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___121 *blkcg;
	struct blkcg_gq___121 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___121 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___133 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___133(struct request___133 *);

typedef void integrity_complete_fn___133(struct request___133 *, unsigned int);

struct blk_integrity_profile___133 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___133 *prepare_fn;
	integrity_complete_fn___133 *complete_fn;
	const char *name;
};

struct block_device_operations___133 {
	blk_qc_t (*submit_bio)(struct bio___133 *);
	int (*open)(struct block_device___136 *, fmode_t);
	void (*release)(struct gendisk___136 *, fmode_t);
	int (*rw_page)(struct block_device___136 *, sector_t, struct page___245 *, unsigned int);
	int (*ioctl)(struct block_device___136 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___136 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___136 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___136 *);
	int (*getgeo)(struct block_device___136 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___136 *, bool);
	void (*swap_slot_free_notify)(struct block_device___136 *, long unsigned int);
	int (*report_zones)(struct gendisk___136 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___136 *, umode_t *);
	struct module___224 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___136 *, sector_t *);
};

typedef void rq_end_io_fn___133(struct request___133 *, blk_status_t);

struct request___133 {
	struct request_queue___133 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___128 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___133 *bio;
	struct bio___133 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___157 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___133 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___133 *saved_end_io;
		} flush;
	};
	struct gendisk___136 *rq_disk;
	struct block_device___136 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___133 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___128 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___133 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___228 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___240 *debugfs_dir;
	struct dentry___240 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___133;

struct elevator_mq_ops___133 {
	int (*init_sched)(struct request_queue___133 *, struct elevator_type___133 *);
	void (*exit_sched)(struct elevator_queue___133 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___128 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___128 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___128 *);
	bool (*allow_merge)(struct request_queue___133 *, struct request___133 *, struct bio___133 *);
	bool (*bio_merge)(struct request_queue___133 *, struct bio___133 *, unsigned int);
	int (*request_merge)(struct request_queue___133 *, struct request___133 **, struct bio___133 *);
	void (*request_merged)(struct request_queue___133 *, struct request___133 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___133 *, struct request___133 *, struct request___133 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___133 *);
	void (*finish_request)(struct request___133 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___128 *, struct list_head *, bool);
	struct request___133 * (*dispatch_request)(struct blk_mq_hw_ctx___128 *);
	bool (*has_work)(struct blk_mq_hw_ctx___128 *);
	void (*completed_request)(struct request___133 *, u64);
	void (*requeue_request)(struct request___133 *);
	struct request___133 * (*former_request)(struct request_queue___133 *, struct request___133 *);
	struct request___133 * (*next_request)(struct request_queue___133 *, struct request___133 *);
	void (*init_icq)(struct io_cq___133 *);
	void (*exit_icq)(struct io_cq___133 *);
};

struct elv_fs_entry___133;

struct elevator_type___133 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___133 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___133 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___224 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___133 {
	struct elevator_type___133 *type;
	void *elevator_data;
	struct kobject___228 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___133 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___133 *, char *);
	ssize_t (*store)(struct elevator_queue___133 *, const char *, size_t);
};

struct blk_mq_queue_data___128;

struct blk_mq_ops___128 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___128 *, const struct blk_mq_queue_data___128 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___128 *);
	int (*get_budget)(struct request_queue___133 *);
	void (*put_budget)(struct request_queue___133 *, int);
	void (*set_rq_budget_token)(struct request___133 *, int);
	int (*get_rq_budget_token)(struct request___133 *);
	enum blk_eh_timer_return (*timeout)(struct request___133 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___128 *);
	void (*complete)(struct request___133 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___128 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___128 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___128 *, struct request___133 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___128 *, struct request___133 *, unsigned int);
	void (*initialize_rq_fn)(struct request___133 *);
	void (*cleanup_rq)(struct request___133 *);
	bool (*busy)(struct request_queue___133 *);
	int (*map_queues)(struct blk_mq_tag_set___128 *);
	void (*show_rq)(struct seq_file___215 *, struct request___133 *);
};

struct blk_mq_tag_set___128 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___128 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___128 {
	struct request___133 *rq;
	bool last;
};

struct blkcg_policy_data___121;

struct blkcg___121 {
	struct cgroup_subsys_state___167 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___121 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___121 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___121 {
	struct blkcg___121 *blkcg;
	int plid;
};

struct blkg_policy_data___121 {
	struct blkcg_gq___121 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___107 {
	struct mem_cgroup___107 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___107 {
	struct lruvec___115 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___107 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___107 *memcg;
};

struct obj_cgroup___107 {
	struct percpu_ref refcnt;
	struct mem_cgroup___107 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___45 {
	spinlock_t *lock;
	struct sk_buff___50 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___45;

struct Qdisc_ops___45 {
	struct Qdisc_ops___45 *next;
	const struct Qdisc_class_ops___45 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___50 *, struct Qdisc___45 *, struct sk_buff___50 **);
	struct sk_buff___50 * (*dequeue)(struct Qdisc___45 *);
	struct sk_buff___50 * (*peek)(struct Qdisc___45 *);
	int (*init)(struct Qdisc___45 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___45 *);
	void (*destroy)(struct Qdisc___45 *);
	int (*change)(struct Qdisc___45 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___45 *);
	int (*change_tx_queue_len)(struct Qdisc___45 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___45 *, unsigned int);
	int (*dump)(struct Qdisc___45 *, struct sk_buff___50 *);
	int (*dump_stats)(struct Qdisc___45 *, struct gnet_dump___45 *);
	void (*ingress_block_set)(struct Qdisc___45 *, u32);
	void (*egress_block_set)(struct Qdisc___45 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___45 *);
	u32 (*egress_block_get)(struct Qdisc___45 *);
	struct module___224 *owner;
};

struct Qdisc_class_ops___45 {
	unsigned int flags;
	struct netdev_queue___49 * (*select_queue)(struct Qdisc___45 *, struct tcmsg *);
	int (*graft)(struct Qdisc___45 *, long unsigned int, struct Qdisc___45 *, struct Qdisc___45 **, struct netlink_ext_ack *);
	struct Qdisc___45 * (*leaf)(struct Qdisc___45 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___45 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___45 *, u32);
	int (*change)(struct Qdisc___45 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___45 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___45 *, struct qdisc_walker *);
	struct tcf_block___45 * (*tcf_block)(struct Qdisc___45 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___45 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___45 *, long unsigned int);
	int (*dump)(struct Qdisc___45 *, long unsigned int, struct sk_buff___50 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___45 *, long unsigned int, struct gnet_dump___45 *);
};

struct tcf_chain___45;

struct tcf_block___45 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___54 *net;
	struct Qdisc___45 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___45 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___45;

struct tcf_proto_ops___45;

struct tcf_proto___45 {
	struct tcf_proto___45 *next;
	void *root;
	int (*classify)(struct sk_buff___50 *, const struct tcf_proto___45 *, struct tcf_result___45 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___45 *ops;
	struct tcf_chain___45 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___45 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___45 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___45 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___50 *, const struct tcf_proto___45 *, struct tcf_result___45 *);
	int (*init)(struct tcf_proto___45 *);
	void (*destroy)(struct tcf_proto___45 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___45 *, u32);
	void (*put)(struct tcf_proto___45 *, void *);
	int (*change)(struct net___54 *, struct sk_buff___50 *, struct tcf_proto___45 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___45 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___45 *);
	void (*walk)(struct tcf_proto___45 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___45 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___45 *, void *);
	void (*hw_del)(struct tcf_proto___45 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___54 *, struct tcf_chain___45 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___54 *, struct tcf_proto___45 *, void *, struct sk_buff___50 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___54 *, struct tcf_proto___45 *, void *, struct sk_buff___50 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___50 *, struct net___54 *, void *);
	struct module___224 *owner;
	int flags;
};

struct tcf_chain___45 {
	struct mutex filter_chain_lock;
	struct tcf_proto___45 *filter_chain;
	struct list_head list;
	struct tcf_block___45 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___45 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___38 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___45 *prog;
};

struct pneigh_entry___38;

struct neigh_hash_table___38;

struct neigh_table___38 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___51 *, __u32 *);
	bool (*key_eq)(const struct neighbour___38 *, const void *);
	int (*constructor)(struct neighbour___38 *);
	int (*pconstructor)(struct pneigh_entry___38 *);
	void (*pdestructor)(struct pneigh_entry___38 *);
	void (*proxy_redo)(struct sk_buff___50 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___51 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___38 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___49 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___38 *nht;
	struct pneigh_entry___38 **phash_buckets;
};

struct neigh_ops___38 {
	int family;
	void (*solicit)(struct neighbour___38 *, struct sk_buff___50 *);
	void (*error_report)(struct neighbour___38 *, struct sk_buff___50 *);
	int (*output)(struct neighbour___38 *, struct sk_buff___50 *);
	int (*connected_output)(struct neighbour___38 *, struct sk_buff___50 *);
};

struct pneigh_entry___38 {
	struct pneigh_entry___38 *next;
	possible_net_t___49 net;
	struct net_device___51 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___38 {
	struct neighbour___38 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___21 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___54 *, struct sock___39 *, struct sk_buff___50 *);
	int (*orig_input)(struct sk_buff___50 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___38 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___38 *ctarget;
	struct net___54 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___38 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___38 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___28;

struct timewait_sock_ops___28;

struct proto___38 {
	void (*close)(struct sock___39 *, long int);
	int (*pre_connect)(struct sock___39 *, struct sockaddr *, int);
	int (*connect)(struct sock___39 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___39 *, int);
	struct sock___39 * (*accept)(struct sock___39 *, int, int *, bool);
	int (*ioctl)(struct sock___39 *, int, long unsigned int);
	int (*init)(struct sock___39 *);
	void (*destroy)(struct sock___39 *);
	void (*shutdown)(struct sock___39 *, int);
	int (*setsockopt)(struct sock___39 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___39 *, int, int, char *, int *);
	void (*keepalive)(struct sock___39 *, int);
	int (*compat_ioctl)(struct sock___39 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___39 *, struct msghdr___40 *, size_t);
	int (*recvmsg)(struct sock___39 *, struct msghdr___40 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___39 *, struct page___245 *, int, size_t, int);
	int (*bind)(struct sock___39 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___39 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___39 *, struct sk_buff___50 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___39 *);
	int (*hash)(struct sock___39 *);
	void (*unhash)(struct sock___39 *);
	void (*rehash)(struct sock___39 *);
	int (*get_port)(struct sock___39 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___39 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___39 *, int);
	bool (*sock_is_readable)(struct sock___39 *);
	void (*enter_memory_pressure)(struct sock___39 *);
	void (*leave_memory_pressure)(struct sock___39 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___28 *rsk_prot;
	struct timewait_sock_ops___28 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___224 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___39 *, int);
};

struct request_sock___29;

struct request_sock_ops___28 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___39 *, struct request_sock___29 *);
	void (*send_ack)(const struct sock___39 *, struct sk_buff___50 *, struct request_sock___29 *);
	void (*send_reset)(const struct sock___39 *, struct sk_buff___50 *);
	void (*destructor)(struct request_sock___29 *);
	void (*syn_ack_timeout)(const struct request_sock___29 *);
};

struct timewait_sock_ops___28 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___39 *, struct sock___39 *, void *);
	void (*twsk_destructor)(struct sock___39 *);
};

struct request_sock___29 {
	struct sock_common___38 __req_common;
	struct request_sock___29 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___28 *rsk_ops;
	struct sock___39 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___26 {
	struct in6_addr mca_addr;
	struct inet6_dev___26 *idev;
	struct ifmcaddr6___26 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ahash_request___6;

struct scm_fp_list___2 {
	short int count;
	short int max;
	struct user_struct *user;
	struct file___240 *fp[253];
};

struct scm_cookie {
	struct pid___217 *pid;
	struct scm_fp_list___2 *fp;
	struct scm_creds creds;
	struct lsmblob lsmblob;
};

struct scm_timestamping {
	struct __kernel_old_timespec ts[3];
};

struct scm_timestamping64 {
	struct __kernel_timespec ts[3];
};

enum {
	TCA_STATS_UNSPEC = 0,
	TCA_STATS_BASIC = 1,
	TCA_STATS_RATE_EST = 2,
	TCA_STATS_QUEUE = 3,
	TCA_STATS_APP = 4,
	TCA_STATS_RATE_EST64 = 5,
	TCA_STATS_PAD = 6,
	TCA_STATS_BASIC_HW = 7,
	TCA_STATS_PKT64 = 8,
	__TCA_STATS_MAX = 9,
};

struct gnet_stats_basic {
	__u64 bytes;
	__u32 packets;
};

struct gnet_stats_rate_est {
	__u32 bps;
	__u32 pps;
};

struct gnet_stats_rate_est64 {
	__u64 bps;
	__u64 pps;
};

struct gnet_estimator {
	signed char interval;
	unsigned char ewma_log;
};

struct net_rate_estimator {
	struct gnet_stats_basic_packed *bstats;
	spinlock_t *stats_lock;
	seqcount_t *running;
	struct gnet_stats_basic_cpu *cpu_bstats;
	u8 ewma_log;
	u8 intvl_log;
	seqcount_t seq;
	u64 last_packets;
	u64 last_bytes;
	u64 avpps;
	u64 avbps;
	long unsigned int next_jiffies;
	struct timer_list timer;
	struct callback_head rcu;
};

struct dentry___241;

struct super_block___241;

struct module___225;

struct file_system_type___241 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___241 * (*mount)(struct file_system_type___241 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___241 *);
	struct module___225 *owner;
	struct file_system_type___241 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___241;

struct kiocb___241;

struct iov_iter___161;

struct poll_table_struct___164;

struct vm_area_struct___246;

struct inode___241;

struct file_lock___241;

struct page___246;

struct pipe_inode_info___82;

struct seq_file___216;

struct file_operations___242 {
	struct module___225 *owner;
	loff_t (*llseek)(struct file___241 *, loff_t, int);
	ssize_t (*read)(struct file___241 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___241 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___241 *, struct iov_iter___161 *);
	ssize_t (*write_iter)(struct kiocb___241 *, struct iov_iter___161 *);
	int (*iopoll)(struct kiocb___241 *, bool);
	int (*iterate)(struct file___241 *, struct dir_context *);
	int (*iterate_shared)(struct file___241 *, struct dir_context *);
	__poll_t (*poll)(struct file___241 *, struct poll_table_struct___164 *);
	long int (*unlocked_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___241 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___241 *, struct vm_area_struct___246 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___241 *, struct file___241 *);
	int (*flush)(struct file___241 *, fl_owner_t);
	int (*release)(struct inode___241 *, struct file___241 *);
	int (*fsync)(struct file___241 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___241 *, int);
	int (*lock)(struct file___241 *, int, struct file_lock___241 *);
	ssize_t (*sendpage)(struct file___241 *, struct page___246 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___241 *, long unsigned int);
	int (*flock)(struct file___241 *, int, struct file_lock___241 *);
	ssize_t (*splice_write)(struct pipe_inode_info___82 *, struct file___241 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___241 *, loff_t *, struct pipe_inode_info___82 *, size_t, unsigned int);
	int (*setlease)(struct file___241 *, long int, struct file_lock___241 **, void **);
	long int (*fallocate)(struct file___241 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___216 *, struct file___241 *);
	ssize_t (*copy_file_range)(struct file___241 *, loff_t, struct file___241 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___241 *, loff_t, struct file___241 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___241 *, loff_t, loff_t, int);
};

struct vmacache___246 {
	u64 seqnum;
	struct vm_area_struct___246 *vmas[4];
};

struct page_frag___246 {
	struct page___246 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___247;

struct pid___218;

struct cred___31;

struct nsproxy___227;

struct signal_struct___242;

struct bio_list___134;

struct backing_dev_info___120;

struct io_context___134;

struct css_set___168;

struct mem_cgroup___108;

struct request_queue___134;

struct vm_struct___224;

struct task_struct___248 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___248 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___247 *mm;
	struct mm_struct___247 *active_mm;
	struct vmacache___246 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___248 *real_parent;
	struct task_struct___248 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___248 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___218 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___227 *nsproxy;
	struct signal_struct___242 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___248 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___134 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___120 *backing_dev_info;
	struct io_context___134 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___168 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___82 *splice_pipe;
	struct page_frag___246 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___108 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___108 *active_memcg;
	struct request_queue___134 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___248 *oom_reaper_list;
	struct vm_struct___224 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___229;

struct kobj_type___229;

struct kernfs_node___229;

struct kobject___229 {
	const char *name;
	struct list_head entry;
	struct kobject___229 *parent;
	struct kset___229 *kset;
	struct kobj_type___229 *ktype;
	struct kernfs_node___229 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___226 {
	struct kobject___229 kobj;
	struct module___225 *mod;
	struct kobject___229 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___225 {
	struct module___225 *mod;
	struct latch_tree_node node;
};

struct module_layout___225 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___225 mtn;
};

struct module_attribute___225;

struct kernel_param___225;

struct module___225 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___226 mkobj;
	struct module_attribute___225 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___229 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___225 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___225 core_layout;
	struct module_layout___225 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___218;

struct upid___218 {
	int nr;
	struct pid_namespace___218 *ns;
};

struct proc_ns_operations___27;

struct ns_common___27 {
	atomic_long_t stashed;
	const struct proc_ns_operations___27 *ops;
	unsigned int inum;
	refcount_t count;
};

struct user_namespace___26;

struct ucounts___26;

struct pid_namespace___218 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___248 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___218 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___218 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___218 numbers[1];
};

struct user_namespace___26 {
	struct uid_gid_map uid_map;
	struct uid_gid_map gid_map;
	struct uid_gid_map projid_map;
	struct user_namespace___26 *parent;
	int level;
	kuid_t owner;
	kgid_t group;
	struct ns_common___27 ns;
	long unsigned int flags;
	bool parent_could_setfcap;
	struct list_head keyring_name_list;
	struct key___2 *user_keyring_register;
	struct rw_semaphore keyring_sem;
	struct key___2 *persistent_keyring_register;
	struct work_struct work;
	struct ctl_table_set set;
	struct ctl_table_header *sysctls;
	struct ucounts___26 *ucounts;
	long int ucount_max[16];
};

typedef struct page___246 *pgtable_t___246;

struct address_space___241;

struct page_pool___70;

struct dev_pagemap___236;

struct page___246 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___241 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___70 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___246 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___246 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___247 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___236 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct ucounts___26 {
	struct hlist_node node;
	struct user_namespace___26 *ns;
	kuid_t uid;
	atomic_t count;
	atomic_long_t ucount[16];
};

struct vm_operations_struct___236;

struct vm_area_struct___246 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___246 *vm_next;
	struct vm_area_struct___246 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___247 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___236 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___241 *vm_file;
	struct file___241 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___242 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___248 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___248 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___218 *pids[4];
	struct pid___218 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___247 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___246;

struct mm_struct___247 {
	struct {
		struct vm_area_struct___246 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___241 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___246 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___248 *owner;
		struct user_namespace___26 *user_ns;
		struct file___241 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct cred___31 {
	atomic_t usage;
	kuid_t uid;
	kgid_t gid;
	kuid_t suid;
	kgid_t sgid;
	kuid_t euid;
	kgid_t egid;
	kuid_t fsuid;
	kgid_t fsgid;
	unsigned int securebits;
	kernel_cap_t cap_inheritable;
	kernel_cap_t cap_permitted;
	kernel_cap_t cap_effective;
	kernel_cap_t cap_bset;
	kernel_cap_t cap_ambient;
	unsigned char jit_keyring;
	struct key___2 *session_keyring;
	struct key___2 *process_keyring;
	struct key___2 *thread_keyring;
	struct key___2 *request_key_auth;
	void *security;
	struct user_struct *user;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct group_info *group_info;
	union {
		int non_rcu;
		struct callback_head rcu;
	};
};

struct net___55;

struct cgroup_namespace___168;

struct nsproxy___227 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___218 *pid_ns_for_children;
	struct net___55 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___168 *cgroup_ns;
};

struct bio___134;

struct bio_list___134 {
	struct bio___134 *head;
	struct bio___134 *tail;
};

struct cgroup_subsys_state___168;

struct bdi_writeback___120 {
	struct backing_dev_info___120 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___168 *memcg_css;
	struct cgroup_subsys_state___168 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___222;

struct backing_dev_info___120 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___120 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___222 *dev;
	char dev_name[64];
	struct device___222 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___241 *debug_dir;
};

struct io_cq___134;

struct io_context___134 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___134 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___168;

struct css_set___168 {
	struct cgroup_subsys_state___168 *subsys[14];
	refcount_t refcount;
	struct css_set___168 *dom_cset;
	struct cgroup___168 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___168 *mg_src_cgrp;
	struct cgroup___168 *mg_dst_cgrp;
	struct css_set___168 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___241;

struct pipe_buffer___82;

struct pipe_inode_info___82 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___246 *tmp_page;
	struct fasync_struct___241 *fasync_readers;
	struct fasync_struct___241 *fasync_writers;
	struct pipe_buffer___82 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___168;

struct cgroup_subsys_state___168 {
	struct cgroup___168 *cgroup;
	struct cgroup_subsys___168 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___168 *parent;
};

struct cgroup_file___168 {
	struct kernfs_node___229 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___108;

struct mem_cgroup_per_node___108;

struct mem_cgroup___108 {
	struct cgroup_subsys_state___168 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___168 events_file;
	struct cgroup_file___168 events_local_file;
	struct cgroup_file___168 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___108 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___248 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___108 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___134;

struct blk_integrity___134 {
	const struct blk_integrity_profile___134 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___134 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___134 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___134;

struct elevator_queue___134;

struct blk_mq_ops___129;

struct blk_mq_hw_ctx___129;

struct gendisk___137;

struct blkcg_gq___122;

struct blk_mq_tag_set___129;

struct request_queue___134 {
	struct request___134 *last_merge;
	struct elevator_queue___134 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___129 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___129 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___137 *disk;
	struct kobject___229 kobj;
	struct kobject___229 *mq_kobj;
	struct blk_integrity___134 integrity;
	struct device___222 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___122 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___129 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___134 bio_split;
	struct dentry___241 *debugfs_dir;
	struct dentry___241 *sched_debugfs_dir;
	struct dentry___241 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___224 {
	struct vm_struct___224 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___246 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___158 {
	struct page___246 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___161 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___158 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___82 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___41 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___161 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___241 *msg_iocb;
};

struct kiocb___241 {
	struct file___241 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___241 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___52;

struct sock___40;

struct sk_buff___51 {
	union {
		struct {
			struct sk_buff___51 *next;
			struct sk_buff___51 *prev;
			union {
				struct net_device___52 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___40 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___51 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___55;

struct fqdir___55 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___55 *f;
	struct net___55 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___55;

struct inet_frags___55 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___55 *, const void *);
	void (*destructor)(struct inet_frag_queue___55 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct fib_rules_ops___39;

struct fib_notifier_ops___39;

struct netns_ipv4___55 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___39 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___40 *fibnl;
	struct sock___40 **icmp_sk;
	struct sock___40 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___40 **tcp_sk;
	struct fqdir___55 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___39 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___39 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___39 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___39;

struct neighbour___39;

struct dst_ops___55 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___55 *);
	struct dst_entry___39 * (*check)(struct dst_entry___39 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___39 *);
	unsigned int (*mtu)(const struct dst_entry___39 *);
	u32 * (*cow_metrics)(struct dst_entry___39 *, long unsigned int);
	void (*destroy)(struct dst_entry___39 *);
	void (*ifdown)(struct dst_entry___39 *, struct net_device___52 *, int);
	struct dst_entry___39 * (*negative_advice)(struct dst_entry___39 *);
	void (*link_failure)(struct sk_buff___51 *);
	void (*update_pmtu)(struct dst_entry___39 *, struct sock___40 *, struct sk_buff___51 *, u32, bool);
	void (*redirect)(struct dst_entry___39 *, struct sock___40 *, struct sk_buff___51 *);
	int (*local_out)(struct net___55 *, struct sock___40 *, struct sk_buff___51 *);
	struct neighbour___39 * (*neigh_lookup)(const struct dst_entry___39 *, struct sk_buff___51 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___39 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___55 {
	struct dst_ops___55 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___55 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___39 *fib6_rules_ops;
	struct sock___40 **icmp_sk;
	struct sock___40 *ndisc_sk;
	struct sock___40 *tcp_sk;
	struct sock___40 *igmp_sk;
	struct sock___40 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___39 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___39 *notifier_ops;
	struct fib_notifier_ops___39 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___55 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___55 *fqdir;
};

struct netns_sctp___39 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___40 *ctl_sock;
	struct sock___40 *udp4_sock;
	struct sock___40 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___50 {
	struct sk_buff___51 *next;
	struct sk_buff___51 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___46;

struct bpf_prog___46;

struct netns_bpf___46 {
	struct bpf_prog_array___46 *run_array[2];
	struct bpf_prog___46 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___55 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___40 *nlsk;
	struct sock___40 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___55 xfrm4_dst_ops;
	struct dst_ops___55 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___55 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___40 *rtnl;
	struct sock___40 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___52 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___55 ipv4;
	struct netns_ipv6___55 ipv6;
	struct netns_ieee802154_lowpan___55 ieee802154_lowpan;
	struct netns_sctp___39 sctp;
	struct netns_nf nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___50 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___46 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___55 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___40 *crypto_nlsk;
	struct sock___40 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___55 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___51 *fragments_tail;
	struct sk_buff___51 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___55 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___39;

struct fib_lookup_arg___39;

struct fib_rules_ops___39 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___39 *, struct flowi *, int, struct fib_lookup_arg___39 *);
	bool (*suppress)(struct fib_rule___39 *, int, struct fib_lookup_arg___39 *);
	int (*match)(struct fib_rule___39 *, struct flowi *, int);
	int (*configure)(struct fib_rule___39 *, struct sk_buff___51 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___39 *);
	int (*compare)(struct fib_rule___39 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___39 *, struct sk_buff___51 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___39 *);
	void (*flush_cache)(struct fib_rules_ops___39 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___225 *owner;
	struct net___55 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___55 *net;
} possible_net_t___50;

struct proto___39;

struct sock_common___39 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___39 *skc_prot;
	possible_net_t___50 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___40 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___39 {
	struct cgroup___168 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___39;

struct socket_wq___40;

struct socket___41;

struct sock___40 {
	struct sock_common___39 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___50 sk_error_queue;
	struct sk_buff___51 *sk_rx_skb_cache;
	struct sk_buff_head___50 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___51 *head;
		struct sk_buff___51 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___39 *sk_filter;
	union {
		struct socket_wq___40 *sk_wq;
		struct socket_wq___40 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___39 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___39 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___51 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___51 *sk_tx_skb_cache;
	struct sk_buff_head___50 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___246 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___39 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___218 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___41 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___39 sk_cgrp_data;
	struct mem_cgroup___108 *sk_memcg;
	void (*sk_state_change)(struct sock___40 *);
	void (*sk_data_ready)(struct sock___40 *);
	void (*sk_write_space)(struct sock___40 *);
	void (*sk_error_report)(struct sock___40 *);
	int (*sk_backlog_rcv)(struct sock___40 *, struct sk_buff___51 *);
	struct sk_buff___51 * (*sk_validate_xmit_skb)(struct sock___40 *, struct net_device___52 *, struct sk_buff___51 *);
	void (*sk_destruct)(struct sock___40 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct fib_notifier_ops___39 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___55 *);
	int (*fib_dump)(struct net___55 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___225 *owner;
	struct callback_head rcu;
};

struct address_space_operations___241;

struct address_space___241 {
	struct inode___241 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___241 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___70 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___222 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___70 {
	u32 count;
	struct page___246 *cache[128];
};

struct page_pool___70 {
	struct page_pool_params___70 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___246 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___70 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___236;

struct dev_pagemap___236 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___236 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___241;

struct path___241 {
	struct vfsmount___241 *mnt;
	struct dentry___241 *dentry;
};

struct fown_struct___218 {
	rwlock_t lock;
	struct pid___218 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___241 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___241 f_path;
	struct inode___241 *f_inode;
	const struct file_operations___242 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___218 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___241 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___236;

struct vm_operations_struct___236 {
	void (*open)(struct vm_area_struct___246 *);
	void (*close)(struct vm_area_struct___246 *);
	int (*may_split)(struct vm_area_struct___246 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___246 *);
	int (*mprotect)(struct vm_area_struct___246 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___236 *);
	vm_fault_t (*huge_fault)(struct vm_fault___236 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___236 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___246 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___236 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___236 *);
	int (*access)(struct vm_area_struct___246 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___246 *);
	int (*set_policy)(struct vm_area_struct___246 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___246 *, long unsigned int);
	struct page___246 * (*find_special_page)(struct vm_area_struct___246 *, long unsigned int);
};

struct core_thread___246 {
	struct task_struct___248 *task;
	struct core_thread___246 *next;
};

struct core_state___246 {
	atomic_t nr_threads;
	struct core_thread___246 dumper;
	struct completion startup;
};

struct vm_fault___236 {
	const struct {
		struct vm_area_struct___246 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___246 *cow_page;
	struct page___246 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___246 prealloc_pte;
};

struct pglist_data___116;

struct lruvec___116 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___116 *pgdat;
};

struct zone___116 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___116 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___116 {
	struct zone___116 *zone;
	int zone_idx;
};

struct zonelist___116 {
	struct zoneref___116 _zonerefs[321];
};

struct pglist_data___116 {
	struct zone___116 node_zones[5];
	struct zonelist___116 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___248 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___248 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___116 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dst_entry___39 {
	struct net_device___52 *dev;
	struct dst_ops___55 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___51 *);
	int (*output)(struct net___55 *, struct sock___40 *, struct sk_buff___51 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___50(struct sk_buff___51 **);

struct wakeup_source___222;

struct dev_pm_info___222 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___222 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___222 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___222;

struct bus_type___222;

struct device_driver___222;

struct dev_pm_domain___222;

struct fwnode_handle___218;

struct class___222;

struct attribute_group___229;

struct device___222 {
	struct kobject___229 kobj;
	struct device___222 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___222 *type;
	struct bus_type___222 *bus;
	struct device_driver___222 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___222 power;
	struct dev_pm_domain___222 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___218 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___222 *class;
	const struct attribute_group___229 **groups;
	void (*release)(struct device___222 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___46 {
	struct bpf_prog___46 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___50;

struct net_device_ops___50;

struct l3mdev_ops___39;

struct xfrmdev_ops___50;

struct header_ops___50;

struct netdev_rx_queue___50;

struct mini_Qdisc___46;

struct netdev_queue___50;

struct Qdisc___46;

struct rtnl_link_ops___46;

struct dcbnl_rtnl_ops___50;

struct net_device___52 {
	char name[16];
	struct netdev_name_node___50 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___50 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___39 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___50 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___50 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___229 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___50 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___46 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___50 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___46 *miniq_ingress;
	struct netdev_queue___50 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___50 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___46 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___46 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___50 = 0,
		NETREG_REGISTERED___50 = 1,
		NETREG_UNREGISTERING___50 = 2,
		NETREG_UNREGISTERED___50 = 3,
		NETREG_RELEASED___50 = 4,
		NETREG_DUMMY___50 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___50 = 0,
		RTNL_LINK_INITIALIZING___50 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___52 *);
	struct netpoll_info *npinfo;
	possible_net_t___50 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___222 dev;
	const struct attribute_group___229 *sysfs_groups[4];
	const struct attribute_group___229 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___46 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___50 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___46 xdp_state[3];
	long: 64;
};

struct neigh_table___39;

struct neigh_parms___39;

struct neigh_ops___39;

struct neighbour___39 {
	struct neighbour___39 *next;
	struct neigh_table___39 *tbl;
	struct neigh_parms___39 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___50 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___39 *, struct sk_buff___51 *);
	const struct neigh_ops___39 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___52 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___46 {
	struct bpf_prog___46 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___46 {
	struct callback_head rcu;
	struct bpf_prog_array_item___46 items[0];
};

struct bpf_prog_aux___53;

struct bpf_prog___46 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___53 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct nsset___26;

struct proc_ns_operations___27 {
	const char *name;
	const char *real_ns_name;
	int type;
	struct ns_common___27 * (*get)(struct task_struct___248 *);
	void (*put)(struct ns_common___27 *);
	int (*install)(struct nsset___26 *, struct ns_common___27 *);
	struct user_namespace___26 * (*owner)(struct ns_common___27 *);
	struct ns_common___27 * (*get_parent)(struct ns_common___27 *);
};

struct dentry_operations___241;

struct dentry___241 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___241 *d_parent;
	struct qstr d_name;
	struct inode___241 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___241 *d_op;
	struct super_block___241 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___241;

struct inode___241 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___241 *i_op;
	struct super_block___241 *i_sb;
	struct address_space___241 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___120 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___242 *i_fop;
		void (*free_inode)(struct inode___241 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___241 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___82 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___241 {
	int (*d_revalidate)(struct dentry___241 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___241 *, unsigned int);
	int (*d_hash)(const struct dentry___241 *, struct qstr *);
	int (*d_compare)(const struct dentry___241 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___241 *);
	int (*d_init)(struct dentry___241 *);
	void (*d_release)(struct dentry___241 *);
	void (*d_prune)(struct dentry___241 *);
	void (*d_iput)(struct dentry___241 *, struct inode___241 *);
	char * (*d_dname)(struct dentry___241 *, char *, int);
	struct vfsmount___241 * (*d_automount)(struct path___241 *);
	int (*d_manage)(const struct path___241 *, bool);
	struct dentry___241 * (*d_real)(struct dentry___241 *, const struct inode___241 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___241;

struct mem_dqinfo___241 {
	struct quota_format_type___241 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___241;

struct quota_info___241 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___241 *files[3];
	struct mem_dqinfo___241 info[3];
	const struct quota_format_ops___241 *ops[3];
};

struct rcuwait___242 {
	struct task_struct___248 *task;
};

struct percpu_rw_semaphore___242 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___242 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___241 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___242 rw_sem[3];
};

struct shrink_control___108;

struct shrinker___108 {
	long unsigned int (*count_objects)(struct shrinker___108 *, struct shrink_control___108 *);
	long unsigned int (*scan_objects)(struct shrinker___108 *, struct shrink_control___108 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___241;

struct dquot_operations___241;

struct quotactl_ops___241;

struct block_device___137;

struct super_block___241 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___241 *s_type;
	const struct super_operations___241 *s_op;
	const struct dquot_operations___241 *dq_op;
	const struct quotactl_ops___241 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___241 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___137 *s_bdev;
	struct backing_dev_info___120 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___241 s_dquot;
	struct sb_writers___241 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___241 *s_d_op;
	int cleancache_poolid;
	struct shrinker___108 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___241 {
	struct dentry___241 *mnt_root;
	struct super_block___241 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___108 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___108 *memcg;
};

struct psi_group___168 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___248 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___46 {
	struct bpf_prog_array___46 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___46 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___168;

struct cgroup_rstat_cpu___168;

struct cgroup___168 {
	struct cgroup_subsys_state___168 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___229 *kn;
	struct cgroup_file___168 procs_file;
	struct cgroup_file___168 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___168 *subsys[14];
	struct cgroup_root___168 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___168 *dom_cgrp;
	struct cgroup___168 *old_dom_cgrp;
	struct cgroup_rstat_cpu___168 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___168 psi;
	struct cgroup_bpf___46 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___134 {
	struct request_queue___134 *q;
	struct io_context___134 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___241 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___241 *ia_file;
};

struct dquot___241 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___241 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___241 {
	int qf_fmt_id;
	const struct quota_format_ops___241 *qf_ops;
	struct module___225 *qf_owner;
	struct quota_format_type___241 *qf_next;
};

struct quota_format_ops___241 {
	int (*check_quota_file)(struct super_block___241 *, int);
	int (*read_file_info)(struct super_block___241 *, int);
	int (*write_file_info)(struct super_block___241 *, int);
	int (*free_file_info)(struct super_block___241 *, int);
	int (*read_dqblk)(struct dquot___241 *);
	int (*commit_dqblk)(struct dquot___241 *);
	int (*release_dqblk)(struct dquot___241 *);
	int (*get_next_id)(struct super_block___241 *, struct kqid *);
};

struct dquot_operations___241 {
	int (*write_dquot)(struct dquot___241 *);
	struct dquot___241 * (*alloc_dquot)(struct super_block___241 *, int);
	void (*destroy_dquot)(struct dquot___241 *);
	int (*acquire_dquot)(struct dquot___241 *);
	int (*release_dquot)(struct dquot___241 *);
	int (*mark_dirty)(struct dquot___241 *);
	int (*write_info)(struct super_block___241 *, int);
	qsize_t * (*get_reserved_space)(struct inode___241 *);
	int (*get_projid)(struct inode___241 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___241 *, qsize_t *);
	int (*get_next_id)(struct super_block___241 *, struct kqid *);
};

struct quotactl_ops___241 {
	int (*quota_on)(struct super_block___241 *, int, int, const struct path___241 *);
	int (*quota_off)(struct super_block___241 *, int);
	int (*quota_enable)(struct super_block___241 *, unsigned int);
	int (*quota_disable)(struct super_block___241 *, unsigned int);
	int (*quota_sync)(struct super_block___241 *, int);
	int (*set_info)(struct super_block___241 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___241 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___241 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___241 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___241 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___241 *, unsigned int);
};

struct writeback_control___120;

struct address_space_operations___241 {
	int (*writepage)(struct page___246 *, struct writeback_control___120 *);
	int (*readpage)(struct file___241 *, struct page___246 *);
	int (*writepages)(struct address_space___241 *, struct writeback_control___120 *);
	int (*set_page_dirty)(struct page___246 *);
	int (*readpages)(struct file___241 *, struct address_space___241 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___241 *, struct address_space___241 *, loff_t, unsigned int, unsigned int, struct page___246 **, void **);
	int (*write_end)(struct file___241 *, struct address_space___241 *, loff_t, unsigned int, unsigned int, struct page___246 *, void *);
	sector_t (*bmap)(struct address_space___241 *, sector_t);
	void (*invalidatepage)(struct page___246 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___246 *, gfp_t);
	void (*freepage)(struct page___246 *);
	ssize_t (*direct_IO)(struct kiocb___241 *, struct iov_iter___161 *);
	int (*migratepage)(struct address_space___241 *, struct page___246 *, struct page___246 *, enum migrate_mode);
	bool (*isolate_page)(struct page___246 *, isolate_mode_t);
	void (*putback_page)(struct page___246 *);
	int (*launder_page)(struct page___246 *);
	int (*is_partially_uptodate)(struct page___246 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___246 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___241 *, struct page___246 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___241 *, sector_t *);
	void (*swap_deactivate)(struct file___241 *);
};

struct writeback_control___120 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___120 *wb;
	struct inode___241 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___241 {
	struct dentry___241 * (*lookup)(struct inode___241 *, struct dentry___241 *, unsigned int);
	const char * (*get_link)(struct dentry___241 *, struct inode___241 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___241 *, int);
	struct posix_acl * (*get_acl)(struct inode___241 *, int, bool);
	int (*readlink)(struct dentry___241 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___241 *, struct dentry___241 *, umode_t, bool);
	int (*link)(struct dentry___241 *, struct inode___241 *, struct dentry___241 *);
	int (*unlink)(struct inode___241 *, struct dentry___241 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___241 *, struct dentry___241 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___241 *, struct dentry___241 *, umode_t);
	int (*rmdir)(struct inode___241 *, struct dentry___241 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___241 *, struct dentry___241 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___241 *, struct dentry___241 *, struct inode___241 *, struct dentry___241 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___241 *, struct iattr___241 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___241 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___241 *, char *, size_t);
	int (*fiemap)(struct inode___241 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___241 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___241 *, struct dentry___241 *, struct file___241 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___241 *, struct dentry___241 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___241 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___241 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___241 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___241 {
	void (*fl_copy_lock)(struct file_lock___241 *, struct file_lock___241 *);
	void (*fl_release_private)(struct file_lock___241 *);
};

struct lock_manager_operations___241;

struct file_lock___241 {
	struct file_lock___241 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___241 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___241 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___241 *fl_ops;
	const struct lock_manager_operations___241 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___241 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___241 *);
	int (*lm_grant)(struct file_lock___241 *, int);
	bool (*lm_break)(struct file_lock___241 *);
	int (*lm_change)(struct file_lock___241 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___241 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___241 *);
};

struct fasync_struct___241 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___241 *fa_next;
	struct file___241 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___241 {
	struct inode___241 * (*alloc_inode)(struct super_block___241 *);
	void (*destroy_inode)(struct inode___241 *);
	void (*free_inode)(struct inode___241 *);
	void (*dirty_inode)(struct inode___241 *, int);
	int (*write_inode)(struct inode___241 *, struct writeback_control___120 *);
	int (*drop_inode)(struct inode___241 *);
	void (*evict_inode)(struct inode___241 *);
	void (*put_super)(struct super_block___241 *);
	int (*sync_fs)(struct super_block___241 *, int);
	int (*freeze_super)(struct super_block___241 *);
	int (*freeze_fs)(struct super_block___241 *);
	int (*thaw_super)(struct super_block___241 *);
	int (*unfreeze_fs)(struct super_block___241 *);
	int (*statfs)(struct dentry___241 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___241 *, int *, char *);
	void (*umount_begin)(struct super_block___241 *);
	int (*show_options)(struct seq_file___216 *, struct dentry___241 *);
	int (*show_devname)(struct seq_file___216 *, struct dentry___241 *);
	int (*show_path)(struct seq_file___216 *, struct dentry___241 *);
	int (*show_stats)(struct seq_file___216 *, struct dentry___241 *);
	ssize_t (*quota_read)(struct super_block___241 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___241 *, int, const char *, size_t, loff_t);
	struct dquot___241 ** (*get_dquots)(struct inode___241 *);
	long int (*nr_cached_objects)(struct super_block___241 *, struct shrink_control___108 *);
	long int (*free_cached_objects)(struct super_block___241 *, struct shrink_control___108 *);
	struct file___241 * (*real_loop)(struct file___241 *);
};

struct block_device___137 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___241 *bd_inode;
	struct super_block___241 *bd_super;
	void *bd_claiming;
	struct device___222 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___229 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___137 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___241 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___172)(struct file___241 *, wait_queue_head_t *, struct poll_table_struct___164 *);

struct poll_table_struct___164 {
	poll_queue_proc___172 _qproc;
	__poll_t _key;
};

struct seq_operations___216;

struct seq_file___216 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___216 *op;
	int poll_event;
	const struct file___241 *file;
	void *private;
};

typedef void bio_end_io_t___134(struct bio___134 *);

struct bio_integrity_payload___134;

struct bio___134 {
	struct bio___134 *bi_next;
	struct block_device___137 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___134 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___122 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___134 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___158 *bi_io_vec;
	struct bio_set___134 *bi_pool;
	struct bio_vec___158 bi_inline_vecs[0];
};

struct dev_pagemap_ops___236 {
	void (*page_free)(struct page___246 *);
	void (*kill)(struct dev_pagemap___236 *);
	void (*cleanup)(struct dev_pagemap___236 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___236 *);
};

struct fwnode_operations___218;

struct fwnode_handle___218 {
	struct fwnode_handle___218 *secondary;
	const struct fwnode_operations___218 *ops;
	struct device___222 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___218;

struct fwnode_endpoint___218;

struct fwnode_operations___218 {
	struct fwnode_handle___218 * (*get)(struct fwnode_handle___218 *);
	void (*put)(struct fwnode_handle___218 *);
	bool (*device_is_available)(const struct fwnode_handle___218 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___218 *, const struct device___222 *);
	bool (*property_present)(const struct fwnode_handle___218 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___218 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___218 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___218 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*get_parent)(const struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*get_next_child_node)(const struct fwnode_handle___218 *, struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*get_named_child_node)(const struct fwnode_handle___218 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___218 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___218 *);
	struct fwnode_handle___218 * (*graph_get_next_endpoint)(const struct fwnode_handle___218 *, struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*graph_get_remote_endpoint)(const struct fwnode_handle___218 *);
	struct fwnode_handle___218 * (*graph_get_port_parent)(struct fwnode_handle___218 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___218 *, struct fwnode_endpoint___218 *);
	int (*add_links)(struct fwnode_handle___218 *);
};

struct fwnode_endpoint___218 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___218 *local_fwnode;
};

struct fwnode_reference_args___218 {
	struct fwnode_handle___218 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___229;

struct kernfs_elem_dir___229 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___229 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___229;

struct kernfs_root___229 {
	struct kernfs_node___229 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___229 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___229 {
	struct kernfs_node___229 *target_kn;
};

struct kernfs_ops___229;

struct kernfs_elem_attr___229 {
	const struct kernfs_ops___229 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___229 *notify_next;
};

struct kernfs_node___229 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___229 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___229 dir;
		struct kernfs_elem_symlink___229 symlink;
		struct kernfs_elem_attr___229 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___229;

struct kernfs_ops___229 {
	int (*open)(struct kernfs_open_file___229 *);
	void (*release)(struct kernfs_open_file___229 *);
	int (*seq_show)(struct seq_file___216 *, void *);
	void * (*seq_start)(struct seq_file___216 *, loff_t *);
	void * (*seq_next)(struct seq_file___216 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___216 *, void *);
	ssize_t (*read)(struct kernfs_open_file___229 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___229 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___229 *, struct poll_table_struct___164 *);
	int (*mmap)(struct kernfs_open_file___229 *, struct vm_area_struct___246 *);
};

struct kernfs_syscall_ops___229 {
	int (*show_options)(struct seq_file___216 *, struct kernfs_root___229 *);
	int (*mkdir)(struct kernfs_node___229 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___229 *);
	int (*rename)(struct kernfs_node___229 *, struct kernfs_node___229 *, const char *);
	int (*show_path)(struct seq_file___216 *, struct kernfs_node___229 *, struct kernfs_root___229 *);
};

struct kernfs_open_file___229 {
	struct kernfs_node___229 *kn;
	struct file___241 *file;
	struct seq_file___216 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___236 *vm_ops;
};

struct kobj_ns_type_operations___39 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___40 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___229;

struct attribute_group___229 {
	const char *name;
	umode_t (*is_visible)(struct kobject___229 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___229 *, struct bin_attribute___229 *, int);
	struct attribute **attrs;
	struct bin_attribute___229 **bin_attrs;
};

struct bin_attribute___229 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___241 * (*f_mapping)();
	ssize_t (*read)(struct file___241 *, struct kobject___229 *, struct bin_attribute___229 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___241 *, struct kobject___229 *, struct bin_attribute___229 *, char *, loff_t, size_t);
	int (*mmap)(struct file___241 *, struct kobject___229 *, struct bin_attribute___229 *, struct vm_area_struct___246 *);
};

struct sysfs_ops___229 {
	ssize_t (*show)(struct kobject___229 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___229 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___229;

struct kset___229 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___229 kobj;
	const struct kset_uevent_ops___229 *uevent_ops;
};

struct kobj_type___229 {
	void (*release)(struct kobject___229 *);
	const struct sysfs_ops___229 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___229 **default_groups;
	const struct kobj_ns_type_operations___39 * (*child_ns_type)(struct kobject___229 *);
	const void * (*namespace)(struct kobject___229 *);
	void (*get_ownership)(struct kobject___229 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___229 {
	int (* const filter)(struct kset___229 *, struct kobject___229 *);
	const char * (* const name)(struct kset___229 *, struct kobject___229 *);
	int (* const uevent)(struct kset___229 *, struct kobject___229 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___225 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___225 *);
	int (*get)(char *, const struct kernel_param___225 *);
	void (*free)(void *);
};

struct kparam_array___225;

struct kernel_param___225 {
	const char *name;
	struct module___225 *mod;
	const struct kernel_param_ops___225 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___225 *arr;
	};
};

struct kparam_array___225 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___225 *ops;
	void *elem;
};

struct module_attribute___225 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___225 *, struct module_kobject___226 *, char *);
	ssize_t (*store)(struct module_attribute___225 *, struct module_kobject___226 *, const char *, size_t);
	void (*setup)(struct module___225 *, const char *);
	int (*test)(struct module___225 *);
	void (*free)(struct module___225 *);
};

struct cgroup_namespace___168 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___168 *root_cset;
};

struct nsset___26 {
	unsigned int flags;
	struct nsproxy___227 *nsproxy;
	struct fs_struct *fs;
	const struct cred___31 *cred;
};

struct socket_wq___40 {
	wait_queue_head_t wait;
	struct fasync_struct___241 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___40;

struct socket___41 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___241 *file;
	struct sock___40 *sk;
	const struct proto_ops___40 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___40 wq;
};

typedef int (*sk_read_actor_t___39)(read_descriptor_t *, struct sk_buff___51 *, unsigned int, size_t);

struct proto_ops___40 {
	int family;
	struct module___225 *owner;
	int (*release)(struct socket___41 *);
	int (*bind)(struct socket___41 *, struct sockaddr *, int);
	int (*connect)(struct socket___41 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___41 *, struct socket___41 *);
	int (*accept)(struct socket___41 *, struct socket___41 *, int, bool);
	int (*getname)(struct socket___41 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___241 *, struct socket___41 *, struct poll_table_struct___164 *);
	int (*ioctl)(struct socket___41 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___41 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___41 *, void *, bool, bool);
	int (*listen)(struct socket___41 *, int);
	int (*shutdown)(struct socket___41 *, int);
	int (*setsockopt)(struct socket___41 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___41 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___216 *, struct socket___41 *);
	int (*sendmsg)(struct socket___41 *, struct msghdr___41 *, size_t);
	int (*recvmsg)(struct socket___41 *, struct msghdr___41 *, size_t, int);
	int (*mmap)(struct file___241 *, struct socket___41 *, struct vm_area_struct___246 *);
	ssize_t (*sendpage)(struct socket___41 *, struct page___246 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___41 *, loff_t *, struct pipe_inode_info___82 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___40 *, int);
	int (*peek_len)(struct socket___41 *);
	int (*read_sock)(struct sock___40 *, read_descriptor_t *, sk_read_actor_t___39);
	int (*sendpage_locked)(struct sock___40 *, struct page___246 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___40 *, struct msghdr___41 *, size_t);
	int (*set_rcvlowat)(struct sock___40 *, int);
};

struct dev_pm_ops___222 {
	int (*prepare)(struct device___222 *);
	void (*complete)(struct device___222 *);
	int (*suspend)(struct device___222 *);
	int (*resume)(struct device___222 *);
	int (*freeze)(struct device___222 *);
	int (*thaw)(struct device___222 *);
	int (*poweroff)(struct device___222 *);
	int (*restore)(struct device___222 *);
	int (*suspend_late)(struct device___222 *);
	int (*resume_early)(struct device___222 *);
	int (*freeze_late)(struct device___222 *);
	int (*thaw_early)(struct device___222 *);
	int (*poweroff_late)(struct device___222 *);
	int (*restore_early)(struct device___222 *);
	int (*suspend_noirq)(struct device___222 *);
	int (*resume_noirq)(struct device___222 *);
	int (*freeze_noirq)(struct device___222 *);
	int (*thaw_noirq)(struct device___222 *);
	int (*poweroff_noirq)(struct device___222 *);
	int (*restore_noirq)(struct device___222 *);
	int (*runtime_suspend)(struct device___222 *);
	int (*runtime_resume)(struct device___222 *);
	int (*runtime_idle)(struct device___222 *);
};

struct wakeup_source___222 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___222 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___222 {
	struct dev_pm_ops___222 ops;
	int (*start)(struct device___222 *);
	void (*detach)(struct device___222 *, bool);
	int (*activate)(struct device___222 *);
	void (*sync)(struct device___222 *);
	void (*dismiss)(struct device___222 *);
};

struct bus_type___222 {
	const char *name;
	const char *dev_name;
	struct device___222 *dev_root;
	const struct attribute_group___229 **bus_groups;
	const struct attribute_group___229 **dev_groups;
	const struct attribute_group___229 **drv_groups;
	int (*match)(struct device___222 *, struct device_driver___222 *);
	int (*uevent)(struct device___222 *, struct kobj_uevent_env *);
	int (*probe)(struct device___222 *);
	void (*sync_state)(struct device___222 *);
	void (*remove)(struct device___222 *);
	void (*shutdown)(struct device___222 *);
	int (*online)(struct device___222 *);
	int (*offline)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	int (*num_vf)(struct device___222 *);
	int (*dma_configure)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___222 {
	const char *name;
	struct bus_type___222 *bus;
	struct module___225 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___222 *);
	void (*sync_state)(struct device___222 *);
	int (*remove)(struct device___222 *);
	void (*shutdown)(struct device___222 *);
	int (*suspend)(struct device___222 *, pm_message_t);
	int (*resume)(struct device___222 *);
	const struct attribute_group___229 **groups;
	const struct attribute_group___229 **dev_groups;
	const struct dev_pm_ops___222 *pm;
	void (*coredump)(struct device___222 *);
	struct driver_private *p;
};

struct device_type___222 {
	const char *name;
	const struct attribute_group___229 **groups;
	int (*uevent)(struct device___222 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___222 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___222 *);
	const struct dev_pm_ops___222 *pm;
};

struct class___222 {
	const char *name;
	struct module___225 *owner;
	const struct attribute_group___229 **class_groups;
	const struct attribute_group___229 **dev_groups;
	struct kobject___229 *dev_kobj;
	int (*dev_uevent)(struct device___222 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___222 *, umode_t *);
	void (*class_release)(struct class___222 *);
	void (*dev_release)(struct device___222 *);
	int (*shutdown_pre)(struct device___222 *);
	const struct kobj_ns_type_operations___39 *ns_type;
	const void * (*namespace)(struct device___222 *);
	void (*get_ownership)(struct device___222 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___222 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___82;

struct pipe_buffer___82 {
	struct page___246 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___82 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___82 {
	int (*confirm)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
	void (*release)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
	bool (*try_steal)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
	bool (*get)(struct pipe_inode_info___82 *, struct pipe_buffer___82 *);
};

struct seq_operations___216 {
	void * (*start)(struct seq_file___216 *, loff_t *);
	void (*stop)(struct seq_file___216 *, void *);
	void * (*next)(struct seq_file___216 *, void *, loff_t *);
	int (*show)(struct seq_file___216 *, void *);
};

struct pernet_operations___9 {
	struct list_head list;
	int (*init)(struct net___55 *);
	void (*pre_exit)(struct net___55 *);
	void (*exit)(struct net___55 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___50 {
	int (*ieee_getets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___52 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___52 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___52 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___52 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___52 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___52 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___52 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___52 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___52 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___52 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___52 *);
	u8 (*setstate)(struct net_device___52 *, u8);
	void (*getpermhwaddr)(struct net_device___52 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___52 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___52 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___52 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___52 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___52 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___52 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___52 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___52 *, int, u8 *);
	void (*setpfccfg)(struct net_device___52 *, int, u8);
	void (*getpfccfg)(struct net_device___52 *, int, u8 *);
	u8 (*setall)(struct net_device___52 *);
	u8 (*getcap)(struct net_device___52 *, int, u8 *);
	int (*getnumtcs)(struct net_device___52 *, int, u8 *);
	int (*setnumtcs)(struct net_device___52 *, int, u8);
	u8 (*getpfcstate)(struct net_device___52 *);
	void (*setpfcstate)(struct net_device___52 *, u8);
	void (*getbcncfg)(struct net_device___52 *, int, u32 *);
	void (*setbcncfg)(struct net_device___52 *, int, u32);
	void (*getbcnrp)(struct net_device___52 *, int, u8 *);
	void (*setbcnrp)(struct net_device___52 *, int, u8);
	int (*setapp)(struct net_device___52 *, u8, u16, u8);
	int (*getapp)(struct net_device___52 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___52 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___52 *, int, u8);
	u8 (*getdcbx)(struct net_device___52 *);
	u8 (*setdcbx)(struct net_device___52 *, u8);
	int (*peer_getappinfo)(struct net_device___52 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___52 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___52 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___52 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___52 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___52 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___53;

typedef int (*bpf_iter_init_seq_priv_t___52)(void *, struct bpf_iter_aux_info___53 *);

struct bpf_map___53;

struct bpf_iter_aux_info___53 {
	struct bpf_map___53 *map;
};

struct bpf_iter_seq_info___52 {
	const struct seq_operations___216 *seq_ops;
	bpf_iter_init_seq_priv_t___52 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___52 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___53 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___53 *, struct file___241 *);
	void (*map_free)(struct bpf_map___53 *);
	int (*map_get_next_key)(struct bpf_map___53 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___53 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___53 *, void *);
	int (*map_lookup_batch)(struct bpf_map___53 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___53 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___53 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___53 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___53 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___53 *, void *);
	int (*map_update_elem)(struct bpf_map___53 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___53 *, void *);
	int (*map_push_elem)(struct bpf_map___53 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___53 *, void *);
	int (*map_peek_elem)(struct bpf_map___53 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___53 *, struct file___241 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___53 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___53 *, void *, struct seq_file___216 *);
	int (*map_check_btf)(const struct bpf_map___53 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___53 *, struct bpf_prog_aux___53 *);
	void (*map_poke_untrack)(struct bpf_map___53 *, struct bpf_prog_aux___53 *);
	void (*map_poke_run)(struct bpf_map___53 *, u32, struct bpf_prog___46 *, struct bpf_prog___46 *);
	int (*map_direct_value_addr)(const struct bpf_map___53 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___53 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___53 *, struct vm_area_struct___246 *);
	__poll_t (*map_poll)(struct bpf_map___53 *, struct file___241 *, struct poll_table_struct___164 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___53 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___53 *, const struct bpf_map___53 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___53 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___52 *iter_seq_info;
};

struct bpf_map___53 {
	const struct bpf_map_ops___52 *ops;
	struct bpf_map___53 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___108 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___52;

struct bpf_jit_poke_descriptor___52;

struct bpf_prog_ops___46;

struct btf_mod_pair___52;

struct bpf_prog_offload___50;

struct bpf_prog_aux___53 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___46 *dst_prog;
	struct bpf_trampoline___52 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___46 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___52 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___46 *ops;
	struct bpf_map___53 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___52 *used_btfs;
	struct bpf_prog___46 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___53 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___50 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___50;

struct bpf_map_dev_ops___50 {
	int (*map_get_next_key)(struct bpf_offloaded_map___50 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___50 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___50 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___50 *, void *);
};

struct bpf_offloaded_map___50 {
	struct bpf_map___53 map;
	struct net_device___52 *netdev;
	const struct bpf_map_dev_ops___50 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___46 {
	int (*test_run)(struct bpf_prog___46 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___50 {
	struct bpf_prog___46 *prog;
	struct net_device___52 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___52 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___46 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___225 *mod;
};

struct bpf_jit_poke_descriptor___52 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___53 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___52 {
	struct btf *btf;
	struct module___225 *module;
};

struct cftype___168;

struct cgroup_subsys___168 {
	struct cgroup_subsys_state___168 * (*css_alloc)(struct cgroup_subsys_state___168 *);
	int (*css_online)(struct cgroup_subsys_state___168 *);
	void (*css_offline)(struct cgroup_subsys_state___168 *);
	void (*css_released)(struct cgroup_subsys_state___168 *);
	void (*css_free)(struct cgroup_subsys_state___168 *);
	void (*css_reset)(struct cgroup_subsys_state___168 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___168 *, int);
	int (*css_extra_stat_show)(struct seq_file___216 *, struct cgroup_subsys_state___168 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___248 *, struct css_set___168 *);
	void (*cancel_fork)(struct task_struct___248 *, struct css_set___168 *);
	void (*fork)(struct task_struct___248 *);
	void (*exit)(struct task_struct___248 *);
	void (*release)(struct task_struct___248 *);
	void (*bind)(struct cgroup_subsys_state___168 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___168 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___168 *dfl_cftypes;
	struct cftype___168 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___168 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___168 *updated_children;
	struct cgroup___168 *updated_next;
};

struct cgroup_root___168 {
	struct kernfs_root___229 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___168 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___168 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___168 *ss;
	struct list_head node;
	struct kernfs_ops___229 *kf_ops;
	int (*open)(struct kernfs_open_file___229 *);
	void (*release)(struct kernfs_open_file___229 *);
	u64 (*read_u64)(struct cgroup_subsys_state___168 *, struct cftype___168 *);
	s64 (*read_s64)(struct cgroup_subsys_state___168 *, struct cftype___168 *);
	int (*seq_show)(struct seq_file___216 *, void *);
	void * (*seq_start)(struct seq_file___216 *, loff_t *);
	void * (*seq_next)(struct seq_file___216 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___216 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___168 *, struct cftype___168 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___168 *, struct cftype___168 *, s64);
	ssize_t (*write)(struct kernfs_open_file___229 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___229 *, struct poll_table_struct___164 *);
};

struct xdp_rxq_info___50 {
	struct net_device___52 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___50 {
	struct net_device___52 *dev;
};

struct xdp_buff___50 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___50 *rxq;
	struct xdp_txq_info___50 *txq;
	u32 frame_sz;
};

struct xdp_frame___50 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___52 *dev_rx;
};

struct netlink_skb_parms___5 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___40 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___50 {
	struct sk_buff___51 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___51 *, struct netlink_callback___50 *);
	int (*done)(struct netlink_callback___50 *);
	void *data;
	struct module___225 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___50 {
	int (*create)(struct sk_buff___51 *, struct net_device___52 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___51 *, unsigned char *);
	int (*cache)(const struct neighbour___39 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___52 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___51 *);
};

struct netdev_queue___50 {
	struct net_device___52 *dev;
	struct Qdisc___46 *qdisc;
	struct Qdisc___46 *qdisc_sleeping;
	struct kobject___229 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___52 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___46 {
	struct sk_buff___51 *head;
	struct sk_buff___51 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___46;

struct Qdisc___46 {
	int (*enqueue)(struct sk_buff___51 *, struct Qdisc___46 *, struct sk_buff___51 **);
	struct sk_buff___51 * (*dequeue)(struct Qdisc___46 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___46 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___50 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___50 gso_skb;
	struct qdisc_skb_head___46 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___46 *next_sched;
	struct sk_buff_head___50 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___50 {
	struct xdp_rxq_info___50 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___229 kobj;
	struct net_device___52 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___50 {
	enum net_device_path_type type;
	const struct net_device___52 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___50 = 0,
				DEV_PATH_BR_VLAN_TAG___50 = 1,
				DEV_PATH_BR_VLAN_UNTAG___50 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___50 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___50 {
	const struct net_device___52 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___50 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___46 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___50 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___50 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___51 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___50 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___52 *dev;
	const char *name;
};

struct net_device_ops___50 {
	int (*ndo_init)(struct net_device___52 *);
	void (*ndo_uninit)(struct net_device___52 *);
	int (*ndo_open)(struct net_device___52 *);
	int (*ndo_stop)(struct net_device___52 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___51 *, struct net_device___52 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___51 *, struct net_device___52 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___52 *, struct sk_buff___51 *, struct net_device___52 *);
	void (*ndo_change_rx_flags)(struct net_device___52 *, int);
	void (*ndo_set_rx_mode)(struct net_device___52 *);
	int (*ndo_set_mac_address)(struct net_device___52 *, void *);
	int (*ndo_validate_addr)(struct net_device___52 *);
	int (*ndo_do_ioctl)(struct net_device___52 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___52 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___52 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___52 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___52 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___52 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___52 *, int);
	int (*ndo_neigh_setup)(struct net_device___52 *, struct neigh_parms___39 *);
	void (*ndo_tx_timeout)(struct net_device___52 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___52 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___52 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___52 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___52 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___52 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___52 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___52 *);
	int (*ndo_netpoll_setup)(struct net_device___52 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___52 *);
	int (*ndo_set_vf_mac)(struct net_device___52 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___52 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___52 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___52 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___52 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___52 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___52 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___52 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___52 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___52 *, int, struct sk_buff___51 *);
	int (*ndo_get_vf_guid)(struct net_device___52 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___52 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___52 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___52 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___52 *);
	int (*ndo_fcoe_disable)(struct net_device___52 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___52 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___52 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___52 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___52 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___52 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___52 *, const struct sk_buff___51 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___52 *, struct net_device___52 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___52 *, struct net_device___52 *);
	struct net_device___52 * (*ndo_get_xmit_slave)(struct net_device___52 *, struct sk_buff___51 *, bool);
	struct net_device___52 * (*ndo_sk_get_lower_dev)(struct net_device___52 *, struct sock___40 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___52 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___52 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___52 *, struct neighbour___39 *);
	void (*ndo_neigh_destroy)(struct net_device___52 *, struct neighbour___39 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___51 *, struct netlink_callback___50 *, struct net_device___52 *, struct net_device___52 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___51 *, struct nlattr **, struct net_device___52 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___52 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___51 *, u32, u32, struct net_device___52 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___52 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___52 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___52 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___52 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___52 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___52 *, struct net_device___52 *);
	void (*ndo_dfwd_del_station)(struct net_device___52 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___52 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___52 *);
	int (*ndo_change_proto_down)(struct net_device___52 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___52 *, struct sk_buff___51 *);
	void (*ndo_set_rx_headroom)(struct net_device___52 *, int);
	int (*ndo_bpf)(struct net_device___52 *, struct netdev_bpf___50 *);
	int (*ndo_xdp_xmit)(struct net_device___52 *, int, struct xdp_frame___50 **, u32);
	struct net_device___52 * (*ndo_xdp_get_xmit_slave)(struct net_device___52 *, struct xdp_buff___50 *);
	int (*ndo_xsk_wakeup)(struct net_device___52 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___52 *);
	int (*ndo_tunnel_ctl)(struct net_device___52 *, struct ip_tunnel_parm *, int);
	struct net_device___52 * (*ndo_get_peer_dev)(struct net_device___52 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___50 *, struct net_device_path___50 *);
};

struct neigh_parms___39 {
	possible_net_t___50 net;
	struct net_device___52 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___39 *);
	struct neigh_table___39 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___39 {
	u32 (*l3mdev_fib_table)(const struct net_device___52 *);
	struct sk_buff___51 * (*l3mdev_l3_rcv)(struct net_device___52 *, struct sk_buff___51 *, u16);
	struct sk_buff___51 * (*l3mdev_l3_out)(struct net_device___52 *, struct sock___40 *, struct sk_buff___51 *, u16);
	struct dst_entry___39 * (*l3mdev_link_scope_lookup)(const struct net_device___52 *, struct flowi6 *);
};

struct tcf_proto___46;

struct tcf_block___46;

struct mini_Qdisc___46 {
	struct tcf_proto___46 *filter_list;
	struct tcf_block___46 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___46 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___52 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___52 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___55 *, struct net_device___52 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___52 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___52 *, struct list_head *);
	size_t (*get_size)(const struct net_device___52 *);
	int (*fill_info)(struct sk_buff___51 *, const struct net_device___52 *);
	size_t (*get_xstats_size)(const struct net_device___52 *);
	int (*fill_xstats)(struct sk_buff___51 *, const struct net_device___52 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___52 *, struct net_device___52 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___52 *, const struct net_device___52 *);
	int (*fill_slave_info)(struct sk_buff___51 *, const struct net_device___52 *, const struct net_device___52 *);
	struct net___55 * (*get_link_net)(const struct net_device___52 *);
	size_t (*get_linkxstats_size)(const struct net_device___52 *, int);
	int (*fill_linkxstats)(struct sk_buff___51 *, const struct net_device___52 *, int *, int);
};

struct rtgenmsg {
	unsigned char rtgen_family;
};

enum rtnetlink_groups {
	RTNLGRP_NONE = 0,
	RTNLGRP_LINK = 1,
	RTNLGRP_NOTIFY = 2,
	RTNLGRP_NEIGH = 3,
	RTNLGRP_TC = 4,
	RTNLGRP_IPV4_IFADDR = 5,
	RTNLGRP_IPV4_MROUTE = 6,
	RTNLGRP_IPV4_ROUTE = 7,
	RTNLGRP_IPV4_RULE = 8,
	RTNLGRP_IPV6_IFADDR = 9,
	RTNLGRP_IPV6_MROUTE = 10,
	RTNLGRP_IPV6_ROUTE = 11,
	RTNLGRP_IPV6_IFINFO = 12,
	RTNLGRP_DECnet_IFADDR = 13,
	RTNLGRP_NOP2 = 14,
	RTNLGRP_DECnet_ROUTE = 15,
	RTNLGRP_DECnet_RULE = 16,
	RTNLGRP_NOP4 = 17,
	RTNLGRP_IPV6_PREFIX = 18,
	RTNLGRP_IPV6_RULE = 19,
	RTNLGRP_ND_USEROPT = 20,
	RTNLGRP_PHONET_IFADDR = 21,
	RTNLGRP_PHONET_ROUTE = 22,
	RTNLGRP_DCB = 23,
	RTNLGRP_IPV4_NETCONF = 24,
	RTNLGRP_IPV6_NETCONF = 25,
	RTNLGRP_MDB = 26,
	RTNLGRP_MPLS_ROUTE = 27,
	RTNLGRP_NSID = 28,
	RTNLGRP_MPLS_NETCONF = 29,
	RTNLGRP_IPV4_MROUTE_R = 30,
	RTNLGRP_IPV6_MROUTE_R = 31,
	RTNLGRP_NEXTHOP = 32,
	RTNLGRP_BRVLAN = 33,
	__RTNLGRP_MAX = 34,
};

enum {
	NETNSA_NONE = 0,
	NETNSA_NSID = 1,
	NETNSA_PID = 2,
	NETNSA_FD = 3,
	NETNSA_TARGET_NSID = 4,
	NETNSA_CURRENT_NSID = 5,
	__NETNSA_MAX = 6,
};

struct pcpu_gen_cookie {
	local_t nesting;
	u64 last;
};

struct gen_cookie {
	struct pcpu_gen_cookie *local;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic64_t forward_last;
	atomic64_t reverse_last;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device_operations___134;

struct gendisk___137 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___137 *part0;
	const struct block_device_operations___134 *fops;
	struct request_queue___134 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___120 *bdi;
	struct kobject___229 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___229 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___134 {
	struct bio___134 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___158 *bip_vec;
	struct bio_vec___158 bip_inline_vecs[0];
};

struct blkcg___122;

struct blkg_policy_data___122;

struct blkcg_gq___122 {
	struct request_queue___134 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___122 *blkcg;
	struct blkcg_gq___122 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___122 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___134 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___134(struct request___134 *);

typedef void integrity_complete_fn___134(struct request___134 *, unsigned int);

struct blk_integrity_profile___134 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___134 *prepare_fn;
	integrity_complete_fn___134 *complete_fn;
	const char *name;
};

struct block_device_operations___134 {
	blk_qc_t (*submit_bio)(struct bio___134 *);
	int (*open)(struct block_device___137 *, fmode_t);
	void (*release)(struct gendisk___137 *, fmode_t);
	int (*rw_page)(struct block_device___137 *, sector_t, struct page___246 *, unsigned int);
	int (*ioctl)(struct block_device___137 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___137 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___137 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___137 *);
	int (*getgeo)(struct block_device___137 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___137 *, bool);
	void (*swap_slot_free_notify)(struct block_device___137 *, long unsigned int);
	int (*report_zones)(struct gendisk___137 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___137 *, umode_t *);
	struct module___225 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___137 *, sector_t *);
};

typedef void rq_end_io_fn___134(struct request___134 *, blk_status_t);

struct request___134 {
	struct request_queue___134 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___129 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___134 *bio;
	struct bio___134 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___158 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___134 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___134 *saved_end_io;
		} flush;
	};
	struct gendisk___137 *rq_disk;
	struct block_device___137 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___134 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___129 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___134 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___229 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___241 *debugfs_dir;
	struct dentry___241 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___134;

struct elevator_mq_ops___134 {
	int (*init_sched)(struct request_queue___134 *, struct elevator_type___134 *);
	void (*exit_sched)(struct elevator_queue___134 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___129 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___129 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___129 *);
	bool (*allow_merge)(struct request_queue___134 *, struct request___134 *, struct bio___134 *);
	bool (*bio_merge)(struct request_queue___134 *, struct bio___134 *, unsigned int);
	int (*request_merge)(struct request_queue___134 *, struct request___134 **, struct bio___134 *);
	void (*request_merged)(struct request_queue___134 *, struct request___134 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___134 *, struct request___134 *, struct request___134 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___134 *);
	void (*finish_request)(struct request___134 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___129 *, struct list_head *, bool);
	struct request___134 * (*dispatch_request)(struct blk_mq_hw_ctx___129 *);
	bool (*has_work)(struct blk_mq_hw_ctx___129 *);
	void (*completed_request)(struct request___134 *, u64);
	void (*requeue_request)(struct request___134 *);
	struct request___134 * (*former_request)(struct request_queue___134 *, struct request___134 *);
	struct request___134 * (*next_request)(struct request_queue___134 *, struct request___134 *);
	void (*init_icq)(struct io_cq___134 *);
	void (*exit_icq)(struct io_cq___134 *);
};

struct elv_fs_entry___134;

struct elevator_type___134 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___134 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___134 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___225 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___134 {
	struct elevator_type___134 *type;
	void *elevator_data;
	struct kobject___229 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___134 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___134 *, char *);
	ssize_t (*store)(struct elevator_queue___134 *, const char *, size_t);
};

struct blk_mq_queue_data___129;

struct blk_mq_ops___129 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___129 *, const struct blk_mq_queue_data___129 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___129 *);
	int (*get_budget)(struct request_queue___134 *);
	void (*put_budget)(struct request_queue___134 *, int);
	void (*set_rq_budget_token)(struct request___134 *, int);
	int (*get_rq_budget_token)(struct request___134 *);
	enum blk_eh_timer_return (*timeout)(struct request___134 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___129 *);
	void (*complete)(struct request___134 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___129 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___129 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___129 *, struct request___134 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___129 *, struct request___134 *, unsigned int);
	void (*initialize_rq_fn)(struct request___134 *);
	void (*cleanup_rq)(struct request___134 *);
	bool (*busy)(struct request_queue___134 *);
	int (*map_queues)(struct blk_mq_tag_set___129 *);
	void (*show_rq)(struct seq_file___216 *, struct request___134 *);
};

struct blk_mq_tag_set___129 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___129 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___129 {
	struct request___134 *rq;
	bool last;
};

struct blkcg_policy_data___122;

struct blkcg___122 {
	struct cgroup_subsys_state___168 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___122 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___122 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___122 {
	struct blkcg___122 *blkcg;
	int plid;
};

struct blkg_policy_data___122 {
	struct blkcg_gq___122 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___108 {
	struct mem_cgroup___108 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___108 {
	struct lruvec___116 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___108 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___108 *memcg;
};

struct obj_cgroup___108 {
	struct percpu_ref refcnt;
	struct mem_cgroup___108 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___46 {
	spinlock_t *lock;
	struct sk_buff___51 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

typedef int (*rtnl_doit_func)(struct sk_buff___51 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func)(struct sk_buff___51 *, struct netlink_callback___50 *);

enum rtnl_link_flags {
	RTNL_FLAG_DOIT_UNLOCKED = 1,
};

struct Qdisc_class_ops___46;

struct Qdisc_ops___46 {
	struct Qdisc_ops___46 *next;
	const struct Qdisc_class_ops___46 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___51 *, struct Qdisc___46 *, struct sk_buff___51 **);
	struct sk_buff___51 * (*dequeue)(struct Qdisc___46 *);
	struct sk_buff___51 * (*peek)(struct Qdisc___46 *);
	int (*init)(struct Qdisc___46 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___46 *);
	void (*destroy)(struct Qdisc___46 *);
	int (*change)(struct Qdisc___46 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___46 *);
	int (*change_tx_queue_len)(struct Qdisc___46 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___46 *, unsigned int);
	int (*dump)(struct Qdisc___46 *, struct sk_buff___51 *);
	int (*dump_stats)(struct Qdisc___46 *, struct gnet_dump___46 *);
	void (*ingress_block_set)(struct Qdisc___46 *, u32);
	void (*egress_block_set)(struct Qdisc___46 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___46 *);
	u32 (*egress_block_get)(struct Qdisc___46 *);
	struct module___225 *owner;
};

struct Qdisc_class_ops___46 {
	unsigned int flags;
	struct netdev_queue___50 * (*select_queue)(struct Qdisc___46 *, struct tcmsg *);
	int (*graft)(struct Qdisc___46 *, long unsigned int, struct Qdisc___46 *, struct Qdisc___46 **, struct netlink_ext_ack *);
	struct Qdisc___46 * (*leaf)(struct Qdisc___46 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___46 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___46 *, u32);
	int (*change)(struct Qdisc___46 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___46 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___46 *, struct qdisc_walker *);
	struct tcf_block___46 * (*tcf_block)(struct Qdisc___46 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___46 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___46 *, long unsigned int);
	int (*dump)(struct Qdisc___46 *, long unsigned int, struct sk_buff___51 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___46 *, long unsigned int, struct gnet_dump___46 *);
};

struct tcf_chain___46;

struct tcf_block___46 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___55 *net;
	struct Qdisc___46 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___46 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___46;

struct tcf_proto_ops___46;

struct tcf_proto___46 {
	struct tcf_proto___46 *next;
	void *root;
	int (*classify)(struct sk_buff___51 *, const struct tcf_proto___46 *, struct tcf_result___46 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___46 *ops;
	struct tcf_chain___46 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___46 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___46 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___46 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___51 *, const struct tcf_proto___46 *, struct tcf_result___46 *);
	int (*init)(struct tcf_proto___46 *);
	void (*destroy)(struct tcf_proto___46 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___46 *, u32);
	void (*put)(struct tcf_proto___46 *, void *);
	int (*change)(struct net___55 *, struct sk_buff___51 *, struct tcf_proto___46 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___46 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___46 *);
	void (*walk)(struct tcf_proto___46 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___46 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___46 *, void *);
	void (*hw_del)(struct tcf_proto___46 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___55 *, struct tcf_chain___46 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___55 *, struct tcf_proto___46 *, void *, struct sk_buff___51 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___55 *, struct tcf_proto___46 *, void *, struct sk_buff___51 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___51 *, struct net___55 *, void *);
	struct module___225 *owner;
	int flags;
};

struct tcf_chain___46 {
	struct mutex filter_chain_lock;
	struct tcf_proto___46 *filter_chain;
	struct list_head list;
	struct tcf_block___46 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___46 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___39 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___46 *prog;
};

struct pneigh_entry___39;

struct neigh_hash_table___39;

struct neigh_table___39 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___52 *, __u32 *);
	bool (*key_eq)(const struct neighbour___39 *, const void *);
	int (*constructor)(struct neighbour___39 *);
	int (*pconstructor)(struct pneigh_entry___39 *);
	void (*pdestructor)(struct pneigh_entry___39 *);
	void (*proxy_redo)(struct sk_buff___51 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___52 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___39 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___50 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___39 *nht;
	struct pneigh_entry___39 **phash_buckets;
};

struct neigh_ops___39 {
	int family;
	void (*solicit)(struct neighbour___39 *, struct sk_buff___51 *);
	void (*error_report)(struct neighbour___39 *, struct sk_buff___51 *);
	int (*output)(struct neighbour___39 *, struct sk_buff___51 *);
	int (*connected_output)(struct neighbour___39 *, struct sk_buff___51 *);
};

struct pneigh_entry___39 {
	struct pneigh_entry___39 *next;
	possible_net_t___50 net;
	struct net_device___52 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___39 {
	struct neighbour___39 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___39 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___39 *ctarget;
	struct net___55 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___39 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___39 *rule;
	u32 table;
	int flags;
};

struct proto___39 {
	void (*close)(struct sock___40 *, long int);
	int (*pre_connect)(struct sock___40 *, struct sockaddr *, int);
	int (*connect)(struct sock___40 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___40 *, int);
	struct sock___40 * (*accept)(struct sock___40 *, int, int *, bool);
	int (*ioctl)(struct sock___40 *, int, long unsigned int);
	int (*init)(struct sock___40 *);
	void (*destroy)(struct sock___40 *);
	void (*shutdown)(struct sock___40 *, int);
	int (*setsockopt)(struct sock___40 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___40 *, int, int, char *, int *);
	void (*keepalive)(struct sock___40 *, int);
	int (*compat_ioctl)(struct sock___40 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___40 *, struct msghdr___41 *, size_t);
	int (*recvmsg)(struct sock___40 *, struct msghdr___41 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___40 *, struct page___246 *, int, size_t, int);
	int (*bind)(struct sock___40 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___40 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___40 *, struct sk_buff___51 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___40 *);
	int (*hash)(struct sock___40 *);
	void (*unhash)(struct sock___40 *);
	void (*rehash)(struct sock___40 *);
	int (*get_port)(struct sock___40 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___40 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___40 *, int);
	bool (*sock_is_readable)(struct sock___40 *);
	void (*enter_memory_pressure)(struct sock___40 *);
	void (*leave_memory_pressure)(struct sock___40 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___225 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___40 *, int);
};

struct net_fill_args {
	u32 portid;
	u32 seq;
	int flags;
	int cmd;
	int nsid;
	bool add_ref;
	int ref_nsid;
};

struct rtnl_net_dump_cb {
	struct net___55 *tgt_net;
	struct net___55 *ref_net;
	struct sk_buff___51 *skb;
	struct net_fill_args fillargs;
	int idx;
	int s_idx;
};

typedef u16 u_int16_t;

typedef u32 u_int32_t;

typedef u64 u_int64_t;

struct dentry___242;

struct super_block___242;

struct module___226;

struct file_system_type___242 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___242 * (*mount)(struct file_system_type___242 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___242 *);
	struct module___226 *owner;
	struct file_system_type___242 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___242;

struct kiocb___242;

struct iov_iter___162;

struct poll_table_struct___165;

struct vm_area_struct___247;

struct inode___242;

struct file_lock___242;

struct page___247;

struct pipe_inode_info___83;

struct seq_file___217;

struct file_operations___243 {
	struct module___226 *owner;
	loff_t (*llseek)(struct file___242 *, loff_t, int);
	ssize_t (*read)(struct file___242 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___242 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___242 *, struct iov_iter___162 *);
	ssize_t (*write_iter)(struct kiocb___242 *, struct iov_iter___162 *);
	int (*iopoll)(struct kiocb___242 *, bool);
	int (*iterate)(struct file___242 *, struct dir_context *);
	int (*iterate_shared)(struct file___242 *, struct dir_context *);
	__poll_t (*poll)(struct file___242 *, struct poll_table_struct___165 *);
	long int (*unlocked_ioctl)(struct file___242 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___242 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___242 *, struct vm_area_struct___247 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___242 *, struct file___242 *);
	int (*flush)(struct file___242 *, fl_owner_t);
	int (*release)(struct inode___242 *, struct file___242 *);
	int (*fsync)(struct file___242 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___242 *, int);
	int (*lock)(struct file___242 *, int, struct file_lock___242 *);
	ssize_t (*sendpage)(struct file___242 *, struct page___247 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___242 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___242 *, long unsigned int);
	int (*flock)(struct file___242 *, int, struct file_lock___242 *);
	ssize_t (*splice_write)(struct pipe_inode_info___83 *, struct file___242 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___242 *, loff_t *, struct pipe_inode_info___83 *, size_t, unsigned int);
	int (*setlease)(struct file___242 *, long int, struct file_lock___242 **, void **);
	long int (*fallocate)(struct file___242 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___217 *, struct file___242 *);
	ssize_t (*copy_file_range)(struct file___242 *, loff_t, struct file___242 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___242 *, loff_t, struct file___242 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___242 *, loff_t, loff_t, int);
};

struct vmacache___247 {
	u64 seqnum;
	struct vm_area_struct___247 *vmas[4];
};

struct page_frag___247 {
	struct page___247 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___248;

struct pid___219;

struct nsproxy___228;

struct signal_struct___243;

struct bio_list___135;

struct backing_dev_info___121;

struct io_context___135;

struct css_set___169;

struct mem_cgroup___109;

struct request_queue___135;

struct vm_struct___225;

struct task_struct___249 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___249 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___248 *mm;
	struct mm_struct___248 *active_mm;
	struct vmacache___247 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___249 *real_parent;
	struct task_struct___249 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___249 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___219 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___228 *nsproxy;
	struct signal_struct___243 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___249 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___135 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___121 *backing_dev_info;
	struct io_context___135 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___169 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___83 *splice_pipe;
	struct page_frag___247 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___109 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___109 *active_memcg;
	struct request_queue___135 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___249 *oom_reaper_list;
	struct vm_struct___225 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___230;

struct kobj_type___230;

struct kernfs_node___230;

struct kobject___230 {
	const char *name;
	struct list_head entry;
	struct kobject___230 *parent;
	struct kset___230 *kset;
	struct kobj_type___230 *ktype;
	struct kernfs_node___230 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___227 {
	struct kobject___230 kobj;
	struct module___226 *mod;
	struct kobject___230 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___226 {
	struct module___226 *mod;
	struct latch_tree_node node;
};

struct module_layout___226 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___226 mtn;
};

struct module_attribute___226;

struct kernel_param___226;

struct module___226 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___227 mkobj;
	struct module_attribute___226 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___230 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___226 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___226 core_layout;
	struct module_layout___226 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___242;

struct dentry___242 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___242 *d_parent;
	struct qstr d_name;
	struct inode___242 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___242 *d_op;
	struct super_block___242 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___242;

struct address_space___242 {
	struct inode___242 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___242 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___242;

struct bdi_writeback___121;

struct inode___242 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___242 *i_op;
	struct super_block___242 *i_sb;
	struct address_space___242 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___121 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___243 *i_fop;
		void (*free_inode)(struct inode___242 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___242 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___83 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___242;

struct path___242;

struct dentry_operations___242 {
	int (*d_revalidate)(struct dentry___242 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___242 *, unsigned int);
	int (*d_hash)(const struct dentry___242 *, struct qstr *);
	int (*d_compare)(const struct dentry___242 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___242 *);
	int (*d_init)(struct dentry___242 *);
	void (*d_release)(struct dentry___242 *);
	void (*d_prune)(struct dentry___242 *);
	void (*d_iput)(struct dentry___242 *, struct inode___242 *);
	char * (*d_dname)(struct dentry___242 *, char *, int);
	struct vfsmount___242 * (*d_automount)(struct path___242 *);
	int (*d_manage)(const struct path___242 *, bool);
	struct dentry___242 * (*d_real)(struct dentry___242 *, const struct inode___242 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___242;

struct mem_dqinfo___242 {
	struct quota_format_type___242 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___242;

struct quota_info___242 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___242 *files[3];
	struct mem_dqinfo___242 info[3];
	const struct quota_format_ops___242 *ops[3];
};

struct rcuwait___243 {
	struct task_struct___249 *task;
};

struct percpu_rw_semaphore___243 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___243 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___242 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___243 rw_sem[3];
};

struct shrink_control___109;

struct shrinker___109 {
	long unsigned int (*count_objects)(struct shrinker___109 *, struct shrink_control___109 *);
	long unsigned int (*scan_objects)(struct shrinker___109 *, struct shrink_control___109 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___242;

struct dquot_operations___242;

struct quotactl_ops___242;

struct block_device___138;

struct super_block___242 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___242 *s_type;
	const struct super_operations___242 *s_op;
	const struct dquot_operations___242 *dq_op;
	const struct quotactl_ops___242 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___242 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___138 *s_bdev;
	struct backing_dev_info___121 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___242 s_dquot;
	struct sb_writers___242 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___242 *s_d_op;
	int cleancache_poolid;
	struct shrinker___109 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___242 {
	struct dentry___242 *mnt_root;
	struct super_block___242 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___242 {
	struct vfsmount___242 *mnt;
	struct dentry___242 *dentry;
};

struct pid_namespace___219;

struct upid___219 {
	int nr;
	struct pid_namespace___219 *ns;
};

struct pid_namespace___219 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___249 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___219 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___219 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___219 numbers[1];
};

typedef struct page___247 *pgtable_t___247;

struct page_pool___71;

struct dev_pagemap___237;

struct page___247 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___242 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___71 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___247 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___247 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___248 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___237 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___237;

struct vm_area_struct___247 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___247 *vm_next;
	struct vm_area_struct___247 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___248 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___237 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___242 *vm_file;
	struct file___242 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___243 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___249 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___249 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___219 *pids[4];
	struct pid___219 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___248 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___247;

struct mm_struct___248 {
	struct {
		struct vm_area_struct___247 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___242 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___247 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___249 *owner;
		struct user_namespace___26 *user_ns;
		struct file___242 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___56;

struct cgroup_namespace___169;

struct nsproxy___228 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___219 *pid_ns_for_children;
	struct net___56 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___169 *cgroup_ns;
};

struct bio___135;

struct bio_list___135 {
	struct bio___135 *head;
	struct bio___135 *tail;
};

struct cgroup_subsys_state___169;

struct bdi_writeback___121 {
	struct backing_dev_info___121 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___169 *memcg_css;
	struct cgroup_subsys_state___169 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___223;

struct backing_dev_info___121 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___121 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___223 *dev;
	char dev_name[64];
	struct device___223 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___242 *debug_dir;
};

struct io_cq___135;

struct io_context___135 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___135 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___169;

struct css_set___169 {
	struct cgroup_subsys_state___169 *subsys[14];
	refcount_t refcount;
	struct css_set___169 *dom_cset;
	struct cgroup___169 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___169 *mg_src_cgrp;
	struct cgroup___169 *mg_dst_cgrp;
	struct css_set___169 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___242;

struct pipe_buffer___83;

struct pipe_inode_info___83 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___247 *tmp_page;
	struct fasync_struct___242 *fasync_readers;
	struct fasync_struct___242 *fasync_writers;
	struct pipe_buffer___83 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___169;

struct cgroup_subsys_state___169 {
	struct cgroup___169 *cgroup;
	struct cgroup_subsys___169 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___169 *parent;
};

struct cgroup_file___169 {
	struct kernfs_node___230 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___109;

struct mem_cgroup_per_node___109;

struct mem_cgroup___109 {
	struct cgroup_subsys_state___169 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___169 events_file;
	struct cgroup_file___169 events_local_file;
	struct cgroup_file___169 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___109 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___249 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___109 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___135;

struct blk_integrity___135 {
	const struct blk_integrity_profile___135 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___135 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___135 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___135;

struct elevator_queue___135;

struct blk_mq_ops___130;

struct blk_mq_hw_ctx___130;

struct gendisk___138;

struct blkcg_gq___123;

struct blk_mq_tag_set___130;

struct request_queue___135 {
	struct request___135 *last_merge;
	struct elevator_queue___135 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___130 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___130 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___138 *disk;
	struct kobject___230 kobj;
	struct kobject___230 *mq_kobj;
	struct blk_integrity___135 integrity;
	struct device___223 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___123 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___130 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___135 bio_split;
	struct dentry___242 *debugfs_dir;
	struct dentry___242 *sched_debugfs_dir;
	struct dentry___242 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___225 {
	struct vm_struct___225 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___247 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___109 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___109 *memcg;
};

struct page_pool_params___71 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___223 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___71 {
	u32 count;
	struct page___247 *cache[128];
};

struct page_pool___71 {
	struct page_pool_params___71 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___247 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___71 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___237;

struct dev_pagemap___237 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___237 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___219 {
	rwlock_t lock;
	struct pid___219 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___242 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___242 f_path;
	struct inode___242 *f_inode;
	const struct file_operations___243 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___219 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___242 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___237;

struct vm_operations_struct___237 {
	void (*open)(struct vm_area_struct___247 *);
	void (*close)(struct vm_area_struct___247 *);
	int (*may_split)(struct vm_area_struct___247 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___247 *);
	int (*mprotect)(struct vm_area_struct___247 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___237 *);
	vm_fault_t (*huge_fault)(struct vm_fault___237 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___237 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___247 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___237 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___237 *);
	int (*access)(struct vm_area_struct___247 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___247 *);
	int (*set_policy)(struct vm_area_struct___247 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___247 *, long unsigned int);
	struct page___247 * (*find_special_page)(struct vm_area_struct___247 *, long unsigned int);
};

struct core_thread___247 {
	struct task_struct___249 *task;
	struct core_thread___247 *next;
};

struct core_state___247 {
	atomic_t nr_threads;
	struct core_thread___247 dumper;
	struct completion startup;
};

struct vm_fault___237 {
	const struct {
		struct vm_area_struct___247 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___247 *cow_page;
	struct page___247 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___247 prealloc_pte;
};

struct pglist_data___117;

struct lruvec___117 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___117 *pgdat;
};

struct zone___117 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___117 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___117 {
	struct zone___117 *zone;
	int zone_idx;
};

struct zonelist___117 {
	struct zoneref___117 _zonerefs[321];
};

struct pglist_data___117 {
	struct zone___117 node_zones[5];
	struct zonelist___117 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___249 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___249 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___117 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___169 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___249 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___47;

struct cgroup_bpf___47 {
	struct bpf_prog_array___47 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___47 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___169;

struct cgroup_rstat_cpu___169;

struct cgroup___169 {
	struct cgroup_subsys_state___169 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___230 *kn;
	struct cgroup_file___169 procs_file;
	struct cgroup_file___169 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___169 *subsys[14];
	struct cgroup_root___169 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___169 *dom_cgrp;
	struct cgroup___169 *old_dom_cgrp;
	struct cgroup_rstat_cpu___169 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___169 psi;
	struct cgroup_bpf___47 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___135 {
	struct request_queue___135 *q;
	struct io_context___135 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___242 {
	struct file___242 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___242 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___242 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___242 *ia_file;
};

struct dquot___242 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___242 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___242 {
	int qf_fmt_id;
	const struct quota_format_ops___242 *qf_ops;
	struct module___226 *qf_owner;
	struct quota_format_type___242 *qf_next;
};

struct quota_format_ops___242 {
	int (*check_quota_file)(struct super_block___242 *, int);
	int (*read_file_info)(struct super_block___242 *, int);
	int (*write_file_info)(struct super_block___242 *, int);
	int (*free_file_info)(struct super_block___242 *, int);
	int (*read_dqblk)(struct dquot___242 *);
	int (*commit_dqblk)(struct dquot___242 *);
	int (*release_dqblk)(struct dquot___242 *);
	int (*get_next_id)(struct super_block___242 *, struct kqid *);
};

struct dquot_operations___242 {
	int (*write_dquot)(struct dquot___242 *);
	struct dquot___242 * (*alloc_dquot)(struct super_block___242 *, int);
	void (*destroy_dquot)(struct dquot___242 *);
	int (*acquire_dquot)(struct dquot___242 *);
	int (*release_dquot)(struct dquot___242 *);
	int (*mark_dirty)(struct dquot___242 *);
	int (*write_info)(struct super_block___242 *, int);
	qsize_t * (*get_reserved_space)(struct inode___242 *);
	int (*get_projid)(struct inode___242 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___242 *, qsize_t *);
	int (*get_next_id)(struct super_block___242 *, struct kqid *);
};

struct quotactl_ops___242 {
	int (*quota_on)(struct super_block___242 *, int, int, const struct path___242 *);
	int (*quota_off)(struct super_block___242 *, int);
	int (*quota_enable)(struct super_block___242 *, unsigned int);
	int (*quota_disable)(struct super_block___242 *, unsigned int);
	int (*quota_sync)(struct super_block___242 *, int);
	int (*set_info)(struct super_block___242 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___242 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___242 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___242 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___242 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___242 *, unsigned int);
};

struct writeback_control___121;

struct address_space_operations___242 {
	int (*writepage)(struct page___247 *, struct writeback_control___121 *);
	int (*readpage)(struct file___242 *, struct page___247 *);
	int (*writepages)(struct address_space___242 *, struct writeback_control___121 *);
	int (*set_page_dirty)(struct page___247 *);
	int (*readpages)(struct file___242 *, struct address_space___242 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___242 *, struct address_space___242 *, loff_t, unsigned int, unsigned int, struct page___247 **, void **);
	int (*write_end)(struct file___242 *, struct address_space___242 *, loff_t, unsigned int, unsigned int, struct page___247 *, void *);
	sector_t (*bmap)(struct address_space___242 *, sector_t);
	void (*invalidatepage)(struct page___247 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___247 *, gfp_t);
	void (*freepage)(struct page___247 *);
	ssize_t (*direct_IO)(struct kiocb___242 *, struct iov_iter___162 *);
	int (*migratepage)(struct address_space___242 *, struct page___247 *, struct page___247 *, enum migrate_mode);
	bool (*isolate_page)(struct page___247 *, isolate_mode_t);
	void (*putback_page)(struct page___247 *);
	int (*launder_page)(struct page___247 *);
	int (*is_partially_uptodate)(struct page___247 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___247 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___242 *, struct page___247 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___242 *, sector_t *);
	void (*swap_deactivate)(struct file___242 *);
};

struct writeback_control___121 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___121 *wb;
	struct inode___242 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___159;

struct iov_iter___162 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___159 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___83 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___242 {
	struct dentry___242 * (*lookup)(struct inode___242 *, struct dentry___242 *, unsigned int);
	const char * (*get_link)(struct dentry___242 *, struct inode___242 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___242 *, int);
	struct posix_acl * (*get_acl)(struct inode___242 *, int, bool);
	int (*readlink)(struct dentry___242 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___242 *, struct dentry___242 *, umode_t, bool);
	int (*link)(struct dentry___242 *, struct inode___242 *, struct dentry___242 *);
	int (*unlink)(struct inode___242 *, struct dentry___242 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___242 *, struct dentry___242 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___242 *, struct dentry___242 *, umode_t);
	int (*rmdir)(struct inode___242 *, struct dentry___242 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___242 *, struct dentry___242 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___242 *, struct dentry___242 *, struct inode___242 *, struct dentry___242 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___242 *, struct iattr___242 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___242 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___242 *, char *, size_t);
	int (*fiemap)(struct inode___242 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___242 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___242 *, struct dentry___242 *, struct file___242 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___242 *, struct dentry___242 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___242 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___242 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___242 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___242 {
	void (*fl_copy_lock)(struct file_lock___242 *, struct file_lock___242 *);
	void (*fl_release_private)(struct file_lock___242 *);
};

struct lock_manager_operations___242;

struct file_lock___242 {
	struct file_lock___242 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___242 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___242 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___242 *fl_ops;
	const struct lock_manager_operations___242 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___242 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___242 *);
	int (*lm_grant)(struct file_lock___242 *, int);
	bool (*lm_break)(struct file_lock___242 *);
	int (*lm_change)(struct file_lock___242 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___242 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___242 *);
};

struct fasync_struct___242 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___242 *fa_next;
	struct file___242 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___242 {
	struct inode___242 * (*alloc_inode)(struct super_block___242 *);
	void (*destroy_inode)(struct inode___242 *);
	void (*free_inode)(struct inode___242 *);
	void (*dirty_inode)(struct inode___242 *, int);
	int (*write_inode)(struct inode___242 *, struct writeback_control___121 *);
	int (*drop_inode)(struct inode___242 *);
	void (*evict_inode)(struct inode___242 *);
	void (*put_super)(struct super_block___242 *);
	int (*sync_fs)(struct super_block___242 *, int);
	int (*freeze_super)(struct super_block___242 *);
	int (*freeze_fs)(struct super_block___242 *);
	int (*thaw_super)(struct super_block___242 *);
	int (*unfreeze_fs)(struct super_block___242 *);
	int (*statfs)(struct dentry___242 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___242 *, int *, char *);
	void (*umount_begin)(struct super_block___242 *);
	int (*show_options)(struct seq_file___217 *, struct dentry___242 *);
	int (*show_devname)(struct seq_file___217 *, struct dentry___242 *);
	int (*show_path)(struct seq_file___217 *, struct dentry___242 *);
	int (*show_stats)(struct seq_file___217 *, struct dentry___242 *);
	ssize_t (*quota_read)(struct super_block___242 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___242 *, int, const char *, size_t, loff_t);
	struct dquot___242 ** (*get_dquots)(struct inode___242 *);
	long int (*nr_cached_objects)(struct super_block___242 *, struct shrink_control___109 *);
	long int (*free_cached_objects)(struct super_block___242 *, struct shrink_control___109 *);
	struct file___242 * (*real_loop)(struct file___242 *);
};

struct wakeup_source___223;

struct dev_pm_info___223 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___223 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___223 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___223;

struct bus_type___223;

struct device_driver___223;

struct dev_pm_domain___223;

struct device_node___100;

struct fwnode_handle___219;

struct class___223;

struct attribute_group___230;

struct device___223 {
	struct kobject___230 kobj;
	struct device___223 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___223 *type;
	struct bus_type___223 *bus;
	struct device_driver___223 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___223 power;
	struct dev_pm_domain___223 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___100 *of_node;
	struct fwnode_handle___219 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___223 *class;
	const struct attribute_group___230 **groups;
	void (*release)(struct device___223 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___138 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___242 *bd_inode;
	struct super_block___242 *bd_super;
	void *bd_claiming;
	struct device___223 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___230 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___138 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___242 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___173)(struct file___242 *, wait_queue_head_t *, struct poll_table_struct___165 *);

struct poll_table_struct___165 {
	poll_queue_proc___173 _qproc;
	__poll_t _key;
};

struct seq_operations___217;

struct seq_file___217 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___217 *op;
	int poll_event;
	const struct file___242 *file;
	void *private;
};

typedef void bio_end_io_t___135(struct bio___135 *);

struct bio_vec___159 {
	struct page___247 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___135;

struct bio___135 {
	struct bio___135 *bi_next;
	struct block_device___138 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___135 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___123 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___135 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___159 *bi_io_vec;
	struct bio_set___135 *bi_pool;
	struct bio_vec___159 bi_inline_vecs[0];
};

struct dev_pagemap_ops___237 {
	void (*page_free)(struct page___247 *);
	void (*kill)(struct dev_pagemap___237 *);
	void (*cleanup)(struct dev_pagemap___237 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___237 *);
};

struct fwnode_operations___219;

struct fwnode_handle___219 {
	struct fwnode_handle___219 *secondary;
	const struct fwnode_operations___219 *ops;
	struct device___223 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___219;

struct fwnode_endpoint___219;

struct fwnode_operations___219 {
	struct fwnode_handle___219 * (*get)(struct fwnode_handle___219 *);
	void (*put)(struct fwnode_handle___219 *);
	bool (*device_is_available)(const struct fwnode_handle___219 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___219 *, const struct device___223 *);
	bool (*property_present)(const struct fwnode_handle___219 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___219 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___219 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___219 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*get_parent)(const struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*get_next_child_node)(const struct fwnode_handle___219 *, struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*get_named_child_node)(const struct fwnode_handle___219 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___219 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___219 *);
	struct fwnode_handle___219 * (*graph_get_next_endpoint)(const struct fwnode_handle___219 *, struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*graph_get_remote_endpoint)(const struct fwnode_handle___219 *);
	struct fwnode_handle___219 * (*graph_get_port_parent)(struct fwnode_handle___219 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___219 *, struct fwnode_endpoint___219 *);
	int (*add_links)(struct fwnode_handle___219 *);
};

struct fwnode_endpoint___219 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___219 *local_fwnode;
};

struct fwnode_reference_args___219 {
	struct fwnode_handle___219 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___230;

struct kernfs_elem_dir___230 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___230 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___230;

struct kernfs_root___230 {
	struct kernfs_node___230 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___230 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___230 {
	struct kernfs_node___230 *target_kn;
};

struct kernfs_ops___230;

struct kernfs_elem_attr___230 {
	const struct kernfs_ops___230 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___230 *notify_next;
};

struct kernfs_node___230 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___230 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___230 dir;
		struct kernfs_elem_symlink___230 symlink;
		struct kernfs_elem_attr___230 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___230;

struct kernfs_ops___230 {
	int (*open)(struct kernfs_open_file___230 *);
	void (*release)(struct kernfs_open_file___230 *);
	int (*seq_show)(struct seq_file___217 *, void *);
	void * (*seq_start)(struct seq_file___217 *, loff_t *);
	void * (*seq_next)(struct seq_file___217 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___217 *, void *);
	ssize_t (*read)(struct kernfs_open_file___230 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___230 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___230 *, struct poll_table_struct___165 *);
	int (*mmap)(struct kernfs_open_file___230 *, struct vm_area_struct___247 *);
};

struct kernfs_syscall_ops___230 {
	int (*show_options)(struct seq_file___217 *, struct kernfs_root___230 *);
	int (*mkdir)(struct kernfs_node___230 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___230 *);
	int (*rename)(struct kernfs_node___230 *, struct kernfs_node___230 *, const char *);
	int (*show_path)(struct seq_file___217 *, struct kernfs_node___230 *, struct kernfs_root___230 *);
};

struct kernfs_open_file___230 {
	struct kernfs_node___230 *kn;
	struct file___242 *file;
	struct seq_file___217 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___237 *vm_ops;
};

struct sock___41;

struct kobj_ns_type_operations___40 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___41 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___56 *net;
} possible_net_t___51;

struct proto___40;

struct sock_common___40 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___40 *skc_prot;
	possible_net_t___51 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___41 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___52;

struct sk_buff_head___51 {
	struct sk_buff___52 *next;
	struct sk_buff___52 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___40 {
	struct cgroup___169 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___40;

struct socket_wq___41;

struct dst_entry___40;

struct socket___42;

struct net_device___53;

struct sock___41 {
	struct sock_common___40 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___51 sk_error_queue;
	struct sk_buff___52 *sk_rx_skb_cache;
	struct sk_buff_head___51 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___52 *head;
		struct sk_buff___52 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___40 *sk_filter;
	union {
		struct socket_wq___41 *sk_wq;
		struct socket_wq___41 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___40 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___40 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___52 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___52 *sk_tx_skb_cache;
	struct sk_buff_head___51 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___247 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___40 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___219 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___42 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___40 sk_cgrp_data;
	struct mem_cgroup___109 *sk_memcg;
	void (*sk_state_change)(struct sock___41 *);
	void (*sk_data_ready)(struct sock___41 *);
	void (*sk_write_space)(struct sock___41 *);
	void (*sk_error_report)(struct sock___41 *);
	int (*sk_backlog_rcv)(struct sock___41 *, struct sk_buff___52 *);
	struct sk_buff___52 * (*sk_validate_xmit_skb)(struct sock___41 *, struct net_device___53 *, struct sk_buff___52 *);
	void (*sk_destruct)(struct sock___41 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___230;

struct attribute_group___230 {
	const char *name;
	umode_t (*is_visible)(struct kobject___230 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___230 *, struct bin_attribute___230 *, int);
	struct attribute **attrs;
	struct bin_attribute___230 **bin_attrs;
};

struct bin_attribute___230 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___242 * (*f_mapping)();
	ssize_t (*read)(struct file___242 *, struct kobject___230 *, struct bin_attribute___230 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___242 *, struct kobject___230 *, struct bin_attribute___230 *, char *, loff_t, size_t);
	int (*mmap)(struct file___242 *, struct kobject___230 *, struct bin_attribute___230 *, struct vm_area_struct___247 *);
};

struct sysfs_ops___230 {
	ssize_t (*show)(struct kobject___230 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___230 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___230;

struct kset___230 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___230 kobj;
	const struct kset_uevent_ops___230 *uevent_ops;
};

struct kobj_type___230 {
	void (*release)(struct kobject___230 *);
	const struct sysfs_ops___230 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___230 **default_groups;
	const struct kobj_ns_type_operations___40 * (*child_ns_type)(struct kobject___230 *);
	const void * (*namespace)(struct kobject___230 *);
	void (*get_ownership)(struct kobject___230 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___230 {
	int (* const filter)(struct kset___230 *, struct kobject___230 *);
	const char * (* const name)(struct kset___230 *, struct kobject___230 *);
	int (* const uevent)(struct kset___230 *, struct kobject___230 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___226 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___226 *);
	int (*get)(char *, const struct kernel_param___226 *);
	void (*free)(void *);
};

struct kparam_array___226;

struct kernel_param___226 {
	const char *name;
	struct module___226 *mod;
	const struct kernel_param_ops___226 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___226 *arr;
	};
};

struct kparam_array___226 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___226 *ops;
	void *elem;
};

struct module_attribute___226 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___226 *, struct module_kobject___227 *, char *);
	ssize_t (*store)(struct module_attribute___226 *, struct module_kobject___227 *, const char *, size_t);
	void (*setup)(struct module___226 *, const char *);
	int (*test)(struct module___226 *);
	void (*free)(struct module___226 *);
};

struct ip_ra_chain___21;

struct fib_rules_ops___40;

struct fqdir___56;

struct fib_notifier_ops___40;

struct netns_ipv4___56 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___21 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___40 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___41 *fibnl;
	struct sock___41 **icmp_sk;
	struct sock___41 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___41 **tcp_sk;
	struct fqdir___56 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___40 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___40 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___40 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___40;

struct dst_ops___56 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___56 *);
	struct dst_entry___40 * (*check)(struct dst_entry___40 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___40 *);
	unsigned int (*mtu)(const struct dst_entry___40 *);
	u32 * (*cow_metrics)(struct dst_entry___40 *, long unsigned int);
	void (*destroy)(struct dst_entry___40 *);
	void (*ifdown)(struct dst_entry___40 *, struct net_device___53 *, int);
	struct dst_entry___40 * (*negative_advice)(struct dst_entry___40 *);
	void (*link_failure)(struct sk_buff___52 *);
	void (*update_pmtu)(struct dst_entry___40 *, struct sock___41 *, struct sk_buff___52 *, u32, bool);
	void (*redirect)(struct dst_entry___40 *, struct sock___41 *, struct sk_buff___52 *);
	int (*local_out)(struct net___56 *, struct sock___41 *, struct sk_buff___52 *);
	struct neighbour___40 * (*neigh_lookup)(const struct dst_entry___40 *, struct sk_buff___52 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___40 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___5;

struct rt6_info___5;

struct fib6_table___5;

struct netns_ipv6___56 {
	struct dst_ops___56 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___56 *fqdir;
	struct fib6_info___5 *fib6_null_entry;
	struct rt6_info___5 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___5 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___5 *ip6_prohibit_entry;
	struct rt6_info___5 *ip6_blk_hole_entry;
	struct fib6_table___5 *fib6_local_tbl;
	struct fib_rules_ops___40 *fib6_rules_ops;
	struct sock___41 **icmp_sk;
	struct sock___41 *ndisc_sk;
	struct sock___41 *tcp_sk;
	struct sock___41 *igmp_sk;
	struct sock___41 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___40 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___40 *notifier_ops;
	struct fib_notifier_ops___40 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___56 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___56 *fqdir;
};

struct netns_sctp___40 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___41 *ctl_sock;
	struct sock___41 *udp4_sock;
	struct sock___41 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___4;

struct netns_nf___4 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___4 *hooks_ipv4[5];
	struct nf_hook_entries___4 *hooks_ipv6[5];
	struct nf_hook_entries___4 *hooks_arp[3];
	struct nf_hook_entries___4 *hooks_bridge[5];
	struct nf_hook_entries___4 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___47;

struct netns_bpf___47 {
	struct bpf_prog_array___47 *run_array[2];
	struct bpf_prog___47 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___56 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___41 *nlsk;
	struct sock___41 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___56 xfrm4_dst_ops;
	struct dst_ops___56 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___56 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___41 *rtnl;
	struct sock___41 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___53 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___56 ipv4;
	struct netns_ipv6___56 ipv6;
	struct netns_ieee802154_lowpan___56 ieee802154_lowpan;
	struct netns_sctp___40 sctp;
	struct netns_nf___4 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___51 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___47 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___56 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___41 *crypto_nlsk;
	struct sock___41 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___169 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___169 *root_cset;
};

struct msghdr___42 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___162 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___242 *msg_iocb;
};

struct socket_wq___41 {
	wait_queue_head_t wait;
	struct fasync_struct___242 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___41;

struct socket___42 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___242 *file;
	struct sock___41 *sk;
	const struct proto_ops___41 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___41 wq;
};

typedef int (*sk_read_actor_t___40)(read_descriptor_t *, struct sk_buff___52 *, unsigned int, size_t);

struct proto_ops___41 {
	int family;
	struct module___226 *owner;
	int (*release)(struct socket___42 *);
	int (*bind)(struct socket___42 *, struct sockaddr *, int);
	int (*connect)(struct socket___42 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___42 *, struct socket___42 *);
	int (*accept)(struct socket___42 *, struct socket___42 *, int, bool);
	int (*getname)(struct socket___42 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___242 *, struct socket___42 *, struct poll_table_struct___165 *);
	int (*ioctl)(struct socket___42 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___42 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___42 *, void *, bool, bool);
	int (*listen)(struct socket___42 *, int);
	int (*shutdown)(struct socket___42 *, int);
	int (*setsockopt)(struct socket___42 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___42 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___217 *, struct socket___42 *);
	int (*sendmsg)(struct socket___42 *, struct msghdr___42 *, size_t);
	int (*recvmsg)(struct socket___42 *, struct msghdr___42 *, size_t, int);
	int (*mmap)(struct file___242 *, struct socket___42 *, struct vm_area_struct___247 *);
	ssize_t (*sendpage)(struct socket___42 *, struct page___247 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___42 *, loff_t *, struct pipe_inode_info___83 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___41 *, int);
	int (*peek_len)(struct socket___42 *);
	int (*read_sock)(struct sock___41 *, read_descriptor_t *, sk_read_actor_t___40);
	int (*sendpage_locked)(struct sock___41 *, struct page___247 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___41 *, struct msghdr___42 *, size_t);
	int (*set_rcvlowat)(struct sock___41 *, int);
};

struct sk_buff___52 {
	union {
		struct {
			struct sk_buff___52 *next;
			struct sk_buff___52 *prev;
			union {
				struct net_device___53 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___41 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___52 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___223 {
	int (*prepare)(struct device___223 *);
	void (*complete)(struct device___223 *);
	int (*suspend)(struct device___223 *);
	int (*resume)(struct device___223 *);
	int (*freeze)(struct device___223 *);
	int (*thaw)(struct device___223 *);
	int (*poweroff)(struct device___223 *);
	int (*restore)(struct device___223 *);
	int (*suspend_late)(struct device___223 *);
	int (*resume_early)(struct device___223 *);
	int (*freeze_late)(struct device___223 *);
	int (*thaw_early)(struct device___223 *);
	int (*poweroff_late)(struct device___223 *);
	int (*restore_early)(struct device___223 *);
	int (*suspend_noirq)(struct device___223 *);
	int (*resume_noirq)(struct device___223 *);
	int (*freeze_noirq)(struct device___223 *);
	int (*thaw_noirq)(struct device___223 *);
	int (*poweroff_noirq)(struct device___223 *);
	int (*restore_noirq)(struct device___223 *);
	int (*runtime_suspend)(struct device___223 *);
	int (*runtime_resume)(struct device___223 *);
	int (*runtime_idle)(struct device___223 *);
};

struct wakeup_source___223 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___223 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___223 {
	struct dev_pm_ops___223 ops;
	int (*start)(struct device___223 *);
	void (*detach)(struct device___223 *, bool);
	int (*activate)(struct device___223 *);
	void (*sync)(struct device___223 *);
	void (*dismiss)(struct device___223 *);
};

struct bus_type___223 {
	const char *name;
	const char *dev_name;
	struct device___223 *dev_root;
	const struct attribute_group___230 **bus_groups;
	const struct attribute_group___230 **dev_groups;
	const struct attribute_group___230 **drv_groups;
	int (*match)(struct device___223 *, struct device_driver___223 *);
	int (*uevent)(struct device___223 *, struct kobj_uevent_env *);
	int (*probe)(struct device___223 *);
	void (*sync_state)(struct device___223 *);
	void (*remove)(struct device___223 *);
	void (*shutdown)(struct device___223 *);
	int (*online)(struct device___223 *);
	int (*offline)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	int (*num_vf)(struct device___223 *);
	int (*dma_configure)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___223 {
	const char *name;
	struct bus_type___223 *bus;
	struct module___226 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___223 *);
	void (*sync_state)(struct device___223 *);
	int (*remove)(struct device___223 *);
	void (*shutdown)(struct device___223 *);
	int (*suspend)(struct device___223 *, pm_message_t);
	int (*resume)(struct device___223 *);
	const struct attribute_group___230 **groups;
	const struct attribute_group___230 **dev_groups;
	const struct dev_pm_ops___223 *pm;
	void (*coredump)(struct device___223 *);
	struct driver_private *p;
};

struct device_type___223 {
	const char *name;
	const struct attribute_group___230 **groups;
	int (*uevent)(struct device___223 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___223 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___223 *);
	const struct dev_pm_ops___223 *pm;
};

struct class___223 {
	const char *name;
	struct module___226 *owner;
	const struct attribute_group___230 **class_groups;
	const struct attribute_group___230 **dev_groups;
	struct kobject___230 *dev_kobj;
	int (*dev_uevent)(struct device___223 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___223 *, umode_t *);
	void (*class_release)(struct class___223 *);
	void (*dev_release)(struct device___223 *);
	int (*shutdown_pre)(struct device___223 *);
	const struct kobj_ns_type_operations___40 *ns_type;
	const void * (*namespace)(struct device___223 *);
	void (*get_ownership)(struct device___223 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___223 *pm;
	struct subsys_private *p;
};

struct property___74;

struct device_node___100 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___219 fwnode;
	struct property___74 *properties;
	struct property___74 *deadprops;
	struct device_node___100 *parent;
	struct device_node___100 *child;
	struct device_node___100 *sibling;
	struct kobject___230 kobj;
	long unsigned int _flags;
	void *data;
};

enum flow_dissect_ret {
	FLOW_DISSECT_RET_OUT_GOOD = 0,
	FLOW_DISSECT_RET_OUT_BAD = 1,
	FLOW_DISSECT_RET_PROTO_AGAIN = 2,
	FLOW_DISSECT_RET_IPPROTO_AGAIN = 3,
	FLOW_DISSECT_RET_CONTINUE = 4,
};

struct flow_dissector_key_tags {
	u32 flow_label;
};

struct flow_dissector_key_vlan {
	union {
		struct {
			u16 vlan_id: 12;
			u16 vlan_dei: 1;
			u16 vlan_priority: 3;
		};
		__be16 vlan_tci;
	};
	__be16 vlan_tpid;
	__be16 vlan_eth_type;
	u16 padding;
};

struct flow_dissector_mpls_lse {
	u32 mpls_ttl: 8;
	u32 mpls_bos: 1;
	u32 mpls_tc: 3;
	u32 mpls_label: 20;
};

struct flow_dissector_key_mpls {
	struct flow_dissector_mpls_lse ls[7];
	u8 used_lses;
};

struct flow_dissector_key_enc_opts {
	u8 data[255];
	u8 len;
	__be16 dst_opt_type;
};

struct flow_dissector_key_keyid {
	__be32 keyid;
};

struct flow_dissector_key_ipv4_addrs {
	__be32 src;
	__be32 dst;
};

struct flow_dissector_key_ipv6_addrs {
	struct in6_addr src;
	struct in6_addr dst;
};

struct flow_dissector_key_tipc {
	__be32 key;
};

struct flow_dissector_key_addrs {
	union {
		struct flow_dissector_key_ipv4_addrs v4addrs;
		struct flow_dissector_key_ipv6_addrs v6addrs;
		struct flow_dissector_key_tipc tipckey;
	};
};

struct flow_dissector_key_arp {
	__u32 sip;
	__u32 tip;
	__u8 op;
	unsigned char sha[6];
	unsigned char tha[6];
};

struct flow_dissector_key_ports {
	union {
		__be32 ports;
		struct {
			__be16 src;
			__be16 dst;
		};
	};
};

struct flow_dissector_key_icmp {
	struct {
		u8 type;
		u8 code;
	};
	u16 id;
};

struct flow_dissector_key_eth_addrs {
	unsigned char dst[6];
	unsigned char src[6];
};

struct flow_dissector_key_tcp {
	__be16 flags;
};

struct flow_dissector_key_ip {
	__u8 tos;
	__u8 ttl;
};

struct flow_dissector_key_meta {
	int ingress_ifindex;
	u16 ingress_iftype;
};

struct flow_dissector_key_ct {
	u16 ct_state;
	u16 ct_zone;
	u32 ct_mark;
	u32 ct_labels[4];
};

struct flow_dissector_key_hash {
	u32 hash;
};

struct flow_dissector_key {
	enum flow_dissector_key_id key_id;
	size_t offset;
};

struct flow_keys {
	struct flow_dissector_key_control control;
	struct flow_dissector_key_basic basic;
	struct flow_dissector_key_tags tags;
	struct flow_dissector_key_vlan vlan;
	struct flow_dissector_key_vlan cvlan;
	struct flow_dissector_key_keyid keyid;
	struct flow_dissector_key_ports ports;
	struct flow_dissector_key_icmp icmp;
	struct flow_dissector_key_addrs addrs;
	int: 32;
};

struct flow_keys_digest {
	u8 data[16];
};

struct bpf_flow_dissector___2 {
	struct bpf_flow_keys *flow_keys;
	const struct sk_buff___52 *skb;
	const void *data;
	const void *data_end;
};

struct pipe_buf_operations___83;

struct pipe_buffer___83 {
	struct page___247 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___83 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___83 {
	int (*confirm)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
	void (*release)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
	bool (*try_steal)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
	bool (*get)(struct pipe_inode_info___83 *, struct pipe_buffer___83 *);
};

enum ip_conntrack_info {
	IP_CT_ESTABLISHED = 0,
	IP_CT_RELATED = 1,
	IP_CT_NEW = 2,
	IP_CT_IS_REPLY = 3,
	IP_CT_ESTABLISHED_REPLY = 3,
	IP_CT_RELATED_REPLY = 4,
	IP_CT_NUMBER = 5,
	IP_CT_UNTRACKED = 7,
};

typedef rx_handler_result_t rx_handler_func_t___51(struct sk_buff___52 **);

struct bpf_xdp_entity___47 {
	struct bpf_prog___47 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___51;

struct net_device_ops___51;

struct ethtool_ops___23;

struct l3mdev_ops___40;

struct ndisc_ops___27;

struct xfrmdev_ops___51;

struct header_ops___51;

struct dsa_port___2;

struct inet6_dev___27;

struct netdev_rx_queue___51;

struct mini_Qdisc___47;

struct netdev_queue___51;

struct Qdisc___47;

struct rtnl_link_ops___47;

struct dcbnl_rtnl_ops___51;

struct phy_device___7;

struct net_device___53 {
	char name[16];
	struct netdev_name_node___51 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___51 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___23 *ethtool_ops;
	const struct l3mdev_ops___40 *l3mdev_ops;
	const struct ndisc_ops___27 *ndisc_ops;
	const struct xfrmdev_ops___51 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___51 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___230 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port___2 *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___27 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___51 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___47 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___51 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___47 *miniq_ingress;
	struct netdev_queue___51 *ingress_queue;
	struct nf_hook_entries___4 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___51 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___47 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___47 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___51 = 0,
		NETREG_REGISTERED___51 = 1,
		NETREG_UNREGISTERING___51 = 2,
		NETREG_UNREGISTERED___51 = 3,
		NETREG_RELEASED___51 = 4,
		NETREG_DUMMY___51 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___51 = 0,
		RTNL_LINK_INITIALIZING___51 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___53 *);
	struct netpoll_info *npinfo;
	possible_net_t___51 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___223 dev;
	const struct attribute_group___230 *sysfs_groups[4];
	const struct attribute_group___230 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___47 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___51 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___7 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___47 xdp_state[3];
	long: 64;
};

struct inet_frags___56;

struct fqdir___56 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___56 *f;
	struct net___56 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___56;

struct inet_frags___56 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___56 *, const void *);
	void (*destructor)(struct inet_frag_queue___56 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___56 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___52 *fragments_tail;
	struct sk_buff___52 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___56 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___21 {
	struct ip_ra_chain___21 *next;
	struct sock___41 *sk;
	union {
		void (*destructor)(struct sock___41 *);
		struct sock___41 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___40;

struct fib_lookup_arg___40;

struct fib_rules_ops___40 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___40 *, struct flowi *, int, struct fib_lookup_arg___40 *);
	bool (*suppress)(struct fib_rule___40 *, int, struct fib_lookup_arg___40 *);
	int (*match)(struct fib_rule___40 *, struct flowi *, int);
	int (*configure)(struct fib_rule___40 *, struct sk_buff___52 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___40 *);
	int (*compare)(struct fib_rule___40 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___40 *, struct sk_buff___52 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___40 *);
	void (*flush_cache)(struct fib_rules_ops___40 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___226 *owner;
	struct net___56 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___40 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___56 *);
	int (*fib_dump)(struct net___56 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___226 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___22;

struct dst_entry___40 {
	struct net_device___53 *dev;
	struct dst_ops___56 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___52 *);
	int (*output)(struct net___56 *, struct sock___41 *, struct sk_buff___52 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___22 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___40;

struct neigh_parms___40;

struct neigh_ops___40;

struct neighbour___40 {
	struct neighbour___40 *next;
	struct neigh_table___40 *tbl;
	struct neigh_parms___40 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___51 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___40 *, struct sk_buff___52 *);
	const struct neigh_ops___40 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___53 *dev;
	u8 primary_key[0];
};

struct rtable___5;

struct fnhe_hash_bucket___5;

struct fib_nh_common___5 {
	struct net_device___53 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___22 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___5 **nhc_pcpu_rth_output;
	struct rtable___5 *nhc_rth_input;
	struct fnhe_hash_bucket___5 *nhc_exceptions;
};

struct fib6_nh___5 {
	struct fib_nh_common___5 nh_common;
	long unsigned int last_probe;
	struct rt6_info___5 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___5;

struct nexthop___3;

struct fib6_info___5 {
	struct fib6_table___5 *fib6_table;
	struct fib6_info___5 *fib6_next;
	struct fib6_node___5 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___3 *nh;
	struct fib6_nh___5 fib6_nh[0];
};

struct rt6_info___5 {
	struct dst_entry___40 dst;
	struct fib6_info___5 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___27 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___5 {
	struct fib6_node___5 *parent;
	struct fib6_node___5 *left;
	struct fib6_node___5 *right;
	struct fib6_node___5 *subtree;
	struct fib6_info___5 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___5 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___5 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___5 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

union nf_inet_addr {
	__u32 all[4];
	__be32 ip;
	__be32 ip6[4];
	struct in_addr in;
	struct in6_addr in6;
};

struct nf_hook_state___4;

typedef unsigned int nf_hookfn___4(void *, struct sk_buff___52 *, const struct nf_hook_state___4 *);

struct nf_hook_entry___4 {
	nf_hookfn___4 *hook;
	void *priv;
};

struct nf_hook_entries___4 {
	u16 num_hook_entries;
	struct nf_hook_entry___4 hooks[0];
};

struct ip_ct_tcp_state {
	u_int32_t td_end;
	u_int32_t td_maxend;
	u_int32_t td_maxwin;
	u_int32_t td_maxack;
	u_int8_t td_scale;
	u_int8_t flags;
};

struct ip_ct_tcp {
	struct ip_ct_tcp_state seen[2];
	u_int8_t state;
	u_int8_t last_dir;
	u_int8_t retrans;
	u_int8_t last_index;
	u_int32_t last_seq;
	u_int32_t last_ack;
	u_int32_t last_end;
	u_int16_t last_win;
	u_int8_t last_wscale;
	u_int8_t last_flags;
};

union nf_conntrack_man_proto {
	__be16 all;
	struct {
		__be16 port;
	} tcp;
	struct {
		__be16 port;
	} udp;
	struct {
		__be16 id;
	} icmp;
	struct {
		__be16 port;
	} dccp;
	struct {
		__be16 port;
	} sctp;
	struct {
		__be16 key;
	} gre;
};

struct nf_ct_dccp {
	u_int8_t role[2];
	u_int8_t state;
	u_int8_t last_pkt;
	u_int8_t last_dir;
	u_int64_t handshake_seq;
};

struct ip_ct_sctp {
	enum sctp_conntrack state;
	__be32 vtag[2];
	u8 last_dir;
	u8 flags;
};

struct nf_ct_event;

struct nf_exp_event;

struct nf_ct_event_notifier {
	int (*ct_event)(unsigned int, const struct nf_ct_event *);
	int (*exp_event)(unsigned int, const struct nf_exp_event *);
};

enum bpf_ret_code {
	BPF_OK = 0,
	BPF_DROP = 2,
	BPF_REDIRECT = 7,
	BPF_LWT_REROUTE = 128,
};

enum {
	BPF_FLOW_DISSECTOR_F_PARSE_1ST_FRAG = 1,
	BPF_FLOW_DISSECTOR_F_STOP_AT_FLOW_LABEL = 2,
	BPF_FLOW_DISSECTOR_F_STOP_AT_ENCAP = 4,
};

struct bpf_prog_array_item___47 {
	struct bpf_prog___47 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___47 {
	struct callback_head rcu;
	struct bpf_prog_array_item___47 items[0];
};

struct bpf_prog_aux___54;

struct bpf_prog___47 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___54 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___217 {
	void * (*start)(struct seq_file___217 *, loff_t *);
	void (*stop)(struct seq_file___217 *, void *);
	void * (*next)(struct seq_file___217 *, void *, loff_t *);
	int (*show)(struct seq_file___217 *, void *);
};

struct dcbnl_rtnl_ops___51 {
	int (*ieee_getets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___53 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___53 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___53 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___53 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___53 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___53 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___53 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___53 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___53 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___53 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___53 *);
	u8 (*setstate)(struct net_device___53 *, u8);
	void (*getpermhwaddr)(struct net_device___53 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___53 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___53 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___53 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___53 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___53 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___53 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___53 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___53 *, int, u8 *);
	void (*setpfccfg)(struct net_device___53 *, int, u8);
	void (*getpfccfg)(struct net_device___53 *, int, u8 *);
	u8 (*setall)(struct net_device___53 *);
	u8 (*getcap)(struct net_device___53 *, int, u8 *);
	int (*getnumtcs)(struct net_device___53 *, int, u8 *);
	int (*setnumtcs)(struct net_device___53 *, int, u8);
	u8 (*getpfcstate)(struct net_device___53 *);
	void (*setpfcstate)(struct net_device___53 *, u8);
	void (*getbcncfg)(struct net_device___53 *, int, u32 *);
	void (*setbcncfg)(struct net_device___53 *, int, u32);
	void (*getbcnrp)(struct net_device___53 *, int, u8 *);
	void (*setbcnrp)(struct net_device___53 *, int, u8);
	int (*setapp)(struct net_device___53 *, u8, u16, u8);
	int (*getapp)(struct net_device___53 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___53 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___53 *, int, u8);
	u8 (*getdcbx)(struct net_device___53 *);
	u8 (*setdcbx)(struct net_device___53 *, u8);
	int (*peer_getappinfo)(struct net_device___53 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___53 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___53 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___53 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___53 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___53 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___54;

typedef int (*bpf_iter_init_seq_priv_t___53)(void *, struct bpf_iter_aux_info___54 *);

struct bpf_map___54;

struct bpf_iter_aux_info___54 {
	struct bpf_map___54 *map;
};

struct bpf_iter_seq_info___53 {
	const struct seq_operations___217 *seq_ops;
	bpf_iter_init_seq_priv_t___53 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___53 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___54 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___54 *, struct file___242 *);
	void (*map_free)(struct bpf_map___54 *);
	int (*map_get_next_key)(struct bpf_map___54 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___54 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___54 *, void *);
	int (*map_lookup_batch)(struct bpf_map___54 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___54 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___54 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___54 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___54 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___54 *, void *);
	int (*map_update_elem)(struct bpf_map___54 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___54 *, void *);
	int (*map_push_elem)(struct bpf_map___54 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___54 *, void *);
	int (*map_peek_elem)(struct bpf_map___54 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___54 *, struct file___242 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___54 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___54 *, void *, struct seq_file___217 *);
	int (*map_check_btf)(const struct bpf_map___54 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___54 *, struct bpf_prog_aux___54 *);
	void (*map_poke_untrack)(struct bpf_map___54 *, struct bpf_prog_aux___54 *);
	void (*map_poke_run)(struct bpf_map___54 *, u32, struct bpf_prog___47 *, struct bpf_prog___47 *);
	int (*map_direct_value_addr)(const struct bpf_map___54 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___54 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___54 *, struct vm_area_struct___247 *);
	__poll_t (*map_poll)(struct bpf_map___54 *, struct file___242 *, struct poll_table_struct___165 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___54 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___54 *, const struct bpf_map___54 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___54 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___53 *iter_seq_info;
};

struct bpf_map___54 {
	const struct bpf_map_ops___53 *ops;
	struct bpf_map___54 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___109 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___53;

struct bpf_jit_poke_descriptor___53;

struct bpf_prog_ops___47;

struct btf_mod_pair___53;

struct bpf_prog_offload___51;

struct bpf_prog_aux___54 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___47 *dst_prog;
	struct bpf_trampoline___53 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___47 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___53 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___47 *ops;
	struct bpf_map___54 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___53 *used_btfs;
	struct bpf_prog___47 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___54 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___51 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___51;

struct bpf_map_dev_ops___51 {
	int (*map_get_next_key)(struct bpf_offloaded_map___51 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___51 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___51 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___51 *, void *);
};

struct bpf_offloaded_map___51 {
	struct bpf_map___54 map;
	struct net_device___53 *netdev;
	const struct bpf_map_dev_ops___51 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___47 {
	int (*test_run)(struct bpf_prog___47 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___51 {
	struct bpf_prog___47 *prog;
	struct net_device___53 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___53 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___47 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___226 *mod;
};

struct bpf_jit_poke_descriptor___53 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___54 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___53 {
	struct btf *btf;
	struct module___226 *module;
};

struct cftype___169;

struct cgroup_subsys___169 {
	struct cgroup_subsys_state___169 * (*css_alloc)(struct cgroup_subsys_state___169 *);
	int (*css_online)(struct cgroup_subsys_state___169 *);
	void (*css_offline)(struct cgroup_subsys_state___169 *);
	void (*css_released)(struct cgroup_subsys_state___169 *);
	void (*css_free)(struct cgroup_subsys_state___169 *);
	void (*css_reset)(struct cgroup_subsys_state___169 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___169 *, int);
	int (*css_extra_stat_show)(struct seq_file___217 *, struct cgroup_subsys_state___169 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___249 *, struct css_set___169 *);
	void (*cancel_fork)(struct task_struct___249 *, struct css_set___169 *);
	void (*fork)(struct task_struct___249 *);
	void (*exit)(struct task_struct___249 *);
	void (*release)(struct task_struct___249 *);
	void (*bind)(struct cgroup_subsys_state___169 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___169 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___169 *dfl_cftypes;
	struct cftype___169 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___169 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___169 *updated_children;
	struct cgroup___169 *updated_next;
};

struct cgroup_root___169 {
	struct kernfs_root___230 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___169 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___169 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___169 *ss;
	struct list_head node;
	struct kernfs_ops___230 *kf_ops;
	int (*open)(struct kernfs_open_file___230 *);
	void (*release)(struct kernfs_open_file___230 *);
	u64 (*read_u64)(struct cgroup_subsys_state___169 *, struct cftype___169 *);
	s64 (*read_s64)(struct cgroup_subsys_state___169 *, struct cftype___169 *);
	int (*seq_show)(struct seq_file___217 *, void *);
	void * (*seq_start)(struct seq_file___217 *, loff_t *);
	void * (*seq_next)(struct seq_file___217 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___217 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___169 *, struct cftype___169 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___169 *, struct cftype___169 *, s64);
	ssize_t (*write)(struct kernfs_open_file___230 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___230 *, struct poll_table_struct___165 *);
};

struct xdp_rxq_info___51 {
	struct net_device___53 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___51 {
	struct net_device___53 *dev;
};

struct xdp_buff___51 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___51 *rxq;
	struct xdp_txq_info___51 *txq;
	u32 frame_sz;
};

struct xdp_frame___51 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___53 *dev_rx;
};

struct netlink_callback___51 {
	struct sk_buff___52 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___52 *, struct netlink_callback___51 *);
	int (*done)(struct netlink_callback___51 *);
	void *data;
	struct module___226 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum {
	TCA_FLOWER_KEY_CT_FLAGS_NEW = 1,
	TCA_FLOWER_KEY_CT_FLAGS_ESTABLISHED = 2,
	TCA_FLOWER_KEY_CT_FLAGS_RELATED = 4,
	TCA_FLOWER_KEY_CT_FLAGS_TRACKED = 8,
	TCA_FLOWER_KEY_CT_FLAGS_INVALID = 16,
	TCA_FLOWER_KEY_CT_FLAGS_REPLY = 32,
	__TCA_FLOWER_KEY_CT_FLAGS_MAX = 33,
};

struct header_ops___51 {
	int (*create)(struct sk_buff___52 *, struct net_device___53 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___52 *, unsigned char *);
	int (*cache)(const struct neighbour___40 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___53 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___52 *);
};

struct netdev_queue___51 {
	struct net_device___53 *dev;
	struct Qdisc___47 *qdisc;
	struct Qdisc___47 *qdisc_sleeping;
	struct kobject___230 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___53 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___47 {
	struct sk_buff___52 *head;
	struct sk_buff___52 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___47;

struct Qdisc___47 {
	int (*enqueue)(struct sk_buff___52 *, struct Qdisc___47 *, struct sk_buff___52 **);
	struct sk_buff___52 * (*dequeue)(struct Qdisc___47 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___47 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___51 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___51 gso_skb;
	struct qdisc_skb_head___47 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___47 *next_sched;
	struct sk_buff_head___51 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___51 {
	struct xdp_rxq_info___51 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___230 kobj;
	struct net_device___53 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___51 {
	enum net_device_path_type type;
	const struct net_device___53 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___51 = 0,
				DEV_PATH_BR_VLAN_TAG___51 = 1,
				DEV_PATH_BR_VLAN_UNTAG___51 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___51 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___51 {
	const struct net_device___53 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___51 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___47 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___51 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___51 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___52 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___51 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___53 *dev;
	const char *name;
};

struct devlink_port___2;

struct net_device_ops___51 {
	int (*ndo_init)(struct net_device___53 *);
	void (*ndo_uninit)(struct net_device___53 *);
	int (*ndo_open)(struct net_device___53 *);
	int (*ndo_stop)(struct net_device___53 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___52 *, struct net_device___53 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___52 *, struct net_device___53 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___53 *, struct sk_buff___52 *, struct net_device___53 *);
	void (*ndo_change_rx_flags)(struct net_device___53 *, int);
	void (*ndo_set_rx_mode)(struct net_device___53 *);
	int (*ndo_set_mac_address)(struct net_device___53 *, void *);
	int (*ndo_validate_addr)(struct net_device___53 *);
	int (*ndo_do_ioctl)(struct net_device___53 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___53 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___53 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___53 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___53 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___53 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___53 *, int);
	int (*ndo_neigh_setup)(struct net_device___53 *, struct neigh_parms___40 *);
	void (*ndo_tx_timeout)(struct net_device___53 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___53 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___53 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___53 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___53 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___53 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___53 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___53 *);
	int (*ndo_netpoll_setup)(struct net_device___53 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___53 *);
	int (*ndo_set_vf_mac)(struct net_device___53 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___53 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___53 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___53 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___53 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___53 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___53 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___53 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___53 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___53 *, int, struct sk_buff___52 *);
	int (*ndo_get_vf_guid)(struct net_device___53 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___53 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___53 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___53 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___53 *);
	int (*ndo_fcoe_disable)(struct net_device___53 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___53 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___53 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___53 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___53 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___53 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___53 *, const struct sk_buff___52 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___53 *, struct net_device___53 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___53 *, struct net_device___53 *);
	struct net_device___53 * (*ndo_get_xmit_slave)(struct net_device___53 *, struct sk_buff___52 *, bool);
	struct net_device___53 * (*ndo_sk_get_lower_dev)(struct net_device___53 *, struct sock___41 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___53 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___53 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___53 *, struct neighbour___40 *);
	void (*ndo_neigh_destroy)(struct net_device___53 *, struct neighbour___40 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___52 *, struct netlink_callback___51 *, struct net_device___53 *, struct net_device___53 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___52 *, struct nlattr **, struct net_device___53 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___53 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___52 *, u32, u32, struct net_device___53 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___53 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___53 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___53 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___53 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___53 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___53 *, struct net_device___53 *);
	void (*ndo_dfwd_del_station)(struct net_device___53 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___53 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___53 *);
	int (*ndo_change_proto_down)(struct net_device___53 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___53 *, struct sk_buff___52 *);
	void (*ndo_set_rx_headroom)(struct net_device___53 *, int);
	int (*ndo_bpf)(struct net_device___53 *, struct netdev_bpf___51 *);
	int (*ndo_xdp_xmit)(struct net_device___53 *, int, struct xdp_frame___51 **, u32);
	struct net_device___53 * (*ndo_xdp_get_xmit_slave)(struct net_device___53 *, struct xdp_buff___51 *);
	int (*ndo_xsk_wakeup)(struct net_device___53 *, u32, u32);
	struct devlink_port___2 * (*ndo_get_devlink_port)(struct net_device___53 *);
	int (*ndo_tunnel_ctl)(struct net_device___53 *, struct ip_tunnel_parm *, int);
	struct net_device___53 * (*ndo_get_peer_dev)(struct net_device___53 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___51 *, struct net_device_path___51 *);
};

struct neigh_parms___40 {
	possible_net_t___51 net;
	struct net_device___53 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___40 *);
	struct neigh_table___40 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct devlink___2;

struct devlink_rate___2;

struct devlink_port___2 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___2 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set: 1;
	u8 switch_port: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___2 *devlink_rate;
};

struct ethtool_ops___23 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___53 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___53 *);
	void (*get_regs)(struct net_device___53 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___53 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___53 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___53 *);
	void (*set_msglevel)(struct net_device___53 *, u32);
	int (*nway_reset)(struct net_device___53 *);
	u32 (*get_link)(struct net_device___53 *);
	int (*get_link_ext_state)(struct net_device___53 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___53 *);
	int (*get_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___53 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___53 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___53 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___53 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___53 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___53 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___53 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___53 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___53 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___53 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___53 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___53 *);
	void (*complete)(struct net_device___53 *);
	u32 (*get_priv_flags)(struct net_device___53 *);
	int (*set_priv_flags)(struct net_device___53 *, u32);
	int (*get_sset_count)(struct net_device___53 *, int);
	int (*get_rxnfc)(struct net_device___53 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___53 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___53 *, struct ethtool_flash *);
	int (*reset)(struct net_device___53 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___53 *);
	u32 (*get_rxfh_indir_size)(struct net_device___53 *);
	int (*get_rxfh)(struct net_device___53 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___53 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___53 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___53 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___53 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___53 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___53 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___53 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___53 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___53 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___53 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___53 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___53 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___53 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___53 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___53 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___53 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___53 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___53 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___53 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___53 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___53 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___53 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___53 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___53 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___53 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___53 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___53 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___53 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___53 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___53 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___40 {
	u32 (*l3mdev_fib_table)(const struct net_device___53 *);
	struct sk_buff___52 * (*l3mdev_l3_rcv)(struct net_device___53 *, struct sk_buff___52 *, u16);
	struct sk_buff___52 * (*l3mdev_l3_out)(struct net_device___53 *, struct sock___41 *, struct sk_buff___52 *, u16);
	struct dst_entry___40 * (*l3mdev_link_scope_lookup)(const struct net_device___53 *, struct flowi6 *);
};

struct ndisc_ops___27 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___53 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___53 *, struct neighbour___40 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___53 *, u8, struct neighbour___40 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___53 *, struct sk_buff___52 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___56 *, struct net_device___53 *, const struct prefix_info *, struct inet6_dev___27 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct phylink_config___2 {
	struct device___223 *dev;
	enum phylink_op_type type;
	bool pcs_poll;
	bool poll_fixed_state;
	bool ovr_an_inband;
	void (*get_fixed_state)(struct phylink_config___2 *, struct phylink_link_state *);
};

struct dsa_device_ops___2;

struct dsa_switch_tree___2;

struct dsa_switch___2;

struct dsa_netdevice_ops___2;

struct dsa_port___2 {
	union {
		struct net_device___53 *master;
		struct net_device___53 *slave;
	};
	const struct dsa_device_ops___2 *tag_ops;
	struct dsa_switch_tree___2 *dst;
	struct sk_buff___52 * (*rcv)(struct sk_buff___52 *, struct net_device___53 *);
	enum {
		DSA_PORT_TYPE_UNUSED___2 = 0,
		DSA_PORT_TYPE_CPU___2 = 1,
		DSA_PORT_TYPE_DSA___2 = 2,
		DSA_PORT_TYPE_USER___2 = 3,
	} type;
	struct dsa_switch___2 *ds;
	unsigned int index;
	const char *name;
	struct dsa_port___2 *cpu_dp;
	u8 mac[6];
	struct device_node___100 *dn;
	unsigned int ageing_time;
	bool vlan_filtering;
	bool learning;
	u8 stp_state;
	struct net_device___53 *bridge_dev;
	int bridge_num;
	struct devlink_port___2 devlink_port;
	bool devlink_port_setup;
	struct phylink *pl;
	struct phylink_config___2 pl_config;
	struct net_device___53 *lag_dev;
	bool lag_tx_enabled;
	struct net_device___53 *hsr_dev;
	struct list_head list;
	void *priv;
	const struct ethtool_ops___23 *orig_ethtool_ops;
	const struct dsa_netdevice_ops___2 *netdev_ops;
	struct list_head fdbs;
	struct list_head mdbs;
	bool setup;
};

struct ifmcaddr6___27;

struct ifacaddr6___5;

struct inet6_dev___27 {
	struct net_device___53 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___27 *mc_list;
	struct ifmcaddr6___27 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___51 mc_query_queue;
	struct sk_buff_head___51 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___5 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___40 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___47;

struct tcf_block___47;

struct mini_Qdisc___47 {
	struct tcf_proto___47 *filter_list;
	struct tcf_block___47 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___47 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___53 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___53 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___56 *, struct net_device___53 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___53 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___53 *, struct list_head *);
	size_t (*get_size)(const struct net_device___53 *);
	int (*fill_info)(struct sk_buff___52 *, const struct net_device___53 *);
	size_t (*get_xstats_size)(const struct net_device___53 *);
	int (*fill_xstats)(struct sk_buff___52 *, const struct net_device___53 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___53 *, struct net_device___53 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___53 *, const struct net_device___53 *);
	int (*fill_slave_info)(struct sk_buff___52 *, const struct net_device___53 *, const struct net_device___53 *);
	struct net___56 * (*get_link_net)(const struct net_device___53 *);
	size_t (*get_linkxstats_size)(const struct net_device___53 *, int);
	int (*fill_linkxstats)(struct sk_buff___52 *, const struct net_device___53 *, int *, int);
};

struct mii_bus___10;

struct mdio_device___10 {
	struct device___223 dev;
	struct mii_bus___10 *bus;
	char modalias[32];
	int (*bus_match)(struct device___223 *, struct device_driver___223 *);
	void (*device_free)(struct mdio_device___10 *);
	void (*device_remove)(struct mdio_device___10 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___7;

struct mii_timestamper___7;

struct phy_device___7 {
	struct mdio_device___10 mdio;
	struct phy_driver___7 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45;
	unsigned int is_internal;
	unsigned int is_pseudo_fixed_link;
	unsigned int is_gigabit_capable;
	unsigned int has_fixups;
	unsigned int suspended;
	unsigned int suspended_by_mdio_bus;
	unsigned int sysfs_links;
	unsigned int loopback_enabled;
	unsigned int downshifted_rate;
	unsigned int is_on_sfp_module;
	unsigned int mac_managed_pm;
	unsigned int autoneg;
	unsigned int link;
	unsigned int autoneg_complete;
	unsigned int interrupts;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___52 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___53 *attached_dev;
	struct mii_timestamper___7 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___7 *, bool);
	void (*adjust_link)(struct net_device___53 *);
	const struct macsec_ops *macsec_ops;
};

struct netdev_notifier_info___5 {
	struct net_device___53 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_changeupper_info___2 {
	struct netdev_notifier_info___5 info;
	struct net_device___53 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct block_device_operations___135;

struct gendisk___138 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___138 *part0;
	const struct block_device_operations___135 *fops;
	struct request_queue___135 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___121 *bdi;
	struct kobject___230 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___230 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___135 {
	struct bio___135 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___159 *bip_vec;
	struct bio_vec___159 bip_inline_vecs[0];
};

struct blkcg___123;

struct blkg_policy_data___123;

struct blkcg_gq___123 {
	struct request_queue___135 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___123 *blkcg;
	struct blkcg_gq___123 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___123 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___135 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___135(struct request___135 *);

typedef void integrity_complete_fn___135(struct request___135 *, unsigned int);

struct blk_integrity_profile___135 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___135 *prepare_fn;
	integrity_complete_fn___135 *complete_fn;
	const char *name;
};

struct block_device_operations___135 {
	blk_qc_t (*submit_bio)(struct bio___135 *);
	int (*open)(struct block_device___138 *, fmode_t);
	void (*release)(struct gendisk___138 *, fmode_t);
	int (*rw_page)(struct block_device___138 *, sector_t, struct page___247 *, unsigned int);
	int (*ioctl)(struct block_device___138 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___138 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___138 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___138 *);
	int (*getgeo)(struct block_device___138 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___138 *, bool);
	void (*swap_slot_free_notify)(struct block_device___138 *, long unsigned int);
	int (*report_zones)(struct gendisk___138 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___138 *, umode_t *);
	struct module___226 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___138 *, sector_t *);
};

typedef void rq_end_io_fn___135(struct request___135 *, blk_status_t);

struct request___135 {
	struct request_queue___135 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___130 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___135 *bio;
	struct bio___135 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___159 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___135 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___135 *saved_end_io;
		} flush;
	};
	struct gendisk___138 *rq_disk;
	struct block_device___138 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___135 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___130 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___135 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___230 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___242 *debugfs_dir;
	struct dentry___242 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___135;

struct elevator_mq_ops___135 {
	int (*init_sched)(struct request_queue___135 *, struct elevator_type___135 *);
	void (*exit_sched)(struct elevator_queue___135 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___130 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___130 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___130 *);
	bool (*allow_merge)(struct request_queue___135 *, struct request___135 *, struct bio___135 *);
	bool (*bio_merge)(struct request_queue___135 *, struct bio___135 *, unsigned int);
	int (*request_merge)(struct request_queue___135 *, struct request___135 **, struct bio___135 *);
	void (*request_merged)(struct request_queue___135 *, struct request___135 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___135 *, struct request___135 *, struct request___135 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___135 *);
	void (*finish_request)(struct request___135 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___130 *, struct list_head *, bool);
	struct request___135 * (*dispatch_request)(struct blk_mq_hw_ctx___130 *);
	bool (*has_work)(struct blk_mq_hw_ctx___130 *);
	void (*completed_request)(struct request___135 *, u64);
	void (*requeue_request)(struct request___135 *);
	struct request___135 * (*former_request)(struct request_queue___135 *, struct request___135 *);
	struct request___135 * (*next_request)(struct request_queue___135 *, struct request___135 *);
	void (*init_icq)(struct io_cq___135 *);
	void (*exit_icq)(struct io_cq___135 *);
};

struct elv_fs_entry___135;

struct elevator_type___135 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___135 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___135 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___226 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___135 {
	struct elevator_type___135 *type;
	void *elevator_data;
	struct kobject___230 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___135 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___135 *, char *);
	ssize_t (*store)(struct elevator_queue___135 *, const char *, size_t);
};

struct blk_mq_queue_data___130;

struct blk_mq_ops___130 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___130 *, const struct blk_mq_queue_data___130 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___130 *);
	int (*get_budget)(struct request_queue___135 *);
	void (*put_budget)(struct request_queue___135 *, int);
	void (*set_rq_budget_token)(struct request___135 *, int);
	int (*get_rq_budget_token)(struct request___135 *);
	enum blk_eh_timer_return (*timeout)(struct request___135 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___130 *);
	void (*complete)(struct request___135 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___130 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___130 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___130 *, struct request___135 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___130 *, struct request___135 *, unsigned int);
	void (*initialize_rq_fn)(struct request___135 *);
	void (*cleanup_rq)(struct request___135 *);
	bool (*busy)(struct request_queue___135 *);
	int (*map_queues)(struct blk_mq_tag_set___130 *);
	void (*show_rq)(struct seq_file___217 *, struct request___135 *);
};

struct blk_mq_tag_set___130 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___130 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___130 {
	struct request___135 *rq;
	bool last;
};

struct blkcg_policy_data___123;

struct blkcg___123 {
	struct cgroup_subsys_state___169 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___123 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___123 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___123 {
	struct blkcg___123 *blkcg;
	int plid;
};

struct blkg_policy_data___123 {
	struct blkcg_gq___123 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___109 {
	struct mem_cgroup___109 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___109 {
	struct lruvec___117 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___109 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___109 *memcg;
};

struct obj_cgroup___109 {
	struct percpu_ref refcnt;
	struct mem_cgroup___109 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___47 {
	spinlock_t *lock;
	struct sk_buff___52 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct ip_tunnel_key {
	__be64 tun_id;
	union {
		struct {
			__be32 src;
			__be32 dst;
		} ipv4;
		struct {
			struct in6_addr src;
			struct in6_addr dst;
		} ipv6;
	} u;
	__be16 tun_flags;
	u8 tos;
	u8 ttl;
	__be32 label;
	__be16 tp_src;
	__be16 tp_dst;
};

struct dst_cache_pcpu;

struct dst_cache {
	struct dst_cache_pcpu *cache;
	long unsigned int reset_ts;
};

struct ip_tunnel_info___2 {
	struct ip_tunnel_key key;
	struct dst_cache dst_cache;
	u8 options_len;
	u8 mode;
};

struct flow_action_entry___2 {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___53 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info___2 *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action___2 {
	unsigned int num_entries;
	struct flow_action_entry___2 entries[0];
};

struct flow_rule___2 {
	struct flow_match match;
	struct flow_action___2 action;
};

struct flow_cls_offload___2 {
	struct flow_cls_common_offload common;
	enum flow_cls_command command;
	long unsigned int cookie;
	struct flow_rule___2 *rule;
	struct flow_stats stats;
	u32 classid;
};

struct Qdisc_class_ops___47;

struct Qdisc_ops___47 {
	struct Qdisc_ops___47 *next;
	const struct Qdisc_class_ops___47 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___52 *, struct Qdisc___47 *, struct sk_buff___52 **);
	struct sk_buff___52 * (*dequeue)(struct Qdisc___47 *);
	struct sk_buff___52 * (*peek)(struct Qdisc___47 *);
	int (*init)(struct Qdisc___47 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___47 *);
	void (*destroy)(struct Qdisc___47 *);
	int (*change)(struct Qdisc___47 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___47 *);
	int (*change_tx_queue_len)(struct Qdisc___47 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___47 *, unsigned int);
	int (*dump)(struct Qdisc___47 *, struct sk_buff___52 *);
	int (*dump_stats)(struct Qdisc___47 *, struct gnet_dump___47 *);
	void (*ingress_block_set)(struct Qdisc___47 *, u32);
	void (*egress_block_set)(struct Qdisc___47 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___47 *);
	u32 (*egress_block_get)(struct Qdisc___47 *);
	struct module___226 *owner;
};

struct Qdisc_class_ops___47 {
	unsigned int flags;
	struct netdev_queue___51 * (*select_queue)(struct Qdisc___47 *, struct tcmsg *);
	int (*graft)(struct Qdisc___47 *, long unsigned int, struct Qdisc___47 *, struct Qdisc___47 **, struct netlink_ext_ack *);
	struct Qdisc___47 * (*leaf)(struct Qdisc___47 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___47 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___47 *, u32);
	int (*change)(struct Qdisc___47 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___47 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___47 *, struct qdisc_walker *);
	struct tcf_block___47 * (*tcf_block)(struct Qdisc___47 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___47 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___47 *, long unsigned int);
	int (*dump)(struct Qdisc___47 *, long unsigned int, struct sk_buff___52 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___47 *, long unsigned int, struct gnet_dump___47 *);
};

struct tcf_chain___47;

struct tcf_block___47 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___56 *net;
	struct Qdisc___47 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___47 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___47;

struct tcf_proto_ops___47;

struct tcf_proto___47 {
	struct tcf_proto___47 *next;
	void *root;
	int (*classify)(struct sk_buff___52 *, const struct tcf_proto___47 *, struct tcf_result___47 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___47 *ops;
	struct tcf_chain___47 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___47 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___47 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___47 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___52 *, const struct tcf_proto___47 *, struct tcf_result___47 *);
	int (*init)(struct tcf_proto___47 *);
	void (*destroy)(struct tcf_proto___47 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___47 *, u32);
	void (*put)(struct tcf_proto___47 *, void *);
	int (*change)(struct net___56 *, struct sk_buff___52 *, struct tcf_proto___47 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___47 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___47 *);
	void (*walk)(struct tcf_proto___47 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___47 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___47 *, void *);
	void (*hw_del)(struct tcf_proto___47 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___56 *, struct tcf_chain___47 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___56 *, struct tcf_proto___47 *, void *, struct sk_buff___52 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___56 *, struct tcf_proto___47 *, void *, struct sk_buff___52 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___52 *, struct net___56 *, void *);
	struct module___226 *owner;
	int flags;
};

struct tcf_chain___47 {
	struct mutex filter_chain_lock;
	struct tcf_proto___47 *filter_chain;
	struct list_head list;
	struct tcf_block___47 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___47 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___40 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___47 *prog;
};

struct pneigh_entry___40;

struct neigh_hash_table___40;

struct neigh_table___40 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___53 *, __u32 *);
	bool (*key_eq)(const struct neighbour___40 *, const void *);
	int (*constructor)(struct neighbour___40 *);
	int (*pconstructor)(struct pneigh_entry___40 *);
	void (*pdestructor)(struct pneigh_entry___40 *);
	void (*proxy_redo)(struct sk_buff___52 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___53 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___40 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___51 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___40 *nht;
	struct pneigh_entry___40 **phash_buckets;
};

struct neigh_ops___40 {
	int family;
	void (*solicit)(struct neighbour___40 *, struct sk_buff___52 *);
	void (*error_report)(struct neighbour___40 *, struct sk_buff___52 *);
	int (*output)(struct neighbour___40 *, struct sk_buff___52 *);
	int (*connected_output)(struct neighbour___40 *, struct sk_buff___52 *);
};

struct pneigh_entry___40 {
	struct pneigh_entry___40 *next;
	possible_net_t___51 net;
	struct net_device___53 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___40 {
	struct neighbour___40 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___22 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___56 *, struct sock___41 *, struct sk_buff___52 *);
	int (*orig_input)(struct sk_buff___52 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___40 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___40 *ctarget;
	struct net___56 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___40 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___40 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___29;

struct timewait_sock_ops___29;

struct proto___40 {
	void (*close)(struct sock___41 *, long int);
	int (*pre_connect)(struct sock___41 *, struct sockaddr *, int);
	int (*connect)(struct sock___41 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___41 *, int);
	struct sock___41 * (*accept)(struct sock___41 *, int, int *, bool);
	int (*ioctl)(struct sock___41 *, int, long unsigned int);
	int (*init)(struct sock___41 *);
	void (*destroy)(struct sock___41 *);
	void (*shutdown)(struct sock___41 *, int);
	int (*setsockopt)(struct sock___41 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___41 *, int, int, char *, int *);
	void (*keepalive)(struct sock___41 *, int);
	int (*compat_ioctl)(struct sock___41 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___41 *, struct msghdr___42 *, size_t);
	int (*recvmsg)(struct sock___41 *, struct msghdr___42 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___41 *, struct page___247 *, int, size_t, int);
	int (*bind)(struct sock___41 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___41 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___41 *, struct sk_buff___52 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___41 *);
	int (*hash)(struct sock___41 *);
	void (*unhash)(struct sock___41 *);
	void (*rehash)(struct sock___41 *);
	int (*get_port)(struct sock___41 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___41 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___41 *, int);
	bool (*sock_is_readable)(struct sock___41 *);
	void (*enter_memory_pressure)(struct sock___41 *);
	void (*leave_memory_pressure)(struct sock___41 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___29 *rsk_prot;
	struct timewait_sock_ops___29 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___226 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___41 *, int);
};

struct request_sock___30;

struct request_sock_ops___29 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___41 *, struct request_sock___30 *);
	void (*send_ack)(const struct sock___41 *, struct sk_buff___52 *, struct request_sock___30 *);
	void (*send_reset)(const struct sock___41 *, struct sk_buff___52 *);
	void (*destructor)(struct request_sock___30 *);
	void (*syn_ack_timeout)(const struct request_sock___30 *);
};

struct timewait_sock_ops___29 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___41 *, struct sock___41 *, void *);
	void (*twsk_destructor)(struct sock___41 *);
};

struct request_sock___30 {
	struct sock_common___40 __req_common;
	struct request_sock___30 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___29 *rsk_ops;
	struct sock___41 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

union tcp_word_hdr {
	struct tcphdr hdr;
	__be32 words[5];
};

struct property___74 {
	char *name;
	int length;
	void *value;
	struct property___74 *next;
	long unsigned int _flags;
	struct bin_attribute___230 attr;
};

struct mii_bus___10 {
	struct module___226 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___10 *, int, int);
	int (*write)(struct mii_bus___10 *, int, int, u16);
	int (*reset)(struct mii_bus___10 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___223 *parent;
	enum {
		MDIOBUS_ALLOCATED___10 = 1,
		MDIOBUS_REGISTERED___10 = 2,
		MDIOBUS_UNREGISTERED___10 = 3,
		MDIOBUS_RELEASED___10 = 4,
	} state;
	struct device___223 dev;
	struct mdio_device___10 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___10 = 0,
		MDIOBUS_C22___10 = 1,
		MDIOBUS_C45___10 = 2,
		MDIOBUS_C22_C45___10 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___9 {
	struct device_driver___223 driver;
	int flags;
};

struct mii_timestamper___7 {
	bool (*rxtstamp)(struct mii_timestamper___7 *, struct sk_buff___52 *, int);
	void (*txtstamp)(struct mii_timestamper___7 *, struct sk_buff___52 *, int);
	int (*hwtstamp)(struct mii_timestamper___7 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___7 *, struct phy_device___7 *);
	int (*ts_info)(struct mii_timestamper___7 *, struct ethtool_ts_info *);
	struct device___223 *device;
};

struct phy_driver___7 {
	struct mdio_driver_common___9 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___7 *);
	int (*config_init)(struct phy_device___7 *);
	int (*probe)(struct phy_device___7 *);
	int (*get_features)(struct phy_device___7 *);
	int (*suspend)(struct phy_device___7 *);
	int (*resume)(struct phy_device___7 *);
	int (*config_aneg)(struct phy_device___7 *);
	int (*aneg_done)(struct phy_device___7 *);
	int (*read_status)(struct phy_device___7 *);
	int (*config_intr)(struct phy_device___7 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___7 *);
	void (*remove)(struct phy_device___7 *);
	int (*match_phy_device)(struct phy_device___7 *);
	int (*set_wol)(struct phy_device___7 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___7 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___7 *);
	int (*read_mmd)(struct phy_device___7 *, int, u16);
	int (*write_mmd)(struct phy_device___7 *, int, u16, u16);
	int (*read_page)(struct phy_device___7 *);
	int (*write_page)(struct phy_device___7 *, int);
	int (*module_info)(struct phy_device___7 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___7 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___7 *);
	int (*cable_test_tdr_start)(struct phy_device___7 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___7 *, bool *);
	int (*get_sset_count)(struct phy_device___7 *);
	void (*get_strings)(struct phy_device___7 *, u8 *);
	void (*get_stats)(struct phy_device___7 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___7 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___7 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___7 *, bool);
	int (*get_sqi)(struct phy_device___7 *);
	int (*get_sqi_max)(struct phy_device___7 *);
};

struct dsa_chip_data___2 {
	struct device___223 *host_dev;
	int sw_addr;
	struct device___223 *netdev[12];
	int eeprom_len;
	struct device_node___100 *of_node;
	char *port_names[12];
	struct device_node___100 *port_dn[12];
	s8 rtable[4];
};

struct dsa_platform_data___2 {
	struct device___223 *netdev;
	struct net_device___53 *of_netdev;
	int nr_chips;
	struct dsa_chip_data___2 *chip;
};

struct devlink_ops___2;

struct devlink___2 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___2 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___223 *dev;
	possible_net_t___51 _net;
	struct mutex lock;
	u8 reload_failed: 1;
	u8 reload_enabled: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_ops___2 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___2 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___2 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___2 *, enum devlink_port_type);
	int (*port_split)(struct devlink___2 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___2 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___2 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___2 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___2 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___2 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___2 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___2 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___2 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___2 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___2 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___2 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___2 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___2 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___2 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___2 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___2 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___2 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___2 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___2 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___2 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___2 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___2 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___2 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___2 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___2 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___2 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___2 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___2 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___2 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___2 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___2 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___2 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___2 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___2 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___2 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___2 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___2 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___2 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___2 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___2 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___2 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___2 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___2 *, struct devlink_rate___2 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___2 *, struct devlink_rate___2 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___2 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___2 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___2 *parent;
	union {
		struct devlink_port___2 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct ifmcaddr6___27 {
	struct in6_addr mca_addr;
	struct inet6_dev___27 *idev;
	struct ifmcaddr6___27 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___5 {
	struct in6_addr aca_addr;
	struct fib6_info___5 *aca_rt;
	struct ifacaddr6___5 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct arphdr {
	__be16 ar_hrd;
	__be16 ar_pro;
	unsigned char ar_hln;
	unsigned char ar_pln;
	__be16 ar_op;
};

struct fib_nh_exception___5 {
	struct fib_nh_exception___5 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___5 *fnhe_rth_input;
	struct rtable___5 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___5 {
	struct dst_entry___40 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___5 {
	struct fib_nh_exception___5 *chain;
};

struct fib_info___2;

struct fib_nh___2 {
	struct fib_nh_common___5 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___2 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___2 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___56 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___3 *nh;
	struct callback_head rcu;
	struct fib_nh___2 fib_nh[0];
};

struct nh_info___2;

struct nh_group___2;

struct nexthop___3 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___56 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___2 *nh_info;
		struct nh_group___2 *nh_grp;
	};
};

struct switchdev_obj___2 {
	struct list_head list;
	struct net_device___53 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___53 *, int, void *);
};

struct switchdev_obj_port_vlan___2 {
	struct switchdev_obj___2 obj;
	u16 flags;
	u16 vid;
};

struct switchdev_obj_port_mdb___2 {
	struct switchdev_obj___2 obj;
	unsigned char addr[6];
	u16 vid;
};

struct switchdev_obj_mrp___2 {
	struct switchdev_obj___2 obj;
	struct net_device___53 *p_port;
	struct net_device___53 *s_port;
	u32 ring_id;
	u16 prio;
};

struct switchdev_obj_ring_role_mrp___2 {
	struct switchdev_obj___2 obj;
	u8 ring_role;
	u32 ring_id;
	u8 sw_backup;
};

struct dsa_device_ops___2 {
	struct sk_buff___52 * (*xmit)(struct sk_buff___52 *, struct net_device___53 *);
	struct sk_buff___52 * (*rcv)(struct sk_buff___52 *, struct net_device___53 *);
	void (*flow_dissect)(const struct sk_buff___52 *, __be16 *, int *);
	unsigned int needed_headroom;
	unsigned int needed_tailroom;
	const char *name;
	enum dsa_tag_protocol proto;
	bool promisc_on_master;
};

struct dsa_netdevice_ops___2 {
	int (*ndo_eth_ioctl)(struct net_device___53 *, struct ifreq *, int);
};

struct dsa_switch_tree___2 {
	struct list_head list;
	struct raw_notifier_head nh;
	unsigned int index;
	struct kref refcount;
	bool setup;
	const struct dsa_device_ops___2 *tag_ops;
	enum dsa_tag_protocol default_proto;
	struct dsa_platform_data___2 *pd;
	struct list_head ports;
	struct list_head rtable;
	struct net_device___53 **lags;
	unsigned int lags_len;
	unsigned int last_switch;
};

struct dsa_switch_ops___2;

struct dsa_switch___2 {
	bool setup;
	struct device___223 *dev;
	struct dsa_switch_tree___2 *dst;
	unsigned int index;
	struct notifier_block nb;
	void *priv;
	struct dsa_chip_data___2 *cd;
	const struct dsa_switch_ops___2 *ops;
	u32 phys_mii_mask;
	struct mii_bus___10 *slave_mii_bus;
	unsigned int ageing_time_min;
	unsigned int ageing_time_max;
	struct dsa_8021q_context *tag_8021q_ctx;
	struct devlink___2 *devlink;
	unsigned int num_tx_queues;
	bool vlan_filtering_is_global;
	bool needs_standalone_vlan_filtering;
	bool configure_vlan_while_not_filtering;
	bool untag_bridge_pvid;
	bool assisted_learning_on_cpu_port;
	bool vlan_filtering;
	bool pcs_poll;
	bool mtu_enforcement_ingress;
	unsigned int num_lag_ids;
	unsigned int num_fwd_offloading_bridges;
	size_t num_ports;
};

struct fixed_phy_status___2;

struct dsa_switch_ops___2 {
	enum dsa_tag_protocol (*get_tag_protocol)(struct dsa_switch___2 *, int, enum dsa_tag_protocol);
	int (*change_tag_protocol)(struct dsa_switch___2 *, int, enum dsa_tag_protocol);
	int (*setup)(struct dsa_switch___2 *);
	void (*teardown)(struct dsa_switch___2 *);
	int (*port_setup)(struct dsa_switch___2 *, int);
	void (*port_teardown)(struct dsa_switch___2 *, int);
	u32 (*get_phy_flags)(struct dsa_switch___2 *, int);
	int (*phy_read)(struct dsa_switch___2 *, int, int);
	int (*phy_write)(struct dsa_switch___2 *, int, int, u16);
	void (*adjust_link)(struct dsa_switch___2 *, int, struct phy_device___7 *);
	void (*fixed_link_update)(struct dsa_switch___2 *, int, struct fixed_phy_status___2 *);
	void (*phylink_validate)(struct dsa_switch___2 *, int, long unsigned int *, struct phylink_link_state *);
	int (*phylink_mac_link_state)(struct dsa_switch___2 *, int, struct phylink_link_state *);
	void (*phylink_mac_config)(struct dsa_switch___2 *, int, unsigned int, const struct phylink_link_state *);
	void (*phylink_mac_an_restart)(struct dsa_switch___2 *, int);
	void (*phylink_mac_link_down)(struct dsa_switch___2 *, int, unsigned int, phy_interface_t);
	void (*phylink_mac_link_up)(struct dsa_switch___2 *, int, unsigned int, phy_interface_t, struct phy_device___7 *, int, int, bool, bool);
	void (*phylink_fixed_state)(struct dsa_switch___2 *, int, struct phylink_link_state *);
	void (*get_strings)(struct dsa_switch___2 *, int, u32, uint8_t *);
	void (*get_ethtool_stats)(struct dsa_switch___2 *, int, uint64_t *);
	int (*get_sset_count)(struct dsa_switch___2 *, int, int);
	void (*get_ethtool_phy_stats)(struct dsa_switch___2 *, int, uint64_t *);
	void (*get_stats64)(struct dsa_switch___2 *, int, struct rtnl_link_stats64 *);
	void (*self_test)(struct dsa_switch___2 *, int, struct ethtool_test *, u64 *);
	void (*get_wol)(struct dsa_switch___2 *, int, struct ethtool_wolinfo *);
	int (*set_wol)(struct dsa_switch___2 *, int, struct ethtool_wolinfo *);
	int (*get_ts_info)(struct dsa_switch___2 *, int, struct ethtool_ts_info *);
	int (*suspend)(struct dsa_switch___2 *);
	int (*resume)(struct dsa_switch___2 *);
	int (*port_enable)(struct dsa_switch___2 *, int, struct phy_device___7 *);
	void (*port_disable)(struct dsa_switch___2 *, int);
	int (*set_mac_eee)(struct dsa_switch___2 *, int, struct ethtool_eee *);
	int (*get_mac_eee)(struct dsa_switch___2 *, int, struct ethtool_eee *);
	int (*get_eeprom_len)(struct dsa_switch___2 *);
	int (*get_eeprom)(struct dsa_switch___2 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct dsa_switch___2 *, struct ethtool_eeprom *, u8 *);
	int (*get_regs_len)(struct dsa_switch___2 *, int);
	void (*get_regs)(struct dsa_switch___2 *, int, struct ethtool_regs *, void *);
	int (*port_prechangeupper)(struct dsa_switch___2 *, int, struct netdev_notifier_changeupper_info___2 *);
	int (*set_ageing_time)(struct dsa_switch___2 *, unsigned int);
	int (*port_bridge_join)(struct dsa_switch___2 *, int, struct net_device___53 *);
	void (*port_bridge_leave)(struct dsa_switch___2 *, int, struct net_device___53 *);
	int (*port_bridge_tx_fwd_offload)(struct dsa_switch___2 *, int, struct net_device___53 *, int);
	void (*port_bridge_tx_fwd_unoffload)(struct dsa_switch___2 *, int, struct net_device___53 *, int);
	void (*port_stp_state_set)(struct dsa_switch___2 *, int, u8);
	void (*port_fast_age)(struct dsa_switch___2 *, int);
	int (*port_pre_bridge_flags)(struct dsa_switch___2 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_bridge_flags)(struct dsa_switch___2 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_vlan_filtering)(struct dsa_switch___2 *, int, bool, struct netlink_ext_ack *);
	int (*port_vlan_add)(struct dsa_switch___2 *, int, const struct switchdev_obj_port_vlan___2 *, struct netlink_ext_ack *);
	int (*port_vlan_del)(struct dsa_switch___2 *, int, const struct switchdev_obj_port_vlan___2 *);
	int (*port_fdb_add)(struct dsa_switch___2 *, int, const unsigned char *, u16);
	int (*port_fdb_del)(struct dsa_switch___2 *, int, const unsigned char *, u16);
	int (*port_fdb_dump)(struct dsa_switch___2 *, int, dsa_fdb_dump_cb_t *, void *);
	int (*port_mdb_add)(struct dsa_switch___2 *, int, const struct switchdev_obj_port_mdb___2 *);
	int (*port_mdb_del)(struct dsa_switch___2 *, int, const struct switchdev_obj_port_mdb___2 *);
	int (*get_rxnfc)(struct dsa_switch___2 *, int, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct dsa_switch___2 *, int, struct ethtool_rxnfc *);
	int (*cls_flower_add)(struct dsa_switch___2 *, int, struct flow_cls_offload___2 *, bool);
	int (*cls_flower_del)(struct dsa_switch___2 *, int, struct flow_cls_offload___2 *, bool);
	int (*cls_flower_stats)(struct dsa_switch___2 *, int, struct flow_cls_offload___2 *, bool);
	int (*port_mirror_add)(struct dsa_switch___2 *, int, struct dsa_mall_mirror_tc_entry *, bool);
	void (*port_mirror_del)(struct dsa_switch___2 *, int, struct dsa_mall_mirror_tc_entry *);
	int (*port_policer_add)(struct dsa_switch___2 *, int, struct dsa_mall_policer_tc_entry *);
	void (*port_policer_del)(struct dsa_switch___2 *, int);
	int (*port_setup_tc)(struct dsa_switch___2 *, int, enum tc_setup_type, void *);
	int (*crosschip_bridge_join)(struct dsa_switch___2 *, int, int, int, struct net_device___53 *);
	void (*crosschip_bridge_leave)(struct dsa_switch___2 *, int, int, int, struct net_device___53 *);
	int (*crosschip_lag_change)(struct dsa_switch___2 *, int, int);
	int (*crosschip_lag_join)(struct dsa_switch___2 *, int, int, struct net_device___53 *, struct netdev_lag_upper_info *);
	int (*crosschip_lag_leave)(struct dsa_switch___2 *, int, int, struct net_device___53 *);
	int (*port_hwtstamp_get)(struct dsa_switch___2 *, int, struct ifreq *);
	int (*port_hwtstamp_set)(struct dsa_switch___2 *, int, struct ifreq *);
	void (*port_txtstamp)(struct dsa_switch___2 *, int, struct sk_buff___52 *);
	bool (*port_rxtstamp)(struct dsa_switch___2 *, int, struct sk_buff___52 *, unsigned int);
	int (*devlink_param_get)(struct dsa_switch___2 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_param_set)(struct dsa_switch___2 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_info_get)(struct dsa_switch___2 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*devlink_sb_pool_get)(struct dsa_switch___2 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*devlink_sb_pool_set)(struct dsa_switch___2 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*devlink_sb_port_pool_get)(struct dsa_switch___2 *, int, unsigned int, u16, u32 *);
	int (*devlink_sb_port_pool_set)(struct dsa_switch___2 *, int, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_tc_pool_bind_get)(struct dsa_switch___2 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*devlink_sb_tc_pool_bind_set)(struct dsa_switch___2 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_occ_snapshot)(struct dsa_switch___2 *, unsigned int);
	int (*devlink_sb_occ_max_clear)(struct dsa_switch___2 *, unsigned int);
	int (*devlink_sb_occ_port_pool_get)(struct dsa_switch___2 *, int, unsigned int, u16, u32 *, u32 *);
	int (*devlink_sb_occ_tc_port_bind_get)(struct dsa_switch___2 *, int, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*port_change_mtu)(struct dsa_switch___2 *, int, int);
	int (*port_max_mtu)(struct dsa_switch___2 *, int);
	int (*port_lag_change)(struct dsa_switch___2 *, int);
	int (*port_lag_join)(struct dsa_switch___2 *, int, struct net_device___53 *, struct netdev_lag_upper_info *);
	int (*port_lag_leave)(struct dsa_switch___2 *, int, struct net_device___53 *);
	int (*port_hsr_join)(struct dsa_switch___2 *, int, struct net_device___53 *);
	int (*port_hsr_leave)(struct dsa_switch___2 *, int, struct net_device___53 *);
	int (*port_mrp_add)(struct dsa_switch___2 *, int, const struct switchdev_obj_mrp___2 *);
	int (*port_mrp_del)(struct dsa_switch___2 *, int, const struct switchdev_obj_mrp___2 *);
	int (*port_mrp_add_ring_role)(struct dsa_switch___2 *, int, const struct switchdev_obj_ring_role_mrp___2 *);
	int (*port_mrp_del_ring_role)(struct dsa_switch___2 *, int, const struct switchdev_obj_ring_role_mrp___2 *);
	int (*tag_8021q_vlan_add)(struct dsa_switch___2 *, int, u16, u16);
	int (*tag_8021q_vlan_del)(struct dsa_switch___2 *, int, u16);
};

enum lwtunnel_encap_types {
	LWTUNNEL_ENCAP_NONE = 0,
	LWTUNNEL_ENCAP_MPLS = 1,
	LWTUNNEL_ENCAP_IP = 2,
	LWTUNNEL_ENCAP_ILA = 3,
	LWTUNNEL_ENCAP_IP6 = 4,
	LWTUNNEL_ENCAP_SEG6 = 5,
	LWTUNNEL_ENCAP_BPF = 6,
	LWTUNNEL_ENCAP_SEG6_LOCAL = 7,
	LWTUNNEL_ENCAP_RPL = 8,
	LWTUNNEL_ENCAP_IOAM6 = 9,
	__LWTUNNEL_ENCAP_MAX = 10,
};

struct nh_info___2 {
	struct hlist_node dev_hash;
	struct nexthop___3 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___5 fib_nhc;
		struct fib_nh___2 fib_nh;
		struct fib6_nh___5 fib6_nh;
	};
};

struct nh_grp_entry___2;

struct nh_res_bucket___2 {
	struct nh_grp_entry___2 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___2 {
	struct nexthop___3 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___3 *nh_parent;
};

struct nh_res_table___2 {
	struct net___56 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___2 nh_buckets[0];
};

struct nh_group___2 {
	struct nh_group___2 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___2 *res_table;
	struct nh_grp_entry___2 nh_entries[0];
};

enum metadata_type {
	METADATA_IP_TUNNEL = 0,
	METADATA_HW_PORT_MUX = 1,
};

struct hw_port_info {
	struct net_device___53 *lower_dev;
	u32 port_id;
};

struct metadata_dst {
	struct dst_entry___40 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info port_info;
	} u;
};

struct gre_base_hdr {
	__be16 flags;
	__be16 protocol;
};

struct gre_full_hdr {
	struct gre_base_hdr fixed_header;
	__be16 csum;
	__be16 reserved1;
	__be32 key;
	__be32 seq;
};

struct pptp_gre_header {
	struct gre_base_hdr gre_hd;
	__be16 payload_len;
	__be16 call_id;
	__be32 seq;
	__be32 ack;
};

struct tipc_basic_hdr {
	__be32 w[4];
};

struct icmphdr {
	__u8 type;
	__u8 code;
	__sum16 checksum;
	union {
		struct {
			__be16 id;
			__be16 sequence;
		} echo;
		__be32 gateway;
		struct {
			__be16 __unused;
			__be16 mtu;
		} frag;
		__u8 reserved[4];
	} un;
};

enum l2tp_debug_flags {
	L2TP_MSG_DEBUG = 1,
	L2TP_MSG_CONTROL = 2,
	L2TP_MSG_SEQ = 4,
	L2TP_MSG_DATA = 8,
};

struct pppoe_tag {
	__be16 tag_type;
	__be16 tag_len;
	char tag_data[0];
};

struct pppoe_hdr {
	__u8 type: 4;
	__u8 ver: 4;
	__u8 code;
	__be16 sid;
	__be16 length;
	struct pppoe_tag tag[0];
};

struct mpls_label {
	__be32 entry;
};

struct clock_identity {
	u8 id[8];
};

struct port_identity {
	struct clock_identity clock_identity;
	__be16 port_number;
};

struct ptp_header {
	u8 tsmt;
	u8 ver;
	__be16 message_length;
	u8 domain_number;
	u8 reserved1;
	u8 flag_field[2];
	__be64 correction;
	__be32 reserved2;
	struct port_identity source_port_identity;
	__be16 sequence_id;
	u8 control;
	u8 log_message_interval;
} __attribute__((packed));

enum batadv_packettype {
	BATADV_IV_OGM = 0,
	BATADV_BCAST = 1,
	BATADV_CODED = 2,
	BATADV_ELP = 3,
	BATADV_OGM2 = 4,
	BATADV_UNICAST = 64,
	BATADV_UNICAST_FRAG = 65,
	BATADV_UNICAST_4ADDR = 66,
	BATADV_ICMP = 67,
	BATADV_UNICAST_TVLV = 68,
};

struct batadv_unicast_packet {
	__u8 packet_type;
	__u8 version;
	__u8 ttl;
	__u8 ttvn;
	__u8 dest[6];
};

struct nf_hook_state___4 {
	u8 hook;
	u8 pf;
	struct net_device___53 *in;
	struct net_device___53 *out;
	struct sock___41 *sk;
	struct net___56 *net;
	int (*okfn)(struct net___56 *, struct sock___41 *, struct sk_buff___52 *);
};

struct nf_conntrack_zone {
	u16 id;
	u8 flags;
	u8 dir;
};

struct nf_conntrack_man {
	union nf_inet_addr u3;
	union nf_conntrack_man_proto u;
	u_int16_t l3num;
};

struct nf_conntrack_tuple {
	struct nf_conntrack_man src;
	struct {
		union nf_inet_addr u3;
		union {
			__be16 all;
			struct {
				__be16 port;
			} tcp;
			struct {
				__be16 port;
			} udp;
			struct {
				u_int8_t type;
				u_int8_t code;
			} icmp;
			struct {
				__be16 port;
			} dccp;
			struct {
				__be16 port;
			} sctp;
			struct {
				__be16 key;
			} gre;
		} u;
		u_int8_t protonum;
		u_int8_t dir;
	} dst;
};

struct nf_conntrack_tuple_hash {
	struct hlist_nulls_node hnnode;
	struct nf_conntrack_tuple tuple;
};

struct nf_ct_udp {
	long unsigned int stream_ts;
};

struct nf_ct_gre {
	unsigned int stream_timeout;
	unsigned int timeout;
};

union nf_conntrack_proto {
	struct nf_ct_dccp dccp;
	struct ip_ct_sctp sctp;
	struct ip_ct_tcp tcp;
	struct nf_ct_udp udp;
	struct nf_ct_gre gre;
	unsigned int tmpl_padto;
};

struct nf_ct_ext;

struct nf_conn {
	struct nf_conntrack ct_general;
	spinlock_t lock;
	u32 timeout;
	struct nf_conntrack_zone zone;
	struct nf_conntrack_tuple_hash tuplehash[2];
	long unsigned int status;
	u16 cpu;
	possible_net_t___51 ct_net;
	struct hlist_node nat_bysource;
	struct {	} __nfct_init_offset;
	struct nf_conn *master;
	u_int32_t mark;
	u_int32_t secmark;
	struct nf_ct_ext *ext;
	union nf_conntrack_proto proto;
};

struct nf_conntrack_tuple_mask {
	struct {
		union nf_inet_addr u3;
		union nf_conntrack_man_proto u;
	} src;
};

struct nf_ct_ext {
	u8 offset[9];
	u8 len;
	char data[0];
};

struct nf_conntrack_helper;

struct nf_conntrack_expect {
	struct hlist_node lnode;
	struct hlist_node hnode;
	struct nf_conntrack_tuple tuple;
	struct nf_conntrack_tuple_mask mask;
	void (*expectfn)(struct nf_conn *, struct nf_conntrack_expect *);
	struct nf_conntrack_helper *helper;
	struct nf_conn *master;
	struct timer_list timeout;
	refcount_t use;
	unsigned int flags;
	unsigned int class;
	union nf_inet_addr saved_addr;
	union nf_conntrack_man_proto saved_proto;
	enum ip_conntrack_dir dir;
	struct callback_head rcu;
};

enum nf_ct_ext_id {
	NF_CT_EXT_HELPER = 0,
	NF_CT_EXT_NAT = 1,
	NF_CT_EXT_SEQADJ = 2,
	NF_CT_EXT_ACCT = 3,
	NF_CT_EXT_ECACHE = 4,
	NF_CT_EXT_TSTAMP = 5,
	NF_CT_EXT_TIMEOUT = 6,
	NF_CT_EXT_LABELS = 7,
	NF_CT_EXT_SYNPROXY = 8,
	NF_CT_EXT_NUM = 9,
};

struct nf_ct_event {
	struct nf_conn *ct;
	u32 portid;
	int report;
};

struct nf_exp_event {
	struct nf_conntrack_expect *exp;
	u32 portid;
	int report;
};

struct nf_conn_labels {
	long unsigned int bits[2];
};

struct _flow_keys_digest_data {
	__be16 n_proto;
	u8 ip_proto;
	u8 padding;
	__be32 ports;
	__be32 src;
	__be32 dst;
};

struct pernet_operations___10 {
	struct list_head list;
	int (*init)(struct net___54 *);
	void (*pre_exit)(struct net___54 *);
	void (*exit)(struct net___54 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct napi_struct___8 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___8 *, int);
	int poll_owner;
	struct net_device___51 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___50 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___247 *thread;
};

struct softnet_data___2 {
	struct list_head poll_list;
	struct sk_buff_head___49 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___2 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___45 *output_queue;
	struct Qdisc___45 **output_queue_tailp;
	struct sk_buff___50 *completion_queue;
	struct sk_buff_head___49 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___2 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___49 input_pkt_queue;
	struct napi_struct___8 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct qdisc_walker {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___45 *, long unsigned int, struct qdisc_walker *);
};

struct dentry___243;

struct super_block___243;

struct module___227;

struct file_system_type___243 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___243 * (*mount)(struct file_system_type___243 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___243 *);
	struct module___227 *owner;
	struct file_system_type___243 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___243;

struct kiocb___243;

struct iov_iter___163;

struct poll_table_struct___166;

struct vm_area_struct___248;

struct inode___243;

struct file_lock___243;

struct page___248;

struct pipe_inode_info___84;

struct seq_file___218;

struct file_operations___244 {
	struct module___227 *owner;
	loff_t (*llseek)(struct file___243 *, loff_t, int);
	ssize_t (*read)(struct file___243 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___243 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___243 *, struct iov_iter___163 *);
	ssize_t (*write_iter)(struct kiocb___243 *, struct iov_iter___163 *);
	int (*iopoll)(struct kiocb___243 *, bool);
	int (*iterate)(struct file___243 *, struct dir_context *);
	int (*iterate_shared)(struct file___243 *, struct dir_context *);
	__poll_t (*poll)(struct file___243 *, struct poll_table_struct___166 *);
	long int (*unlocked_ioctl)(struct file___243 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___243 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___243 *, struct vm_area_struct___248 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___243 *, struct file___243 *);
	int (*flush)(struct file___243 *, fl_owner_t);
	int (*release)(struct inode___243 *, struct file___243 *);
	int (*fsync)(struct file___243 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___243 *, int);
	int (*lock)(struct file___243 *, int, struct file_lock___243 *);
	ssize_t (*sendpage)(struct file___243 *, struct page___248 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___243 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___243 *, long unsigned int);
	int (*flock)(struct file___243 *, int, struct file_lock___243 *);
	ssize_t (*splice_write)(struct pipe_inode_info___84 *, struct file___243 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___243 *, loff_t *, struct pipe_inode_info___84 *, size_t, unsigned int);
	int (*setlease)(struct file___243 *, long int, struct file_lock___243 **, void **);
	long int (*fallocate)(struct file___243 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___218 *, struct file___243 *);
	ssize_t (*copy_file_range)(struct file___243 *, loff_t, struct file___243 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___243 *, loff_t, struct file___243 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___243 *, loff_t, loff_t, int);
};

struct vmacache___248 {
	u64 seqnum;
	struct vm_area_struct___248 *vmas[4];
};

struct page_frag___248 {
	struct page___248 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___249;

struct pid___220;

struct nsproxy___229;

struct signal_struct___244;

struct bio_list___136;

struct backing_dev_info___122;

struct io_context___136;

struct css_set___170;

struct mem_cgroup___110;

struct request_queue___136;

struct vm_struct___226;

struct task_struct___250 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___250 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___249 *mm;
	struct mm_struct___249 *active_mm;
	struct vmacache___248 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___250 *real_parent;
	struct task_struct___250 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___250 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___220 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___229 *nsproxy;
	struct signal_struct___244 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___250 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___136 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___122 *backing_dev_info;
	struct io_context___136 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___170 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___84 *splice_pipe;
	struct page_frag___248 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___110 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___110 *active_memcg;
	struct request_queue___136 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___250 *oom_reaper_list;
	struct vm_struct___226 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___231;

struct kobj_type___231;

struct kernfs_node___231;

struct kobject___231 {
	const char *name;
	struct list_head entry;
	struct kobject___231 *parent;
	struct kset___231 *kset;
	struct kobj_type___231 *ktype;
	struct kernfs_node___231 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___228 {
	struct kobject___231 kobj;
	struct module___227 *mod;
	struct kobject___231 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___227 {
	struct module___227 *mod;
	struct latch_tree_node node;
};

struct module_layout___227 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___227 mtn;
};

struct module_attribute___227;

struct kernel_param___227;

struct module___227 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___228 mkobj;
	struct module_attribute___227 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___231 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___227 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___227 core_layout;
	struct module_layout___227 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___220;

struct upid___220 {
	int nr;
	struct pid_namespace___220 *ns;
};

struct pid_namespace___220 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___250 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___220 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___220 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___220 numbers[1];
};

typedef struct page___248 *pgtable_t___248;

struct address_space___243;

struct page_pool___72;

struct dev_pagemap___238;

struct page___248 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___243 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___72 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___248 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___248 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___249 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___238 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___238;

struct vm_area_struct___248 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___248 *vm_next;
	struct vm_area_struct___248 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___249 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___238 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___243 *vm_file;
	struct file___243 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___244 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___250 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___250 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___220 *pids[4];
	struct pid___220 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___249 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___248;

struct mm_struct___249 {
	struct {
		struct vm_area_struct___248 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___243 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___248 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___250 *owner;
		struct user_namespace___26 *user_ns;
		struct file___243 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___57;

struct cgroup_namespace___170;

struct nsproxy___229 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___220 *pid_ns_for_children;
	struct net___57 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___170 *cgroup_ns;
};

struct bio___136;

struct bio_list___136 {
	struct bio___136 *head;
	struct bio___136 *tail;
};

struct cgroup_subsys_state___170;

struct bdi_writeback___122 {
	struct backing_dev_info___122 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___170 *memcg_css;
	struct cgroup_subsys_state___170 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___224;

struct backing_dev_info___122 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___122 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___224 *dev;
	char dev_name[64];
	struct device___224 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___243 *debug_dir;
};

struct io_cq___136;

struct io_context___136 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___136 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___170;

struct css_set___170 {
	struct cgroup_subsys_state___170 *subsys[14];
	refcount_t refcount;
	struct css_set___170 *dom_cset;
	struct cgroup___170 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___170 *mg_src_cgrp;
	struct cgroup___170 *mg_dst_cgrp;
	struct css_set___170 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___243;

struct pipe_buffer___84;

struct pipe_inode_info___84 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___248 *tmp_page;
	struct fasync_struct___243 *fasync_readers;
	struct fasync_struct___243 *fasync_writers;
	struct pipe_buffer___84 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___170;

struct cgroup_subsys_state___170 {
	struct cgroup___170 *cgroup;
	struct cgroup_subsys___170 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___170 *parent;
};

struct cgroup_file___170 {
	struct kernfs_node___231 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___110;

struct mem_cgroup_per_node___110;

struct mem_cgroup___110 {
	struct cgroup_subsys_state___170 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___170 events_file;
	struct cgroup_file___170 events_local_file;
	struct cgroup_file___170 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___110 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___250 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___110 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___136;

struct blk_integrity___136 {
	const struct blk_integrity_profile___136 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___136 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___136 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___136;

struct elevator_queue___136;

struct blk_mq_ops___131;

struct blk_mq_hw_ctx___131;

struct gendisk___139;

struct blkcg_gq___124;

struct blk_mq_tag_set___131;

struct request_queue___136 {
	struct request___136 *last_merge;
	struct elevator_queue___136 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___131 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___131 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___139 *disk;
	struct kobject___231 kobj;
	struct kobject___231 *mq_kobj;
	struct blk_integrity___136 integrity;
	struct device___224 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___124 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___131 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___136 bio_split;
	struct dentry___243 *debugfs_dir;
	struct dentry___243 *sched_debugfs_dir;
	struct dentry___243 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___226 {
	struct vm_struct___226 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___248 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___243;

struct address_space___243 {
	struct inode___243 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___243 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___72 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___224 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___72 {
	u32 count;
	struct page___248 *cache[128];
};

struct page_pool___72 {
	struct page_pool_params___72 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___248 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___72 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___238;

struct dev_pagemap___238 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___238 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___243;

struct path___243 {
	struct vfsmount___243 *mnt;
	struct dentry___243 *dentry;
};

struct fown_struct___220 {
	rwlock_t lock;
	struct pid___220 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___243 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___243 f_path;
	struct inode___243 *f_inode;
	const struct file_operations___244 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___220 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___243 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___238;

struct vm_operations_struct___238 {
	void (*open)(struct vm_area_struct___248 *);
	void (*close)(struct vm_area_struct___248 *);
	int (*may_split)(struct vm_area_struct___248 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___248 *);
	int (*mprotect)(struct vm_area_struct___248 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___238 *);
	vm_fault_t (*huge_fault)(struct vm_fault___238 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___238 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___248 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___238 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___238 *);
	int (*access)(struct vm_area_struct___248 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___248 *);
	int (*set_policy)(struct vm_area_struct___248 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___248 *, long unsigned int);
	struct page___248 * (*find_special_page)(struct vm_area_struct___248 *, long unsigned int);
};

struct core_thread___248 {
	struct task_struct___250 *task;
	struct core_thread___248 *next;
};

struct core_state___248 {
	atomic_t nr_threads;
	struct core_thread___248 dumper;
	struct completion startup;
};

struct vm_fault___238 {
	const struct {
		struct vm_area_struct___248 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___248 *cow_page;
	struct page___248 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___248 prealloc_pte;
};

struct pglist_data___118;

struct lruvec___118 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___118 *pgdat;
};

struct zone___118 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___118 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___118 {
	struct zone___118 *zone;
	int zone_idx;
};

struct zonelist___118 {
	struct zoneref___118 _zonerefs[321];
};

struct pglist_data___118 {
	struct zone___118 node_zones[5];
	struct zonelist___118 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___250 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___250 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___118 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct kernfs_root___231;

struct kernfs_elem_dir___231 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___231 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___231;

struct kernfs_root___231 {
	struct kernfs_node___231 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___231 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___231 {
	struct kernfs_node___231 *target_kn;
};

struct kernfs_ops___231;

struct kernfs_elem_attr___231 {
	const struct kernfs_ops___231 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___231 *notify_next;
};

struct kernfs_node___231 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___231 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___231 dir;
		struct kernfs_elem_symlink___231 symlink;
		struct kernfs_elem_attr___231 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___231;

struct kernfs_ops___231 {
	int (*open)(struct kernfs_open_file___231 *);
	void (*release)(struct kernfs_open_file___231 *);
	int (*seq_show)(struct seq_file___218 *, void *);
	void * (*seq_start)(struct seq_file___218 *, loff_t *);
	void * (*seq_next)(struct seq_file___218 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___218 *, void *);
	ssize_t (*read)(struct kernfs_open_file___231 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___231 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___231 *, struct poll_table_struct___166 *);
	int (*mmap)(struct kernfs_open_file___231 *, struct vm_area_struct___248 *);
};

struct kernfs_syscall_ops___231 {
	int (*show_options)(struct seq_file___218 *, struct kernfs_root___231 *);
	int (*mkdir)(struct kernfs_node___231 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___231 *);
	int (*rename)(struct kernfs_node___231 *, struct kernfs_node___231 *, const char *);
	int (*show_path)(struct seq_file___218 *, struct kernfs_node___231 *, struct kernfs_root___231 *);
};

struct seq_operations___218;

struct seq_file___218 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___218 *op;
	int poll_event;
	const struct file___243 *file;
	void *private;
};

struct kernfs_open_file___231 {
	struct kernfs_node___231 *kn;
	struct file___243 *file;
	struct seq_file___218 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___238 *vm_ops;
};

typedef void (*poll_queue_proc___174)(struct file___243 *, wait_queue_head_t *, struct poll_table_struct___166 *);

struct poll_table_struct___166 {
	poll_queue_proc___174 _qproc;
	__poll_t _key;
};

struct sock___42;

struct kobj_ns_type_operations___41 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___42 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___57 *net;
} possible_net_t___52;

struct proto___41;

struct sock_common___41 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___41 *skc_prot;
	possible_net_t___52 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___42 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___53;

struct sk_buff_head___52 {
	struct sk_buff___53 *next;
	struct sk_buff___53 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___41 {
	struct cgroup___170 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___41;

struct socket_wq___42;

struct xfrm_policy___4;

struct dst_entry___41;

struct socket___43;

struct sock___42 {
	struct sock_common___41 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___52 sk_error_queue;
	struct sk_buff___53 *sk_rx_skb_cache;
	struct sk_buff_head___52 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___53 *head;
		struct sk_buff___53 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___41 *sk_filter;
	union {
		struct socket_wq___42 *sk_wq;
		struct socket_wq___42 *sk_wq_raw;
	};
	struct xfrm_policy___4 *sk_policy[2];
	struct dst_entry___41 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___41 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___53 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___53 *sk_tx_skb_cache;
	struct sk_buff_head___52 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___248 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___41 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___220 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___43 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___41 sk_cgrp_data;
	struct mem_cgroup___110 *sk_memcg;
	void (*sk_state_change)(struct sock___42 *);
	void (*sk_data_ready)(struct sock___42 *);
	void (*sk_write_space)(struct sock___42 *);
	void (*sk_error_report)(struct sock___42 *);
	int (*sk_backlog_rcv)(struct sock___42 *, struct sk_buff___53 *);
	struct sk_buff___53 * (*sk_validate_xmit_skb)(struct sock___42 *, struct net_device___6 *, struct sk_buff___53 *);
	void (*sk_destruct)(struct sock___42 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___231;

struct attribute_group___231 {
	const char *name;
	umode_t (*is_visible)(struct kobject___231 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___231 *, struct bin_attribute___231 *, int);
	struct attribute **attrs;
	struct bin_attribute___231 **bin_attrs;
};

struct bin_attribute___231 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___243 * (*f_mapping)();
	ssize_t (*read)(struct file___243 *, struct kobject___231 *, struct bin_attribute___231 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___243 *, struct kobject___231 *, struct bin_attribute___231 *, char *, loff_t, size_t);
	int (*mmap)(struct file___243 *, struct kobject___231 *, struct bin_attribute___231 *, struct vm_area_struct___248 *);
};

struct sysfs_ops___231 {
	ssize_t (*show)(struct kobject___231 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___231 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___231;

struct kset___231 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___231 kobj;
	const struct kset_uevent_ops___231 *uevent_ops;
};

struct kobj_type___231 {
	void (*release)(struct kobject___231 *);
	const struct sysfs_ops___231 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___231 **default_groups;
	const struct kobj_ns_type_operations___41 * (*child_ns_type)(struct kobject___231 *);
	const void * (*namespace)(struct kobject___231 *);
	void (*get_ownership)(struct kobject___231 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___231 {
	int (* const filter)(struct kset___231 *, struct kobject___231 *);
	const char * (* const name)(struct kset___231 *, struct kobject___231 *);
	int (* const uevent)(struct kset___231 *, struct kobject___231 *, struct kobj_uevent_env *);
};

struct wakeup_source___224;

struct dev_pm_info___224 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___224 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___224 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___224;

struct bus_type___224;

struct device_driver___224;

struct dev_pm_domain___224;

struct device_node___101;

struct fwnode_handle___220;

struct class___224;

struct device___224 {
	struct kobject___231 kobj;
	struct device___224 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___224 *type;
	struct bus_type___224 *bus;
	struct device_driver___224 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___224 power;
	struct dev_pm_domain___224 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___101 *of_node;
	struct fwnode_handle___220 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___224 *class;
	const struct attribute_group___231 **groups;
	void (*release)(struct device___224 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_ops___224 {
	int (*prepare)(struct device___224 *);
	void (*complete)(struct device___224 *);
	int (*suspend)(struct device___224 *);
	int (*resume)(struct device___224 *);
	int (*freeze)(struct device___224 *);
	int (*thaw)(struct device___224 *);
	int (*poweroff)(struct device___224 *);
	int (*restore)(struct device___224 *);
	int (*suspend_late)(struct device___224 *);
	int (*resume_early)(struct device___224 *);
	int (*freeze_late)(struct device___224 *);
	int (*thaw_early)(struct device___224 *);
	int (*poweroff_late)(struct device___224 *);
	int (*restore_early)(struct device___224 *);
	int (*suspend_noirq)(struct device___224 *);
	int (*resume_noirq)(struct device___224 *);
	int (*freeze_noirq)(struct device___224 *);
	int (*thaw_noirq)(struct device___224 *);
	int (*poweroff_noirq)(struct device___224 *);
	int (*restore_noirq)(struct device___224 *);
	int (*runtime_suspend)(struct device___224 *);
	int (*runtime_resume)(struct device___224 *);
	int (*runtime_idle)(struct device___224 *);
};

struct wakeup_source___224 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___224 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___224 {
	struct dev_pm_ops___224 ops;
	int (*start)(struct device___224 *);
	void (*detach)(struct device___224 *, bool);
	int (*activate)(struct device___224 *);
	void (*sync)(struct device___224 *);
	void (*dismiss)(struct device___224 *);
};

struct bus_type___224 {
	const char *name;
	const char *dev_name;
	struct device___224 *dev_root;
	const struct attribute_group___231 **bus_groups;
	const struct attribute_group___231 **dev_groups;
	const struct attribute_group___231 **drv_groups;
	int (*match)(struct device___224 *, struct device_driver___224 *);
	int (*uevent)(struct device___224 *, struct kobj_uevent_env *);
	int (*probe)(struct device___224 *);
	void (*sync_state)(struct device___224 *);
	void (*remove)(struct device___224 *);
	void (*shutdown)(struct device___224 *);
	int (*online)(struct device___224 *);
	int (*offline)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	int (*num_vf)(struct device___224 *);
	int (*dma_configure)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___224 {
	const char *name;
	struct bus_type___224 *bus;
	struct module___227 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___224 *);
	void (*sync_state)(struct device___224 *);
	int (*remove)(struct device___224 *);
	void (*shutdown)(struct device___224 *);
	int (*suspend)(struct device___224 *, pm_message_t);
	int (*resume)(struct device___224 *);
	const struct attribute_group___231 **groups;
	const struct attribute_group___231 **dev_groups;
	const struct dev_pm_ops___224 *pm;
	void (*coredump)(struct device___224 *);
	struct driver_private *p;
};

struct device_type___224 {
	const char *name;
	const struct attribute_group___231 **groups;
	int (*uevent)(struct device___224 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___224 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___224 *);
	const struct dev_pm_ops___224 *pm;
};

struct class___224 {
	const char *name;
	struct module___227 *owner;
	const struct attribute_group___231 **class_groups;
	const struct attribute_group___231 **dev_groups;
	struct kobject___231 *dev_kobj;
	int (*dev_uevent)(struct device___224 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___224 *, umode_t *);
	void (*class_release)(struct class___224 *);
	void (*dev_release)(struct device___224 *);
	int (*shutdown_pre)(struct device___224 *);
	const struct kobj_ns_type_operations___41 *ns_type;
	const void * (*namespace)(struct device___224 *);
	void (*get_ownership)(struct device___224 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___224 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___220;

struct fwnode_handle___220 {
	struct fwnode_handle___220 *secondary;
	const struct fwnode_operations___220 *ops;
	struct device___224 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct property___75;

struct device_node___101 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___220 fwnode;
	struct property___75 *properties;
	struct property___75 *deadprops;
	struct device_node___101 *parent;
	struct device_node___101 *child;
	struct device_node___101 *sibling;
	struct kobject___231 kobj;
	long unsigned int _flags;
	void *data;
};

struct shrink_control___110 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___110 *memcg;
};

struct shrinker___110 {
	long unsigned int (*count_objects)(struct shrinker___110 *, struct shrink_control___110 *);
	long unsigned int (*scan_objects)(struct shrinker___110 *, struct shrink_control___110 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___238 {
	void (*page_free)(struct page___248 *);
	void (*kill)(struct dev_pagemap___238 *);
	void (*cleanup)(struct dev_pagemap___238 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___238 *);
};

struct dentry_operations___243;

struct dentry___243 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___243 *d_parent;
	struct qstr d_name;
	struct inode___243 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___243 *d_op;
	struct super_block___243 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___243;

struct inode___243 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___243 *i_op;
	struct super_block___243 *i_sb;
	struct address_space___243 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___122 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___244 *i_fop;
		void (*free_inode)(struct inode___243 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___243 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___84 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___243 {
	int (*d_revalidate)(struct dentry___243 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___243 *, unsigned int);
	int (*d_hash)(const struct dentry___243 *, struct qstr *);
	int (*d_compare)(const struct dentry___243 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___243 *);
	int (*d_init)(struct dentry___243 *);
	void (*d_release)(struct dentry___243 *);
	void (*d_prune)(struct dentry___243 *);
	void (*d_iput)(struct dentry___243 *, struct inode___243 *);
	char * (*d_dname)(struct dentry___243 *, char *, int);
	struct vfsmount___243 * (*d_automount)(struct path___243 *);
	int (*d_manage)(const struct path___243 *, bool);
	struct dentry___243 * (*d_real)(struct dentry___243 *, const struct inode___243 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___243;

struct mem_dqinfo___243 {
	struct quota_format_type___243 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___243;

struct quota_info___243 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___243 *files[3];
	struct mem_dqinfo___243 info[3];
	const struct quota_format_ops___243 *ops[3];
};

struct rcuwait___244 {
	struct task_struct___250 *task;
};

struct percpu_rw_semaphore___244 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___244 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___243 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___244 rw_sem[3];
};

struct super_operations___243;

struct dquot_operations___243;

struct quotactl_ops___243;

struct block_device___139;

struct super_block___243 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___243 *s_type;
	const struct super_operations___243 *s_op;
	const struct dquot_operations___243 *dq_op;
	const struct quotactl_ops___243 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___243 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___139 *s_bdev;
	struct backing_dev_info___122 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___243 s_dquot;
	struct sb_writers___243 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___243 *s_d_op;
	int cleancache_poolid;
	struct shrinker___110 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___243 {
	struct dentry___243 *mnt_root;
	struct super_block___243 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___170 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___250 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___48;

struct cgroup_bpf___48 {
	struct bpf_prog_array___48 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___48 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___170;

struct cgroup_rstat_cpu___170;

struct cgroup___170 {
	struct cgroup_subsys_state___170 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___231 *kn;
	struct cgroup_file___170 procs_file;
	struct cgroup_file___170 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___170 *subsys[14];
	struct cgroup_root___170 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___170 *dom_cgrp;
	struct cgroup___170 *old_dom_cgrp;
	struct cgroup_rstat_cpu___170 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___170 psi;
	struct cgroup_bpf___48 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___136 {
	struct request_queue___136 *q;
	struct io_context___136 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___243 {
	struct file___243 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___243 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___243 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___243 *ia_file;
};

struct dquot___243 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___243 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___243 {
	int qf_fmt_id;
	const struct quota_format_ops___243 *qf_ops;
	struct module___227 *qf_owner;
	struct quota_format_type___243 *qf_next;
};

struct quota_format_ops___243 {
	int (*check_quota_file)(struct super_block___243 *, int);
	int (*read_file_info)(struct super_block___243 *, int);
	int (*write_file_info)(struct super_block___243 *, int);
	int (*free_file_info)(struct super_block___243 *, int);
	int (*read_dqblk)(struct dquot___243 *);
	int (*commit_dqblk)(struct dquot___243 *);
	int (*release_dqblk)(struct dquot___243 *);
	int (*get_next_id)(struct super_block___243 *, struct kqid *);
};

struct dquot_operations___243 {
	int (*write_dquot)(struct dquot___243 *);
	struct dquot___243 * (*alloc_dquot)(struct super_block___243 *, int);
	void (*destroy_dquot)(struct dquot___243 *);
	int (*acquire_dquot)(struct dquot___243 *);
	int (*release_dquot)(struct dquot___243 *);
	int (*mark_dirty)(struct dquot___243 *);
	int (*write_info)(struct super_block___243 *, int);
	qsize_t * (*get_reserved_space)(struct inode___243 *);
	int (*get_projid)(struct inode___243 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___243 *, qsize_t *);
	int (*get_next_id)(struct super_block___243 *, struct kqid *);
};

struct quotactl_ops___243 {
	int (*quota_on)(struct super_block___243 *, int, int, const struct path___243 *);
	int (*quota_off)(struct super_block___243 *, int);
	int (*quota_enable)(struct super_block___243 *, unsigned int);
	int (*quota_disable)(struct super_block___243 *, unsigned int);
	int (*quota_sync)(struct super_block___243 *, int);
	int (*set_info)(struct super_block___243 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___243 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___243 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___243 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___243 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___243 *, unsigned int);
};

struct writeback_control___122;

struct address_space_operations___243 {
	int (*writepage)(struct page___248 *, struct writeback_control___122 *);
	int (*readpage)(struct file___243 *, struct page___248 *);
	int (*writepages)(struct address_space___243 *, struct writeback_control___122 *);
	int (*set_page_dirty)(struct page___248 *);
	int (*readpages)(struct file___243 *, struct address_space___243 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___243 *, struct address_space___243 *, loff_t, unsigned int, unsigned int, struct page___248 **, void **);
	int (*write_end)(struct file___243 *, struct address_space___243 *, loff_t, unsigned int, unsigned int, struct page___248 *, void *);
	sector_t (*bmap)(struct address_space___243 *, sector_t);
	void (*invalidatepage)(struct page___248 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___248 *, gfp_t);
	void (*freepage)(struct page___248 *);
	ssize_t (*direct_IO)(struct kiocb___243 *, struct iov_iter___163 *);
	int (*migratepage)(struct address_space___243 *, struct page___248 *, struct page___248 *, enum migrate_mode);
	bool (*isolate_page)(struct page___248 *, isolate_mode_t);
	void (*putback_page)(struct page___248 *);
	int (*launder_page)(struct page___248 *);
	int (*is_partially_uptodate)(struct page___248 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___248 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___243 *, struct page___248 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___243 *, sector_t *);
	void (*swap_deactivate)(struct file___243 *);
};

struct writeback_control___122 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___122 *wb;
	struct inode___243 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___160;

struct iov_iter___163 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___160 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___84 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___243 {
	struct dentry___243 * (*lookup)(struct inode___243 *, struct dentry___243 *, unsigned int);
	const char * (*get_link)(struct dentry___243 *, struct inode___243 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___243 *, int);
	struct posix_acl * (*get_acl)(struct inode___243 *, int, bool);
	int (*readlink)(struct dentry___243 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___243 *, struct dentry___243 *, umode_t, bool);
	int (*link)(struct dentry___243 *, struct inode___243 *, struct dentry___243 *);
	int (*unlink)(struct inode___243 *, struct dentry___243 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___243 *, struct dentry___243 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___243 *, struct dentry___243 *, umode_t);
	int (*rmdir)(struct inode___243 *, struct dentry___243 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___243 *, struct dentry___243 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___243 *, struct dentry___243 *, struct inode___243 *, struct dentry___243 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___243 *, struct iattr___243 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___243 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___243 *, char *, size_t);
	int (*fiemap)(struct inode___243 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___243 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___243 *, struct dentry___243 *, struct file___243 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___243 *, struct dentry___243 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___243 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___243 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___243 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___243 {
	void (*fl_copy_lock)(struct file_lock___243 *, struct file_lock___243 *);
	void (*fl_release_private)(struct file_lock___243 *);
};

struct lock_manager_operations___243;

struct file_lock___243 {
	struct file_lock___243 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___243 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___243 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___243 *fl_ops;
	const struct lock_manager_operations___243 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___243 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___243 *);
	int (*lm_grant)(struct file_lock___243 *, int);
	bool (*lm_break)(struct file_lock___243 *);
	int (*lm_change)(struct file_lock___243 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___243 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___243 *);
};

struct fasync_struct___243 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___243 *fa_next;
	struct file___243 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___243 {
	struct inode___243 * (*alloc_inode)(struct super_block___243 *);
	void (*destroy_inode)(struct inode___243 *);
	void (*free_inode)(struct inode___243 *);
	void (*dirty_inode)(struct inode___243 *, int);
	int (*write_inode)(struct inode___243 *, struct writeback_control___122 *);
	int (*drop_inode)(struct inode___243 *);
	void (*evict_inode)(struct inode___243 *);
	void (*put_super)(struct super_block___243 *);
	int (*sync_fs)(struct super_block___243 *, int);
	int (*freeze_super)(struct super_block___243 *);
	int (*freeze_fs)(struct super_block___243 *);
	int (*thaw_super)(struct super_block___243 *);
	int (*unfreeze_fs)(struct super_block___243 *);
	int (*statfs)(struct dentry___243 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___243 *, int *, char *);
	void (*umount_begin)(struct super_block___243 *);
	int (*show_options)(struct seq_file___218 *, struct dentry___243 *);
	int (*show_devname)(struct seq_file___218 *, struct dentry___243 *);
	int (*show_path)(struct seq_file___218 *, struct dentry___243 *);
	int (*show_stats)(struct seq_file___218 *, struct dentry___243 *);
	ssize_t (*quota_read)(struct super_block___243 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___243 *, int, const char *, size_t, loff_t);
	struct dquot___243 ** (*get_dquots)(struct inode___243 *);
	long int (*nr_cached_objects)(struct super_block___243 *, struct shrink_control___110 *);
	long int (*free_cached_objects)(struct super_block___243 *, struct shrink_control___110 *);
	struct file___243 * (*real_loop)(struct file___243 *);
};

struct block_device___139 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___243 *bd_inode;
	struct super_block___243 *bd_super;
	void *bd_claiming;
	struct device___224 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___231 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___139 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___243 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void bio_end_io_t___136(struct bio___136 *);

struct bio_vec___160 {
	struct page___248 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___136;

struct bio___136 {
	struct bio___136 *bi_next;
	struct block_device___139 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___136 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___124 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___136 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___160 *bi_io_vec;
	struct bio_set___136 *bi_pool;
	struct bio_vec___160 bi_inline_vecs[0];
};

struct msghdr___43 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___163 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___243 *msg_iocb;
};

struct fwnode_reference_args___220;

struct fwnode_endpoint___220;

struct fwnode_operations___220 {
	struct fwnode_handle___220 * (*get)(struct fwnode_handle___220 *);
	void (*put)(struct fwnode_handle___220 *);
	bool (*device_is_available)(const struct fwnode_handle___220 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___220 *, const struct device___224 *);
	bool (*property_present)(const struct fwnode_handle___220 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___220 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___220 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___220 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*get_parent)(const struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*get_next_child_node)(const struct fwnode_handle___220 *, struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*get_named_child_node)(const struct fwnode_handle___220 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___220 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___220 *);
	struct fwnode_handle___220 * (*graph_get_next_endpoint)(const struct fwnode_handle___220 *, struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*graph_get_remote_endpoint)(const struct fwnode_handle___220 *);
	struct fwnode_handle___220 * (*graph_get_port_parent)(struct fwnode_handle___220 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___220 *, struct fwnode_endpoint___220 *);
	int (*add_links)(struct fwnode_handle___220 *);
};

struct fwnode_endpoint___220 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___220 *local_fwnode;
};

struct fwnode_reference_args___220 {
	struct fwnode_handle___220 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernel_param_ops___227 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___227 *);
	int (*get)(char *, const struct kernel_param___227 *);
	void (*free)(void *);
};

struct kparam_array___227;

struct kernel_param___227 {
	const char *name;
	struct module___227 *mod;
	const struct kernel_param_ops___227 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___227 *arr;
	};
};

struct kparam_array___227 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___227 *ops;
	void *elem;
};

struct module_attribute___227 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___227 *, struct module_kobject___228 *, char *);
	ssize_t (*store)(struct module_attribute___227 *, struct module_kobject___228 *, const char *, size_t);
	void (*setup)(struct module___227 *, const char *);
	int (*test)(struct module___227 *);
	void (*free)(struct module___227 *);
};

struct ip_ra_chain___22;

struct fib_rules_ops___41;

struct fqdir___57;

struct fib_notifier_ops___41;

struct netns_ipv4___57 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___22 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___41 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___42 *fibnl;
	struct sock___42 **icmp_sk;
	struct sock___42 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___42 **tcp_sk;
	struct fqdir___57 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___41 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___41 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___41 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___41;

struct dst_ops___57 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___57 *);
	struct dst_entry___41 * (*check)(struct dst_entry___41 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___41 *);
	unsigned int (*mtu)(const struct dst_entry___41 *);
	u32 * (*cow_metrics)(struct dst_entry___41 *, long unsigned int);
	void (*destroy)(struct dst_entry___41 *);
	void (*ifdown)(struct dst_entry___41 *, struct net_device___6 *, int);
	struct dst_entry___41 * (*negative_advice)(struct dst_entry___41 *);
	void (*link_failure)(struct sk_buff___53 *);
	void (*update_pmtu)(struct dst_entry___41 *, struct sock___42 *, struct sk_buff___53 *, u32, bool);
	void (*redirect)(struct dst_entry___41 *, struct sock___42 *, struct sk_buff___53 *);
	int (*local_out)(struct net___57 *, struct sock___42 *, struct sk_buff___53 *);
	struct neighbour___41 * (*neigh_lookup)(const struct dst_entry___41 *, struct sk_buff___53 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___41 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___6;

struct rt6_info___6;

struct fib6_table___6;

struct netns_ipv6___57 {
	struct dst_ops___57 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___57 *fqdir;
	struct fib6_info___6 *fib6_null_entry;
	struct rt6_info___6 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___6 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___6 *ip6_prohibit_entry;
	struct rt6_info___6 *ip6_blk_hole_entry;
	struct fib6_table___6 *fib6_local_tbl;
	struct fib_rules_ops___41 *fib6_rules_ops;
	struct sock___42 **icmp_sk;
	struct sock___42 *ndisc_sk;
	struct sock___42 *tcp_sk;
	struct sock___42 *igmp_sk;
	struct sock___42 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___41 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___41 *notifier_ops;
	struct fib_notifier_ops___41 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___57 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___57 *fqdir;
};

struct netns_sctp___41 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___42 *ctl_sock;
	struct sock___42 *udp4_sock;
	struct sock___42 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___5;

struct netns_nf___5 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___5 *hooks_ipv4[5];
	struct nf_hook_entries___5 *hooks_ipv6[5];
	struct nf_hook_entries___5 *hooks_arp[3];
	struct nf_hook_entries___5 *hooks_bridge[5];
	struct nf_hook_entries___5 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___48;

struct netns_bpf___48 {
	struct bpf_prog_array___48 *run_array[2];
	struct bpf_prog___48 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___57 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___42 *nlsk;
	struct sock___42 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___57 xfrm4_dst_ops;
	struct dst_ops___57 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___57 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___42 *rtnl;
	struct sock___42 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___6 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___57 ipv4;
	struct netns_ipv6___57 ipv6;
	struct netns_ieee802154_lowpan___57 ieee802154_lowpan;
	struct netns_sctp___41 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___52 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___48 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___57 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___42 *crypto_nlsk;
	struct sock___42 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___170 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___170 *root_cset;
};

enum {
	IF_OPER_UNKNOWN = 0,
	IF_OPER_NOTPRESENT = 1,
	IF_OPER_DOWN = 2,
	IF_OPER_LOWERLAYERDOWN = 3,
	IF_OPER_TESTING = 4,
	IF_OPER_DORMANT = 5,
	IF_OPER_UP = 6,
};

struct socket_wq___42 {
	wait_queue_head_t wait;
	struct fasync_struct___243 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___42;

struct socket___43 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___243 *file;
	struct sock___42 *sk;
	const struct proto_ops___42 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___42 wq;
};

typedef int (*sk_read_actor_t___41)(read_descriptor_t *, struct sk_buff___53 *, unsigned int, size_t);

struct proto_ops___42 {
	int family;
	struct module___227 *owner;
	int (*release)(struct socket___43 *);
	int (*bind)(struct socket___43 *, struct sockaddr *, int);
	int (*connect)(struct socket___43 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___43 *, struct socket___43 *);
	int (*accept)(struct socket___43 *, struct socket___43 *, int, bool);
	int (*getname)(struct socket___43 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___243 *, struct socket___43 *, struct poll_table_struct___166 *);
	int (*ioctl)(struct socket___43 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___43 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___43 *, void *, bool, bool);
	int (*listen)(struct socket___43 *, int);
	int (*shutdown)(struct socket___43 *, int);
	int (*setsockopt)(struct socket___43 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___43 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___218 *, struct socket___43 *);
	int (*sendmsg)(struct socket___43 *, struct msghdr___43 *, size_t);
	int (*recvmsg)(struct socket___43 *, struct msghdr___43 *, size_t, int);
	int (*mmap)(struct file___243 *, struct socket___43 *, struct vm_area_struct___248 *);
	ssize_t (*sendpage)(struct socket___43 *, struct page___248 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___43 *, loff_t *, struct pipe_inode_info___84 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___42 *, int);
	int (*peek_len)(struct socket___43 *);
	int (*read_sock)(struct sock___42 *, read_descriptor_t *, sk_read_actor_t___41);
	int (*sendpage_locked)(struct sock___42 *, struct page___248 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___42 *, struct msghdr___43 *, size_t);
	int (*set_rcvlowat)(struct sock___42 *, int);
};

struct sk_buff___53 {
	union {
		struct {
			struct sk_buff___53 *next;
			struct sk_buff___53 *prev;
			union {
				struct net_device___6 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___42 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___53 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct pipe_buf_operations___84;

struct pipe_buffer___84 {
	struct page___248 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___84 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___84 {
	int (*confirm)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
	void (*release)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
	bool (*try_steal)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
	bool (*get)(struct pipe_inode_info___84 *, struct pipe_buffer___84 *);
};

typedef rx_handler_result_t rx_handler_func_t___52(struct sk_buff___53 **);

struct bpf_xdp_entity___48 {
	struct bpf_prog___48 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___52;

struct net_device_ops___52;

struct iw_handler_def___2;

struct ethtool_ops___24;

struct l3mdev_ops___41;

struct ndisc_ops___28;

struct xfrmdev_ops___52;

struct header_ops___52;

struct dsa_port___3;

struct inet6_dev___28;

struct netdev_rx_queue___52;

struct mini_Qdisc___48;

struct netdev_queue___52;

struct Qdisc___48;

struct rtnl_link_ops___48;

struct dcbnl_rtnl_ops___52;

struct phy_device___8;

struct net_device___6 {
	char name[16];
	struct netdev_name_node___52 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___52 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def___2 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___24 *ethtool_ops;
	const struct l3mdev_ops___41 *l3mdev_ops;
	const struct ndisc_ops___28 *ndisc_ops;
	const struct xfrmdev_ops___52 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___52 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___231 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port___3 *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___28 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___52 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___48 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___52 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___48 *miniq_ingress;
	struct netdev_queue___52 *ingress_queue;
	struct nf_hook_entries___5 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___52 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___48 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___48 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___52 = 0,
		NETREG_REGISTERED___52 = 1,
		NETREG_UNREGISTERING___52 = 2,
		NETREG_UNREGISTERED___52 = 3,
		NETREG_RELEASED___52 = 4,
		NETREG_DUMMY___52 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___52 = 0,
		RTNL_LINK_INITIALIZING___52 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___6 *);
	struct netpoll_info *npinfo;
	possible_net_t___52 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___224 dev;
	const struct attribute_group___231 *sysfs_groups[4];
	const struct attribute_group___231 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___48 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___52 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___8 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___48 xdp_state[3];
	long: 64;
};

struct tc_skb_ext {
	__u32 chain;
	__u16 mru;
	__u16 zone;
	u8 post_ct: 1;
	u8 post_ct_snat: 1;
	u8 post_ct_dnat: 1;
	long: 31;
	long: 64;
};

typedef struct bio_vec___160 skb_frag_t___11;

struct ubuf_info___4 {
	void (*callback)(struct sk_buff___53 *, struct ubuf_info___4 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___11 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___53 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___11 frags[17];
};

struct inet_frags___57;

struct fqdir___57 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___57 *f;
	struct net___57 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___57;

struct inet_frags___57 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___57 *, const void *);
	void (*destructor)(struct inet_frag_queue___57 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___57 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___53 *fragments_tail;
	struct sk_buff___53 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___57 *fqdir;
	struct callback_head rcu;
};

struct ipv4_devconf {
	void *sysctl;
	int data[32];
	long unsigned int state[1];
};

struct ip_ra_chain___22 {
	struct ip_ra_chain___22 *next;
	struct sock___42 *sk;
	union {
		void (*destructor)(struct sock___42 *);
		struct sock___42 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___41;

struct fib_lookup_arg___41;

struct fib_rules_ops___41 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___41 *, struct flowi *, int, struct fib_lookup_arg___41 *);
	bool (*suppress)(struct fib_rule___41 *, int, struct fib_lookup_arg___41 *);
	int (*match)(struct fib_rule___41 *, struct flowi *, int);
	int (*configure)(struct fib_rule___41 *, struct sk_buff___53 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___41 *);
	int (*compare)(struct fib_rule___41 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___41 *, struct sk_buff___53 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___41 *);
	void (*flush_cache)(struct fib_rules_ops___41 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___227 *owner;
	struct net___57 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___41 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___57 *);
	int (*fib_dump)(struct net___57 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___227 *owner;
	struct callback_head rcu;
};

struct xfrm_state___4;

struct lwtunnel_state___23;

struct dst_entry___41 {
	struct net_device___6 *dev;
	struct dst_ops___57 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___4 *xfrm;
	int (*input)(struct sk_buff___53 *);
	int (*output)(struct net___57 *, struct sock___42 *, struct sk_buff___53 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___23 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___41;

struct neigh_parms___41;

struct neigh_ops___41;

struct neighbour___41 {
	struct neighbour___41 *next;
	struct neigh_table___41 *tbl;
	struct neigh_parms___41 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___52 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___41 *, struct sk_buff___53 *);
	const struct neigh_ops___41 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___6 *dev;
	u8 primary_key[0];
};

struct rtable___6;

struct fnhe_hash_bucket___6;

struct fib_nh_common___6 {
	struct net_device___6 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___23 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___6 **nhc_pcpu_rth_output;
	struct rtable___6 *nhc_rth_input;
	struct fnhe_hash_bucket___6 *nhc_exceptions;
};

struct fib6_nh___6 {
	struct fib_nh_common___6 nh_common;
	long unsigned int last_probe;
	struct rt6_info___6 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___6;

struct fib6_info___6 {
	struct fib6_table___6 *fib6_table;
	struct fib6_info___6 *fib6_next;
	struct fib6_node___6 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___6 fib6_nh[0];
};

struct rt6_info___6 {
	struct dst_entry___41 dst;
	struct fib6_info___6 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___28 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___6 {
	struct fib6_node___6 *parent;
	struct fib6_node___6 *left;
	struct fib6_node___6 *right;
	struct fib6_node___6 *subtree;
	struct fib6_info___6 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___6 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___6 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___6 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

enum nf_dev_hooks {
	NF_NETDEV_INGRESS = 0,
	NF_NETDEV_NUMHOOKS = 1,
};

struct nf_hook_state___5;

typedef unsigned int nf_hookfn___5(void *, struct sk_buff___53 *, const struct nf_hook_state___5 *);

struct nf_hook_entry___5 {
	nf_hookfn___5 *hook;
	void *priv;
};

struct nf_hook_entries___5 {
	u16 num_hook_entries;
	struct nf_hook_entry___5 hooks[0];
};

struct bpf_prog_array_item___48 {
	struct bpf_prog___48 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___48 {
	struct callback_head rcu;
	struct bpf_prog_array_item___48 items[0];
};

struct bpf_prog_aux___55;

struct bpf_prog___48 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___55 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___218 {
	void * (*start)(struct seq_file___218 *, loff_t *);
	void (*stop)(struct seq_file___218 *, void *);
	void * (*next)(struct seq_file___218 *, void *, loff_t *);
	int (*show)(struct seq_file___218 *, void *);
};

struct pernet_operations___11 {
	struct list_head list;
	int (*init)(struct net___57 *);
	void (*pre_exit)(struct net___57 *);
	void (*exit)(struct net___57 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___52 {
	int (*ieee_getets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___6 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___6 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___6 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___6 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___6 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___6 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___6 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___6 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___6 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___6 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___6 *);
	u8 (*setstate)(struct net_device___6 *, u8);
	void (*getpermhwaddr)(struct net_device___6 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___6 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___6 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___6 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___6 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___6 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___6 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___6 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___6 *, int, u8 *);
	void (*setpfccfg)(struct net_device___6 *, int, u8);
	void (*getpfccfg)(struct net_device___6 *, int, u8 *);
	u8 (*setall)(struct net_device___6 *);
	u8 (*getcap)(struct net_device___6 *, int, u8 *);
	int (*getnumtcs)(struct net_device___6 *, int, u8 *);
	int (*setnumtcs)(struct net_device___6 *, int, u8);
	u8 (*getpfcstate)(struct net_device___6 *);
	void (*setpfcstate)(struct net_device___6 *, u8);
	void (*getbcncfg)(struct net_device___6 *, int, u32 *);
	void (*setbcncfg)(struct net_device___6 *, int, u32);
	void (*getbcnrp)(struct net_device___6 *, int, u8 *);
	void (*setbcnrp)(struct net_device___6 *, int, u8);
	int (*setapp)(struct net_device___6 *, u8, u16, u8);
	int (*getapp)(struct net_device___6 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___6 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___6 *, int, u8);
	u8 (*getdcbx)(struct net_device___6 *);
	u8 (*setdcbx)(struct net_device___6 *, u8);
	int (*peer_getappinfo)(struct net_device___6 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___6 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___6 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___6 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___6 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___6 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___55;

typedef int (*bpf_iter_init_seq_priv_t___54)(void *, struct bpf_iter_aux_info___55 *);

struct bpf_map___55;

struct bpf_iter_aux_info___55 {
	struct bpf_map___55 *map;
};

struct bpf_iter_seq_info___54 {
	const struct seq_operations___218 *seq_ops;
	bpf_iter_init_seq_priv_t___54 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___54 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___55 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___55 *, struct file___243 *);
	void (*map_free)(struct bpf_map___55 *);
	int (*map_get_next_key)(struct bpf_map___55 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___55 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___55 *, void *);
	int (*map_lookup_batch)(struct bpf_map___55 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___55 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___55 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___55 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___55 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___55 *, void *);
	int (*map_update_elem)(struct bpf_map___55 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___55 *, void *);
	int (*map_push_elem)(struct bpf_map___55 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___55 *, void *);
	int (*map_peek_elem)(struct bpf_map___55 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___55 *, struct file___243 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___55 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___55 *, void *, struct seq_file___218 *);
	int (*map_check_btf)(const struct bpf_map___55 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___55 *, struct bpf_prog_aux___55 *);
	void (*map_poke_untrack)(struct bpf_map___55 *, struct bpf_prog_aux___55 *);
	void (*map_poke_run)(struct bpf_map___55 *, u32, struct bpf_prog___48 *, struct bpf_prog___48 *);
	int (*map_direct_value_addr)(const struct bpf_map___55 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___55 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___55 *, struct vm_area_struct___248 *);
	__poll_t (*map_poll)(struct bpf_map___55 *, struct file___243 *, struct poll_table_struct___166 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___55 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___55 *, const struct bpf_map___55 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___55 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___54 *iter_seq_info;
};

struct bpf_map___55 {
	const struct bpf_map_ops___54 *ops;
	struct bpf_map___55 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___110 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___54;

struct bpf_jit_poke_descriptor___54;

struct bpf_prog_ops___48;

struct btf_mod_pair___54;

struct bpf_prog_offload___52;

struct bpf_prog_aux___55 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___48 *dst_prog;
	struct bpf_trampoline___54 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___48 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___54 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___48 *ops;
	struct bpf_map___55 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___54 *used_btfs;
	struct bpf_prog___48 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___55 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___52 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___52;

struct bpf_map_dev_ops___52 {
	int (*map_get_next_key)(struct bpf_offloaded_map___52 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___52 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___52 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___52 *, void *);
};

struct bpf_offloaded_map___52 {
	struct bpf_map___55 map;
	struct net_device___6 *netdev;
	const struct bpf_map_dev_ops___52 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___48 {
	int (*test_run)(struct bpf_prog___48 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___52 {
	struct bpf_prog___48 *prog;
	struct net_device___6 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___54 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___48 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___227 *mod;
};

struct bpf_jit_poke_descriptor___54 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___55 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___54 {
	struct btf *btf;
	struct module___227 *module;
};

struct bpf_link_ops___5;

struct bpf_link___5 {
	atomic64_t refcnt;
	u32 id;
	enum bpf_link_type type;
	const struct bpf_link_ops___5 *ops;
	struct bpf_prog___48 *prog;
	struct work_struct work;
};

struct bpf_link_ops___5 {
	void (*release)(struct bpf_link___5 *);
	void (*dealloc)(struct bpf_link___5 *);
	int (*detach)(struct bpf_link___5 *);
	int (*update_prog)(struct bpf_link___5 *, struct bpf_prog___48 *, struct bpf_prog___48 *);
	void (*show_fdinfo)(const struct bpf_link___5 *, struct seq_file___218 *);
	int (*fill_link_info)(const struct bpf_link___5 *, struct bpf_link_info *);
};

struct bpf_link_primer___3 {
	struct bpf_link___5 *link;
	struct file___243 *file;
	int fd;
	u32 id;
};

struct cftype___170;

struct cgroup_subsys___170 {
	struct cgroup_subsys_state___170 * (*css_alloc)(struct cgroup_subsys_state___170 *);
	int (*css_online)(struct cgroup_subsys_state___170 *);
	void (*css_offline)(struct cgroup_subsys_state___170 *);
	void (*css_released)(struct cgroup_subsys_state___170 *);
	void (*css_free)(struct cgroup_subsys_state___170 *);
	void (*css_reset)(struct cgroup_subsys_state___170 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___170 *, int);
	int (*css_extra_stat_show)(struct seq_file___218 *, struct cgroup_subsys_state___170 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___250 *, struct css_set___170 *);
	void (*cancel_fork)(struct task_struct___250 *, struct css_set___170 *);
	void (*fork)(struct task_struct___250 *);
	void (*exit)(struct task_struct___250 *);
	void (*release)(struct task_struct___250 *);
	void (*bind)(struct cgroup_subsys_state___170 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___170 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___170 *dfl_cftypes;
	struct cftype___170 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___170 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___170 *updated_children;
	struct cgroup___170 *updated_next;
};

struct cgroup_root___170 {
	struct kernfs_root___231 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___170 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___170 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___170 *ss;
	struct list_head node;
	struct kernfs_ops___231 *kf_ops;
	int (*open)(struct kernfs_open_file___231 *);
	void (*release)(struct kernfs_open_file___231 *);
	u64 (*read_u64)(struct cgroup_subsys_state___170 *, struct cftype___170 *);
	s64 (*read_s64)(struct cgroup_subsys_state___170 *, struct cftype___170 *);
	int (*seq_show)(struct seq_file___218 *, void *);
	void * (*seq_start)(struct seq_file___218 *, loff_t *);
	void * (*seq_next)(struct seq_file___218 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___218 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___170 *, struct cftype___170 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___170 *, struct cftype___170 *, s64);
	ssize_t (*write)(struct kernfs_open_file___231 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___231 *, struct poll_table_struct___166 *);
};

struct xdp_rxq_info___52 {
	struct net_device___6 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___52 {
	struct net_device___6 *dev;
};

struct xdp_buff___52 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___52 *rxq;
	struct xdp_txq_info___52 *txq;
	u32 frame_sz;
};

struct xdp_frame___52 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___6 *dev_rx;
};

struct netlink_callback___52 {
	struct sk_buff___53 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___53 *, struct netlink_callback___52 *);
	int (*done)(struct netlink_callback___52 *);
	void *data;
	struct module___227 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ifbond {
	__s32 bond_mode;
	__s32 num_slaves;
	__s32 miimon;
};

typedef struct ifbond ifbond;

struct ifslave {
	__s32 slave_id;
	char slave_name[16];
	__s8 link;
	__s8 state;
	__u32 link_failure_count;
};

typedef struct ifslave ifslave;

struct header_ops___52 {
	int (*create)(struct sk_buff___53 *, struct net_device___6 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___53 *, unsigned char *);
	int (*cache)(const struct neighbour___41 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___6 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___53 *);
};

struct napi_struct___9 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___9 *, int);
	int poll_owner;
	struct net_device___6 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___53 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___250 *thread;
};

enum {
	NAPIF_STATE_SCHED = 1,
	NAPIF_STATE_MISSED = 2,
	NAPIF_STATE_DISABLE = 4,
	NAPIF_STATE_NPSVC = 8,
	NAPIF_STATE_LISTED = 16,
	NAPIF_STATE_NO_BUSY_POLL = 32,
	NAPIF_STATE_IN_BUSY_POLL = 64,
	NAPIF_STATE_PREFER_BUSY_POLL = 128,
	NAPIF_STATE_THREADED = 256,
	NAPIF_STATE_SCHED_THREADED = 512,
};

struct netdev_queue___52 {
	struct net_device___6 *dev;
	struct Qdisc___48 *qdisc;
	struct Qdisc___48 *qdisc_sleeping;
	struct kobject___231 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___6 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___48 {
	struct sk_buff___53 *head;
	struct sk_buff___53 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___48;

struct Qdisc___48 {
	int (*enqueue)(struct sk_buff___53 *, struct Qdisc___48 *, struct sk_buff___53 **);
	struct sk_buff___53 * (*dequeue)(struct Qdisc___48 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___48 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___52 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___52 gso_skb;
	struct qdisc_skb_head___48 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___48 *next_sched;
	struct sk_buff_head___52 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___52 {
	struct xdp_rxq_info___52 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___231 kobj;
	struct net_device___6 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___52 {
	enum net_device_path_type type;
	const struct net_device___6 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___52 = 0,
				DEV_PATH_BR_VLAN_TAG___52 = 1,
				DEV_PATH_BR_VLAN_UNTAG___52 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___52 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_stack {
	int num_paths;
	struct net_device_path___52 path[5];
};

struct net_device_path_ctx___52 {
	const struct net_device___6 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct bpf_xdp_link {
	struct bpf_link___5 link;
	struct net_device___6 *dev;
	int flags;
};

struct netdev_bpf___52 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___48 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___52 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___52 {
	int (*xdo_dev_state_add)(struct xfrm_state___4 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___4 *);
	void (*xdo_dev_state_free)(struct xfrm_state___4 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___53 *, struct xfrm_state___4 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___4 *);
};

struct xfrm_state_offload___4 {
	struct net_device___6 *dev;
	struct net_device___6 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___4;

struct xfrm_type_offload___4;

struct xfrm_state___4 {
	possible_net_t___52 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___42 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___4 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___4 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___248 xfrag;
	const struct xfrm_type___4 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___4 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___52 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___6 *dev;
	const char *name;
};

struct netdev_net_notifier {
	struct list_head list;
	struct notifier_block *nb;
};

struct devlink_port___3;

struct net_device_ops___52 {
	int (*ndo_init)(struct net_device___6 *);
	void (*ndo_uninit)(struct net_device___6 *);
	int (*ndo_open)(struct net_device___6 *);
	int (*ndo_stop)(struct net_device___6 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___53 *, struct net_device___6 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___53 *, struct net_device___6 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___6 *, struct sk_buff___53 *, struct net_device___6 *);
	void (*ndo_change_rx_flags)(struct net_device___6 *, int);
	void (*ndo_set_rx_mode)(struct net_device___6 *);
	int (*ndo_set_mac_address)(struct net_device___6 *, void *);
	int (*ndo_validate_addr)(struct net_device___6 *);
	int (*ndo_do_ioctl)(struct net_device___6 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___6 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___6 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___6 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___6 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___6 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___6 *, int);
	int (*ndo_neigh_setup)(struct net_device___6 *, struct neigh_parms___41 *);
	void (*ndo_tx_timeout)(struct net_device___6 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___6 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___6 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___6 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___6 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___6 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___6 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___6 *);
	int (*ndo_netpoll_setup)(struct net_device___6 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___6 *);
	int (*ndo_set_vf_mac)(struct net_device___6 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___6 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___6 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___6 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___6 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___6 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___6 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___6 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___6 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___6 *, int, struct sk_buff___53 *);
	int (*ndo_get_vf_guid)(struct net_device___6 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___6 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___6 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___6 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___6 *);
	int (*ndo_fcoe_disable)(struct net_device___6 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___6 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___6 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___6 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___6 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___6 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___6 *, const struct sk_buff___53 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___6 *, struct net_device___6 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___6 *, struct net_device___6 *);
	struct net_device___6 * (*ndo_get_xmit_slave)(struct net_device___6 *, struct sk_buff___53 *, bool);
	struct net_device___6 * (*ndo_sk_get_lower_dev)(struct net_device___6 *, struct sock___42 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___6 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___6 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___6 *, struct neighbour___41 *);
	void (*ndo_neigh_destroy)(struct net_device___6 *, struct neighbour___41 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___53 *, struct netlink_callback___52 *, struct net_device___6 *, struct net_device___6 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___53 *, struct nlattr **, struct net_device___6 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___6 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___53 *, u32, u32, struct net_device___6 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___6 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___6 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___6 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___6 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___6 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___6 *, struct net_device___6 *);
	void (*ndo_dfwd_del_station)(struct net_device___6 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___6 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___6 *);
	int (*ndo_change_proto_down)(struct net_device___6 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___6 *, struct sk_buff___53 *);
	void (*ndo_set_rx_headroom)(struct net_device___6 *, int);
	int (*ndo_bpf)(struct net_device___6 *, struct netdev_bpf___52 *);
	int (*ndo_xdp_xmit)(struct net_device___6 *, int, struct xdp_frame___52 **, u32);
	struct net_device___6 * (*ndo_xdp_get_xmit_slave)(struct net_device___6 *, struct xdp_buff___52 *);
	int (*ndo_xsk_wakeup)(struct net_device___6 *, u32, u32);
	struct devlink_port___3 * (*ndo_get_devlink_port)(struct net_device___6 *);
	int (*ndo_tunnel_ctl)(struct net_device___6 *, struct ip_tunnel_parm *, int);
	struct net_device___6 * (*ndo_get_peer_dev)(struct net_device___6 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___52 *, struct net_device_path___52 *);
};

struct neigh_parms___41 {
	possible_net_t___52 net;
	struct net_device___6 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___41 *);
	struct neigh_table___41 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll;

struct netpoll_info {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___52 txq;
	struct delayed_work tx_work;
	struct netpoll *netpoll;
	struct callback_head rcu;
};

struct devlink___3;

struct devlink_rate___3;

struct devlink_port___3 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___3 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set: 1;
	u8 switch_port: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___3 *devlink_rate;
};

typedef int (*iw_handler___2)(struct net_device___6 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___2 {
	const iw_handler___2 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___2 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___6 *);
};

struct ethtool_ops___24 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___6 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___6 *);
	void (*get_regs)(struct net_device___6 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___6 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___6 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___6 *);
	void (*set_msglevel)(struct net_device___6 *, u32);
	int (*nway_reset)(struct net_device___6 *);
	u32 (*get_link)(struct net_device___6 *);
	int (*get_link_ext_state)(struct net_device___6 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___6 *);
	int (*get_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___6 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___6 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___6 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___6 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___6 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___6 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___6 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___6 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___6 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___6 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___6 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___6 *);
	void (*complete)(struct net_device___6 *);
	u32 (*get_priv_flags)(struct net_device___6 *);
	int (*set_priv_flags)(struct net_device___6 *, u32);
	int (*get_sset_count)(struct net_device___6 *, int);
	int (*get_rxnfc)(struct net_device___6 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___6 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___6 *, struct ethtool_flash *);
	int (*reset)(struct net_device___6 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___6 *);
	u32 (*get_rxfh_indir_size)(struct net_device___6 *);
	int (*get_rxfh)(struct net_device___6 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___6 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___6 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___6 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___6 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___6 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___6 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___6 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___6 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___6 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___6 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___6 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___6 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___6 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___6 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___6 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___6 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___6 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___6 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___6 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___6 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___6 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___6 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___6 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___6 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___6 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___6 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___6 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___6 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___6 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___6 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___41 {
	u32 (*l3mdev_fib_table)(const struct net_device___6 *);
	struct sk_buff___53 * (*l3mdev_l3_rcv)(struct net_device___6 *, struct sk_buff___53 *, u16);
	struct sk_buff___53 * (*l3mdev_l3_out)(struct net_device___6 *, struct sock___42 *, struct sk_buff___53 *, u16);
	struct dst_entry___41 * (*l3mdev_link_scope_lookup)(const struct net_device___6 *, struct flowi6 *);
};

struct ndisc_ops___28 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___6 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___6 *, struct neighbour___41 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___6 *, u8, struct neighbour___41 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___6 *, struct sk_buff___53 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___57 *, struct net_device___6 *, const struct prefix_info *, struct inet6_dev___28 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct phylink_config___3 {
	struct device___224 *dev;
	enum phylink_op_type type;
	bool pcs_poll;
	bool poll_fixed_state;
	bool ovr_an_inband;
	void (*get_fixed_state)(struct phylink_config___3 *, struct phylink_link_state *);
};

struct dsa_device_ops___3;

struct dsa_switch_tree___3;

struct dsa_switch___3;

struct dsa_netdevice_ops___3;

struct dsa_port___3 {
	union {
		struct net_device___6 *master;
		struct net_device___6 *slave;
	};
	const struct dsa_device_ops___3 *tag_ops;
	struct dsa_switch_tree___3 *dst;
	struct sk_buff___53 * (*rcv)(struct sk_buff___53 *, struct net_device___6 *);
	enum {
		DSA_PORT_TYPE_UNUSED___3 = 0,
		DSA_PORT_TYPE_CPU___3 = 1,
		DSA_PORT_TYPE_DSA___3 = 2,
		DSA_PORT_TYPE_USER___3 = 3,
	} type;
	struct dsa_switch___3 *ds;
	unsigned int index;
	const char *name;
	struct dsa_port___3 *cpu_dp;
	u8 mac[6];
	struct device_node___101 *dn;
	unsigned int ageing_time;
	bool vlan_filtering;
	bool learning;
	u8 stp_state;
	struct net_device___6 *bridge_dev;
	int bridge_num;
	struct devlink_port___3 devlink_port;
	bool devlink_port_setup;
	struct phylink *pl;
	struct phylink_config___3 pl_config;
	struct net_device___6 *lag_dev;
	bool lag_tx_enabled;
	struct net_device___6 *hsr_dev;
	struct list_head list;
	void *priv;
	const struct ethtool_ops___24 *orig_ethtool_ops;
	const struct dsa_netdevice_ops___3 *netdev_ops;
	struct list_head fdbs;
	struct list_head mdbs;
	bool setup;
};

struct in_ifaddr;

struct ip_mc_list;

struct in_device {
	struct net_device___6 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___41 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___28;

struct ifacaddr6___6;

struct inet6_dev___28 {
	struct net_device___6 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___28 *mc_list;
	struct ifmcaddr6___28 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___52 mc_query_queue;
	struct sk_buff_head___52 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___6 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___41 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___48;

struct tcf_block___48;

struct mini_Qdisc___48 {
	struct tcf_proto___48 *filter_list;
	struct tcf_block___48 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct cpu_rmap {
	struct kref refcount;
	u16 size;
	u16 used;
	void **obj;
	struct {
		u16 index;
		u16 dist;
	} near[0];
};

struct rtnl_link_ops___48 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___6 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___6 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___57 *, struct net_device___6 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___6 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___6 *, struct list_head *);
	size_t (*get_size)(const struct net_device___6 *);
	int (*fill_info)(struct sk_buff___53 *, const struct net_device___6 *);
	size_t (*get_xstats_size)(const struct net_device___6 *);
	int (*fill_xstats)(struct sk_buff___53 *, const struct net_device___6 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___6 *, struct net_device___6 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___6 *, const struct net_device___6 *);
	int (*fill_slave_info)(struct sk_buff___53 *, const struct net_device___6 *, const struct net_device___6 *);
	struct net___57 * (*get_link_net)(const struct net_device___6 *);
	size_t (*get_linkxstats_size)(const struct net_device___6 *, int);
	int (*fill_linkxstats)(struct sk_buff___53 *, const struct net_device___6 *, int *, int);
};

struct mii_bus___11;

struct mdio_device___11 {
	struct device___224 dev;
	struct mii_bus___11 *bus;
	char modalias[32];
	int (*bus_match)(struct device___224 *, struct device_driver___224 *);
	void (*device_free)(struct mdio_device___11 *);
	void (*device_remove)(struct mdio_device___11 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___8;

struct mii_timestamper___8;

struct phy_device___8 {
	struct mdio_device___11 mdio;
	struct phy_driver___8 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45;
	unsigned int is_internal;
	unsigned int is_pseudo_fixed_link;
	unsigned int is_gigabit_capable;
	unsigned int has_fixups;
	unsigned int suspended;
	unsigned int suspended_by_mdio_bus;
	unsigned int sysfs_links;
	unsigned int loopback_enabled;
	unsigned int downshifted_rate;
	unsigned int is_on_sfp_module;
	unsigned int mac_managed_pm;
	unsigned int autoneg;
	unsigned int link;
	unsigned int autoneg_complete;
	unsigned int interrupts;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___53 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___6 *attached_dev;
	struct mii_timestamper___8 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___8 *, bool);
	void (*adjust_link)(struct net_device___6 *);
	const struct macsec_ops *macsec_ops;
};

struct napi_gro_cb___2 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___53 *last;
};

struct packet_type {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___6 *dev;
	int (*func)(struct sk_buff___53 *, struct net_device___6 *, struct packet_type *, struct net_device___6 *);
	void (*list_func)(struct list_head *, struct packet_type *, struct net_device___6 *);
	bool (*id_match)(struct packet_type *, struct sock___42 *);
	struct net___57 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct offload_callbacks {
	struct sk_buff___53 * (*gso_segment)(struct sk_buff___53 *, netdev_features_t);
	struct sk_buff___53 * (*gro_receive)(struct list_head *, struct sk_buff___53 *);
	int (*gro_complete)(struct sk_buff___53 *, int);
};

struct packet_offload {
	__be16 type;
	u16 priority;
	struct offload_callbacks callbacks;
	struct list_head list;
};

struct netdev_notifier_info___6 {
	struct net_device___6 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_info_ext {
	struct netdev_notifier_info___6 info;
	union {
		u32 mtu;
	} ext;
};

struct netdev_notifier_change_info {
	struct netdev_notifier_info___6 info;
	unsigned int flags_changed;
};

struct netdev_notifier_changeupper_info___3 {
	struct netdev_notifier_info___6 info;
	struct net_device___6 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct netdev_notifier_changelowerstate_info {
	struct netdev_notifier_info___6 info;
	void *lower_state_info;
};

struct netdev_notifier_pre_changeaddr_info {
	struct netdev_notifier_info___6 info;
	const unsigned char *dev_addr;
};

struct softnet_data___3 {
	struct list_head poll_list;
	struct sk_buff_head___52 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___3 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___48 *output_queue;
	struct Qdisc___48 **output_queue_tailp;
	struct sk_buff___53 *completion_queue;
	struct sk_buff_head___52 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___3 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___52 input_pkt_queue;
	struct napi_struct___9 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef int (*bpf_op_t)(struct net_device___6 *, struct netdev_bpf___52 *);

enum {
	NESTED_SYNC_IMM_BIT = 0,
	NESTED_SYNC_TODO_BIT = 1,
};

struct netdev_nested_priv {
	unsigned char flags;
	void *data;
};

struct netdev_bonding_info {
	ifslave slave;
	ifbond master;
};

struct netdev_notifier_bonding_info {
	struct netdev_notifier_info___6 info;
	struct netdev_bonding_info bonding_info;
};

struct flow_action_entry___3 {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___6 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info___2 *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action___3 {
	unsigned int num_entries;
	struct flow_action_entry___3 entries[0];
};

struct flow_rule___3 {
	struct flow_match match;
	struct flow_action___3 action;
};

union inet_addr {
	__u32 all[4];
	__be32 ip;
	__be32 ip6[4];
	struct in_addr in;
	struct in6_addr in6;
};

struct netpoll {
	struct net_device___6 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
};

struct gnet_dump___48 {
	spinlock_t *lock;
	struct sk_buff___53 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct flow_cls_offload___3 {
	struct flow_cls_common_offload common;
	enum flow_cls_command command;
	long unsigned int cookie;
	struct flow_rule___3 *rule;
	struct flow_stats stats;
	u32 classid;
};

enum qdisc_state_t {
	__QDISC_STATE_SCHED = 0,
	__QDISC_STATE_DEACTIVATED = 1,
	__QDISC_STATE_MISSED = 2,
	__QDISC_STATE_DRAINING = 3,
};

struct Qdisc_class_ops___48;

struct Qdisc_ops___48 {
	struct Qdisc_ops___48 *next;
	const struct Qdisc_class_ops___48 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___53 *, struct Qdisc___48 *, struct sk_buff___53 **);
	struct sk_buff___53 * (*dequeue)(struct Qdisc___48 *);
	struct sk_buff___53 * (*peek)(struct Qdisc___48 *);
	int (*init)(struct Qdisc___48 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___48 *);
	void (*destroy)(struct Qdisc___48 *);
	int (*change)(struct Qdisc___48 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___48 *);
	int (*change_tx_queue_len)(struct Qdisc___48 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___48 *, unsigned int);
	int (*dump)(struct Qdisc___48 *, struct sk_buff___53 *);
	int (*dump_stats)(struct Qdisc___48 *, struct gnet_dump___48 *);
	void (*ingress_block_set)(struct Qdisc___48 *, u32);
	void (*egress_block_set)(struct Qdisc___48 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___48 *);
	u32 (*egress_block_get)(struct Qdisc___48 *);
	struct module___227 *owner;
};

struct qdisc_walker___3;

struct Qdisc_class_ops___48 {
	unsigned int flags;
	struct netdev_queue___52 * (*select_queue)(struct Qdisc___48 *, struct tcmsg *);
	int (*graft)(struct Qdisc___48 *, long unsigned int, struct Qdisc___48 *, struct Qdisc___48 **, struct netlink_ext_ack *);
	struct Qdisc___48 * (*leaf)(struct Qdisc___48 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___48 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___48 *, u32);
	int (*change)(struct Qdisc___48 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___48 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___48 *, struct qdisc_walker___3 *);
	struct tcf_block___48 * (*tcf_block)(struct Qdisc___48 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___48 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___48 *, long unsigned int);
	int (*dump)(struct Qdisc___48 *, long unsigned int, struct sk_buff___53 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___48 *, long unsigned int, struct gnet_dump___48 *);
};

struct qdisc_walker___3 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___48 *, long unsigned int, struct qdisc_walker___3 *);
};

struct tcf_chain___48;

struct tcf_block___48 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___57 *net;
	struct Qdisc___48 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___48 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___48;

struct tcf_proto_ops___48;

struct tcf_proto___48 {
	struct tcf_proto___48 *next;
	void *root;
	int (*classify)(struct sk_buff___53 *, const struct tcf_proto___48 *, struct tcf_result___48 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___48 *ops;
	struct tcf_chain___48 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___48 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___48 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___48 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___53 *, const struct tcf_proto___48 *, struct tcf_result___48 *);
	int (*init)(struct tcf_proto___48 *);
	void (*destroy)(struct tcf_proto___48 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___48 *, u32);
	void (*put)(struct tcf_proto___48 *, void *);
	int (*change)(struct net___57 *, struct sk_buff___53 *, struct tcf_proto___48 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___48 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___48 *);
	void (*walk)(struct tcf_proto___48 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___48 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___48 *, void *);
	void (*hw_del)(struct tcf_proto___48 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___57 *, struct tcf_chain___48 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___57 *, struct tcf_proto___48 *, void *, struct sk_buff___53 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___57 *, struct tcf_proto___48 *, void *, struct sk_buff___53 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___53 *, struct net___57 *, void *);
	struct module___227 *owner;
	int flags;
};

struct tcf_walker {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___48 *, void *, struct tcf_walker *);
};

struct tcf_chain___48 {
	struct mutex filter_chain_lock;
	struct tcf_proto___48 *filter_chain;
	struct list_head list;
	struct tcf_block___48 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___48 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___41 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___48 *prog;
};

struct block_device_operations___136;

struct gendisk___139 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___139 *part0;
	const struct block_device_operations___136 *fops;
	struct request_queue___136 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___122 *bdi;
	struct kobject___231 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___231 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___136 {
	struct bio___136 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___160 *bip_vec;
	struct bio_vec___160 bip_inline_vecs[0];
};

struct blkcg___124;

struct blkg_policy_data___124;

struct blkcg_gq___124 {
	struct request_queue___136 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___124 *blkcg;
	struct blkcg_gq___124 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___124 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___136 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___136(struct request___136 *);

typedef void integrity_complete_fn___136(struct request___136 *, unsigned int);

struct blk_integrity_profile___136 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___136 *prepare_fn;
	integrity_complete_fn___136 *complete_fn;
	const char *name;
};

struct block_device_operations___136 {
	blk_qc_t (*submit_bio)(struct bio___136 *);
	int (*open)(struct block_device___139 *, fmode_t);
	void (*release)(struct gendisk___139 *, fmode_t);
	int (*rw_page)(struct block_device___139 *, sector_t, struct page___248 *, unsigned int);
	int (*ioctl)(struct block_device___139 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___139 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___139 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___139 *);
	int (*getgeo)(struct block_device___139 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___139 *, bool);
	void (*swap_slot_free_notify)(struct block_device___139 *, long unsigned int);
	int (*report_zones)(struct gendisk___139 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___139 *, umode_t *);
	struct module___227 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___139 *, sector_t *);
};

typedef void rq_end_io_fn___136(struct request___136 *, blk_status_t);

struct request___136 {
	struct request_queue___136 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___131 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___136 *bio;
	struct bio___136 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___160 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___136 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___136 *saved_end_io;
		} flush;
	};
	struct gendisk___139 *rq_disk;
	struct block_device___139 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___136 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___131 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___136 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___231 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___243 *debugfs_dir;
	struct dentry___243 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___136;

struct elevator_mq_ops___136 {
	int (*init_sched)(struct request_queue___136 *, struct elevator_type___136 *);
	void (*exit_sched)(struct elevator_queue___136 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___131 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___131 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___131 *);
	bool (*allow_merge)(struct request_queue___136 *, struct request___136 *, struct bio___136 *);
	bool (*bio_merge)(struct request_queue___136 *, struct bio___136 *, unsigned int);
	int (*request_merge)(struct request_queue___136 *, struct request___136 **, struct bio___136 *);
	void (*request_merged)(struct request_queue___136 *, struct request___136 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___136 *, struct request___136 *, struct request___136 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___136 *);
	void (*finish_request)(struct request___136 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___131 *, struct list_head *, bool);
	struct request___136 * (*dispatch_request)(struct blk_mq_hw_ctx___131 *);
	bool (*has_work)(struct blk_mq_hw_ctx___131 *);
	void (*completed_request)(struct request___136 *, u64);
	void (*requeue_request)(struct request___136 *);
	struct request___136 * (*former_request)(struct request_queue___136 *, struct request___136 *);
	struct request___136 * (*next_request)(struct request_queue___136 *, struct request___136 *);
	void (*init_icq)(struct io_cq___136 *);
	void (*exit_icq)(struct io_cq___136 *);
};

struct elv_fs_entry___136;

struct elevator_type___136 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___136 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___136 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___227 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___136 {
	struct elevator_type___136 *type;
	void *elevator_data;
	struct kobject___231 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___136 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___136 *, char *);
	ssize_t (*store)(struct elevator_queue___136 *, const char *, size_t);
};

struct blk_mq_queue_data___131;

struct blk_mq_ops___131 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___131 *, const struct blk_mq_queue_data___131 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___131 *);
	int (*get_budget)(struct request_queue___136 *);
	void (*put_budget)(struct request_queue___136 *, int);
	void (*set_rq_budget_token)(struct request___136 *, int);
	int (*get_rq_budget_token)(struct request___136 *);
	enum blk_eh_timer_return (*timeout)(struct request___136 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___131 *);
	void (*complete)(struct request___136 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___131 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___131 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___131 *, struct request___136 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___131 *, struct request___136 *, unsigned int);
	void (*initialize_rq_fn)(struct request___136 *);
	void (*cleanup_rq)(struct request___136 *);
	bool (*busy)(struct request_queue___136 *);
	int (*map_queues)(struct blk_mq_tag_set___131 *);
	void (*show_rq)(struct seq_file___218 *, struct request___136 *);
};

struct blk_mq_tag_set___131 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___131 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___131 {
	struct request___136 *rq;
	bool last;
};

struct blkcg_policy_data___124;

struct blkcg___124 {
	struct cgroup_subsys_state___170 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___124 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___124 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___124 {
	struct blkcg___124 *blkcg;
	int plid;
};

struct blkg_policy_data___124 {
	struct blkcg_gq___124 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___110 {
	struct mem_cgroup___110 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___110 {
	struct lruvec___118 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___110 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___110 *memcg;
};

struct obj_cgroup___110 {
	struct percpu_ref refcnt;
	struct mem_cgroup___110 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___41;

struct neigh_hash_table___41;

struct neigh_table___41 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___6 *, __u32 *);
	bool (*key_eq)(const struct neighbour___41 *, const void *);
	int (*constructor)(struct neighbour___41 *);
	int (*pconstructor)(struct pneigh_entry___41 *);
	void (*pdestructor)(struct pneigh_entry___41 *);
	void (*proxy_redo)(struct sk_buff___53 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___6 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___41 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___52 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___41 *nht;
	struct pneigh_entry___41 **phash_buckets;
};

struct neigh_ops___41 {
	int family;
	void (*solicit)(struct neighbour___41 *, struct sk_buff___53 *);
	void (*error_report)(struct neighbour___41 *, struct sk_buff___53 *);
	int (*output)(struct neighbour___41 *, struct sk_buff___53 *);
	int (*connected_output)(struct neighbour___41 *, struct sk_buff___53 *);
};

struct pneigh_entry___41 {
	struct pneigh_entry___41 *next;
	possible_net_t___52 net;
	struct net_device___6 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___41 {
	struct neighbour___41 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___23 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___57 *, struct sock___42 *, struct sk_buff___53 *);
	int (*orig_input)(struct sk_buff___53 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___41 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___41 *ctarget;
	struct net___57 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___41 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___41 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___30;

struct timewait_sock_ops___30;

struct proto___41 {
	void (*close)(struct sock___42 *, long int);
	int (*pre_connect)(struct sock___42 *, struct sockaddr *, int);
	int (*connect)(struct sock___42 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___42 *, int);
	struct sock___42 * (*accept)(struct sock___42 *, int, int *, bool);
	int (*ioctl)(struct sock___42 *, int, long unsigned int);
	int (*init)(struct sock___42 *);
	void (*destroy)(struct sock___42 *);
	void (*shutdown)(struct sock___42 *, int);
	int (*setsockopt)(struct sock___42 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___42 *, int, int, char *, int *);
	void (*keepalive)(struct sock___42 *, int);
	int (*compat_ioctl)(struct sock___42 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___42 *, struct msghdr___43 *, size_t);
	int (*recvmsg)(struct sock___42 *, struct msghdr___43 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___42 *, struct page___248 *, int, size_t, int);
	int (*bind)(struct sock___42 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___42 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___42 *, struct sk_buff___53 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___42 *);
	int (*hash)(struct sock___42 *);
	void (*unhash)(struct sock___42 *);
	void (*rehash)(struct sock___42 *);
	int (*get_port)(struct sock___42 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___42 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___42 *, int);
	bool (*sock_is_readable)(struct sock___42 *);
	void (*enter_memory_pressure)(struct sock___42 *);
	void (*leave_memory_pressure)(struct sock___42 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___30 *rsk_prot;
	struct timewait_sock_ops___30 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___227 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___42 *, int);
};

struct xfrm_policy_queue___4 {
	struct sk_buff_head___52 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___4 {
	possible_net_t___52 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___4 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct request_sock___31;

struct request_sock_ops___30 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___42 *, struct request_sock___31 *);
	void (*send_ack)(const struct sock___42 *, struct sk_buff___53 *, struct request_sock___31 *);
	void (*send_reset)(const struct sock___42 *, struct sk_buff___53 *);
	void (*destructor)(struct request_sock___31 *);
	void (*syn_ack_timeout)(const struct request_sock___31 *);
};

struct timewait_sock_ops___30 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___42 *, struct sock___42 *, void *);
	void (*twsk_destructor)(struct sock___42 *);
};

enum {
	IPV4_DEVCONF_FORWARDING = 1,
	IPV4_DEVCONF_MC_FORWARDING = 2,
	IPV4_DEVCONF_PROXY_ARP = 3,
	IPV4_DEVCONF_ACCEPT_REDIRECTS = 4,
	IPV4_DEVCONF_SECURE_REDIRECTS = 5,
	IPV4_DEVCONF_SEND_REDIRECTS = 6,
	IPV4_DEVCONF_SHARED_MEDIA = 7,
	IPV4_DEVCONF_RP_FILTER = 8,
	IPV4_DEVCONF_ACCEPT_SOURCE_ROUTE = 9,
	IPV4_DEVCONF_BOOTP_RELAY = 10,
	IPV4_DEVCONF_LOG_MARTIANS = 11,
	IPV4_DEVCONF_TAG = 12,
	IPV4_DEVCONF_ARPFILTER = 13,
	IPV4_DEVCONF_MEDIUM_ID = 14,
	IPV4_DEVCONF_NOXFRM = 15,
	IPV4_DEVCONF_NOPOLICY = 16,
	IPV4_DEVCONF_FORCE_IGMP_VERSION = 17,
	IPV4_DEVCONF_ARP_ANNOUNCE = 18,
	IPV4_DEVCONF_ARP_IGNORE = 19,
	IPV4_DEVCONF_PROMOTE_SECONDARIES = 20,
	IPV4_DEVCONF_ARP_ACCEPT = 21,
	IPV4_DEVCONF_ARP_NOTIFY = 22,
	IPV4_DEVCONF_ACCEPT_LOCAL = 23,
	IPV4_DEVCONF_SRC_VMARK = 24,
	IPV4_DEVCONF_PROXY_ARP_PVLAN = 25,
	IPV4_DEVCONF_ROUTE_LOCALNET = 26,
	IPV4_DEVCONF_IGMPV2_UNSOLICITED_REPORT_INTERVAL = 27,
	IPV4_DEVCONF_IGMPV3_UNSOLICITED_REPORT_INTERVAL = 28,
	IPV4_DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN = 29,
	IPV4_DEVCONF_DROP_UNICAST_IN_L2_MULTICAST = 30,
	IPV4_DEVCONF_DROP_GRATUITOUS_ARP = 31,
	IPV4_DEVCONF_BC_FORWARDING = 32,
	__IPV4_DEVCONF_MAX = 33,
};

struct request_sock___31 {
	struct sock_common___41 __req_common;
	struct request_sock___31 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___30 *rsk_ops;
	struct sock___42 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___28 {
	struct in6_addr mca_addr;
	struct inet6_dev___28 *idev;
	struct ifmcaddr6___28 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___6 {
	struct in6_addr aca_addr;
	struct fib6_info___6 *aca_rt;
	struct ifacaddr6___6 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___6 {
	struct fib_nh_exception___6 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___6 *fnhe_rth_input;
	struct rtable___6 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___6 {
	struct dst_entry___41 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___6 {
	struct fib_nh_exception___6 *chain;
};

struct fib_info___3;

struct fib_nh___3 {
	struct fib_nh_common___6 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___3 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___3 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___57 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop *nh;
	struct callback_head rcu;
	struct fib_nh___3 fib_nh[0];
};

struct nh_info___3;

struct nh_group___3;

struct nexthop {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___57 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___3 *nh_info;
		struct nh_group___3 *nh_grp;
	};
};

struct property___75 {
	char *name;
	int length;
	void *value;
	struct property___75 *next;
	long unsigned int _flags;
	struct bin_attribute___231 attr;
};

struct mii_bus___11 {
	struct module___227 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___11 *, int, int);
	int (*write)(struct mii_bus___11 *, int, int, u16);
	int (*reset)(struct mii_bus___11 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___224 *parent;
	enum {
		MDIOBUS_ALLOCATED___11 = 1,
		MDIOBUS_REGISTERED___11 = 2,
		MDIOBUS_UNREGISTERED___11 = 3,
		MDIOBUS_RELEASED___11 = 4,
	} state;
	struct device___224 dev;
	struct mdio_device___11 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___11 = 0,
		MDIOBUS_C22___11 = 1,
		MDIOBUS_C45___11 = 2,
		MDIOBUS_C22_C45___11 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___10 {
	struct device_driver___224 driver;
	int flags;
};

struct mii_timestamper___8 {
	bool (*rxtstamp)(struct mii_timestamper___8 *, struct sk_buff___53 *, int);
	void (*txtstamp)(struct mii_timestamper___8 *, struct sk_buff___53 *, int);
	int (*hwtstamp)(struct mii_timestamper___8 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___8 *, struct phy_device___8 *);
	int (*ts_info)(struct mii_timestamper___8 *, struct ethtool_ts_info *);
	struct device___224 *device;
};

struct phy_driver___8 {
	struct mdio_driver_common___10 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___8 *);
	int (*config_init)(struct phy_device___8 *);
	int (*probe)(struct phy_device___8 *);
	int (*get_features)(struct phy_device___8 *);
	int (*suspend)(struct phy_device___8 *);
	int (*resume)(struct phy_device___8 *);
	int (*config_aneg)(struct phy_device___8 *);
	int (*aneg_done)(struct phy_device___8 *);
	int (*read_status)(struct phy_device___8 *);
	int (*config_intr)(struct phy_device___8 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___8 *);
	void (*remove)(struct phy_device___8 *);
	int (*match_phy_device)(struct phy_device___8 *);
	int (*set_wol)(struct phy_device___8 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___8 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___8 *);
	int (*read_mmd)(struct phy_device___8 *, int, u16);
	int (*write_mmd)(struct phy_device___8 *, int, u16, u16);
	int (*read_page)(struct phy_device___8 *);
	int (*write_page)(struct phy_device___8 *, int);
	int (*module_info)(struct phy_device___8 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___8 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___8 *);
	int (*cable_test_tdr_start)(struct phy_device___8 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___8 *, bool *);
	int (*get_sset_count)(struct phy_device___8 *);
	void (*get_strings)(struct phy_device___8 *, u8 *);
	void (*get_stats)(struct phy_device___8 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___8 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___8 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___8 *, bool);
	int (*get_sqi)(struct phy_device___8 *);
	int (*get_sqi_max)(struct phy_device___8 *);
};

struct dsa_chip_data___3 {
	struct device___224 *host_dev;
	int sw_addr;
	struct device___224 *netdev[12];
	int eeprom_len;
	struct device_node___101 *of_node;
	char *port_names[12];
	struct device_node___101 *port_dn[12];
	s8 rtable[4];
};

struct dsa_platform_data___3 {
	struct device___224 *netdev;
	struct net_device___6 *of_netdev;
	int nr_chips;
	struct dsa_chip_data___3 *chip;
};

struct devlink_ops___3;

struct devlink___3 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___3 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___224 *dev;
	possible_net_t___52 _net;
	struct mutex lock;
	u8 reload_failed: 1;
	u8 reload_enabled: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_ops___3 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___3 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___3 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___3 *, enum devlink_port_type);
	int (*port_split)(struct devlink___3 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___3 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___3 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___3 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___3 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___3 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___3 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___3 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___3 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___3 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___3 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___3 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___3 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___3 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___3 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___3 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___3 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___3 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___3 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___3 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___3 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___3 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___3 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___3 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___3 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___3 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___3 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___3 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___3 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___3 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___3 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___3 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___3 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___3 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___3 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___3 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___3 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___3 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___3 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___3 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___3 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___3 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___3 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___3 *, struct devlink_rate___3 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___3 *, struct devlink_rate___3 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___3 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___3 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___3 *parent;
	union {
		struct devlink_port___3 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct switchdev_obj___3 {
	struct list_head list;
	struct net_device___6 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___6 *, int, void *);
};

struct switchdev_obj_port_vlan___3 {
	struct switchdev_obj___3 obj;
	u16 flags;
	u16 vid;
};

struct switchdev_obj_port_mdb___3 {
	struct switchdev_obj___3 obj;
	unsigned char addr[6];
	u16 vid;
};

struct switchdev_obj_mrp___3 {
	struct switchdev_obj___3 obj;
	struct net_device___6 *p_port;
	struct net_device___6 *s_port;
	u32 ring_id;
	u16 prio;
};

struct switchdev_obj_ring_role_mrp___3 {
	struct switchdev_obj___3 obj;
	u8 ring_role;
	u32 ring_id;
	u8 sw_backup;
};

struct dsa_device_ops___3 {
	struct sk_buff___53 * (*xmit)(struct sk_buff___53 *, struct net_device___6 *);
	struct sk_buff___53 * (*rcv)(struct sk_buff___53 *, struct net_device___6 *);
	void (*flow_dissect)(const struct sk_buff___53 *, __be16 *, int *);
	unsigned int needed_headroom;
	unsigned int needed_tailroom;
	const char *name;
	enum dsa_tag_protocol proto;
	bool promisc_on_master;
};

struct dsa_netdevice_ops___3 {
	int (*ndo_eth_ioctl)(struct net_device___6 *, struct ifreq *, int);
};

struct dsa_switch_tree___3 {
	struct list_head list;
	struct raw_notifier_head nh;
	unsigned int index;
	struct kref refcount;
	bool setup;
	const struct dsa_device_ops___3 *tag_ops;
	enum dsa_tag_protocol default_proto;
	struct dsa_platform_data___3 *pd;
	struct list_head ports;
	struct list_head rtable;
	struct net_device___6 **lags;
	unsigned int lags_len;
	unsigned int last_switch;
};

struct dsa_switch_ops___3;

struct dsa_switch___3 {
	bool setup;
	struct device___224 *dev;
	struct dsa_switch_tree___3 *dst;
	unsigned int index;
	struct notifier_block nb;
	void *priv;
	struct dsa_chip_data___3 *cd;
	const struct dsa_switch_ops___3 *ops;
	u32 phys_mii_mask;
	struct mii_bus___11 *slave_mii_bus;
	unsigned int ageing_time_min;
	unsigned int ageing_time_max;
	struct dsa_8021q_context *tag_8021q_ctx;
	struct devlink___3 *devlink;
	unsigned int num_tx_queues;
	bool vlan_filtering_is_global;
	bool needs_standalone_vlan_filtering;
	bool configure_vlan_while_not_filtering;
	bool untag_bridge_pvid;
	bool assisted_learning_on_cpu_port;
	bool vlan_filtering;
	bool pcs_poll;
	bool mtu_enforcement_ingress;
	unsigned int num_lag_ids;
	unsigned int num_fwd_offloading_bridges;
	size_t num_ports;
};

struct dsa_switch_ops___3 {
	enum dsa_tag_protocol (*get_tag_protocol)(struct dsa_switch___3 *, int, enum dsa_tag_protocol);
	int (*change_tag_protocol)(struct dsa_switch___3 *, int, enum dsa_tag_protocol);
	int (*setup)(struct dsa_switch___3 *);
	void (*teardown)(struct dsa_switch___3 *);
	int (*port_setup)(struct dsa_switch___3 *, int);
	void (*port_teardown)(struct dsa_switch___3 *, int);
	u32 (*get_phy_flags)(struct dsa_switch___3 *, int);
	int (*phy_read)(struct dsa_switch___3 *, int, int);
	int (*phy_write)(struct dsa_switch___3 *, int, int, u16);
	void (*adjust_link)(struct dsa_switch___3 *, int, struct phy_device___8 *);
	void (*fixed_link_update)(struct dsa_switch___3 *, int, struct fixed_phy_status___2 *);
	void (*phylink_validate)(struct dsa_switch___3 *, int, long unsigned int *, struct phylink_link_state *);
	int (*phylink_mac_link_state)(struct dsa_switch___3 *, int, struct phylink_link_state *);
	void (*phylink_mac_config)(struct dsa_switch___3 *, int, unsigned int, const struct phylink_link_state *);
	void (*phylink_mac_an_restart)(struct dsa_switch___3 *, int);
	void (*phylink_mac_link_down)(struct dsa_switch___3 *, int, unsigned int, phy_interface_t);
	void (*phylink_mac_link_up)(struct dsa_switch___3 *, int, unsigned int, phy_interface_t, struct phy_device___8 *, int, int, bool, bool);
	void (*phylink_fixed_state)(struct dsa_switch___3 *, int, struct phylink_link_state *);
	void (*get_strings)(struct dsa_switch___3 *, int, u32, uint8_t *);
	void (*get_ethtool_stats)(struct dsa_switch___3 *, int, uint64_t *);
	int (*get_sset_count)(struct dsa_switch___3 *, int, int);
	void (*get_ethtool_phy_stats)(struct dsa_switch___3 *, int, uint64_t *);
	void (*get_stats64)(struct dsa_switch___3 *, int, struct rtnl_link_stats64 *);
	void (*self_test)(struct dsa_switch___3 *, int, struct ethtool_test *, u64 *);
	void (*get_wol)(struct dsa_switch___3 *, int, struct ethtool_wolinfo *);
	int (*set_wol)(struct dsa_switch___3 *, int, struct ethtool_wolinfo *);
	int (*get_ts_info)(struct dsa_switch___3 *, int, struct ethtool_ts_info *);
	int (*suspend)(struct dsa_switch___3 *);
	int (*resume)(struct dsa_switch___3 *);
	int (*port_enable)(struct dsa_switch___3 *, int, struct phy_device___8 *);
	void (*port_disable)(struct dsa_switch___3 *, int);
	int (*set_mac_eee)(struct dsa_switch___3 *, int, struct ethtool_eee *);
	int (*get_mac_eee)(struct dsa_switch___3 *, int, struct ethtool_eee *);
	int (*get_eeprom_len)(struct dsa_switch___3 *);
	int (*get_eeprom)(struct dsa_switch___3 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct dsa_switch___3 *, struct ethtool_eeprom *, u8 *);
	int (*get_regs_len)(struct dsa_switch___3 *, int);
	void (*get_regs)(struct dsa_switch___3 *, int, struct ethtool_regs *, void *);
	int (*port_prechangeupper)(struct dsa_switch___3 *, int, struct netdev_notifier_changeupper_info___3 *);
	int (*set_ageing_time)(struct dsa_switch___3 *, unsigned int);
	int (*port_bridge_join)(struct dsa_switch___3 *, int, struct net_device___6 *);
	void (*port_bridge_leave)(struct dsa_switch___3 *, int, struct net_device___6 *);
	int (*port_bridge_tx_fwd_offload)(struct dsa_switch___3 *, int, struct net_device___6 *, int);
	void (*port_bridge_tx_fwd_unoffload)(struct dsa_switch___3 *, int, struct net_device___6 *, int);
	void (*port_stp_state_set)(struct dsa_switch___3 *, int, u8);
	void (*port_fast_age)(struct dsa_switch___3 *, int);
	int (*port_pre_bridge_flags)(struct dsa_switch___3 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_bridge_flags)(struct dsa_switch___3 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_vlan_filtering)(struct dsa_switch___3 *, int, bool, struct netlink_ext_ack *);
	int (*port_vlan_add)(struct dsa_switch___3 *, int, const struct switchdev_obj_port_vlan___3 *, struct netlink_ext_ack *);
	int (*port_vlan_del)(struct dsa_switch___3 *, int, const struct switchdev_obj_port_vlan___3 *);
	int (*port_fdb_add)(struct dsa_switch___3 *, int, const unsigned char *, u16);
	int (*port_fdb_del)(struct dsa_switch___3 *, int, const unsigned char *, u16);
	int (*port_fdb_dump)(struct dsa_switch___3 *, int, dsa_fdb_dump_cb_t *, void *);
	int (*port_mdb_add)(struct dsa_switch___3 *, int, const struct switchdev_obj_port_mdb___3 *);
	int (*port_mdb_del)(struct dsa_switch___3 *, int, const struct switchdev_obj_port_mdb___3 *);
	int (*get_rxnfc)(struct dsa_switch___3 *, int, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct dsa_switch___3 *, int, struct ethtool_rxnfc *);
	int (*cls_flower_add)(struct dsa_switch___3 *, int, struct flow_cls_offload___3 *, bool);
	int (*cls_flower_del)(struct dsa_switch___3 *, int, struct flow_cls_offload___3 *, bool);
	int (*cls_flower_stats)(struct dsa_switch___3 *, int, struct flow_cls_offload___3 *, bool);
	int (*port_mirror_add)(struct dsa_switch___3 *, int, struct dsa_mall_mirror_tc_entry *, bool);
	void (*port_mirror_del)(struct dsa_switch___3 *, int, struct dsa_mall_mirror_tc_entry *);
	int (*port_policer_add)(struct dsa_switch___3 *, int, struct dsa_mall_policer_tc_entry *);
	void (*port_policer_del)(struct dsa_switch___3 *, int);
	int (*port_setup_tc)(struct dsa_switch___3 *, int, enum tc_setup_type, void *);
	int (*crosschip_bridge_join)(struct dsa_switch___3 *, int, int, int, struct net_device___6 *);
	void (*crosschip_bridge_leave)(struct dsa_switch___3 *, int, int, int, struct net_device___6 *);
	int (*crosschip_lag_change)(struct dsa_switch___3 *, int, int);
	int (*crosschip_lag_join)(struct dsa_switch___3 *, int, int, struct net_device___6 *, struct netdev_lag_upper_info *);
	int (*crosschip_lag_leave)(struct dsa_switch___3 *, int, int, struct net_device___6 *);
	int (*port_hwtstamp_get)(struct dsa_switch___3 *, int, struct ifreq *);
	int (*port_hwtstamp_set)(struct dsa_switch___3 *, int, struct ifreq *);
	void (*port_txtstamp)(struct dsa_switch___3 *, int, struct sk_buff___53 *);
	bool (*port_rxtstamp)(struct dsa_switch___3 *, int, struct sk_buff___53 *, unsigned int);
	int (*devlink_param_get)(struct dsa_switch___3 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_param_set)(struct dsa_switch___3 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_info_get)(struct dsa_switch___3 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*devlink_sb_pool_get)(struct dsa_switch___3 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*devlink_sb_pool_set)(struct dsa_switch___3 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*devlink_sb_port_pool_get)(struct dsa_switch___3 *, int, unsigned int, u16, u32 *);
	int (*devlink_sb_port_pool_set)(struct dsa_switch___3 *, int, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_tc_pool_bind_get)(struct dsa_switch___3 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*devlink_sb_tc_pool_bind_set)(struct dsa_switch___3 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_occ_snapshot)(struct dsa_switch___3 *, unsigned int);
	int (*devlink_sb_occ_max_clear)(struct dsa_switch___3 *, unsigned int);
	int (*devlink_sb_occ_port_pool_get)(struct dsa_switch___3 *, int, unsigned int, u16, u32 *, u32 *);
	int (*devlink_sb_occ_tc_port_bind_get)(struct dsa_switch___3 *, int, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*port_change_mtu)(struct dsa_switch___3 *, int, int);
	int (*port_max_mtu)(struct dsa_switch___3 *, int);
	int (*port_lag_change)(struct dsa_switch___3 *, int);
	int (*port_lag_join)(struct dsa_switch___3 *, int, struct net_device___6 *, struct netdev_lag_upper_info *);
	int (*port_lag_leave)(struct dsa_switch___3 *, int, struct net_device___6 *);
	int (*port_hsr_join)(struct dsa_switch___3 *, int, struct net_device___6 *);
	int (*port_hsr_leave)(struct dsa_switch___3 *, int, struct net_device___6 *);
	int (*port_mrp_add)(struct dsa_switch___3 *, int, const struct switchdev_obj_mrp___3 *);
	int (*port_mrp_del)(struct dsa_switch___3 *, int, const struct switchdev_obj_mrp___3 *);
	int (*port_mrp_add_ring_role)(struct dsa_switch___3 *, int, const struct switchdev_obj_ring_role_mrp___3 *);
	int (*port_mrp_del_ring_role)(struct dsa_switch___3 *, int, const struct switchdev_obj_ring_role_mrp___3 *);
	int (*tag_8021q_vlan_add)(struct dsa_switch___3 *, int, u16, u16);
	int (*tag_8021q_vlan_del)(struct dsa_switch___3 *, int, u16);
};

struct nh_info___3 {
	struct hlist_node dev_hash;
	struct nexthop *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___6 fib_nhc;
		struct fib_nh___3 fib_nh;
		struct fib6_nh___6 fib6_nh;
	};
};

struct nh_grp_entry___3;

struct nh_res_bucket___3 {
	struct nh_grp_entry___3 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___3 {
	struct nexthop *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop *nh_parent;
};

struct nh_res_table___3 {
	struct net___57 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___3 nh_buckets[0];
};

struct nh_group___3 {
	struct nh_group___3 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___3 *res_table;
	struct nh_grp_entry___3 nh_entries[0];
};

struct hw_port_info___2 {
	struct net_device___6 *lower_dev;
	u32 port_id;
};

struct metadata_dst___2 {
	struct dst_entry___41 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___2 port_info;
	} u;
};

struct tc_skb_cb {
	struct qdisc_skb_cb qdisc_cb;
	u16 mru;
	u8 post_ct: 1;
	u8 post_ct_snat: 1;
	u8 post_ct_dnat: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	u16 zone;
};

struct xfrm_type___4 {
	struct module___227 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___4 *);
	void (*destructor)(struct xfrm_state___4 *);
	int (*input)(struct xfrm_state___4 *, struct sk_buff___53 *);
	int (*output)(struct xfrm_state___4 *, struct sk_buff___53 *);
	int (*reject)(struct xfrm_state___4 *, struct sk_buff___53 *, const struct flowi *);
};

struct xfrm_type_offload___4 {
	struct module___227 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___4 *, struct sk_buff___53 *);
	int (*input_tail)(struct xfrm_state___4 *, struct sk_buff___53 *);
	int (*xmit)(struct xfrm_state___4 *, struct sk_buff___53 *, netdev_features_t);
};

struct in_ifaddr {
	struct hlist_node hash;
	struct in_ifaddr *ifa_next;
	struct in_device *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct nf_hook_state___5 {
	u8 hook;
	u8 pf;
	struct net_device___6 *in;
	struct net_device___6 *out;
	struct sock___42 *sk;
	struct net___57 *net;
	int (*okfn)(struct net___57 *, struct sock___42 *, struct sk_buff___53 *);
};

struct udp_tunnel_info {
	short unsigned int type;
	sa_family_t sa_family;
	__be16 port;
	u8 hw_priv;
};

struct udp_tunnel_nic_shared {
	struct udp_tunnel_nic *udp_tunnel_nic_info;
	struct list_head devices;
};

struct dev_kfree_skb_cb {
	enum skb_free_reason reason;
};

struct netdev_adjacent {
	struct net_device___6 *dev;
	bool master;
	bool ignore;
	u16 ref_nr;
	void *private;
	struct list_head list;
	struct callback_head rcu;
};

struct dentry___244;

struct super_block___244;

struct module___228;

struct file_system_type___244 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___244 * (*mount)(struct file_system_type___244 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___244 *);
	struct module___228 *owner;
	struct file_system_type___244 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___244;

struct kiocb___244;

struct iov_iter___164;

struct poll_table_struct___167;

struct vm_area_struct___249;

struct inode___244;

struct file_lock___244;

struct page___249;

struct pipe_inode_info___85;

struct seq_file___219;

struct file_operations___245 {
	struct module___228 *owner;
	loff_t (*llseek)(struct file___244 *, loff_t, int);
	ssize_t (*read)(struct file___244 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___244 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___244 *, struct iov_iter___164 *);
	ssize_t (*write_iter)(struct kiocb___244 *, struct iov_iter___164 *);
	int (*iopoll)(struct kiocb___244 *, bool);
	int (*iterate)(struct file___244 *, struct dir_context *);
	int (*iterate_shared)(struct file___244 *, struct dir_context *);
	__poll_t (*poll)(struct file___244 *, struct poll_table_struct___167 *);
	long int (*unlocked_ioctl)(struct file___244 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___244 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___244 *, struct vm_area_struct___249 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___244 *, struct file___244 *);
	int (*flush)(struct file___244 *, fl_owner_t);
	int (*release)(struct inode___244 *, struct file___244 *);
	int (*fsync)(struct file___244 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___244 *, int);
	int (*lock)(struct file___244 *, int, struct file_lock___244 *);
	ssize_t (*sendpage)(struct file___244 *, struct page___249 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___244 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___244 *, long unsigned int);
	int (*flock)(struct file___244 *, int, struct file_lock___244 *);
	ssize_t (*splice_write)(struct pipe_inode_info___85 *, struct file___244 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___244 *, loff_t *, struct pipe_inode_info___85 *, size_t, unsigned int);
	int (*setlease)(struct file___244 *, long int, struct file_lock___244 **, void **);
	long int (*fallocate)(struct file___244 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___219 *, struct file___244 *);
	ssize_t (*copy_file_range)(struct file___244 *, loff_t, struct file___244 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___244 *, loff_t, struct file___244 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___244 *, loff_t, loff_t, int);
};

struct vmacache___249 {
	u64 seqnum;
	struct vm_area_struct___249 *vmas[4];
};

struct page_frag___249 {
	struct page___249 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___250;

struct pid___221;

struct nsproxy___230;

struct signal_struct___245;

struct bio_list___137;

struct backing_dev_info___123;

struct io_context___137;

struct css_set___171;

struct mem_cgroup___111;

struct request_queue___137;

struct vm_struct___227;

struct task_struct___251 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___251 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___250 *mm;
	struct mm_struct___250 *active_mm;
	struct vmacache___249 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___251 *real_parent;
	struct task_struct___251 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___251 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___221 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___230 *nsproxy;
	struct signal_struct___245 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___251 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___137 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___123 *backing_dev_info;
	struct io_context___137 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___171 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___85 *splice_pipe;
	struct page_frag___249 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___111 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___111 *active_memcg;
	struct request_queue___137 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___251 *oom_reaper_list;
	struct vm_struct___227 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___232;

struct kobj_type___232;

struct kernfs_node___232;

struct kobject___232 {
	const char *name;
	struct list_head entry;
	struct kobject___232 *parent;
	struct kset___232 *kset;
	struct kobj_type___232 *ktype;
	struct kernfs_node___232 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___229 {
	struct kobject___232 kobj;
	struct module___228 *mod;
	struct kobject___232 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___228 {
	struct module___228 *mod;
	struct latch_tree_node node;
};

struct module_layout___228 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___228 mtn;
};

struct module_attribute___228;

struct kernel_param___228;

struct module___228 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___229 mkobj;
	struct module_attribute___228 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___232 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___228 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___228 core_layout;
	struct module_layout___228 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___249 *pgtable_t___249;

struct address_space___244;

struct page_pool___73;

struct dev_pagemap___239;

struct page___249 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___244 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___73 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___249 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___249 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___250 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___239 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___239;

struct vm_area_struct___249 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___249 *vm_next;
	struct vm_area_struct___249 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___250 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___239 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___244 *vm_file;
	struct file___244 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___249;

struct mm_struct___250 {
	struct {
		struct vm_area_struct___249 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___244 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___249 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___251 *owner;
		struct user_namespace___26 *user_ns;
		struct file___244 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___244;

struct address_space___244 {
	struct inode___244 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___244 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___225;

struct page_pool_params___73 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___225 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___73 {
	u32 count;
	struct page___249 *cache[128];
};

struct page_pool___73 {
	struct page_pool_params___73 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___249 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___73 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___239;

struct dev_pagemap___239 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___239 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___244;

struct path___244 {
	struct vfsmount___244 *mnt;
	struct dentry___244 *dentry;
};

struct fown_struct___221 {
	rwlock_t lock;
	struct pid___221 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___244 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___244 f_path;
	struct inode___244 *f_inode;
	const struct file_operations___245 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___221 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___244 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___239;

struct vm_operations_struct___239 {
	void (*open)(struct vm_area_struct___249 *);
	void (*close)(struct vm_area_struct___249 *);
	int (*may_split)(struct vm_area_struct___249 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___249 *);
	int (*mprotect)(struct vm_area_struct___249 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___239 *);
	vm_fault_t (*huge_fault)(struct vm_fault___239 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___239 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___249 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___239 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___239 *);
	int (*access)(struct vm_area_struct___249 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___249 *);
	int (*set_policy)(struct vm_area_struct___249 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___249 *, long unsigned int);
	struct page___249 * (*find_special_page)(struct vm_area_struct___249 *, long unsigned int);
};

struct core_thread___249 {
	struct task_struct___251 *task;
	struct core_thread___249 *next;
};

struct core_state___249 {
	atomic_t nr_threads;
	struct core_thread___249 dumper;
	struct completion startup;
};

struct vm_fault___239 {
	const struct {
		struct vm_area_struct___249 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___249 *cow_page;
	struct page___249 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___249 prealloc_pte;
};

struct pglist_data___119;

struct lruvec___119 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___119 *pgdat;
};

struct zone___119 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___119 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___119 {
	struct zone___119 *zone;
	int zone_idx;
};

struct zonelist___119 {
	struct zoneref___119 _zonerefs[321];
};

struct pglist_data___119 {
	struct zone___119 node_zones[5];
	struct zonelist___119 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___251 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___251 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___119 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___111 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___111 *memcg;
};

struct cgroup___171;

struct cgroup_subsys___171;

struct cgroup_subsys_state___171 {
	struct cgroup___171 *cgroup;
	struct cgroup_subsys___171 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___171 *parent;
};

struct cgroup_file___171 {
	struct kernfs_node___232 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___111;

struct mem_cgroup_per_node___111;

struct mem_cgroup___111 {
	struct cgroup_subsys_state___171 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___171 events_file;
	struct cgroup_file___171 events_local_file;
	struct cgroup_file___171 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___111 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___251 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___111 *nodeinfo[0];
	long: 64;
};

struct shrinker___111 {
	long unsigned int (*count_objects)(struct shrinker___111 *, struct shrink_control___111 *);
	long unsigned int (*scan_objects)(struct shrinker___111 *, struct shrink_control___111 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___239 {
	void (*page_free)(struct page___249 *);
	void (*kill)(struct dev_pagemap___239 *);
	void (*cleanup)(struct dev_pagemap___239 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___239 *);
};

struct pid_namespace___221;

struct upid___221 {
	int nr;
	struct pid_namespace___221 *ns;
};

struct pid_namespace___221 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___251 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___221 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___221 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___221 numbers[1];
};

struct signal_struct___245 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___251 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___251 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___221 *pids[4];
	struct pid___221 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___250 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___58;

struct cgroup_namespace___171;

struct nsproxy___230 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___221 *pid_ns_for_children;
	struct net___58 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___171 *cgroup_ns;
};

struct bio___137;

struct bio_list___137 {
	struct bio___137 *head;
	struct bio___137 *tail;
};

struct bdi_writeback___123 {
	struct backing_dev_info___123 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___171 *memcg_css;
	struct cgroup_subsys_state___171 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___123 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___123 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___225 *dev;
	char dev_name[64];
	struct device___225 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___244 *debug_dir;
};

struct io_cq___137;

struct io_context___137 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___137 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___171 {
	struct cgroup_subsys_state___171 *subsys[14];
	refcount_t refcount;
	struct css_set___171 *dom_cset;
	struct cgroup___171 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___171 *mg_src_cgrp;
	struct cgroup___171 *mg_dst_cgrp;
	struct css_set___171 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___244;

struct pipe_buffer___85;

struct pipe_inode_info___85 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___249 *tmp_page;
	struct fasync_struct___244 *fasync_readers;
	struct fasync_struct___244 *fasync_writers;
	struct pipe_buffer___85 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___137;

struct blk_integrity___137 {
	const struct blk_integrity_profile___137 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___137 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___137 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___137;

struct elevator_queue___137;

struct blk_mq_ops___132;

struct blk_mq_hw_ctx___132;

struct gendisk___140;

struct blkcg_gq___125;

struct blk_mq_tag_set___132;

struct request_queue___137 {
	struct request___137 *last_merge;
	struct elevator_queue___137 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___132 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___132 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___140 *disk;
	struct kobject___232 kobj;
	struct kobject___232 *mq_kobj;
	struct blk_integrity___137 integrity;
	struct device___225 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___125 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___132 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___137 bio_split;
	struct dentry___244 *debugfs_dir;
	struct dentry___244 *sched_debugfs_dir;
	struct dentry___244 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___227 {
	struct vm_struct___227 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___249 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___244;

struct dentry___244 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___244 *d_parent;
	struct qstr d_name;
	struct inode___244 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___244 *d_op;
	struct super_block___244 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___244;

struct inode___244 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___244 *i_op;
	struct super_block___244 *i_sb;
	struct address_space___244 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___123 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___245 *i_fop;
		void (*free_inode)(struct inode___244 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___244 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___85 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___244 {
	int (*d_revalidate)(struct dentry___244 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___244 *, unsigned int);
	int (*d_hash)(const struct dentry___244 *, struct qstr *);
	int (*d_compare)(const struct dentry___244 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___244 *);
	int (*d_init)(struct dentry___244 *);
	void (*d_release)(struct dentry___244 *);
	void (*d_prune)(struct dentry___244 *);
	void (*d_iput)(struct dentry___244 *, struct inode___244 *);
	char * (*d_dname)(struct dentry___244 *, char *, int);
	struct vfsmount___244 * (*d_automount)(struct path___244 *);
	int (*d_manage)(const struct path___244 *, bool);
	struct dentry___244 * (*d_real)(struct dentry___244 *, const struct inode___244 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___244;

struct mem_dqinfo___244 {
	struct quota_format_type___244 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___244;

struct quota_info___244 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___244 *files[3];
	struct mem_dqinfo___244 info[3];
	const struct quota_format_ops___244 *ops[3];
};

struct rcuwait___245 {
	struct task_struct___251 *task;
};

struct percpu_rw_semaphore___245 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___245 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___244 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___245 rw_sem[3];
};

struct super_operations___244;

struct dquot_operations___244;

struct quotactl_ops___244;

struct block_device___140;

struct super_block___244 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___244 *s_type;
	const struct super_operations___244 *s_op;
	const struct dquot_operations___244 *dq_op;
	const struct quotactl_ops___244 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___244 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___140 *s_bdev;
	struct backing_dev_info___123 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___244 s_dquot;
	struct sb_writers___244 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___244 *s_d_op;
	int cleancache_poolid;
	struct shrinker___111 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___244 {
	struct dentry___244 *mnt_root;
	struct super_block___244 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___171 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___251 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___49;

struct cgroup_bpf___49 {
	struct bpf_prog_array___49 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___49 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___171;

struct cgroup_rstat_cpu___171;

struct cgroup___171 {
	struct cgroup_subsys_state___171 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___232 *kn;
	struct cgroup_file___171 procs_file;
	struct cgroup_file___171 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___171 *subsys[14];
	struct cgroup_root___171 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___171 *dom_cgrp;
	struct cgroup___171 *old_dom_cgrp;
	struct cgroup_rstat_cpu___171 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___171 psi;
	struct cgroup_bpf___49 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___137 {
	struct request_queue___137 *q;
	struct io_context___137 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___244 {
	struct file___244 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___244 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___244 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___244 *ia_file;
};

struct dquot___244 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___244 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___244 {
	int qf_fmt_id;
	const struct quota_format_ops___244 *qf_ops;
	struct module___228 *qf_owner;
	struct quota_format_type___244 *qf_next;
};

struct quota_format_ops___244 {
	int (*check_quota_file)(struct super_block___244 *, int);
	int (*read_file_info)(struct super_block___244 *, int);
	int (*write_file_info)(struct super_block___244 *, int);
	int (*free_file_info)(struct super_block___244 *, int);
	int (*read_dqblk)(struct dquot___244 *);
	int (*commit_dqblk)(struct dquot___244 *);
	int (*release_dqblk)(struct dquot___244 *);
	int (*get_next_id)(struct super_block___244 *, struct kqid *);
};

struct dquot_operations___244 {
	int (*write_dquot)(struct dquot___244 *);
	struct dquot___244 * (*alloc_dquot)(struct super_block___244 *, int);
	void (*destroy_dquot)(struct dquot___244 *);
	int (*acquire_dquot)(struct dquot___244 *);
	int (*release_dquot)(struct dquot___244 *);
	int (*mark_dirty)(struct dquot___244 *);
	int (*write_info)(struct super_block___244 *, int);
	qsize_t * (*get_reserved_space)(struct inode___244 *);
	int (*get_projid)(struct inode___244 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___244 *, qsize_t *);
	int (*get_next_id)(struct super_block___244 *, struct kqid *);
};

struct quotactl_ops___244 {
	int (*quota_on)(struct super_block___244 *, int, int, const struct path___244 *);
	int (*quota_off)(struct super_block___244 *, int);
	int (*quota_enable)(struct super_block___244 *, unsigned int);
	int (*quota_disable)(struct super_block___244 *, unsigned int);
	int (*quota_sync)(struct super_block___244 *, int);
	int (*set_info)(struct super_block___244 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___244 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___244 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___244 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___244 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___244 *, unsigned int);
};

struct writeback_control___123;

struct address_space_operations___244 {
	int (*writepage)(struct page___249 *, struct writeback_control___123 *);
	int (*readpage)(struct file___244 *, struct page___249 *);
	int (*writepages)(struct address_space___244 *, struct writeback_control___123 *);
	int (*set_page_dirty)(struct page___249 *);
	int (*readpages)(struct file___244 *, struct address_space___244 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___244 *, struct address_space___244 *, loff_t, unsigned int, unsigned int, struct page___249 **, void **);
	int (*write_end)(struct file___244 *, struct address_space___244 *, loff_t, unsigned int, unsigned int, struct page___249 *, void *);
	sector_t (*bmap)(struct address_space___244 *, sector_t);
	void (*invalidatepage)(struct page___249 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___249 *, gfp_t);
	void (*freepage)(struct page___249 *);
	ssize_t (*direct_IO)(struct kiocb___244 *, struct iov_iter___164 *);
	int (*migratepage)(struct address_space___244 *, struct page___249 *, struct page___249 *, enum migrate_mode);
	bool (*isolate_page)(struct page___249 *, isolate_mode_t);
	void (*putback_page)(struct page___249 *);
	int (*launder_page)(struct page___249 *);
	int (*is_partially_uptodate)(struct page___249 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___249 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___244 *, struct page___249 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___244 *, sector_t *);
	void (*swap_deactivate)(struct file___244 *);
};

struct writeback_control___123 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___123 *wb;
	struct inode___244 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___161;

struct iov_iter___164 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___161 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___85 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___244 {
	struct dentry___244 * (*lookup)(struct inode___244 *, struct dentry___244 *, unsigned int);
	const char * (*get_link)(struct dentry___244 *, struct inode___244 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___244 *, int);
	struct posix_acl * (*get_acl)(struct inode___244 *, int, bool);
	int (*readlink)(struct dentry___244 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___244 *, struct dentry___244 *, umode_t, bool);
	int (*link)(struct dentry___244 *, struct inode___244 *, struct dentry___244 *);
	int (*unlink)(struct inode___244 *, struct dentry___244 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___244 *, struct dentry___244 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___244 *, struct dentry___244 *, umode_t);
	int (*rmdir)(struct inode___244 *, struct dentry___244 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___244 *, struct dentry___244 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___244 *, struct dentry___244 *, struct inode___244 *, struct dentry___244 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___244 *, struct iattr___244 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___244 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___244 *, char *, size_t);
	int (*fiemap)(struct inode___244 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___244 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___244 *, struct dentry___244 *, struct file___244 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___244 *, struct dentry___244 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___244 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___244 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___244 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___244 {
	void (*fl_copy_lock)(struct file_lock___244 *, struct file_lock___244 *);
	void (*fl_release_private)(struct file_lock___244 *);
};

struct lock_manager_operations___244;

struct file_lock___244 {
	struct file_lock___244 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___244 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___244 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___244 *fl_ops;
	const struct lock_manager_operations___244 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___244 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___244 *);
	int (*lm_grant)(struct file_lock___244 *, int);
	bool (*lm_break)(struct file_lock___244 *);
	int (*lm_change)(struct file_lock___244 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___244 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___244 *);
};

struct fasync_struct___244 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___244 *fa_next;
	struct file___244 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___244 {
	struct inode___244 * (*alloc_inode)(struct super_block___244 *);
	void (*destroy_inode)(struct inode___244 *);
	void (*free_inode)(struct inode___244 *);
	void (*dirty_inode)(struct inode___244 *, int);
	int (*write_inode)(struct inode___244 *, struct writeback_control___123 *);
	int (*drop_inode)(struct inode___244 *);
	void (*evict_inode)(struct inode___244 *);
	void (*put_super)(struct super_block___244 *);
	int (*sync_fs)(struct super_block___244 *, int);
	int (*freeze_super)(struct super_block___244 *);
	int (*freeze_fs)(struct super_block___244 *);
	int (*thaw_super)(struct super_block___244 *);
	int (*unfreeze_fs)(struct super_block___244 *);
	int (*statfs)(struct dentry___244 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___244 *, int *, char *);
	void (*umount_begin)(struct super_block___244 *);
	int (*show_options)(struct seq_file___219 *, struct dentry___244 *);
	int (*show_devname)(struct seq_file___219 *, struct dentry___244 *);
	int (*show_path)(struct seq_file___219 *, struct dentry___244 *);
	int (*show_stats)(struct seq_file___219 *, struct dentry___244 *);
	ssize_t (*quota_read)(struct super_block___244 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___244 *, int, const char *, size_t, loff_t);
	struct dquot___244 ** (*get_dquots)(struct inode___244 *);
	long int (*nr_cached_objects)(struct super_block___244 *, struct shrink_control___111 *);
	long int (*free_cached_objects)(struct super_block___244 *, struct shrink_control___111 *);
	struct file___244 * (*real_loop)(struct file___244 *);
};

struct wakeup_source___225;

struct dev_pm_info___225 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___225 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___225 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___225;

struct bus_type___225;

struct device_driver___225;

struct dev_pm_domain___225;

struct fwnode_handle___221;

struct class___225;

struct attribute_group___232;

struct device___225 {
	struct kobject___232 kobj;
	struct device___225 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___225 *type;
	struct bus_type___225 *bus;
	struct device_driver___225 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___225 power;
	struct dev_pm_domain___225 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___221 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___225 *class;
	const struct attribute_group___232 **groups;
	void (*release)(struct device___225 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___140 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___244 *bd_inode;
	struct super_block___244 *bd_super;
	void *bd_claiming;
	struct device___225 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___232 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___140 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___244 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___175)(struct file___244 *, wait_queue_head_t *, struct poll_table_struct___167 *);

struct poll_table_struct___167 {
	poll_queue_proc___175 _qproc;
	__poll_t _key;
};

struct seq_operations___219;

struct seq_file___219 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___219 *op;
	int poll_event;
	const struct file___244 *file;
	void *private;
};

typedef void bio_end_io_t___137(struct bio___137 *);

struct bio_vec___161 {
	struct page___249 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___137;

struct bio___137 {
	struct bio___137 *bi_next;
	struct block_device___140 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___137 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___125 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___137 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___161 *bi_io_vec;
	struct bio_set___137 *bi_pool;
	struct bio_vec___161 bi_inline_vecs[0];
};

struct kernfs_root___232;

struct kernfs_elem_dir___232 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___232 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___232;

struct kernfs_root___232 {
	struct kernfs_node___232 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___232 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___232 {
	struct kernfs_node___232 *target_kn;
};

struct kernfs_ops___232;

struct kernfs_elem_attr___232 {
	const struct kernfs_ops___232 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___232 *notify_next;
};

struct kernfs_node___232 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___232 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___232 dir;
		struct kernfs_elem_symlink___232 symlink;
		struct kernfs_elem_attr___232 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___232;

struct kernfs_ops___232 {
	int (*open)(struct kernfs_open_file___232 *);
	void (*release)(struct kernfs_open_file___232 *);
	int (*seq_show)(struct seq_file___219 *, void *);
	void * (*seq_start)(struct seq_file___219 *, loff_t *);
	void * (*seq_next)(struct seq_file___219 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___219 *, void *);
	ssize_t (*read)(struct kernfs_open_file___232 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___232 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___232 *, struct poll_table_struct___167 *);
	int (*mmap)(struct kernfs_open_file___232 *, struct vm_area_struct___249 *);
};

struct kernfs_syscall_ops___232 {
	int (*show_options)(struct seq_file___219 *, struct kernfs_root___232 *);
	int (*mkdir)(struct kernfs_node___232 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___232 *);
	int (*rename)(struct kernfs_node___232 *, struct kernfs_node___232 *, const char *);
	int (*show_path)(struct seq_file___219 *, struct kernfs_node___232 *, struct kernfs_root___232 *);
};

struct kernfs_open_file___232 {
	struct kernfs_node___232 *kn;
	struct file___244 *file;
	struct seq_file___219 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___239 *vm_ops;
};

struct sock___43;

struct kobj_ns_type_operations___42 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___43 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___58 *net;
} possible_net_t___53;

struct proto___42;

struct sock_common___42 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___42 *skc_prot;
	possible_net_t___53 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___43 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___54;

struct sk_buff_head___53 {
	struct sk_buff___54 *next;
	struct sk_buff___54 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___42 {
	struct cgroup___171 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___42;

struct socket_wq___43;

struct xfrm_policy___5;

struct dst_entry___42;

struct socket___44;

struct net_device___54;

struct sock___43 {
	struct sock_common___42 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___53 sk_error_queue;
	struct sk_buff___54 *sk_rx_skb_cache;
	struct sk_buff_head___53 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___54 *head;
		struct sk_buff___54 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___42 *sk_filter;
	union {
		struct socket_wq___43 *sk_wq;
		struct socket_wq___43 *sk_wq_raw;
	};
	struct xfrm_policy___5 *sk_policy[2];
	struct dst_entry___42 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___42 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___54 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___54 *sk_tx_skb_cache;
	struct sk_buff_head___53 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___249 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___42 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___221 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___44 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___42 sk_cgrp_data;
	struct mem_cgroup___111 *sk_memcg;
	void (*sk_state_change)(struct sock___43 *);
	void (*sk_data_ready)(struct sock___43 *);
	void (*sk_write_space)(struct sock___43 *);
	void (*sk_error_report)(struct sock___43 *);
	int (*sk_backlog_rcv)(struct sock___43 *, struct sk_buff___54 *);
	struct sk_buff___54 * (*sk_validate_xmit_skb)(struct sock___43 *, struct net_device___54 *, struct sk_buff___54 *);
	void (*sk_destruct)(struct sock___43 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___232;

struct attribute_group___232 {
	const char *name;
	umode_t (*is_visible)(struct kobject___232 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___232 *, struct bin_attribute___232 *, int);
	struct attribute **attrs;
	struct bin_attribute___232 **bin_attrs;
};

struct bin_attribute___232 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___244 * (*f_mapping)();
	ssize_t (*read)(struct file___244 *, struct kobject___232 *, struct bin_attribute___232 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___244 *, struct kobject___232 *, struct bin_attribute___232 *, char *, loff_t, size_t);
	int (*mmap)(struct file___244 *, struct kobject___232 *, struct bin_attribute___232 *, struct vm_area_struct___249 *);
};

struct sysfs_ops___232 {
	ssize_t (*show)(struct kobject___232 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___232 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___232;

struct kset___232 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___232 kobj;
	const struct kset_uevent_ops___232 *uevent_ops;
};

struct kobj_type___232 {
	void (*release)(struct kobject___232 *);
	const struct sysfs_ops___232 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___232 **default_groups;
	const struct kobj_ns_type_operations___42 * (*child_ns_type)(struct kobject___232 *);
	const void * (*namespace)(struct kobject___232 *);
	void (*get_ownership)(struct kobject___232 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___232 {
	int (* const filter)(struct kset___232 *, struct kobject___232 *);
	const char * (* const name)(struct kset___232 *, struct kobject___232 *);
	int (* const uevent)(struct kset___232 *, struct kobject___232 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___228 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___228 *);
	int (*get)(char *, const struct kernel_param___228 *);
	void (*free)(void *);
};

struct kparam_array___228;

struct kernel_param___228 {
	const char *name;
	struct module___228 *mod;
	const struct kernel_param_ops___228 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___228 *arr;
	};
};

struct kparam_array___228 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___228 *ops;
	void *elem;
};

struct module_attribute___228 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___228 *, struct module_kobject___229 *, char *);
	ssize_t (*store)(struct module_attribute___228 *, struct module_kobject___229 *, const char *, size_t);
	void (*setup)(struct module___228 *, const char *);
	int (*test)(struct module___228 *);
	void (*free)(struct module___228 *);
};

struct msghdr___44 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___164 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___244 *msg_iocb;
};

struct sk_buff___54 {
	union {
		struct {
			struct sk_buff___54 *next;
			struct sk_buff___54 *prev;
			union {
				struct net_device___54 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___43 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___54 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___58;

struct fqdir___58 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___58 *f;
	struct net___58 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___58;

struct inet_frags___58 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___58 *, const void *);
	void (*destructor)(struct inet_frag_queue___58 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___23;

struct fib_rules_ops___42;

struct fib_notifier_ops___42;

struct netns_ipv4___58 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___23 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___42 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___43 *fibnl;
	struct sock___43 **icmp_sk;
	struct sock___43 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___43 **tcp_sk;
	struct fqdir___58 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___42 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___42 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___42 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___42;

struct dst_ops___58 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___58 *);
	struct dst_entry___42 * (*check)(struct dst_entry___42 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___42 *);
	unsigned int (*mtu)(const struct dst_entry___42 *);
	u32 * (*cow_metrics)(struct dst_entry___42 *, long unsigned int);
	void (*destroy)(struct dst_entry___42 *);
	void (*ifdown)(struct dst_entry___42 *, struct net_device___54 *, int);
	struct dst_entry___42 * (*negative_advice)(struct dst_entry___42 *);
	void (*link_failure)(struct sk_buff___54 *);
	void (*update_pmtu)(struct dst_entry___42 *, struct sock___43 *, struct sk_buff___54 *, u32, bool);
	void (*redirect)(struct dst_entry___42 *, struct sock___43 *, struct sk_buff___54 *);
	int (*local_out)(struct net___58 *, struct sock___43 *, struct sk_buff___54 *);
	struct neighbour___42 * (*neigh_lookup)(const struct dst_entry___42 *, struct sk_buff___54 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___42 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___7;

struct rt6_info___7;

struct fib6_table___7;

struct netns_ipv6___58 {
	struct dst_ops___58 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___58 *fqdir;
	struct fib6_info___7 *fib6_null_entry;
	struct rt6_info___7 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___7 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___7 *ip6_prohibit_entry;
	struct rt6_info___7 *ip6_blk_hole_entry;
	struct fib6_table___7 *fib6_local_tbl;
	struct fib_rules_ops___42 *fib6_rules_ops;
	struct sock___43 **icmp_sk;
	struct sock___43 *ndisc_sk;
	struct sock___43 *tcp_sk;
	struct sock___43 *igmp_sk;
	struct sock___43 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___42 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___42 *notifier_ops;
	struct fib_notifier_ops___42 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___58 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___58 *fqdir;
};

struct netns_sctp___42 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___43 *ctl_sock;
	struct sock___43 *udp4_sock;
	struct sock___43 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___49;

struct netns_bpf___49 {
	struct bpf_prog_array___49 *run_array[2];
	struct bpf_prog___49 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___58 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___43 *nlsk;
	struct sock___43 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___58 xfrm4_dst_ops;
	struct dst_ops___58 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___58 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___43 *rtnl;
	struct sock___43 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___54 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___58 ipv4;
	struct netns_ipv6___58 ipv6;
	struct netns_ieee802154_lowpan___58 ieee802154_lowpan;
	struct netns_sctp___42 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___53 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___49 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___58 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___43 *crypto_nlsk;
	struct sock___43 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___58 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___54 *fragments_tail;
	struct sk_buff___54 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___58 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___23 {
	struct ip_ra_chain___23 *next;
	struct sock___43 *sk;
	union {
		void (*destructor)(struct sock___43 *);
		struct sock___43 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___42;

struct fib_lookup_arg___42;

struct fib_rules_ops___42 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___42 *, struct flowi *, int, struct fib_lookup_arg___42 *);
	bool (*suppress)(struct fib_rule___42 *, int, struct fib_lookup_arg___42 *);
	int (*match)(struct fib_rule___42 *, struct flowi *, int);
	int (*configure)(struct fib_rule___42 *, struct sk_buff___54 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___42 *);
	int (*compare)(struct fib_rule___42 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___42 *, struct sk_buff___54 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___42 *);
	void (*flush_cache)(struct fib_rules_ops___42 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___228 *owner;
	struct net___58 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___42 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___58 *);
	int (*fib_dump)(struct net___58 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___228 *owner;
	struct callback_head rcu;
};

struct xfrm_state___5;

struct lwtunnel_state___24;

struct dst_entry___42 {
	struct net_device___54 *dev;
	struct dst_ops___58 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___5 *xfrm;
	int (*input)(struct sk_buff___54 *);
	int (*output)(struct net___58 *, struct sock___43 *, struct sk_buff___54 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___24 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___53(struct sk_buff___54 **);

struct bpf_xdp_entity___49 {
	struct bpf_prog___49 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___53;

struct net_device_ops___53;

struct l3mdev_ops___42;

struct ndisc_ops___29;

struct xfrmdev_ops___53;

struct header_ops___53;

struct inet6_dev___29;

struct netdev_rx_queue___53;

struct mini_Qdisc___49;

struct netdev_queue___53;

struct Qdisc___49;

struct rtnl_link_ops___49;

struct dcbnl_rtnl_ops___53;

struct net_device___54 {
	char name[16];
	struct netdev_name_node___53 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___53 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___42 *l3mdev_ops;
	const struct ndisc_ops___29 *ndisc_ops;
	const struct xfrmdev_ops___53 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___53 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___232 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___29 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___53 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___49 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___53 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___49 *miniq_ingress;
	struct netdev_queue___53 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___53 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___49 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___49 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___53 = 0,
		NETREG_REGISTERED___53 = 1,
		NETREG_UNREGISTERING___53 = 2,
		NETREG_UNREGISTERED___53 = 3,
		NETREG_RELEASED___53 = 4,
		NETREG_DUMMY___53 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___53 = 0,
		RTNL_LINK_INITIALIZING___53 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___54 *);
	struct netpoll_info *npinfo;
	possible_net_t___53 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___225 dev;
	const struct attribute_group___232 *sysfs_groups[4];
	const struct attribute_group___232 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___49 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___53 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___49 xdp_state[3];
	long: 64;
};

struct neigh_table___42;

struct neigh_parms___42;

struct neigh_ops___42;

struct neighbour___42 {
	struct neighbour___42 *next;
	struct neigh_table___42 *tbl;
	struct neigh_parms___42 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___53 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___42 *, struct sk_buff___54 *);
	const struct neigh_ops___42 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___54 *dev;
	u8 primary_key[0];
};

struct rtable___7;

struct fnhe_hash_bucket___7;

struct fib_nh_common___7 {
	struct net_device___54 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___24 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___7 **nhc_pcpu_rth_output;
	struct rtable___7 *nhc_rth_input;
	struct fnhe_hash_bucket___7 *nhc_exceptions;
};

struct fib6_nh___7 {
	struct fib_nh_common___7 nh_common;
	long unsigned int last_probe;
	struct rt6_info___7 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___7;

struct nexthop___4;

struct fib6_info___7 {
	struct fib6_table___7 *fib6_table;
	struct fib6_info___7 *fib6_next;
	struct fib6_node___7 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___4 *nh;
	struct fib6_nh___7 fib6_nh[0];
};

struct rt6_info___7 {
	struct dst_entry___42 dst;
	struct fib6_info___7 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___29 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___7 {
	struct fib6_node___7 *parent;
	struct fib6_node___7 *left;
	struct fib6_node___7 *right;
	struct fib6_node___7 *subtree;
	struct fib6_info___7 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___7 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___7 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___7 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___49 {
	struct bpf_prog___49 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___49 {
	struct callback_head rcu;
	struct bpf_prog_array_item___49 items[0];
};

struct bpf_prog_aux___56;

struct bpf_prog___49 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___56 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___221;

struct fwnode_handle___221 {
	struct fwnode_handle___221 *secondary;
	const struct fwnode_operations___221 *ops;
	struct device___225 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___221;

struct fwnode_endpoint___221;

struct fwnode_operations___221 {
	struct fwnode_handle___221 * (*get)(struct fwnode_handle___221 *);
	void (*put)(struct fwnode_handle___221 *);
	bool (*device_is_available)(const struct fwnode_handle___221 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___221 *, const struct device___225 *);
	bool (*property_present)(const struct fwnode_handle___221 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___221 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___221 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___221 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*get_parent)(const struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*get_next_child_node)(const struct fwnode_handle___221 *, struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*get_named_child_node)(const struct fwnode_handle___221 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___221 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___221 *);
	struct fwnode_handle___221 * (*graph_get_next_endpoint)(const struct fwnode_handle___221 *, struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*graph_get_remote_endpoint)(const struct fwnode_handle___221 *);
	struct fwnode_handle___221 * (*graph_get_port_parent)(struct fwnode_handle___221 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___221 *, struct fwnode_endpoint___221 *);
	int (*add_links)(struct fwnode_handle___221 *);
};

struct fwnode_endpoint___221 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___221 *local_fwnode;
};

struct fwnode_reference_args___221 {
	struct fwnode_handle___221 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___171 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___171 *root_cset;
};

struct socket_wq___43 {
	wait_queue_head_t wait;
	struct fasync_struct___244 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___43;

struct socket___44 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___244 *file;
	struct sock___43 *sk;
	const struct proto_ops___43 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___43 wq;
};

typedef int (*sk_read_actor_t___42)(read_descriptor_t *, struct sk_buff___54 *, unsigned int, size_t);

struct proto_ops___43 {
	int family;
	struct module___228 *owner;
	int (*release)(struct socket___44 *);
	int (*bind)(struct socket___44 *, struct sockaddr *, int);
	int (*connect)(struct socket___44 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___44 *, struct socket___44 *);
	int (*accept)(struct socket___44 *, struct socket___44 *, int, bool);
	int (*getname)(struct socket___44 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___244 *, struct socket___44 *, struct poll_table_struct___167 *);
	int (*ioctl)(struct socket___44 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___44 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___44 *, void *, bool, bool);
	int (*listen)(struct socket___44 *, int);
	int (*shutdown)(struct socket___44 *, int);
	int (*setsockopt)(struct socket___44 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___44 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___219 *, struct socket___44 *);
	int (*sendmsg)(struct socket___44 *, struct msghdr___44 *, size_t);
	int (*recvmsg)(struct socket___44 *, struct msghdr___44 *, size_t, int);
	int (*mmap)(struct file___244 *, struct socket___44 *, struct vm_area_struct___249 *);
	ssize_t (*sendpage)(struct socket___44 *, struct page___249 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___44 *, loff_t *, struct pipe_inode_info___85 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___43 *, int);
	int (*peek_len)(struct socket___44 *);
	int (*read_sock)(struct sock___43 *, read_descriptor_t *, sk_read_actor_t___42);
	int (*sendpage_locked)(struct sock___43 *, struct page___249 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___43 *, struct msghdr___44 *, size_t);
	int (*set_rcvlowat)(struct sock___43 *, int);
};

struct dev_pm_ops___225 {
	int (*prepare)(struct device___225 *);
	void (*complete)(struct device___225 *);
	int (*suspend)(struct device___225 *);
	int (*resume)(struct device___225 *);
	int (*freeze)(struct device___225 *);
	int (*thaw)(struct device___225 *);
	int (*poweroff)(struct device___225 *);
	int (*restore)(struct device___225 *);
	int (*suspend_late)(struct device___225 *);
	int (*resume_early)(struct device___225 *);
	int (*freeze_late)(struct device___225 *);
	int (*thaw_early)(struct device___225 *);
	int (*poweroff_late)(struct device___225 *);
	int (*restore_early)(struct device___225 *);
	int (*suspend_noirq)(struct device___225 *);
	int (*resume_noirq)(struct device___225 *);
	int (*freeze_noirq)(struct device___225 *);
	int (*thaw_noirq)(struct device___225 *);
	int (*poweroff_noirq)(struct device___225 *);
	int (*restore_noirq)(struct device___225 *);
	int (*runtime_suspend)(struct device___225 *);
	int (*runtime_resume)(struct device___225 *);
	int (*runtime_idle)(struct device___225 *);
};

struct wakeup_source___225 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___225 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___225 {
	struct dev_pm_ops___225 ops;
	int (*start)(struct device___225 *);
	void (*detach)(struct device___225 *, bool);
	int (*activate)(struct device___225 *);
	void (*sync)(struct device___225 *);
	void (*dismiss)(struct device___225 *);
};

struct bus_type___225 {
	const char *name;
	const char *dev_name;
	struct device___225 *dev_root;
	const struct attribute_group___232 **bus_groups;
	const struct attribute_group___232 **dev_groups;
	const struct attribute_group___232 **drv_groups;
	int (*match)(struct device___225 *, struct device_driver___225 *);
	int (*uevent)(struct device___225 *, struct kobj_uevent_env *);
	int (*probe)(struct device___225 *);
	void (*sync_state)(struct device___225 *);
	void (*remove)(struct device___225 *);
	void (*shutdown)(struct device___225 *);
	int (*online)(struct device___225 *);
	int (*offline)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	int (*num_vf)(struct device___225 *);
	int (*dma_configure)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___225 {
	const char *name;
	struct bus_type___225 *bus;
	struct module___228 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___225 *);
	void (*sync_state)(struct device___225 *);
	int (*remove)(struct device___225 *);
	void (*shutdown)(struct device___225 *);
	int (*suspend)(struct device___225 *, pm_message_t);
	int (*resume)(struct device___225 *);
	const struct attribute_group___232 **groups;
	const struct attribute_group___232 **dev_groups;
	const struct dev_pm_ops___225 *pm;
	void (*coredump)(struct device___225 *);
	struct driver_private *p;
};

struct device_type___225 {
	const char *name;
	const struct attribute_group___232 **groups;
	int (*uevent)(struct device___225 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___225 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___225 *);
	const struct dev_pm_ops___225 *pm;
};

struct class___225 {
	const char *name;
	struct module___228 *owner;
	const struct attribute_group___232 **class_groups;
	const struct attribute_group___232 **dev_groups;
	struct kobject___232 *dev_kobj;
	int (*dev_uevent)(struct device___225 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___225 *, umode_t *);
	void (*class_release)(struct class___225 *);
	void (*dev_release)(struct device___225 *);
	int (*shutdown_pre)(struct device___225 *);
	const struct kobj_ns_type_operations___42 *ns_type;
	const void * (*namespace)(struct device___225 *);
	void (*get_ownership)(struct device___225 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___225 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___85;

struct pipe_buffer___85 {
	struct page___249 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___85 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___85 {
	int (*confirm)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
	void (*release)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
	bool (*try_steal)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
	bool (*get)(struct pipe_inode_info___85 *, struct pipe_buffer___85 *);
};

struct seq_operations___219 {
	void * (*start)(struct seq_file___219 *, loff_t *);
	void (*stop)(struct seq_file___219 *, void *);
	void * (*next)(struct seq_file___219 *, void *, loff_t *);
	int (*show)(struct seq_file___219 *, void *);
};

struct dcbnl_rtnl_ops___53 {
	int (*ieee_getets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___54 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___54 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___54 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___54 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___54 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___54 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___54 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___54 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___54 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___54 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___54 *);
	u8 (*setstate)(struct net_device___54 *, u8);
	void (*getpermhwaddr)(struct net_device___54 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___54 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___54 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___54 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___54 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___54 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___54 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___54 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___54 *, int, u8 *);
	void (*setpfccfg)(struct net_device___54 *, int, u8);
	void (*getpfccfg)(struct net_device___54 *, int, u8 *);
	u8 (*setall)(struct net_device___54 *);
	u8 (*getcap)(struct net_device___54 *, int, u8 *);
	int (*getnumtcs)(struct net_device___54 *, int, u8 *);
	int (*setnumtcs)(struct net_device___54 *, int, u8);
	u8 (*getpfcstate)(struct net_device___54 *);
	void (*setpfcstate)(struct net_device___54 *, u8);
	void (*getbcncfg)(struct net_device___54 *, int, u32 *);
	void (*setbcncfg)(struct net_device___54 *, int, u32);
	void (*getbcnrp)(struct net_device___54 *, int, u8 *);
	void (*setbcnrp)(struct net_device___54 *, int, u8);
	int (*setapp)(struct net_device___54 *, u8, u16, u8);
	int (*getapp)(struct net_device___54 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___54 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___54 *, int, u8);
	u8 (*getdcbx)(struct net_device___54 *);
	u8 (*setdcbx)(struct net_device___54 *, u8);
	int (*peer_getappinfo)(struct net_device___54 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___54 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___54 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___54 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___54 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___54 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___56;

typedef int (*bpf_iter_init_seq_priv_t___55)(void *, struct bpf_iter_aux_info___56 *);

struct bpf_map___56;

struct bpf_iter_aux_info___56 {
	struct bpf_map___56 *map;
};

struct bpf_iter_seq_info___55 {
	const struct seq_operations___219 *seq_ops;
	bpf_iter_init_seq_priv_t___55 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___55 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___56 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___56 *, struct file___244 *);
	void (*map_free)(struct bpf_map___56 *);
	int (*map_get_next_key)(struct bpf_map___56 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___56 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___56 *, void *);
	int (*map_lookup_batch)(struct bpf_map___56 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___56 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___56 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___56 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___56 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___56 *, void *);
	int (*map_update_elem)(struct bpf_map___56 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___56 *, void *);
	int (*map_push_elem)(struct bpf_map___56 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___56 *, void *);
	int (*map_peek_elem)(struct bpf_map___56 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___56 *, struct file___244 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___56 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___56 *, void *, struct seq_file___219 *);
	int (*map_check_btf)(const struct bpf_map___56 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___56 *, struct bpf_prog_aux___56 *);
	void (*map_poke_untrack)(struct bpf_map___56 *, struct bpf_prog_aux___56 *);
	void (*map_poke_run)(struct bpf_map___56 *, u32, struct bpf_prog___49 *, struct bpf_prog___49 *);
	int (*map_direct_value_addr)(const struct bpf_map___56 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___56 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___56 *, struct vm_area_struct___249 *);
	__poll_t (*map_poll)(struct bpf_map___56 *, struct file___244 *, struct poll_table_struct___167 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___56 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___56 *, const struct bpf_map___56 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___56 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___55 *iter_seq_info;
};

struct bpf_map___56 {
	const struct bpf_map_ops___55 *ops;
	struct bpf_map___56 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___111 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___55;

struct bpf_jit_poke_descriptor___55;

struct bpf_prog_ops___49;

struct btf_mod_pair___55;

struct bpf_prog_offload___53;

struct bpf_prog_aux___56 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___49 *dst_prog;
	struct bpf_trampoline___55 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___49 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___55 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___49 *ops;
	struct bpf_map___56 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___55 *used_btfs;
	struct bpf_prog___49 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___56 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___53 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___53;

struct bpf_map_dev_ops___53 {
	int (*map_get_next_key)(struct bpf_offloaded_map___53 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___53 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___53 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___53 *, void *);
};

struct bpf_offloaded_map___53 {
	struct bpf_map___56 map;
	struct net_device___54 *netdev;
	const struct bpf_map_dev_ops___53 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___49 {
	int (*test_run)(struct bpf_prog___49 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___53 {
	struct bpf_prog___49 *prog;
	struct net_device___54 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___55 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___49 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___228 *mod;
};

struct bpf_jit_poke_descriptor___55 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___56 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___55 {
	struct btf *btf;
	struct module___228 *module;
};

struct cftype___171;

struct cgroup_subsys___171 {
	struct cgroup_subsys_state___171 * (*css_alloc)(struct cgroup_subsys_state___171 *);
	int (*css_online)(struct cgroup_subsys_state___171 *);
	void (*css_offline)(struct cgroup_subsys_state___171 *);
	void (*css_released)(struct cgroup_subsys_state___171 *);
	void (*css_free)(struct cgroup_subsys_state___171 *);
	void (*css_reset)(struct cgroup_subsys_state___171 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___171 *, int);
	int (*css_extra_stat_show)(struct seq_file___219 *, struct cgroup_subsys_state___171 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___251 *, struct css_set___171 *);
	void (*cancel_fork)(struct task_struct___251 *, struct css_set___171 *);
	void (*fork)(struct task_struct___251 *);
	void (*exit)(struct task_struct___251 *);
	void (*release)(struct task_struct___251 *);
	void (*bind)(struct cgroup_subsys_state___171 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___171 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___171 *dfl_cftypes;
	struct cftype___171 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___171 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___171 *updated_children;
	struct cgroup___171 *updated_next;
};

struct cgroup_root___171 {
	struct kernfs_root___232 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___171 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___171 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___171 *ss;
	struct list_head node;
	struct kernfs_ops___232 *kf_ops;
	int (*open)(struct kernfs_open_file___232 *);
	void (*release)(struct kernfs_open_file___232 *);
	u64 (*read_u64)(struct cgroup_subsys_state___171 *, struct cftype___171 *);
	s64 (*read_s64)(struct cgroup_subsys_state___171 *, struct cftype___171 *);
	int (*seq_show)(struct seq_file___219 *, void *);
	void * (*seq_start)(struct seq_file___219 *, loff_t *);
	void * (*seq_next)(struct seq_file___219 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___219 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___171 *, struct cftype___171 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___171 *, struct cftype___171 *, s64);
	ssize_t (*write)(struct kernfs_open_file___232 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___232 *, struct poll_table_struct___167 *);
};

struct xdp_rxq_info___53 {
	struct net_device___54 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___53 {
	struct net_device___54 *dev;
};

struct xdp_buff___53 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___53 *rxq;
	struct xdp_txq_info___53 *txq;
	u32 frame_sz;
};

struct xdp_frame___53 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___54 *dev_rx;
};

struct netlink_callback___53 {
	struct sk_buff___54 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___54 *, struct netlink_callback___53 *);
	int (*done)(struct netlink_callback___53 *);
	void *data;
	struct module___228 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___53 {
	int (*create)(struct sk_buff___54 *, struct net_device___54 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___54 *, unsigned char *);
	int (*cache)(const struct neighbour___42 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___54 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___54 *);
};

struct netdev_queue___53 {
	struct net_device___54 *dev;
	struct Qdisc___49 *qdisc;
	struct Qdisc___49 *qdisc_sleeping;
	struct kobject___232 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___54 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___49 {
	struct sk_buff___54 *head;
	struct sk_buff___54 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___49;

struct Qdisc___49 {
	int (*enqueue)(struct sk_buff___54 *, struct Qdisc___49 *, struct sk_buff___54 **);
	struct sk_buff___54 * (*dequeue)(struct Qdisc___49 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___49 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___53 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___53 gso_skb;
	struct qdisc_skb_head___49 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___49 *next_sched;
	struct sk_buff_head___53 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___53 {
	struct xdp_rxq_info___53 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___232 kobj;
	struct net_device___54 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___53 {
	enum net_device_path_type type;
	const struct net_device___54 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___53 = 0,
				DEV_PATH_BR_VLAN_TAG___53 = 1,
				DEV_PATH_BR_VLAN_UNTAG___53 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___53 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___53 {
	const struct net_device___54 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___53 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___49 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___53 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___53 {
	int (*xdo_dev_state_add)(struct xfrm_state___5 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___5 *);
	void (*xdo_dev_state_free)(struct xfrm_state___5 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___54 *, struct xfrm_state___5 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___5 *);
};

struct xfrm_state_offload___5 {
	struct net_device___54 *dev;
	struct net_device___54 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___5;

struct xfrm_type_offload___5;

struct xfrm_state___5 {
	possible_net_t___53 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___43 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___5 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___5 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___249 xfrag;
	const struct xfrm_type___5 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___5 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___53 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___54 *dev;
	const char *name;
};

struct net_device_ops___53 {
	int (*ndo_init)(struct net_device___54 *);
	void (*ndo_uninit)(struct net_device___54 *);
	int (*ndo_open)(struct net_device___54 *);
	int (*ndo_stop)(struct net_device___54 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___54 *, struct net_device___54 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___54 *, struct net_device___54 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___54 *, struct sk_buff___54 *, struct net_device___54 *);
	void (*ndo_change_rx_flags)(struct net_device___54 *, int);
	void (*ndo_set_rx_mode)(struct net_device___54 *);
	int (*ndo_set_mac_address)(struct net_device___54 *, void *);
	int (*ndo_validate_addr)(struct net_device___54 *);
	int (*ndo_do_ioctl)(struct net_device___54 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___54 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___54 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___54 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___54 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___54 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___54 *, int);
	int (*ndo_neigh_setup)(struct net_device___54 *, struct neigh_parms___42 *);
	void (*ndo_tx_timeout)(struct net_device___54 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___54 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___54 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___54 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___54 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___54 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___54 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___54 *);
	int (*ndo_netpoll_setup)(struct net_device___54 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___54 *);
	int (*ndo_set_vf_mac)(struct net_device___54 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___54 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___54 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___54 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___54 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___54 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___54 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___54 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___54 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___54 *, int, struct sk_buff___54 *);
	int (*ndo_get_vf_guid)(struct net_device___54 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___54 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___54 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___54 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___54 *);
	int (*ndo_fcoe_disable)(struct net_device___54 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___54 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___54 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___54 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___54 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___54 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___54 *, const struct sk_buff___54 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___54 *, struct net_device___54 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___54 *, struct net_device___54 *);
	struct net_device___54 * (*ndo_get_xmit_slave)(struct net_device___54 *, struct sk_buff___54 *, bool);
	struct net_device___54 * (*ndo_sk_get_lower_dev)(struct net_device___54 *, struct sock___43 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___54 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___54 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___54 *, struct neighbour___42 *);
	void (*ndo_neigh_destroy)(struct net_device___54 *, struct neighbour___42 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___54 *, struct netlink_callback___53 *, struct net_device___54 *, struct net_device___54 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___54 *, struct nlattr **, struct net_device___54 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___54 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___54 *, u32, u32, struct net_device___54 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___54 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___54 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___54 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___54 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___54 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___54 *, struct net_device___54 *);
	void (*ndo_dfwd_del_station)(struct net_device___54 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___54 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___54 *);
	int (*ndo_change_proto_down)(struct net_device___54 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___54 *, struct sk_buff___54 *);
	void (*ndo_set_rx_headroom)(struct net_device___54 *, int);
	int (*ndo_bpf)(struct net_device___54 *, struct netdev_bpf___53 *);
	int (*ndo_xdp_xmit)(struct net_device___54 *, int, struct xdp_frame___53 **, u32);
	struct net_device___54 * (*ndo_xdp_get_xmit_slave)(struct net_device___54 *, struct xdp_buff___53 *);
	int (*ndo_xsk_wakeup)(struct net_device___54 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___54 *);
	int (*ndo_tunnel_ctl)(struct net_device___54 *, struct ip_tunnel_parm *, int);
	struct net_device___54 * (*ndo_get_peer_dev)(struct net_device___54 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___53 *, struct net_device_path___53 *);
};

struct neigh_parms___42 {
	possible_net_t___53 net;
	struct net_device___54 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___42 *);
	struct neigh_table___42 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___42 {
	u32 (*l3mdev_fib_table)(const struct net_device___54 *);
	struct sk_buff___54 * (*l3mdev_l3_rcv)(struct net_device___54 *, struct sk_buff___54 *, u16);
	struct sk_buff___54 * (*l3mdev_l3_out)(struct net_device___54 *, struct sock___43 *, struct sk_buff___54 *, u16);
	struct dst_entry___42 * (*l3mdev_link_scope_lookup)(const struct net_device___54 *, struct flowi6 *);
};

struct ndisc_ops___29 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___54 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___54 *, struct neighbour___42 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___54 *, u8, struct neighbour___42 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___54 *, struct sk_buff___54 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___58 *, struct net_device___54 *, const struct prefix_info *, struct inet6_dev___29 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___29;

struct ifacaddr6___7;

struct inet6_dev___29 {
	struct net_device___54 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___29 *mc_list;
	struct ifmcaddr6___29 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___53 mc_query_queue;
	struct sk_buff_head___53 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___7 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___42 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___49;

struct tcf_block___49;

struct mini_Qdisc___49 {
	struct tcf_proto___49 *filter_list;
	struct tcf_block___49 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___49 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___54 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___54 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___58 *, struct net_device___54 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___54 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___54 *, struct list_head *);
	size_t (*get_size)(const struct net_device___54 *);
	int (*fill_info)(struct sk_buff___54 *, const struct net_device___54 *);
	size_t (*get_xstats_size)(const struct net_device___54 *);
	int (*fill_xstats)(struct sk_buff___54 *, const struct net_device___54 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___54 *, struct net_device___54 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___54 *, const struct net_device___54 *);
	int (*fill_slave_info)(struct sk_buff___54 *, const struct net_device___54 *, const struct net_device___54 *);
	struct net___58 * (*get_link_net)(const struct net_device___54 *);
	size_t (*get_linkxstats_size)(const struct net_device___54 *, int);
	int (*fill_linkxstats)(struct sk_buff___54 *, const struct net_device___54 *, int *, int);
};

struct pneigh_entry___42;

struct neigh_hash_table___42;

struct neigh_table___42 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___54 *, __u32 *);
	bool (*key_eq)(const struct neighbour___42 *, const void *);
	int (*constructor)(struct neighbour___42 *);
	int (*pconstructor)(struct pneigh_entry___42 *);
	void (*pdestructor)(struct pneigh_entry___42 *);
	void (*proxy_redo)(struct sk_buff___54 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___54 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___42 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___53 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___42 *nht;
	struct pneigh_entry___42 **phash_buckets;
};

struct neigh_ops___42 {
	int family;
	void (*solicit)(struct neighbour___42 *, struct sk_buff___54 *);
	void (*error_report)(struct neighbour___42 *, struct sk_buff___54 *);
	int (*output)(struct neighbour___42 *, struct sk_buff___54 *);
	int (*connected_output)(struct neighbour___42 *, struct sk_buff___54 *);
};

struct pneigh_entry___42 {
	struct pneigh_entry___42 *next;
	possible_net_t___53 net;
	struct net_device___54 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___42 {
	struct neighbour___42 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___24 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___58 *, struct sock___43 *, struct sk_buff___54 *);
	int (*orig_input)(struct sk_buff___54 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct block_device_operations___137;

struct gendisk___140 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___140 *part0;
	const struct block_device_operations___137 *fops;
	struct request_queue___137 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___123 *bdi;
	struct kobject___232 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___232 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___137 {
	struct bio___137 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___161 *bip_vec;
	struct bio_vec___161 bip_inline_vecs[0];
};

struct blkcg___125;

struct blkg_policy_data___125;

struct blkcg_gq___125 {
	struct request_queue___137 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___125 *blkcg;
	struct blkcg_gq___125 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___125 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___137 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___137(struct request___137 *);

typedef void integrity_complete_fn___137(struct request___137 *, unsigned int);

struct blk_integrity_profile___137 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___137 *prepare_fn;
	integrity_complete_fn___137 *complete_fn;
	const char *name;
};

struct block_device_operations___137 {
	blk_qc_t (*submit_bio)(struct bio___137 *);
	int (*open)(struct block_device___140 *, fmode_t);
	void (*release)(struct gendisk___140 *, fmode_t);
	int (*rw_page)(struct block_device___140 *, sector_t, struct page___249 *, unsigned int);
	int (*ioctl)(struct block_device___140 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___140 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___140 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___140 *);
	int (*getgeo)(struct block_device___140 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___140 *, bool);
	void (*swap_slot_free_notify)(struct block_device___140 *, long unsigned int);
	int (*report_zones)(struct gendisk___140 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___140 *, umode_t *);
	struct module___228 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___140 *, sector_t *);
};

typedef void rq_end_io_fn___137(struct request___137 *, blk_status_t);

struct request___137 {
	struct request_queue___137 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___132 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___137 *bio;
	struct bio___137 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___161 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___137 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___137 *saved_end_io;
		} flush;
	};
	struct gendisk___140 *rq_disk;
	struct block_device___140 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___137 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___132 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___137 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___232 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___244 *debugfs_dir;
	struct dentry___244 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___137;

struct elevator_mq_ops___137 {
	int (*init_sched)(struct request_queue___137 *, struct elevator_type___137 *);
	void (*exit_sched)(struct elevator_queue___137 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___132 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___132 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___132 *);
	bool (*allow_merge)(struct request_queue___137 *, struct request___137 *, struct bio___137 *);
	bool (*bio_merge)(struct request_queue___137 *, struct bio___137 *, unsigned int);
	int (*request_merge)(struct request_queue___137 *, struct request___137 **, struct bio___137 *);
	void (*request_merged)(struct request_queue___137 *, struct request___137 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___137 *, struct request___137 *, struct request___137 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___137 *);
	void (*finish_request)(struct request___137 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___132 *, struct list_head *, bool);
	struct request___137 * (*dispatch_request)(struct blk_mq_hw_ctx___132 *);
	bool (*has_work)(struct blk_mq_hw_ctx___132 *);
	void (*completed_request)(struct request___137 *, u64);
	void (*requeue_request)(struct request___137 *);
	struct request___137 * (*former_request)(struct request_queue___137 *, struct request___137 *);
	struct request___137 * (*next_request)(struct request_queue___137 *, struct request___137 *);
	void (*init_icq)(struct io_cq___137 *);
	void (*exit_icq)(struct io_cq___137 *);
};

struct elv_fs_entry___137;

struct elevator_type___137 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___137 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___137 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___228 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___137 {
	struct elevator_type___137 *type;
	void *elevator_data;
	struct kobject___232 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___137 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___137 *, char *);
	ssize_t (*store)(struct elevator_queue___137 *, const char *, size_t);
};

struct blk_mq_queue_data___132;

struct blk_mq_ops___132 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___132 *, const struct blk_mq_queue_data___132 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___132 *);
	int (*get_budget)(struct request_queue___137 *);
	void (*put_budget)(struct request_queue___137 *, int);
	void (*set_rq_budget_token)(struct request___137 *, int);
	int (*get_rq_budget_token)(struct request___137 *);
	enum blk_eh_timer_return (*timeout)(struct request___137 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___132 *);
	void (*complete)(struct request___137 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___132 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___132 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___132 *, struct request___137 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___132 *, struct request___137 *, unsigned int);
	void (*initialize_rq_fn)(struct request___137 *);
	void (*cleanup_rq)(struct request___137 *);
	bool (*busy)(struct request_queue___137 *);
	int (*map_queues)(struct blk_mq_tag_set___132 *);
	void (*show_rq)(struct seq_file___219 *, struct request___137 *);
};

struct blk_mq_tag_set___132 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___132 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___132 {
	struct request___137 *rq;
	bool last;
};

struct blkcg_policy_data___125;

struct blkcg___125 {
	struct cgroup_subsys_state___171 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___125 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___125 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___125 {
	struct blkcg___125 *blkcg;
	int plid;
};

struct blkg_policy_data___125 {
	struct blkcg_gq___125 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___111 {
	struct mem_cgroup___111 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___111 {
	struct lruvec___119 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___111 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___111 *memcg;
};

struct obj_cgroup___111 {
	struct percpu_ref refcnt;
	struct mem_cgroup___111 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___49 {
	spinlock_t *lock;
	struct sk_buff___54 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___49;

struct Qdisc_ops___49 {
	struct Qdisc_ops___49 *next;
	const struct Qdisc_class_ops___49 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___54 *, struct Qdisc___49 *, struct sk_buff___54 **);
	struct sk_buff___54 * (*dequeue)(struct Qdisc___49 *);
	struct sk_buff___54 * (*peek)(struct Qdisc___49 *);
	int (*init)(struct Qdisc___49 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___49 *);
	void (*destroy)(struct Qdisc___49 *);
	int (*change)(struct Qdisc___49 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___49 *);
	int (*change_tx_queue_len)(struct Qdisc___49 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___49 *, unsigned int);
	int (*dump)(struct Qdisc___49 *, struct sk_buff___54 *);
	int (*dump_stats)(struct Qdisc___49 *, struct gnet_dump___49 *);
	void (*ingress_block_set)(struct Qdisc___49 *, u32);
	void (*egress_block_set)(struct Qdisc___49 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___49 *);
	u32 (*egress_block_get)(struct Qdisc___49 *);
	struct module___228 *owner;
};

struct Qdisc_class_ops___49 {
	unsigned int flags;
	struct netdev_queue___53 * (*select_queue)(struct Qdisc___49 *, struct tcmsg *);
	int (*graft)(struct Qdisc___49 *, long unsigned int, struct Qdisc___49 *, struct Qdisc___49 **, struct netlink_ext_ack *);
	struct Qdisc___49 * (*leaf)(struct Qdisc___49 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___49 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___49 *, u32);
	int (*change)(struct Qdisc___49 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___49 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___49 *, struct qdisc_walker *);
	struct tcf_block___49 * (*tcf_block)(struct Qdisc___49 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___49 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___49 *, long unsigned int);
	int (*dump)(struct Qdisc___49 *, long unsigned int, struct sk_buff___54 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___49 *, long unsigned int, struct gnet_dump___49 *);
};

struct tcf_chain___49;

struct tcf_block___49 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___58 *net;
	struct Qdisc___49 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___49 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___49;

struct tcf_proto_ops___49;

struct tcf_proto___49 {
	struct tcf_proto___49 *next;
	void *root;
	int (*classify)(struct sk_buff___54 *, const struct tcf_proto___49 *, struct tcf_result___49 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___49 *ops;
	struct tcf_chain___49 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___49 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___49 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___49 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___54 *, const struct tcf_proto___49 *, struct tcf_result___49 *);
	int (*init)(struct tcf_proto___49 *);
	void (*destroy)(struct tcf_proto___49 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___49 *, u32);
	void (*put)(struct tcf_proto___49 *, void *);
	int (*change)(struct net___58 *, struct sk_buff___54 *, struct tcf_proto___49 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___49 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___49 *);
	void (*walk)(struct tcf_proto___49 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___49 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___49 *, void *);
	void (*hw_del)(struct tcf_proto___49 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___58 *, struct tcf_chain___49 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___58 *, struct tcf_proto___49 *, void *, struct sk_buff___54 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___58 *, struct tcf_proto___49 *, void *, struct sk_buff___54 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___54 *, struct net___58 *, void *);
	struct module___228 *owner;
	int flags;
};

struct tcf_chain___49 {
	struct mutex filter_chain_lock;
	struct tcf_proto___49 *filter_chain;
	struct list_head list;
	struct tcf_block___49 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___49 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___42 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___49 *prog;
};

struct fib_rule___42 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___42 *ctarget;
	struct net___58 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___42 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___42 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___31;

struct timewait_sock_ops___31;

struct proto___42 {
	void (*close)(struct sock___43 *, long int);
	int (*pre_connect)(struct sock___43 *, struct sockaddr *, int);
	int (*connect)(struct sock___43 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___43 *, int);
	struct sock___43 * (*accept)(struct sock___43 *, int, int *, bool);
	int (*ioctl)(struct sock___43 *, int, long unsigned int);
	int (*init)(struct sock___43 *);
	void (*destroy)(struct sock___43 *);
	void (*shutdown)(struct sock___43 *, int);
	int (*setsockopt)(struct sock___43 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___43 *, int, int, char *, int *);
	void (*keepalive)(struct sock___43 *, int);
	int (*compat_ioctl)(struct sock___43 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___43 *, struct msghdr___44 *, size_t);
	int (*recvmsg)(struct sock___43 *, struct msghdr___44 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___43 *, struct page___249 *, int, size_t, int);
	int (*bind)(struct sock___43 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___43 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___43 *, struct sk_buff___54 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___43 *);
	int (*hash)(struct sock___43 *);
	void (*unhash)(struct sock___43 *);
	void (*rehash)(struct sock___43 *);
	int (*get_port)(struct sock___43 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___43 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___43 *, int);
	bool (*sock_is_readable)(struct sock___43 *);
	void (*enter_memory_pressure)(struct sock___43 *);
	void (*leave_memory_pressure)(struct sock___43 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___31 *rsk_prot;
	struct timewait_sock_ops___31 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___228 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___43 *, int);
};

struct xfrm_policy_queue___5 {
	struct sk_buff_head___53 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___5 {
	possible_net_t___53 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___5 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct request_sock___32;

struct request_sock_ops___31 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___43 *, struct request_sock___32 *);
	void (*send_ack)(const struct sock___43 *, struct sk_buff___54 *, struct request_sock___32 *);
	void (*send_reset)(const struct sock___43 *, struct sk_buff___54 *);
	void (*destructor)(struct request_sock___32 *);
	void (*syn_ack_timeout)(const struct request_sock___32 *);
};

struct timewait_sock_ops___31 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___43 *, struct sock___43 *, void *);
	void (*twsk_destructor)(struct sock___43 *);
};

struct request_sock___32 {
	struct sock_common___42 __req_common;
	struct request_sock___32 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___31 *rsk_ops;
	struct sock___43 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___29 {
	struct in6_addr mca_addr;
	struct inet6_dev___29 *idev;
	struct ifmcaddr6___29 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___7 {
	struct in6_addr aca_addr;
	struct fib6_info___7 *aca_rt;
	struct ifacaddr6___7 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___7 {
	struct fib_nh_exception___7 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___7 *fnhe_rth_input;
	struct rtable___7 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___7 {
	struct dst_entry___42 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___7 {
	struct fib_nh_exception___7 *chain;
};

struct fib_info___4;

struct fib_nh___4 {
	struct fib_nh_common___7 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___4 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___4 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___58 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___4 *nh;
	struct callback_head rcu;
	struct fib_nh___4 fib_nh[0];
};

struct nh_info___4;

struct nh_group___4;

struct nexthop___4 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___58 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___4 *nh_info;
		struct nh_group___4 *nh_grp;
	};
};

struct xfrm_type___5 {
	struct module___228 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___5 *);
	void (*destructor)(struct xfrm_state___5 *);
	int (*input)(struct xfrm_state___5 *, struct sk_buff___54 *);
	int (*output)(struct xfrm_state___5 *, struct sk_buff___54 *);
	int (*reject)(struct xfrm_state___5 *, struct sk_buff___54 *, const struct flowi *);
};

struct xfrm_type_offload___5 {
	struct module___228 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___5 *, struct sk_buff___54 *);
	int (*input_tail)(struct xfrm_state___5 *, struct sk_buff___54 *);
	int (*xmit)(struct xfrm_state___5 *, struct sk_buff___54 *, netdev_features_t);
};

struct xfrm_dst___3 {
	union {
		struct dst_entry___42 dst;
		struct rtable___7 rt;
		struct rt6_info___7 rt6;
	} u;
	struct dst_entry___42 *route;
	struct dst_entry___42 *child;
	struct dst_entry___42 *path;
	struct xfrm_policy___5 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct nh_info___4 {
	struct hlist_node dev_hash;
	struct nexthop___4 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___7 fib_nhc;
		struct fib_nh___4 fib_nh;
		struct fib6_nh___7 fib6_nh;
	};
};

struct nh_grp_entry___4;

struct nh_res_bucket___4 {
	struct nh_grp_entry___4 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___4 {
	struct nexthop___4 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___4 *nh_parent;
};

struct nh_res_table___4 {
	struct net___58 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___4 nh_buckets[0];
};

struct nh_group___4 {
	struct nh_group___4 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___4 *res_table;
	struct nh_grp_entry___4 nh_entries[0];
};

struct hw_port_info___3 {
	struct net_device___54 *lower_dev;
	u32 port_id;
};

struct metadata_dst___3 {
	struct dst_entry___42 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___3 port_info;
	} u;
};

struct atomic_notifier_head___2 {
	spinlock_t___2 lock;
	struct notifier_block *head;
};

struct netlink_skb_parms___6 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___42 *sk;
	bool nsid_is_set;
	int nsid;
};

enum {
	NDA_UNSPEC = 0,
	NDA_DST = 1,
	NDA_LLADDR = 2,
	NDA_CACHEINFO = 3,
	NDA_PROBES = 4,
	NDA_VLAN = 5,
	NDA_PORT = 6,
	NDA_VNI = 7,
	NDA_IFINDEX = 8,
	NDA_MASTER = 9,
	NDA_LINK_NETNSID = 10,
	NDA_SRC_VNI = 11,
	NDA_PROTOCOL = 12,
	NDA_NH_ID = 13,
	NDA_FDB_EXT_ATTRS = 14,
	__NDA_MAX = 15,
};

struct nda_cacheinfo {
	__u32 ndm_confirmed;
	__u32 ndm_used;
	__u32 ndm_updated;
	__u32 ndm_refcnt;
};

struct ndt_stats {
	__u64 ndts_allocs;
	__u64 ndts_destroys;
	__u64 ndts_hash_grows;
	__u64 ndts_res_failed;
	__u64 ndts_lookups;
	__u64 ndts_hits;
	__u64 ndts_rcv_probes_mcast;
	__u64 ndts_rcv_probes_ucast;
	__u64 ndts_periodic_gc_runs;
	__u64 ndts_forced_gc_runs;
	__u64 ndts_table_fulls;
};

enum {
	NDTPA_UNSPEC = 0,
	NDTPA_IFINDEX = 1,
	NDTPA_REFCNT = 2,
	NDTPA_REACHABLE_TIME = 3,
	NDTPA_BASE_REACHABLE_TIME = 4,
	NDTPA_RETRANS_TIME = 5,
	NDTPA_GC_STALETIME = 6,
	NDTPA_DELAY_PROBE_TIME = 7,
	NDTPA_QUEUE_LEN = 8,
	NDTPA_APP_PROBES = 9,
	NDTPA_UCAST_PROBES = 10,
	NDTPA_MCAST_PROBES = 11,
	NDTPA_ANYCAST_DELAY = 12,
	NDTPA_PROXY_DELAY = 13,
	NDTPA_PROXY_QLEN = 14,
	NDTPA_LOCKTIME = 15,
	NDTPA_QUEUE_LENBYTES = 16,
	NDTPA_MCAST_REPROBES = 17,
	NDTPA_PAD = 18,
	__NDTPA_MAX = 19,
};

struct ndtmsg {
	__u8 ndtm_family;
	__u8 ndtm_pad1;
	__u16 ndtm_pad2;
};

struct ndt_config {
	__u16 ndtc_key_len;
	__u16 ndtc_entry_size;
	__u32 ndtc_entries;
	__u32 ndtc_last_flush;
	__u32 ndtc_last_rand;
	__u32 ndtc_hash_rnd;
	__u32 ndtc_hash_mask;
	__u32 ndtc_hash_chain_gc;
	__u32 ndtc_proxy_qlen;
};

enum {
	NDTA_UNSPEC = 0,
	NDTA_NAME = 1,
	NDTA_THRESH1 = 2,
	NDTA_THRESH2 = 3,
	NDTA_THRESH3 = 4,
	NDTA_CONFIG = 5,
	NDTA_PARMS = 6,
	NDTA_STATS = 7,
	NDTA_GC_INTERVAL = 8,
	NDTA_PAD = 9,
	__NDTA_MAX = 10,
};

enum {
	RTN_UNSPEC = 0,
	RTN_UNICAST = 1,
	RTN_LOCAL = 2,
	RTN_BROADCAST = 3,
	RTN_ANYCAST = 4,
	RTN_MULTICAST = 5,
	RTN_BLACKHOLE = 6,
	RTN_UNREACHABLE = 7,
	RTN_PROHIBIT = 8,
	RTN_THROW = 9,
	RTN_NAT = 10,
	RTN_XRESOLVE = 11,
	__RTN_MAX = 12,
};

typedef int (*rtnl_doit_func___2)(struct sk_buff___53 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___2)(struct sk_buff___53 *, struct netlink_callback___52 *);

enum {
	NEIGH_ARP_TABLE = 0,
	NEIGH_ND_TABLE = 1,
	NEIGH_DN_TABLE = 2,
	NEIGH_NR_TABLES = 3,
	NEIGH_LINK_TABLE = 3,
};

struct neigh_seq_state {
	struct seq_net_private___2 p;
	struct neigh_table___41 *tbl;
	struct neigh_hash_table___41 *nht;
	void * (*neigh_sub_iter)(struct neigh_seq_state *, struct neighbour___41 *, loff_t *);
	unsigned int bucket;
	unsigned int flags;
};

struct neighbour_cb {
	long unsigned int sched_next;
	unsigned int flags;
};

enum netevent_notif_type {
	NETEVENT_NEIGH_UPDATE = 1,
	NETEVENT_REDIRECT = 2,
	NETEVENT_DELAY_PROBE_TIME_UPDATE = 3,
	NETEVENT_IPV4_MPATH_HASH_UPDATE = 4,
	NETEVENT_IPV6_MPATH_HASH_UPDATE = 5,
	NETEVENT_IPV4_FWD_UPDATE_PRIORITY_UPDATE = 6,
};

struct neigh_dump_filter {
	int master_idx;
	int dev_idx;
};

struct neigh_sysctl_table {
	struct ctl_table_header *sysctl_header;
	struct ctl_table neigh_vars[21];
};

struct dentry___245;

struct super_block___245;

struct module___229;

struct file_system_type___245 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___245 * (*mount)(struct file_system_type___245 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___245 *);
	struct module___229 *owner;
	struct file_system_type___245 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___245;

struct kiocb___245;

struct iov_iter___165;

struct poll_table_struct___168;

struct vm_area_struct___250;

struct inode___245;

struct file_lock___245;

struct page___250;

struct pipe_inode_info___86;

struct seq_file___220;

struct file_operations___246 {
	struct module___229 *owner;
	loff_t (*llseek)(struct file___245 *, loff_t, int);
	ssize_t (*read)(struct file___245 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___245 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___245 *, struct iov_iter___165 *);
	ssize_t (*write_iter)(struct kiocb___245 *, struct iov_iter___165 *);
	int (*iopoll)(struct kiocb___245 *, bool);
	int (*iterate)(struct file___245 *, struct dir_context *);
	int (*iterate_shared)(struct file___245 *, struct dir_context *);
	__poll_t (*poll)(struct file___245 *, struct poll_table_struct___168 *);
	long int (*unlocked_ioctl)(struct file___245 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___245 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___245 *, struct vm_area_struct___250 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___245 *, struct file___245 *);
	int (*flush)(struct file___245 *, fl_owner_t);
	int (*release)(struct inode___245 *, struct file___245 *);
	int (*fsync)(struct file___245 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___245 *, int);
	int (*lock)(struct file___245 *, int, struct file_lock___245 *);
	ssize_t (*sendpage)(struct file___245 *, struct page___250 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___245 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___245 *, long unsigned int);
	int (*flock)(struct file___245 *, int, struct file_lock___245 *);
	ssize_t (*splice_write)(struct pipe_inode_info___86 *, struct file___245 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___245 *, loff_t *, struct pipe_inode_info___86 *, size_t, unsigned int);
	int (*setlease)(struct file___245 *, long int, struct file_lock___245 **, void **);
	long int (*fallocate)(struct file___245 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___220 *, struct file___245 *);
	ssize_t (*copy_file_range)(struct file___245 *, loff_t, struct file___245 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___245 *, loff_t, struct file___245 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___245 *, loff_t, loff_t, int);
};

struct vmacache___250 {
	u64 seqnum;
	struct vm_area_struct___250 *vmas[4];
};

struct page_frag___250 {
	struct page___250 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___251;

struct pid___222;

struct nsproxy___231;

struct signal_struct___246;

struct bio_list___138;

struct backing_dev_info___124;

struct io_context___138;

struct css_set___172;

struct mem_cgroup___112;

struct request_queue___138;

struct vm_struct___228;

struct task_struct___252 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___252 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___251 *mm;
	struct mm_struct___251 *active_mm;
	struct vmacache___250 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___252 *real_parent;
	struct task_struct___252 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___252 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___222 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___231 *nsproxy;
	struct signal_struct___246 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___252 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___138 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___124 *backing_dev_info;
	struct io_context___138 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___172 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___86 *splice_pipe;
	struct page_frag___250 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___112 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___112 *active_memcg;
	struct request_queue___138 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___252 *oom_reaper_list;
	struct vm_struct___228 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___233;

struct kobj_type___233;

struct kernfs_node___233;

struct kobject___233 {
	const char *name;
	struct list_head entry;
	struct kobject___233 *parent;
	struct kset___233 *kset;
	struct kobj_type___233 *ktype;
	struct kernfs_node___233 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___230 {
	struct kobject___233 kobj;
	struct module___229 *mod;
	struct kobject___233 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___229 {
	struct module___229 *mod;
	struct latch_tree_node node;
};

struct module_layout___229 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___229 mtn;
};

struct module_attribute___229;

struct kernel_param___229;

struct module___229 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___230 mkobj;
	struct module_attribute___229 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___233 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___229 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___229 core_layout;
	struct module_layout___229 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___222;

struct upid___222 {
	int nr;
	struct pid_namespace___222 *ns;
};

struct pid_namespace___222 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___252 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___222 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___222 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___222 numbers[1];
};

typedef struct page___250 *pgtable_t___250;

struct address_space___245;

struct page_pool___74;

struct dev_pagemap___240;

struct page___250 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___245 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___74 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___250 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___250 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___251 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___240 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___240;

struct vm_area_struct___250 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___250 *vm_next;
	struct vm_area_struct___250 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___251 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___240 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___245 *vm_file;
	struct file___245 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___246 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___252 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___252 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___222 *pids[4];
	struct pid___222 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___251 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___250;

struct mm_struct___251 {
	struct {
		struct vm_area_struct___250 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___245 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___250 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___252 *owner;
		struct user_namespace___26 *user_ns;
		struct file___245 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___59;

struct cgroup_namespace___172;

struct nsproxy___231 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___222 *pid_ns_for_children;
	struct net___59 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___172 *cgroup_ns;
};

struct bio___138;

struct bio_list___138 {
	struct bio___138 *head;
	struct bio___138 *tail;
};

struct cgroup_subsys_state___172;

struct bdi_writeback___124 {
	struct backing_dev_info___124 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___172 *memcg_css;
	struct cgroup_subsys_state___172 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___226;

struct backing_dev_info___124 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___124 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___226 *dev;
	char dev_name[64];
	struct device___226 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___245 *debug_dir;
};

struct io_cq___138;

struct io_context___138 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___138 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___172;

struct css_set___172 {
	struct cgroup_subsys_state___172 *subsys[14];
	refcount_t refcount;
	struct css_set___172 *dom_cset;
	struct cgroup___172 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___172 *mg_src_cgrp;
	struct cgroup___172 *mg_dst_cgrp;
	struct css_set___172 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___245;

struct pipe_buffer___86;

struct pipe_inode_info___86 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___250 *tmp_page;
	struct fasync_struct___245 *fasync_readers;
	struct fasync_struct___245 *fasync_writers;
	struct pipe_buffer___86 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___172;

struct cgroup_subsys_state___172 {
	struct cgroup___172 *cgroup;
	struct cgroup_subsys___172 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___172 *parent;
};

struct cgroup_file___172 {
	struct kernfs_node___233 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___112;

struct mem_cgroup_per_node___112;

struct mem_cgroup___112 {
	struct cgroup_subsys_state___172 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___172 events_file;
	struct cgroup_file___172 events_local_file;
	struct cgroup_file___172 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___112 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___252 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___112 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___138;

struct blk_integrity___138 {
	const struct blk_integrity_profile___138 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___138 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___138 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___138;

struct elevator_queue___138;

struct blk_mq_ops___133;

struct blk_mq_hw_ctx___133;

struct gendisk___141;

struct blkcg_gq___126;

struct blk_mq_tag_set___133;

struct request_queue___138 {
	struct request___138 *last_merge;
	struct elevator_queue___138 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___133 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___133 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___141 *disk;
	struct kobject___233 kobj;
	struct kobject___233 *mq_kobj;
	struct blk_integrity___138 integrity;
	struct device___226 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___126 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___133 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___138 bio_split;
	struct dentry___245 *debugfs_dir;
	struct dentry___245 *sched_debugfs_dir;
	struct dentry___245 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___228 {
	struct vm_struct___228 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___250 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___245;

struct address_space___245 {
	struct inode___245 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___245 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___74 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___226 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___74 {
	u32 count;
	struct page___250 *cache[128];
};

struct page_pool___74 {
	struct page_pool_params___74 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___250 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___74 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___240;

struct dev_pagemap___240 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___240 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___245;

struct path___245 {
	struct vfsmount___245 *mnt;
	struct dentry___245 *dentry;
};

struct fown_struct___222 {
	rwlock_t lock;
	struct pid___222 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___245 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___245 f_path;
	struct inode___245 *f_inode;
	const struct file_operations___246 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___222 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___245 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___240;

struct vm_operations_struct___240 {
	void (*open)(struct vm_area_struct___250 *);
	void (*close)(struct vm_area_struct___250 *);
	int (*may_split)(struct vm_area_struct___250 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___250 *);
	int (*mprotect)(struct vm_area_struct___250 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___240 *);
	vm_fault_t (*huge_fault)(struct vm_fault___240 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___240 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___250 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___240 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___240 *);
	int (*access)(struct vm_area_struct___250 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___250 *);
	int (*set_policy)(struct vm_area_struct___250 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___250 *, long unsigned int);
	struct page___250 * (*find_special_page)(struct vm_area_struct___250 *, long unsigned int);
};

struct core_thread___250 {
	struct task_struct___252 *task;
	struct core_thread___250 *next;
};

struct core_state___250 {
	atomic_t nr_threads;
	struct core_thread___250 dumper;
	struct completion startup;
};

struct vm_fault___240 {
	const struct {
		struct vm_area_struct___250 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___250 *cow_page;
	struct page___250 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___250 prealloc_pte;
};

struct pglist_data___120;

struct lruvec___120 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___120 *pgdat;
};

struct zone___120 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___120 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___120 {
	struct zone___120 *zone;
	int zone_idx;
};

struct zonelist___120 {
	struct zoneref___120 _zonerefs[321];
};

struct pglist_data___120 {
	struct zone___120 node_zones[5];
	struct zonelist___120 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___252 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___252 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___120 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___245;

struct dentry___245 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___245 *d_parent;
	struct qstr d_name;
	struct inode___245 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___245 *d_op;
	struct super_block___245 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___245;

struct inode___245 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___245 *i_op;
	struct super_block___245 *i_sb;
	struct address_space___245 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___124 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___246 *i_fop;
		void (*free_inode)(struct inode___245 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___245 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___86 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___245 {
	int (*d_revalidate)(struct dentry___245 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___245 *, unsigned int);
	int (*d_hash)(const struct dentry___245 *, struct qstr *);
	int (*d_compare)(const struct dentry___245 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___245 *);
	int (*d_init)(struct dentry___245 *);
	void (*d_release)(struct dentry___245 *);
	void (*d_prune)(struct dentry___245 *);
	void (*d_iput)(struct dentry___245 *, struct inode___245 *);
	char * (*d_dname)(struct dentry___245 *, char *, int);
	struct vfsmount___245 * (*d_automount)(struct path___245 *);
	int (*d_manage)(const struct path___245 *, bool);
	struct dentry___245 * (*d_real)(struct dentry___245 *, const struct inode___245 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___245;

struct mem_dqinfo___245 {
	struct quota_format_type___245 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___245;

struct quota_info___245 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___245 *files[3];
	struct mem_dqinfo___245 info[3];
	const struct quota_format_ops___245 *ops[3];
};

struct rcuwait___246 {
	struct task_struct___252 *task;
};

struct percpu_rw_semaphore___246 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___246 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___245 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___246 rw_sem[3];
};

struct shrink_control___112;

struct shrinker___112 {
	long unsigned int (*count_objects)(struct shrinker___112 *, struct shrink_control___112 *);
	long unsigned int (*scan_objects)(struct shrinker___112 *, struct shrink_control___112 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___245;

struct dquot_operations___245;

struct quotactl_ops___245;

struct block_device___141;

struct super_block___245 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___245 *s_type;
	const struct super_operations___245 *s_op;
	const struct dquot_operations___245 *dq_op;
	const struct quotactl_ops___245 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___245 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___141 *s_bdev;
	struct backing_dev_info___124 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___245 s_dquot;
	struct sb_writers___245 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___245 *s_d_op;
	int cleancache_poolid;
	struct shrinker___112 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___245 {
	struct dentry___245 *mnt_root;
	struct super_block___245 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___112 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___112 *memcg;
};

struct psi_group___172 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___252 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___50;

struct cgroup_bpf___50 {
	struct bpf_prog_array___50 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___50 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___172;

struct cgroup_rstat_cpu___172;

struct cgroup___172 {
	struct cgroup_subsys_state___172 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___233 *kn;
	struct cgroup_file___172 procs_file;
	struct cgroup_file___172 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___172 *subsys[14];
	struct cgroup_root___172 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___172 *dom_cgrp;
	struct cgroup___172 *old_dom_cgrp;
	struct cgroup_rstat_cpu___172 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___172 psi;
	struct cgroup_bpf___50 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___138 {
	struct request_queue___138 *q;
	struct io_context___138 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___245 {
	struct file___245 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___245 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___245 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___245 *ia_file;
};

struct dquot___245 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___245 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___245 {
	int qf_fmt_id;
	const struct quota_format_ops___245 *qf_ops;
	struct module___229 *qf_owner;
	struct quota_format_type___245 *qf_next;
};

struct quota_format_ops___245 {
	int (*check_quota_file)(struct super_block___245 *, int);
	int (*read_file_info)(struct super_block___245 *, int);
	int (*write_file_info)(struct super_block___245 *, int);
	int (*free_file_info)(struct super_block___245 *, int);
	int (*read_dqblk)(struct dquot___245 *);
	int (*commit_dqblk)(struct dquot___245 *);
	int (*release_dqblk)(struct dquot___245 *);
	int (*get_next_id)(struct super_block___245 *, struct kqid *);
};

struct dquot_operations___245 {
	int (*write_dquot)(struct dquot___245 *);
	struct dquot___245 * (*alloc_dquot)(struct super_block___245 *, int);
	void (*destroy_dquot)(struct dquot___245 *);
	int (*acquire_dquot)(struct dquot___245 *);
	int (*release_dquot)(struct dquot___245 *);
	int (*mark_dirty)(struct dquot___245 *);
	int (*write_info)(struct super_block___245 *, int);
	qsize_t * (*get_reserved_space)(struct inode___245 *);
	int (*get_projid)(struct inode___245 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___245 *, qsize_t *);
	int (*get_next_id)(struct super_block___245 *, struct kqid *);
};

struct quotactl_ops___245 {
	int (*quota_on)(struct super_block___245 *, int, int, const struct path___245 *);
	int (*quota_off)(struct super_block___245 *, int);
	int (*quota_enable)(struct super_block___245 *, unsigned int);
	int (*quota_disable)(struct super_block___245 *, unsigned int);
	int (*quota_sync)(struct super_block___245 *, int);
	int (*set_info)(struct super_block___245 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___245 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___245 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___245 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___245 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___245 *, unsigned int);
};

struct writeback_control___124;

struct address_space_operations___245 {
	int (*writepage)(struct page___250 *, struct writeback_control___124 *);
	int (*readpage)(struct file___245 *, struct page___250 *);
	int (*writepages)(struct address_space___245 *, struct writeback_control___124 *);
	int (*set_page_dirty)(struct page___250 *);
	int (*readpages)(struct file___245 *, struct address_space___245 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___245 *, struct address_space___245 *, loff_t, unsigned int, unsigned int, struct page___250 **, void **);
	int (*write_end)(struct file___245 *, struct address_space___245 *, loff_t, unsigned int, unsigned int, struct page___250 *, void *);
	sector_t (*bmap)(struct address_space___245 *, sector_t);
	void (*invalidatepage)(struct page___250 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___250 *, gfp_t);
	void (*freepage)(struct page___250 *);
	ssize_t (*direct_IO)(struct kiocb___245 *, struct iov_iter___165 *);
	int (*migratepage)(struct address_space___245 *, struct page___250 *, struct page___250 *, enum migrate_mode);
	bool (*isolate_page)(struct page___250 *, isolate_mode_t);
	void (*putback_page)(struct page___250 *);
	int (*launder_page)(struct page___250 *);
	int (*is_partially_uptodate)(struct page___250 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___250 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___245 *, struct page___250 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___245 *, sector_t *);
	void (*swap_deactivate)(struct file___245 *);
};

struct writeback_control___124 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___124 *wb;
	struct inode___245 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___162;

struct iov_iter___165 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___162 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___86 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___245 {
	struct dentry___245 * (*lookup)(struct inode___245 *, struct dentry___245 *, unsigned int);
	const char * (*get_link)(struct dentry___245 *, struct inode___245 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___245 *, int);
	struct posix_acl * (*get_acl)(struct inode___245 *, int, bool);
	int (*readlink)(struct dentry___245 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___245 *, struct dentry___245 *, umode_t, bool);
	int (*link)(struct dentry___245 *, struct inode___245 *, struct dentry___245 *);
	int (*unlink)(struct inode___245 *, struct dentry___245 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___245 *, struct dentry___245 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___245 *, struct dentry___245 *, umode_t);
	int (*rmdir)(struct inode___245 *, struct dentry___245 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___245 *, struct dentry___245 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___245 *, struct dentry___245 *, struct inode___245 *, struct dentry___245 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___245 *, struct iattr___245 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___245 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___245 *, char *, size_t);
	int (*fiemap)(struct inode___245 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___245 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___245 *, struct dentry___245 *, struct file___245 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___245 *, struct dentry___245 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___245 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___245 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___245 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___245 {
	void (*fl_copy_lock)(struct file_lock___245 *, struct file_lock___245 *);
	void (*fl_release_private)(struct file_lock___245 *);
};

struct lock_manager_operations___245;

struct file_lock___245 {
	struct file_lock___245 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___245 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___245 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___245 *fl_ops;
	const struct lock_manager_operations___245 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___245 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___245 *);
	int (*lm_grant)(struct file_lock___245 *, int);
	bool (*lm_break)(struct file_lock___245 *);
	int (*lm_change)(struct file_lock___245 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___245 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___245 *);
};

struct fasync_struct___245 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___245 *fa_next;
	struct file___245 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___245 {
	struct inode___245 * (*alloc_inode)(struct super_block___245 *);
	void (*destroy_inode)(struct inode___245 *);
	void (*free_inode)(struct inode___245 *);
	void (*dirty_inode)(struct inode___245 *, int);
	int (*write_inode)(struct inode___245 *, struct writeback_control___124 *);
	int (*drop_inode)(struct inode___245 *);
	void (*evict_inode)(struct inode___245 *);
	void (*put_super)(struct super_block___245 *);
	int (*sync_fs)(struct super_block___245 *, int);
	int (*freeze_super)(struct super_block___245 *);
	int (*freeze_fs)(struct super_block___245 *);
	int (*thaw_super)(struct super_block___245 *);
	int (*unfreeze_fs)(struct super_block___245 *);
	int (*statfs)(struct dentry___245 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___245 *, int *, char *);
	void (*umount_begin)(struct super_block___245 *);
	int (*show_options)(struct seq_file___220 *, struct dentry___245 *);
	int (*show_devname)(struct seq_file___220 *, struct dentry___245 *);
	int (*show_path)(struct seq_file___220 *, struct dentry___245 *);
	int (*show_stats)(struct seq_file___220 *, struct dentry___245 *);
	ssize_t (*quota_read)(struct super_block___245 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___245 *, int, const char *, size_t, loff_t);
	struct dquot___245 ** (*get_dquots)(struct inode___245 *);
	long int (*nr_cached_objects)(struct super_block___245 *, struct shrink_control___112 *);
	long int (*free_cached_objects)(struct super_block___245 *, struct shrink_control___112 *);
	struct file___245 * (*real_loop)(struct file___245 *);
};

struct wakeup_source___226;

struct dev_pm_info___226 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___226 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___226 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___226;

struct bus_type___226;

struct device_driver___226;

struct dev_pm_domain___226;

struct fwnode_handle___222;

struct class___226;

struct attribute_group___233;

struct device___226 {
	struct kobject___233 kobj;
	struct device___226 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___226 *type;
	struct bus_type___226 *bus;
	struct device_driver___226 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___226 power;
	struct dev_pm_domain___226 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___222 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___226 *class;
	const struct attribute_group___233 **groups;
	void (*release)(struct device___226 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___141 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___245 *bd_inode;
	struct super_block___245 *bd_super;
	void *bd_claiming;
	struct device___226 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___233 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___141 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___245 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___176)(struct file___245 *, wait_queue_head_t *, struct poll_table_struct___168 *);

struct poll_table_struct___168 {
	poll_queue_proc___176 _qproc;
	__poll_t _key;
};

struct seq_operations___220;

struct seq_file___220 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___220 *op;
	int poll_event;
	const struct file___245 *file;
	void *private;
};

typedef void bio_end_io_t___138(struct bio___138 *);

struct bio_vec___162 {
	struct page___250 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___138;

struct bio___138 {
	struct bio___138 *bi_next;
	struct block_device___141 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___138 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___126 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___138 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___162 *bi_io_vec;
	struct bio_set___138 *bi_pool;
	struct bio_vec___162 bi_inline_vecs[0];
};

struct kernfs_root___233;

struct kernfs_elem_dir___233 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___233 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___233;

struct kernfs_root___233 {
	struct kernfs_node___233 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___233 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___233 {
	struct kernfs_node___233 *target_kn;
};

struct kernfs_ops___233;

struct kernfs_elem_attr___233 {
	const struct kernfs_ops___233 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___233 *notify_next;
};

struct kernfs_node___233 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___233 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___233 dir;
		struct kernfs_elem_symlink___233 symlink;
		struct kernfs_elem_attr___233 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___233;

struct kernfs_ops___233 {
	int (*open)(struct kernfs_open_file___233 *);
	void (*release)(struct kernfs_open_file___233 *);
	int (*seq_show)(struct seq_file___220 *, void *);
	void * (*seq_start)(struct seq_file___220 *, loff_t *);
	void * (*seq_next)(struct seq_file___220 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___220 *, void *);
	ssize_t (*read)(struct kernfs_open_file___233 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___233 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___233 *, struct poll_table_struct___168 *);
	int (*mmap)(struct kernfs_open_file___233 *, struct vm_area_struct___250 *);
};

struct kernfs_syscall_ops___233 {
	int (*show_options)(struct seq_file___220 *, struct kernfs_root___233 *);
	int (*mkdir)(struct kernfs_node___233 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___233 *);
	int (*rename)(struct kernfs_node___233 *, struct kernfs_node___233 *, const char *);
	int (*show_path)(struct seq_file___220 *, struct kernfs_node___233 *, struct kernfs_root___233 *);
};

struct kernfs_open_file___233 {
	struct kernfs_node___233 *kn;
	struct file___245 *file;
	struct seq_file___220 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___240 *vm_ops;
};

struct sock___44;

struct kobj_ns_type_operations___43 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___44 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___59 *net;
} possible_net_t___54;

struct proto___43;

struct sock_common___43 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___43 *skc_prot;
	possible_net_t___54 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___44 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___55;

struct sk_buff_head___54 {
	struct sk_buff___55 *next;
	struct sk_buff___55 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___43 {
	struct cgroup___172 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___43;

struct socket_wq___44;

struct dst_entry___43;

struct socket___45;

struct net_device___55;

struct sock_reuseport___9;

struct sock___44 {
	struct sock_common___43 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___54 sk_error_queue;
	struct sk_buff___55 *sk_rx_skb_cache;
	struct sk_buff_head___54 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___55 *head;
		struct sk_buff___55 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___43 *sk_filter;
	union {
		struct socket_wq___44 *sk_wq;
		struct socket_wq___44 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___43 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___43 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___55 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___55 *sk_tx_skb_cache;
	struct sk_buff_head___54 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___250 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___43 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___222 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___45 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___43 sk_cgrp_data;
	struct mem_cgroup___112 *sk_memcg;
	void (*sk_state_change)(struct sock___44 *);
	void (*sk_data_ready)(struct sock___44 *);
	void (*sk_write_space)(struct sock___44 *);
	void (*sk_error_report)(struct sock___44 *);
	int (*sk_backlog_rcv)(struct sock___44 *, struct sk_buff___55 *);
	struct sk_buff___55 * (*sk_validate_xmit_skb)(struct sock___44 *, struct net_device___55 *, struct sk_buff___55 *);
	void (*sk_destruct)(struct sock___44 *);
	struct sock_reuseport___9 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___233;

struct attribute_group___233 {
	const char *name;
	umode_t (*is_visible)(struct kobject___233 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___233 *, struct bin_attribute___233 *, int);
	struct attribute **attrs;
	struct bin_attribute___233 **bin_attrs;
};

struct bin_attribute___233 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___245 * (*f_mapping)();
	ssize_t (*read)(struct file___245 *, struct kobject___233 *, struct bin_attribute___233 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___245 *, struct kobject___233 *, struct bin_attribute___233 *, char *, loff_t, size_t);
	int (*mmap)(struct file___245 *, struct kobject___233 *, struct bin_attribute___233 *, struct vm_area_struct___250 *);
};

struct sysfs_ops___233 {
	ssize_t (*show)(struct kobject___233 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___233 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___233;

struct kset___233 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___233 kobj;
	const struct kset_uevent_ops___233 *uevent_ops;
};

struct kobj_type___233 {
	void (*release)(struct kobject___233 *);
	const struct sysfs_ops___233 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___233 **default_groups;
	const struct kobj_ns_type_operations___43 * (*child_ns_type)(struct kobject___233 *);
	const void * (*namespace)(struct kobject___233 *);
	void (*get_ownership)(struct kobject___233 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___233 {
	int (* const filter)(struct kset___233 *, struct kobject___233 *);
	const char * (* const name)(struct kset___233 *, struct kobject___233 *);
	int (* const uevent)(struct kset___233 *, struct kobject___233 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___229 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___229 *);
	int (*get)(char *, const struct kernel_param___229 *);
	void (*free)(void *);
};

struct kparam_array___229;

struct kernel_param___229 {
	const char *name;
	struct module___229 *mod;
	const struct kernel_param_ops___229 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___229 *arr;
	};
};

struct kparam_array___229 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___229 *ops;
	void *elem;
};

struct module_attribute___229 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___229 *, struct module_kobject___230 *, char *);
	ssize_t (*store)(struct module_attribute___229 *, struct module_kobject___230 *, const char *, size_t);
	void (*setup)(struct module___229 *, const char *);
	int (*test)(struct module___229 *);
	void (*free)(struct module___229 *);
};

struct msghdr___45 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___165 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___245 *msg_iocb;
};

struct dev_pagemap_ops___240 {
	void (*page_free)(struct page___250 *);
	void (*kill)(struct dev_pagemap___240 *);
	void (*cleanup)(struct dev_pagemap___240 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___240 *);
};

struct socket_wq___44 {
	wait_queue_head_t wait;
	struct fasync_struct___245 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___44;

struct socket___45 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___245 *file;
	struct sock___44 *sk;
	const struct proto_ops___44 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___44 wq;
};

typedef int (*sk_read_actor_t___43)(read_descriptor_t *, struct sk_buff___55 *, unsigned int, size_t);

struct proto_ops___44 {
	int family;
	struct module___229 *owner;
	int (*release)(struct socket___45 *);
	int (*bind)(struct socket___45 *, struct sockaddr *, int);
	int (*connect)(struct socket___45 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___45 *, struct socket___45 *);
	int (*accept)(struct socket___45 *, struct socket___45 *, int, bool);
	int (*getname)(struct socket___45 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___245 *, struct socket___45 *, struct poll_table_struct___168 *);
	int (*ioctl)(struct socket___45 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___45 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___45 *, void *, bool, bool);
	int (*listen)(struct socket___45 *, int);
	int (*shutdown)(struct socket___45 *, int);
	int (*setsockopt)(struct socket___45 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___45 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___220 *, struct socket___45 *);
	int (*sendmsg)(struct socket___45 *, struct msghdr___45 *, size_t);
	int (*recvmsg)(struct socket___45 *, struct msghdr___45 *, size_t, int);
	int (*mmap)(struct file___245 *, struct socket___45 *, struct vm_area_struct___250 *);
	ssize_t (*sendpage)(struct socket___45 *, struct page___250 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___45 *, loff_t *, struct pipe_inode_info___86 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___44 *, int);
	int (*peek_len)(struct socket___45 *);
	int (*read_sock)(struct sock___44 *, read_descriptor_t *, sk_read_actor_t___43);
	int (*sendpage_locked)(struct sock___44 *, struct page___250 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___44 *, struct msghdr___45 *, size_t);
	int (*set_rcvlowat)(struct sock___44 *, int);
};

struct sk_buff___55 {
	union {
		struct {
			struct sk_buff___55 *next;
			struct sk_buff___55 *prev;
			union {
				struct net_device___55 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___44 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___55 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___24;

struct fib_rules_ops___43;

struct fqdir___59;

struct tcp_congestion_ops___8;

struct fib_notifier_ops___43;

struct netns_ipv4___59 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___24 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___43 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___44 *fibnl;
	struct sock___44 **icmp_sk;
	struct sock___44 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___44 **tcp_sk;
	struct fqdir___59 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___8 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___43 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___43 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___43 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___43;

struct dst_ops___59 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___59 *);
	struct dst_entry___43 * (*check)(struct dst_entry___43 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___43 *);
	unsigned int (*mtu)(const struct dst_entry___43 *);
	u32 * (*cow_metrics)(struct dst_entry___43 *, long unsigned int);
	void (*destroy)(struct dst_entry___43 *);
	void (*ifdown)(struct dst_entry___43 *, struct net_device___55 *, int);
	struct dst_entry___43 * (*negative_advice)(struct dst_entry___43 *);
	void (*link_failure)(struct sk_buff___55 *);
	void (*update_pmtu)(struct dst_entry___43 *, struct sock___44 *, struct sk_buff___55 *, u32, bool);
	void (*redirect)(struct dst_entry___43 *, struct sock___44 *, struct sk_buff___55 *);
	int (*local_out)(struct net___59 *, struct sock___44 *, struct sk_buff___55 *);
	struct neighbour___43 * (*neigh_lookup)(const struct dst_entry___43 *, struct sk_buff___55 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___43 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___59 {
	struct dst_ops___59 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___59 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___43 *fib6_rules_ops;
	struct sock___44 **icmp_sk;
	struct sock___44 *ndisc_sk;
	struct sock___44 *tcp_sk;
	struct sock___44 *igmp_sk;
	struct sock___44 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___43 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___43 *notifier_ops;
	struct fib_notifier_ops___43 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___59 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___59 *fqdir;
};

struct netns_sctp___43 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___44 *ctl_sock;
	struct sock___44 *udp4_sock;
	struct sock___44 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___50;

struct netns_bpf___50 {
	struct bpf_prog_array___50 *run_array[2];
	struct bpf_prog___50 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___59 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___44 *nlsk;
	struct sock___44 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___59 xfrm4_dst_ops;
	struct dst_ops___59 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___59 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___44 *rtnl;
	struct sock___44 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___55 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___59 ipv4;
	struct netns_ipv6___59 ipv6;
	struct netns_ieee802154_lowpan___59 ieee802154_lowpan;
	struct netns_sctp___43 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___54 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___50 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___59 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___44 *crypto_nlsk;
	struct sock___44 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct fwnode_operations___222;

struct fwnode_handle___222 {
	struct fwnode_handle___222 *secondary;
	const struct fwnode_operations___222 *ops;
	struct device___226 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___222;

struct fwnode_endpoint___222;

struct fwnode_operations___222 {
	struct fwnode_handle___222 * (*get)(struct fwnode_handle___222 *);
	void (*put)(struct fwnode_handle___222 *);
	bool (*device_is_available)(const struct fwnode_handle___222 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___222 *, const struct device___226 *);
	bool (*property_present)(const struct fwnode_handle___222 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___222 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___222 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___222 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*get_parent)(const struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*get_next_child_node)(const struct fwnode_handle___222 *, struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*get_named_child_node)(const struct fwnode_handle___222 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___222 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___222 *);
	struct fwnode_handle___222 * (*graph_get_next_endpoint)(const struct fwnode_handle___222 *, struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*graph_get_remote_endpoint)(const struct fwnode_handle___222 *);
	struct fwnode_handle___222 * (*graph_get_port_parent)(struct fwnode_handle___222 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___222 *, struct fwnode_endpoint___222 *);
	int (*add_links)(struct fwnode_handle___222 *);
};

struct fwnode_endpoint___222 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___222 *local_fwnode;
};

struct fwnode_reference_args___222 {
	struct fwnode_handle___222 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___172 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___172 *root_cset;
};

struct dev_pm_ops___226 {
	int (*prepare)(struct device___226 *);
	void (*complete)(struct device___226 *);
	int (*suspend)(struct device___226 *);
	int (*resume)(struct device___226 *);
	int (*freeze)(struct device___226 *);
	int (*thaw)(struct device___226 *);
	int (*poweroff)(struct device___226 *);
	int (*restore)(struct device___226 *);
	int (*suspend_late)(struct device___226 *);
	int (*resume_early)(struct device___226 *);
	int (*freeze_late)(struct device___226 *);
	int (*thaw_early)(struct device___226 *);
	int (*poweroff_late)(struct device___226 *);
	int (*restore_early)(struct device___226 *);
	int (*suspend_noirq)(struct device___226 *);
	int (*resume_noirq)(struct device___226 *);
	int (*freeze_noirq)(struct device___226 *);
	int (*thaw_noirq)(struct device___226 *);
	int (*poweroff_noirq)(struct device___226 *);
	int (*restore_noirq)(struct device___226 *);
	int (*runtime_suspend)(struct device___226 *);
	int (*runtime_resume)(struct device___226 *);
	int (*runtime_idle)(struct device___226 *);
};

struct wakeup_source___226 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___226 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___226 {
	struct dev_pm_ops___226 ops;
	int (*start)(struct device___226 *);
	void (*detach)(struct device___226 *, bool);
	int (*activate)(struct device___226 *);
	void (*sync)(struct device___226 *);
	void (*dismiss)(struct device___226 *);
};

struct bus_type___226 {
	const char *name;
	const char *dev_name;
	struct device___226 *dev_root;
	const struct attribute_group___233 **bus_groups;
	const struct attribute_group___233 **dev_groups;
	const struct attribute_group___233 **drv_groups;
	int (*match)(struct device___226 *, struct device_driver___226 *);
	int (*uevent)(struct device___226 *, struct kobj_uevent_env *);
	int (*probe)(struct device___226 *);
	void (*sync_state)(struct device___226 *);
	void (*remove)(struct device___226 *);
	void (*shutdown)(struct device___226 *);
	int (*online)(struct device___226 *);
	int (*offline)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	int (*num_vf)(struct device___226 *);
	int (*dma_configure)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___226 {
	const char *name;
	struct bus_type___226 *bus;
	struct module___229 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___226 *);
	void (*sync_state)(struct device___226 *);
	int (*remove)(struct device___226 *);
	void (*shutdown)(struct device___226 *);
	int (*suspend)(struct device___226 *, pm_message_t);
	int (*resume)(struct device___226 *);
	const struct attribute_group___233 **groups;
	const struct attribute_group___233 **dev_groups;
	const struct dev_pm_ops___226 *pm;
	void (*coredump)(struct device___226 *);
	struct driver_private *p;
};

struct device_type___226 {
	const char *name;
	const struct attribute_group___233 **groups;
	int (*uevent)(struct device___226 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___226 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___226 *);
	const struct dev_pm_ops___226 *pm;
};

struct class___226 {
	const char *name;
	struct module___229 *owner;
	const struct attribute_group___233 **class_groups;
	const struct attribute_group___233 **dev_groups;
	struct kobject___233 *dev_kobj;
	int (*dev_uevent)(struct device___226 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___226 *, umode_t *);
	void (*class_release)(struct class___226 *);
	void (*dev_release)(struct device___226 *);
	int (*shutdown_pre)(struct device___226 *);
	const struct kobj_ns_type_operations___43 *ns_type;
	const void * (*namespace)(struct device___226 *);
	void (*get_ownership)(struct device___226 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___226 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___86;

struct pipe_buffer___86 {
	struct page___250 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___86 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___86 {
	int (*confirm)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
	void (*release)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
	bool (*try_steal)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
	bool (*get)(struct pipe_inode_info___86 *, struct pipe_buffer___86 *);
};

typedef rx_handler_result_t rx_handler_func_t___54(struct sk_buff___55 **);

struct bpf_xdp_entity___50 {
	struct bpf_prog___50 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___54;

struct net_device_ops___54;

struct l3mdev_ops___43;

struct ndisc_ops___30;

struct xfrmdev_ops___54;

struct header_ops___54;

struct inet6_dev___30;

struct netdev_rx_queue___54;

struct mini_Qdisc___50;

struct netdev_queue___54;

struct Qdisc___50;

struct rtnl_link_ops___50;

struct dcbnl_rtnl_ops___54;

struct net_device___55 {
	char name[16];
	struct netdev_name_node___54 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___54 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___43 *l3mdev_ops;
	const struct ndisc_ops___30 *ndisc_ops;
	const struct xfrmdev_ops___54 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___54 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___233 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___30 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___54 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___50 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___54 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___50 *miniq_ingress;
	struct netdev_queue___54 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___54 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___50 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___50 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___54 = 0,
		NETREG_REGISTERED___54 = 1,
		NETREG_UNREGISTERING___54 = 2,
		NETREG_UNREGISTERED___54 = 3,
		NETREG_RELEASED___54 = 4,
		NETREG_DUMMY___54 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___54 = 0,
		RTNL_LINK_INITIALIZING___54 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___55 *);
	struct netpoll_info *npinfo;
	possible_net_t___54 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___226 dev;
	const struct attribute_group___233 *sysfs_groups[4];
	const struct attribute_group___233 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___50 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___54 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___50 xdp_state[3];
	long: 64;
};

struct netlink_skb_parms___7 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___44 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___4 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___55 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___59 *, int);
	void (*unbind)(struct net___59 *, int);
	bool (*compare)(struct net___59 *, struct sock___44 *);
};

struct netlink_callback___54 {
	struct sk_buff___55 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___55 *, struct netlink_callback___54 *);
	int (*done)(struct netlink_callback___54 *);
	void *data;
	struct module___229 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct netlink_dump_control {
	int (*start)(struct netlink_callback___54 *);
	int (*dump)(struct sk_buff___55 *, struct netlink_callback___54 *);
	int (*done)(struct netlink_callback___54 *);
	void *data;
	struct module___229 *module;
	u32 min_dump_alloc;
};

struct inet_frags___59;

struct fqdir___59 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___59 *f;
	struct net___59 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___59;

struct inet_frags___59 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___59 *, const void *);
	void (*destructor)(struct inet_frag_queue___59 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___59 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___55 *fragments_tail;
	struct sk_buff___55 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___59 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___24 {
	struct ip_ra_chain___24 *next;
	struct sock___44 *sk;
	union {
		void (*destructor)(struct sock___44 *);
		struct sock___44 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___43;

struct fib_lookup_arg___43;

struct fib_rules_ops___43 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___43 *, struct flowi *, int, struct fib_lookup_arg___43 *);
	bool (*suppress)(struct fib_rule___43 *, int, struct fib_lookup_arg___43 *);
	int (*match)(struct fib_rule___43 *, struct flowi *, int);
	int (*configure)(struct fib_rule___43 *, struct sk_buff___55 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___43 *);
	int (*compare)(struct fib_rule___43 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___43 *, struct sk_buff___55 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___43 *);
	void (*flush_cache)(struct fib_rules_ops___43 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___229 *owner;
	struct net___59 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___8 {
	u32 (*ssthresh)(struct sock___44 *);
	void (*cong_avoid)(struct sock___44 *, u32, u32);
	void (*set_state)(struct sock___44 *, u8);
	void (*cwnd_event)(struct sock___44 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___44 *, u32);
	void (*pkts_acked)(struct sock___44 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___44 *);
	void (*cong_control)(struct sock___44 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___44 *);
	u32 (*sndbuf_expand)(struct sock___44 *);
	size_t (*get_info)(struct sock___44 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___229 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___44 *);
	void (*release)(struct sock___44 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___43 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___59 *);
	int (*fib_dump)(struct net___59 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___229 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___25;

struct dst_entry___43 {
	struct net_device___55 *dev;
	struct dst_ops___59 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___55 *);
	int (*output)(struct net___59 *, struct sock___44 *, struct sk_buff___55 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___25 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___43;

struct neigh_parms___43;

struct neigh_ops___43;

struct neighbour___43 {
	struct neighbour___43 *next;
	struct neigh_table___43 *tbl;
	struct neigh_parms___43 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___54 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___43 *, struct sk_buff___55 *);
	const struct neigh_ops___43 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___55 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___50 {
	struct bpf_prog___50 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___50 {
	struct callback_head rcu;
	struct bpf_prog_array_item___50 items[0];
};

struct bpf_prog_aux___57;

struct bpf_prog___50 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___57 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___220 {
	void * (*start)(struct seq_file___220 *, loff_t *);
	void (*stop)(struct seq_file___220 *, void *);
	void * (*next)(struct seq_file___220 *, void *, loff_t *);
	int (*show)(struct seq_file___220 *, void *);
};

struct pernet_operations___12 {
	struct list_head list;
	int (*init)(struct net___59 *);
	void (*pre_exit)(struct net___59 *);
	void (*exit)(struct net___59 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___54 {
	int (*ieee_getets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___55 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___55 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___55 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___55 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___55 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___55 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___55 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___55 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___55 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___55 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___55 *);
	u8 (*setstate)(struct net_device___55 *, u8);
	void (*getpermhwaddr)(struct net_device___55 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___55 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___55 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___55 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___55 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___55 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___55 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___55 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___55 *, int, u8 *);
	void (*setpfccfg)(struct net_device___55 *, int, u8);
	void (*getpfccfg)(struct net_device___55 *, int, u8 *);
	u8 (*setall)(struct net_device___55 *);
	u8 (*getcap)(struct net_device___55 *, int, u8 *);
	int (*getnumtcs)(struct net_device___55 *, int, u8 *);
	int (*setnumtcs)(struct net_device___55 *, int, u8);
	u8 (*getpfcstate)(struct net_device___55 *);
	void (*setpfcstate)(struct net_device___55 *, u8);
	void (*getbcncfg)(struct net_device___55 *, int, u32 *);
	void (*setbcncfg)(struct net_device___55 *, int, u32);
	void (*getbcnrp)(struct net_device___55 *, int, u8 *);
	void (*setbcnrp)(struct net_device___55 *, int, u8);
	int (*setapp)(struct net_device___55 *, u8, u16, u8);
	int (*getapp)(struct net_device___55 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___55 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___55 *, int, u8);
	u8 (*getdcbx)(struct net_device___55 *);
	u8 (*setdcbx)(struct net_device___55 *, u8);
	int (*peer_getappinfo)(struct net_device___55 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___55 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___55 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___55 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___55 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___55 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___57;

typedef int (*bpf_iter_init_seq_priv_t___56)(void *, struct bpf_iter_aux_info___57 *);

struct bpf_map___57;

struct bpf_iter_aux_info___57 {
	struct bpf_map___57 *map;
};

struct bpf_iter_seq_info___56 {
	const struct seq_operations___220 *seq_ops;
	bpf_iter_init_seq_priv_t___56 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___56 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___57 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___57 *, struct file___245 *);
	void (*map_free)(struct bpf_map___57 *);
	int (*map_get_next_key)(struct bpf_map___57 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___57 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___57 *, void *);
	int (*map_lookup_batch)(struct bpf_map___57 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___57 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___57 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___57 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___57 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___57 *, void *);
	int (*map_update_elem)(struct bpf_map___57 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___57 *, void *);
	int (*map_push_elem)(struct bpf_map___57 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___57 *, void *);
	int (*map_peek_elem)(struct bpf_map___57 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___57 *, struct file___245 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___57 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___57 *, void *, struct seq_file___220 *);
	int (*map_check_btf)(const struct bpf_map___57 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___57 *, struct bpf_prog_aux___57 *);
	void (*map_poke_untrack)(struct bpf_map___57 *, struct bpf_prog_aux___57 *);
	void (*map_poke_run)(struct bpf_map___57 *, u32, struct bpf_prog___50 *, struct bpf_prog___50 *);
	int (*map_direct_value_addr)(const struct bpf_map___57 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___57 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___57 *, struct vm_area_struct___250 *);
	__poll_t (*map_poll)(struct bpf_map___57 *, struct file___245 *, struct poll_table_struct___168 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___57 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___57 *, const struct bpf_map___57 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___57 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___56 *iter_seq_info;
};

struct bpf_map___57 {
	const struct bpf_map_ops___56 *ops;
	struct bpf_map___57 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___112 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___56;

struct bpf_jit_poke_descriptor___56;

struct bpf_prog_ops___50;

struct btf_mod_pair___56;

struct bpf_prog_offload___54;

struct bpf_prog_aux___57 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___50 *dst_prog;
	struct bpf_trampoline___56 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___50 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___56 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___50 *ops;
	struct bpf_map___57 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___56 *used_btfs;
	struct bpf_prog___50 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___57 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___54 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___54;

struct bpf_map_dev_ops___54 {
	int (*map_get_next_key)(struct bpf_offloaded_map___54 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___54 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___54 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___54 *, void *);
};

struct bpf_offloaded_map___54 {
	struct bpf_map___57 map;
	struct net_device___55 *netdev;
	const struct bpf_map_dev_ops___54 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___50 {
	int (*test_run)(struct bpf_prog___50 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___54 {
	struct bpf_prog___50 *prog;
	struct net_device___55 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___56 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___50 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___229 *mod;
};

struct bpf_jit_poke_descriptor___56 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___57 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___56 {
	struct btf *btf;
	struct module___229 *module;
};

struct cftype___172;

struct cgroup_subsys___172 {
	struct cgroup_subsys_state___172 * (*css_alloc)(struct cgroup_subsys_state___172 *);
	int (*css_online)(struct cgroup_subsys_state___172 *);
	void (*css_offline)(struct cgroup_subsys_state___172 *);
	void (*css_released)(struct cgroup_subsys_state___172 *);
	void (*css_free)(struct cgroup_subsys_state___172 *);
	void (*css_reset)(struct cgroup_subsys_state___172 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___172 *, int);
	int (*css_extra_stat_show)(struct seq_file___220 *, struct cgroup_subsys_state___172 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___252 *, struct css_set___172 *);
	void (*cancel_fork)(struct task_struct___252 *, struct css_set___172 *);
	void (*fork)(struct task_struct___252 *);
	void (*exit)(struct task_struct___252 *);
	void (*release)(struct task_struct___252 *);
	void (*bind)(struct cgroup_subsys_state___172 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___172 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___172 *dfl_cftypes;
	struct cftype___172 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___172 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___172 *updated_children;
	struct cgroup___172 *updated_next;
};

struct cgroup_root___172 {
	struct kernfs_root___233 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___172 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___172 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___172 *ss;
	struct list_head node;
	struct kernfs_ops___233 *kf_ops;
	int (*open)(struct kernfs_open_file___233 *);
	void (*release)(struct kernfs_open_file___233 *);
	u64 (*read_u64)(struct cgroup_subsys_state___172 *, struct cftype___172 *);
	s64 (*read_s64)(struct cgroup_subsys_state___172 *, struct cftype___172 *);
	int (*seq_show)(struct seq_file___220 *, void *);
	void * (*seq_start)(struct seq_file___220 *, loff_t *);
	void * (*seq_next)(struct seq_file___220 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___220 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___172 *, struct cftype___172 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___172 *, struct cftype___172 *, s64);
	ssize_t (*write)(struct kernfs_open_file___233 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___233 *, struct poll_table_struct___168 *);
};

struct xdp_rxq_info___54 {
	struct net_device___55 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___54 {
	struct net_device___55 *dev;
};

struct xdp_buff___54 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___54 *rxq;
	struct xdp_txq_info___54 *txq;
	u32 frame_sz;
};

struct xdp_frame___54 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___55 *dev_rx;
};

struct rtnl_link_stats {
	__u32 rx_packets;
	__u32 tx_packets;
	__u32 rx_bytes;
	__u32 tx_bytes;
	__u32 rx_errors;
	__u32 tx_errors;
	__u32 rx_dropped;
	__u32 tx_dropped;
	__u32 multicast;
	__u32 collisions;
	__u32 rx_length_errors;
	__u32 rx_over_errors;
	__u32 rx_crc_errors;
	__u32 rx_frame_errors;
	__u32 rx_fifo_errors;
	__u32 rx_missed_errors;
	__u32 tx_aborted_errors;
	__u32 tx_carrier_errors;
	__u32 tx_fifo_errors;
	__u32 tx_heartbeat_errors;
	__u32 tx_window_errors;
	__u32 rx_compressed;
	__u32 tx_compressed;
	__u32 rx_nohandler;
};

struct rtnl_link_ifmap {
	__u64 mem_start;
	__u64 mem_end;
	__u64 base_addr;
	__u16 irq;
	__u8 dma;
	__u8 port;
};

enum {
	IFLA_PROTO_DOWN_REASON_UNSPEC = 0,
	IFLA_PROTO_DOWN_REASON_MASK = 1,
	IFLA_PROTO_DOWN_REASON_VALUE = 2,
	__IFLA_PROTO_DOWN_REASON_CNT = 3,
	IFLA_PROTO_DOWN_REASON_MAX = 2,
};

enum {
	IFLA_BRPORT_UNSPEC = 0,
	IFLA_BRPORT_STATE = 1,
	IFLA_BRPORT_PRIORITY = 2,
	IFLA_BRPORT_COST = 3,
	IFLA_BRPORT_MODE = 4,
	IFLA_BRPORT_GUARD = 5,
	IFLA_BRPORT_PROTECT = 6,
	IFLA_BRPORT_FAST_LEAVE = 7,
	IFLA_BRPORT_LEARNING = 8,
	IFLA_BRPORT_UNICAST_FLOOD = 9,
	IFLA_BRPORT_PROXYARP = 10,
	IFLA_BRPORT_LEARNING_SYNC = 11,
	IFLA_BRPORT_PROXYARP_WIFI = 12,
	IFLA_BRPORT_ROOT_ID = 13,
	IFLA_BRPORT_BRIDGE_ID = 14,
	IFLA_BRPORT_DESIGNATED_PORT = 15,
	IFLA_BRPORT_DESIGNATED_COST = 16,
	IFLA_BRPORT_ID = 17,
	IFLA_BRPORT_NO = 18,
	IFLA_BRPORT_TOPOLOGY_CHANGE_ACK = 19,
	IFLA_BRPORT_CONFIG_PENDING = 20,
	IFLA_BRPORT_MESSAGE_AGE_TIMER = 21,
	IFLA_BRPORT_FORWARD_DELAY_TIMER = 22,
	IFLA_BRPORT_HOLD_TIMER = 23,
	IFLA_BRPORT_FLUSH = 24,
	IFLA_BRPORT_MULTICAST_ROUTER = 25,
	IFLA_BRPORT_PAD = 26,
	IFLA_BRPORT_MCAST_FLOOD = 27,
	IFLA_BRPORT_MCAST_TO_UCAST = 28,
	IFLA_BRPORT_VLAN_TUNNEL = 29,
	IFLA_BRPORT_BCAST_FLOOD = 30,
	IFLA_BRPORT_GROUP_FWD_MASK = 31,
	IFLA_BRPORT_NEIGH_SUPPRESS = 32,
	IFLA_BRPORT_ISOLATED = 33,
	IFLA_BRPORT_BACKUP_PORT = 34,
	IFLA_BRPORT_MRP_RING_OPEN = 35,
	IFLA_BRPORT_MRP_IN_OPEN = 36,
	IFLA_BRPORT_MCAST_EHT_HOSTS_LIMIT = 37,
	IFLA_BRPORT_MCAST_EHT_HOSTS_CNT = 38,
	__IFLA_BRPORT_MAX = 39,
};

enum {
	IFLA_VF_INFO_UNSPEC = 0,
	IFLA_VF_INFO = 1,
	__IFLA_VF_INFO_MAX = 2,
};

enum {
	IFLA_VF_UNSPEC = 0,
	IFLA_VF_MAC = 1,
	IFLA_VF_VLAN = 2,
	IFLA_VF_TX_RATE = 3,
	IFLA_VF_SPOOFCHK = 4,
	IFLA_VF_LINK_STATE = 5,
	IFLA_VF_RATE = 6,
	IFLA_VF_RSS_QUERY_EN = 7,
	IFLA_VF_STATS = 8,
	IFLA_VF_TRUST = 9,
	IFLA_VF_IB_NODE_GUID = 10,
	IFLA_VF_IB_PORT_GUID = 11,
	IFLA_VF_VLAN_LIST = 12,
	IFLA_VF_BROADCAST = 13,
	__IFLA_VF_MAX = 14,
};

struct ifla_vf_mac {
	__u32 vf;
	__u8 mac[32];
};

struct ifla_vf_broadcast {
	__u8 broadcast[32];
};

struct ifla_vf_vlan {
	__u32 vf;
	__u32 vlan;
	__u32 qos;
};

enum {
	IFLA_VF_VLAN_INFO_UNSPEC = 0,
	IFLA_VF_VLAN_INFO = 1,
	__IFLA_VF_VLAN_INFO_MAX = 2,
};

struct ifla_vf_vlan_info {
	__u32 vf;
	__u32 vlan;
	__u32 qos;
	__be16 vlan_proto;
};

struct ifla_vf_tx_rate {
	__u32 vf;
	__u32 rate;
};

struct ifla_vf_rate {
	__u32 vf;
	__u32 min_tx_rate;
	__u32 max_tx_rate;
};

struct ifla_vf_spoofchk {
	__u32 vf;
	__u32 setting;
};

struct ifla_vf_link_state {
	__u32 vf;
	__u32 link_state;
};

struct ifla_vf_rss_query_en {
	__u32 vf;
	__u32 setting;
};

enum {
	IFLA_VF_STATS_RX_PACKETS = 0,
	IFLA_VF_STATS_TX_PACKETS = 1,
	IFLA_VF_STATS_RX_BYTES = 2,
	IFLA_VF_STATS_TX_BYTES = 3,
	IFLA_VF_STATS_BROADCAST = 4,
	IFLA_VF_STATS_MULTICAST = 5,
	IFLA_VF_STATS_PAD = 6,
	IFLA_VF_STATS_RX_DROPPED = 7,
	IFLA_VF_STATS_TX_DROPPED = 8,
	__IFLA_VF_STATS_MAX = 9,
};

struct ifla_vf_trust {
	__u32 vf;
	__u32 setting;
};

enum {
	IFLA_VF_PORT_UNSPEC = 0,
	IFLA_VF_PORT = 1,
	__IFLA_VF_PORT_MAX = 2,
};

enum {
	IFLA_PORT_UNSPEC = 0,
	IFLA_PORT_VF = 1,
	IFLA_PORT_PROFILE = 2,
	IFLA_PORT_VSI_TYPE = 3,
	IFLA_PORT_INSTANCE_UUID = 4,
	IFLA_PORT_HOST_UUID = 5,
	IFLA_PORT_REQUEST = 6,
	IFLA_PORT_RESPONSE = 7,
	__IFLA_PORT_MAX = 8,
};

struct if_stats_msg {
	__u8 family;
	__u8 pad1;
	__u16 pad2;
	__u32 ifindex;
	__u32 filter_mask;
};

enum {
	IFLA_STATS_UNSPEC = 0,
	IFLA_STATS_LINK_64 = 1,
	IFLA_STATS_LINK_XSTATS = 2,
	IFLA_STATS_LINK_XSTATS_SLAVE = 3,
	IFLA_STATS_LINK_OFFLOAD_XSTATS = 4,
	IFLA_STATS_AF_SPEC = 5,
	__IFLA_STATS_MAX = 6,
};

enum {
	IFLA_OFFLOAD_XSTATS_UNSPEC = 0,
	IFLA_OFFLOAD_XSTATS_CPU_HIT = 1,
	__IFLA_OFFLOAD_XSTATS_MAX = 2,
};

enum {
	XDP_ATTACHED_NONE = 0,
	XDP_ATTACHED_DRV = 1,
	XDP_ATTACHED_SKB = 2,
	XDP_ATTACHED_HW = 3,
	XDP_ATTACHED_MULTI = 4,
};

enum {
	IFLA_XDP_UNSPEC = 0,
	IFLA_XDP_FD = 1,
	IFLA_XDP_ATTACHED = 2,
	IFLA_XDP_FLAGS = 3,
	IFLA_XDP_PROG_ID = 4,
	IFLA_XDP_DRV_PROG_ID = 5,
	IFLA_XDP_SKB_PROG_ID = 6,
	IFLA_XDP_HW_PROG_ID = 7,
	IFLA_XDP_EXPECTED_FD = 8,
	__IFLA_XDP_MAX = 9,
};

enum {
	IFLA_EVENT_NONE = 0,
	IFLA_EVENT_REBOOT = 1,
	IFLA_EVENT_FEATURES = 2,
	IFLA_EVENT_BONDING_FAILOVER = 3,
	IFLA_EVENT_NOTIFY_PEERS = 4,
	IFLA_EVENT_IGMP_RESEND = 5,
	IFLA_EVENT_BONDING_OPTIONS = 6,
};

struct header_ops___54 {
	int (*create)(struct sk_buff___55 *, struct net_device___55 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___55 *, unsigned char *);
	int (*cache)(const struct neighbour___43 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___55 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___55 *);
};

struct netdev_queue___54 {
	struct net_device___55 *dev;
	struct Qdisc___50 *qdisc;
	struct Qdisc___50 *qdisc_sleeping;
	struct kobject___233 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___55 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___50 {
	struct sk_buff___55 *head;
	struct sk_buff___55 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___50;

struct Qdisc___50 {
	int (*enqueue)(struct sk_buff___55 *, struct Qdisc___50 *, struct sk_buff___55 **);
	struct sk_buff___55 * (*dequeue)(struct Qdisc___50 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___50 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___54 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___54 gso_skb;
	struct qdisc_skb_head___50 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___50 *next_sched;
	struct sk_buff_head___54 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___54 {
	struct xdp_rxq_info___54 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___233 kobj;
	struct net_device___55 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___54 {
	enum net_device_path_type type;
	const struct net_device___55 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___54 = 0,
				DEV_PATH_BR_VLAN_TAG___54 = 1,
				DEV_PATH_BR_VLAN_UNTAG___54 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___54 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___54 {
	const struct net_device___55 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___54 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___50 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___54 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___54 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___55 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___54 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___55 *dev;
	const char *name;
};

struct net_device_ops___54 {
	int (*ndo_init)(struct net_device___55 *);
	void (*ndo_uninit)(struct net_device___55 *);
	int (*ndo_open)(struct net_device___55 *);
	int (*ndo_stop)(struct net_device___55 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___55 *, struct net_device___55 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___55 *, struct net_device___55 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___55 *, struct sk_buff___55 *, struct net_device___55 *);
	void (*ndo_change_rx_flags)(struct net_device___55 *, int);
	void (*ndo_set_rx_mode)(struct net_device___55 *);
	int (*ndo_set_mac_address)(struct net_device___55 *, void *);
	int (*ndo_validate_addr)(struct net_device___55 *);
	int (*ndo_do_ioctl)(struct net_device___55 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___55 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___55 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___55 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___55 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___55 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___55 *, int);
	int (*ndo_neigh_setup)(struct net_device___55 *, struct neigh_parms___43 *);
	void (*ndo_tx_timeout)(struct net_device___55 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___55 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___55 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___55 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___55 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___55 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___55 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___55 *);
	int (*ndo_netpoll_setup)(struct net_device___55 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___55 *);
	int (*ndo_set_vf_mac)(struct net_device___55 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___55 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___55 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___55 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___55 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___55 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___55 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___55 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___55 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___55 *, int, struct sk_buff___55 *);
	int (*ndo_get_vf_guid)(struct net_device___55 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___55 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___55 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___55 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___55 *);
	int (*ndo_fcoe_disable)(struct net_device___55 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___55 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___55 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___55 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___55 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___55 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___55 *, const struct sk_buff___55 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___55 *, struct net_device___55 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___55 *, struct net_device___55 *);
	struct net_device___55 * (*ndo_get_xmit_slave)(struct net_device___55 *, struct sk_buff___55 *, bool);
	struct net_device___55 * (*ndo_sk_get_lower_dev)(struct net_device___55 *, struct sock___44 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___55 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___55 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___55 *, struct neighbour___43 *);
	void (*ndo_neigh_destroy)(struct net_device___55 *, struct neighbour___43 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___55 *, struct netlink_callback___54 *, struct net_device___55 *, struct net_device___55 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___55 *, struct nlattr **, struct net_device___55 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___55 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___55 *, u32, u32, struct net_device___55 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___55 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___55 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___55 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___55 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___55 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___55 *, struct net_device___55 *);
	void (*ndo_dfwd_del_station)(struct net_device___55 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___55 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___55 *);
	int (*ndo_change_proto_down)(struct net_device___55 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___55 *, struct sk_buff___55 *);
	void (*ndo_set_rx_headroom)(struct net_device___55 *, int);
	int (*ndo_bpf)(struct net_device___55 *, struct netdev_bpf___54 *);
	int (*ndo_xdp_xmit)(struct net_device___55 *, int, struct xdp_frame___54 **, u32);
	struct net_device___55 * (*ndo_xdp_get_xmit_slave)(struct net_device___55 *, struct xdp_buff___54 *);
	int (*ndo_xsk_wakeup)(struct net_device___55 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___55 *);
	int (*ndo_tunnel_ctl)(struct net_device___55 *, struct ip_tunnel_parm *, int);
	struct net_device___55 * (*ndo_get_peer_dev)(struct net_device___55 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___54 *, struct net_device_path___54 *);
};

struct neigh_parms___43 {
	possible_net_t___54 net;
	struct net_device___55 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___43 *);
	struct neigh_table___43 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___43 {
	u32 (*l3mdev_fib_table)(const struct net_device___55 *);
	struct sk_buff___55 * (*l3mdev_l3_rcv)(struct net_device___55 *, struct sk_buff___55 *, u16);
	struct sk_buff___55 * (*l3mdev_l3_out)(struct net_device___55 *, struct sock___44 *, struct sk_buff___55 *, u16);
	struct dst_entry___43 * (*l3mdev_link_scope_lookup)(const struct net_device___55 *, struct flowi6 *);
};

struct ndisc_ops___30 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___55 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___55 *, struct neighbour___43 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___55 *, u8, struct neighbour___43 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___55 *, struct sk_buff___55 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___59 *, struct net_device___55 *, const struct prefix_info *, struct inet6_dev___30 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___30;

struct inet6_dev___30 {
	struct net_device___55 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___30 *mc_list;
	struct ifmcaddr6___30 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___54 mc_query_queue;
	struct sk_buff_head___54 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___7 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___43 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___50;

struct tcf_block___50;

struct mini_Qdisc___50 {
	struct tcf_proto___50 *filter_list;
	struct tcf_block___50 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___50 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___55 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___55 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___59 *, struct net_device___55 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___55 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___55 *, struct list_head *);
	size_t (*get_size)(const struct net_device___55 *);
	int (*fill_info)(struct sk_buff___55 *, const struct net_device___55 *);
	size_t (*get_xstats_size)(const struct net_device___55 *);
	int (*fill_xstats)(struct sk_buff___55 *, const struct net_device___55 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___55 *, struct net_device___55 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___55 *, const struct net_device___55 *);
	int (*fill_slave_info)(struct sk_buff___55 *, const struct net_device___55 *, const struct net_device___55 *);
	struct net___59 * (*get_link_net)(const struct net_device___55 *);
	size_t (*get_linkxstats_size)(const struct net_device___55 *, int);
	int (*fill_linkxstats)(struct sk_buff___55 *, const struct net_device___55 *, int *, int);
};

struct netdev_notifier_info___7 {
	struct net_device___55 *dev;
	struct netlink_ext_ack *extack;
};

enum {
	IFLA_BRIDGE_FLAGS = 0,
	IFLA_BRIDGE_MODE = 1,
	IFLA_BRIDGE_VLAN_INFO = 2,
	IFLA_BRIDGE_VLAN_TUNNEL_INFO = 3,
	IFLA_BRIDGE_MRP = 4,
	IFLA_BRIDGE_CFM = 5,
	__IFLA_BRIDGE_MAX = 6,
};

enum {
	BR_MCAST_DIR_RX = 0,
	BR_MCAST_DIR_TX = 1,
	BR_MCAST_DIR_SIZE = 2,
};

enum rtattr_type_t {
	RTA_UNSPEC = 0,
	RTA_DST = 1,
	RTA_SRC = 2,
	RTA_IIF = 3,
	RTA_OIF = 4,
	RTA_GATEWAY = 5,
	RTA_PRIORITY = 6,
	RTA_PREFSRC = 7,
	RTA_METRICS = 8,
	RTA_MULTIPATH = 9,
	RTA_PROTOINFO = 10,
	RTA_FLOW = 11,
	RTA_CACHEINFO = 12,
	RTA_SESSION = 13,
	RTA_MP_ALGO = 14,
	RTA_TABLE = 15,
	RTA_MARK = 16,
	RTA_MFC_STATS = 17,
	RTA_VIA = 18,
	RTA_NEWDST = 19,
	RTA_PREF = 20,
	RTA_ENCAP_TYPE = 21,
	RTA_ENCAP = 22,
	RTA_EXPIRES = 23,
	RTA_PAD = 24,
	RTA_UID = 25,
	RTA_TTL_PROPAGATE = 26,
	RTA_IP_PROTO = 27,
	RTA_SPORT = 28,
	RTA_DPORT = 29,
	RTA_NH_ID = 30,
	__RTA_MAX = 31,
};

struct rta_cacheinfo {
	__u32 rta_clntref;
	__u32 rta_lastuse;
	__s32 rta_expires;
	__u32 rta_error;
	__u32 rta_used;
	__u32 rta_id;
	__u32 rta_ts;
	__u32 rta_tsage;
};

struct block_device_operations___138;

struct gendisk___141 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___141 *part0;
	const struct block_device_operations___138 *fops;
	struct request_queue___138 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___124 *bdi;
	struct kobject___233 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___233 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___138 {
	struct bio___138 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___162 *bip_vec;
	struct bio_vec___162 bip_inline_vecs[0];
};

struct blkcg___126;

struct blkg_policy_data___126;

struct blkcg_gq___126 {
	struct request_queue___138 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___126 *blkcg;
	struct blkcg_gq___126 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___126 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___138 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___138(struct request___138 *);

typedef void integrity_complete_fn___138(struct request___138 *, unsigned int);

struct blk_integrity_profile___138 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___138 *prepare_fn;
	integrity_complete_fn___138 *complete_fn;
	const char *name;
};

struct block_device_operations___138 {
	blk_qc_t (*submit_bio)(struct bio___138 *);
	int (*open)(struct block_device___141 *, fmode_t);
	void (*release)(struct gendisk___141 *, fmode_t);
	int (*rw_page)(struct block_device___141 *, sector_t, struct page___250 *, unsigned int);
	int (*ioctl)(struct block_device___141 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___141 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___141 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___141 *);
	int (*getgeo)(struct block_device___141 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___141 *, bool);
	void (*swap_slot_free_notify)(struct block_device___141 *, long unsigned int);
	int (*report_zones)(struct gendisk___141 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___141 *, umode_t *);
	struct module___229 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___141 *, sector_t *);
};

typedef void rq_end_io_fn___138(struct request___138 *, blk_status_t);

struct request___138 {
	struct request_queue___138 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___133 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___138 *bio;
	struct bio___138 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___162 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___138 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___138 *saved_end_io;
		} flush;
	};
	struct gendisk___141 *rq_disk;
	struct block_device___141 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___138 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___133 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___138 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___233 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___245 *debugfs_dir;
	struct dentry___245 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___138;

struct elevator_mq_ops___138 {
	int (*init_sched)(struct request_queue___138 *, struct elevator_type___138 *);
	void (*exit_sched)(struct elevator_queue___138 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___133 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___133 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___133 *);
	bool (*allow_merge)(struct request_queue___138 *, struct request___138 *, struct bio___138 *);
	bool (*bio_merge)(struct request_queue___138 *, struct bio___138 *, unsigned int);
	int (*request_merge)(struct request_queue___138 *, struct request___138 **, struct bio___138 *);
	void (*request_merged)(struct request_queue___138 *, struct request___138 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___138 *, struct request___138 *, struct request___138 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___138 *);
	void (*finish_request)(struct request___138 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___133 *, struct list_head *, bool);
	struct request___138 * (*dispatch_request)(struct blk_mq_hw_ctx___133 *);
	bool (*has_work)(struct blk_mq_hw_ctx___133 *);
	void (*completed_request)(struct request___138 *, u64);
	void (*requeue_request)(struct request___138 *);
	struct request___138 * (*former_request)(struct request_queue___138 *, struct request___138 *);
	struct request___138 * (*next_request)(struct request_queue___138 *, struct request___138 *);
	void (*init_icq)(struct io_cq___138 *);
	void (*exit_icq)(struct io_cq___138 *);
};

struct elv_fs_entry___138;

struct elevator_type___138 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___138 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___138 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___229 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___138 {
	struct elevator_type___138 *type;
	void *elevator_data;
	struct kobject___233 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___138 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___138 *, char *);
	ssize_t (*store)(struct elevator_queue___138 *, const char *, size_t);
};

struct blk_mq_queue_data___133;

struct blk_mq_ops___133 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___133 *, const struct blk_mq_queue_data___133 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___133 *);
	int (*get_budget)(struct request_queue___138 *);
	void (*put_budget)(struct request_queue___138 *, int);
	void (*set_rq_budget_token)(struct request___138 *, int);
	int (*get_rq_budget_token)(struct request___138 *);
	enum blk_eh_timer_return (*timeout)(struct request___138 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___133 *);
	void (*complete)(struct request___138 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___133 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___133 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___133 *, struct request___138 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___133 *, struct request___138 *, unsigned int);
	void (*initialize_rq_fn)(struct request___138 *);
	void (*cleanup_rq)(struct request___138 *);
	bool (*busy)(struct request_queue___138 *);
	int (*map_queues)(struct blk_mq_tag_set___133 *);
	void (*show_rq)(struct seq_file___220 *, struct request___138 *);
};

struct blk_mq_tag_set___133 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___133 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___133 {
	struct request___138 *rq;
	bool last;
};

struct blkcg_policy_data___126;

struct blkcg___126 {
	struct cgroup_subsys_state___172 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___126 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___126 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___126 {
	struct blkcg___126 *blkcg;
	int plid;
};

struct blkg_policy_data___126 {
	struct blkcg_gq___126 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___112 {
	struct mem_cgroup___112 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___112 {
	struct lruvec___120 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___112 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___112 *memcg;
};

struct obj_cgroup___112 {
	struct percpu_ref refcnt;
	struct mem_cgroup___112 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___50 {
	spinlock_t *lock;
	struct sk_buff___55 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

typedef int (*rtnl_doit_func___3)(struct sk_buff___55 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___3)(struct sk_buff___55 *, struct netlink_callback___54 *);

struct rtnl_af_ops {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___55 *, const struct net_device___55 *, u32);
	size_t (*get_link_af_size)(const struct net_device___55 *, u32);
	int (*validate_link_af)(const struct net_device___55 *, const struct nlattr *, struct netlink_ext_ack *);
	int (*set_link_af)(struct net_device___55 *, const struct nlattr *, struct netlink_ext_ack *);
	int (*fill_stats_af)(struct sk_buff___55 *, const struct net_device___55 *);
	size_t (*get_stats_af_size)(const struct net_device___55 *);
};

struct Qdisc_class_ops___50;

struct Qdisc_ops___50 {
	struct Qdisc_ops___50 *next;
	const struct Qdisc_class_ops___50 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___55 *, struct Qdisc___50 *, struct sk_buff___55 **);
	struct sk_buff___55 * (*dequeue)(struct Qdisc___50 *);
	struct sk_buff___55 * (*peek)(struct Qdisc___50 *);
	int (*init)(struct Qdisc___50 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___50 *);
	void (*destroy)(struct Qdisc___50 *);
	int (*change)(struct Qdisc___50 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___50 *);
	int (*change_tx_queue_len)(struct Qdisc___50 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___50 *, unsigned int);
	int (*dump)(struct Qdisc___50 *, struct sk_buff___55 *);
	int (*dump_stats)(struct Qdisc___50 *, struct gnet_dump___50 *);
	void (*ingress_block_set)(struct Qdisc___50 *, u32);
	void (*egress_block_set)(struct Qdisc___50 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___50 *);
	u32 (*egress_block_get)(struct Qdisc___50 *);
	struct module___229 *owner;
};

struct qdisc_walker___4;

struct Qdisc_class_ops___50 {
	unsigned int flags;
	struct netdev_queue___54 * (*select_queue)(struct Qdisc___50 *, struct tcmsg *);
	int (*graft)(struct Qdisc___50 *, long unsigned int, struct Qdisc___50 *, struct Qdisc___50 **, struct netlink_ext_ack *);
	struct Qdisc___50 * (*leaf)(struct Qdisc___50 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___50 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___50 *, u32);
	int (*change)(struct Qdisc___50 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___50 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___50 *, struct qdisc_walker___4 *);
	struct tcf_block___50 * (*tcf_block)(struct Qdisc___50 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___50 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___50 *, long unsigned int);
	int (*dump)(struct Qdisc___50 *, long unsigned int, struct sk_buff___55 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___50 *, long unsigned int, struct gnet_dump___50 *);
};

struct qdisc_walker___4 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___50 *, long unsigned int, struct qdisc_walker___4 *);
};

struct tcf_chain___50;

struct tcf_block___50 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___59 *net;
	struct Qdisc___50 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___50 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___50;

struct tcf_proto_ops___50;

struct tcf_proto___50 {
	struct tcf_proto___50 *next;
	void *root;
	int (*classify)(struct sk_buff___55 *, const struct tcf_proto___50 *, struct tcf_result___50 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___50 *ops;
	struct tcf_chain___50 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___50 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___50 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___50 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___55 *, const struct tcf_proto___50 *, struct tcf_result___50 *);
	int (*init)(struct tcf_proto___50 *);
	void (*destroy)(struct tcf_proto___50 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___50 *, u32);
	void (*put)(struct tcf_proto___50 *, void *);
	int (*change)(struct net___59 *, struct sk_buff___55 *, struct tcf_proto___50 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___50 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___50 *);
	void (*walk)(struct tcf_proto___50 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___50 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___50 *, void *);
	void (*hw_del)(struct tcf_proto___50 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___59 *, struct tcf_chain___50 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___59 *, struct tcf_proto___50 *, void *, struct sk_buff___55 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___59 *, struct tcf_proto___50 *, void *, struct sk_buff___55 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___55 *, struct net___59 *, void *);
	struct module___229 *owner;
	int flags;
};

struct tcf_chain___50 {
	struct mutex filter_chain_lock;
	struct tcf_proto___50 *filter_chain;
	struct list_head list;
	struct tcf_block___50 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___50 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___43 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___50 *prog;
};

struct pneigh_entry___43;

struct neigh_hash_table___43;

struct neigh_table___43 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___55 *, __u32 *);
	bool (*key_eq)(const struct neighbour___43 *, const void *);
	int (*constructor)(struct neighbour___43 *);
	int (*pconstructor)(struct pneigh_entry___43 *);
	void (*pdestructor)(struct pneigh_entry___43 *);
	void (*proxy_redo)(struct sk_buff___55 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___55 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___43 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___54 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___43 *nht;
	struct pneigh_entry___43 **phash_buckets;
};

struct neigh_ops___43 {
	int family;
	void (*solicit)(struct neighbour___43 *, struct sk_buff___55 *);
	void (*error_report)(struct neighbour___43 *, struct sk_buff___55 *);
	int (*output)(struct neighbour___43 *, struct sk_buff___55 *);
	int (*connected_output)(struct neighbour___43 *, struct sk_buff___55 *);
};

struct pneigh_entry___43 {
	struct pneigh_entry___43 *next;
	possible_net_t___54 net;
	struct net_device___55 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___43 {
	struct neighbour___43 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___25 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___59 *, struct sock___44 *, struct sk_buff___55 *);
	int (*orig_input)(struct sk_buff___55 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___43 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___43 *ctarget;
	struct net___59 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___43 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___43 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___32;

struct timewait_sock_ops___32;

struct proto___43 {
	void (*close)(struct sock___44 *, long int);
	int (*pre_connect)(struct sock___44 *, struct sockaddr *, int);
	int (*connect)(struct sock___44 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___44 *, int);
	struct sock___44 * (*accept)(struct sock___44 *, int, int *, bool);
	int (*ioctl)(struct sock___44 *, int, long unsigned int);
	int (*init)(struct sock___44 *);
	void (*destroy)(struct sock___44 *);
	void (*shutdown)(struct sock___44 *, int);
	int (*setsockopt)(struct sock___44 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___44 *, int, int, char *, int *);
	void (*keepalive)(struct sock___44 *, int);
	int (*compat_ioctl)(struct sock___44 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___44 *, struct msghdr___45 *, size_t);
	int (*recvmsg)(struct sock___44 *, struct msghdr___45 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___44 *, struct page___250 *, int, size_t, int);
	int (*bind)(struct sock___44 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___44 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___44 *, struct sk_buff___55 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___44 *);
	int (*hash)(struct sock___44 *);
	void (*unhash)(struct sock___44 *);
	void (*rehash)(struct sock___44 *);
	int (*get_port)(struct sock___44 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___44 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___44 *, int);
	bool (*sock_is_readable)(struct sock___44 *);
	void (*enter_memory_pressure)(struct sock___44 *);
	void (*leave_memory_pressure)(struct sock___44 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___32 *rsk_prot;
	struct timewait_sock_ops___32 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___229 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___44 *, int);
};

struct sock_reuseport___9 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___50 *prog;
	struct sock___44 *socks[0];
};

struct request_sock___33;

struct request_sock_ops___32 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___44 *, struct request_sock___33 *);
	void (*send_ack)(const struct sock___44 *, struct sk_buff___55 *, struct request_sock___33 *);
	void (*send_reset)(const struct sock___44 *, struct sk_buff___55 *);
	void (*destructor)(struct request_sock___33 *);
	void (*syn_ack_timeout)(const struct request_sock___33 *);
};

struct timewait_sock_ops___32 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___44 *, struct sock___44 *, void *);
	void (*twsk_destructor)(struct sock___44 *);
};

struct request_sock___33 {
	struct sock_common___43 __req_common;
	struct request_sock___33 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___32 *rsk_ops;
	struct sock___44 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___30 {
	struct in6_addr mca_addr;
	struct inet6_dev___30 *idev;
	struct ifmcaddr6___30 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct rtnl_link {
	rtnl_doit_func___3 doit;
	rtnl_dumpit_func___3 dumpit;
	struct module___229 *owner;
	unsigned int flags;
	struct callback_head rcu;
};

enum {
	IF_LINK_MODE_DEFAULT = 0,
	IF_LINK_MODE_DORMANT = 1,
	IF_LINK_MODE_TESTING = 2,
};

enum lw_bits {
	LW_URGENT = 0,
};

struct dentry___246;

struct super_block___246;

struct module___230;

struct file_system_type___246 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___246 * (*mount)(struct file_system_type___246 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___246 *);
	struct module___230 *owner;
	struct file_system_type___246 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___246;

struct kiocb___246;

struct iov_iter___166;

struct poll_table_struct___169;

struct vm_area_struct___251;

struct inode___246;

struct file_lock___246;

struct page___251;

struct pipe_inode_info___87;

struct seq_file___221;

struct file_operations___247 {
	struct module___230 *owner;
	loff_t (*llseek)(struct file___246 *, loff_t, int);
	ssize_t (*read)(struct file___246 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___246 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___246 *, struct iov_iter___166 *);
	ssize_t (*write_iter)(struct kiocb___246 *, struct iov_iter___166 *);
	int (*iopoll)(struct kiocb___246 *, bool);
	int (*iterate)(struct file___246 *, struct dir_context *);
	int (*iterate_shared)(struct file___246 *, struct dir_context *);
	__poll_t (*poll)(struct file___246 *, struct poll_table_struct___169 *);
	long int (*unlocked_ioctl)(struct file___246 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___246 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___246 *, struct vm_area_struct___251 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___246 *, struct file___246 *);
	int (*flush)(struct file___246 *, fl_owner_t);
	int (*release)(struct inode___246 *, struct file___246 *);
	int (*fsync)(struct file___246 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___246 *, int);
	int (*lock)(struct file___246 *, int, struct file_lock___246 *);
	ssize_t (*sendpage)(struct file___246 *, struct page___251 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___246 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___246 *, long unsigned int);
	int (*flock)(struct file___246 *, int, struct file_lock___246 *);
	ssize_t (*splice_write)(struct pipe_inode_info___87 *, struct file___246 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___246 *, loff_t *, struct pipe_inode_info___87 *, size_t, unsigned int);
	int (*setlease)(struct file___246 *, long int, struct file_lock___246 **, void **);
	long int (*fallocate)(struct file___246 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___221 *, struct file___246 *);
	ssize_t (*copy_file_range)(struct file___246 *, loff_t, struct file___246 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___246 *, loff_t, struct file___246 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___246 *, loff_t, loff_t, int);
};

struct vmacache___251 {
	u64 seqnum;
	struct vm_area_struct___251 *vmas[4];
};

struct page_frag___251 {
	struct page___251 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___252;

struct pid___223;

struct nsproxy___232;

struct signal_struct___247;

struct bio_list___139;

struct backing_dev_info___125;

struct io_context___139;

struct css_set___173;

struct mem_cgroup___113;

struct request_queue___139;

struct vm_struct___229;

struct bpf_local_storage___8;

struct task_struct___253 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___253 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___252 *mm;
	struct mm_struct___252 *active_mm;
	struct vmacache___251 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___253 *real_parent;
	struct task_struct___253 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___253 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___223 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___232 *nsproxy;
	struct signal_struct___247 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___253 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___139 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___125 *backing_dev_info;
	struct io_context___139 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___173 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___87 *splice_pipe;
	struct page_frag___251 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___113 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___113 *active_memcg;
	struct request_queue___139 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___253 *oom_reaper_list;
	struct vm_struct___229 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___8 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___234;

struct kobj_type___234;

struct kernfs_node___234;

struct kobject___234 {
	const char *name;
	struct list_head entry;
	struct kobject___234 *parent;
	struct kset___234 *kset;
	struct kobj_type___234 *ktype;
	struct kernfs_node___234 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___231 {
	struct kobject___234 kobj;
	struct module___230 *mod;
	struct kobject___234 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___230 {
	struct module___230 *mod;
	struct latch_tree_node node;
};

struct module_layout___230 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___230 mtn;
};

struct module_attribute___230;

struct kernel_param___230;

struct module___230 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___231 mkobj;
	struct module_attribute___230 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___234 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___230 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___230 core_layout;
	struct module_layout___230 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___223;

struct upid___223 {
	int nr;
	struct pid_namespace___223 *ns;
};

struct pid_namespace___223 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___253 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___223 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___223 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___223 numbers[1];
};

typedef struct page___251 *pgtable_t___251;

struct address_space___246;

struct page_pool___75;

struct dev_pagemap___241;

struct page___251 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___246 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___75 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___251 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___251 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___252 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___241 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___241;

struct vm_area_struct___251 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___251 *vm_next;
	struct vm_area_struct___251 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___252 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___241 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___246 *vm_file;
	struct file___246 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___247 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___253 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___253 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___223 *pids[4];
	struct pid___223 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___252 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___251;

struct mm_struct___252 {
	struct {
		struct vm_area_struct___251 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___246 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___251 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___253 *owner;
		struct user_namespace___26 *user_ns;
		struct file___246 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___60;

struct cgroup_namespace___173;

struct nsproxy___232 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___223 *pid_ns_for_children;
	struct net___60 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___173 *cgroup_ns;
};

struct bio___139;

struct bio_list___139 {
	struct bio___139 *head;
	struct bio___139 *tail;
};

struct cgroup_subsys_state___173;

struct bdi_writeback___125 {
	struct backing_dev_info___125 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___173 *memcg_css;
	struct cgroup_subsys_state___173 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___227;

struct backing_dev_info___125 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___125 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___227 *dev;
	char dev_name[64];
	struct device___227 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___246 *debug_dir;
};

struct io_cq___139;

struct io_context___139 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___139 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___173;

struct css_set___173 {
	struct cgroup_subsys_state___173 *subsys[14];
	refcount_t refcount;
	struct css_set___173 *dom_cset;
	struct cgroup___173 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___173 *mg_src_cgrp;
	struct cgroup___173 *mg_dst_cgrp;
	struct css_set___173 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___246;

struct pipe_buffer___87;

struct pipe_inode_info___87 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___251 *tmp_page;
	struct fasync_struct___246 *fasync_readers;
	struct fasync_struct___246 *fasync_writers;
	struct pipe_buffer___87 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___173;

struct cgroup_subsys_state___173 {
	struct cgroup___173 *cgroup;
	struct cgroup_subsys___173 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___173 *parent;
};

struct cgroup_file___173 {
	struct kernfs_node___234 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___113;

struct mem_cgroup_per_node___113;

struct mem_cgroup___113 {
	struct cgroup_subsys_state___173 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___173 events_file;
	struct cgroup_file___173 events_local_file;
	struct cgroup_file___173 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___113 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___253 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___113 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___139;

struct blk_integrity___139 {
	const struct blk_integrity_profile___139 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___139 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___139 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___139;

struct elevator_queue___139;

struct blk_mq_ops___134;

struct blk_mq_hw_ctx___134;

struct gendisk___142;

struct blkcg_gq___127;

struct blk_mq_tag_set___134;

struct request_queue___139 {
	struct request___139 *last_merge;
	struct elevator_queue___139 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___134 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___134 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___142 *disk;
	struct kobject___234 kobj;
	struct kobject___234 *mq_kobj;
	struct blk_integrity___139 integrity;
	struct device___227 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___127 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___134 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___139 bio_split;
	struct dentry___246 *debugfs_dir;
	struct dentry___246 *sched_debugfs_dir;
	struct dentry___246 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___229 {
	struct vm_struct___229 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___251 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___8;

struct bpf_local_storage___8 {
	struct bpf_local_storage_data___8 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct address_space_operations___246;

struct address_space___246 {
	struct inode___246 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___246 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___75 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___227 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___75 {
	u32 count;
	struct page___251 *cache[128];
};

struct page_pool___75 {
	struct page_pool_params___75 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___251 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___75 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___241;

struct dev_pagemap___241 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___241 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___246;

struct path___246 {
	struct vfsmount___246 *mnt;
	struct dentry___246 *dentry;
};

struct fown_struct___223 {
	rwlock_t lock;
	struct pid___223 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___246 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___246 f_path;
	struct inode___246 *f_inode;
	const struct file_operations___247 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___223 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___246 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___241;

struct vm_operations_struct___241 {
	void (*open)(struct vm_area_struct___251 *);
	void (*close)(struct vm_area_struct___251 *);
	int (*may_split)(struct vm_area_struct___251 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___251 *);
	int (*mprotect)(struct vm_area_struct___251 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___241 *);
	vm_fault_t (*huge_fault)(struct vm_fault___241 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___241 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___251 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___241 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___241 *);
	int (*access)(struct vm_area_struct___251 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___251 *);
	int (*set_policy)(struct vm_area_struct___251 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___251 *, long unsigned int);
	struct page___251 * (*find_special_page)(struct vm_area_struct___251 *, long unsigned int);
};

struct core_thread___251 {
	struct task_struct___253 *task;
	struct core_thread___251 *next;
};

struct core_state___251 {
	atomic_t nr_threads;
	struct core_thread___251 dumper;
	struct completion startup;
};

struct vm_fault___241 {
	const struct {
		struct vm_area_struct___251 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___251 *cow_page;
	struct page___251 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___251 prealloc_pte;
};

struct pglist_data___121;

struct lruvec___121 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___121 *pgdat;
};

struct zone___121 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___121 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___121 {
	struct zone___121 *zone;
	int zone_idx;
};

struct zonelist___121 {
	struct zoneref___121 _zonerefs[321];
};

struct pglist_data___121 {
	struct zone___121 node_zones[5];
	struct zonelist___121 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___253 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___253 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___121 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___246;

struct dentry___246 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___246 *d_parent;
	struct qstr d_name;
	struct inode___246 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___246 *d_op;
	struct super_block___246 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___246;

struct inode___246 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___246 *i_op;
	struct super_block___246 *i_sb;
	struct address_space___246 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___125 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___247 *i_fop;
		void (*free_inode)(struct inode___246 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___246 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___87 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___246 {
	int (*d_revalidate)(struct dentry___246 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___246 *, unsigned int);
	int (*d_hash)(const struct dentry___246 *, struct qstr *);
	int (*d_compare)(const struct dentry___246 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___246 *);
	int (*d_init)(struct dentry___246 *);
	void (*d_release)(struct dentry___246 *);
	void (*d_prune)(struct dentry___246 *);
	void (*d_iput)(struct dentry___246 *, struct inode___246 *);
	char * (*d_dname)(struct dentry___246 *, char *, int);
	struct vfsmount___246 * (*d_automount)(struct path___246 *);
	int (*d_manage)(const struct path___246 *, bool);
	struct dentry___246 * (*d_real)(struct dentry___246 *, const struct inode___246 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___246;

struct mem_dqinfo___246 {
	struct quota_format_type___246 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___246;

struct quota_info___246 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___246 *files[3];
	struct mem_dqinfo___246 info[3];
	const struct quota_format_ops___246 *ops[3];
};

struct rcuwait___247 {
	struct task_struct___253 *task;
};

struct percpu_rw_semaphore___247 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___247 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___246 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___247 rw_sem[3];
};

struct shrink_control___113;

struct shrinker___113 {
	long unsigned int (*count_objects)(struct shrinker___113 *, struct shrink_control___113 *);
	long unsigned int (*scan_objects)(struct shrinker___113 *, struct shrink_control___113 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___246;

struct dquot_operations___246;

struct quotactl_ops___246;

struct block_device___142;

struct super_block___246 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___246 *s_type;
	const struct super_operations___246 *s_op;
	const struct dquot_operations___246 *dq_op;
	const struct quotactl_ops___246 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___246 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___142 *s_bdev;
	struct backing_dev_info___125 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___246 s_dquot;
	struct sb_writers___246 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___246 *s_d_op;
	int cleancache_poolid;
	struct shrinker___113 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___246 {
	struct dentry___246 *mnt_root;
	struct super_block___246 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___113 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___113 *memcg;
};

struct psi_group___173 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___253 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___51;

struct cgroup_bpf___51 {
	struct bpf_prog_array___51 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___51 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___173;

struct cgroup_rstat_cpu___173;

struct cgroup___173 {
	struct cgroup_subsys_state___173 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___234 *kn;
	struct cgroup_file___173 procs_file;
	struct cgroup_file___173 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___173 *subsys[14];
	struct cgroup_root___173 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___173 *dom_cgrp;
	struct cgroup___173 *old_dom_cgrp;
	struct cgroup_rstat_cpu___173 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___173 psi;
	struct cgroup_bpf___51 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___139 {
	struct request_queue___139 *q;
	struct io_context___139 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___246 {
	struct file___246 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___246 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___246 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___246 *ia_file;
};

struct dquot___246 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___246 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___246 {
	int qf_fmt_id;
	const struct quota_format_ops___246 *qf_ops;
	struct module___230 *qf_owner;
	struct quota_format_type___246 *qf_next;
};

struct quota_format_ops___246 {
	int (*check_quota_file)(struct super_block___246 *, int);
	int (*read_file_info)(struct super_block___246 *, int);
	int (*write_file_info)(struct super_block___246 *, int);
	int (*free_file_info)(struct super_block___246 *, int);
	int (*read_dqblk)(struct dquot___246 *);
	int (*commit_dqblk)(struct dquot___246 *);
	int (*release_dqblk)(struct dquot___246 *);
	int (*get_next_id)(struct super_block___246 *, struct kqid *);
};

struct dquot_operations___246 {
	int (*write_dquot)(struct dquot___246 *);
	struct dquot___246 * (*alloc_dquot)(struct super_block___246 *, int);
	void (*destroy_dquot)(struct dquot___246 *);
	int (*acquire_dquot)(struct dquot___246 *);
	int (*release_dquot)(struct dquot___246 *);
	int (*mark_dirty)(struct dquot___246 *);
	int (*write_info)(struct super_block___246 *, int);
	qsize_t * (*get_reserved_space)(struct inode___246 *);
	int (*get_projid)(struct inode___246 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___246 *, qsize_t *);
	int (*get_next_id)(struct super_block___246 *, struct kqid *);
};

struct quotactl_ops___246 {
	int (*quota_on)(struct super_block___246 *, int, int, const struct path___246 *);
	int (*quota_off)(struct super_block___246 *, int);
	int (*quota_enable)(struct super_block___246 *, unsigned int);
	int (*quota_disable)(struct super_block___246 *, unsigned int);
	int (*quota_sync)(struct super_block___246 *, int);
	int (*set_info)(struct super_block___246 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___246 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___246 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___246 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___246 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___246 *, unsigned int);
};

struct writeback_control___125;

struct address_space_operations___246 {
	int (*writepage)(struct page___251 *, struct writeback_control___125 *);
	int (*readpage)(struct file___246 *, struct page___251 *);
	int (*writepages)(struct address_space___246 *, struct writeback_control___125 *);
	int (*set_page_dirty)(struct page___251 *);
	int (*readpages)(struct file___246 *, struct address_space___246 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___246 *, struct address_space___246 *, loff_t, unsigned int, unsigned int, struct page___251 **, void **);
	int (*write_end)(struct file___246 *, struct address_space___246 *, loff_t, unsigned int, unsigned int, struct page___251 *, void *);
	sector_t (*bmap)(struct address_space___246 *, sector_t);
	void (*invalidatepage)(struct page___251 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___251 *, gfp_t);
	void (*freepage)(struct page___251 *);
	ssize_t (*direct_IO)(struct kiocb___246 *, struct iov_iter___166 *);
	int (*migratepage)(struct address_space___246 *, struct page___251 *, struct page___251 *, enum migrate_mode);
	bool (*isolate_page)(struct page___251 *, isolate_mode_t);
	void (*putback_page)(struct page___251 *);
	int (*launder_page)(struct page___251 *);
	int (*is_partially_uptodate)(struct page___251 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___251 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___246 *, struct page___251 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___246 *, sector_t *);
	void (*swap_deactivate)(struct file___246 *);
};

struct writeback_control___125 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___125 *wb;
	struct inode___246 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___163;

struct iov_iter___166 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___163 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___87 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___246 {
	struct dentry___246 * (*lookup)(struct inode___246 *, struct dentry___246 *, unsigned int);
	const char * (*get_link)(struct dentry___246 *, struct inode___246 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___246 *, int);
	struct posix_acl * (*get_acl)(struct inode___246 *, int, bool);
	int (*readlink)(struct dentry___246 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___246 *, struct dentry___246 *, umode_t, bool);
	int (*link)(struct dentry___246 *, struct inode___246 *, struct dentry___246 *);
	int (*unlink)(struct inode___246 *, struct dentry___246 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___246 *, struct dentry___246 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___246 *, struct dentry___246 *, umode_t);
	int (*rmdir)(struct inode___246 *, struct dentry___246 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___246 *, struct dentry___246 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___246 *, struct dentry___246 *, struct inode___246 *, struct dentry___246 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___246 *, struct iattr___246 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___246 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___246 *, char *, size_t);
	int (*fiemap)(struct inode___246 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___246 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___246 *, struct dentry___246 *, struct file___246 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___246 *, struct dentry___246 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___246 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___246 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___246 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___246 {
	void (*fl_copy_lock)(struct file_lock___246 *, struct file_lock___246 *);
	void (*fl_release_private)(struct file_lock___246 *);
};

struct lock_manager_operations___246;

struct file_lock___246 {
	struct file_lock___246 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___246 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___246 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___246 *fl_ops;
	const struct lock_manager_operations___246 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___246 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___246 *);
	int (*lm_grant)(struct file_lock___246 *, int);
	bool (*lm_break)(struct file_lock___246 *);
	int (*lm_change)(struct file_lock___246 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___246 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___246 *);
};

struct fasync_struct___246 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___246 *fa_next;
	struct file___246 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___246 {
	struct inode___246 * (*alloc_inode)(struct super_block___246 *);
	void (*destroy_inode)(struct inode___246 *);
	void (*free_inode)(struct inode___246 *);
	void (*dirty_inode)(struct inode___246 *, int);
	int (*write_inode)(struct inode___246 *, struct writeback_control___125 *);
	int (*drop_inode)(struct inode___246 *);
	void (*evict_inode)(struct inode___246 *);
	void (*put_super)(struct super_block___246 *);
	int (*sync_fs)(struct super_block___246 *, int);
	int (*freeze_super)(struct super_block___246 *);
	int (*freeze_fs)(struct super_block___246 *);
	int (*thaw_super)(struct super_block___246 *);
	int (*unfreeze_fs)(struct super_block___246 *);
	int (*statfs)(struct dentry___246 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___246 *, int *, char *);
	void (*umount_begin)(struct super_block___246 *);
	int (*show_options)(struct seq_file___221 *, struct dentry___246 *);
	int (*show_devname)(struct seq_file___221 *, struct dentry___246 *);
	int (*show_path)(struct seq_file___221 *, struct dentry___246 *);
	int (*show_stats)(struct seq_file___221 *, struct dentry___246 *);
	ssize_t (*quota_read)(struct super_block___246 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___246 *, int, const char *, size_t, loff_t);
	struct dquot___246 ** (*get_dquots)(struct inode___246 *);
	long int (*nr_cached_objects)(struct super_block___246 *, struct shrink_control___113 *);
	long int (*free_cached_objects)(struct super_block___246 *, struct shrink_control___113 *);
	struct file___246 * (*real_loop)(struct file___246 *);
};

struct wakeup_source___227;

struct dev_pm_info___227 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___227 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___227 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___227;

struct bus_type___227;

struct device_driver___227;

struct dev_pm_domain___227;

struct fwnode_handle___223;

struct class___227;

struct attribute_group___234;

struct device___227 {
	struct kobject___234 kobj;
	struct device___227 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___227 *type;
	struct bus_type___227 *bus;
	struct device_driver___227 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___227 power;
	struct dev_pm_domain___227 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___223 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___227 *class;
	const struct attribute_group___234 **groups;
	void (*release)(struct device___227 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___142 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___246 *bd_inode;
	struct super_block___246 *bd_super;
	void *bd_claiming;
	struct device___227 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___234 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___142 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___246 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___177)(struct file___246 *, wait_queue_head_t *, struct poll_table_struct___169 *);

struct poll_table_struct___169 {
	poll_queue_proc___177 _qproc;
	__poll_t _key;
};

struct seq_operations___221;

struct seq_file___221 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___221 *op;
	int poll_event;
	const struct file___246 *file;
	void *private;
};

typedef void bio_end_io_t___139(struct bio___139 *);

struct bio_vec___163 {
	struct page___251 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___139;

struct bio___139 {
	struct bio___139 *bi_next;
	struct block_device___142 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___139 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___127 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___139 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___163 *bi_io_vec;
	struct bio_set___139 *bi_pool;
	struct bio_vec___163 bi_inline_vecs[0];
};

struct kernfs_root___234;

struct kernfs_elem_dir___234 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___234 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___234;

struct kernfs_root___234 {
	struct kernfs_node___234 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___234 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___234 {
	struct kernfs_node___234 *target_kn;
};

struct kernfs_ops___234;

struct kernfs_elem_attr___234 {
	const struct kernfs_ops___234 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___234 *notify_next;
};

struct kernfs_node___234 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___234 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___234 dir;
		struct kernfs_elem_symlink___234 symlink;
		struct kernfs_elem_attr___234 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___234;

struct kernfs_ops___234 {
	int (*open)(struct kernfs_open_file___234 *);
	void (*release)(struct kernfs_open_file___234 *);
	int (*seq_show)(struct seq_file___221 *, void *);
	void * (*seq_start)(struct seq_file___221 *, loff_t *);
	void * (*seq_next)(struct seq_file___221 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___221 *, void *);
	ssize_t (*read)(struct kernfs_open_file___234 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___234 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___234 *, struct poll_table_struct___169 *);
	int (*mmap)(struct kernfs_open_file___234 *, struct vm_area_struct___251 *);
};

struct kernfs_syscall_ops___234 {
	int (*show_options)(struct seq_file___221 *, struct kernfs_root___234 *);
	int (*mkdir)(struct kernfs_node___234 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___234 *);
	int (*rename)(struct kernfs_node___234 *, struct kernfs_node___234 *, const char *);
	int (*show_path)(struct seq_file___221 *, struct kernfs_node___234 *, struct kernfs_root___234 *);
};

struct kernfs_open_file___234 {
	struct kernfs_node___234 *kn;
	struct file___246 *file;
	struct seq_file___221 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___241 *vm_ops;
};

struct kobj_ns_type_operations___44 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___3 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___60 *net;
} possible_net_t___55;

struct proto___44;

struct sock_common___44 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___44 *skc_prot;
	possible_net_t___55 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___3 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___56;

struct sk_buff_head___55 {
	struct sk_buff___56 *next;
	struct sk_buff___56 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___44 {
	struct cgroup___173 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___44;

struct socket_wq___45;

struct xfrm_policy___6;

struct dst_entry___44;

struct socket___46;

struct sock_reuseport___10;

struct sock___3 {
	struct sock_common___44 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___55 sk_error_queue;
	struct sk_buff___56 *sk_rx_skb_cache;
	struct sk_buff_head___55 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___56 *head;
		struct sk_buff___56 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___44 *sk_filter;
	union {
		struct socket_wq___45 *sk_wq;
		struct socket_wq___45 *sk_wq_raw;
	};
	struct xfrm_policy___6 *sk_policy[2];
	struct dst_entry___44 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___44 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___56 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___56 *sk_tx_skb_cache;
	struct sk_buff_head___55 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___251 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___44 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___223 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___46 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___44 sk_cgrp_data;
	struct mem_cgroup___113 *sk_memcg;
	void (*sk_state_change)(struct sock___3 *);
	void (*sk_data_ready)(struct sock___3 *);
	void (*sk_write_space)(struct sock___3 *);
	void (*sk_error_report)(struct sock___3 *);
	int (*sk_backlog_rcv)(struct sock___3 *, struct sk_buff___56 *);
	struct sk_buff___56 * (*sk_validate_xmit_skb)(struct sock___3 *, struct net_device___5 *, struct sk_buff___56 *);
	void (*sk_destruct)(struct sock___3 *);
	struct sock_reuseport___10 *sk_reuseport_cb;
	struct bpf_local_storage___8 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___234;

struct attribute_group___234 {
	const char *name;
	umode_t (*is_visible)(struct kobject___234 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___234 *, struct bin_attribute___234 *, int);
	struct attribute **attrs;
	struct bin_attribute___234 **bin_attrs;
};

struct bin_attribute___234 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___246 * (*f_mapping)();
	ssize_t (*read)(struct file___246 *, struct kobject___234 *, struct bin_attribute___234 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___246 *, struct kobject___234 *, struct bin_attribute___234 *, char *, loff_t, size_t);
	int (*mmap)(struct file___246 *, struct kobject___234 *, struct bin_attribute___234 *, struct vm_area_struct___251 *);
};

struct sysfs_ops___234 {
	ssize_t (*show)(struct kobject___234 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___234 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___234;

struct kset___234 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___234 kobj;
	const struct kset_uevent_ops___234 *uevent_ops;
};

struct kobj_type___234 {
	void (*release)(struct kobject___234 *);
	const struct sysfs_ops___234 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___234 **default_groups;
	const struct kobj_ns_type_operations___44 * (*child_ns_type)(struct kobject___234 *);
	const void * (*namespace)(struct kobject___234 *);
	void (*get_ownership)(struct kobject___234 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___234 {
	int (* const filter)(struct kset___234 *, struct kobject___234 *);
	const char * (* const name)(struct kset___234 *, struct kobject___234 *);
	int (* const uevent)(struct kset___234 *, struct kobject___234 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___230 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___230 *);
	int (*get)(char *, const struct kernel_param___230 *);
	void (*free)(void *);
};

struct kparam_array___230;

struct kernel_param___230 {
	const char *name;
	struct module___230 *mod;
	const struct kernel_param_ops___230 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___230 *arr;
	};
};

struct kparam_array___230 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___230 *ops;
	void *elem;
};

struct module_attribute___230 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___230 *, struct module_kobject___231 *, char *);
	ssize_t (*store)(struct module_attribute___230 *, struct module_kobject___231 *, const char *, size_t);
	void (*setup)(struct module___230 *, const char *);
	int (*test)(struct module___230 *);
	void (*free)(struct module___230 *);
};

struct dev_pagemap_ops___241 {
	void (*page_free)(struct page___251 *);
	void (*kill)(struct dev_pagemap___241 *);
	void (*cleanup)(struct dev_pagemap___241 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___241 *);
};

struct msghdr___46 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___166 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___246 *msg_iocb;
};

struct fwnode_operations___223;

struct fwnode_handle___223 {
	struct fwnode_handle___223 *secondary;
	const struct fwnode_operations___223 *ops;
	struct device___227 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___223;

struct fwnode_endpoint___223;

struct fwnode_operations___223 {
	struct fwnode_handle___223 * (*get)(struct fwnode_handle___223 *);
	void (*put)(struct fwnode_handle___223 *);
	bool (*device_is_available)(const struct fwnode_handle___223 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___223 *, const struct device___227 *);
	bool (*property_present)(const struct fwnode_handle___223 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___223 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___223 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___223 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*get_parent)(const struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*get_next_child_node)(const struct fwnode_handle___223 *, struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*get_named_child_node)(const struct fwnode_handle___223 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___223 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___223 *);
	struct fwnode_handle___223 * (*graph_get_next_endpoint)(const struct fwnode_handle___223 *, struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*graph_get_remote_endpoint)(const struct fwnode_handle___223 *);
	struct fwnode_handle___223 * (*graph_get_port_parent)(struct fwnode_handle___223 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___223 *, struct fwnode_endpoint___223 *);
	int (*add_links)(struct fwnode_handle___223 *);
};

struct fwnode_endpoint___223 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___223 *local_fwnode;
};

struct fwnode_reference_args___223 {
	struct fwnode_handle___223 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___25;

struct fib_rules_ops___44;

struct fqdir___60;

struct tcp_congestion_ops___9;

struct fib_notifier_ops___44;

struct netns_ipv4___60 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___25 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___44 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___3 *fibnl;
	struct sock___3 **icmp_sk;
	struct sock___3 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___3 **tcp_sk;
	struct fqdir___60 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___9 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___44 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___44 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___44 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___44;

struct dst_ops___60 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___60 *);
	struct dst_entry___44 * (*check)(struct dst_entry___44 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___44 *);
	unsigned int (*mtu)(const struct dst_entry___44 *);
	u32 * (*cow_metrics)(struct dst_entry___44 *, long unsigned int);
	void (*destroy)(struct dst_entry___44 *);
	void (*ifdown)(struct dst_entry___44 *, struct net_device___5 *, int);
	struct dst_entry___44 * (*negative_advice)(struct dst_entry___44 *);
	void (*link_failure)(struct sk_buff___56 *);
	void (*update_pmtu)(struct dst_entry___44 *, struct sock___3 *, struct sk_buff___56 *, u32, bool);
	void (*redirect)(struct dst_entry___44 *, struct sock___3 *, struct sk_buff___56 *);
	int (*local_out)(struct net___60 *, struct sock___3 *, struct sk_buff___56 *);
	struct neighbour___44 * (*neigh_lookup)(const struct dst_entry___44 *, struct sk_buff___56 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___44 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___8;

struct rt6_info___8;

struct fib6_table___8;

struct netns_ipv6___60 {
	struct dst_ops___60 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___60 *fqdir;
	struct fib6_info___8 *fib6_null_entry;
	struct rt6_info___8 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___8 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___8 *ip6_prohibit_entry;
	struct rt6_info___8 *ip6_blk_hole_entry;
	struct fib6_table___8 *fib6_local_tbl;
	struct fib_rules_ops___44 *fib6_rules_ops;
	struct sock___3 **icmp_sk;
	struct sock___3 *ndisc_sk;
	struct sock___3 *tcp_sk;
	struct sock___3 *igmp_sk;
	struct sock___3 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___44 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___44 *notifier_ops;
	struct fib_notifier_ops___44 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___60 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___60 *fqdir;
};

struct netns_sctp___44 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___3 *ctl_sock;
	struct sock___3 *udp4_sock;
	struct sock___3 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___51;

struct netns_bpf___51 {
	struct bpf_prog_array___51 *run_array[2];
	struct bpf_prog___51 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___60 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___3 *nlsk;
	struct sock___3 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___60 xfrm4_dst_ops;
	struct dst_ops___60 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___60 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___3 *rtnl;
	struct sock___3 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___5 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___60 ipv4;
	struct netns_ipv6___60 ipv6;
	struct netns_ieee802154_lowpan___60 ieee802154_lowpan;
	struct netns_sctp___44 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___55 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___51 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___60 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___3 *crypto_nlsk;
	struct sock___3 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___173 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___173 *root_cset;
};

struct socket_wq___45 {
	wait_queue_head_t wait;
	struct fasync_struct___246 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___45;

struct socket___46 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___246 *file;
	struct sock___3 *sk;
	const struct proto_ops___45 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___45 wq;
};

typedef int (*sk_read_actor_t___44)(read_descriptor_t *, struct sk_buff___56 *, unsigned int, size_t);

struct proto_ops___45 {
	int family;
	struct module___230 *owner;
	int (*release)(struct socket___46 *);
	int (*bind)(struct socket___46 *, struct sockaddr *, int);
	int (*connect)(struct socket___46 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___46 *, struct socket___46 *);
	int (*accept)(struct socket___46 *, struct socket___46 *, int, bool);
	int (*getname)(struct socket___46 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___246 *, struct socket___46 *, struct poll_table_struct___169 *);
	int (*ioctl)(struct socket___46 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___46 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___46 *, void *, bool, bool);
	int (*listen)(struct socket___46 *, int);
	int (*shutdown)(struct socket___46 *, int);
	int (*setsockopt)(struct socket___46 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___46 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___221 *, struct socket___46 *);
	int (*sendmsg)(struct socket___46 *, struct msghdr___46 *, size_t);
	int (*recvmsg)(struct socket___46 *, struct msghdr___46 *, size_t, int);
	int (*mmap)(struct file___246 *, struct socket___46 *, struct vm_area_struct___251 *);
	ssize_t (*sendpage)(struct socket___46 *, struct page___251 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___46 *, loff_t *, struct pipe_inode_info___87 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___3 *, int);
	int (*peek_len)(struct socket___46 *);
	int (*read_sock)(struct sock___3 *, read_descriptor_t *, sk_read_actor_t___44);
	int (*sendpage_locked)(struct sock___3 *, struct page___251 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___3 *, struct msghdr___46 *, size_t);
	int (*set_rcvlowat)(struct sock___3 *, int);
};

struct sk_buff___56 {
	union {
		struct {
			struct sk_buff___56 *next;
			struct sk_buff___56 *prev;
			union {
				struct net_device___5 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___3 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___56 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___227 {
	int (*prepare)(struct device___227 *);
	void (*complete)(struct device___227 *);
	int (*suspend)(struct device___227 *);
	int (*resume)(struct device___227 *);
	int (*freeze)(struct device___227 *);
	int (*thaw)(struct device___227 *);
	int (*poweroff)(struct device___227 *);
	int (*restore)(struct device___227 *);
	int (*suspend_late)(struct device___227 *);
	int (*resume_early)(struct device___227 *);
	int (*freeze_late)(struct device___227 *);
	int (*thaw_early)(struct device___227 *);
	int (*poweroff_late)(struct device___227 *);
	int (*restore_early)(struct device___227 *);
	int (*suspend_noirq)(struct device___227 *);
	int (*resume_noirq)(struct device___227 *);
	int (*freeze_noirq)(struct device___227 *);
	int (*thaw_noirq)(struct device___227 *);
	int (*poweroff_noirq)(struct device___227 *);
	int (*restore_noirq)(struct device___227 *);
	int (*runtime_suspend)(struct device___227 *);
	int (*runtime_resume)(struct device___227 *);
	int (*runtime_idle)(struct device___227 *);
};

struct wakeup_source___227 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___227 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___227 {
	struct dev_pm_ops___227 ops;
	int (*start)(struct device___227 *);
	void (*detach)(struct device___227 *, bool);
	int (*activate)(struct device___227 *);
	void (*sync)(struct device___227 *);
	void (*dismiss)(struct device___227 *);
};

struct bus_type___227 {
	const char *name;
	const char *dev_name;
	struct device___227 *dev_root;
	const struct attribute_group___234 **bus_groups;
	const struct attribute_group___234 **dev_groups;
	const struct attribute_group___234 **drv_groups;
	int (*match)(struct device___227 *, struct device_driver___227 *);
	int (*uevent)(struct device___227 *, struct kobj_uevent_env *);
	int (*probe)(struct device___227 *);
	void (*sync_state)(struct device___227 *);
	void (*remove)(struct device___227 *);
	void (*shutdown)(struct device___227 *);
	int (*online)(struct device___227 *);
	int (*offline)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	int (*num_vf)(struct device___227 *);
	int (*dma_configure)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___227 {
	const char *name;
	struct bus_type___227 *bus;
	struct module___230 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___227 *);
	void (*sync_state)(struct device___227 *);
	int (*remove)(struct device___227 *);
	void (*shutdown)(struct device___227 *);
	int (*suspend)(struct device___227 *, pm_message_t);
	int (*resume)(struct device___227 *);
	const struct attribute_group___234 **groups;
	const struct attribute_group___234 **dev_groups;
	const struct dev_pm_ops___227 *pm;
	void (*coredump)(struct device___227 *);
	struct driver_private *p;
};

struct device_type___227 {
	const char *name;
	const struct attribute_group___234 **groups;
	int (*uevent)(struct device___227 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___227 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___227 *);
	const struct dev_pm_ops___227 *pm;
};

struct class___227 {
	const char *name;
	struct module___230 *owner;
	const struct attribute_group___234 **class_groups;
	const struct attribute_group___234 **dev_groups;
	struct kobject___234 *dev_kobj;
	int (*dev_uevent)(struct device___227 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___227 *, umode_t *);
	void (*class_release)(struct class___227 *);
	void (*dev_release)(struct device___227 *);
	int (*shutdown_pre)(struct device___227 *);
	const struct kobj_ns_type_operations___44 *ns_type;
	const void * (*namespace)(struct device___227 *);
	void (*get_ownership)(struct device___227 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___227 *pm;
	struct subsys_private *p;
};

struct bpf_flow_dissector___3 {
	struct bpf_flow_keys *flow_keys;
	const struct sk_buff___56 *skb;
	const void *data;
	const void *data_end;
};

struct pipe_buf_operations___87;

struct pipe_buffer___87 {
	struct page___251 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___87 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___87 {
	int (*confirm)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
	void (*release)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
	bool (*try_steal)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
	bool (*get)(struct pipe_inode_info___87 *, struct pipe_buffer___87 *);
};

typedef rx_handler_result_t rx_handler_func_t___55(struct sk_buff___56 **);

struct bpf_xdp_entity___51 {
	struct bpf_prog___51 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___55;

struct net_device_ops___55;

struct l3mdev_ops___44;

struct ndisc_ops___31;

struct xfrmdev_ops___55;

struct header_ops___55;

struct in_device___2;

struct inet6_dev___31;

struct netdev_rx_queue___55;

struct mini_Qdisc___51;

struct netdev_queue___55;

struct Qdisc___51;

struct rtnl_link_ops___51;

struct dcbnl_rtnl_ops___55;

struct net_device___5 {
	char name[16];
	struct netdev_name_node___55 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___55 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___44 *l3mdev_ops;
	const struct ndisc_ops___31 *ndisc_ops;
	const struct xfrmdev_ops___55 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___55 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___234 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___2 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___31 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___55 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___51 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___55 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___51 *miniq_ingress;
	struct netdev_queue___55 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___55 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___51 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___51 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___55 = 0,
		NETREG_REGISTERED___55 = 1,
		NETREG_UNREGISTERING___55 = 2,
		NETREG_UNREGISTERED___55 = 3,
		NETREG_RELEASED___55 = 4,
		NETREG_DUMMY___55 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___55 = 0,
		RTNL_LINK_INITIALIZING___55 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___5 *);
	struct netpoll_info *npinfo;
	possible_net_t___55 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___227 dev;
	const struct attribute_group___234 *sysfs_groups[4];
	const struct attribute_group___234 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___51 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___55 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___51 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___163 skb_frag_t___12;

struct ubuf_info___5 {
	void (*callback)(struct sk_buff___56 *, struct ubuf_info___5 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___12 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___56 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___12 frags[17];
};

struct netlink_callback___55 {
	struct sk_buff___56 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___56 *, struct netlink_callback___55 *);
	int (*done)(struct netlink_callback___55 *);
	void *data;
	struct module___230 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct seq_operations___221 {
	void * (*start)(struct seq_file___221 *, loff_t *);
	void (*stop)(struct seq_file___221 *, void *);
	void * (*next)(struct seq_file___221 *, void *, loff_t *);
	int (*show)(struct seq_file___221 *, void *);
};

struct inet_frags___60;

struct fqdir___60 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___60 *f;
	struct net___60 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___60;

struct inet_frags___60 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___60 *, const void *);
	void (*destructor)(struct inet_frag_queue___60 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___60 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___56 *fragments_tail;
	struct sk_buff___56 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___60 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___25 {
	struct ip_ra_chain___25 *next;
	struct sock___3 *sk;
	union {
		void (*destructor)(struct sock___3 *);
		struct sock___3 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___44;

struct fib_lookup_arg___44;

struct fib_rules_ops___44 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___44 *, struct flowi *, int, struct fib_lookup_arg___44 *);
	bool (*suppress)(struct fib_rule___44 *, int, struct fib_lookup_arg___44 *);
	int (*match)(struct fib_rule___44 *, struct flowi *, int);
	int (*configure)(struct fib_rule___44 *, struct sk_buff___56 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___44 *);
	int (*compare)(struct fib_rule___44 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___44 *, struct sk_buff___56 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___44 *);
	void (*flush_cache)(struct fib_rules_ops___44 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___230 *owner;
	struct net___60 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___9 {
	u32 (*ssthresh)(struct sock___3 *);
	void (*cong_avoid)(struct sock___3 *, u32, u32);
	void (*set_state)(struct sock___3 *, u8);
	void (*cwnd_event)(struct sock___3 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___3 *, u32);
	void (*pkts_acked)(struct sock___3 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___3 *);
	void (*cong_control)(struct sock___3 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___3 *);
	u32 (*sndbuf_expand)(struct sock___3 *);
	size_t (*get_info)(struct sock___3 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___230 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___3 *);
	void (*release)(struct sock___3 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___44 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___60 *);
	int (*fib_dump)(struct net___60 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___230 *owner;
	struct callback_head rcu;
};

struct xfrm_state___6;

struct lwtunnel_state___26;

struct dst_entry___44 {
	struct net_device___5 *dev;
	struct dst_ops___60 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___6 *xfrm;
	int (*input)(struct sk_buff___56 *);
	int (*output)(struct net___60 *, struct sock___3 *, struct sk_buff___56 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___26 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___44;

struct neigh_parms___44;

struct neigh_ops___44;

struct neighbour___44 {
	struct neighbour___44 *next;
	struct neigh_table___44 *tbl;
	struct neigh_parms___44 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___55 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___44 *, struct sk_buff___56 *);
	const struct neigh_ops___44 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___5 *dev;
	u8 primary_key[0];
};

struct rtable___8;

struct fnhe_hash_bucket___8;

struct fib_nh_common___8 {
	struct net_device___5 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___26 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___8 **nhc_pcpu_rth_output;
	struct rtable___8 *nhc_rth_input;
	struct fnhe_hash_bucket___8 *nhc_exceptions;
};

struct fib6_nh___8 {
	struct fib_nh_common___8 nh_common;
	long unsigned int last_probe;
	struct rt6_info___8 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___8;

struct nexthop___5;

struct fib6_info___8 {
	struct fib6_table___8 *fib6_table;
	struct fib6_info___8 *fib6_next;
	struct fib6_node___8 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___5 *nh;
	struct fib6_nh___8 fib6_nh[0];
};

struct rt6_info___8 {
	struct dst_entry___44 dst;
	struct fib6_info___8 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___31 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___8 {
	struct fib6_node___8 *parent;
	struct fib6_node___8 *left;
	struct fib6_node___8 *right;
	struct fib6_node___8 *subtree;
	struct fib6_info___8 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___8 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___8 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___8 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct seg6_pernet_data {
	struct mutex lock;
	struct in6_addr *tun_src;
	struct rhashtable hmac_infos;
};

enum {
	BPF_F_RECOMPUTE_CSUM = 1,
	BPF_F_INVALIDATE_HASH = 2,
};

enum {
	BPF_F_HDR_FIELD_MASK = 15,
};

enum {
	BPF_F_PSEUDO_HDR = 16,
	BPF_F_MARK_MANGLED_0 = 32,
	BPF_F_MARK_ENFORCE = 64,
};

enum {
	BPF_F_INGRESS = 1,
};

enum {
	BPF_F_TUNINFO_IPV6 = 1,
};

enum {
	BPF_F_ZERO_CSUM_TX = 2,
	BPF_F_DONT_FRAGMENT = 4,
	BPF_F_SEQ_NUMBER = 8,
};

enum {
	BPF_F_INDEX_MASK___2 = 4294967295,
	BPF_F_CURRENT_CPU___2 = 4294967295,
	BPF_F_CTXLEN_MASK___2 = 0,
};

enum {
	BPF_CSUM_LEVEL_QUERY = 0,
	BPF_CSUM_LEVEL_INC = 1,
	BPF_CSUM_LEVEL_DEC = 2,
	BPF_CSUM_LEVEL_RESET = 3,
};

enum {
	BPF_F_ADJ_ROOM_FIXED_GSO = 1,
	BPF_F_ADJ_ROOM_ENCAP_L3_IPV4 = 2,
	BPF_F_ADJ_ROOM_ENCAP_L3_IPV6 = 4,
	BPF_F_ADJ_ROOM_ENCAP_L4_GRE = 8,
	BPF_F_ADJ_ROOM_ENCAP_L4_UDP = 16,
	BPF_F_ADJ_ROOM_NO_CSUM_RESET = 32,
	BPF_F_ADJ_ROOM_ENCAP_L2_ETH = 64,
};

enum {
	BPF_ADJ_ROOM_ENCAP_L2_MASK = 255,
	BPF_ADJ_ROOM_ENCAP_L2_SHIFT = 56,
};

enum {
	BPF_SK_LOOKUP_F_REPLACE = 1,
	BPF_SK_LOOKUP_F_NO_REUSEPORT = 2,
};

enum bpf_adj_room_mode {
	BPF_ADJ_ROOM_NET = 0,
	BPF_ADJ_ROOM_MAC = 1,
};

enum bpf_hdr_start_off {
	BPF_HDR_START_MAC = 0,
	BPF_HDR_START_NET = 1,
};

enum bpf_lwt_encap_mode {
	BPF_LWT_ENCAP_SEG6 = 0,
	BPF_LWT_ENCAP_SEG6_INLINE = 1,
	BPF_LWT_ENCAP_IP = 2,
};

struct bpf_tunnel_key {
	__u32 tunnel_id;
	union {
		__u32 remote_ipv4;
		__u32 remote_ipv6[4];
	};
	__u8 tunnel_tos;
	__u8 tunnel_ttl;
	__u16 tunnel_ext;
	__u32 tunnel_label;
};

struct bpf_xfrm_state {
	__u32 reqid;
	__u32 spi;
	__u16 family;
	__u16 ext;
	union {
		__u32 remote_ipv4;
		__u32 remote_ipv6[4];
	};
};

struct bpf_tcp_sock {
	__u32 snd_cwnd;
	__u32 srtt_us;
	__u32 rtt_min;
	__u32 snd_ssthresh;
	__u32 rcv_nxt;
	__u32 snd_nxt;
	__u32 snd_una;
	__u32 mss_cache;
	__u32 ecn_flags;
	__u32 rate_delivered;
	__u32 rate_interval_us;
	__u32 packets_out;
	__u32 retrans_out;
	__u32 total_retrans;
	__u32 segs_in;
	__u32 data_segs_in;
	__u32 segs_out;
	__u32 data_segs_out;
	__u32 lost_out;
	__u32 sacked_out;
	__u64 bytes_received;
	__u64 bytes_acked;
	__u32 dsack_dups;
	__u32 delivered;
	__u32 delivered_ce;
	__u32 icsk_retransmits;
};

struct bpf_sock_tuple {
	union {
		struct {
			__be32 saddr;
			__be32 daddr;
			__be16 sport;
			__be16 dport;
		} ipv4;
		struct {
			__be32 saddr[4];
			__be32 daddr[4];
			__be16 sport;
			__be16 dport;
		} ipv6;
	};
};

struct bpf_xdp_sock {
	__u32 queue_id;
};

enum {
	BPF_SOCK_OPS_RTO_CB_FLAG = 1,
	BPF_SOCK_OPS_RETRANS_CB_FLAG = 2,
	BPF_SOCK_OPS_STATE_CB_FLAG = 4,
	BPF_SOCK_OPS_RTT_CB_FLAG = 8,
	BPF_SOCK_OPS_PARSE_ALL_HDR_OPT_CB_FLAG = 16,
	BPF_SOCK_OPS_PARSE_UNKNOWN_HDR_OPT_CB_FLAG = 32,
	BPF_SOCK_OPS_WRITE_HDR_OPT_CB_FLAG = 64,
	BPF_SOCK_OPS_ALL_CB_FLAGS = 127,
};

enum {
	BPF_SOCK_OPS_VOID = 0,
	BPF_SOCK_OPS_TIMEOUT_INIT = 1,
	BPF_SOCK_OPS_RWND_INIT = 2,
	BPF_SOCK_OPS_TCP_CONNECT_CB = 3,
	BPF_SOCK_OPS_ACTIVE_ESTABLISHED_CB = 4,
	BPF_SOCK_OPS_PASSIVE_ESTABLISHED_CB = 5,
	BPF_SOCK_OPS_NEEDS_ECN = 6,
	BPF_SOCK_OPS_BASE_RTT = 7,
	BPF_SOCK_OPS_RTO_CB = 8,
	BPF_SOCK_OPS_RETRANS_CB = 9,
	BPF_SOCK_OPS_STATE_CB = 10,
	BPF_SOCK_OPS_TCP_LISTEN_CB = 11,
	BPF_SOCK_OPS_RTT_CB = 12,
	BPF_SOCK_OPS_PARSE_HDR_OPT_CB = 13,
	BPF_SOCK_OPS_HDR_OPT_LEN_CB = 14,
	BPF_SOCK_OPS_WRITE_HDR_OPT_CB = 15,
};

enum {
	TCP_BPF_IW = 1001,
	TCP_BPF_SNDCWND_CLAMP = 1002,
	TCP_BPF_DELACK_MAX = 1003,
	TCP_BPF_RTO_MIN = 1004,
	TCP_BPF_SYN = 1005,
	TCP_BPF_SYN_IP = 1006,
	TCP_BPF_SYN_MAC = 1007,
};

enum {
	BPF_LOAD_HDR_OPT_TCP_SYN = 1,
};

enum {
	BPF_FIB_LOOKUP_DIRECT = 1,
	BPF_FIB_LOOKUP_OUTPUT = 2,
};

enum {
	BPF_FIB_LKUP_RET_SUCCESS = 0,
	BPF_FIB_LKUP_RET_BLACKHOLE = 1,
	BPF_FIB_LKUP_RET_UNREACHABLE = 2,
	BPF_FIB_LKUP_RET_PROHIBIT = 3,
	BPF_FIB_LKUP_RET_NOT_FWDED = 4,
	BPF_FIB_LKUP_RET_FWD_DISABLED = 5,
	BPF_FIB_LKUP_RET_UNSUPP_LWT = 6,
	BPF_FIB_LKUP_RET_NO_NEIGH = 7,
	BPF_FIB_LKUP_RET_FRAG_NEEDED = 8,
};

struct bpf_fib_lookup {
	__u8 family;
	__u8 l4_protocol;
	__be16 sport;
	__be16 dport;
	union {
		__u16 tot_len;
		__u16 mtu_result;
	};
	__u32 ifindex;
	union {
		__u8 tos;
		__be32 flowinfo;
		__u32 rt_metric;
	};
	union {
		__be32 ipv4_src;
		__u32 ipv6_src[4];
	};
	union {
		__be32 ipv4_dst;
		__u32 ipv6_dst[4];
	};
	__be16 h_vlan_proto;
	__be16 h_vlan_TCI;
	__u8 smac[6];
	__u8 dmac[6];
};

struct bpf_redir_neigh {
	__u32 nh_family;
	union {
		__be32 ipv4_nh;
		__u32 ipv6_nh[4];
	};
};

enum bpf_check_mtu_flags {
	BPF_MTU_CHK_SEGS = 1,
};

enum bpf_check_mtu_ret {
	BPF_MTU_CHK_RET_SUCCESS = 0,
	BPF_MTU_CHK_RET_FRAG_NEEDED = 1,
	BPF_MTU_CHK_RET_SEGS_TOOBIG = 2,
};

struct bpf_prog_array_item___51 {
	struct bpf_prog___51 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___51 {
	struct callback_head rcu;
	struct bpf_prog_array_item___51 items[0];
};

struct bpf_prog_aux___58;

struct bpf_prog___51 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___58 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dcbnl_rtnl_ops___55 {
	int (*ieee_getets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___5 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___5 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___5 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___5 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___5 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___5 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___5 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___5 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___5 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___5 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___5 *);
	u8 (*setstate)(struct net_device___5 *, u8);
	void (*getpermhwaddr)(struct net_device___5 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___5 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___5 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___5 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___5 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___5 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___5 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___5 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___5 *, int, u8 *);
	void (*setpfccfg)(struct net_device___5 *, int, u8);
	void (*getpfccfg)(struct net_device___5 *, int, u8 *);
	u8 (*setall)(struct net_device___5 *);
	u8 (*getcap)(struct net_device___5 *, int, u8 *);
	int (*getnumtcs)(struct net_device___5 *, int, u8 *);
	int (*setnumtcs)(struct net_device___5 *, int, u8);
	u8 (*getpfcstate)(struct net_device___5 *);
	void (*setpfcstate)(struct net_device___5 *, u8);
	void (*getbcncfg)(struct net_device___5 *, int, u32 *);
	void (*setbcncfg)(struct net_device___5 *, int, u32);
	void (*getbcnrp)(struct net_device___5 *, int, u8 *);
	void (*setbcnrp)(struct net_device___5 *, int, u8);
	int (*setapp)(struct net_device___5 *, u8, u16, u8);
	int (*getapp)(struct net_device___5 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___5 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___5 *, int, u8);
	u8 (*getdcbx)(struct net_device___5 *);
	u8 (*setdcbx)(struct net_device___5 *, u8);
	int (*peer_getappinfo)(struct net_device___5 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___5 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___5 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___5 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___5 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___5 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___58;

typedef int (*bpf_iter_init_seq_priv_t___57)(void *, struct bpf_iter_aux_info___58 *);

struct bpf_map___58;

struct bpf_iter_aux_info___58 {
	struct bpf_map___58 *map;
};

struct bpf_iter_seq_info___57 {
	const struct seq_operations___221 *seq_ops;
	bpf_iter_init_seq_priv_t___57 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_local_storage_map___8;

struct bpf_map_ops___57 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___58 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___58 *, struct file___246 *);
	void (*map_free)(struct bpf_map___58 *);
	int (*map_get_next_key)(struct bpf_map___58 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___58 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___58 *, void *);
	int (*map_lookup_batch)(struct bpf_map___58 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___58 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___58 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___58 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___58 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___58 *, void *);
	int (*map_update_elem)(struct bpf_map___58 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___58 *, void *);
	int (*map_push_elem)(struct bpf_map___58 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___58 *, void *);
	int (*map_peek_elem)(struct bpf_map___58 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___58 *, struct file___246 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___58 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___58 *, void *, struct seq_file___221 *);
	int (*map_check_btf)(const struct bpf_map___58 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___58 *, struct bpf_prog_aux___58 *);
	void (*map_poke_untrack)(struct bpf_map___58 *, struct bpf_prog_aux___58 *);
	void (*map_poke_run)(struct bpf_map___58 *, u32, struct bpf_prog___51 *, struct bpf_prog___51 *);
	int (*map_direct_value_addr)(const struct bpf_map___58 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___58 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___58 *, struct vm_area_struct___251 *);
	__poll_t (*map_poll)(struct bpf_map___58 *, struct file___246 *, struct poll_table_struct___169 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___8 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___8 *, void *, u32);
	struct bpf_local_storage___8 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___58 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___58 *, const struct bpf_map___58 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___58 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___57 *iter_seq_info;
};

struct bpf_map___58 {
	const struct bpf_map_ops___57 *ops;
	struct bpf_map___58 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___113 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___57;

struct bpf_jit_poke_descriptor___57;

struct bpf_prog_ops___51;

struct btf_mod_pair___57;

struct bpf_prog_offload___55;

struct bpf_prog_aux___58 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___51 *dst_prog;
	struct bpf_trampoline___57 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___51 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___57 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___51 *ops;
	struct bpf_map___58 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___57 *used_btfs;
	struct bpf_prog___51 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___58 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___55 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_local_storage_map___8 {
	struct bpf_map___58 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___55;

struct bpf_map_dev_ops___55 {
	int (*map_get_next_key)(struct bpf_offloaded_map___55 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___55 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___55 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___55 *, void *);
};

struct bpf_offloaded_map___55 {
	struct bpf_map___58 map;
	struct net_device___5 *netdev;
	const struct bpf_map_dev_ops___55 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_func_proto___12 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___51 *);
};

struct bpf_prog_ops___51 {
	int (*test_run)(struct bpf_prog___51 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___8 {
	const struct bpf_func_proto___12 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___51 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___51 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___51 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___51 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___55 {
	struct bpf_prog___51 *prog;
	struct net_device___5 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___57 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___51 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___230 *mod;
};

struct bpf_dispatcher_prog___2 {
	struct bpf_prog___51 *prog;
	refcount_t users;
};

struct bpf_dispatcher___2 {
	struct mutex mutex;
	void *func;
	struct bpf_dispatcher_prog___2 progs[48];
	int num_progs;
	void *image;
	u32 image_off;
	struct bpf_ksym ksym;
};

struct bpf_jit_poke_descriptor___57 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___58 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___57 {
	struct btf *btf;
	struct module___230 *module;
};

struct bpf_array_aux___7 {
	struct {
		spinlock_t lock;
		enum bpf_prog_type type;
		bool jited;
	} owner;
	struct list_head poke_progs;
	struct bpf_map___58 *map;
	struct mutex poke_mutex;
	struct work_struct work;
};

struct bpf_array___7 {
	struct bpf_map___58 map;
	u32 elem_size;
	u32 index_mask;
	struct bpf_array_aux___7 *aux;
	union {
		char value[0];
		void *ptrs[0];
		void *pptrs[0];
	};
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct sk_reuseport_kern___2 {
	struct sk_buff___56 *skb;
	struct sock___3 *sk;
	struct sock___3 *selected_sk;
	struct sock___3 *migrating_sk;
	void *data_end;
	u32 hash;
	u32 reuseport_id;
	bool bind_inany;
};

struct cftype___173;

struct cgroup_subsys___173 {
	struct cgroup_subsys_state___173 * (*css_alloc)(struct cgroup_subsys_state___173 *);
	int (*css_online)(struct cgroup_subsys_state___173 *);
	void (*css_offline)(struct cgroup_subsys_state___173 *);
	void (*css_released)(struct cgroup_subsys_state___173 *);
	void (*css_free)(struct cgroup_subsys_state___173 *);
	void (*css_reset)(struct cgroup_subsys_state___173 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___173 *, int);
	int (*css_extra_stat_show)(struct seq_file___221 *, struct cgroup_subsys_state___173 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___253 *, struct css_set___173 *);
	void (*cancel_fork)(struct task_struct___253 *, struct css_set___173 *);
	void (*fork)(struct task_struct___253 *);
	void (*exit)(struct task_struct___253 *);
	void (*release)(struct task_struct___253 *);
	void (*bind)(struct cgroup_subsys_state___173 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___173 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___173 *dfl_cftypes;
	struct cftype___173 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___173 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___173 *updated_children;
	struct cgroup___173 *updated_next;
};

struct cgroup_root___173 {
	struct kernfs_root___234 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___173 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___173 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___173 *ss;
	struct list_head node;
	struct kernfs_ops___234 *kf_ops;
	int (*open)(struct kernfs_open_file___234 *);
	void (*release)(struct kernfs_open_file___234 *);
	u64 (*read_u64)(struct cgroup_subsys_state___173 *, struct cftype___173 *);
	s64 (*read_s64)(struct cgroup_subsys_state___173 *, struct cftype___173 *);
	int (*seq_show)(struct seq_file___221 *, void *);
	void * (*seq_start)(struct seq_file___221 *, loff_t *);
	void * (*seq_next)(struct seq_file___221 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___221 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___173 *, struct cftype___173 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___173 *, struct cftype___173 *, s64);
	ssize_t (*write)(struct kernfs_open_file___234 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___234 *, struct poll_table_struct___169 *);
};

struct xdp_rxq_info___55 {
	struct net_device___5 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___55 {
	struct net_device___5 *dev;
};

struct xdp_buff___55 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___55 *rxq;
	struct xdp_txq_info___55 *txq;
	u32 frame_sz;
};

struct xdp_frame___55 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___5 *dev_rx;
};

struct header_ops___55 {
	int (*create)(struct sk_buff___56 *, struct net_device___5 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___56 *, unsigned char *);
	int (*cache)(const struct neighbour___44 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___5 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___56 *);
};

struct napi_struct___10 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___10 *, int);
	int poll_owner;
	struct net_device___5 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___56 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___253 *thread;
};

struct netdev_queue___55 {
	struct net_device___5 *dev;
	struct Qdisc___51 *qdisc;
	struct Qdisc___51 *qdisc_sleeping;
	struct kobject___234 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___5 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___51 {
	struct sk_buff___56 *head;
	struct sk_buff___56 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___51;

struct Qdisc___51 {
	int (*enqueue)(struct sk_buff___56 *, struct Qdisc___51 *, struct sk_buff___56 **);
	struct sk_buff___56 * (*dequeue)(struct Qdisc___51 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___51 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___55 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___55 gso_skb;
	struct qdisc_skb_head___51 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___51 *next_sched;
	struct sk_buff_head___55 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___55 {
	struct xdp_rxq_info___55 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___234 kobj;
	struct net_device___5 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___55 {
	enum net_device_path_type type;
	const struct net_device___5 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___55 = 0,
				DEV_PATH_BR_VLAN_TAG___55 = 1,
				DEV_PATH_BR_VLAN_UNTAG___55 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___55 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___55 {
	const struct net_device___5 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___55 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___51 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___55 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___55 {
	int (*xdo_dev_state_add)(struct xfrm_state___6 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___6 *);
	void (*xdo_dev_state_free)(struct xfrm_state___6 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___56 *, struct xfrm_state___6 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___6 *);
};

struct xfrm_state_offload___6 {
	struct net_device___5 *dev;
	struct net_device___5 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___6;

struct xfrm_type_offload___6;

struct xfrm_state___6 {
	possible_net_t___55 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___3 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___6 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___6 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___251 xfrag;
	const struct xfrm_type___6 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___6 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___55 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___5 *dev;
	const char *name;
};

struct net_device_ops___55 {
	int (*ndo_init)(struct net_device___5 *);
	void (*ndo_uninit)(struct net_device___5 *);
	int (*ndo_open)(struct net_device___5 *);
	int (*ndo_stop)(struct net_device___5 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___56 *, struct net_device___5 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___56 *, struct net_device___5 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___5 *, struct sk_buff___56 *, struct net_device___5 *);
	void (*ndo_change_rx_flags)(struct net_device___5 *, int);
	void (*ndo_set_rx_mode)(struct net_device___5 *);
	int (*ndo_set_mac_address)(struct net_device___5 *, void *);
	int (*ndo_validate_addr)(struct net_device___5 *);
	int (*ndo_do_ioctl)(struct net_device___5 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___5 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___5 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___5 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___5 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___5 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___5 *, int);
	int (*ndo_neigh_setup)(struct net_device___5 *, struct neigh_parms___44 *);
	void (*ndo_tx_timeout)(struct net_device___5 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___5 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___5 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___5 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___5 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___5 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___5 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___5 *);
	int (*ndo_netpoll_setup)(struct net_device___5 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___5 *);
	int (*ndo_set_vf_mac)(struct net_device___5 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___5 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___5 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___5 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___5 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___5 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___5 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___5 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___5 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___5 *, int, struct sk_buff___56 *);
	int (*ndo_get_vf_guid)(struct net_device___5 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___5 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___5 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___5 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___5 *);
	int (*ndo_fcoe_disable)(struct net_device___5 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___5 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___5 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___5 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___5 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___5 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___5 *, const struct sk_buff___56 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___5 *, struct net_device___5 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___5 *, struct net_device___5 *);
	struct net_device___5 * (*ndo_get_xmit_slave)(struct net_device___5 *, struct sk_buff___56 *, bool);
	struct net_device___5 * (*ndo_sk_get_lower_dev)(struct net_device___5 *, struct sock___3 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___5 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___5 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___5 *, struct neighbour___44 *);
	void (*ndo_neigh_destroy)(struct net_device___5 *, struct neighbour___44 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___56 *, struct netlink_callback___55 *, struct net_device___5 *, struct net_device___5 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___56 *, struct nlattr **, struct net_device___5 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___5 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___56 *, u32, u32, struct net_device___5 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___5 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___5 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___5 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___5 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___5 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___5 *, struct net_device___5 *);
	void (*ndo_dfwd_del_station)(struct net_device___5 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___5 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___5 *);
	int (*ndo_change_proto_down)(struct net_device___5 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___5 *, struct sk_buff___56 *);
	void (*ndo_set_rx_headroom)(struct net_device___5 *, int);
	int (*ndo_bpf)(struct net_device___5 *, struct netdev_bpf___55 *);
	int (*ndo_xdp_xmit)(struct net_device___5 *, int, struct xdp_frame___55 **, u32);
	struct net_device___5 * (*ndo_xdp_get_xmit_slave)(struct net_device___5 *, struct xdp_buff___55 *);
	int (*ndo_xsk_wakeup)(struct net_device___5 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___5 *);
	int (*ndo_tunnel_ctl)(struct net_device___5 *, struct ip_tunnel_parm *, int);
	struct net_device___5 * (*ndo_get_peer_dev)(struct net_device___5 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___55 *, struct net_device_path___55 *);
};

struct neigh_parms___44 {
	possible_net_t___55 net;
	struct net_device___5 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___44 *);
	struct neigh_table___44 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___44 {
	u32 (*l3mdev_fib_table)(const struct net_device___5 *);
	struct sk_buff___56 * (*l3mdev_l3_rcv)(struct net_device___5 *, struct sk_buff___56 *, u16);
	struct sk_buff___56 * (*l3mdev_l3_out)(struct net_device___5 *, struct sock___3 *, struct sk_buff___56 *, u16);
	struct dst_entry___44 * (*l3mdev_link_scope_lookup)(const struct net_device___5 *, struct flowi6 *);
};

struct ndisc_ops___31 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___5 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___5 *, struct neighbour___44 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___5 *, u8, struct neighbour___44 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___5 *, struct sk_buff___56 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___60 *, struct net_device___5 *, const struct prefix_info *, struct inet6_dev___31 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___2;

struct in_device___2 {
	struct net_device___5 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___2 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___44 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___31;

struct ifacaddr6___8;

struct inet6_dev___31 {
	struct net_device___5 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___31 *mc_list;
	struct ifmcaddr6___31 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___55 mc_query_queue;
	struct sk_buff_head___55 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___8 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___44 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___51;

struct tcf_block___51;

struct mini_Qdisc___51 {
	struct tcf_proto___51 *filter_list;
	struct tcf_block___51 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___51 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___5 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___5 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___60 *, struct net_device___5 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___5 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___5 *, struct list_head *);
	size_t (*get_size)(const struct net_device___5 *);
	int (*fill_info)(struct sk_buff___56 *, const struct net_device___5 *);
	size_t (*get_xstats_size)(const struct net_device___5 *);
	int (*fill_xstats)(struct sk_buff___56 *, const struct net_device___5 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___5 *, struct net_device___5 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___5 *, const struct net_device___5 *);
	int (*fill_slave_info)(struct sk_buff___56 *, const struct net_device___5 *, const struct net_device___5 *);
	struct net___60 * (*get_link_net)(const struct net_device___5 *);
	size_t (*get_linkxstats_size)(const struct net_device___5 *, int);
	int (*fill_linkxstats)(struct sk_buff___56 *, const struct net_device___5 *, int *, int);
};

struct softnet_data___4 {
	struct list_head poll_list;
	struct sk_buff_head___55 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___4 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___51 *output_queue;
	struct Qdisc___51 **output_queue_tailp;
	struct sk_buff___56 *completion_queue;
	struct sk_buff_head___55 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___4 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___55 input_pkt_queue;
	struct napi_struct___10 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device_operations___139;

struct gendisk___142 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___142 *part0;
	const struct block_device_operations___139 *fops;
	struct request_queue___139 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___125 *bdi;
	struct kobject___234 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___234 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___139 {
	struct bio___139 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___163 *bip_vec;
	struct bio_vec___163 bip_inline_vecs[0];
};

struct blkcg___127;

struct blkg_policy_data___127;

struct blkcg_gq___127 {
	struct request_queue___139 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___127 *blkcg;
	struct blkcg_gq___127 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___127 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___139 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___139(struct request___139 *);

typedef void integrity_complete_fn___139(struct request___139 *, unsigned int);

struct blk_integrity_profile___139 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___139 *prepare_fn;
	integrity_complete_fn___139 *complete_fn;
	const char *name;
};

struct block_device_operations___139 {
	blk_qc_t (*submit_bio)(struct bio___139 *);
	int (*open)(struct block_device___142 *, fmode_t);
	void (*release)(struct gendisk___142 *, fmode_t);
	int (*rw_page)(struct block_device___142 *, sector_t, struct page___251 *, unsigned int);
	int (*ioctl)(struct block_device___142 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___142 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___142 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___142 *);
	int (*getgeo)(struct block_device___142 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___142 *, bool);
	void (*swap_slot_free_notify)(struct block_device___142 *, long unsigned int);
	int (*report_zones)(struct gendisk___142 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___142 *, umode_t *);
	struct module___230 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___142 *, sector_t *);
};

typedef void rq_end_io_fn___139(struct request___139 *, blk_status_t);

struct request___139 {
	struct request_queue___139 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___134 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___139 *bio;
	struct bio___139 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___163 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___139 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___139 *saved_end_io;
		} flush;
	};
	struct gendisk___142 *rq_disk;
	struct block_device___142 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___139 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___134 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___139 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___234 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___246 *debugfs_dir;
	struct dentry___246 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___139;

struct elevator_mq_ops___139 {
	int (*init_sched)(struct request_queue___139 *, struct elevator_type___139 *);
	void (*exit_sched)(struct elevator_queue___139 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___134 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___134 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___134 *);
	bool (*allow_merge)(struct request_queue___139 *, struct request___139 *, struct bio___139 *);
	bool (*bio_merge)(struct request_queue___139 *, struct bio___139 *, unsigned int);
	int (*request_merge)(struct request_queue___139 *, struct request___139 **, struct bio___139 *);
	void (*request_merged)(struct request_queue___139 *, struct request___139 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___139 *, struct request___139 *, struct request___139 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___139 *);
	void (*finish_request)(struct request___139 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___134 *, struct list_head *, bool);
	struct request___139 * (*dispatch_request)(struct blk_mq_hw_ctx___134 *);
	bool (*has_work)(struct blk_mq_hw_ctx___134 *);
	void (*completed_request)(struct request___139 *, u64);
	void (*requeue_request)(struct request___139 *);
	struct request___139 * (*former_request)(struct request_queue___139 *, struct request___139 *);
	struct request___139 * (*next_request)(struct request_queue___139 *, struct request___139 *);
	void (*init_icq)(struct io_cq___139 *);
	void (*exit_icq)(struct io_cq___139 *);
};

struct elv_fs_entry___139;

struct elevator_type___139 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___139 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___139 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___230 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___139 {
	struct elevator_type___139 *type;
	void *elevator_data;
	struct kobject___234 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___139 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___139 *, char *);
	ssize_t (*store)(struct elevator_queue___139 *, const char *, size_t);
};

struct blk_mq_queue_data___134;

struct blk_mq_ops___134 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___134 *, const struct blk_mq_queue_data___134 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___134 *);
	int (*get_budget)(struct request_queue___139 *);
	void (*put_budget)(struct request_queue___139 *, int);
	void (*set_rq_budget_token)(struct request___139 *, int);
	int (*get_rq_budget_token)(struct request___139 *);
	enum blk_eh_timer_return (*timeout)(struct request___139 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___134 *);
	void (*complete)(struct request___139 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___134 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___134 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___134 *, struct request___139 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___134 *, struct request___139 *, unsigned int);
	void (*initialize_rq_fn)(struct request___139 *);
	void (*cleanup_rq)(struct request___139 *);
	bool (*busy)(struct request_queue___139 *);
	int (*map_queues)(struct blk_mq_tag_set___134 *);
	void (*show_rq)(struct seq_file___221 *, struct request___139 *);
};

struct blk_mq_tag_set___134 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___134 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___134 {
	struct request___139 *rq;
	bool last;
};

struct blkcg_policy_data___127;

struct blkcg___127 {
	struct cgroup_subsys_state___173 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___127 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___127 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___127 {
	struct blkcg___127 *blkcg;
	int plid;
};

struct blkg_policy_data___127 {
	struct blkcg_gq___127 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___113 {
	struct mem_cgroup___113 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___113 {
	struct lruvec___121 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___113 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___113 *memcg;
};

struct obj_cgroup___113 {
	struct percpu_ref refcnt;
	struct mem_cgroup___113 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

enum rt_scope_t {
	RT_SCOPE_UNIVERSE = 0,
	RT_SCOPE_SITE = 200,
	RT_SCOPE_LINK = 253,
	RT_SCOPE_HOST = 254,
	RT_SCOPE_NOWHERE = 255,
};

enum rt_class_t {
	RT_TABLE_UNSPEC = 0,
	RT_TABLE_COMPAT = 252,
	RT_TABLE_DEFAULT = 253,
	RT_TABLE_MAIN = 254,
	RT_TABLE_LOCAL = 255,
	RT_TABLE_MAX = 4294967295,
};

struct gnet_dump___51 {
	spinlock_t *lock;
	struct sk_buff___56 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info {
	struct nlmsghdr *nlh;
	struct net___60 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct Qdisc_class_ops___51;

struct Qdisc_ops___51 {
	struct Qdisc_ops___51 *next;
	const struct Qdisc_class_ops___51 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___56 *, struct Qdisc___51 *, struct sk_buff___56 **);
	struct sk_buff___56 * (*dequeue)(struct Qdisc___51 *);
	struct sk_buff___56 * (*peek)(struct Qdisc___51 *);
	int (*init)(struct Qdisc___51 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___51 *);
	void (*destroy)(struct Qdisc___51 *);
	int (*change)(struct Qdisc___51 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___51 *);
	int (*change_tx_queue_len)(struct Qdisc___51 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___51 *, unsigned int);
	int (*dump)(struct Qdisc___51 *, struct sk_buff___56 *);
	int (*dump_stats)(struct Qdisc___51 *, struct gnet_dump___51 *);
	void (*ingress_block_set)(struct Qdisc___51 *, u32);
	void (*egress_block_set)(struct Qdisc___51 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___51 *);
	u32 (*egress_block_get)(struct Qdisc___51 *);
	struct module___230 *owner;
};

struct Qdisc_class_ops___51 {
	unsigned int flags;
	struct netdev_queue___55 * (*select_queue)(struct Qdisc___51 *, struct tcmsg *);
	int (*graft)(struct Qdisc___51 *, long unsigned int, struct Qdisc___51 *, struct Qdisc___51 **, struct netlink_ext_ack *);
	struct Qdisc___51 * (*leaf)(struct Qdisc___51 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___51 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___51 *, u32);
	int (*change)(struct Qdisc___51 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___51 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___51 *, struct qdisc_walker *);
	struct tcf_block___51 * (*tcf_block)(struct Qdisc___51 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___51 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___51 *, long unsigned int);
	int (*dump)(struct Qdisc___51 *, long unsigned int, struct sk_buff___56 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___51 *, long unsigned int, struct gnet_dump___51 *);
};

struct tcf_chain___51;

struct tcf_block___51 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___60 *net;
	struct Qdisc___51 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___51 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___51;

struct tcf_proto_ops___51;

struct tcf_proto___51 {
	struct tcf_proto___51 *next;
	void *root;
	int (*classify)(struct sk_buff___56 *, const struct tcf_proto___51 *, struct tcf_result___51 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___51 *ops;
	struct tcf_chain___51 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___51 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___51 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___51 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___56 *, const struct tcf_proto___51 *, struct tcf_result___51 *);
	int (*init)(struct tcf_proto___51 *);
	void (*destroy)(struct tcf_proto___51 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___51 *, u32);
	void (*put)(struct tcf_proto___51 *, void *);
	int (*change)(struct net___60 *, struct sk_buff___56 *, struct tcf_proto___51 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___51 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___51 *);
	void (*walk)(struct tcf_proto___51 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___51 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___51 *, void *);
	void (*hw_del)(struct tcf_proto___51 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___60 *, struct tcf_chain___51 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___60 *, struct tcf_proto___51 *, void *, struct sk_buff___56 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___60 *, struct tcf_proto___51 *, void *, struct sk_buff___56 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___56 *, struct net___60 *, void *);
	struct module___230 *owner;
	int flags;
};

struct tcf_chain___51 {
	struct mutex filter_chain_lock;
	struct tcf_proto___51 *filter_chain;
	struct list_head list;
	struct tcf_block___51 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___51 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___44 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___51 *prog;
};

struct bpf_redirect_info___3 {
	u32 flags;
	u32 tgt_index;
	void *tgt_value;
	struct bpf_map___58 *map;
	u32 map_id;
	enum bpf_map_type map_type;
	u32 kern_flags;
	struct bpf_nh_params nh;
};

struct bpf_sock_addr_kern___3 {
	struct sock___3 *sk;
	struct sockaddr *uaddr;
	u64 tmp_reg;
	void *t_ctx;
};

struct bpf_sock_ops_kern___3 {
	struct sock___3 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___56 *syn_skb;
	struct sk_buff___56 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct bpf_sk_lookup_kern___2 {
	u16 family;
	u16 protocol;
	__be16 sport;
	u16 dport;
	struct {
		__be32 saddr;
		__be32 daddr;
	} v4;
	struct {
		const struct in6_addr *saddr;
		const struct in6_addr *daddr;
	} v6;
	struct sock___3 *selected_sk;
	bool no_reuseport;
};

struct pneigh_entry___44;

struct neigh_hash_table___44;

struct neigh_table___44 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___5 *, __u32 *);
	bool (*key_eq)(const struct neighbour___44 *, const void *);
	int (*constructor)(struct neighbour___44 *);
	int (*pconstructor)(struct pneigh_entry___44 *);
	void (*pdestructor)(struct pneigh_entry___44 *);
	void (*proxy_redo)(struct sk_buff___56 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___5 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___44 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___55 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___44 *nht;
	struct pneigh_entry___44 **phash_buckets;
};

struct neigh_ops___44 {
	int family;
	void (*solicit)(struct neighbour___44 *, struct sk_buff___56 *);
	void (*error_report)(struct neighbour___44 *, struct sk_buff___56 *);
	int (*output)(struct neighbour___44 *, struct sk_buff___56 *);
	int (*connected_output)(struct neighbour___44 *, struct sk_buff___56 *);
};

struct pneigh_entry___44 {
	struct pneigh_entry___44 *next;
	possible_net_t___55 net;
	struct net_device___5 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___44 {
	struct neighbour___44 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___26 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___60 *, struct sock___3 *, struct sk_buff___56 *);
	int (*orig_input)(struct sk_buff___56 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___44 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___44 *ctarget;
	struct net___60 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___44 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___44 *rule;
	u32 table;
	int flags;
};

struct sk_psock___2;

struct request_sock_ops___33;

struct timewait_sock_ops___33;

struct proto___44 {
	void (*close)(struct sock___3 *, long int);
	int (*pre_connect)(struct sock___3 *, struct sockaddr *, int);
	int (*connect)(struct sock___3 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___3 *, int);
	struct sock___3 * (*accept)(struct sock___3 *, int, int *, bool);
	int (*ioctl)(struct sock___3 *, int, long unsigned int);
	int (*init)(struct sock___3 *);
	void (*destroy)(struct sock___3 *);
	void (*shutdown)(struct sock___3 *, int);
	int (*setsockopt)(struct sock___3 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___3 *, int, int, char *, int *);
	void (*keepalive)(struct sock___3 *, int);
	int (*compat_ioctl)(struct sock___3 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___3 *, struct msghdr___46 *, size_t);
	int (*recvmsg)(struct sock___3 *, struct msghdr___46 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___3 *, struct page___251 *, int, size_t, int);
	int (*bind)(struct sock___3 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___3 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___3 *, struct sk_buff___56 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___3 *);
	int (*hash)(struct sock___3 *);
	void (*unhash)(struct sock___3 *);
	void (*rehash)(struct sock___3 *);
	int (*get_port)(struct sock___3 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___3 *, struct sk_psock___2 *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___3 *, int);
	bool (*sock_is_readable)(struct sock___3 *);
	void (*enter_memory_pressure)(struct sock___3 *);
	void (*leave_memory_pressure)(struct sock___3 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___33 *rsk_prot;
	struct timewait_sock_ops___33 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___230 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___3 *, int);
};

struct xfrm_policy_queue___6 {
	struct sk_buff_head___55 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___6 {
	possible_net_t___55 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___6 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___10 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___51 *prog;
	struct sock___3 *socks[0];
};

struct sk_psock_progs___2 {
	struct bpf_prog___51 *msg_parser;
	struct bpf_prog___51 *stream_parser;
	struct bpf_prog___51 *stream_verdict;
	struct bpf_prog___51 *skb_verdict;
};

struct strparser___2;

struct strp_callbacks___2 {
	int (*parse_msg)(struct strparser___2 *, struct sk_buff___56 *);
	void (*rcv_msg)(struct strparser___2 *, struct sk_buff___56 *);
	int (*read_sock_done)(struct strparser___2 *, int);
	void (*abort_parser)(struct strparser___2 *, int);
	void (*lock)(struct strparser___2 *);
	void (*unlock)(struct strparser___2 *);
};

struct strparser___2 {
	struct sock___3 *sk;
	u32 stopped: 1;
	u32 paused: 1;
	u32 aborted: 1;
	u32 interrupted: 1;
	u32 unrecov_intr: 1;
	long: 63;
	long: 64;
	struct sk_buff___56 **skb_nextp;
	struct sk_buff___56 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___2 cb;
};

struct sk_psock_work_state___2 {
	struct sk_buff___56 *skb;
	u32 len;
	u32 off;
};

struct sk_msg___2;

struct sk_psock___2 {
	struct sock___3 *sk;
	struct sock___3 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg___2 *cork;
	struct sk_psock_progs___2 progs;
	struct strparser___2 strp;
	struct sk_buff_head___55 ingress_skb;
	struct list_head ingress_msg;
	spinlock_t ingress_lock;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___3 *);
	void (*saved_close)(struct sock___3 *, long int);
	void (*saved_write_space)(struct sock___3 *);
	void (*saved_data_ready)(struct sock___3 *);
	int (*psock_update_sk_prot)(struct sock___3 *, struct sk_psock___2 *, bool);
	struct proto___44 *sk_proto;
	struct mutex work_mutex;
	struct sk_psock_work_state___2 work_state;
	struct work_struct work;
	struct rcu_work rwork;
};

struct request_sock___34;

struct request_sock_ops___33 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___3 *, struct request_sock___34 *);
	void (*send_ack)(const struct sock___3 *, struct sk_buff___56 *, struct request_sock___34 *);
	void (*send_reset)(const struct sock___3 *, struct sk_buff___56 *);
	void (*destructor)(struct request_sock___34 *);
	void (*syn_ack_timeout)(const struct request_sock___34 *);
};

struct timewait_sock_ops___33 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___3 *, struct sock___3 *, void *);
	void (*twsk_destructor)(struct sock___3 *);
};

struct request_sock___34 {
	struct sock_common___44 __req_common;
	struct request_sock___34 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___33 *rsk_ops;
	struct sock___3 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___2 {
	struct request_sock___34 *rskq_rst_head;
	struct request_sock___34 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___2 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___34 *rskq_accept_head;
	struct request_sock___34 *rskq_accept_tail;
	struct fastopen_queue___2 fastopenq;
};

struct inet_cork___3 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___44 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___3 {
	struct inet_cork___3 base;
	struct flowi fl;
};

struct ipv6_pinfo___3;

struct inet_sock___3 {
	struct sock___3 sk;
	struct ipv6_pinfo___3 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___3 cork;
};

struct ipv6_fl_socklist___3;

struct ipv6_pinfo___3 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___3 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___56 *pktoptions;
	struct sk_buff___56 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___2 {
	int (*queue_xmit)(struct sock___3 *, struct sk_buff___56 *, struct flowi *);
	void (*send_check)(struct sock___3 *, struct sk_buff___56 *);
	int (*rebuild_header)(struct sock___3 *);
	void (*sk_rx_dst_set)(struct sock___3 *, const struct sk_buff___56 *);
	int (*conn_request)(struct sock___3 *, struct sk_buff___56 *);
	struct sock___3 * (*syn_recv_sock)(const struct sock___3 *, struct sk_buff___56 *, struct request_sock___34 *, struct dst_entry___44 *, struct request_sock___34 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___3 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___3 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___3 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___3 *);
};

struct inet_bind_bucket___2;

struct tcp_ulp_ops___2;

struct inet_connection_sock___2 {
	struct inet_sock___3 icsk_inet;
	struct request_sock_queue___2 icsk_accept_queue;
	struct inet_bind_bucket___2 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___9 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___2 *icsk_af_ops;
	const struct tcp_ulp_ops___2 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___3 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___3 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___2 {
	possible_net_t___55 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___2 {
	struct list_head list;
	int (*init)(struct sock___3 *);
	void (*update)(struct sock___3 *, struct proto___44 *, void (*)(struct sock___3 *));
	void (*release)(struct sock___3 *);
	int (*get_info)(const struct sock___3 *, struct sk_buff___56 *);
	size_t (*get_info_size)(const struct sock___3 *);
	void (*clone)(const struct request_sock___34 *, struct sock___3 *, const gfp_t);
	char name[16];
	struct module___230 *owner;
};

struct inet_timewait_sock {
	struct sock_common___44 __tw_common;
	__u32 tw_mark;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_kill: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tw_txhash;
	u32 tw_priority;
	struct timer_list tw_timer;
	struct inet_bind_bucket___2 *tw_tb;
};

struct tcp_sock_af_ops___3;

struct tcp_fastopen_request___3;

struct tcp_sock___3 {
	struct inet_connection_sock___2 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___56 *lost_skb_hint;
	struct sk_buff___56 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___56 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___56 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___3 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___3 *fastopen_req;
	struct request_sock___34 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___3 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___3 *, const struct sock___3 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___3 *, const struct sk_buff___56 *);
	int (*md5_parse)(struct sock___3 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___3 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___46 *data;
	size_t size;
	int copied;
	struct ubuf_info___5 *uarg;
};

struct tcp_timewait_sock {
	struct inet_timewait_sock tw_sk;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	int tw_ts_recent_stamp;
	u32 tw_tx_delay;
	struct tcp_md5sig_key *tw_md5_key;
};

struct udp_sock {
	struct inet_sock___3 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	unsigned char encap_enabled: 1;
	unsigned char gro_enabled: 1;
	unsigned char accept_udp_l4: 1;
	unsigned char accept_udp_fraglist: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___3 *, struct sk_buff___56 *);
	int (*encap_err_lookup)(struct sock___3 *, struct sk_buff___56 *);
	void (*encap_destroy)(struct sock___3 *);
	struct sk_buff___56 * (*gro_receive)(struct sock___3 *, struct list_head *, struct sk_buff___56 *);
	int (*gro_complete)(struct sock___3 *, struct sk_buff___56 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___55 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip6_flowlabel___3;

struct ipv6_fl_socklist___3 {
	struct ipv6_fl_socklist___3 *next;
	struct ip6_flowlabel___3 *fl;
	struct callback_head rcu;
};

struct udp6_sock {
	struct udp_sock udp;
	struct ipv6_pinfo___3 inet6;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct tcp6_sock {
	struct tcp_sock___3 tcp;
	struct ipv6_pinfo___3 inet6;
};

struct ifmcaddr6___31 {
	struct in6_addr mca_addr;
	struct inet6_dev___31 *idev;
	struct ifmcaddr6___31 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___8 {
	struct in6_addr aca_addr;
	struct fib6_info___8 *aca_rt;
	struct ifacaddr6___8 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result;

struct fib6_config;

struct ipv6_stub {
	int (*ipv6_sock_mc_join)(struct sock___3 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___3 *, int, const struct in6_addr *);
	struct dst_entry___44 * (*ipv6_dst_lookup_flow)(struct net___60 *, const struct sock___3 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___56 *);
	struct fib6_table___8 * (*fib6_get_table)(struct net___60 *, u32);
	int (*fib6_lookup)(struct net___60 *, int, struct flowi6 *, struct fib6_result *, int);
	int (*fib6_table_lookup)(struct net___60 *, struct fib6_table___8 *, int, struct flowi6 *, struct fib6_result *, int);
	void (*fib6_select_path)(const struct net___60 *, struct fib6_result *, struct flowi6 *, int, bool, const struct sk_buff___56 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___60 *, struct fib6_nh___8 *, struct fib6_config *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___8 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___8 *);
	void (*fib6_update_sernum)(struct net___60 *, struct fib6_info___8 *);
	int (*ip6_del_rt)(struct net___60 *, struct fib6_info___8 *, bool);
	void (*fib6_rt_update)(struct net___60 *, struct fib6_info___8 *, struct nl_info *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___5 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___56 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___3 *, struct sk_buff___56 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___56 *, int, __be32, int);
	struct neigh_table___44 *nd_tbl;
	int (*ipv6_fragment)(struct net___60 *, struct sock___3 *, struct sk_buff___56 *, int (*)(struct net___60 *, struct sock___3 *, struct sk_buff___56 *));
	struct net_device___5 * (*ipv6_dev_find)(struct net___60 *, const struct in6_addr *, struct net_device___5 *);
};

struct fib6_result {
	struct fib6_nh___8 *nh;
	struct fib6_info___8 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___8 *rt6;
};

struct fib6_config {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct ipv6_bpf_stub {
	int (*inet6_bind)(struct sock___3 *, struct sockaddr *, int, u32);
	struct sock___3 * (*udp6_lib_lookup)(struct net___60 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___56 *);
};

struct ip6_flowlabel___3 {
	struct ip6_flowlabel___3 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___223 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___60 *fl_net;
};

struct fib_nh_exception___8 {
	struct fib_nh_exception___8 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___8 *fnhe_rth_input;
	struct rtable___8 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___8 {
	struct dst_entry___44 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___8 {
	struct fib_nh_exception___8 *chain;
};

struct fib_info___5;

struct fib_nh___5 {
	struct fib_nh_common___8 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___5 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___5 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___60 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___5 *nh;
	struct callback_head rcu;
	struct fib_nh___5 fib_nh[0];
};

struct nh_info___5;

struct nh_group___5;

struct nexthop___5 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___60 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___5 *nh_info;
		struct nh_group___5 *nh_grp;
	};
};

struct fib_result {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_nh_common___8 *nhc;
	struct fib_info___5 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

enum {
	INET_ECN_NOT_ECT = 0,
	INET_ECN_ECT_1 = 1,
	INET_ECN_ECT_0 = 2,
	INET_ECN_CE = 3,
	INET_ECN_MASK = 3,
};

struct tcp_skb_cb {
	__u32 seq;
	__u32 end_seq;
	union {
		__u32 tcp_tw_isn;
		struct {
			u16 tcp_gso_segs;
			u16 tcp_gso_size;
		};
	};
	__u8 tcp_flags;
	__u8 sacked;
	__u8 ip_dsfield;
	__u8 txstamp_ack: 1;
	__u8 eor: 1;
	__u8 has_rxtstamp: 1;
	__u8 unused: 5;
	long: 59;
	long: 64;
	__u32 ack_seq;
	union {
		struct {
			__u32 in_flight: 30;
			__u32 is_app_limited: 1;
			__u32 unused: 1;
			__u32 delivered;
			u64 first_tx_mstamp;
			u64 delivered_mstamp;
		} tx;
		union {
			struct inet_skb_parm h4;
			struct inet6_skb_parm h6;
		} header;
	};
};

struct strp_msg {
	int full_len;
	int offset;
};

struct _strp_msg {
	struct strp_msg strp;
	int accum_len;
};

struct sk_skb_cb {
	unsigned char data[20];
	struct _strp_msg strp;
	u64 temp_reg;
};

struct sk_msg___2 {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___56 *skb;
	struct sock___3 *sk_redir;
	struct sock___3 *sk;
	struct list_head list;
};

struct cgroup_cls_state___2 {
	struct cgroup_subsys_state___173 css;
	u32 classid;
};

struct nh_info___5 {
	struct hlist_node dev_hash;
	struct nexthop___5 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___8 fib_nhc;
		struct fib_nh___5 fib_nh;
		struct fib6_nh___8 fib6_nh;
	};
};

struct nh_grp_entry___5;

struct nh_res_bucket___5 {
	struct nh_grp_entry___5 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___5 {
	struct nexthop___5 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___5 *nh_parent;
};

struct nh_res_table___5 {
	struct net___60 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___5 nh_buckets[0];
};

struct nh_group___5 {
	struct nh_group___5 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___5 *res_table;
	struct nh_grp_entry___5 nh_entries[0];
};

struct hw_port_info___4 {
	struct net_device___5 *lower_dev;
	u32 port_id;
};

struct metadata_dst___4 {
	struct dst_entry___44 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___4 port_info;
	} u;
};

struct xfrm_type___6 {
	struct module___230 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___6 *);
	void (*destructor)(struct xfrm_state___6 *);
	int (*input)(struct xfrm_state___6 *, struct sk_buff___56 *);
	int (*output)(struct xfrm_state___6 *, struct sk_buff___56 *);
	int (*reject)(struct xfrm_state___6 *, struct sk_buff___56 *, const struct flowi *);
};

struct xfrm_type_offload___6 {
	struct module___230 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___6 *, struct sk_buff___56 *);
	int (*input_tail)(struct xfrm_state___6 *, struct sk_buff___56 *);
	int (*xmit)(struct xfrm_state___6 *, struct sk_buff___56 *, netdev_features_t);
};

struct sec_path___3 {
	int len;
	int olen;
	struct xfrm_state___6 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct xdp_umem {
	void *addrs;
	u64 size;
	u32 headroom;
	u32 chunk_size;
	u32 chunks;
	u32 npgs;
	struct user_struct *user;
	refcount_t users;
	u8 flags;
	bool zc;
	struct page___251 **pgs;
	int id;
	struct list_head xsk_dma_list;
	struct work_struct work;
};

struct xsk_queue;

struct xdp_sock {
	struct sock___3 sk;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *rx;
	struct net_device___5 *dev;
	struct xdp_umem *umem;
	struct list_head flush_node;
	struct xsk_buff_pool *pool;
	u16 queue_id;
	bool zc;
	enum {
		XSK_READY = 0,
		XSK_BOUND = 1,
		XSK_UNBOUND = 2,
	} state;
	long: 64;
	struct xsk_queue *tx;
	struct list_head tx_list;
	spinlock_t rx_lock;
	u64 rx_dropped;
	u64 rx_queue_full;
	struct list_head map_list;
	spinlock_t map_list_lock;
	struct mutex mutex;
	struct xsk_queue *fq_tmp;
	struct xsk_queue *cq_tmp;
	long: 64;
};

struct in_ifaddr___2 {
	struct hlist_node hash;
	struct in_ifaddr___2 *ifa_next;
	struct in_device___2 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ipv6_sr_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
	__u8 first_segment;
	__u8 flags;
	__u16 tag;
	struct in6_addr segments[0];
};

enum {
	SEG6_LOCAL_ACTION_UNSPEC = 0,
	SEG6_LOCAL_ACTION_END = 1,
	SEG6_LOCAL_ACTION_END_X = 2,
	SEG6_LOCAL_ACTION_END_T = 3,
	SEG6_LOCAL_ACTION_END_DX2 = 4,
	SEG6_LOCAL_ACTION_END_DX6 = 5,
	SEG6_LOCAL_ACTION_END_DX4 = 6,
	SEG6_LOCAL_ACTION_END_DT6 = 7,
	SEG6_LOCAL_ACTION_END_DT4 = 8,
	SEG6_LOCAL_ACTION_END_B6 = 9,
	SEG6_LOCAL_ACTION_END_B6_ENCAP = 10,
	SEG6_LOCAL_ACTION_END_BM = 11,
	SEG6_LOCAL_ACTION_END_S = 12,
	SEG6_LOCAL_ACTION_END_AS = 13,
	SEG6_LOCAL_ACTION_END_AM = 14,
	SEG6_LOCAL_ACTION_END_BPF = 15,
	SEG6_LOCAL_ACTION_END_DT46 = 16,
	__SEG6_LOCAL_ACTION_MAX = 17,
};

struct seg6_bpf_srh_state {
	struct ipv6_sr_hdr *srh;
	u16 hdrlen;
	bool valid;
};

struct bpf_local_storage_data___8 {
	struct bpf_local_storage_map___8 *smap;
	u8 data[0];
};

struct crypto_alg___24;

struct crypto_tfm___24 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___24 *);
	struct crypto_alg___24 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___24 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___24 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___24 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___24 *, u8 *, const u8 *);
};

struct compress_alg___24 {
	int (*coa_compress)(struct crypto_tfm___24 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___24 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___24 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___24 cipher;
		struct compress_alg___24 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___24 *);
	void (*cra_exit)(struct crypto_tfm___24 *);
	void (*cra_destroy)(struct crypto_alg___24 *);
	struct module___230 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_aead___3 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___24 base;
};

struct tls_crypto_info {
	__u16 version;
	__u16 cipher_type;
};

struct tls12_crypto_info_aes_gcm_128 {
	struct tls_crypto_info info;
	unsigned char iv[8];
	unsigned char key[16];
	unsigned char salt[4];
	unsigned char rec_seq[8];
};

struct tls12_crypto_info_aes_gcm_256 {
	struct tls_crypto_info info;
	unsigned char iv[8];
	unsigned char key[32];
	unsigned char salt[4];
	unsigned char rec_seq[8];
};

struct tls12_crypto_info_chacha20_poly1305 {
	struct tls_crypto_info info;
	unsigned char iv[12];
	unsigned char key[32];
	unsigned char salt[0];
	unsigned char rec_seq[8];
};

struct tls_sw_context_rx {
	struct crypto_aead___3 *aead_recv;
	struct crypto_wait async_wait;
	struct strparser___2 strp;
	struct sk_buff_head___55 rx_list;
	void (*saved_data_ready)(struct sock___3 *);
	struct sk_buff___56 *recv_pkt;
	u8 control;
	u8 async_capable: 1;
	u8 decrypted: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t decrypt_pending;
	spinlock_t decrypt_compl_lock;
	bool async_notify;
};

struct cipher_context {
	char *iv;
	char *rec_seq;
};

union tls_crypto_context {
	struct tls_crypto_info info;
	union {
		struct tls12_crypto_info_aes_gcm_128 aes_gcm_128;
		struct tls12_crypto_info_aes_gcm_256 aes_gcm_256;
		struct tls12_crypto_info_chacha20_poly1305 chacha20_poly1305;
	};
};

struct tls_prot_info {
	u16 version;
	u16 cipher_type;
	u16 prepend_size;
	u16 tag_size;
	u16 overhead_size;
	u16 iv_size;
	u16 salt_size;
	u16 rec_seq_size;
	u16 aad_size;
	u16 tail_size;
};

struct tls_context {
	struct tls_prot_info prot_info;
	u8 tx_conf: 3;
	u8 rx_conf: 3;
	long: 61;
	long: 64;
	long: 64;
	int (*push_pending_record)(struct sock___3 *, int);
	void (*sk_write_space)(struct sock___3 *);
	void *priv_ctx_tx;
	void *priv_ctx_rx;
	struct net_device___5 *netdev;
	struct cipher_context tx;
	struct cipher_context rx;
	struct scatterlist *partially_sent_record;
	u16 partially_sent_offset;
	bool in_tcp_sendpages;
	bool pending_open_record_frags;
	struct mutex tx_lock;
	long unsigned int flags;
	struct proto___44 *sk_proto;
	struct sock___3 *sk;
	void (*sk_destruct)(struct sock___3 *);
	union tls_crypto_context crypto_send;
	union tls_crypto_context crypto_recv;
	struct list_head list;
	refcount_t refcount;
	struct callback_head rcu;
};

typedef u64 (*btf_bpf_skb_get_pay_offset)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_skb_get_nlattr)(struct sk_buff___56 *, u32, u32);

typedef u64 (*btf_bpf_skb_get_nlattr_nest)(struct sk_buff___56 *, u32, u32);

typedef u64 (*btf_bpf_skb_load_helper_8)(const struct sk_buff___56 *, const void *, int, int);

typedef u64 (*btf_bpf_skb_load_helper_8_no_cache)(const struct sk_buff___56 *, int);

typedef u64 (*btf_bpf_skb_load_helper_16)(const struct sk_buff___56 *, const void *, int, int);

typedef u64 (*btf_bpf_skb_load_helper_16_no_cache)(const struct sk_buff___56 *, int);

typedef u64 (*btf_bpf_skb_load_helper_32)(const struct sk_buff___56 *, const void *, int, int);

typedef u64 (*btf_bpf_skb_load_helper_32_no_cache)(const struct sk_buff___56 *, int);

struct bpf_scratchpad {
	union {
		__be32 diff[128];
		u8 buff[512];
	};
};

typedef u64 (*btf_bpf_skb_store_bytes)(struct sk_buff___56 *, u32, const void *, u32, u64);

typedef u64 (*btf_bpf_skb_load_bytes)(const struct sk_buff___56 *, u32, void *, u32);

typedef u64 (*btf_bpf_flow_dissector_load_bytes)(const struct bpf_flow_dissector___3 *, u32, void *, u32);

typedef u64 (*btf_bpf_skb_load_bytes_relative)(const struct sk_buff___56 *, u32, void *, u32, u32);

typedef u64 (*btf_bpf_skb_pull_data)(struct sk_buff___56 *, u32);

typedef u64 (*btf_bpf_sk_fullsock)(struct sock___3 *);

typedef u64 (*btf_sk_skb_pull_data)(struct sk_buff___56 *, u32);

typedef u64 (*btf_bpf_l3_csum_replace)(struct sk_buff___56 *, u32, u64, u64, u64);

typedef u64 (*btf_bpf_l4_csum_replace)(struct sk_buff___56 *, u32, u64, u64, u64);

typedef u64 (*btf_bpf_csum_diff)(__be32 *, u32, __be32 *, u32, __wsum);

typedef u64 (*btf_bpf_csum_update)(struct sk_buff___56 *, __wsum);

typedef u64 (*btf_bpf_csum_level)(struct sk_buff___56 *, u64);

enum {
	BPF_F_NEIGH = 2,
	BPF_F_PEER = 4,
	BPF_F_NEXTHOP = 8,
};

typedef u64 (*btf_bpf_clone_redirect)(struct sk_buff___56 *, u32, u64);

typedef u64 (*btf_bpf_redirect)(u32, u64);

typedef u64 (*btf_bpf_redirect_peer)(u32, u64);

typedef u64 (*btf_bpf_redirect_neigh)(u32, struct bpf_redir_neigh *, int, u64);

typedef u64 (*btf_bpf_msg_apply_bytes)(struct sk_msg___2 *, u32);

typedef u64 (*btf_bpf_msg_cork_bytes)(struct sk_msg___2 *, u32);

typedef u64 (*btf_bpf_msg_pull_data)(struct sk_msg___2 *, u32, u32, u64);

typedef u64 (*btf_bpf_msg_push_data)(struct sk_msg___2 *, u32, u32, u64);

typedef u64 (*btf_bpf_msg_pop_data)(struct sk_msg___2 *, u32, u32, u64);

typedef u64 (*btf_bpf_get_cgroup_classid_curr)();

typedef u64 (*btf_bpf_skb_cgroup_classid)(const struct sk_buff___56 *);

typedef u64 (*btf_bpf_get_cgroup_classid)(const struct sk_buff___56 *);

typedef u64 (*btf_bpf_get_route_realm)(const struct sk_buff___56 *);

typedef u64 (*btf_bpf_get_hash_recalc)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_set_hash_invalid)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_set_hash)(struct sk_buff___56 *, u32);

typedef u64 (*btf_bpf_skb_vlan_push)(struct sk_buff___56 *, __be16, u16);

typedef u64 (*btf_bpf_skb_vlan_pop)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_skb_change_proto)(struct sk_buff___56 *, __be16, u64);

typedef u64 (*btf_bpf_skb_change_type)(struct sk_buff___56 *, u32);

typedef u64 (*btf_sk_skb_adjust_room)(struct sk_buff___56 *, s32, u32, u64);

typedef u64 (*btf_bpf_skb_adjust_room)(struct sk_buff___56 *, s32, u32, u64);

typedef u64 (*btf_bpf_skb_change_tail)(struct sk_buff___56 *, u32, u64);

typedef u64 (*btf_sk_skb_change_tail)(struct sk_buff___56 *, u32, u64);

typedef u64 (*btf_bpf_skb_change_head)(struct sk_buff___56 *, u32, u64);

typedef u64 (*btf_sk_skb_change_head)(struct sk_buff___56 *, u32, u64);

typedef u64 (*btf_bpf_xdp_adjust_head)(struct xdp_buff___55 *, int);

typedef u64 (*btf_bpf_xdp_adjust_tail)(struct xdp_buff___55 *, int);

typedef u64 (*btf_bpf_xdp_adjust_meta)(struct xdp_buff___55 *, int);

typedef u64 (*btf_bpf_xdp_redirect)(u32, u64);

typedef u64 (*btf_bpf_xdp_redirect_map)(struct bpf_map___58 *, u32, u64);

typedef u64 (*btf_bpf_skb_event_output)(struct sk_buff___56 *, struct bpf_map___58 *, u64, void *, u64);

typedef u64 (*btf_bpf_skb_get_tunnel_key)(struct sk_buff___56 *, struct bpf_tunnel_key *, u32, u64);

typedef u64 (*btf_bpf_skb_get_tunnel_opt)(struct sk_buff___56 *, u8 *, u32);

typedef u64 (*btf_bpf_skb_set_tunnel_key)(struct sk_buff___56 *, const struct bpf_tunnel_key *, u32, u64);

typedef u64 (*btf_bpf_skb_set_tunnel_opt)(struct sk_buff___56 *, const u8 *, u32);

typedef u64 (*btf_bpf_skb_under_cgroup)(struct sk_buff___56 *, struct bpf_map___58 *, u32);

typedef u64 (*btf_bpf_skb_cgroup_id)(const struct sk_buff___56 *);

typedef u64 (*btf_bpf_skb_ancestor_cgroup_id)(const struct sk_buff___56 *, int);

typedef u64 (*btf_bpf_sk_cgroup_id)(struct sock___3 *);

typedef u64 (*btf_bpf_sk_ancestor_cgroup_id)(struct sock___3 *, int);

typedef u64 (*btf_bpf_xdp_event_output)(struct xdp_buff___55 *, struct bpf_map___58 *, u64, void *, u64);

typedef u64 (*btf_bpf_get_socket_cookie)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_get_socket_cookie_sock_addr)(struct bpf_sock_addr_kern___3 *);

typedef u64 (*btf_bpf_get_socket_cookie_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_get_socket_ptr_cookie)(struct sock___3 *);

typedef u64 (*btf_bpf_get_socket_cookie_sock_ops)(struct bpf_sock_ops_kern___3 *);

typedef u64 (*btf_bpf_get_netns_cookie_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_get_netns_cookie_sock_addr)(struct bpf_sock_addr_kern___3 *);

typedef u64 (*btf_bpf_get_netns_cookie_sock_ops)(struct bpf_sock_ops_kern___3 *);

typedef u64 (*btf_bpf_get_netns_cookie_sk_msg)(struct sk_msg___2 *);

typedef u64 (*btf_bpf_get_socket_uid)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_sk_setsockopt)(struct sock___3 *, int, int, char *, int);

typedef u64 (*btf_bpf_sk_getsockopt)(struct sock___3 *, int, int, char *, int);

typedef u64 (*btf_bpf_sock_addr_setsockopt)(struct bpf_sock_addr_kern___3 *, int, int, char *, int);

typedef u64 (*btf_bpf_sock_addr_getsockopt)(struct bpf_sock_addr_kern___3 *, int, int, char *, int);

typedef u64 (*btf_bpf_sock_ops_setsockopt)(struct bpf_sock_ops_kern___3 *, int, int, char *, int);

typedef u64 (*btf_bpf_sock_ops_getsockopt)(struct bpf_sock_ops_kern___3 *, int, int, char *, int);

typedef u64 (*btf_bpf_sock_ops_cb_flags_set)(struct bpf_sock_ops_kern___3 *, int);

typedef u64 (*btf_bpf_bind)(struct bpf_sock_addr_kern___3 *, struct sockaddr *, int);

typedef u64 (*btf_bpf_skb_get_xfrm_state)(struct sk_buff___56 *, u32, struct bpf_xfrm_state *, u32, u64);

typedef u64 (*btf_bpf_xdp_fib_lookup)(struct xdp_buff___55 *, struct bpf_fib_lookup *, int, u32);

typedef u64 (*btf_bpf_skb_fib_lookup)(struct sk_buff___56 *, struct bpf_fib_lookup *, int, u32);

typedef u64 (*btf_bpf_skb_check_mtu)(struct sk_buff___56 *, u32, u32 *, s32, u64);

typedef u64 (*btf_bpf_xdp_check_mtu)(struct xdp_buff___55 *, u32, u32 *, s32, u64);

typedef u64 (*btf_bpf_lwt_in_push_encap)(struct sk_buff___56 *, u32, void *, u32);

typedef u64 (*btf_bpf_lwt_xmit_push_encap)(struct sk_buff___56 *, u32, void *, u32);

typedef u64 (*btf_bpf_lwt_seg6_store_bytes)(struct sk_buff___56 *, u32, const void *, u32);

typedef u64 (*btf_bpf_lwt_seg6_action)(struct sk_buff___56 *, u32, void *, u32);

typedef u64 (*btf_bpf_lwt_seg6_adjust_srh)(struct sk_buff___56 *, u32, s32);

typedef u64 (*btf_bpf_skc_lookup_tcp)(struct sk_buff___56 *, struct bpf_sock_tuple *, u32, u64, u64);

typedef u64 (*btf_bpf_sk_lookup_tcp)(struct sk_buff___56 *, struct bpf_sock_tuple *, u32, u64, u64);

typedef u64 (*btf_bpf_sk_lookup_udp)(struct sk_buff___56 *, struct bpf_sock_tuple *, u32, u64, u64);

typedef u64 (*btf_bpf_sk_release)(struct sock___3 *);

typedef u64 (*btf_bpf_xdp_sk_lookup_udp)(struct xdp_buff___55 *, struct bpf_sock_tuple *, u32, u32, u64);

typedef u64 (*btf_bpf_xdp_skc_lookup_tcp)(struct xdp_buff___55 *, struct bpf_sock_tuple *, u32, u32, u64);

typedef u64 (*btf_bpf_xdp_sk_lookup_tcp)(struct xdp_buff___55 *, struct bpf_sock_tuple *, u32, u32, u64);

typedef u64 (*btf_bpf_sock_addr_skc_lookup_tcp)(struct bpf_sock_addr_kern___3 *, struct bpf_sock_tuple *, u32, u64, u64);

typedef u64 (*btf_bpf_sock_addr_sk_lookup_tcp)(struct bpf_sock_addr_kern___3 *, struct bpf_sock_tuple *, u32, u64, u64);

typedef u64 (*btf_bpf_sock_addr_sk_lookup_udp)(struct bpf_sock_addr_kern___3 *, struct bpf_sock_tuple *, u32, u64, u64);

typedef u64 (*btf_bpf_tcp_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_get_listener_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_skb_ecn_set_ce)(struct sk_buff___56 *);

typedef u64 (*btf_bpf_tcp_check_syncookie)(struct sock___3 *, void *, u32, struct tcphdr *, u32);

typedef u64 (*btf_bpf_tcp_gen_syncookie)(struct sock___3 *, void *, u32, struct tcphdr *, u32);

typedef u64 (*btf_bpf_sk_assign)(struct sk_buff___56 *, struct sock___3 *, u64);

typedef u64 (*btf_bpf_sock_ops_load_hdr_opt)(struct bpf_sock_ops_kern___3 *, void *, u32, u64);

typedef u64 (*btf_bpf_sock_ops_store_hdr_opt)(struct bpf_sock_ops_kern___3 *, const void *, u32, u64);

typedef u64 (*btf_bpf_sock_ops_reserve_hdr_opt)(struct bpf_sock_ops_kern___3 *, u32, u64);

typedef u64 (*btf_sk_select_reuseport)(struct sk_reuseport_kern___2 *, struct bpf_map___58 *, void *, u32);

typedef u64 (*btf_sk_reuseport_load_bytes)(const struct sk_reuseport_kern___2 *, u32, void *, u32);

typedef u64 (*btf_sk_reuseport_load_bytes_relative)(const struct sk_reuseport_kern___2 *, u32, void *, u32, u32);

typedef u64 (*btf_bpf_sk_lookup_assign)(struct bpf_sk_lookup_kern___2 *, struct sock___3 *, u64);

typedef u64 (*btf_bpf_skc_to_tcp6_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_skc_to_tcp_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_skc_to_tcp_timewait_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_skc_to_tcp_request_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_skc_to_udp6_sock)(struct sock___3 *);

typedef u64 (*btf_bpf_sock_from_file)(struct file___246 *);

struct bpf_cpu_map_entry___2;

struct bpf_dtab_netdev___2;

enum {
	INET_DIAG_REQ_NONE = 0,
	INET_DIAG_REQ_BYTECODE = 1,
	INET_DIAG_REQ_SK_BPF_STORAGES = 2,
	INET_DIAG_REQ_PROTOCOL = 3,
	__INET_DIAG_REQ_MAX = 4,
};

struct sock_diag_req {
	__u8 sdiag_family;
	__u8 sdiag_protocol;
};

struct sock_diag_handler {
	__u8 family;
	int (*dump)(struct sk_buff___50 *, struct nlmsghdr *);
	int (*get_info)(struct sk_buff___50 *, struct sock___39 *);
	int (*destroy)(struct sk_buff___50 *, struct nlmsghdr *);
};

struct broadcast_sk {
	struct sock___39 *sk;
	struct work_struct work;
};

struct dentry___247;

struct super_block___247;

struct module___231;

struct file_system_type___247 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___247 * (*mount)(struct file_system_type___247 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___247 *);
	struct module___231 *owner;
	struct file_system_type___247 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___247;

struct kiocb___247;

struct iov_iter___167;

struct poll_table_struct___170;

struct vm_area_struct___252;

struct inode___247;

struct file_lock___247;

struct page___252;

struct pipe_inode_info___88;

struct seq_file___222;

struct file_operations___248 {
	struct module___231 *owner;
	loff_t (*llseek)(struct file___247 *, loff_t, int);
	ssize_t (*read)(struct file___247 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___247 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___247 *, struct iov_iter___167 *);
	ssize_t (*write_iter)(struct kiocb___247 *, struct iov_iter___167 *);
	int (*iopoll)(struct kiocb___247 *, bool);
	int (*iterate)(struct file___247 *, struct dir_context *);
	int (*iterate_shared)(struct file___247 *, struct dir_context *);
	__poll_t (*poll)(struct file___247 *, struct poll_table_struct___170 *);
	long int (*unlocked_ioctl)(struct file___247 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___247 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___247 *, struct vm_area_struct___252 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___247 *, struct file___247 *);
	int (*flush)(struct file___247 *, fl_owner_t);
	int (*release)(struct inode___247 *, struct file___247 *);
	int (*fsync)(struct file___247 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___247 *, int);
	int (*lock)(struct file___247 *, int, struct file_lock___247 *);
	ssize_t (*sendpage)(struct file___247 *, struct page___252 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___247 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___247 *, long unsigned int);
	int (*flock)(struct file___247 *, int, struct file_lock___247 *);
	ssize_t (*splice_write)(struct pipe_inode_info___88 *, struct file___247 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___247 *, loff_t *, struct pipe_inode_info___88 *, size_t, unsigned int);
	int (*setlease)(struct file___247 *, long int, struct file_lock___247 **, void **);
	long int (*fallocate)(struct file___247 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___222 *, struct file___247 *);
	ssize_t (*copy_file_range)(struct file___247 *, loff_t, struct file___247 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___247 *, loff_t, struct file___247 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___247 *, loff_t, loff_t, int);
};

struct vmacache___252 {
	u64 seqnum;
	struct vm_area_struct___252 *vmas[4];
};

struct page_frag___252 {
	struct page___252 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___253;

struct pid___224;

struct nsproxy___233;

struct signal_struct___248;

struct bio_list___140;

struct backing_dev_info___126;

struct io_context___140;

struct css_set___174;

struct mem_cgroup___114;

struct request_queue___140;

struct vm_struct___230;

struct task_struct___254 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___254 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___253 *mm;
	struct mm_struct___253 *active_mm;
	struct vmacache___252 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___254 *real_parent;
	struct task_struct___254 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___254 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___224 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___233 *nsproxy;
	struct signal_struct___248 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___254 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___140 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___126 *backing_dev_info;
	struct io_context___140 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___174 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___88 *splice_pipe;
	struct page_frag___252 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___114 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___114 *active_memcg;
	struct request_queue___140 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___254 *oom_reaper_list;
	struct vm_struct___230 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___235;

struct kobj_type___235;

struct kernfs_node___235;

struct kobject___235 {
	const char *name;
	struct list_head entry;
	struct kobject___235 *parent;
	struct kset___235 *kset;
	struct kobj_type___235 *ktype;
	struct kernfs_node___235 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___232 {
	struct kobject___235 kobj;
	struct module___231 *mod;
	struct kobject___235 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___231 {
	struct module___231 *mod;
	struct latch_tree_node node;
};

struct module_layout___231 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___231 mtn;
};

struct module_attribute___231;

struct kernel_param___231;

struct module___231 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___232 mkobj;
	struct module_attribute___231 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___235 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___231 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___231 core_layout;
	struct module_layout___231 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___252 *pgtable_t___252;

struct address_space___247;

struct page_pool___76;

struct dev_pagemap___242;

struct page___252 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___247 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___76 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___252 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___252 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___253 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___242 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___242;

struct vm_area_struct___252 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___252 *vm_next;
	struct vm_area_struct___252 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___253 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___242 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___247 *vm_file;
	struct file___247 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___252;

struct mm_struct___253 {
	struct {
		struct vm_area_struct___252 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___247 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___252 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___254 *owner;
		struct user_namespace___26 *user_ns;
		struct file___247 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___247;

struct address_space___247 {
	struct inode___247 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___247 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___228;

struct page_pool_params___76 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___228 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___76 {
	u32 count;
	struct page___252 *cache[128];
};

struct page_pool___76 {
	struct page_pool_params___76 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___252 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___76 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___242;

struct dev_pagemap___242 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___242 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___247;

struct path___247 {
	struct vfsmount___247 *mnt;
	struct dentry___247 *dentry;
};

struct fown_struct___224 {
	rwlock_t lock;
	struct pid___224 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___247 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___247 f_path;
	struct inode___247 *f_inode;
	const struct file_operations___248 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___224 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___247 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___242;

struct vm_operations_struct___242 {
	void (*open)(struct vm_area_struct___252 *);
	void (*close)(struct vm_area_struct___252 *);
	int (*may_split)(struct vm_area_struct___252 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___252 *);
	int (*mprotect)(struct vm_area_struct___252 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___242 *);
	vm_fault_t (*huge_fault)(struct vm_fault___242 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___242 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___252 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___242 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___242 *);
	int (*access)(struct vm_area_struct___252 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___252 *);
	int (*set_policy)(struct vm_area_struct___252 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___252 *, long unsigned int);
	struct page___252 * (*find_special_page)(struct vm_area_struct___252 *, long unsigned int);
};

struct core_thread___252 {
	struct task_struct___254 *task;
	struct core_thread___252 *next;
};

struct core_state___252 {
	atomic_t nr_threads;
	struct core_thread___252 dumper;
	struct completion startup;
};

struct vm_fault___242 {
	const struct {
		struct vm_area_struct___252 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___252 *cow_page;
	struct page___252 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___252 prealloc_pte;
};

struct pglist_data___122;

struct lruvec___122 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___122 *pgdat;
};

struct zone___122 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___122 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___122 {
	struct zone___122 *zone;
	int zone_idx;
};

struct zonelist___122 {
	struct zoneref___122 _zonerefs[321];
};

struct pglist_data___122 {
	struct zone___122 node_zones[5];
	struct zonelist___122 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___254 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___254 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___122 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___224;

struct upid___224 {
	int nr;
	struct pid_namespace___224 *ns;
};

struct pid_namespace___224 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___254 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___224 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___224 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___224 numbers[1];
};

struct signal_struct___248 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___254 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___254 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___224 *pids[4];
	struct pid___224 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___253 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___61;

struct cgroup_namespace___174;

struct nsproxy___233 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___224 *pid_ns_for_children;
	struct net___61 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___174 *cgroup_ns;
};

struct bio___140;

struct bio_list___140 {
	struct bio___140 *head;
	struct bio___140 *tail;
};

struct cgroup_subsys_state___174;

struct bdi_writeback___126 {
	struct backing_dev_info___126 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___174 *memcg_css;
	struct cgroup_subsys_state___174 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___126 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___126 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___228 *dev;
	char dev_name[64];
	struct device___228 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___247 *debug_dir;
};

struct io_cq___140;

struct io_context___140 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___140 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___174;

struct css_set___174 {
	struct cgroup_subsys_state___174 *subsys[14];
	refcount_t refcount;
	struct css_set___174 *dom_cset;
	struct cgroup___174 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___174 *mg_src_cgrp;
	struct cgroup___174 *mg_dst_cgrp;
	struct css_set___174 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___247;

struct pipe_buffer___88;

struct pipe_inode_info___88 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___252 *tmp_page;
	struct fasync_struct___247 *fasync_readers;
	struct fasync_struct___247 *fasync_writers;
	struct pipe_buffer___88 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___174;

struct cgroup_subsys_state___174 {
	struct cgroup___174 *cgroup;
	struct cgroup_subsys___174 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___174 *parent;
};

struct cgroup_file___174 {
	struct kernfs_node___235 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___114;

struct mem_cgroup_per_node___114;

struct mem_cgroup___114 {
	struct cgroup_subsys_state___174 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___174 events_file;
	struct cgroup_file___174 events_local_file;
	struct cgroup_file___174 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___114 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___254 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___114 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___140;

struct blk_integrity___140 {
	const struct blk_integrity_profile___140 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___140 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___140 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___140;

struct elevator_queue___140;

struct blk_mq_ops___135;

struct blk_mq_hw_ctx___135;

struct gendisk___143;

struct blkcg_gq___128;

struct blk_mq_tag_set___135;

struct request_queue___140 {
	struct request___140 *last_merge;
	struct elevator_queue___140 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___135 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___135 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___143 *disk;
	struct kobject___235 kobj;
	struct kobject___235 *mq_kobj;
	struct blk_integrity___140 integrity;
	struct device___228 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___128 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___135 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___140 bio_split;
	struct dentry___247 *debugfs_dir;
	struct dentry___247 *sched_debugfs_dir;
	struct dentry___247 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___230 {
	struct vm_struct___230 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___252 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___164 {
	struct page___252 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___167 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___164 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___88 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___47 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___167 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___247 *msg_iocb;
};

struct kiocb___247 {
	struct file___247 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___247 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___56;

struct sock___45;

struct sk_buff___57 {
	union {
		struct {
			struct sk_buff___57 *next;
			struct sk_buff___57 *prev;
			union {
				struct net_device___56 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___45 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___57 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___61;

struct fqdir___61 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___61 *f;
	struct net___61 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___61;

struct inet_frags___61 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___61 *, const void *);
	void (*destructor)(struct inet_frag_queue___61 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct fib_rules_ops___45;

struct fib_notifier_ops___45;

struct netns_ipv4___61 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___45 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___45 *fibnl;
	struct sock___45 **icmp_sk;
	struct sock___45 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___45 **tcp_sk;
	struct fqdir___61 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___45 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___45 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___45 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___45;

struct neighbour___45;

struct dst_ops___61 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___61 *);
	struct dst_entry___45 * (*check)(struct dst_entry___45 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___45 *);
	unsigned int (*mtu)(const struct dst_entry___45 *);
	u32 * (*cow_metrics)(struct dst_entry___45 *, long unsigned int);
	void (*destroy)(struct dst_entry___45 *);
	void (*ifdown)(struct dst_entry___45 *, struct net_device___56 *, int);
	struct dst_entry___45 * (*negative_advice)(struct dst_entry___45 *);
	void (*link_failure)(struct sk_buff___57 *);
	void (*update_pmtu)(struct dst_entry___45 *, struct sock___45 *, struct sk_buff___57 *, u32, bool);
	void (*redirect)(struct dst_entry___45 *, struct sock___45 *, struct sk_buff___57 *);
	int (*local_out)(struct net___61 *, struct sock___45 *, struct sk_buff___57 *);
	struct neighbour___45 * (*neigh_lookup)(const struct dst_entry___45 *, struct sk_buff___57 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___45 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___61 {
	struct dst_ops___61 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___61 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___45 *fib6_rules_ops;
	struct sock___45 **icmp_sk;
	struct sock___45 *ndisc_sk;
	struct sock___45 *tcp_sk;
	struct sock___45 *igmp_sk;
	struct sock___45 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___45 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___45 *notifier_ops;
	struct fib_notifier_ops___45 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___61 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___61 *fqdir;
};

struct netns_sctp___45 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___45 *ctl_sock;
	struct sock___45 *udp4_sock;
	struct sock___45 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___56 {
	struct sk_buff___57 *next;
	struct sk_buff___57 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___52;

struct bpf_prog___52;

struct netns_bpf___52 {
	struct bpf_prog_array___52 *run_array[2];
	struct bpf_prog___52 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___61 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___45 *nlsk;
	struct sock___45 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___61 xfrm4_dst_ops;
	struct dst_ops___61 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___61 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___45 *rtnl;
	struct sock___45 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___56 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___61 ipv4;
	struct netns_ipv6___61 ipv6;
	struct netns_ieee802154_lowpan___61 ieee802154_lowpan;
	struct netns_sctp___45 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___56 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___52 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___61 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___45 *crypto_nlsk;
	struct sock___45 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___61 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___57 *fragments_tail;
	struct sk_buff___57 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___61 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___45;

struct fib_lookup_arg___45;

struct fib_rules_ops___45 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___45 *, struct flowi *, int, struct fib_lookup_arg___45 *);
	bool (*suppress)(struct fib_rule___45 *, int, struct fib_lookup_arg___45 *);
	int (*match)(struct fib_rule___45 *, struct flowi *, int);
	int (*configure)(struct fib_rule___45 *, struct sk_buff___57 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___45 *);
	int (*compare)(struct fib_rule___45 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___45 *, struct sk_buff___57 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___45 *);
	void (*flush_cache)(struct fib_rules_ops___45 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___231 *owner;
	struct net___61 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___61 *net;
} possible_net_t___56;

struct proto___45;

struct sock_common___45 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___45 *skc_prot;
	possible_net_t___56 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___45 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___45 {
	struct cgroup___174 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___45;

struct socket_wq___46;

struct socket___47;

struct sock___45 {
	struct sock_common___45 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___56 sk_error_queue;
	struct sk_buff___57 *sk_rx_skb_cache;
	struct sk_buff_head___56 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___57 *head;
		struct sk_buff___57 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___45 *sk_filter;
	union {
		struct socket_wq___46 *sk_wq;
		struct socket_wq___46 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___45 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___45 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___57 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___57 *sk_tx_skb_cache;
	struct sk_buff_head___56 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___252 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___45 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___224 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___47 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___45 sk_cgrp_data;
	struct mem_cgroup___114 *sk_memcg;
	void (*sk_state_change)(struct sock___45 *);
	void (*sk_data_ready)(struct sock___45 *);
	void (*sk_write_space)(struct sock___45 *);
	void (*sk_error_report)(struct sock___45 *);
	int (*sk_backlog_rcv)(struct sock___45 *, struct sk_buff___57 *);
	struct sk_buff___57 * (*sk_validate_xmit_skb)(struct sock___45 *, struct net_device___56 *, struct sk_buff___57 *);
	void (*sk_destruct)(struct sock___45 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct fib_notifier_ops___45 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___61 *);
	int (*fib_dump)(struct net___61 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___231 *owner;
	struct callback_head rcu;
};

struct dst_entry___45 {
	struct net_device___56 *dev;
	struct dst_ops___61 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___57 *);
	int (*output)(struct net___61 *, struct sock___45 *, struct sk_buff___57 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___56(struct sk_buff___57 **);

struct wakeup_source___228;

struct dev_pm_info___228 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___228 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___228 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___228;

struct bus_type___228;

struct device_driver___228;

struct dev_pm_domain___228;

struct device_node___102;

struct fwnode_handle___224;

struct class___228;

struct attribute_group___235;

struct device___228 {
	struct kobject___235 kobj;
	struct device___228 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___228 *type;
	struct bus_type___228 *bus;
	struct device_driver___228 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___228 power;
	struct dev_pm_domain___228 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___102 *of_node;
	struct fwnode_handle___224 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___228 *class;
	const struct attribute_group___235 **groups;
	void (*release)(struct device___228 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___52 {
	struct bpf_prog___52 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___56;

struct net_device_ops___56;

struct iw_handler_def___3;

struct ethtool_ops___25;

struct l3mdev_ops___45;

struct ndisc_ops___32;

struct xfrmdev_ops___56;

struct header_ops___56;

struct dsa_port___4;

struct in_device___3;

struct inet6_dev___32;

struct netdev_rx_queue___56;

struct mini_Qdisc___52;

struct netdev_queue___56;

struct Qdisc___52;

struct rtnl_link_ops___52;

struct dcbnl_rtnl_ops___56;

struct phy_device___9;

struct net_device___56 {
	char name[16];
	struct netdev_name_node___56 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___56 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def___3 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___25 *ethtool_ops;
	const struct l3mdev_ops___45 *l3mdev_ops;
	const struct ndisc_ops___32 *ndisc_ops;
	const struct xfrmdev_ops___56 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___56 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___235 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port___4 *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___3 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___32 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___56 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___52 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___56 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___52 *miniq_ingress;
	struct netdev_queue___56 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___56 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___52 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___52 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___56 = 0,
		NETREG_REGISTERED___56 = 1,
		NETREG_UNREGISTERING___56 = 2,
		NETREG_UNREGISTERED___56 = 3,
		NETREG_RELEASED___56 = 4,
		NETREG_DUMMY___56 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___56 = 0,
		RTNL_LINK_INITIALIZING___56 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___56 *);
	struct netpoll_info *npinfo;
	possible_net_t___56 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___228 dev;
	const struct attribute_group___235 *sysfs_groups[4];
	const struct attribute_group___235 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___52 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___56 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___9 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___52 xdp_state[3];
	long: 64;
};

struct neigh_table___45;

struct neigh_parms___45;

struct neigh_ops___45;

struct neighbour___45 {
	struct neighbour___45 *next;
	struct neigh_table___45 *tbl;
	struct neigh_parms___45 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___56 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___45 *, struct sk_buff___57 *);
	const struct neigh_ops___45 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___56 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___52 {
	struct bpf_prog___52 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___52 {
	struct callback_head rcu;
	struct bpf_prog_array_item___52 items[0];
};

struct bpf_prog_aux___59;

struct bpf_prog___52 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___59 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___247;

struct dentry___247 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___247 *d_parent;
	struct qstr d_name;
	struct inode___247 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___247 *d_op;
	struct super_block___247 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___247;

struct inode___247 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___247 *i_op;
	struct super_block___247 *i_sb;
	struct address_space___247 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___126 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___248 *i_fop;
		void (*free_inode)(struct inode___247 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___247 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___88 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___247 {
	int (*d_revalidate)(struct dentry___247 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___247 *, unsigned int);
	int (*d_hash)(const struct dentry___247 *, struct qstr *);
	int (*d_compare)(const struct dentry___247 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___247 *);
	int (*d_init)(struct dentry___247 *);
	void (*d_release)(struct dentry___247 *);
	void (*d_prune)(struct dentry___247 *);
	void (*d_iput)(struct dentry___247 *, struct inode___247 *);
	char * (*d_dname)(struct dentry___247 *, char *, int);
	struct vfsmount___247 * (*d_automount)(struct path___247 *);
	int (*d_manage)(const struct path___247 *, bool);
	struct dentry___247 * (*d_real)(struct dentry___247 *, const struct inode___247 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___247;

struct mem_dqinfo___247 {
	struct quota_format_type___247 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___247;

struct quota_info___247 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___247 *files[3];
	struct mem_dqinfo___247 info[3];
	const struct quota_format_ops___247 *ops[3];
};

struct rcuwait___248 {
	struct task_struct___254 *task;
};

struct percpu_rw_semaphore___248 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___248 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___247 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___248 rw_sem[3];
};

struct shrink_control___114;

struct shrinker___114 {
	long unsigned int (*count_objects)(struct shrinker___114 *, struct shrink_control___114 *);
	long unsigned int (*scan_objects)(struct shrinker___114 *, struct shrink_control___114 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___247;

struct dquot_operations___247;

struct quotactl_ops___247;

struct block_device___143;

struct super_block___247 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___247 *s_type;
	const struct super_operations___247 *s_op;
	const struct dquot_operations___247 *dq_op;
	const struct quotactl_ops___247 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___247 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___143 *s_bdev;
	struct backing_dev_info___126 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___247 s_dquot;
	struct sb_writers___247 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___247 *s_d_op;
	int cleancache_poolid;
	struct shrinker___114 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___247 {
	struct dentry___247 *mnt_root;
	struct super_block___247 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___114 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___114 *memcg;
};

struct psi_group___174 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___254 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___52 {
	struct bpf_prog_array___52 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___52 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___174;

struct cgroup_rstat_cpu___174;

struct cgroup___174 {
	struct cgroup_subsys_state___174 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___235 *kn;
	struct cgroup_file___174 procs_file;
	struct cgroup_file___174 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___174 *subsys[14];
	struct cgroup_root___174 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___174 *dom_cgrp;
	struct cgroup___174 *old_dom_cgrp;
	struct cgroup_rstat_cpu___174 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___174 psi;
	struct cgroup_bpf___52 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___140 {
	struct request_queue___140 *q;
	struct io_context___140 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___247 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___247 *ia_file;
};

struct dquot___247 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___247 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___247 {
	int qf_fmt_id;
	const struct quota_format_ops___247 *qf_ops;
	struct module___231 *qf_owner;
	struct quota_format_type___247 *qf_next;
};

struct quota_format_ops___247 {
	int (*check_quota_file)(struct super_block___247 *, int);
	int (*read_file_info)(struct super_block___247 *, int);
	int (*write_file_info)(struct super_block___247 *, int);
	int (*free_file_info)(struct super_block___247 *, int);
	int (*read_dqblk)(struct dquot___247 *);
	int (*commit_dqblk)(struct dquot___247 *);
	int (*release_dqblk)(struct dquot___247 *);
	int (*get_next_id)(struct super_block___247 *, struct kqid *);
};

struct dquot_operations___247 {
	int (*write_dquot)(struct dquot___247 *);
	struct dquot___247 * (*alloc_dquot)(struct super_block___247 *, int);
	void (*destroy_dquot)(struct dquot___247 *);
	int (*acquire_dquot)(struct dquot___247 *);
	int (*release_dquot)(struct dquot___247 *);
	int (*mark_dirty)(struct dquot___247 *);
	int (*write_info)(struct super_block___247 *, int);
	qsize_t * (*get_reserved_space)(struct inode___247 *);
	int (*get_projid)(struct inode___247 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___247 *, qsize_t *);
	int (*get_next_id)(struct super_block___247 *, struct kqid *);
};

struct quotactl_ops___247 {
	int (*quota_on)(struct super_block___247 *, int, int, const struct path___247 *);
	int (*quota_off)(struct super_block___247 *, int);
	int (*quota_enable)(struct super_block___247 *, unsigned int);
	int (*quota_disable)(struct super_block___247 *, unsigned int);
	int (*quota_sync)(struct super_block___247 *, int);
	int (*set_info)(struct super_block___247 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___247 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___247 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___247 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___247 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___247 *, unsigned int);
};

struct writeback_control___126;

struct address_space_operations___247 {
	int (*writepage)(struct page___252 *, struct writeback_control___126 *);
	int (*readpage)(struct file___247 *, struct page___252 *);
	int (*writepages)(struct address_space___247 *, struct writeback_control___126 *);
	int (*set_page_dirty)(struct page___252 *);
	int (*readpages)(struct file___247 *, struct address_space___247 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___247 *, struct address_space___247 *, loff_t, unsigned int, unsigned int, struct page___252 **, void **);
	int (*write_end)(struct file___247 *, struct address_space___247 *, loff_t, unsigned int, unsigned int, struct page___252 *, void *);
	sector_t (*bmap)(struct address_space___247 *, sector_t);
	void (*invalidatepage)(struct page___252 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___252 *, gfp_t);
	void (*freepage)(struct page___252 *);
	ssize_t (*direct_IO)(struct kiocb___247 *, struct iov_iter___167 *);
	int (*migratepage)(struct address_space___247 *, struct page___252 *, struct page___252 *, enum migrate_mode);
	bool (*isolate_page)(struct page___252 *, isolate_mode_t);
	void (*putback_page)(struct page___252 *);
	int (*launder_page)(struct page___252 *);
	int (*is_partially_uptodate)(struct page___252 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___252 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___247 *, struct page___252 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___247 *, sector_t *);
	void (*swap_deactivate)(struct file___247 *);
};

struct writeback_control___126 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___126 *wb;
	struct inode___247 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___247 {
	struct dentry___247 * (*lookup)(struct inode___247 *, struct dentry___247 *, unsigned int);
	const char * (*get_link)(struct dentry___247 *, struct inode___247 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___247 *, int);
	struct posix_acl * (*get_acl)(struct inode___247 *, int, bool);
	int (*readlink)(struct dentry___247 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___247 *, struct dentry___247 *, umode_t, bool);
	int (*link)(struct dentry___247 *, struct inode___247 *, struct dentry___247 *);
	int (*unlink)(struct inode___247 *, struct dentry___247 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___247 *, struct dentry___247 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___247 *, struct dentry___247 *, umode_t);
	int (*rmdir)(struct inode___247 *, struct dentry___247 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___247 *, struct dentry___247 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___247 *, struct dentry___247 *, struct inode___247 *, struct dentry___247 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___247 *, struct iattr___247 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___247 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___247 *, char *, size_t);
	int (*fiemap)(struct inode___247 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___247 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___247 *, struct dentry___247 *, struct file___247 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___247 *, struct dentry___247 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___247 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___247 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___247 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___247 {
	void (*fl_copy_lock)(struct file_lock___247 *, struct file_lock___247 *);
	void (*fl_release_private)(struct file_lock___247 *);
};

struct lock_manager_operations___247;

struct file_lock___247 {
	struct file_lock___247 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___247 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___247 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___247 *fl_ops;
	const struct lock_manager_operations___247 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___247 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___247 *);
	int (*lm_grant)(struct file_lock___247 *, int);
	bool (*lm_break)(struct file_lock___247 *);
	int (*lm_change)(struct file_lock___247 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___247 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___247 *);
};

struct fasync_struct___247 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___247 *fa_next;
	struct file___247 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___247 {
	struct inode___247 * (*alloc_inode)(struct super_block___247 *);
	void (*destroy_inode)(struct inode___247 *);
	void (*free_inode)(struct inode___247 *);
	void (*dirty_inode)(struct inode___247 *, int);
	int (*write_inode)(struct inode___247 *, struct writeback_control___126 *);
	int (*drop_inode)(struct inode___247 *);
	void (*evict_inode)(struct inode___247 *);
	void (*put_super)(struct super_block___247 *);
	int (*sync_fs)(struct super_block___247 *, int);
	int (*freeze_super)(struct super_block___247 *);
	int (*freeze_fs)(struct super_block___247 *);
	int (*thaw_super)(struct super_block___247 *);
	int (*unfreeze_fs)(struct super_block___247 *);
	int (*statfs)(struct dentry___247 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___247 *, int *, char *);
	void (*umount_begin)(struct super_block___247 *);
	int (*show_options)(struct seq_file___222 *, struct dentry___247 *);
	int (*show_devname)(struct seq_file___222 *, struct dentry___247 *);
	int (*show_path)(struct seq_file___222 *, struct dentry___247 *);
	int (*show_stats)(struct seq_file___222 *, struct dentry___247 *);
	ssize_t (*quota_read)(struct super_block___247 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___247 *, int, const char *, size_t, loff_t);
	struct dquot___247 ** (*get_dquots)(struct inode___247 *);
	long int (*nr_cached_objects)(struct super_block___247 *, struct shrink_control___114 *);
	long int (*free_cached_objects)(struct super_block___247 *, struct shrink_control___114 *);
	struct file___247 * (*real_loop)(struct file___247 *);
};

struct block_device___143 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___247 *bd_inode;
	struct super_block___247 *bd_super;
	void *bd_claiming;
	struct device___228 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___235 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___143 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___247 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___178)(struct file___247 *, wait_queue_head_t *, struct poll_table_struct___170 *);

struct poll_table_struct___170 {
	poll_queue_proc___178 _qproc;
	__poll_t _key;
};

struct seq_operations___222;

struct seq_file___222 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___222 *op;
	int poll_event;
	const struct file___247 *file;
	void *private;
};

typedef void bio_end_io_t___140(struct bio___140 *);

struct bio_integrity_payload___140;

struct bio___140 {
	struct bio___140 *bi_next;
	struct block_device___143 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___140 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___128 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___140 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___164 *bi_io_vec;
	struct bio_set___140 *bi_pool;
	struct bio_vec___164 bi_inline_vecs[0];
};

struct dev_pagemap_ops___242 {
	void (*page_free)(struct page___252 *);
	void (*kill)(struct dev_pagemap___242 *);
	void (*cleanup)(struct dev_pagemap___242 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___242 *);
};

struct fwnode_operations___224;

struct fwnode_handle___224 {
	struct fwnode_handle___224 *secondary;
	const struct fwnode_operations___224 *ops;
	struct device___228 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___224;

struct fwnode_endpoint___224;

struct fwnode_operations___224 {
	struct fwnode_handle___224 * (*get)(struct fwnode_handle___224 *);
	void (*put)(struct fwnode_handle___224 *);
	bool (*device_is_available)(const struct fwnode_handle___224 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___224 *, const struct device___228 *);
	bool (*property_present)(const struct fwnode_handle___224 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___224 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___224 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___224 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*get_parent)(const struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*get_next_child_node)(const struct fwnode_handle___224 *, struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*get_named_child_node)(const struct fwnode_handle___224 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___224 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___224 *);
	struct fwnode_handle___224 * (*graph_get_next_endpoint)(const struct fwnode_handle___224 *, struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*graph_get_remote_endpoint)(const struct fwnode_handle___224 *);
	struct fwnode_handle___224 * (*graph_get_port_parent)(struct fwnode_handle___224 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___224 *, struct fwnode_endpoint___224 *);
	int (*add_links)(struct fwnode_handle___224 *);
};

struct fwnode_endpoint___224 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___224 *local_fwnode;
};

struct fwnode_reference_args___224 {
	struct fwnode_handle___224 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___235;

struct kernfs_elem_dir___235 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___235 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___235;

struct kernfs_root___235 {
	struct kernfs_node___235 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___235 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___235 {
	struct kernfs_node___235 *target_kn;
};

struct kernfs_ops___235;

struct kernfs_elem_attr___235 {
	const struct kernfs_ops___235 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___235 *notify_next;
};

struct kernfs_node___235 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___235 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___235 dir;
		struct kernfs_elem_symlink___235 symlink;
		struct kernfs_elem_attr___235 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___235;

struct kernfs_ops___235 {
	int (*open)(struct kernfs_open_file___235 *);
	void (*release)(struct kernfs_open_file___235 *);
	int (*seq_show)(struct seq_file___222 *, void *);
	void * (*seq_start)(struct seq_file___222 *, loff_t *);
	void * (*seq_next)(struct seq_file___222 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___222 *, void *);
	ssize_t (*read)(struct kernfs_open_file___235 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___235 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___235 *, struct poll_table_struct___170 *);
	int (*mmap)(struct kernfs_open_file___235 *, struct vm_area_struct___252 *);
};

struct kernfs_syscall_ops___235 {
	int (*show_options)(struct seq_file___222 *, struct kernfs_root___235 *);
	int (*mkdir)(struct kernfs_node___235 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___235 *);
	int (*rename)(struct kernfs_node___235 *, struct kernfs_node___235 *, const char *);
	int (*show_path)(struct seq_file___222 *, struct kernfs_node___235 *, struct kernfs_root___235 *);
};

struct kernfs_open_file___235 {
	struct kernfs_node___235 *kn;
	struct file___247 *file;
	struct seq_file___222 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___242 *vm_ops;
};

struct kobj_ns_type_operations___45 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___45 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___235;

struct attribute_group___235 {
	const char *name;
	umode_t (*is_visible)(struct kobject___235 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___235 *, struct bin_attribute___235 *, int);
	struct attribute **attrs;
	struct bin_attribute___235 **bin_attrs;
};

struct bin_attribute___235 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___247 * (*f_mapping)();
	ssize_t (*read)(struct file___247 *, struct kobject___235 *, struct bin_attribute___235 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___247 *, struct kobject___235 *, struct bin_attribute___235 *, char *, loff_t, size_t);
	int (*mmap)(struct file___247 *, struct kobject___235 *, struct bin_attribute___235 *, struct vm_area_struct___252 *);
};

struct sysfs_ops___235 {
	ssize_t (*show)(struct kobject___235 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___235 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___235;

struct kset___235 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___235 kobj;
	const struct kset_uevent_ops___235 *uevent_ops;
};

struct kobj_type___235 {
	void (*release)(struct kobject___235 *);
	const struct sysfs_ops___235 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___235 **default_groups;
	const struct kobj_ns_type_operations___45 * (*child_ns_type)(struct kobject___235 *);
	const void * (*namespace)(struct kobject___235 *);
	void (*get_ownership)(struct kobject___235 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___235 {
	int (* const filter)(struct kset___235 *, struct kobject___235 *);
	const char * (* const name)(struct kset___235 *, struct kobject___235 *);
	int (* const uevent)(struct kset___235 *, struct kobject___235 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___231 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___231 *);
	int (*get)(char *, const struct kernel_param___231 *);
	void (*free)(void *);
};

struct kparam_array___231;

struct kernel_param___231 {
	const char *name;
	struct module___231 *mod;
	const struct kernel_param_ops___231 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___231 *arr;
	};
};

struct kparam_array___231 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___231 *ops;
	void *elem;
};

struct module_attribute___231 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___231 *, struct module_kobject___232 *, char *);
	ssize_t (*store)(struct module_attribute___231 *, struct module_kobject___232 *, const char *, size_t);
	void (*setup)(struct module___231 *, const char *);
	int (*test)(struct module___231 *);
	void (*free)(struct module___231 *);
};

struct cgroup_namespace___174 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___174 *root_cset;
};

struct compat_ifconf {
	compat_int_t ifc_len;
	compat_caddr_t ifcbuf;
};

struct socket_wq___46 {
	wait_queue_head_t wait;
	struct fasync_struct___247 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___46;

struct socket___47 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___247 *file;
	struct sock___45 *sk;
	const struct proto_ops___46 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___46 wq;
};

typedef int (*sk_read_actor_t___45)(read_descriptor_t *, struct sk_buff___57 *, unsigned int, size_t);

struct proto_ops___46 {
	int family;
	struct module___231 *owner;
	int (*release)(struct socket___47 *);
	int (*bind)(struct socket___47 *, struct sockaddr *, int);
	int (*connect)(struct socket___47 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___47 *, struct socket___47 *);
	int (*accept)(struct socket___47 *, struct socket___47 *, int, bool);
	int (*getname)(struct socket___47 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___247 *, struct socket___47 *, struct poll_table_struct___170 *);
	int (*ioctl)(struct socket___47 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___47 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___47 *, void *, bool, bool);
	int (*listen)(struct socket___47 *, int);
	int (*shutdown)(struct socket___47 *, int);
	int (*setsockopt)(struct socket___47 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___47 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___222 *, struct socket___47 *);
	int (*sendmsg)(struct socket___47 *, struct msghdr___47 *, size_t);
	int (*recvmsg)(struct socket___47 *, struct msghdr___47 *, size_t, int);
	int (*mmap)(struct file___247 *, struct socket___47 *, struct vm_area_struct___252 *);
	ssize_t (*sendpage)(struct socket___47 *, struct page___252 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___47 *, loff_t *, struct pipe_inode_info___88 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___45 *, int);
	int (*peek_len)(struct socket___47 *);
	int (*read_sock)(struct sock___45 *, read_descriptor_t *, sk_read_actor_t___45);
	int (*sendpage_locked)(struct sock___45 *, struct page___252 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___45 *, struct msghdr___47 *, size_t);
	int (*set_rcvlowat)(struct sock___45 *, int);
};

struct dev_pm_ops___228 {
	int (*prepare)(struct device___228 *);
	void (*complete)(struct device___228 *);
	int (*suspend)(struct device___228 *);
	int (*resume)(struct device___228 *);
	int (*freeze)(struct device___228 *);
	int (*thaw)(struct device___228 *);
	int (*poweroff)(struct device___228 *);
	int (*restore)(struct device___228 *);
	int (*suspend_late)(struct device___228 *);
	int (*resume_early)(struct device___228 *);
	int (*freeze_late)(struct device___228 *);
	int (*thaw_early)(struct device___228 *);
	int (*poweroff_late)(struct device___228 *);
	int (*restore_early)(struct device___228 *);
	int (*suspend_noirq)(struct device___228 *);
	int (*resume_noirq)(struct device___228 *);
	int (*freeze_noirq)(struct device___228 *);
	int (*thaw_noirq)(struct device___228 *);
	int (*poweroff_noirq)(struct device___228 *);
	int (*restore_noirq)(struct device___228 *);
	int (*runtime_suspend)(struct device___228 *);
	int (*runtime_resume)(struct device___228 *);
	int (*runtime_idle)(struct device___228 *);
};

struct wakeup_source___228 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___228 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___228 {
	struct dev_pm_ops___228 ops;
	int (*start)(struct device___228 *);
	void (*detach)(struct device___228 *, bool);
	int (*activate)(struct device___228 *);
	void (*sync)(struct device___228 *);
	void (*dismiss)(struct device___228 *);
};

struct bus_type___228 {
	const char *name;
	const char *dev_name;
	struct device___228 *dev_root;
	const struct attribute_group___235 **bus_groups;
	const struct attribute_group___235 **dev_groups;
	const struct attribute_group___235 **drv_groups;
	int (*match)(struct device___228 *, struct device_driver___228 *);
	int (*uevent)(struct device___228 *, struct kobj_uevent_env *);
	int (*probe)(struct device___228 *);
	void (*sync_state)(struct device___228 *);
	void (*remove)(struct device___228 *);
	void (*shutdown)(struct device___228 *);
	int (*online)(struct device___228 *);
	int (*offline)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	int (*num_vf)(struct device___228 *);
	int (*dma_configure)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___228 {
	const char *name;
	struct bus_type___228 *bus;
	struct module___231 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___228 *);
	void (*sync_state)(struct device___228 *);
	int (*remove)(struct device___228 *);
	void (*shutdown)(struct device___228 *);
	int (*suspend)(struct device___228 *, pm_message_t);
	int (*resume)(struct device___228 *);
	const struct attribute_group___235 **groups;
	const struct attribute_group___235 **dev_groups;
	const struct dev_pm_ops___228 *pm;
	void (*coredump)(struct device___228 *);
	struct driver_private *p;
};

struct device_type___228 {
	const char *name;
	const struct attribute_group___235 **groups;
	int (*uevent)(struct device___228 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___228 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___228 *);
	const struct dev_pm_ops___228 *pm;
};

struct class___228 {
	const char *name;
	struct module___231 *owner;
	const struct attribute_group___235 **class_groups;
	const struct attribute_group___235 **dev_groups;
	struct kobject___235 *dev_kobj;
	int (*dev_uevent)(struct device___228 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___228 *, umode_t *);
	void (*class_release)(struct class___228 *);
	void (*dev_release)(struct device___228 *);
	int (*shutdown_pre)(struct device___228 *);
	const struct kobj_ns_type_operations___45 *ns_type;
	const void * (*namespace)(struct device___228 *);
	void (*get_ownership)(struct device___228 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___228 *pm;
	struct subsys_private *p;
};

struct property___76;

struct device_node___102 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___224 fwnode;
	struct property___76 *properties;
	struct property___76 *deadprops;
	struct device_node___102 *parent;
	struct device_node___102 *child;
	struct device_node___102 *sibling;
	struct kobject___235 kobj;
	long unsigned int _flags;
	void *data;
};

struct pipe_buf_operations___88;

struct pipe_buffer___88 {
	struct page___252 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___88 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___88 {
	int (*confirm)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
	void (*release)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
	bool (*try_steal)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
	bool (*get)(struct pipe_inode_info___88 *, struct pipe_buffer___88 *);
};

struct seq_operations___222 {
	void * (*start)(struct seq_file___222 *, loff_t *);
	void (*stop)(struct seq_file___222 *, void *);
	void * (*next)(struct seq_file___222 *, void *, loff_t *);
	int (*show)(struct seq_file___222 *, void *);
};

struct dcbnl_rtnl_ops___56 {
	int (*ieee_getets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___56 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___56 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___56 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___56 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___56 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___56 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___56 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___56 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___56 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___56 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___56 *);
	u8 (*setstate)(struct net_device___56 *, u8);
	void (*getpermhwaddr)(struct net_device___56 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___56 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___56 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___56 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___56 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___56 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___56 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___56 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___56 *, int, u8 *);
	void (*setpfccfg)(struct net_device___56 *, int, u8);
	void (*getpfccfg)(struct net_device___56 *, int, u8 *);
	u8 (*setall)(struct net_device___56 *);
	u8 (*getcap)(struct net_device___56 *, int, u8 *);
	int (*getnumtcs)(struct net_device___56 *, int, u8 *);
	int (*setnumtcs)(struct net_device___56 *, int, u8);
	u8 (*getpfcstate)(struct net_device___56 *);
	void (*setpfcstate)(struct net_device___56 *, u8);
	void (*getbcncfg)(struct net_device___56 *, int, u32 *);
	void (*setbcncfg)(struct net_device___56 *, int, u32);
	void (*getbcnrp)(struct net_device___56 *, int, u8 *);
	void (*setbcnrp)(struct net_device___56 *, int, u8);
	int (*setapp)(struct net_device___56 *, u8, u16, u8);
	int (*getapp)(struct net_device___56 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___56 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___56 *, int, u8);
	u8 (*getdcbx)(struct net_device___56 *);
	u8 (*setdcbx)(struct net_device___56 *, u8);
	int (*peer_getappinfo)(struct net_device___56 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___56 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___56 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___56 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___56 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___56 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___59;

typedef int (*bpf_iter_init_seq_priv_t___58)(void *, struct bpf_iter_aux_info___59 *);

struct bpf_map___59;

struct bpf_iter_aux_info___59 {
	struct bpf_map___59 *map;
};

struct bpf_iter_seq_info___58 {
	const struct seq_operations___222 *seq_ops;
	bpf_iter_init_seq_priv_t___58 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___58 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___59 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___59 *, struct file___247 *);
	void (*map_free)(struct bpf_map___59 *);
	int (*map_get_next_key)(struct bpf_map___59 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___59 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___59 *, void *);
	int (*map_lookup_batch)(struct bpf_map___59 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___59 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___59 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___59 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___59 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___59 *, void *);
	int (*map_update_elem)(struct bpf_map___59 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___59 *, void *);
	int (*map_push_elem)(struct bpf_map___59 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___59 *, void *);
	int (*map_peek_elem)(struct bpf_map___59 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___59 *, struct file___247 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___59 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___59 *, void *, struct seq_file___222 *);
	int (*map_check_btf)(const struct bpf_map___59 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___59 *, struct bpf_prog_aux___59 *);
	void (*map_poke_untrack)(struct bpf_map___59 *, struct bpf_prog_aux___59 *);
	void (*map_poke_run)(struct bpf_map___59 *, u32, struct bpf_prog___52 *, struct bpf_prog___52 *);
	int (*map_direct_value_addr)(const struct bpf_map___59 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___59 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___59 *, struct vm_area_struct___252 *);
	__poll_t (*map_poll)(struct bpf_map___59 *, struct file___247 *, struct poll_table_struct___170 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___59 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___59 *, const struct bpf_map___59 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___59 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___58 *iter_seq_info;
};

struct bpf_map___59 {
	const struct bpf_map_ops___58 *ops;
	struct bpf_map___59 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___114 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___58;

struct bpf_jit_poke_descriptor___58;

struct bpf_prog_ops___52;

struct btf_mod_pair___58;

struct bpf_prog_offload___56;

struct bpf_prog_aux___59 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___52 *dst_prog;
	struct bpf_trampoline___58 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___52 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___58 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___52 *ops;
	struct bpf_map___59 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___58 *used_btfs;
	struct bpf_prog___52 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___59 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___56 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___56;

struct bpf_map_dev_ops___56 {
	int (*map_get_next_key)(struct bpf_offloaded_map___56 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___56 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___56 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___56 *, void *);
};

struct bpf_offloaded_map___56 {
	struct bpf_map___59 map;
	struct net_device___56 *netdev;
	const struct bpf_map_dev_ops___56 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___52 {
	int (*test_run)(struct bpf_prog___52 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___56 {
	struct bpf_prog___52 *prog;
	struct net_device___56 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___58 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___52 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___231 *mod;
};

struct bpf_jit_poke_descriptor___58 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___59 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___58 {
	struct btf *btf;
	struct module___231 *module;
};

struct cftype___174;

struct cgroup_subsys___174 {
	struct cgroup_subsys_state___174 * (*css_alloc)(struct cgroup_subsys_state___174 *);
	int (*css_online)(struct cgroup_subsys_state___174 *);
	void (*css_offline)(struct cgroup_subsys_state___174 *);
	void (*css_released)(struct cgroup_subsys_state___174 *);
	void (*css_free)(struct cgroup_subsys_state___174 *);
	void (*css_reset)(struct cgroup_subsys_state___174 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___174 *, int);
	int (*css_extra_stat_show)(struct seq_file___222 *, struct cgroup_subsys_state___174 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___254 *, struct css_set___174 *);
	void (*cancel_fork)(struct task_struct___254 *, struct css_set___174 *);
	void (*fork)(struct task_struct___254 *);
	void (*exit)(struct task_struct___254 *);
	void (*release)(struct task_struct___254 *);
	void (*bind)(struct cgroup_subsys_state___174 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___174 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___174 *dfl_cftypes;
	struct cftype___174 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___174 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___174 *updated_children;
	struct cgroup___174 *updated_next;
};

struct cgroup_root___174 {
	struct kernfs_root___235 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___174 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___174 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___174 *ss;
	struct list_head node;
	struct kernfs_ops___235 *kf_ops;
	int (*open)(struct kernfs_open_file___235 *);
	void (*release)(struct kernfs_open_file___235 *);
	u64 (*read_u64)(struct cgroup_subsys_state___174 *, struct cftype___174 *);
	s64 (*read_s64)(struct cgroup_subsys_state___174 *, struct cftype___174 *);
	int (*seq_show)(struct seq_file___222 *, void *);
	void * (*seq_start)(struct seq_file___222 *, loff_t *);
	void * (*seq_next)(struct seq_file___222 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___222 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___174 *, struct cftype___174 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___174 *, struct cftype___174 *, s64);
	ssize_t (*write)(struct kernfs_open_file___235 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___235 *, struct poll_table_struct___170 *);
};

struct xdp_rxq_info___56 {
	struct net_device___56 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___56 {
	struct net_device___56 *dev;
};

struct xdp_buff___56 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___56 *rxq;
	struct xdp_txq_info___56 *txq;
	u32 frame_sz;
};

struct xdp_frame___56 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___56 *dev_rx;
};

struct netlink_callback___56 {
	struct sk_buff___57 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___57 *, struct netlink_callback___56 *);
	int (*done)(struct netlink_callback___56 *);
	void *data;
	struct module___231 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___56 {
	int (*create)(struct sk_buff___57 *, struct net_device___56 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___57 *, unsigned char *);
	int (*cache)(const struct neighbour___45 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___56 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___57 *);
};

struct netdev_queue___56 {
	struct net_device___56 *dev;
	struct Qdisc___52 *qdisc;
	struct Qdisc___52 *qdisc_sleeping;
	struct kobject___235 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___56 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___52 {
	struct sk_buff___57 *head;
	struct sk_buff___57 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___52;

struct Qdisc___52 {
	int (*enqueue)(struct sk_buff___57 *, struct Qdisc___52 *, struct sk_buff___57 **);
	struct sk_buff___57 * (*dequeue)(struct Qdisc___52 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___52 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___56 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___56 gso_skb;
	struct qdisc_skb_head___52 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___52 *next_sched;
	struct sk_buff_head___56 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___56 {
	struct xdp_rxq_info___56 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___235 kobj;
	struct net_device___56 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___56 {
	enum net_device_path_type type;
	const struct net_device___56 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___56 = 0,
				DEV_PATH_BR_VLAN_TAG___56 = 1,
				DEV_PATH_BR_VLAN_UNTAG___56 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___56 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___56 {
	const struct net_device___56 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___56 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___52 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___56 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___56 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___57 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___56 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___56 *dev;
	const char *name;
};

struct devlink_port___4;

struct net_device_ops___56 {
	int (*ndo_init)(struct net_device___56 *);
	void (*ndo_uninit)(struct net_device___56 *);
	int (*ndo_open)(struct net_device___56 *);
	int (*ndo_stop)(struct net_device___56 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___57 *, struct net_device___56 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___57 *, struct net_device___56 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___56 *, struct sk_buff___57 *, struct net_device___56 *);
	void (*ndo_change_rx_flags)(struct net_device___56 *, int);
	void (*ndo_set_rx_mode)(struct net_device___56 *);
	int (*ndo_set_mac_address)(struct net_device___56 *, void *);
	int (*ndo_validate_addr)(struct net_device___56 *);
	int (*ndo_do_ioctl)(struct net_device___56 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___56 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___56 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___56 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___56 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___56 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___56 *, int);
	int (*ndo_neigh_setup)(struct net_device___56 *, struct neigh_parms___45 *);
	void (*ndo_tx_timeout)(struct net_device___56 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___56 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___56 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___56 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___56 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___56 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___56 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___56 *);
	int (*ndo_netpoll_setup)(struct net_device___56 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___56 *);
	int (*ndo_set_vf_mac)(struct net_device___56 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___56 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___56 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___56 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___56 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___56 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___56 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___56 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___56 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___56 *, int, struct sk_buff___57 *);
	int (*ndo_get_vf_guid)(struct net_device___56 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___56 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___56 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___56 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___56 *);
	int (*ndo_fcoe_disable)(struct net_device___56 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___56 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___56 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___56 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___56 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___56 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___56 *, const struct sk_buff___57 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___56 *, struct net_device___56 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___56 *, struct net_device___56 *);
	struct net_device___56 * (*ndo_get_xmit_slave)(struct net_device___56 *, struct sk_buff___57 *, bool);
	struct net_device___56 * (*ndo_sk_get_lower_dev)(struct net_device___56 *, struct sock___45 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___56 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___56 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___56 *, struct neighbour___45 *);
	void (*ndo_neigh_destroy)(struct net_device___56 *, struct neighbour___45 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___57 *, struct netlink_callback___56 *, struct net_device___56 *, struct net_device___56 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___57 *, struct nlattr **, struct net_device___56 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___56 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___57 *, u32, u32, struct net_device___56 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___56 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___56 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___56 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___56 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___56 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___56 *, struct net_device___56 *);
	void (*ndo_dfwd_del_station)(struct net_device___56 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___56 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___56 *);
	int (*ndo_change_proto_down)(struct net_device___56 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___56 *, struct sk_buff___57 *);
	void (*ndo_set_rx_headroom)(struct net_device___56 *, int);
	int (*ndo_bpf)(struct net_device___56 *, struct netdev_bpf___56 *);
	int (*ndo_xdp_xmit)(struct net_device___56 *, int, struct xdp_frame___56 **, u32);
	struct net_device___56 * (*ndo_xdp_get_xmit_slave)(struct net_device___56 *, struct xdp_buff___56 *);
	int (*ndo_xsk_wakeup)(struct net_device___56 *, u32, u32);
	struct devlink_port___4 * (*ndo_get_devlink_port)(struct net_device___56 *);
	int (*ndo_tunnel_ctl)(struct net_device___56 *, struct ip_tunnel_parm *, int);
	struct net_device___56 * (*ndo_get_peer_dev)(struct net_device___56 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___56 *, struct net_device_path___56 *);
};

struct neigh_parms___45 {
	possible_net_t___56 net;
	struct net_device___56 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___45 *);
	struct neigh_table___45 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct devlink___4;

struct devlink_rate___4;

struct devlink_port___4 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___4 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set;
	u8 switch_port;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___4 *devlink_rate;
};

typedef int (*iw_handler___3)(struct net_device___56 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___3 {
	const iw_handler___3 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___3 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___56 *);
};

struct ethtool_ops___25 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___56 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___56 *);
	void (*get_regs)(struct net_device___56 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___56 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___56 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___56 *);
	void (*set_msglevel)(struct net_device___56 *, u32);
	int (*nway_reset)(struct net_device___56 *);
	u32 (*get_link)(struct net_device___56 *);
	int (*get_link_ext_state)(struct net_device___56 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___56 *);
	int (*get_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___56 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___56 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___56 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___56 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___56 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___56 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___56 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___56 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___56 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___56 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___56 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___56 *);
	void (*complete)(struct net_device___56 *);
	u32 (*get_priv_flags)(struct net_device___56 *);
	int (*set_priv_flags)(struct net_device___56 *, u32);
	int (*get_sset_count)(struct net_device___56 *, int);
	int (*get_rxnfc)(struct net_device___56 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___56 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___56 *, struct ethtool_flash *);
	int (*reset)(struct net_device___56 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___56 *);
	u32 (*get_rxfh_indir_size)(struct net_device___56 *);
	int (*get_rxfh)(struct net_device___56 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___56 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___56 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___56 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___56 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___56 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___56 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___56 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___56 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___56 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___56 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___56 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___56 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___56 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___56 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___56 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___56 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___56 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___56 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___56 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___56 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___56 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___56 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___56 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___56 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___56 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___56 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___56 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___56 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___56 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___56 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___45 {
	u32 (*l3mdev_fib_table)(const struct net_device___56 *);
	struct sk_buff___57 * (*l3mdev_l3_rcv)(struct net_device___56 *, struct sk_buff___57 *, u16);
	struct sk_buff___57 * (*l3mdev_l3_out)(struct net_device___56 *, struct sock___45 *, struct sk_buff___57 *, u16);
	struct dst_entry___45 * (*l3mdev_link_scope_lookup)(const struct net_device___56 *, struct flowi6 *);
};

struct ndisc_ops___32 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___56 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___56 *, struct neighbour___45 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___56 *, u8, struct neighbour___45 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___56 *, struct sk_buff___57 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___61 *, struct net_device___56 *, const struct prefix_info *, struct inet6_dev___32 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct phylink_config___4 {
	struct device___228 *dev;
	enum phylink_op_type type;
	bool pcs_poll;
	bool poll_fixed_state;
	bool ovr_an_inband;
	void (*get_fixed_state)(struct phylink_config___4 *, struct phylink_link_state *);
};

struct dsa_device_ops___4;

struct dsa_switch_tree___4;

struct dsa_switch___4;

struct dsa_netdevice_ops___4;

struct dsa_port___4 {
	union {
		struct net_device___56 *master;
		struct net_device___56 *slave;
	};
	const struct dsa_device_ops___4 *tag_ops;
	struct dsa_switch_tree___4 *dst;
	struct sk_buff___57 * (*rcv)(struct sk_buff___57 *, struct net_device___56 *);
	enum {
		DSA_PORT_TYPE_UNUSED___4 = 0,
		DSA_PORT_TYPE_CPU___4 = 1,
		DSA_PORT_TYPE_DSA___4 = 2,
		DSA_PORT_TYPE_USER___4 = 3,
	} type;
	struct dsa_switch___4 *ds;
	unsigned int index;
	const char *name;
	struct dsa_port___4 *cpu_dp;
	u8 mac[6];
	struct device_node___102 *dn;
	unsigned int ageing_time;
	bool vlan_filtering;
	bool learning;
	u8 stp_state;
	struct net_device___56 *bridge_dev;
	int bridge_num;
	struct devlink_port___4 devlink_port;
	bool devlink_port_setup;
	struct phylink *pl;
	struct phylink_config___4 pl_config;
	struct net_device___56 *lag_dev;
	bool lag_tx_enabled;
	struct net_device___56 *hsr_dev;
	struct list_head list;
	void *priv;
	const struct ethtool_ops___25 *orig_ethtool_ops;
	const struct dsa_netdevice_ops___4 *netdev_ops;
	struct list_head fdbs;
	struct list_head mdbs;
	bool setup;
};

struct in_ifaddr___3;

struct in_device___3 {
	struct net_device___56 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___3 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___45 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___32;

struct inet6_dev___32 {
	struct net_device___56 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___32 *mc_list;
	struct ifmcaddr6___32 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___56 mc_query_queue;
	struct sk_buff_head___56 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___8 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___45 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___52;

struct tcf_block___52;

struct mini_Qdisc___52 {
	struct tcf_proto___52 *filter_list;
	struct tcf_block___52 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___52 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___56 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___56 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___61 *, struct net_device___56 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___56 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___56 *, struct list_head *);
	size_t (*get_size)(const struct net_device___56 *);
	int (*fill_info)(struct sk_buff___57 *, const struct net_device___56 *);
	size_t (*get_xstats_size)(const struct net_device___56 *);
	int (*fill_xstats)(struct sk_buff___57 *, const struct net_device___56 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___56 *, struct net_device___56 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___56 *, const struct net_device___56 *);
	int (*fill_slave_info)(struct sk_buff___57 *, const struct net_device___56 *, const struct net_device___56 *);
	struct net___61 * (*get_link_net)(const struct net_device___56 *);
	size_t (*get_linkxstats_size)(const struct net_device___56 *, int);
	int (*fill_linkxstats)(struct sk_buff___57 *, const struct net_device___56 *, int *, int);
};

struct mii_bus___12;

struct mdio_device___12 {
	struct device___228 dev;
	struct mii_bus___12 *bus;
	char modalias[32];
	int (*bus_match)(struct device___228 *, struct device_driver___228 *);
	void (*device_free)(struct mdio_device___12 *);
	void (*device_remove)(struct mdio_device___12 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___9;

struct mii_timestamper___9;

struct phy_device___9 {
	struct mdio_device___12 mdio;
	struct phy_driver___9 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45;
	unsigned int is_internal;
	unsigned int is_pseudo_fixed_link;
	unsigned int is_gigabit_capable;
	unsigned int has_fixups;
	unsigned int suspended;
	unsigned int suspended_by_mdio_bus;
	unsigned int sysfs_links;
	unsigned int loopback_enabled;
	unsigned int downshifted_rate;
	unsigned int is_on_sfp_module;
	unsigned int mac_managed_pm;
	unsigned int autoneg;
	unsigned int link;
	unsigned int autoneg_complete;
	unsigned int interrupts;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___57 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___56 *attached_dev;
	struct mii_timestamper___9 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___9 *, bool);
	void (*adjust_link)(struct net_device___56 *);
	const struct macsec_ops *macsec_ops;
};

struct netdev_notifier_info___8 {
	struct net_device___56 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_changeupper_info___4 {
	struct netdev_notifier_info___8 info;
	struct net_device___56 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct in_ifaddr___3 {
	struct hlist_node hash;
	struct in_ifaddr___3 *ifa_next;
	struct in_device___3 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct property___76 {
	char *name;
	int length;
	void *value;
	struct property___76 *next;
	long unsigned int _flags;
	struct bin_attribute___235 attr;
};

struct flow_action_entry___4 {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___56 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action___4 {
	unsigned int num_entries;
	struct flow_action_entry___4 entries[0];
};

struct flow_rule___4 {
	struct flow_match match;
	struct flow_action___4 action;
};

struct mii_bus___12 {
	struct module___231 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___12 *, int, int);
	int (*write)(struct mii_bus___12 *, int, int, u16);
	int (*reset)(struct mii_bus___12 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___228 *parent;
	enum {
		MDIOBUS_ALLOCATED___12 = 1,
		MDIOBUS_REGISTERED___12 = 2,
		MDIOBUS_UNREGISTERED___12 = 3,
		MDIOBUS_RELEASED___12 = 4,
	} state;
	struct device___228 dev;
	struct mdio_device___12 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___12 = 0,
		MDIOBUS_C22___12 = 1,
		MDIOBUS_C45___12 = 2,
		MDIOBUS_C22_C45___12 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___11 {
	struct device_driver___228 driver;
	int flags;
};

struct mii_timestamper___9 {
	bool (*rxtstamp)(struct mii_timestamper___9 *, struct sk_buff___57 *, int);
	void (*txtstamp)(struct mii_timestamper___9 *, struct sk_buff___57 *, int);
	int (*hwtstamp)(struct mii_timestamper___9 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___9 *, struct phy_device___9 *);
	int (*ts_info)(struct mii_timestamper___9 *, struct ethtool_ts_info *);
	struct device___228 *device;
};

struct phy_driver___9 {
	struct mdio_driver_common___11 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___9 *);
	int (*config_init)(struct phy_device___9 *);
	int (*probe)(struct phy_device___9 *);
	int (*get_features)(struct phy_device___9 *);
	int (*suspend)(struct phy_device___9 *);
	int (*resume)(struct phy_device___9 *);
	int (*config_aneg)(struct phy_device___9 *);
	int (*aneg_done)(struct phy_device___9 *);
	int (*read_status)(struct phy_device___9 *);
	int (*config_intr)(struct phy_device___9 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___9 *);
	void (*remove)(struct phy_device___9 *);
	int (*match_phy_device)(struct phy_device___9 *);
	int (*set_wol)(struct phy_device___9 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___9 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___9 *);
	int (*read_mmd)(struct phy_device___9 *, int, u16);
	int (*write_mmd)(struct phy_device___9 *, int, u16, u16);
	int (*read_page)(struct phy_device___9 *);
	int (*write_page)(struct phy_device___9 *, int);
	int (*module_info)(struct phy_device___9 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___9 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___9 *);
	int (*cable_test_tdr_start)(struct phy_device___9 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___9 *, bool *);
	int (*get_sset_count)(struct phy_device___9 *);
	void (*get_strings)(struct phy_device___9 *, u8 *);
	void (*get_stats)(struct phy_device___9 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___9 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___9 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___9 *, bool);
	int (*get_sqi)(struct phy_device___9 *);
	int (*get_sqi_max)(struct phy_device___9 *);
};

struct dsa_chip_data___4 {
	struct device___228 *host_dev;
	int sw_addr;
	struct device___228 *netdev[12];
	int eeprom_len;
	struct device_node___102 *of_node;
	char *port_names[12];
	struct device_node___102 *port_dn[12];
	s8 rtable[4];
};

struct dsa_platform_data___4 {
	struct device___228 *netdev;
	struct net_device___56 *of_netdev;
	int nr_chips;
	struct dsa_chip_data___4 *chip;
};

struct flow_cls_offload___4 {
	struct flow_cls_common_offload common;
	enum flow_cls_command command;
	long unsigned int cookie;
	struct flow_rule___4 *rule;
	struct flow_stats stats;
	u32 classid;
};

struct devlink_ops___4;

struct devlink___4 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___4 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___228 *dev;
	possible_net_t___56 _net;
	struct mutex lock;
	u8 reload_failed;
	u8 reload_enabled;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_ops___4 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___4 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___4 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___4 *, enum devlink_port_type);
	int (*port_split)(struct devlink___4 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___4 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___4 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___4 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___4 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___4 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___4 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___4 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___4 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___4 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___4 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___4 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___4 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___4 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___4 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___4 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___4 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___4 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___4 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___4 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___4 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___4 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___4 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___4 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___4 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___4 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___4 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___4 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___4 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___4 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___4 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___4 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___4 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___4 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___4 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___4 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___4 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___4 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___4 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___4 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___4 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___4 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___4 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___4 *, struct devlink_rate___4 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___4 *, struct devlink_rate___4 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___4 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___4 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___4 *parent;
	union {
		struct devlink_port___4 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct fib_rule___45 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___45 *ctarget;
	struct net___61 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___45 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___45 *rule;
	u32 table;
	int flags;
};

struct block_device_operations___140;

struct gendisk___143 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___143 *part0;
	const struct block_device_operations___140 *fops;
	struct request_queue___140 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___126 *bdi;
	struct kobject___235 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___235 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___140 {
	struct bio___140 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___164 *bip_vec;
	struct bio_vec___164 bip_inline_vecs[0];
};

struct blkcg___128;

struct blkg_policy_data___128;

struct blkcg_gq___128 {
	struct request_queue___140 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___128 *blkcg;
	struct blkcg_gq___128 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___128 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___140 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___140(struct request___140 *);

typedef void integrity_complete_fn___140(struct request___140 *, unsigned int);

struct blk_integrity_profile___140 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___140 *prepare_fn;
	integrity_complete_fn___140 *complete_fn;
	const char *name;
};

struct block_device_operations___140 {
	blk_qc_t (*submit_bio)(struct bio___140 *);
	int (*open)(struct block_device___143 *, fmode_t);
	void (*release)(struct gendisk___143 *, fmode_t);
	int (*rw_page)(struct block_device___143 *, sector_t, struct page___252 *, unsigned int);
	int (*ioctl)(struct block_device___143 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___143 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___143 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___143 *);
	int (*getgeo)(struct block_device___143 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___143 *, bool);
	void (*swap_slot_free_notify)(struct block_device___143 *, long unsigned int);
	int (*report_zones)(struct gendisk___143 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___143 *, umode_t *);
	struct module___231 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___143 *, sector_t *);
};

typedef void rq_end_io_fn___140(struct request___140 *, blk_status_t);

struct request___140 {
	struct request_queue___140 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___135 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___140 *bio;
	struct bio___140 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___164 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___140 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___140 *saved_end_io;
		} flush;
	};
	struct gendisk___143 *rq_disk;
	struct block_device___143 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___140 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___135 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___140 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___235 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___247 *debugfs_dir;
	struct dentry___247 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___140;

struct elevator_mq_ops___140 {
	int (*init_sched)(struct request_queue___140 *, struct elevator_type___140 *);
	void (*exit_sched)(struct elevator_queue___140 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___135 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___135 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___135 *);
	bool (*allow_merge)(struct request_queue___140 *, struct request___140 *, struct bio___140 *);
	bool (*bio_merge)(struct request_queue___140 *, struct bio___140 *, unsigned int);
	int (*request_merge)(struct request_queue___140 *, struct request___140 **, struct bio___140 *);
	void (*request_merged)(struct request_queue___140 *, struct request___140 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___140 *, struct request___140 *, struct request___140 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___140 *);
	void (*finish_request)(struct request___140 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___135 *, struct list_head *, bool);
	struct request___140 * (*dispatch_request)(struct blk_mq_hw_ctx___135 *);
	bool (*has_work)(struct blk_mq_hw_ctx___135 *);
	void (*completed_request)(struct request___140 *, u64);
	void (*requeue_request)(struct request___140 *);
	struct request___140 * (*former_request)(struct request_queue___140 *, struct request___140 *);
	struct request___140 * (*next_request)(struct request_queue___140 *, struct request___140 *);
	void (*init_icq)(struct io_cq___140 *);
	void (*exit_icq)(struct io_cq___140 *);
};

struct elv_fs_entry___140;

struct elevator_type___140 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___140 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___140 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___231 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___140 {
	struct elevator_type___140 *type;
	void *elevator_data;
	struct kobject___235 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___140 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___140 *, char *);
	ssize_t (*store)(struct elevator_queue___140 *, const char *, size_t);
};

struct blk_mq_queue_data___135;

struct blk_mq_ops___135 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___135 *, const struct blk_mq_queue_data___135 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___135 *);
	int (*get_budget)(struct request_queue___140 *);
	void (*put_budget)(struct request_queue___140 *, int);
	void (*set_rq_budget_token)(struct request___140 *, int);
	int (*get_rq_budget_token)(struct request___140 *);
	enum blk_eh_timer_return (*timeout)(struct request___140 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___135 *);
	void (*complete)(struct request___140 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___135 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___135 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___135 *, struct request___140 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___135 *, struct request___140 *, unsigned int);
	void (*initialize_rq_fn)(struct request___140 *);
	void (*cleanup_rq)(struct request___140 *);
	bool (*busy)(struct request_queue___140 *);
	int (*map_queues)(struct blk_mq_tag_set___135 *);
	void (*show_rq)(struct seq_file___222 *, struct request___140 *);
};

struct blk_mq_tag_set___135 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___135 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___135 {
	struct request___140 *rq;
	bool last;
};

struct blkcg_policy_data___128;

struct blkcg___128 {
	struct cgroup_subsys_state___174 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___128 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___128 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___128 {
	struct blkcg___128 *blkcg;
	int plid;
};

struct blkg_policy_data___128 {
	struct blkcg_gq___128 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___114 {
	struct mem_cgroup___114 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___114 {
	struct lruvec___122 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___114 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___114 *memcg;
};

struct obj_cgroup___114 {
	struct percpu_ref refcnt;
	struct mem_cgroup___114 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___52 {
	spinlock_t *lock;
	struct sk_buff___57 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___52;

struct Qdisc_ops___52 {
	struct Qdisc_ops___52 *next;
	const struct Qdisc_class_ops___52 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___57 *, struct Qdisc___52 *, struct sk_buff___57 **);
	struct sk_buff___57 * (*dequeue)(struct Qdisc___52 *);
	struct sk_buff___57 * (*peek)(struct Qdisc___52 *);
	int (*init)(struct Qdisc___52 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___52 *);
	void (*destroy)(struct Qdisc___52 *);
	int (*change)(struct Qdisc___52 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___52 *);
	int (*change_tx_queue_len)(struct Qdisc___52 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___52 *, unsigned int);
	int (*dump)(struct Qdisc___52 *, struct sk_buff___57 *);
	int (*dump_stats)(struct Qdisc___52 *, struct gnet_dump___52 *);
	void (*ingress_block_set)(struct Qdisc___52 *, u32);
	void (*egress_block_set)(struct Qdisc___52 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___52 *);
	u32 (*egress_block_get)(struct Qdisc___52 *);
	struct module___231 *owner;
};

struct Qdisc_class_ops___52 {
	unsigned int flags;
	struct netdev_queue___56 * (*select_queue)(struct Qdisc___52 *, struct tcmsg *);
	int (*graft)(struct Qdisc___52 *, long unsigned int, struct Qdisc___52 *, struct Qdisc___52 **, struct netlink_ext_ack *);
	struct Qdisc___52 * (*leaf)(struct Qdisc___52 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___52 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___52 *, u32);
	int (*change)(struct Qdisc___52 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___52 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___52 *, struct qdisc_walker *);
	struct tcf_block___52 * (*tcf_block)(struct Qdisc___52 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___52 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___52 *, long unsigned int);
	int (*dump)(struct Qdisc___52 *, long unsigned int, struct sk_buff___57 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___52 *, long unsigned int, struct gnet_dump___52 *);
};

struct tcf_chain___52;

struct tcf_block___52 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___61 *net;
	struct Qdisc___52 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___52 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___52;

struct tcf_proto_ops___52;

struct tcf_proto___52 {
	struct tcf_proto___52 *next;
	void *root;
	int (*classify)(struct sk_buff___57 *, const struct tcf_proto___52 *, struct tcf_result___52 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___52 *ops;
	struct tcf_chain___52 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___52 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___52 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___52 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___57 *, const struct tcf_proto___52 *, struct tcf_result___52 *);
	int (*init)(struct tcf_proto___52 *);
	void (*destroy)(struct tcf_proto___52 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___52 *, u32);
	void (*put)(struct tcf_proto___52 *, void *);
	int (*change)(struct net___61 *, struct sk_buff___57 *, struct tcf_proto___52 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___52 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___52 *);
	void (*walk)(struct tcf_proto___52 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___52 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___52 *, void *);
	void (*hw_del)(struct tcf_proto___52 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___61 *, struct tcf_chain___52 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___61 *, struct tcf_proto___52 *, void *, struct sk_buff___57 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___61 *, struct tcf_proto___52 *, void *, struct sk_buff___57 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___57 *, struct net___61 *, void *);
	struct module___231 *owner;
	int flags;
};

struct tcf_chain___52 {
	struct mutex filter_chain_lock;
	struct tcf_proto___52 *filter_chain;
	struct list_head list;
	struct tcf_block___52 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___52 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___45 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___52 *prog;
};

struct pneigh_entry___45;

struct neigh_hash_table___45;

struct neigh_table___45 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___56 *, __u32 *);
	bool (*key_eq)(const struct neighbour___45 *, const void *);
	int (*constructor)(struct neighbour___45 *);
	int (*pconstructor)(struct pneigh_entry___45 *);
	void (*pdestructor)(struct pneigh_entry___45 *);
	void (*proxy_redo)(struct sk_buff___57 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___56 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___45 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___56 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___45 *nht;
	struct pneigh_entry___45 **phash_buckets;
};

struct neigh_ops___45 {
	int family;
	void (*solicit)(struct neighbour___45 *, struct sk_buff___57 *);
	void (*error_report)(struct neighbour___45 *, struct sk_buff___57 *);
	int (*output)(struct neighbour___45 *, struct sk_buff___57 *);
	int (*connected_output)(struct neighbour___45 *, struct sk_buff___57 *);
};

struct pneigh_entry___45 {
	struct pneigh_entry___45 *next;
	possible_net_t___56 net;
	struct net_device___56 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___45 {
	struct neighbour___45 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct request_sock_ops___34;

struct timewait_sock_ops___34;

struct proto___45 {
	void (*close)(struct sock___45 *, long int);
	int (*pre_connect)(struct sock___45 *, struct sockaddr *, int);
	int (*connect)(struct sock___45 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___45 *, int);
	struct sock___45 * (*accept)(struct sock___45 *, int, int *, bool);
	int (*ioctl)(struct sock___45 *, int, long unsigned int);
	int (*init)(struct sock___45 *);
	void (*destroy)(struct sock___45 *);
	void (*shutdown)(struct sock___45 *, int);
	int (*setsockopt)(struct sock___45 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___45 *, int, int, char *, int *);
	void (*keepalive)(struct sock___45 *, int);
	int (*compat_ioctl)(struct sock___45 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___45 *, struct msghdr___47 *, size_t);
	int (*recvmsg)(struct sock___45 *, struct msghdr___47 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___45 *, struct page___252 *, int, size_t, int);
	int (*bind)(struct sock___45 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___45 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___45 *, struct sk_buff___57 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___45 *);
	int (*hash)(struct sock___45 *);
	void (*unhash)(struct sock___45 *);
	void (*rehash)(struct sock___45 *);
	int (*get_port)(struct sock___45 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___45 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___45 *, int);
	bool (*sock_is_readable)(struct sock___45 *);
	void (*enter_memory_pressure)(struct sock___45 *);
	void (*leave_memory_pressure)(struct sock___45 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___34 *rsk_prot;
	struct timewait_sock_ops___34 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___231 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___45 *, int);
};

struct request_sock___35;

struct request_sock_ops___34 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___45 *, struct request_sock___35 *);
	void (*send_ack)(const struct sock___45 *, struct sk_buff___57 *, struct request_sock___35 *);
	void (*send_reset)(const struct sock___45 *, struct sk_buff___57 *);
	void (*destructor)(struct request_sock___35 *);
	void (*syn_ack_timeout)(const struct request_sock___35 *);
};

struct timewait_sock_ops___34 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___45 *, struct sock___45 *, void *);
	void (*twsk_destructor)(struct sock___45 *);
};

struct request_sock___35 {
	struct sock_common___45 __req_common;
	struct request_sock___35 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___34 *rsk_ops;
	struct sock___45 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___32 {
	struct in6_addr mca_addr;
	struct inet6_dev___32 *idev;
	struct ifmcaddr6___32 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct switchdev_obj___4 {
	struct list_head list;
	struct net_device___56 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___56 *, int, void *);
};

struct switchdev_obj_port_vlan___4 {
	struct switchdev_obj___4 obj;
	u16 flags;
	u16 vid;
};

struct switchdev_obj_port_mdb___4 {
	struct switchdev_obj___4 obj;
	unsigned char addr[6];
	u16 vid;
};

struct switchdev_obj_mrp___4 {
	struct switchdev_obj___4 obj;
	struct net_device___56 *p_port;
	struct net_device___56 *s_port;
	u32 ring_id;
	u16 prio;
};

struct switchdev_obj_ring_role_mrp___4 {
	struct switchdev_obj___4 obj;
	u8 ring_role;
	u32 ring_id;
	u8 sw_backup;
};

struct dsa_device_ops___4 {
	struct sk_buff___57 * (*xmit)(struct sk_buff___57 *, struct net_device___56 *);
	struct sk_buff___57 * (*rcv)(struct sk_buff___57 *, struct net_device___56 *);
	void (*flow_dissect)(const struct sk_buff___57 *, __be16 *, int *);
	unsigned int needed_headroom;
	unsigned int needed_tailroom;
	const char *name;
	enum dsa_tag_protocol proto;
	bool promisc_on_master;
};

struct dsa_netdevice_ops___4 {
	int (*ndo_eth_ioctl)(struct net_device___56 *, struct ifreq *, int);
};

struct dsa_switch_tree___4 {
	struct list_head list;
	struct raw_notifier_head nh;
	unsigned int index;
	struct kref refcount;
	bool setup;
	const struct dsa_device_ops___4 *tag_ops;
	enum dsa_tag_protocol default_proto;
	struct dsa_platform_data___4 *pd;
	struct list_head ports;
	struct list_head rtable;
	struct net_device___56 **lags;
	unsigned int lags_len;
	unsigned int last_switch;
};

struct dsa_switch_ops___4;

struct dsa_switch___4 {
	bool setup;
	struct device___228 *dev;
	struct dsa_switch_tree___4 *dst;
	unsigned int index;
	struct notifier_block nb;
	void *priv;
	struct dsa_chip_data___4 *cd;
	const struct dsa_switch_ops___4 *ops;
	u32 phys_mii_mask;
	struct mii_bus___12 *slave_mii_bus;
	unsigned int ageing_time_min;
	unsigned int ageing_time_max;
	struct dsa_8021q_context *tag_8021q_ctx;
	struct devlink___4 *devlink;
	unsigned int num_tx_queues;
	bool vlan_filtering_is_global;
	bool needs_standalone_vlan_filtering;
	bool configure_vlan_while_not_filtering;
	bool untag_bridge_pvid;
	bool assisted_learning_on_cpu_port;
	bool vlan_filtering;
	bool pcs_poll;
	bool mtu_enforcement_ingress;
	unsigned int num_lag_ids;
	unsigned int num_fwd_offloading_bridges;
	size_t num_ports;
};

struct dsa_switch_ops___4 {
	enum dsa_tag_protocol (*get_tag_protocol)(struct dsa_switch___4 *, int, enum dsa_tag_protocol);
	int (*change_tag_protocol)(struct dsa_switch___4 *, int, enum dsa_tag_protocol);
	int (*setup)(struct dsa_switch___4 *);
	void (*teardown)(struct dsa_switch___4 *);
	int (*port_setup)(struct dsa_switch___4 *, int);
	void (*port_teardown)(struct dsa_switch___4 *, int);
	u32 (*get_phy_flags)(struct dsa_switch___4 *, int);
	int (*phy_read)(struct dsa_switch___4 *, int, int);
	int (*phy_write)(struct dsa_switch___4 *, int, int, u16);
	void (*adjust_link)(struct dsa_switch___4 *, int, struct phy_device___9 *);
	void (*fixed_link_update)(struct dsa_switch___4 *, int, struct fixed_phy_status___2 *);
	void (*phylink_validate)(struct dsa_switch___4 *, int, long unsigned int *, struct phylink_link_state *);
	int (*phylink_mac_link_state)(struct dsa_switch___4 *, int, struct phylink_link_state *);
	void (*phylink_mac_config)(struct dsa_switch___4 *, int, unsigned int, const struct phylink_link_state *);
	void (*phylink_mac_an_restart)(struct dsa_switch___4 *, int);
	void (*phylink_mac_link_down)(struct dsa_switch___4 *, int, unsigned int, phy_interface_t);
	void (*phylink_mac_link_up)(struct dsa_switch___4 *, int, unsigned int, phy_interface_t, struct phy_device___9 *, int, int, bool, bool);
	void (*phylink_fixed_state)(struct dsa_switch___4 *, int, struct phylink_link_state *);
	void (*get_strings)(struct dsa_switch___4 *, int, u32, uint8_t *);
	void (*get_ethtool_stats)(struct dsa_switch___4 *, int, uint64_t *);
	int (*get_sset_count)(struct dsa_switch___4 *, int, int);
	void (*get_ethtool_phy_stats)(struct dsa_switch___4 *, int, uint64_t *);
	void (*get_stats64)(struct dsa_switch___4 *, int, struct rtnl_link_stats64 *);
	void (*self_test)(struct dsa_switch___4 *, int, struct ethtool_test *, u64 *);
	void (*get_wol)(struct dsa_switch___4 *, int, struct ethtool_wolinfo *);
	int (*set_wol)(struct dsa_switch___4 *, int, struct ethtool_wolinfo *);
	int (*get_ts_info)(struct dsa_switch___4 *, int, struct ethtool_ts_info *);
	int (*suspend)(struct dsa_switch___4 *);
	int (*resume)(struct dsa_switch___4 *);
	int (*port_enable)(struct dsa_switch___4 *, int, struct phy_device___9 *);
	void (*port_disable)(struct dsa_switch___4 *, int);
	int (*set_mac_eee)(struct dsa_switch___4 *, int, struct ethtool_eee *);
	int (*get_mac_eee)(struct dsa_switch___4 *, int, struct ethtool_eee *);
	int (*get_eeprom_len)(struct dsa_switch___4 *);
	int (*get_eeprom)(struct dsa_switch___4 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct dsa_switch___4 *, struct ethtool_eeprom *, u8 *);
	int (*get_regs_len)(struct dsa_switch___4 *, int);
	void (*get_regs)(struct dsa_switch___4 *, int, struct ethtool_regs *, void *);
	int (*port_prechangeupper)(struct dsa_switch___4 *, int, struct netdev_notifier_changeupper_info___4 *);
	int (*set_ageing_time)(struct dsa_switch___4 *, unsigned int);
	int (*port_bridge_join)(struct dsa_switch___4 *, int, struct net_device___56 *);
	void (*port_bridge_leave)(struct dsa_switch___4 *, int, struct net_device___56 *);
	int (*port_bridge_tx_fwd_offload)(struct dsa_switch___4 *, int, struct net_device___56 *, int);
	void (*port_bridge_tx_fwd_unoffload)(struct dsa_switch___4 *, int, struct net_device___56 *, int);
	void (*port_stp_state_set)(struct dsa_switch___4 *, int, u8);
	void (*port_fast_age)(struct dsa_switch___4 *, int);
	int (*port_pre_bridge_flags)(struct dsa_switch___4 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_bridge_flags)(struct dsa_switch___4 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_vlan_filtering)(struct dsa_switch___4 *, int, bool, struct netlink_ext_ack *);
	int (*port_vlan_add)(struct dsa_switch___4 *, int, const struct switchdev_obj_port_vlan___4 *, struct netlink_ext_ack *);
	int (*port_vlan_del)(struct dsa_switch___4 *, int, const struct switchdev_obj_port_vlan___4 *);
	int (*port_fdb_add)(struct dsa_switch___4 *, int, const unsigned char *, u16);
	int (*port_fdb_del)(struct dsa_switch___4 *, int, const unsigned char *, u16);
	int (*port_fdb_dump)(struct dsa_switch___4 *, int, dsa_fdb_dump_cb_t *, void *);
	int (*port_mdb_add)(struct dsa_switch___4 *, int, const struct switchdev_obj_port_mdb___4 *);
	int (*port_mdb_del)(struct dsa_switch___4 *, int, const struct switchdev_obj_port_mdb___4 *);
	int (*get_rxnfc)(struct dsa_switch___4 *, int, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct dsa_switch___4 *, int, struct ethtool_rxnfc *);
	int (*cls_flower_add)(struct dsa_switch___4 *, int, struct flow_cls_offload___4 *, bool);
	int (*cls_flower_del)(struct dsa_switch___4 *, int, struct flow_cls_offload___4 *, bool);
	int (*cls_flower_stats)(struct dsa_switch___4 *, int, struct flow_cls_offload___4 *, bool);
	int (*port_mirror_add)(struct dsa_switch___4 *, int, struct dsa_mall_mirror_tc_entry *, bool);
	void (*port_mirror_del)(struct dsa_switch___4 *, int, struct dsa_mall_mirror_tc_entry *);
	int (*port_policer_add)(struct dsa_switch___4 *, int, struct dsa_mall_policer_tc_entry *);
	void (*port_policer_del)(struct dsa_switch___4 *, int);
	int (*port_setup_tc)(struct dsa_switch___4 *, int, enum tc_setup_type, void *);
	int (*crosschip_bridge_join)(struct dsa_switch___4 *, int, int, int, struct net_device___56 *);
	void (*crosschip_bridge_leave)(struct dsa_switch___4 *, int, int, int, struct net_device___56 *);
	int (*crosschip_lag_change)(struct dsa_switch___4 *, int, int);
	int (*crosschip_lag_join)(struct dsa_switch___4 *, int, int, struct net_device___56 *, struct netdev_lag_upper_info *);
	int (*crosschip_lag_leave)(struct dsa_switch___4 *, int, int, struct net_device___56 *);
	int (*port_hwtstamp_get)(struct dsa_switch___4 *, int, struct ifreq *);
	int (*port_hwtstamp_set)(struct dsa_switch___4 *, int, struct ifreq *);
	void (*port_txtstamp)(struct dsa_switch___4 *, int, struct sk_buff___57 *);
	bool (*port_rxtstamp)(struct dsa_switch___4 *, int, struct sk_buff___57 *, unsigned int);
	int (*devlink_param_get)(struct dsa_switch___4 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_param_set)(struct dsa_switch___4 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_info_get)(struct dsa_switch___4 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*devlink_sb_pool_get)(struct dsa_switch___4 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*devlink_sb_pool_set)(struct dsa_switch___4 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*devlink_sb_port_pool_get)(struct dsa_switch___4 *, int, unsigned int, u16, u32 *);
	int (*devlink_sb_port_pool_set)(struct dsa_switch___4 *, int, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_tc_pool_bind_get)(struct dsa_switch___4 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*devlink_sb_tc_pool_bind_set)(struct dsa_switch___4 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_occ_snapshot)(struct dsa_switch___4 *, unsigned int);
	int (*devlink_sb_occ_max_clear)(struct dsa_switch___4 *, unsigned int);
	int (*devlink_sb_occ_port_pool_get)(struct dsa_switch___4 *, int, unsigned int, u16, u32 *, u32 *);
	int (*devlink_sb_occ_tc_port_bind_get)(struct dsa_switch___4 *, int, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*port_change_mtu)(struct dsa_switch___4 *, int, int);
	int (*port_max_mtu)(struct dsa_switch___4 *, int);
	int (*port_lag_change)(struct dsa_switch___4 *, int);
	int (*port_lag_join)(struct dsa_switch___4 *, int, struct net_device___56 *, struct netdev_lag_upper_info *);
	int (*port_lag_leave)(struct dsa_switch___4 *, int, struct net_device___56 *);
	int (*port_hsr_join)(struct dsa_switch___4 *, int, struct net_device___56 *);
	int (*port_hsr_leave)(struct dsa_switch___4 *, int, struct net_device___56 *);
	int (*port_mrp_add)(struct dsa_switch___4 *, int, const struct switchdev_obj_mrp___4 *);
	int (*port_mrp_del)(struct dsa_switch___4 *, int, const struct switchdev_obj_mrp___4 *);
	int (*port_mrp_add_ring_role)(struct dsa_switch___4 *, int, const struct switchdev_obj_ring_role_mrp___4 *);
	int (*port_mrp_del_ring_role)(struct dsa_switch___4 *, int, const struct switchdev_obj_ring_role_mrp___4 *);
	int (*tag_8021q_vlan_add)(struct dsa_switch___4 *, int, u16, u16);
	int (*tag_8021q_vlan_del)(struct dsa_switch___4 *, int, u16);
};

typedef struct bio_vec___85 skb_frag_t___13;

struct skb_shared_info___13 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___28 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___13 frags[17];
};

struct ipv6hdr___2 {
	__u8 priority;
	__u8 version;
	__u8 flow_lbl[3];
	__be16 payload_len;
	__u8 nexthdr;
	__u8 hop_limit;
	struct in6_addr saddr;
	struct in6_addr daddr;
};

struct tcphdr___4 {
	__be16 source;
	__be16 dest;
	__be32 seq;
	__be32 ack_seq;
	__u16 res1;
	__u16 doff;
	__u16 fin;
	__u16 syn;
	__u16 rst;
	__u16 psh;
	__u16 ack;
	__u16 urg;
	__u16 ece;
	__u16 cwr;
	long: 32;
	long: 64;
	__be16 window;
	__sum16 check;
	__be16 urg_ptr;
};

struct fib_notifier_info {
	int family;
	struct netlink_ext_ack *extack;
};

enum fib_event_type {
	FIB_EVENT_ENTRY_REPLACE = 0,
	FIB_EVENT_ENTRY_APPEND = 1,
	FIB_EVENT_ENTRY_ADD = 2,
	FIB_EVENT_ENTRY_DEL = 3,
	FIB_EVENT_RULE_ADD = 4,
	FIB_EVENT_RULE_DEL = 5,
	FIB_EVENT_NH_ADD = 6,
	FIB_EVENT_NH_DEL = 7,
	FIB_EVENT_VIF_ADD = 8,
	FIB_EVENT_VIF_DEL = 9,
};

struct fib_notifier_net {
	struct list_head fib_notifier_ops;
	struct atomic_notifier_head fib_chain;
};

struct xdp_frame_bulk {
	int count;
	void *xa;
	void *q[16];
};

struct xdp_attachment_info {
	struct bpf_prog___45 *prog;
	u32 flags;
};

struct xdp_umem___2;

struct xdp_buff_xsk;

struct xsk_buff_pool {
	struct device___221 *dev;
	struct net_device___51 *netdev;
	struct list_head xsk_tx_list;
	spinlock_t xsk_tx_list_lock;
	refcount_t users;
	struct xdp_umem___2 *umem;
	struct work_struct work;
	struct list_head free_list;
	u32 heads_cnt;
	u16 queue_id;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	dma_addr_t *dma_pages;
	struct xdp_buff_xsk *heads;
	u64 chunk_mask;
	u64 addrs_cnt;
	u32 free_list_cnt;
	u32 dma_pages_cnt;
	u32 free_heads_cnt;
	u32 headroom;
	u32 chunk_size;
	u32 frame_len;
	u8 cached_need_wakeup;
	bool uses_need_wakeup;
	bool dma_need_sync;
	bool unaligned;
	void *addrs;
	spinlock_t cq_lock;
	struct xdp_buff_xsk *free_heads[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_redirect_info___4 {
	u32 flags;
	u32 tgt_index;
	void *tgt_value;
	struct bpf_map___52 *map;
	u32 map_id;
	enum bpf_map_type map_type;
	u32 kern_flags;
	struct bpf_nh_params nh;
};

struct xdp_mem_allocator___2 {
	struct xdp_mem_info mem;
	union {
		void *allocator;
		struct page_pool___69 *page_pool;
		struct zero_copy_allocator *zc_alloc;
	};
	struct rhash_head node;
	struct callback_head rcu;
};

struct xdp_umem___2 {
	void *addrs;
	u64 size;
	u32 headroom;
	u32 chunk_size;
	u32 chunks;
	u32 npgs;
	struct user_struct *user;
	refcount_t users;
	u8 flags;
	bool zc;
	struct page___245 **pgs;
	int id;
	struct list_head xsk_dma_list;
	struct work_struct work;
};

struct xdp_buff_xsk {
	struct xdp_buff___49 xdp;
	dma_addr_t dma;
	dma_addr_t frame_dma;
	struct xsk_buff_pool *pool;
	bool unaligned;
	u64 orig_addr;
	struct list_head free_list_node;
};

struct flow_match_meta {
	struct flow_dissector_key_meta *key;
	struct flow_dissector_key_meta *mask;
};

struct flow_match_basic {
	struct flow_dissector_key_basic *key;
	struct flow_dissector_key_basic *mask;
};

struct flow_match_control {
	struct flow_dissector_key_control *key;
	struct flow_dissector_key_control *mask;
};

struct flow_match_eth_addrs {
	struct flow_dissector_key_eth_addrs *key;
	struct flow_dissector_key_eth_addrs *mask;
};

struct flow_match_vlan {
	struct flow_dissector_key_vlan *key;
	struct flow_dissector_key_vlan *mask;
};

struct flow_match_ipv4_addrs {
	struct flow_dissector_key_ipv4_addrs *key;
	struct flow_dissector_key_ipv4_addrs *mask;
};

struct flow_match_ipv6_addrs {
	struct flow_dissector_key_ipv6_addrs *key;
	struct flow_dissector_key_ipv6_addrs *mask;
};

struct flow_match_ip {
	struct flow_dissector_key_ip *key;
	struct flow_dissector_key_ip *mask;
};

struct flow_match_ports {
	struct flow_dissector_key_ports *key;
	struct flow_dissector_key_ports *mask;
};

struct flow_match_icmp {
	struct flow_dissector_key_icmp *key;
	struct flow_dissector_key_icmp *mask;
};

struct flow_match_tcp {
	struct flow_dissector_key_tcp *key;
	struct flow_dissector_key_tcp *mask;
};

struct flow_match_mpls {
	struct flow_dissector_key_mpls *key;
	struct flow_dissector_key_mpls *mask;
};

struct flow_match_enc_keyid {
	struct flow_dissector_key_keyid *key;
	struct flow_dissector_key_keyid *mask;
};

struct flow_match_enc_opts {
	struct flow_dissector_key_enc_opts *key;
	struct flow_dissector_key_enc_opts *mask;
};

struct flow_match_ct {
	struct flow_dissector_key_ct *key;
	struct flow_dissector_key_ct *mask;
};

enum flow_block_command {
	FLOW_BLOCK_BIND = 0,
	FLOW_BLOCK_UNBIND = 1,
};

enum flow_block_binder_type {
	FLOW_BLOCK_BINDER_TYPE_UNSPEC = 0,
	FLOW_BLOCK_BINDER_TYPE_CLSACT_INGRESS = 1,
	FLOW_BLOCK_BINDER_TYPE_CLSACT_EGRESS = 2,
	FLOW_BLOCK_BINDER_TYPE_RED_EARLY_DROP = 3,
	FLOW_BLOCK_BINDER_TYPE_RED_MARK = 4,
};

struct flow_block_offload {
	enum flow_block_command command;
	enum flow_block_binder_type binder_type;
	bool block_shared;
	bool unlocked_driver_cb;
	struct net___59 *net;
	struct flow_block *block;
	struct list_head cb_list;
	struct list_head *driver_block_list;
	struct netlink_ext_ack *extack;
	struct Qdisc___35 *sch;
	struct list_head *cb_list_head;
};

struct flow_block_cb;

struct flow_block_indr {
	struct list_head list;
	struct net_device___55 *dev;
	struct Qdisc___35 *sch;
	enum flow_block_binder_type binder_type;
	void *data;
	void *cb_priv;
	void (*cleanup)(struct flow_block_cb *);
};

struct flow_block_cb {
	struct list_head driver_list;
	struct list_head list;
	flow_setup_cb_t *cb;
	void *cb_ident;
	void *cb_priv;
	void (*release)(void *);
	struct flow_block_indr indr;
	unsigned int refcnt;
};

typedef int flow_indr_block_bind_cb_t(struct net_device___55 *, struct Qdisc___35 *, void *, enum tc_setup_type, void *, void *, void (*)(struct flow_block_cb *));

struct flow_indr_dev {
	struct list_head list;
	flow_indr_block_bind_cb_t *cb;
	void *cb_priv;
	refcount_t refcnt;
};

struct flow_indir_dev_info {
	void *data;
	struct net_device___55 *dev;
	struct Qdisc___35 *sch;
	enum tc_setup_type type;
	void (*cleanup)(struct flow_block_cb *);
	struct list_head list;
	enum flow_block_command command;
	enum flow_block_binder_type binder_type;
	struct list_head *cb_list;
};

struct dentry___248;

struct super_block___248;

struct module___232;

struct file_system_type___248 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___248 * (*mount)(struct file_system_type___248 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___248 *);
	struct module___232 *owner;
	struct file_system_type___248 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___248;

struct kiocb___248;

struct iov_iter___168;

struct poll_table_struct___171;

struct vm_area_struct___253;

struct inode___248;

struct file_lock___248;

struct page___253;

struct pipe_inode_info___89;

struct seq_file___223;

struct file_operations___249 {
	struct module___232 *owner;
	loff_t (*llseek)(struct file___248 *, loff_t, int);
	ssize_t (*read)(struct file___248 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___248 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___248 *, struct iov_iter___168 *);
	ssize_t (*write_iter)(struct kiocb___248 *, struct iov_iter___168 *);
	int (*iopoll)(struct kiocb___248 *, bool);
	int (*iterate)(struct file___248 *, struct dir_context *);
	int (*iterate_shared)(struct file___248 *, struct dir_context *);
	__poll_t (*poll)(struct file___248 *, struct poll_table_struct___171 *);
	long int (*unlocked_ioctl)(struct file___248 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___248 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___248 *, struct vm_area_struct___253 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___248 *, struct file___248 *);
	int (*flush)(struct file___248 *, fl_owner_t);
	int (*release)(struct inode___248 *, struct file___248 *);
	int (*fsync)(struct file___248 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___248 *, int);
	int (*lock)(struct file___248 *, int, struct file_lock___248 *);
	ssize_t (*sendpage)(struct file___248 *, struct page___253 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___248 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___248 *, long unsigned int);
	int (*flock)(struct file___248 *, int, struct file_lock___248 *);
	ssize_t (*splice_write)(struct pipe_inode_info___89 *, struct file___248 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___248 *, loff_t *, struct pipe_inode_info___89 *, size_t, unsigned int);
	int (*setlease)(struct file___248 *, long int, struct file_lock___248 **, void **);
	long int (*fallocate)(struct file___248 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___223 *, struct file___248 *);
	ssize_t (*copy_file_range)(struct file___248 *, loff_t, struct file___248 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___248 *, loff_t, struct file___248 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___248 *, loff_t, loff_t, int);
};

struct vmacache___253 {
	u64 seqnum;
	struct vm_area_struct___253 *vmas[4];
};

struct page_frag___253 {
	struct page___253 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___254;

struct pid___225;

struct nsproxy___234;

struct signal_struct___249;

struct bio_list___141;

struct backing_dev_info___127;

struct io_context___141;

struct css_set___175;

struct mem_cgroup___115;

struct request_queue___141;

struct vm_struct___231;

struct task_struct___255 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___255 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___254 *mm;
	struct mm_struct___254 *active_mm;
	struct vmacache___253 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___255 *real_parent;
	struct task_struct___255 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___255 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___225 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___234 *nsproxy;
	struct signal_struct___249 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___255 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___141 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___127 *backing_dev_info;
	struct io_context___141 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___175 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___89 *splice_pipe;
	struct page_frag___253 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___115 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___115 *active_memcg;
	struct request_queue___141 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___255 *oom_reaper_list;
	struct vm_struct___231 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___236;

struct kobj_type___236;

struct kernfs_node___236;

struct kobject___236 {
	const char *name;
	struct list_head entry;
	struct kobject___236 *parent;
	struct kset___236 *kset;
	struct kobj_type___236 *ktype;
	struct kernfs_node___236 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___233 {
	struct kobject___236 kobj;
	struct module___232 *mod;
	struct kobject___236 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___232 {
	struct module___232 *mod;
	struct latch_tree_node node;
};

struct module_layout___232 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___232 mtn;
};

struct module_attribute___232;

struct kernel_param___232;

struct module___232 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___233 mkobj;
	struct module_attribute___232 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___236 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___232 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___232 core_layout;
	struct module_layout___232 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___225;

struct upid___225 {
	int nr;
	struct pid_namespace___225 *ns;
};

struct pid_namespace___225 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___255 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___225 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___225 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___225 numbers[1];
};

typedef struct page___253 *pgtable_t___253;

struct address_space___248;

struct page_pool___77;

struct dev_pagemap___243;

struct page___253 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___248 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___77 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___253 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___253 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___254 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___243 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___243;

struct vm_area_struct___253 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___253 *vm_next;
	struct vm_area_struct___253 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___254 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___243 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___248 *vm_file;
	struct file___248 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___249 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___255 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___255 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___225 *pids[4];
	struct pid___225 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___254 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___253;

struct mm_struct___254 {
	struct {
		struct vm_area_struct___253 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___248 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___253 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___255 *owner;
		struct user_namespace___26 *user_ns;
		struct file___248 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___62;

struct cgroup_namespace___175;

struct nsproxy___234 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___225 *pid_ns_for_children;
	struct net___62 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___175 *cgroup_ns;
};

struct bio___141;

struct bio_list___141 {
	struct bio___141 *head;
	struct bio___141 *tail;
};

struct cgroup_subsys_state___175;

struct bdi_writeback___127 {
	struct backing_dev_info___127 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___175 *memcg_css;
	struct cgroup_subsys_state___175 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___229;

struct backing_dev_info___127 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___127 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___229 *dev;
	char dev_name[64];
	struct device___229 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___248 *debug_dir;
};

struct io_cq___141;

struct io_context___141 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___141 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___175;

struct css_set___175 {
	struct cgroup_subsys_state___175 *subsys[14];
	refcount_t refcount;
	struct css_set___175 *dom_cset;
	struct cgroup___175 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___175 *mg_src_cgrp;
	struct cgroup___175 *mg_dst_cgrp;
	struct css_set___175 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___248;

struct pipe_buffer___89;

struct pipe_inode_info___89 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___253 *tmp_page;
	struct fasync_struct___248 *fasync_readers;
	struct fasync_struct___248 *fasync_writers;
	struct pipe_buffer___89 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___175;

struct cgroup_subsys_state___175 {
	struct cgroup___175 *cgroup;
	struct cgroup_subsys___175 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___175 *parent;
};

struct cgroup_file___175 {
	struct kernfs_node___236 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___115;

struct mem_cgroup_per_node___115;

struct mem_cgroup___115 {
	struct cgroup_subsys_state___175 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___175 events_file;
	struct cgroup_file___175 events_local_file;
	struct cgroup_file___175 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___115 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___255 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___115 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___141;

struct blk_integrity___141 {
	const struct blk_integrity_profile___141 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___141 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___141 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___141;

struct elevator_queue___141;

struct blk_mq_ops___136;

struct blk_mq_hw_ctx___136;

struct gendisk___144;

struct blkcg_gq___129;

struct blk_mq_tag_set___136;

struct request_queue___141 {
	struct request___141 *last_merge;
	struct elevator_queue___141 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___136 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___136 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___144 *disk;
	struct kobject___236 kobj;
	struct kobject___236 *mq_kobj;
	struct blk_integrity___141 integrity;
	struct device___229 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___129 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___136 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___141 bio_split;
	struct dentry___248 *debugfs_dir;
	struct dentry___248 *sched_debugfs_dir;
	struct dentry___248 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___231 {
	struct vm_struct___231 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___253 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___165 {
	struct page___253 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___168 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___165 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___89 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___48 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___168 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___248 *msg_iocb;
};

struct kiocb___248 {
	struct file___248 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___248 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___57;

struct sock___46;

struct sk_buff___58 {
	union {
		struct {
			struct sk_buff___58 *next;
			struct sk_buff___58 *prev;
			union {
				struct net_device___57 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___46 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___58 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___62;

struct fqdir___62 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___62 *f;
	struct net___62 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___62;

struct inet_frags___62 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___62 *, const void *);
	void (*destructor)(struct inet_frag_queue___62 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct fib_rules_ops___46;

struct fib_notifier_ops___46;

struct netns_ipv4___62 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___46 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___46 *fibnl;
	struct sock___46 **icmp_sk;
	struct sock___46 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___46 **tcp_sk;
	struct fqdir___62 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___46 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___46 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___46 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___46;

struct neighbour___46;

struct dst_ops___62 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___62 *);
	struct dst_entry___46 * (*check)(struct dst_entry___46 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___46 *);
	unsigned int (*mtu)(const struct dst_entry___46 *);
	u32 * (*cow_metrics)(struct dst_entry___46 *, long unsigned int);
	void (*destroy)(struct dst_entry___46 *);
	void (*ifdown)(struct dst_entry___46 *, struct net_device___57 *, int);
	struct dst_entry___46 * (*negative_advice)(struct dst_entry___46 *);
	void (*link_failure)(struct sk_buff___58 *);
	void (*update_pmtu)(struct dst_entry___46 *, struct sock___46 *, struct sk_buff___58 *, u32, bool);
	void (*redirect)(struct dst_entry___46 *, struct sock___46 *, struct sk_buff___58 *);
	int (*local_out)(struct net___62 *, struct sock___46 *, struct sk_buff___58 *);
	struct neighbour___46 * (*neigh_lookup)(const struct dst_entry___46 *, struct sk_buff___58 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___46 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___62 {
	struct dst_ops___62 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___62 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___46 *fib6_rules_ops;
	struct sock___46 **icmp_sk;
	struct sock___46 *ndisc_sk;
	struct sock___46 *tcp_sk;
	struct sock___46 *igmp_sk;
	struct sock___46 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___46 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___46 *notifier_ops;
	struct fib_notifier_ops___46 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___62 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___62 *fqdir;
};

struct netns_sctp___46 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___46 *ctl_sock;
	struct sock___46 *udp4_sock;
	struct sock___46 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___57 {
	struct sk_buff___58 *next;
	struct sk_buff___58 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___53;

struct bpf_prog___53;

struct netns_bpf___53 {
	struct bpf_prog_array___53 *run_array[2];
	struct bpf_prog___53 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___62 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___46 *nlsk;
	struct sock___46 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___62 xfrm4_dst_ops;
	struct dst_ops___62 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___62 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___46 *rtnl;
	struct sock___46 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___57 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___62 ipv4;
	struct netns_ipv6___62 ipv6;
	struct netns_ieee802154_lowpan___62 ieee802154_lowpan;
	struct netns_sctp___46 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___57 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___53 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___62 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___46 *crypto_nlsk;
	struct sock___46 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___62 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___58 *fragments_tail;
	struct sk_buff___58 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___62 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___46;

struct fib_lookup_arg___46;

struct fib_rules_ops___46 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___46 *, struct flowi *, int, struct fib_lookup_arg___46 *);
	bool (*suppress)(struct fib_rule___46 *, int, struct fib_lookup_arg___46 *);
	int (*match)(struct fib_rule___46 *, struct flowi *, int);
	int (*configure)(struct fib_rule___46 *, struct sk_buff___58 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___46 *);
	int (*compare)(struct fib_rule___46 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___46 *, struct sk_buff___58 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___46 *);
	void (*flush_cache)(struct fib_rules_ops___46 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___232 *owner;
	struct net___62 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___62 *net;
} possible_net_t___57;

struct proto___46;

struct sock_common___46 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___46 *skc_prot;
	possible_net_t___57 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___46 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___46 {
	struct cgroup___175 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___46;

struct socket_wq___47;

struct socket___48;

struct sock___46 {
	struct sock_common___46 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___57 sk_error_queue;
	struct sk_buff___58 *sk_rx_skb_cache;
	struct sk_buff_head___57 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___58 *head;
		struct sk_buff___58 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___46 *sk_filter;
	union {
		struct socket_wq___47 *sk_wq;
		struct socket_wq___47 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___46 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___46 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___58 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___58 *sk_tx_skb_cache;
	struct sk_buff_head___57 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___253 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___46 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___225 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___48 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___46 sk_cgrp_data;
	struct mem_cgroup___115 *sk_memcg;
	void (*sk_state_change)(struct sock___46 *);
	void (*sk_data_ready)(struct sock___46 *);
	void (*sk_write_space)(struct sock___46 *);
	void (*sk_error_report)(struct sock___46 *);
	int (*sk_backlog_rcv)(struct sock___46 *, struct sk_buff___58 *);
	struct sk_buff___58 * (*sk_validate_xmit_skb)(struct sock___46 *, struct net_device___57 *, struct sk_buff___58 *);
	void (*sk_destruct)(struct sock___46 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct fib_notifier_ops___46 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___62 *);
	int (*fib_dump)(struct net___62 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___232 *owner;
	struct callback_head rcu;
};

struct address_space_operations___248;

struct address_space___248 {
	struct inode___248 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___248 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___77 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___229 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___77 {
	u32 count;
	struct page___253 *cache[128];
};

struct page_pool___77 {
	struct page_pool_params___77 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___253 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___77 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___243;

struct dev_pagemap___243 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___243 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___248;

struct path___248 {
	struct vfsmount___248 *mnt;
	struct dentry___248 *dentry;
};

struct fown_struct___225 {
	rwlock_t lock;
	struct pid___225 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___248 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___248 f_path;
	struct inode___248 *f_inode;
	const struct file_operations___249 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___225 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___248 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___243;

struct vm_operations_struct___243 {
	void (*open)(struct vm_area_struct___253 *);
	void (*close)(struct vm_area_struct___253 *);
	int (*may_split)(struct vm_area_struct___253 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___253 *);
	int (*mprotect)(struct vm_area_struct___253 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___243 *);
	vm_fault_t (*huge_fault)(struct vm_fault___243 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___243 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___253 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___243 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___243 *);
	int (*access)(struct vm_area_struct___253 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___253 *);
	int (*set_policy)(struct vm_area_struct___253 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___253 *, long unsigned int);
	struct page___253 * (*find_special_page)(struct vm_area_struct___253 *, long unsigned int);
};

struct core_thread___253 {
	struct task_struct___255 *task;
	struct core_thread___253 *next;
};

struct core_state___253 {
	atomic_t nr_threads;
	struct core_thread___253 dumper;
	struct completion startup;
};

struct vm_fault___243 {
	const struct {
		struct vm_area_struct___253 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___253 *cow_page;
	struct page___253 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___253 prealloc_pte;
};

struct pglist_data___123;

struct lruvec___123 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___123 *pgdat;
};

struct zone___123 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___123 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___123 {
	struct zone___123 *zone;
	int zone_idx;
};

struct zonelist___123 {
	struct zoneref___123 _zonerefs[321];
};

struct pglist_data___123 {
	struct zone___123 node_zones[5];
	struct zonelist___123 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___255 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___255 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___123 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dst_entry___46 {
	struct net_device___57 *dev;
	struct dst_ops___62 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___58 *);
	int (*output)(struct net___62 *, struct sock___46 *, struct sk_buff___58 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___57(struct sk_buff___58 **);

struct wakeup_source___229;

struct dev_pm_info___229 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___229 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___229 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___229;

struct bus_type___229;

struct device_driver___229;

struct dev_pm_domain___229;

struct device_node___103;

struct fwnode_handle___225;

struct class___229;

struct attribute_group___236;

struct device___229 {
	struct kobject___236 kobj;
	struct device___229 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___229 *type;
	struct bus_type___229 *bus;
	struct device_driver___229 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___229 power;
	struct dev_pm_domain___229 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___103 *of_node;
	struct fwnode_handle___225 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___229 *class;
	const struct attribute_group___236 **groups;
	void (*release)(struct device___229 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___53 {
	struct bpf_prog___53 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___57;

struct net_device_ops___57;

struct ethtool_ops___26;

struct l3mdev_ops___46;

struct xfrmdev_ops___57;

struct header_ops___57;

struct netdev_rx_queue___57;

struct mini_Qdisc___53;

struct netdev_queue___57;

struct Qdisc___53;

struct rtnl_link_ops___53;

struct dcbnl_rtnl_ops___57;

struct phy_device___10;

struct net_device___57 {
	char name[16];
	struct netdev_name_node___57 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___57 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___26 *ethtool_ops;
	const struct l3mdev_ops___46 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___57 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___57 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___236 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___57 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___53 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___57 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___53 *miniq_ingress;
	struct netdev_queue___57 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___57 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___53 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___53 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___57 = 0,
		NETREG_REGISTERED___57 = 1,
		NETREG_UNREGISTERING___57 = 2,
		NETREG_UNREGISTERED___57 = 3,
		NETREG_RELEASED___57 = 4,
		NETREG_DUMMY___57 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___57 = 0,
		RTNL_LINK_INITIALIZING___57 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___57 *);
	struct netpoll_info *npinfo;
	possible_net_t___57 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___229 dev;
	const struct attribute_group___236 *sysfs_groups[4];
	const struct attribute_group___236 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___53 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___57 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___10 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___53 xdp_state[3];
	long: 64;
};

struct neigh_table___46;

struct neigh_parms___46;

struct neigh_ops___46;

struct neighbour___46 {
	struct neighbour___46 *next;
	struct neigh_table___46 *tbl;
	struct neigh_parms___46 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___57 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___46 *, struct sk_buff___58 *);
	const struct neigh_ops___46 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___57 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___53 {
	struct bpf_prog___53 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___53 {
	struct callback_head rcu;
	struct bpf_prog_array_item___53 items[0];
};

struct bpf_prog_aux___60;

struct bpf_prog___53 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___60 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___248;

struct dentry___248 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___248 *d_parent;
	struct qstr d_name;
	struct inode___248 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___248 *d_op;
	struct super_block___248 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___248;

struct inode___248 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___248 *i_op;
	struct super_block___248 *i_sb;
	struct address_space___248 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___127 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___249 *i_fop;
		void (*free_inode)(struct inode___248 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___248 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___89 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___248 {
	int (*d_revalidate)(struct dentry___248 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___248 *, unsigned int);
	int (*d_hash)(const struct dentry___248 *, struct qstr *);
	int (*d_compare)(const struct dentry___248 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___248 *);
	int (*d_init)(struct dentry___248 *);
	void (*d_release)(struct dentry___248 *);
	void (*d_prune)(struct dentry___248 *);
	void (*d_iput)(struct dentry___248 *, struct inode___248 *);
	char * (*d_dname)(struct dentry___248 *, char *, int);
	struct vfsmount___248 * (*d_automount)(struct path___248 *);
	int (*d_manage)(const struct path___248 *, bool);
	struct dentry___248 * (*d_real)(struct dentry___248 *, const struct inode___248 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___248;

struct mem_dqinfo___248 {
	struct quota_format_type___248 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___248;

struct quota_info___248 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___248 *files[3];
	struct mem_dqinfo___248 info[3];
	const struct quota_format_ops___248 *ops[3];
};

struct rcuwait___249 {
	struct task_struct___255 *task;
};

struct percpu_rw_semaphore___249 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___249 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___248 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___249 rw_sem[3];
};

struct shrink_control___115;

struct shrinker___115 {
	long unsigned int (*count_objects)(struct shrinker___115 *, struct shrink_control___115 *);
	long unsigned int (*scan_objects)(struct shrinker___115 *, struct shrink_control___115 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___248;

struct dquot_operations___248;

struct quotactl_ops___248;

struct block_device___144;

struct super_block___248 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___248 *s_type;
	const struct super_operations___248 *s_op;
	const struct dquot_operations___248 *dq_op;
	const struct quotactl_ops___248 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___248 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___144 *s_bdev;
	struct backing_dev_info___127 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___248 s_dquot;
	struct sb_writers___248 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___248 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___248 {
	struct dentry___248 *mnt_root;
	struct super_block___248 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___115 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___115 *memcg;
};

struct psi_group___175 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___255 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___53 {
	struct bpf_prog_array___53 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___53 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___175;

struct cgroup_rstat_cpu___175;

struct cgroup___175 {
	struct cgroup_subsys_state___175 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___236 *kn;
	struct cgroup_file___175 procs_file;
	struct cgroup_file___175 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___175 *subsys[14];
	struct cgroup_root___175 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___175 *dom_cgrp;
	struct cgroup___175 *old_dom_cgrp;
	struct cgroup_rstat_cpu___175 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___175 psi;
	struct cgroup_bpf___53 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___141 {
	struct request_queue___141 *q;
	struct io_context___141 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___248 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___248 *ia_file;
};

struct dquot___248 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___248 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___248 {
	int qf_fmt_id;
	const struct quota_format_ops___248 *qf_ops;
	struct module___232 *qf_owner;
	struct quota_format_type___248 *qf_next;
};

struct quota_format_ops___248 {
	int (*check_quota_file)(struct super_block___248 *, int);
	int (*read_file_info)(struct super_block___248 *, int);
	int (*write_file_info)(struct super_block___248 *, int);
	int (*free_file_info)(struct super_block___248 *, int);
	int (*read_dqblk)(struct dquot___248 *);
	int (*commit_dqblk)(struct dquot___248 *);
	int (*release_dqblk)(struct dquot___248 *);
	int (*get_next_id)(struct super_block___248 *, struct kqid *);
};

struct dquot_operations___248 {
	int (*write_dquot)(struct dquot___248 *);
	struct dquot___248 * (*alloc_dquot)(struct super_block___248 *, int);
	void (*destroy_dquot)(struct dquot___248 *);
	int (*acquire_dquot)(struct dquot___248 *);
	int (*release_dquot)(struct dquot___248 *);
	int (*mark_dirty)(struct dquot___248 *);
	int (*write_info)(struct super_block___248 *, int);
	qsize_t * (*get_reserved_space)(struct inode___248 *);
	int (*get_projid)(struct inode___248 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___248 *, qsize_t *);
	int (*get_next_id)(struct super_block___248 *, struct kqid *);
};

struct quotactl_ops___248 {
	int (*quota_on)(struct super_block___248 *, int, int, const struct path___248 *);
	int (*quota_off)(struct super_block___248 *, int);
	int (*quota_enable)(struct super_block___248 *, unsigned int);
	int (*quota_disable)(struct super_block___248 *, unsigned int);
	int (*quota_sync)(struct super_block___248 *, int);
	int (*set_info)(struct super_block___248 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___248 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___248 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___248 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___248 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___248 *, unsigned int);
};

struct writeback_control___127;

struct address_space_operations___248 {
	int (*writepage)(struct page___253 *, struct writeback_control___127 *);
	int (*readpage)(struct file___248 *, struct page___253 *);
	int (*writepages)(struct address_space___248 *, struct writeback_control___127 *);
	int (*set_page_dirty)(struct page___253 *);
	int (*readpages)(struct file___248 *, struct address_space___248 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___248 *, struct address_space___248 *, loff_t, unsigned int, unsigned int, struct page___253 **, void **);
	int (*write_end)(struct file___248 *, struct address_space___248 *, loff_t, unsigned int, unsigned int, struct page___253 *, void *);
	sector_t (*bmap)(struct address_space___248 *, sector_t);
	void (*invalidatepage)(struct page___253 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___253 *, gfp_t);
	void (*freepage)(struct page___253 *);
	ssize_t (*direct_IO)(struct kiocb___248 *, struct iov_iter___168 *);
	int (*migratepage)(struct address_space___248 *, struct page___253 *, struct page___253 *, enum migrate_mode);
	bool (*isolate_page)(struct page___253 *, isolate_mode_t);
	void (*putback_page)(struct page___253 *);
	int (*launder_page)(struct page___253 *);
	int (*is_partially_uptodate)(struct page___253 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___253 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___248 *, struct page___253 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___248 *, sector_t *);
	void (*swap_deactivate)(struct file___248 *);
};

struct writeback_control___127 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___127 *wb;
	struct inode___248 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___248 {
	struct dentry___248 * (*lookup)(struct inode___248 *, struct dentry___248 *, unsigned int);
	const char * (*get_link)(struct dentry___248 *, struct inode___248 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___248 *, int);
	struct posix_acl * (*get_acl)(struct inode___248 *, int, bool);
	int (*readlink)(struct dentry___248 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___248 *, struct dentry___248 *, umode_t, bool);
	int (*link)(struct dentry___248 *, struct inode___248 *, struct dentry___248 *);
	int (*unlink)(struct inode___248 *, struct dentry___248 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___248 *, struct dentry___248 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___248 *, struct dentry___248 *, umode_t);
	int (*rmdir)(struct inode___248 *, struct dentry___248 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___248 *, struct dentry___248 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___248 *, struct dentry___248 *, struct inode___248 *, struct dentry___248 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___248 *, struct iattr___248 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___248 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___248 *, char *, size_t);
	int (*fiemap)(struct inode___248 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___248 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___248 *, struct dentry___248 *, struct file___248 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___248 *, struct dentry___248 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___248 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___248 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___248 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___248 {
	void (*fl_copy_lock)(struct file_lock___248 *, struct file_lock___248 *);
	void (*fl_release_private)(struct file_lock___248 *);
};

struct lock_manager_operations___248;

struct file_lock___248 {
	struct file_lock___248 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___248 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___248 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___248 *fl_ops;
	const struct lock_manager_operations___248 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___248 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___248 *);
	int (*lm_grant)(struct file_lock___248 *, int);
	bool (*lm_break)(struct file_lock___248 *);
	int (*lm_change)(struct file_lock___248 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___248 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___248 *);
};

struct fasync_struct___248 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___248 *fa_next;
	struct file___248 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___248 {
	struct inode___248 * (*alloc_inode)(struct super_block___248 *);
	void (*destroy_inode)(struct inode___248 *);
	void (*free_inode)(struct inode___248 *);
	void (*dirty_inode)(struct inode___248 *, int);
	int (*write_inode)(struct inode___248 *, struct writeback_control___127 *);
	int (*drop_inode)(struct inode___248 *);
	void (*evict_inode)(struct inode___248 *);
	void (*put_super)(struct super_block___248 *);
	int (*sync_fs)(struct super_block___248 *, int);
	int (*freeze_super)(struct super_block___248 *);
	int (*freeze_fs)(struct super_block___248 *);
	int (*thaw_super)(struct super_block___248 *);
	int (*unfreeze_fs)(struct super_block___248 *);
	int (*statfs)(struct dentry___248 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___248 *, int *, char *);
	void (*umount_begin)(struct super_block___248 *);
	int (*show_options)(struct seq_file___223 *, struct dentry___248 *);
	int (*show_devname)(struct seq_file___223 *, struct dentry___248 *);
	int (*show_path)(struct seq_file___223 *, struct dentry___248 *);
	int (*show_stats)(struct seq_file___223 *, struct dentry___248 *);
	ssize_t (*quota_read)(struct super_block___248 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___248 *, int, const char *, size_t, loff_t);
	struct dquot___248 ** (*get_dquots)(struct inode___248 *);
	long int (*nr_cached_objects)(struct super_block___248 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___248 *, struct shrink_control___115 *);
	struct file___248 * (*real_loop)(struct file___248 *);
};

struct block_device___144 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___248 *bd_inode;
	struct super_block___248 *bd_super;
	void *bd_claiming;
	struct device___229 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___236 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___144 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___248 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___179)(struct file___248 *, wait_queue_head_t *, struct poll_table_struct___171 *);

struct poll_table_struct___171 {
	poll_queue_proc___179 _qproc;
	__poll_t _key;
};

struct seq_operations___223;

struct seq_file___223 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___223 *op;
	int poll_event;
	const struct file___248 *file;
	void *private;
};

typedef void bio_end_io_t___141(struct bio___141 *);

struct bio_integrity_payload___141;

struct bio___141 {
	struct bio___141 *bi_next;
	struct block_device___144 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___141 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___129 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___141 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___165 *bi_io_vec;
	struct bio_set___141 *bi_pool;
	struct bio_vec___165 bi_inline_vecs[0];
};

struct dev_pagemap_ops___243 {
	void (*page_free)(struct page___253 *);
	void (*kill)(struct dev_pagemap___243 *);
	void (*cleanup)(struct dev_pagemap___243 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___243 *);
};

struct fwnode_operations___225;

struct fwnode_handle___225 {
	struct fwnode_handle___225 *secondary;
	const struct fwnode_operations___225 *ops;
	struct device___229 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___225;

struct fwnode_endpoint___225;

struct fwnode_operations___225 {
	struct fwnode_handle___225 * (*get)(struct fwnode_handle___225 *);
	void (*put)(struct fwnode_handle___225 *);
	bool (*device_is_available)(const struct fwnode_handle___225 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___225 *, const struct device___229 *);
	bool (*property_present)(const struct fwnode_handle___225 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___225 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___225 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___225 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*get_parent)(const struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*get_next_child_node)(const struct fwnode_handle___225 *, struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*get_named_child_node)(const struct fwnode_handle___225 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___225 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___225 *);
	struct fwnode_handle___225 * (*graph_get_next_endpoint)(const struct fwnode_handle___225 *, struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*graph_get_remote_endpoint)(const struct fwnode_handle___225 *);
	struct fwnode_handle___225 * (*graph_get_port_parent)(struct fwnode_handle___225 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___225 *, struct fwnode_endpoint___225 *);
	int (*add_links)(struct fwnode_handle___225 *);
};

struct fwnode_endpoint___225 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___225 *local_fwnode;
};

struct fwnode_reference_args___225 {
	struct fwnode_handle___225 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___236;

struct kernfs_elem_dir___236 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___236 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___236;

struct kernfs_root___236 {
	struct kernfs_node___236 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___236 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___236 {
	struct kernfs_node___236 *target_kn;
};

struct kernfs_ops___236;

struct kernfs_elem_attr___236 {
	const struct kernfs_ops___236 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___236 *notify_next;
};

struct kernfs_node___236 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___236 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___236 dir;
		struct kernfs_elem_symlink___236 symlink;
		struct kernfs_elem_attr___236 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___236;

struct kernfs_ops___236 {
	int (*open)(struct kernfs_open_file___236 *);
	void (*release)(struct kernfs_open_file___236 *);
	int (*seq_show)(struct seq_file___223 *, void *);
	void * (*seq_start)(struct seq_file___223 *, loff_t *);
	void * (*seq_next)(struct seq_file___223 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___223 *, void *);
	ssize_t (*read)(struct kernfs_open_file___236 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___236 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___236 *, struct poll_table_struct___171 *);
	int (*mmap)(struct kernfs_open_file___236 *, struct vm_area_struct___253 *);
};

struct kernfs_syscall_ops___236 {
	int (*show_options)(struct seq_file___223 *, struct kernfs_root___236 *);
	int (*mkdir)(struct kernfs_node___236 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___236 *);
	int (*rename)(struct kernfs_node___236 *, struct kernfs_node___236 *, const char *);
	int (*show_path)(struct seq_file___223 *, struct kernfs_node___236 *, struct kernfs_root___236 *);
};

struct kernfs_open_file___236 {
	struct kernfs_node___236 *kn;
	struct file___248 *file;
	struct seq_file___223 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___243 *vm_ops;
};

struct kobj_ns_type_operations___46 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___46 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___236;

struct attribute_group___236 {
	const char *name;
	umode_t (*is_visible)(struct kobject___236 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___236 *, struct bin_attribute___236 *, int);
	struct attribute **attrs;
	struct bin_attribute___236 **bin_attrs;
};

struct bin_attribute___236 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___248 * (*f_mapping)();
	ssize_t (*read)(struct file___248 *, struct kobject___236 *, struct bin_attribute___236 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___248 *, struct kobject___236 *, struct bin_attribute___236 *, char *, loff_t, size_t);
	int (*mmap)(struct file___248 *, struct kobject___236 *, struct bin_attribute___236 *, struct vm_area_struct___253 *);
};

struct sysfs_ops___236 {
	ssize_t (*show)(struct kobject___236 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___236 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___236;

struct kset___236 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___236 kobj;
	const struct kset_uevent_ops___236 *uevent_ops;
};

struct kobj_type___236 {
	void (*release)(struct kobject___236 *);
	const struct sysfs_ops___236 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___236 **default_groups;
	const struct kobj_ns_type_operations___46 * (*child_ns_type)(struct kobject___236 *);
	const void * (*namespace)(struct kobject___236 *);
	void (*get_ownership)(struct kobject___236 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___236 {
	int (* const filter)(struct kset___236 *, struct kobject___236 *);
	const char * (* const name)(struct kset___236 *, struct kobject___236 *);
	int (* const uevent)(struct kset___236 *, struct kobject___236 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___232 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___232 *);
	int (*get)(char *, const struct kernel_param___232 *);
	void (*free)(void *);
};

struct kparam_array___232;

struct kernel_param___232 {
	const char *name;
	struct module___232 *mod;
	const struct kernel_param_ops___232 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___232 *arr;
	};
};

struct kparam_array___232 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___232 *ops;
	void *elem;
};

struct module_attribute___232 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___232 *, struct module_kobject___233 *, char *);
	ssize_t (*store)(struct module_attribute___232 *, struct module_kobject___233 *, const char *, size_t);
	void (*setup)(struct module___232 *, const char *);
	int (*test)(struct module___232 *);
	void (*free)(struct module___232 *);
};

struct cgroup_namespace___175 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___175 *root_cset;
};

struct socket_wq___47 {
	wait_queue_head_t wait;
	struct fasync_struct___248 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___47;

struct socket___48 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___248 *file;
	struct sock___46 *sk;
	const struct proto_ops___47 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___47 wq;
};

typedef int (*sk_read_actor_t___46)(read_descriptor_t *, struct sk_buff___58 *, unsigned int, size_t);

struct proto_ops___47 {
	int family;
	struct module___232 *owner;
	int (*release)(struct socket___48 *);
	int (*bind)(struct socket___48 *, struct sockaddr *, int);
	int (*connect)(struct socket___48 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___48 *, struct socket___48 *);
	int (*accept)(struct socket___48 *, struct socket___48 *, int, bool);
	int (*getname)(struct socket___48 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___248 *, struct socket___48 *, struct poll_table_struct___171 *);
	int (*ioctl)(struct socket___48 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___48 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___48 *, void *, bool, bool);
	int (*listen)(struct socket___48 *, int);
	int (*shutdown)(struct socket___48 *, int);
	int (*setsockopt)(struct socket___48 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___48 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___223 *, struct socket___48 *);
	int (*sendmsg)(struct socket___48 *, struct msghdr___48 *, size_t);
	int (*recvmsg)(struct socket___48 *, struct msghdr___48 *, size_t, int);
	int (*mmap)(struct file___248 *, struct socket___48 *, struct vm_area_struct___253 *);
	ssize_t (*sendpage)(struct socket___48 *, struct page___253 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___48 *, loff_t *, struct pipe_inode_info___89 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___46 *, int);
	int (*peek_len)(struct socket___48 *);
	int (*read_sock)(struct sock___46 *, read_descriptor_t *, sk_read_actor_t___46);
	int (*sendpage_locked)(struct sock___46 *, struct page___253 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___46 *, struct msghdr___48 *, size_t);
	int (*set_rcvlowat)(struct sock___46 *, int);
};

struct dev_pm_ops___229 {
	int (*prepare)(struct device___229 *);
	void (*complete)(struct device___229 *);
	int (*suspend)(struct device___229 *);
	int (*resume)(struct device___229 *);
	int (*freeze)(struct device___229 *);
	int (*thaw)(struct device___229 *);
	int (*poweroff)(struct device___229 *);
	int (*restore)(struct device___229 *);
	int (*suspend_late)(struct device___229 *);
	int (*resume_early)(struct device___229 *);
	int (*freeze_late)(struct device___229 *);
	int (*thaw_early)(struct device___229 *);
	int (*poweroff_late)(struct device___229 *);
	int (*restore_early)(struct device___229 *);
	int (*suspend_noirq)(struct device___229 *);
	int (*resume_noirq)(struct device___229 *);
	int (*freeze_noirq)(struct device___229 *);
	int (*thaw_noirq)(struct device___229 *);
	int (*poweroff_noirq)(struct device___229 *);
	int (*restore_noirq)(struct device___229 *);
	int (*runtime_suspend)(struct device___229 *);
	int (*runtime_resume)(struct device___229 *);
	int (*runtime_idle)(struct device___229 *);
};

struct wakeup_source___229 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___229 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___229 {
	struct dev_pm_ops___229 ops;
	int (*start)(struct device___229 *);
	void (*detach)(struct device___229 *, bool);
	int (*activate)(struct device___229 *);
	void (*sync)(struct device___229 *);
	void (*dismiss)(struct device___229 *);
};

struct bus_type___229 {
	const char *name;
	const char *dev_name;
	struct device___229 *dev_root;
	const struct attribute_group___236 **bus_groups;
	const struct attribute_group___236 **dev_groups;
	const struct attribute_group___236 **drv_groups;
	int (*match)(struct device___229 *, struct device_driver___229 *);
	int (*uevent)(struct device___229 *, struct kobj_uevent_env *);
	int (*probe)(struct device___229 *);
	void (*sync_state)(struct device___229 *);
	void (*remove)(struct device___229 *);
	void (*shutdown)(struct device___229 *);
	int (*online)(struct device___229 *);
	int (*offline)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	int (*num_vf)(struct device___229 *);
	int (*dma_configure)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___229 {
	const char *name;
	struct bus_type___229 *bus;
	struct module___232 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___229 *);
	void (*sync_state)(struct device___229 *);
	int (*remove)(struct device___229 *);
	void (*shutdown)(struct device___229 *);
	int (*suspend)(struct device___229 *, pm_message_t);
	int (*resume)(struct device___229 *);
	const struct attribute_group___236 **groups;
	const struct attribute_group___236 **dev_groups;
	const struct dev_pm_ops___229 *pm;
	void (*coredump)(struct device___229 *);
	struct driver_private *p;
};

struct device_type___229 {
	const char *name;
	const struct attribute_group___236 **groups;
	int (*uevent)(struct device___229 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___229 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___229 *);
	const struct dev_pm_ops___229 *pm;
};

struct class___229 {
	const char *name;
	struct module___232 *owner;
	const struct attribute_group___236 **class_groups;
	const struct attribute_group___236 **dev_groups;
	struct kobject___236 *dev_kobj;
	int (*dev_uevent)(struct device___229 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___229 *, umode_t *);
	void (*class_release)(struct class___229 *);
	void (*dev_release)(struct device___229 *);
	int (*shutdown_pre)(struct device___229 *);
	const struct kobj_ns_type_operations___46 *ns_type;
	const void * (*namespace)(struct device___229 *);
	void (*get_ownership)(struct device___229 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___229 *pm;
	struct subsys_private *p;
};

struct class_attribute___4 {
	struct attribute attr;
	ssize_t (*show)(struct class___229 *, struct class_attribute___4 *, char *);
	ssize_t (*store)(struct class___229 *, struct class_attribute___4 *, const char *, size_t);
};

struct device_attribute___48 {
	struct attribute attr;
	ssize_t (*show)(struct device___229 *, struct device_attribute___48 *, char *);
	ssize_t (*store)(struct device___229 *, struct device_attribute___48 *, const char *, size_t);
};

struct property___77;

struct device_node___103 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___225 fwnode;
	struct property___77 *properties;
	struct property___77 *deadprops;
	struct device_node___103 *parent;
	struct device_node___103 *child;
	struct device_node___103 *sibling;
	struct kobject___236 kobj;
	long unsigned int _flags;
	void *data;
};

struct pipe_buf_operations___89;

struct pipe_buffer___89 {
	struct page___253 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___89 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___89 {
	int (*confirm)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
	void (*release)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
	bool (*try_steal)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
	bool (*get)(struct pipe_inode_info___89 *, struct pipe_buffer___89 *);
};

struct seq_operations___223 {
	void * (*start)(struct seq_file___223 *, loff_t *);
	void (*stop)(struct seq_file___223 *, void *);
	void * (*next)(struct seq_file___223 *, void *, loff_t *);
	int (*show)(struct seq_file___223 *, void *);
};

struct dcbnl_rtnl_ops___57 {
	int (*ieee_getets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___57 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___57 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___57 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___57 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___57 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___57 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___57 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___57 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___57 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___57 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___57 *);
	u8 (*setstate)(struct net_device___57 *, u8);
	void (*getpermhwaddr)(struct net_device___57 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___57 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___57 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___57 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___57 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___57 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___57 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___57 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___57 *, int, u8 *);
	void (*setpfccfg)(struct net_device___57 *, int, u8);
	void (*getpfccfg)(struct net_device___57 *, int, u8 *);
	u8 (*setall)(struct net_device___57 *);
	u8 (*getcap)(struct net_device___57 *, int, u8 *);
	int (*getnumtcs)(struct net_device___57 *, int, u8 *);
	int (*setnumtcs)(struct net_device___57 *, int, u8);
	u8 (*getpfcstate)(struct net_device___57 *);
	void (*setpfcstate)(struct net_device___57 *, u8);
	void (*getbcncfg)(struct net_device___57 *, int, u32 *);
	void (*setbcncfg)(struct net_device___57 *, int, u32);
	void (*getbcnrp)(struct net_device___57 *, int, u8 *);
	void (*setbcnrp)(struct net_device___57 *, int, u8);
	int (*setapp)(struct net_device___57 *, u8, u16, u8);
	int (*getapp)(struct net_device___57 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___57 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___57 *, int, u8);
	u8 (*getdcbx)(struct net_device___57 *);
	u8 (*setdcbx)(struct net_device___57 *, u8);
	int (*peer_getappinfo)(struct net_device___57 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___57 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___57 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___57 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___57 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___57 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___60;

typedef int (*bpf_iter_init_seq_priv_t___59)(void *, struct bpf_iter_aux_info___60 *);

struct bpf_map___60;

struct bpf_iter_aux_info___60 {
	struct bpf_map___60 *map;
};

struct bpf_iter_seq_info___59 {
	const struct seq_operations___223 *seq_ops;
	bpf_iter_init_seq_priv_t___59 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___59 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___60 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___60 *, struct file___248 *);
	void (*map_free)(struct bpf_map___60 *);
	int (*map_get_next_key)(struct bpf_map___60 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___60 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___60 *, void *);
	int (*map_lookup_batch)(struct bpf_map___60 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___60 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___60 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___60 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___60 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___60 *, void *);
	int (*map_update_elem)(struct bpf_map___60 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___60 *, void *);
	int (*map_push_elem)(struct bpf_map___60 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___60 *, void *);
	int (*map_peek_elem)(struct bpf_map___60 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___60 *, struct file___248 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___60 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___60 *, void *, struct seq_file___223 *);
	int (*map_check_btf)(const struct bpf_map___60 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___60 *, struct bpf_prog_aux___60 *);
	void (*map_poke_untrack)(struct bpf_map___60 *, struct bpf_prog_aux___60 *);
	void (*map_poke_run)(struct bpf_map___60 *, u32, struct bpf_prog___53 *, struct bpf_prog___53 *);
	int (*map_direct_value_addr)(const struct bpf_map___60 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___60 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___60 *, struct vm_area_struct___253 *);
	__poll_t (*map_poll)(struct bpf_map___60 *, struct file___248 *, struct poll_table_struct___171 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___60 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___60 *, const struct bpf_map___60 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___60 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___59 *iter_seq_info;
};

struct bpf_map___60 {
	const struct bpf_map_ops___59 *ops;
	struct bpf_map___60 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___115 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___59;

struct bpf_jit_poke_descriptor___59;

struct bpf_prog_ops___53;

struct btf_mod_pair___59;

struct bpf_prog_offload___57;

struct bpf_prog_aux___60 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___53 *dst_prog;
	struct bpf_trampoline___59 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___53 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___59 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___53 *ops;
	struct bpf_map___60 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___59 *used_btfs;
	struct bpf_prog___53 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___60 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___57 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___57;

struct bpf_map_dev_ops___57 {
	int (*map_get_next_key)(struct bpf_offloaded_map___57 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___57 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___57 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___57 *, void *);
};

struct bpf_offloaded_map___57 {
	struct bpf_map___60 map;
	struct net_device___57 *netdev;
	const struct bpf_map_dev_ops___57 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___53 {
	int (*test_run)(struct bpf_prog___53 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___57 {
	struct bpf_prog___53 *prog;
	struct net_device___57 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___59 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___53 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___232 *mod;
};

struct bpf_jit_poke_descriptor___59 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___60 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___59 {
	struct btf *btf;
	struct module___232 *module;
};

struct cftype___175;

struct cgroup_subsys___175 {
	struct cgroup_subsys_state___175 * (*css_alloc)(struct cgroup_subsys_state___175 *);
	int (*css_online)(struct cgroup_subsys_state___175 *);
	void (*css_offline)(struct cgroup_subsys_state___175 *);
	void (*css_released)(struct cgroup_subsys_state___175 *);
	void (*css_free)(struct cgroup_subsys_state___175 *);
	void (*css_reset)(struct cgroup_subsys_state___175 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___175 *, int);
	int (*css_extra_stat_show)(struct seq_file___223 *, struct cgroup_subsys_state___175 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___255 *, struct css_set___175 *);
	void (*cancel_fork)(struct task_struct___255 *, struct css_set___175 *);
	void (*fork)(struct task_struct___255 *);
	void (*exit)(struct task_struct___255 *);
	void (*release)(struct task_struct___255 *);
	void (*bind)(struct cgroup_subsys_state___175 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___175 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___175 *dfl_cftypes;
	struct cftype___175 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___175 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___175 *updated_children;
	struct cgroup___175 *updated_next;
};

struct cgroup_root___175 {
	struct kernfs_root___236 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___175 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___175 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___175 *ss;
	struct list_head node;
	struct kernfs_ops___236 *kf_ops;
	int (*open)(struct kernfs_open_file___236 *);
	void (*release)(struct kernfs_open_file___236 *);
	u64 (*read_u64)(struct cgroup_subsys_state___175 *, struct cftype___175 *);
	s64 (*read_s64)(struct cgroup_subsys_state___175 *, struct cftype___175 *);
	int (*seq_show)(struct seq_file___223 *, void *);
	void * (*seq_start)(struct seq_file___223 *, loff_t *);
	void * (*seq_next)(struct seq_file___223 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___223 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___175 *, struct cftype___175 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___175 *, struct cftype___175 *, s64);
	ssize_t (*write)(struct kernfs_open_file___236 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___236 *, struct poll_table_struct___171 *);
};

struct xdp_rxq_info___57 {
	struct net_device___57 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___57 {
	struct net_device___57 *dev;
};

struct xdp_buff___57 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___57 *rxq;
	struct xdp_txq_info___57 *txq;
	u32 frame_sz;
};

struct xdp_frame___57 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___57 *dev_rx;
};

struct netlink_callback___57 {
	struct sk_buff___58 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___58 *, struct netlink_callback___57 *);
	int (*done)(struct netlink_callback___57 *);
	void *data;
	struct module___232 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___57 {
	int (*create)(struct sk_buff___58 *, struct net_device___57 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___58 *, unsigned char *);
	int (*cache)(const struct neighbour___46 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___57 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___58 *);
};

struct netdev_queue___57 {
	struct net_device___57 *dev;
	struct Qdisc___53 *qdisc;
	struct Qdisc___53 *qdisc_sleeping;
	struct kobject___236 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___57 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___53 {
	struct sk_buff___58 *head;
	struct sk_buff___58 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___53;

struct Qdisc___53 {
	int (*enqueue)(struct sk_buff___58 *, struct Qdisc___53 *, struct sk_buff___58 **);
	struct sk_buff___58 * (*dequeue)(struct Qdisc___53 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___53 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___57 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___57 gso_skb;
	struct qdisc_skb_head___53 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___53 *next_sched;
	struct sk_buff_head___57 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___57 {
	struct xdp_rxq_info___57 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___236 kobj;
	struct net_device___57 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct rx_queue_attribute {
	struct attribute attr;
	ssize_t (*show)(struct netdev_rx_queue___57 *, char *);
	ssize_t (*store)(struct netdev_rx_queue___57 *, const char *, size_t);
};

struct net_device_path___57 {
	enum net_device_path_type type;
	const struct net_device___57 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___57 = 0,
				DEV_PATH_BR_VLAN_TAG___57 = 1,
				DEV_PATH_BR_VLAN_UNTAG___57 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___57 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___57 {
	const struct net_device___57 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___57 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___53 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___57 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___57 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___58 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___57 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___57 *dev;
	const char *name;
};

struct net_device_ops___57 {
	int (*ndo_init)(struct net_device___57 *);
	void (*ndo_uninit)(struct net_device___57 *);
	int (*ndo_open)(struct net_device___57 *);
	int (*ndo_stop)(struct net_device___57 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___58 *, struct net_device___57 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___58 *, struct net_device___57 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___57 *, struct sk_buff___58 *, struct net_device___57 *);
	void (*ndo_change_rx_flags)(struct net_device___57 *, int);
	void (*ndo_set_rx_mode)(struct net_device___57 *);
	int (*ndo_set_mac_address)(struct net_device___57 *, void *);
	int (*ndo_validate_addr)(struct net_device___57 *);
	int (*ndo_do_ioctl)(struct net_device___57 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___57 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___57 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___57 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___57 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___57 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___57 *, int);
	int (*ndo_neigh_setup)(struct net_device___57 *, struct neigh_parms___46 *);
	void (*ndo_tx_timeout)(struct net_device___57 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___57 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___57 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___57 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___57 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___57 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___57 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___57 *);
	int (*ndo_netpoll_setup)(struct net_device___57 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___57 *);
	int (*ndo_set_vf_mac)(struct net_device___57 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___57 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___57 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___57 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___57 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___57 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___57 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___57 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___57 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___57 *, int, struct sk_buff___58 *);
	int (*ndo_get_vf_guid)(struct net_device___57 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___57 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___57 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___57 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___57 *);
	int (*ndo_fcoe_disable)(struct net_device___57 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___57 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___57 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___57 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___57 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___57 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___57 *, const struct sk_buff___58 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___57 *, struct net_device___57 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___57 *, struct net_device___57 *);
	struct net_device___57 * (*ndo_get_xmit_slave)(struct net_device___57 *, struct sk_buff___58 *, bool);
	struct net_device___57 * (*ndo_sk_get_lower_dev)(struct net_device___57 *, struct sock___46 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___57 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___57 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___57 *, struct neighbour___46 *);
	void (*ndo_neigh_destroy)(struct net_device___57 *, struct neighbour___46 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___58 *, struct netlink_callback___57 *, struct net_device___57 *, struct net_device___57 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___58 *, struct nlattr **, struct net_device___57 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___57 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___58 *, u32, u32, struct net_device___57 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___57 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___57 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___57 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___57 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___57 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___57 *, struct net_device___57 *);
	void (*ndo_dfwd_del_station)(struct net_device___57 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___57 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___57 *);
	int (*ndo_change_proto_down)(struct net_device___57 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___57 *, struct sk_buff___58 *);
	void (*ndo_set_rx_headroom)(struct net_device___57 *, int);
	int (*ndo_bpf)(struct net_device___57 *, struct netdev_bpf___57 *);
	int (*ndo_xdp_xmit)(struct net_device___57 *, int, struct xdp_frame___57 **, u32);
	struct net_device___57 * (*ndo_xdp_get_xmit_slave)(struct net_device___57 *, struct xdp_buff___57 *);
	int (*ndo_xsk_wakeup)(struct net_device___57 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___57 *);
	int (*ndo_tunnel_ctl)(struct net_device___57 *, struct ip_tunnel_parm *, int);
	struct net_device___57 * (*ndo_get_peer_dev)(struct net_device___57 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___57 *, struct net_device_path___57 *);
};

struct neigh_parms___46 {
	possible_net_t___57 net;
	struct net_device___57 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___46 *);
	struct neigh_table___46 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___26 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___57 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___57 *);
	void (*get_regs)(struct net_device___57 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___57 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___57 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___57 *);
	void (*set_msglevel)(struct net_device___57 *, u32);
	int (*nway_reset)(struct net_device___57 *);
	u32 (*get_link)(struct net_device___57 *);
	int (*get_link_ext_state)(struct net_device___57 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___57 *);
	int (*get_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___57 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___57 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___57 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___57 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___57 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___57 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___57 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___57 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___57 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___57 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___57 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___57 *);
	void (*complete)(struct net_device___57 *);
	u32 (*get_priv_flags)(struct net_device___57 *);
	int (*set_priv_flags)(struct net_device___57 *, u32);
	int (*get_sset_count)(struct net_device___57 *, int);
	int (*get_rxnfc)(struct net_device___57 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___57 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___57 *, struct ethtool_flash *);
	int (*reset)(struct net_device___57 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___57 *);
	u32 (*get_rxfh_indir_size)(struct net_device___57 *);
	int (*get_rxfh)(struct net_device___57 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___57 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___57 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___57 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___57 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___57 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___57 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___57 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___57 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___57 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___57 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___57 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___57 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___57 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___57 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___57 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___57 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___57 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___57 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___57 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___57 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___57 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___57 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___57 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___57 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___57 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___57 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___57 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___57 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___57 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___57 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___46 {
	u32 (*l3mdev_fib_table)(const struct net_device___57 *);
	struct sk_buff___58 * (*l3mdev_l3_rcv)(struct net_device___57 *, struct sk_buff___58 *, u16);
	struct sk_buff___58 * (*l3mdev_l3_out)(struct net_device___57 *, struct sock___46 *, struct sk_buff___58 *, u16);
	struct dst_entry___46 * (*l3mdev_link_scope_lookup)(const struct net_device___57 *, struct flowi6 *);
};

struct tcf_proto___53;

struct tcf_block___53;

struct mini_Qdisc___53 {
	struct tcf_proto___53 *filter_list;
	struct tcf_block___53 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___53 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___57 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___57 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___62 *, struct net_device___57 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___57 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___57 *, struct list_head *);
	size_t (*get_size)(const struct net_device___57 *);
	int (*fill_info)(struct sk_buff___58 *, const struct net_device___57 *);
	size_t (*get_xstats_size)(const struct net_device___57 *);
	int (*fill_xstats)(struct sk_buff___58 *, const struct net_device___57 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___57 *, struct net_device___57 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___57 *, const struct net_device___57 *);
	int (*fill_slave_info)(struct sk_buff___58 *, const struct net_device___57 *, const struct net_device___57 *);
	struct net___62 * (*get_link_net)(const struct net_device___57 *);
	size_t (*get_linkxstats_size)(const struct net_device___57 *, int);
	int (*fill_linkxstats)(struct sk_buff___58 *, const struct net_device___57 *, int *, int);
};

struct mii_bus___13;

struct mdio_device___13 {
	struct device___229 dev;
	struct mii_bus___13 *bus;
	char modalias[32];
	int (*bus_match)(struct device___229 *, struct device_driver___229 *);
	void (*device_free)(struct mdio_device___13 *);
	void (*device_remove)(struct mdio_device___13 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___10;

struct mii_timestamper___10;

struct phy_device___10 {
	struct mdio_device___13 mdio;
	struct phy_driver___10 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45;
	unsigned int is_internal;
	unsigned int is_pseudo_fixed_link;
	unsigned int is_gigabit_capable;
	unsigned int has_fixups;
	unsigned int suspended;
	unsigned int suspended_by_mdio_bus;
	unsigned int sysfs_links;
	unsigned int loopback_enabled;
	unsigned int downshifted_rate;
	unsigned int is_on_sfp_module;
	unsigned int mac_managed_pm;
	unsigned int autoneg;
	unsigned int link;
	unsigned int autoneg_complete;
	unsigned int interrupts;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___58 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___57 *attached_dev;
	struct mii_timestamper___10 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___10 *, bool);
	void (*adjust_link)(struct net_device___57 *);
	const struct macsec_ops *macsec_ops;
};

struct property___77 {
	char *name;
	int length;
	void *value;
	struct property___77 *next;
	long unsigned int _flags;
	struct bin_attribute___236 attr;
};

struct block_device_operations___141;

struct gendisk___144 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___144 *part0;
	const struct block_device_operations___141 *fops;
	struct request_queue___141 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___127 *bdi;
	struct kobject___236 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___236 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___141 {
	struct bio___141 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___165 *bip_vec;
	struct bio_vec___165 bip_inline_vecs[0];
};

struct blkcg___129;

struct blkg_policy_data___129;

struct blkcg_gq___129 {
	struct request_queue___141 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___129 *blkcg;
	struct blkcg_gq___129 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___129 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___141 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___141(struct request___141 *);

typedef void integrity_complete_fn___141(struct request___141 *, unsigned int);

struct blk_integrity_profile___141 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___141 *prepare_fn;
	integrity_complete_fn___141 *complete_fn;
	const char *name;
};

struct block_device_operations___141 {
	blk_qc_t (*submit_bio)(struct bio___141 *);
	int (*open)(struct block_device___144 *, fmode_t);
	void (*release)(struct gendisk___144 *, fmode_t);
	int (*rw_page)(struct block_device___144 *, sector_t, struct page___253 *, unsigned int);
	int (*ioctl)(struct block_device___144 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___144 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___144 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___144 *);
	int (*getgeo)(struct block_device___144 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___144 *, bool);
	void (*swap_slot_free_notify)(struct block_device___144 *, long unsigned int);
	int (*report_zones)(struct gendisk___144 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___144 *, umode_t *);
	struct module___232 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___144 *, sector_t *);
};

typedef void rq_end_io_fn___141(struct request___141 *, blk_status_t);

struct request___141 {
	struct request_queue___141 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___136 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___141 *bio;
	struct bio___141 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___165 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___141 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___141 *saved_end_io;
		} flush;
	};
	struct gendisk___144 *rq_disk;
	struct block_device___144 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___141 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___136 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___141 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___236 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___248 *debugfs_dir;
	struct dentry___248 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___141;

struct elevator_mq_ops___141 {
	int (*init_sched)(struct request_queue___141 *, struct elevator_type___141 *);
	void (*exit_sched)(struct elevator_queue___141 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___136 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___136 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___136 *);
	bool (*allow_merge)(struct request_queue___141 *, struct request___141 *, struct bio___141 *);
	bool (*bio_merge)(struct request_queue___141 *, struct bio___141 *, unsigned int);
	int (*request_merge)(struct request_queue___141 *, struct request___141 **, struct bio___141 *);
	void (*request_merged)(struct request_queue___141 *, struct request___141 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___141 *, struct request___141 *, struct request___141 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___141 *);
	void (*finish_request)(struct request___141 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___136 *, struct list_head *, bool);
	struct request___141 * (*dispatch_request)(struct blk_mq_hw_ctx___136 *);
	bool (*has_work)(struct blk_mq_hw_ctx___136 *);
	void (*completed_request)(struct request___141 *, u64);
	void (*requeue_request)(struct request___141 *);
	struct request___141 * (*former_request)(struct request_queue___141 *, struct request___141 *);
	struct request___141 * (*next_request)(struct request_queue___141 *, struct request___141 *);
	void (*init_icq)(struct io_cq___141 *);
	void (*exit_icq)(struct io_cq___141 *);
};

struct elv_fs_entry___141;

struct elevator_type___141 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___141 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___141 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___232 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___141 {
	struct elevator_type___141 *type;
	void *elevator_data;
	struct kobject___236 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___141 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___141 *, char *);
	ssize_t (*store)(struct elevator_queue___141 *, const char *, size_t);
};

struct blk_mq_queue_data___136;

struct blk_mq_ops___136 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___136 *, const struct blk_mq_queue_data___136 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___136 *);
	int (*get_budget)(struct request_queue___141 *);
	void (*put_budget)(struct request_queue___141 *, int);
	void (*set_rq_budget_token)(struct request___141 *, int);
	int (*get_rq_budget_token)(struct request___141 *);
	enum blk_eh_timer_return (*timeout)(struct request___141 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___136 *);
	void (*complete)(struct request___141 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___136 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___136 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___136 *, struct request___141 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___136 *, struct request___141 *, unsigned int);
	void (*initialize_rq_fn)(struct request___141 *);
	void (*cleanup_rq)(struct request___141 *);
	bool (*busy)(struct request_queue___141 *);
	int (*map_queues)(struct blk_mq_tag_set___136 *);
	void (*show_rq)(struct seq_file___223 *, struct request___141 *);
};

struct blk_mq_tag_set___136 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___136 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___136 {
	struct request___141 *rq;
	bool last;
};

struct blkcg_policy_data___129;

struct blkcg___129 {
	struct cgroup_subsys_state___175 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___129 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___129 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___129 {
	struct blkcg___129 *blkcg;
	int plid;
};

struct blkg_policy_data___129 {
	struct blkcg_gq___129 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___115 {
	struct mem_cgroup___115 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___115 {
	struct lruvec___123 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___115 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___115 *memcg;
};

struct obj_cgroup___115 {
	struct percpu_ref refcnt;
	struct mem_cgroup___115 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___53 {
	spinlock_t *lock;
	struct sk_buff___58 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___53;

struct Qdisc_ops___53 {
	struct Qdisc_ops___53 *next;
	const struct Qdisc_class_ops___53 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___58 *, struct Qdisc___53 *, struct sk_buff___58 **);
	struct sk_buff___58 * (*dequeue)(struct Qdisc___53 *);
	struct sk_buff___58 * (*peek)(struct Qdisc___53 *);
	int (*init)(struct Qdisc___53 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___53 *);
	void (*destroy)(struct Qdisc___53 *);
	int (*change)(struct Qdisc___53 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___53 *);
	int (*change_tx_queue_len)(struct Qdisc___53 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___53 *, unsigned int);
	int (*dump)(struct Qdisc___53 *, struct sk_buff___58 *);
	int (*dump_stats)(struct Qdisc___53 *, struct gnet_dump___53 *);
	void (*ingress_block_set)(struct Qdisc___53 *, u32);
	void (*egress_block_set)(struct Qdisc___53 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___53 *);
	u32 (*egress_block_get)(struct Qdisc___53 *);
	struct module___232 *owner;
};

struct Qdisc_class_ops___53 {
	unsigned int flags;
	struct netdev_queue___57 * (*select_queue)(struct Qdisc___53 *, struct tcmsg *);
	int (*graft)(struct Qdisc___53 *, long unsigned int, struct Qdisc___53 *, struct Qdisc___53 **, struct netlink_ext_ack *);
	struct Qdisc___53 * (*leaf)(struct Qdisc___53 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___53 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___53 *, u32);
	int (*change)(struct Qdisc___53 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___53 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___53 *, struct qdisc_walker *);
	struct tcf_block___53 * (*tcf_block)(struct Qdisc___53 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___53 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___53 *, long unsigned int);
	int (*dump)(struct Qdisc___53 *, long unsigned int, struct sk_buff___58 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___53 *, long unsigned int, struct gnet_dump___53 *);
};

struct tcf_chain___53;

struct tcf_block___53 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___62 *net;
	struct Qdisc___53 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___53 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___53;

struct tcf_proto_ops___53;

struct tcf_proto___53 {
	struct tcf_proto___53 *next;
	void *root;
	int (*classify)(struct sk_buff___58 *, const struct tcf_proto___53 *, struct tcf_result___53 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___53 *ops;
	struct tcf_chain___53 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___53 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___53 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___53 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___58 *, const struct tcf_proto___53 *, struct tcf_result___53 *);
	int (*init)(struct tcf_proto___53 *);
	void (*destroy)(struct tcf_proto___53 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___53 *, u32);
	void (*put)(struct tcf_proto___53 *, void *);
	int (*change)(struct net___62 *, struct sk_buff___58 *, struct tcf_proto___53 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___53 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___53 *);
	void (*walk)(struct tcf_proto___53 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___53 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___53 *, void *);
	void (*hw_del)(struct tcf_proto___53 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___62 *, struct tcf_chain___53 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___62 *, struct tcf_proto___53 *, void *, struct sk_buff___58 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___62 *, struct tcf_proto___53 *, void *, struct sk_buff___58 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___58 *, struct net___62 *, void *);
	struct module___232 *owner;
	int flags;
};

struct tcf_chain___53 {
	struct mutex filter_chain_lock;
	struct tcf_proto___53 *filter_chain;
	struct list_head list;
	struct tcf_block___53 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___53 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___46 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___53 *prog;
};

struct pneigh_entry___46;

struct neigh_hash_table___46;

struct neigh_table___46 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___57 *, __u32 *);
	bool (*key_eq)(const struct neighbour___46 *, const void *);
	int (*constructor)(struct neighbour___46 *);
	int (*pconstructor)(struct pneigh_entry___46 *);
	void (*pdestructor)(struct pneigh_entry___46 *);
	void (*proxy_redo)(struct sk_buff___58 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___57 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___46 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___57 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___46 *nht;
	struct pneigh_entry___46 **phash_buckets;
};

struct neigh_ops___46 {
	int family;
	void (*solicit)(struct neighbour___46 *, struct sk_buff___58 *);
	void (*error_report)(struct neighbour___46 *, struct sk_buff___58 *);
	int (*output)(struct neighbour___46 *, struct sk_buff___58 *);
	int (*connected_output)(struct neighbour___46 *, struct sk_buff___58 *);
};

struct pneigh_entry___46 {
	struct pneigh_entry___46 *next;
	possible_net_t___57 net;
	struct net_device___57 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___46 {
	struct neighbour___46 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___46 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___46 *ctarget;
	struct net___62 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___46 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___46 *rule;
	u32 table;
	int flags;
};

struct proto___46 {
	void (*close)(struct sock___46 *, long int);
	int (*pre_connect)(struct sock___46 *, struct sockaddr *, int);
	int (*connect)(struct sock___46 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___46 *, int);
	struct sock___46 * (*accept)(struct sock___46 *, int, int *, bool);
	int (*ioctl)(struct sock___46 *, int, long unsigned int);
	int (*init)(struct sock___46 *);
	void (*destroy)(struct sock___46 *);
	void (*shutdown)(struct sock___46 *, int);
	int (*setsockopt)(struct sock___46 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___46 *, int, int, char *, int *);
	void (*keepalive)(struct sock___46 *, int);
	int (*compat_ioctl)(struct sock___46 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___46 *, struct msghdr___48 *, size_t);
	int (*recvmsg)(struct sock___46 *, struct msghdr___48 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___46 *, struct page___253 *, int, size_t, int);
	int (*bind)(struct sock___46 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___46 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___46 *, struct sk_buff___58 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___46 *);
	int (*hash)(struct sock___46 *);
	void (*unhash)(struct sock___46 *);
	void (*rehash)(struct sock___46 *);
	int (*get_port)(struct sock___46 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___46 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___46 *, int);
	bool (*sock_is_readable)(struct sock___46 *);
	void (*enter_memory_pressure)(struct sock___46 *);
	void (*leave_memory_pressure)(struct sock___46 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___232 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___46 *, int);
};

struct mii_bus___13 {
	struct module___232 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___13 *, int, int);
	int (*write)(struct mii_bus___13 *, int, int, u16);
	int (*reset)(struct mii_bus___13 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___229 *parent;
	enum {
		MDIOBUS_ALLOCATED___13 = 1,
		MDIOBUS_REGISTERED___13 = 2,
		MDIOBUS_UNREGISTERED___13 = 3,
		MDIOBUS_RELEASED___13 = 4,
	} state;
	struct device___229 dev;
	struct mdio_device___13 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___13 = 0,
		MDIOBUS_C22___13 = 1,
		MDIOBUS_C45___13 = 2,
		MDIOBUS_C22_C45___13 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___12 {
	struct device_driver___229 driver;
	int flags;
};

struct mii_timestamper___10 {
	bool (*rxtstamp)(struct mii_timestamper___10 *, struct sk_buff___58 *, int);
	void (*txtstamp)(struct mii_timestamper___10 *, struct sk_buff___58 *, int);
	int (*hwtstamp)(struct mii_timestamper___10 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___10 *, struct phy_device___10 *);
	int (*ts_info)(struct mii_timestamper___10 *, struct ethtool_ts_info *);
	struct device___229 *device;
};

struct phy_driver___10 {
	struct mdio_driver_common___12 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___10 *);
	int (*config_init)(struct phy_device___10 *);
	int (*probe)(struct phy_device___10 *);
	int (*get_features)(struct phy_device___10 *);
	int (*suspend)(struct phy_device___10 *);
	int (*resume)(struct phy_device___10 *);
	int (*config_aneg)(struct phy_device___10 *);
	int (*aneg_done)(struct phy_device___10 *);
	int (*read_status)(struct phy_device___10 *);
	int (*config_intr)(struct phy_device___10 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___10 *);
	void (*remove)(struct phy_device___10 *);
	int (*match_phy_device)(struct phy_device___10 *);
	int (*set_wol)(struct phy_device___10 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___10 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___10 *);
	int (*read_mmd)(struct phy_device___10 *, int, u16);
	int (*write_mmd)(struct phy_device___10 *, int, u16, u16);
	int (*read_page)(struct phy_device___10 *);
	int (*write_page)(struct phy_device___10 *, int);
	int (*module_info)(struct phy_device___10 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___10 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___10 *);
	int (*cable_test_tdr_start)(struct phy_device___10 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___10 *, bool *);
	int (*get_sset_count)(struct phy_device___10 *);
	void (*get_strings)(struct phy_device___10 *, u8 *);
	void (*get_stats)(struct phy_device___10 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___10 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___10 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___10 *, bool);
	int (*get_sqi)(struct phy_device___10 *);
	int (*get_sqi_max)(struct phy_device___10 *);
};

struct netdev_queue_attribute {
	struct attribute attr;
	ssize_t (*show)(struct netdev_queue___57 *, char *);
	ssize_t (*store)(struct netdev_queue___57 *, const char *, size_t);
};

struct dentry___249;

struct super_block___249;

struct module___233;

struct file_system_type___249 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___249 * (*mount)(struct file_system_type___249 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___249 *);
	struct module___233 *owner;
	struct file_system_type___249 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___249;

struct kiocb___249;

struct iov_iter___169;

struct vm_area_struct___254;

struct inode___249;

struct file_lock___249;

struct page___254;

struct pipe_inode_info___90;

struct seq_file___224;

struct file_operations___250 {
	struct module___233 *owner;
	loff_t (*llseek)(struct file___249 *, loff_t, int);
	ssize_t (*read)(struct file___249 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___249 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___249 *, struct iov_iter___169 *);
	ssize_t (*write_iter)(struct kiocb___249 *, struct iov_iter___169 *);
	int (*iopoll)(struct kiocb___249 *, bool);
	int (*iterate)(struct file___249 *, struct dir_context *);
	int (*iterate_shared)(struct file___249 *, struct dir_context *);
	__poll_t (*poll)(struct file___249 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___249 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___249 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___249 *, struct vm_area_struct___254 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___249 *, struct file___249 *);
	int (*flush)(struct file___249 *, fl_owner_t);
	int (*release)(struct inode___249 *, struct file___249 *);
	int (*fsync)(struct file___249 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___249 *, int);
	int (*lock)(struct file___249 *, int, struct file_lock___249 *);
	ssize_t (*sendpage)(struct file___249 *, struct page___254 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___249 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___249 *, long unsigned int);
	int (*flock)(struct file___249 *, int, struct file_lock___249 *);
	ssize_t (*splice_write)(struct pipe_inode_info___90 *, struct file___249 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___249 *, loff_t *, struct pipe_inode_info___90 *, size_t, unsigned int);
	int (*setlease)(struct file___249 *, long int, struct file_lock___249 **, void **);
	long int (*fallocate)(struct file___249 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___224 *, struct file___249 *);
	ssize_t (*copy_file_range)(struct file___249 *, loff_t, struct file___249 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___249 *, loff_t, struct file___249 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___249 *, loff_t, loff_t, int);
};

struct vmacache___254 {
	u64 seqnum;
	struct vm_area_struct___254 *vmas[4];
};

struct page_frag___254 {
	struct page___254 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___255;

struct pid___226;

struct nsproxy___235;

struct signal_struct___250;

struct css_set___176;

struct vm_struct___232;

struct task_struct___256 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___256 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___255 *mm;
	struct mm_struct___255 *active_mm;
	struct vmacache___254 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___256 *real_parent;
	struct task_struct___256 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___256 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___226 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___235 *nsproxy;
	struct signal_struct___250 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___256 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___141 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___176 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___90 *splice_pipe;
	struct page_frag___254 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___256 *oom_reaper_list;
	struct vm_struct___232 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___237;

struct kobj_type___237;

struct kernfs_node___237;

struct kobject___237 {
	const char *name;
	struct list_head entry;
	struct kobject___237 *parent;
	struct kset___237 *kset;
	struct kobj_type___237 *ktype;
	struct kernfs_node___237 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___234 {
	struct kobject___237 kobj;
	struct module___233 *mod;
	struct kobject___237 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___233 {
	struct module___233 *mod;
	struct latch_tree_node node;
};

struct module_layout___233 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___233 mtn;
};

struct module_attribute___233;

struct kernel_param___233;

struct module___233 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___234 mkobj;
	struct module_attribute___233 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___237 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___233 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___233 core_layout;
	struct module_layout___233 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___226;

struct upid___226 {
	int nr;
	struct pid_namespace___226 *ns;
};

struct pid_namespace___226 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___256 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___226 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___226 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___226 numbers[1];
};

typedef struct page___254 *pgtable_t___254;

struct address_space___249;

struct page_pool___78;

struct dev_pagemap___244;

struct page___254 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___249 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___78 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___254 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___254 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___255 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___244 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___244;

struct vm_area_struct___254 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___254 *vm_next;
	struct vm_area_struct___254 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___255 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___244 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___249 *vm_file;
	struct file___249 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___250 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___256 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___256 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___226 *pids[4];
	struct pid___226 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___255 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___254;

struct mm_struct___255 {
	struct {
		struct vm_area_struct___254 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___249 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___254 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___256 *owner;
		struct user_namespace___26 *user_ns;
		struct file___249 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___63;

struct cgroup_namespace___176;

struct nsproxy___235 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___226 *pid_ns_for_children;
	struct net___63 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___176 *cgroup_ns;
};

struct cgroup_subsys_state___176;

struct cgroup___176;

struct css_set___176 {
	struct cgroup_subsys_state___176 *subsys[14];
	refcount_t refcount;
	struct css_set___176 *dom_cset;
	struct cgroup___176 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___176 *mg_src_cgrp;
	struct cgroup___176 *mg_dst_cgrp;
	struct css_set___176 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___249;

struct pipe_buffer___90;

struct pipe_inode_info___90 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___254 *tmp_page;
	struct fasync_struct___249 *fasync_readers;
	struct fasync_struct___249 *fasync_writers;
	struct pipe_buffer___90 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___232 {
	struct vm_struct___232 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___254 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___166 {
	struct page___254 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___169 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___166 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___90 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct kiocb___249 {
	struct file___249 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___249 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___58;

struct sk_buff___59 {
	union {
		struct {
			struct sk_buff___59 *next;
			struct sk_buff___59 *prev;
			union {
				struct net_device___58 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___46 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___59 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___63;

struct fqdir___63 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___63 *f;
	struct net___63 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___63;

struct inet_frags___63 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___63 *, const void *);
	void (*destructor)(struct inet_frag_queue___63 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct netns_ipv4___63 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___63 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___63 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___63 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___58 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___59 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___59 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___59 *);
	int (*local_out)(struct net___63 *, struct sock *, struct sk_buff___59 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___59 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___63 {
	struct dst_ops___63 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___63 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___63 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___63 *fqdir;
};

struct sk_buff_head___58 {
	struct sk_buff___59 *next;
	struct sk_buff___59 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___63 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___63 xfrm4_dst_ops;
	struct dst_ops___63 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___63 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___58 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___63 ipv4;
	struct netns_ipv6___63 ipv6;
	struct netns_ieee802154_lowpan___63 ieee802154_lowpan;
	struct netns_sctp___46 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___58 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___53 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___63 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___63 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___59 *fragments_tail;
	struct sk_buff___59 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___63 *fqdir;
	struct callback_head rcu;
};

struct address_space_operations___249;

struct address_space___249 {
	struct inode___249 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___249 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___230;

struct page_pool_params___78 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___230 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___78 {
	u32 count;
	struct page___254 *cache[128];
};

struct page_pool___78 {
	struct page_pool_params___78 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___254 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___78 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___244;

struct dev_pagemap___244 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___244 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___249;

struct path___249 {
	struct vfsmount___249 *mnt;
	struct dentry___249 *dentry;
};

struct fown_struct___226 {
	rwlock_t lock;
	struct pid___226 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___249 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___249 f_path;
	struct inode___249 *f_inode;
	const struct file_operations___250 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___226 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___249 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___244;

struct vm_operations_struct___244 {
	void (*open)(struct vm_area_struct___254 *);
	void (*close)(struct vm_area_struct___254 *);
	int (*may_split)(struct vm_area_struct___254 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___254 *);
	int (*mprotect)(struct vm_area_struct___254 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___244 *);
	vm_fault_t (*huge_fault)(struct vm_fault___244 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___244 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___254 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___244 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___244 *);
	int (*access)(struct vm_area_struct___254 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___254 *);
	int (*set_policy)(struct vm_area_struct___254 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___254 *, long unsigned int);
	struct page___254 * (*find_special_page)(struct vm_area_struct___254 *, long unsigned int);
};

struct core_thread___254 {
	struct task_struct___256 *task;
	struct core_thread___254 *next;
};

struct core_state___254 {
	atomic_t nr_threads;
	struct core_thread___254 dumper;
	struct completion startup;
};

struct vm_fault___244 {
	const struct {
		struct vm_area_struct___254 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___254 *cow_page;
	struct page___254 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___254 prealloc_pte;
};

typedef rx_handler_result_t rx_handler_func_t___58(struct sk_buff___59 **);

typedef struct {
	struct net___63 *net;
} possible_net_t___58;

struct wakeup_source___230;

struct dev_pm_info___230 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___230 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___230 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___230;

struct bus_type___230;

struct device_driver___230;

struct dev_pm_domain___230;

struct fwnode_handle___226;

struct class___230;

struct attribute_group___237;

struct device___230 {
	struct kobject___237 kobj;
	struct device___230 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___230 *type;
	struct bus_type___230 *bus;
	struct device_driver___230 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___230 power;
	struct dev_pm_domain___230 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___226 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___230 *class;
	const struct attribute_group___237 **groups;
	void (*release)(struct device___230 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_name_node___58;

struct net_device_ops___58;

struct iw_handler_def___4;

struct xfrmdev_ops___58;

struct header_ops___58;

struct netdev_rx_queue___58;

struct netdev_queue___58;

struct dcbnl_rtnl_ops___58;

struct net_device___58 {
	char name[16];
	struct netdev_name_node___58 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___58 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def___4 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___58 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___58 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___237 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___58 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___58 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___58 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___58 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___58 = 0,
		NETREG_REGISTERED___58 = 1,
		NETREG_UNREGISTERING___58 = 2,
		NETREG_UNREGISTERED___58 = 3,
		NETREG_RELEASED___58 = 4,
		NETREG_DUMMY___58 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___58 = 0,
		RTNL_LINK_INITIALIZING___58 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___58 *);
	struct netpoll_info *npinfo;
	possible_net_t___58 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___230 dev;
	const struct attribute_group___237 *sysfs_groups[4];
	const struct attribute_group___237 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___58 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___53 xdp_state[3];
	long: 64;
};

struct dentry_operations___249;

struct dentry___249 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___249 *d_parent;
	struct qstr d_name;
	struct inode___249 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___249 *d_op;
	struct super_block___249 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___249;

struct inode___249 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___249 *i_op;
	struct super_block___249 *i_sb;
	struct address_space___249 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___250 *i_fop;
		void (*free_inode)(struct inode___249 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___249 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___90 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___249 {
	int (*d_revalidate)(struct dentry___249 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___249 *, unsigned int);
	int (*d_hash)(const struct dentry___249 *, struct qstr *);
	int (*d_compare)(const struct dentry___249 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___249 *);
	int (*d_init)(struct dentry___249 *);
	void (*d_release)(struct dentry___249 *);
	void (*d_prune)(struct dentry___249 *);
	void (*d_iput)(struct dentry___249 *, struct inode___249 *);
	char * (*d_dname)(struct dentry___249 *, char *, int);
	struct vfsmount___249 * (*d_automount)(struct path___249 *);
	int (*d_manage)(const struct path___249 *, bool);
	struct dentry___249 * (*d_real)(struct dentry___249 *, const struct inode___249 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___249;

struct mem_dqinfo___249 {
	struct quota_format_type___249 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___249;

struct quota_info___249 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___249 *files[3];
	struct mem_dqinfo___249 info[3];
	const struct quota_format_ops___249 *ops[3];
};

struct rcuwait___250 {
	struct task_struct___256 *task;
};

struct percpu_rw_semaphore___250 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___250 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___249 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___250 rw_sem[3];
};

struct super_operations___249;

struct dquot_operations___249;

struct quotactl_ops___249;

struct super_block___249 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___249 *s_type;
	const struct super_operations___249 *s_op;
	const struct dquot_operations___249 *dq_op;
	const struct quotactl_ops___249 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___249 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___249 s_dquot;
	struct sb_writers___249 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___249 *s_d_op;
	int cleancache_poolid;
	struct shrinker___115 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___249 {
	struct dentry___249 *mnt_root;
	struct super_block___249 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct cgroup_subsys___176;

struct cgroup_subsys_state___176 {
	struct cgroup___176 *cgroup;
	struct cgroup_subsys___176 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___176 *parent;
};

struct cgroup_file___176 {
	struct kernfs_node___237 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___176 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___256 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___176;

struct cgroup_rstat_cpu___176;

struct cgroup___176 {
	struct cgroup_subsys_state___176 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___237 *kn;
	struct cgroup_file___176 procs_file;
	struct cgroup_file___176 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___176 *subsys[14];
	struct cgroup_root___176 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___176 *dom_cgrp;
	struct cgroup___176 *old_dom_cgrp;
	struct cgroup_rstat_cpu___176 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___176 psi;
	struct cgroup_bpf___53 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___249 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___249 *ia_file;
};

struct dquot___249 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___249 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___249 {
	int qf_fmt_id;
	const struct quota_format_ops___249 *qf_ops;
	struct module___233 *qf_owner;
	struct quota_format_type___249 *qf_next;
};

struct quota_format_ops___249 {
	int (*check_quota_file)(struct super_block___249 *, int);
	int (*read_file_info)(struct super_block___249 *, int);
	int (*write_file_info)(struct super_block___249 *, int);
	int (*free_file_info)(struct super_block___249 *, int);
	int (*read_dqblk)(struct dquot___249 *);
	int (*commit_dqblk)(struct dquot___249 *);
	int (*release_dqblk)(struct dquot___249 *);
	int (*get_next_id)(struct super_block___249 *, struct kqid *);
};

struct dquot_operations___249 {
	int (*write_dquot)(struct dquot___249 *);
	struct dquot___249 * (*alloc_dquot)(struct super_block___249 *, int);
	void (*destroy_dquot)(struct dquot___249 *);
	int (*acquire_dquot)(struct dquot___249 *);
	int (*release_dquot)(struct dquot___249 *);
	int (*mark_dirty)(struct dquot___249 *);
	int (*write_info)(struct super_block___249 *, int);
	qsize_t * (*get_reserved_space)(struct inode___249 *);
	int (*get_projid)(struct inode___249 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___249 *, qsize_t *);
	int (*get_next_id)(struct super_block___249 *, struct kqid *);
};

struct quotactl_ops___249 {
	int (*quota_on)(struct super_block___249 *, int, int, const struct path___249 *);
	int (*quota_off)(struct super_block___249 *, int);
	int (*quota_enable)(struct super_block___249 *, unsigned int);
	int (*quota_disable)(struct super_block___249 *, unsigned int);
	int (*quota_sync)(struct super_block___249 *, int);
	int (*set_info)(struct super_block___249 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___249 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___249 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___249 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___249 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___249 *, unsigned int);
};

struct address_space_operations___249 {
	int (*writepage)(struct page___254 *, struct writeback_control___3 *);
	int (*readpage)(struct file___249 *, struct page___254 *);
	int (*writepages)(struct address_space___249 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___254 *);
	int (*readpages)(struct file___249 *, struct address_space___249 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___249 *, struct address_space___249 *, loff_t, unsigned int, unsigned int, struct page___254 **, void **);
	int (*write_end)(struct file___249 *, struct address_space___249 *, loff_t, unsigned int, unsigned int, struct page___254 *, void *);
	sector_t (*bmap)(struct address_space___249 *, sector_t);
	void (*invalidatepage)(struct page___254 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___254 *, gfp_t);
	void (*freepage)(struct page___254 *);
	ssize_t (*direct_IO)(struct kiocb___249 *, struct iov_iter___169 *);
	int (*migratepage)(struct address_space___249 *, struct page___254 *, struct page___254 *, enum migrate_mode);
	bool (*isolate_page)(struct page___254 *, isolate_mode_t);
	void (*putback_page)(struct page___254 *);
	int (*launder_page)(struct page___254 *);
	int (*is_partially_uptodate)(struct page___254 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___254 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___249 *, struct page___254 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___249 *, sector_t *);
	void (*swap_deactivate)(struct file___249 *);
};

struct inode_operations___249 {
	struct dentry___249 * (*lookup)(struct inode___249 *, struct dentry___249 *, unsigned int);
	const char * (*get_link)(struct dentry___249 *, struct inode___249 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___249 *, int);
	struct posix_acl * (*get_acl)(struct inode___249 *, int, bool);
	int (*readlink)(struct dentry___249 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___249 *, struct dentry___249 *, umode_t, bool);
	int (*link)(struct dentry___249 *, struct inode___249 *, struct dentry___249 *);
	int (*unlink)(struct inode___249 *, struct dentry___249 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___249 *, struct dentry___249 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___249 *, struct dentry___249 *, umode_t);
	int (*rmdir)(struct inode___249 *, struct dentry___249 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___249 *, struct dentry___249 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___249 *, struct dentry___249 *, struct inode___249 *, struct dentry___249 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___249 *, struct iattr___249 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___249 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___249 *, char *, size_t);
	int (*fiemap)(struct inode___249 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___249 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___249 *, struct dentry___249 *, struct file___249 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___249 *, struct dentry___249 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___249 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___249 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___249 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___249 {
	void (*fl_copy_lock)(struct file_lock___249 *, struct file_lock___249 *);
	void (*fl_release_private)(struct file_lock___249 *);
};

struct lock_manager_operations___249;

struct file_lock___249 {
	struct file_lock___249 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___249 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___249 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___249 *fl_ops;
	const struct lock_manager_operations___249 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___249 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___249 *);
	int (*lm_grant)(struct file_lock___249 *, int);
	bool (*lm_break)(struct file_lock___249 *);
	int (*lm_change)(struct file_lock___249 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___249 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___249 *);
};

struct fasync_struct___249 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___249 *fa_next;
	struct file___249 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___249 {
	struct inode___249 * (*alloc_inode)(struct super_block___249 *);
	void (*destroy_inode)(struct inode___249 *);
	void (*free_inode)(struct inode___249 *);
	void (*dirty_inode)(struct inode___249 *, int);
	int (*write_inode)(struct inode___249 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___249 *);
	void (*evict_inode)(struct inode___249 *);
	void (*put_super)(struct super_block___249 *);
	int (*sync_fs)(struct super_block___249 *, int);
	int (*freeze_super)(struct super_block___249 *);
	int (*freeze_fs)(struct super_block___249 *);
	int (*thaw_super)(struct super_block___249 *);
	int (*unfreeze_fs)(struct super_block___249 *);
	int (*statfs)(struct dentry___249 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___249 *, int *, char *);
	void (*umount_begin)(struct super_block___249 *);
	int (*show_options)(struct seq_file___224 *, struct dentry___249 *);
	int (*show_devname)(struct seq_file___224 *, struct dentry___249 *);
	int (*show_path)(struct seq_file___224 *, struct dentry___249 *);
	int (*show_stats)(struct seq_file___224 *, struct dentry___249 *);
	ssize_t (*quota_read)(struct super_block___249 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___249 *, int, const char *, size_t, loff_t);
	struct dquot___249 ** (*get_dquots)(struct inode___249 *);
	long int (*nr_cached_objects)(struct super_block___249 *, struct shrink_control___115 *);
	long int (*free_cached_objects)(struct super_block___249 *, struct shrink_control___115 *);
	struct file___249 * (*real_loop)(struct file___249 *);
};

struct seq_operations___224;

struct seq_file___224 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___224 *op;
	int poll_event;
	const struct file___249 *file;
	void *private;
};

struct dev_pagemap_ops___244 {
	void (*page_free)(struct page___254 *);
	void (*kill)(struct dev_pagemap___244 *);
	void (*cleanup)(struct dev_pagemap___244 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___244 *);
};

struct fwnode_operations___226;

struct fwnode_handle___226 {
	struct fwnode_handle___226 *secondary;
	const struct fwnode_operations___226 *ops;
	struct device___230 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___226;

struct fwnode_endpoint___226;

struct fwnode_operations___226 {
	struct fwnode_handle___226 * (*get)(struct fwnode_handle___226 *);
	void (*put)(struct fwnode_handle___226 *);
	bool (*device_is_available)(const struct fwnode_handle___226 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___226 *, const struct device___230 *);
	bool (*property_present)(const struct fwnode_handle___226 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___226 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___226 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___226 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*get_parent)(const struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*get_next_child_node)(const struct fwnode_handle___226 *, struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*get_named_child_node)(const struct fwnode_handle___226 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___226 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___226 *);
	struct fwnode_handle___226 * (*graph_get_next_endpoint)(const struct fwnode_handle___226 *, struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*graph_get_remote_endpoint)(const struct fwnode_handle___226 *);
	struct fwnode_handle___226 * (*graph_get_port_parent)(struct fwnode_handle___226 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___226 *, struct fwnode_endpoint___226 *);
	int (*add_links)(struct fwnode_handle___226 *);
};

struct fwnode_endpoint___226 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___226 *local_fwnode;
};

struct fwnode_reference_args___226 {
	struct fwnode_handle___226 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___237;

struct kernfs_elem_dir___237 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___237 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___237;

struct kernfs_root___237 {
	struct kernfs_node___237 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___237 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___237 {
	struct kernfs_node___237 *target_kn;
};

struct kernfs_ops___237;

struct kernfs_elem_attr___237 {
	const struct kernfs_ops___237 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___237 *notify_next;
};

struct kernfs_node___237 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___237 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___237 dir;
		struct kernfs_elem_symlink___237 symlink;
		struct kernfs_elem_attr___237 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___237;

struct kernfs_ops___237 {
	int (*open)(struct kernfs_open_file___237 *);
	void (*release)(struct kernfs_open_file___237 *);
	int (*seq_show)(struct seq_file___224 *, void *);
	void * (*seq_start)(struct seq_file___224 *, loff_t *);
	void * (*seq_next)(struct seq_file___224 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___224 *, void *);
	ssize_t (*read)(struct kernfs_open_file___237 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___237 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___237 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___237 *, struct vm_area_struct___254 *);
};

struct kernfs_syscall_ops___237 {
	int (*show_options)(struct seq_file___224 *, struct kernfs_root___237 *);
	int (*mkdir)(struct kernfs_node___237 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___237 *);
	int (*rename)(struct kernfs_node___237 *, struct kernfs_node___237 *, const char *);
	int (*show_path)(struct seq_file___224 *, struct kernfs_node___237 *, struct kernfs_root___237 *);
};

struct kernfs_open_file___237 {
	struct kernfs_node___237 *kn;
	struct file___249 *file;
	struct seq_file___224 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___244 *vm_ops;
};

struct bin_attribute___237;

struct attribute_group___237 {
	const char *name;
	umode_t (*is_visible)(struct kobject___237 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___237 *, struct bin_attribute___237 *, int);
	struct attribute **attrs;
	struct bin_attribute___237 **bin_attrs;
};

struct bin_attribute___237 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___249 * (*f_mapping)();
	ssize_t (*read)(struct file___249 *, struct kobject___237 *, struct bin_attribute___237 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___249 *, struct kobject___237 *, struct bin_attribute___237 *, char *, loff_t, size_t);
	int (*mmap)(struct file___249 *, struct kobject___237 *, struct bin_attribute___237 *, struct vm_area_struct___254 *);
};

struct sysfs_ops___237 {
	ssize_t (*show)(struct kobject___237 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___237 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___237;

struct kset___237 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___237 kobj;
	const struct kset_uevent_ops___237 *uevent_ops;
};

struct kobj_type___237 {
	void (*release)(struct kobject___237 *);
	const struct sysfs_ops___237 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___237 **default_groups;
	const struct kobj_ns_type_operations___46 * (*child_ns_type)(struct kobject___237 *);
	const void * (*namespace)(struct kobject___237 *);
	void (*get_ownership)(struct kobject___237 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___237 {
	int (* const filter)(struct kset___237 *, struct kobject___237 *);
	const char * (* const name)(struct kset___237 *, struct kobject___237 *);
	int (* const uevent)(struct kset___237 *, struct kobject___237 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___233 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___233 *);
	int (*get)(char *, const struct kernel_param___233 *);
	void (*free)(void *);
};

struct kparam_array___233;

struct kernel_param___233 {
	const char *name;
	struct module___233 *mod;
	const struct kernel_param_ops___233 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___233 *arr;
	};
};

struct kparam_array___233 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___233 *ops;
	void *elem;
};

struct module_attribute___233 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___233 *, struct module_kobject___234 *, char *);
	ssize_t (*store)(struct module_attribute___233 *, struct module_kobject___234 *, const char *, size_t);
	void (*setup)(struct module___233 *, const char *);
	int (*test)(struct module___233 *);
	void (*free)(struct module___233 *);
};

struct cgroup_namespace___176 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___176 *root_cset;
};

struct dev_pm_ops___230 {
	int (*prepare)(struct device___230 *);
	void (*complete)(struct device___230 *);
	int (*suspend)(struct device___230 *);
	int (*resume)(struct device___230 *);
	int (*freeze)(struct device___230 *);
	int (*thaw)(struct device___230 *);
	int (*poweroff)(struct device___230 *);
	int (*restore)(struct device___230 *);
	int (*suspend_late)(struct device___230 *);
	int (*resume_early)(struct device___230 *);
	int (*freeze_late)(struct device___230 *);
	int (*thaw_early)(struct device___230 *);
	int (*poweroff_late)(struct device___230 *);
	int (*restore_early)(struct device___230 *);
	int (*suspend_noirq)(struct device___230 *);
	int (*resume_noirq)(struct device___230 *);
	int (*freeze_noirq)(struct device___230 *);
	int (*thaw_noirq)(struct device___230 *);
	int (*poweroff_noirq)(struct device___230 *);
	int (*restore_noirq)(struct device___230 *);
	int (*runtime_suspend)(struct device___230 *);
	int (*runtime_resume)(struct device___230 *);
	int (*runtime_idle)(struct device___230 *);
};

struct wakeup_source___230 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___230 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___230 {
	struct dev_pm_ops___230 ops;
	int (*start)(struct device___230 *);
	void (*detach)(struct device___230 *, bool);
	int (*activate)(struct device___230 *);
	void (*sync)(struct device___230 *);
	void (*dismiss)(struct device___230 *);
};

struct bus_type___230 {
	const char *name;
	const char *dev_name;
	struct device___230 *dev_root;
	const struct attribute_group___237 **bus_groups;
	const struct attribute_group___237 **dev_groups;
	const struct attribute_group___237 **drv_groups;
	int (*match)(struct device___230 *, struct device_driver___230 *);
	int (*uevent)(struct device___230 *, struct kobj_uevent_env *);
	int (*probe)(struct device___230 *);
	void (*sync_state)(struct device___230 *);
	void (*remove)(struct device___230 *);
	void (*shutdown)(struct device___230 *);
	int (*online)(struct device___230 *);
	int (*offline)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	int (*num_vf)(struct device___230 *);
	int (*dma_configure)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___230 {
	const char *name;
	struct bus_type___230 *bus;
	struct module___233 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___230 *);
	void (*sync_state)(struct device___230 *);
	int (*remove)(struct device___230 *);
	void (*shutdown)(struct device___230 *);
	int (*suspend)(struct device___230 *, pm_message_t);
	int (*resume)(struct device___230 *);
	const struct attribute_group___237 **groups;
	const struct attribute_group___237 **dev_groups;
	const struct dev_pm_ops___230 *pm;
	void (*coredump)(struct device___230 *);
	struct driver_private *p;
};

struct device_type___230 {
	const char *name;
	const struct attribute_group___237 **groups;
	int (*uevent)(struct device___230 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___230 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___230 *);
	const struct dev_pm_ops___230 *pm;
};

struct class___230 {
	const char *name;
	struct module___233 *owner;
	const struct attribute_group___237 **class_groups;
	const struct attribute_group___237 **dev_groups;
	struct kobject___237 *dev_kobj;
	int (*dev_uevent)(struct device___230 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___230 *, umode_t *);
	void (*class_release)(struct class___230 *);
	void (*dev_release)(struct device___230 *);
	int (*shutdown_pre)(struct device___230 *);
	const struct kobj_ns_type_operations___46 *ns_type;
	const void * (*namespace)(struct device___230 *);
	void (*get_ownership)(struct device___230 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___230 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___90;

struct pipe_buffer___90 {
	struct page___254 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___90 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___90 {
	int (*confirm)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
	void (*release)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
	bool (*try_steal)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
	bool (*get)(struct pipe_inode_info___90 *, struct pipe_buffer___90 *);
};

struct seq_operations___224 {
	void * (*start)(struct seq_file___224 *, loff_t *);
	void (*stop)(struct seq_file___224 *, void *);
	void * (*next)(struct seq_file___224 *, void *, loff_t *);
	int (*show)(struct seq_file___224 *, void *);
};

struct seq_net_private___3 {
	struct net___63 *net;
};

struct pernet_operations___13 {
	struct list_head list;
	int (*init)(struct net___63 *);
	void (*pre_exit)(struct net___63 *);
	void (*exit)(struct net___63 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___58 {
	int (*ieee_getets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___58 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___58 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___58 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___58 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___58 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___58 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___58 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___58 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___58 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___58 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___58 *);
	u8 (*setstate)(struct net_device___58 *, u8);
	void (*getpermhwaddr)(struct net_device___58 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___58 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___58 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___58 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___58 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___58 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___58 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___58 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___58 *, int, u8 *);
	void (*setpfccfg)(struct net_device___58 *, int, u8);
	void (*getpfccfg)(struct net_device___58 *, int, u8 *);
	u8 (*setall)(struct net_device___58 *);
	u8 (*getcap)(struct net_device___58 *, int, u8 *);
	int (*getnumtcs)(struct net_device___58 *, int, u8 *);
	int (*setnumtcs)(struct net_device___58 *, int, u8);
	u8 (*getpfcstate)(struct net_device___58 *);
	void (*setpfcstate)(struct net_device___58 *, u8);
	void (*getbcncfg)(struct net_device___58 *, int, u32 *);
	void (*setbcncfg)(struct net_device___58 *, int, u32);
	void (*getbcnrp)(struct net_device___58 *, int, u8 *);
	void (*setbcnrp)(struct net_device___58 *, int, u8);
	int (*setapp)(struct net_device___58 *, u8, u16, u8);
	int (*getapp)(struct net_device___58 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___58 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___58 *, int, u8);
	u8 (*getdcbx)(struct net_device___58 *);
	u8 (*setdcbx)(struct net_device___58 *, u8);
	int (*peer_getappinfo)(struct net_device___58 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___58 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___58 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___58 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___58 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___58 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___61;

typedef int (*bpf_iter_init_seq_priv_t___60)(void *, struct bpf_iter_aux_info___61 *);

struct bpf_map___61;

struct bpf_iter_aux_info___61 {
	struct bpf_map___61 *map;
};

struct bpf_iter_seq_info___60 {
	const struct seq_operations___224 *seq_ops;
	bpf_iter_init_seq_priv_t___60 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___61;

struct bpf_map_ops___60 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___61 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___61 *, struct file___249 *);
	void (*map_free)(struct bpf_map___61 *);
	int (*map_get_next_key)(struct bpf_map___61 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___61 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___61 *, void *);
	int (*map_lookup_batch)(struct bpf_map___61 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___61 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___61 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___61 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___61 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___61 *, void *);
	int (*map_update_elem)(struct bpf_map___61 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___61 *, void *);
	int (*map_push_elem)(struct bpf_map___61 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___61 *, void *);
	int (*map_peek_elem)(struct bpf_map___61 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___61 *, struct file___249 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___61 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___61 *, void *, struct seq_file___224 *);
	int (*map_check_btf)(const struct bpf_map___61 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___61 *, struct bpf_prog_aux___61 *);
	void (*map_poke_untrack)(struct bpf_map___61 *, struct bpf_prog_aux___61 *);
	void (*map_poke_run)(struct bpf_map___61 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___61 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___61 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___61 *, struct vm_area_struct___254 *);
	__poll_t (*map_poll)(struct bpf_map___61 *, struct file___249 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___61 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___61 *, const struct bpf_map___61 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___61 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___60 *iter_seq_info;
};

struct bpf_map___61 {
	const struct bpf_map_ops___60 *ops;
	struct bpf_map___61 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___60;

struct bpf_jit_poke_descriptor___60;

struct btf_mod_pair___60;

struct bpf_prog_offload___58;

struct bpf_prog_aux___61 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___60 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___60 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___53 *ops;
	struct bpf_map___61 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___60 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___61 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___58 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___58;

struct bpf_map_dev_ops___58 {
	int (*map_get_next_key)(struct bpf_offloaded_map___58 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___58 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___58 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___58 *, void *);
};

struct bpf_offloaded_map___58 {
	struct bpf_map___61 map;
	struct net_device___58 *netdev;
	const struct bpf_map_dev_ops___58 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___58 {
	struct bpf_prog *prog;
	struct net_device___58 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___60 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___233 *mod;
};

struct bpf_jit_poke_descriptor___60 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___61 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___60 {
	struct btf *btf;
	struct module___233 *module;
};

struct cftype___176;

struct cgroup_subsys___176 {
	struct cgroup_subsys_state___176 * (*css_alloc)(struct cgroup_subsys_state___176 *);
	int (*css_online)(struct cgroup_subsys_state___176 *);
	void (*css_offline)(struct cgroup_subsys_state___176 *);
	void (*css_released)(struct cgroup_subsys_state___176 *);
	void (*css_free)(struct cgroup_subsys_state___176 *);
	void (*css_reset)(struct cgroup_subsys_state___176 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___176 *, int);
	int (*css_extra_stat_show)(struct seq_file___224 *, struct cgroup_subsys_state___176 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___256 *, struct css_set___176 *);
	void (*cancel_fork)(struct task_struct___256 *, struct css_set___176 *);
	void (*fork)(struct task_struct___256 *);
	void (*exit)(struct task_struct___256 *);
	void (*release)(struct task_struct___256 *);
	void (*bind)(struct cgroup_subsys_state___176 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___176 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___176 *dfl_cftypes;
	struct cftype___176 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___176 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___176 *updated_children;
	struct cgroup___176 *updated_next;
};

struct cgroup_root___176 {
	struct kernfs_root___237 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___176 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___176 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___176 *ss;
	struct list_head node;
	struct kernfs_ops___237 *kf_ops;
	int (*open)(struct kernfs_open_file___237 *);
	void (*release)(struct kernfs_open_file___237 *);
	u64 (*read_u64)(struct cgroup_subsys_state___176 *, struct cftype___176 *);
	s64 (*read_s64)(struct cgroup_subsys_state___176 *, struct cftype___176 *);
	int (*seq_show)(struct seq_file___224 *, void *);
	void * (*seq_start)(struct seq_file___224 *, loff_t *);
	void * (*seq_next)(struct seq_file___224 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___224 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___176 *, struct cftype___176 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___176 *, struct cftype___176 *, s64);
	ssize_t (*write)(struct kernfs_open_file___237 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___237 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___58 {
	struct net_device___58 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___58 {
	struct net_device___58 *dev;
};

struct xdp_buff___58 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___58 *rxq;
	struct xdp_txq_info___58 *txq;
	u32 frame_sz;
};

struct xdp_frame___58 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___58 *dev_rx;
};

struct netlink_callback___58 {
	struct sk_buff___59 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___59 *, struct netlink_callback___58 *);
	int (*done)(struct netlink_callback___58 *);
	void *data;
	struct module___233 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___58 {
	int (*create)(struct sk_buff___59 *, struct net_device___58 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___59 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___58 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___59 *);
};

struct napi_struct___11 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___11 *, int);
	int poll_owner;
	struct net_device___58 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___59 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___256 *thread;
};

struct netdev_queue___58 {
	struct net_device___58 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___237 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___58 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___58 {
	struct xdp_rxq_info___58 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___237 kobj;
	struct net_device___58 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___58 {
	enum net_device_path_type type;
	const struct net_device___58 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___58 = 0,
				DEV_PATH_BR_VLAN_TAG___58 = 1,
				DEV_PATH_BR_VLAN_UNTAG___58 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___58 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___58 {
	const struct net_device___58 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___58 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___53 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___58 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___58 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___59 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___58 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___58 *dev;
	const char *name;
};

struct net_device_ops___58 {
	int (*ndo_init)(struct net_device___58 *);
	void (*ndo_uninit)(struct net_device___58 *);
	int (*ndo_open)(struct net_device___58 *);
	int (*ndo_stop)(struct net_device___58 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___59 *, struct net_device___58 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___59 *, struct net_device___58 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___58 *, struct sk_buff___59 *, struct net_device___58 *);
	void (*ndo_change_rx_flags)(struct net_device___58 *, int);
	void (*ndo_set_rx_mode)(struct net_device___58 *);
	int (*ndo_set_mac_address)(struct net_device___58 *, void *);
	int (*ndo_validate_addr)(struct net_device___58 *);
	int (*ndo_do_ioctl)(struct net_device___58 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___58 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___58 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___58 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___58 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___58 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___58 *, int);
	int (*ndo_neigh_setup)(struct net_device___58 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___58 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___58 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___58 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___58 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___58 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___58 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___58 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___58 *);
	int (*ndo_netpoll_setup)(struct net_device___58 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___58 *);
	int (*ndo_set_vf_mac)(struct net_device___58 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___58 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___58 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___58 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___58 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___58 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___58 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___58 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___58 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___58 *, int, struct sk_buff___59 *);
	int (*ndo_get_vf_guid)(struct net_device___58 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___58 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___58 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___58 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___58 *);
	int (*ndo_fcoe_disable)(struct net_device___58 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___58 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___58 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___58 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___58 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___58 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___58 *, const struct sk_buff___59 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___58 *, struct net_device___58 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___58 *, struct net_device___58 *);
	struct net_device___58 * (*ndo_get_xmit_slave)(struct net_device___58 *, struct sk_buff___59 *, bool);
	struct net_device___58 * (*ndo_sk_get_lower_dev)(struct net_device___58 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___58 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___58 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___58 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___58 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___59 *, struct netlink_callback___58 *, struct net_device___58 *, struct net_device___58 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___59 *, struct nlattr **, struct net_device___58 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___58 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___59 *, u32, u32, struct net_device___58 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___58 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___58 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___58 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___58 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___58 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___58 *, struct net_device___58 *);
	void (*ndo_dfwd_del_station)(struct net_device___58 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___58 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___58 *);
	int (*ndo_change_proto_down)(struct net_device___58 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___58 *, struct sk_buff___59 *);
	void (*ndo_set_rx_headroom)(struct net_device___58 *, int);
	int (*ndo_bpf)(struct net_device___58 *, struct netdev_bpf___58 *);
	int (*ndo_xdp_xmit)(struct net_device___58 *, int, struct xdp_frame___58 **, u32);
	struct net_device___58 * (*ndo_xdp_get_xmit_slave)(struct net_device___58 *, struct xdp_buff___58 *);
	int (*ndo_xsk_wakeup)(struct net_device___58 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___58 *);
	int (*ndo_tunnel_ctl)(struct net_device___58 *, struct ip_tunnel_parm *, int);
	struct net_device___58 * (*ndo_get_peer_dev)(struct net_device___58 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___58 *, struct net_device_path___58 *);
};

typedef int (*iw_handler___4)(struct net_device___58 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___4 {
	const iw_handler___4 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___4 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___58 *);
};

struct packet_type___2 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___58 *dev;
	int (*func)(struct sk_buff___59 *, struct net_device___58 *, struct packet_type___2 *, struct net_device___58 *);
	void (*list_func)(struct list_head *, struct packet_type___2 *, struct net_device___58 *);
	bool (*id_match)(struct packet_type___2 *, struct sock *);
	struct net___63 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct softnet_data___5 {
	struct list_head poll_list;
	struct sk_buff_head___58 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___5 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___35 *output_queue;
	struct Qdisc___35 **output_queue_tailp;
	struct sk_buff___59 *completion_queue;
	struct sk_buff_head___58 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___5 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___58 input_pkt_queue;
	struct napi_struct___11 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___250;

struct super_block___250;

struct module___234;

struct file_system_type___250 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___250 * (*mount)(struct file_system_type___250 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___250 *);
	struct module___234 *owner;
	struct file_system_type___250 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___250;

struct kiocb___250;

struct iov_iter___170;

struct poll_table_struct___172;

struct vm_area_struct___255;

struct inode___250;

struct file_lock___250;

struct page___255;

struct pipe_inode_info___91;

struct seq_file___225;

struct file_operations___251 {
	struct module___234 *owner;
	loff_t (*llseek)(struct file___250 *, loff_t, int);
	ssize_t (*read)(struct file___250 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___250 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___250 *, struct iov_iter___170 *);
	ssize_t (*write_iter)(struct kiocb___250 *, struct iov_iter___170 *);
	int (*iopoll)(struct kiocb___250 *, bool);
	int (*iterate)(struct file___250 *, struct dir_context *);
	int (*iterate_shared)(struct file___250 *, struct dir_context *);
	__poll_t (*poll)(struct file___250 *, struct poll_table_struct___172 *);
	long int (*unlocked_ioctl)(struct file___250 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___250 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___250 *, struct vm_area_struct___255 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___250 *, struct file___250 *);
	int (*flush)(struct file___250 *, fl_owner_t);
	int (*release)(struct inode___250 *, struct file___250 *);
	int (*fsync)(struct file___250 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___250 *, int);
	int (*lock)(struct file___250 *, int, struct file_lock___250 *);
	ssize_t (*sendpage)(struct file___250 *, struct page___255 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___250 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___250 *, long unsigned int);
	int (*flock)(struct file___250 *, int, struct file_lock___250 *);
	ssize_t (*splice_write)(struct pipe_inode_info___91 *, struct file___250 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___250 *, loff_t *, struct pipe_inode_info___91 *, size_t, unsigned int);
	int (*setlease)(struct file___250 *, long int, struct file_lock___250 **, void **);
	long int (*fallocate)(struct file___250 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___225 *, struct file___250 *);
	ssize_t (*copy_file_range)(struct file___250 *, loff_t, struct file___250 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___250 *, loff_t, struct file___250 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___250 *, loff_t, loff_t, int);
};

struct kernel_param___234;

struct kernel_param_ops___234 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___234 *);
	int (*get)(char *, const struct kernel_param___234 *);
	void (*free)(void *);
};

struct kparam_array___234;

struct kernel_param___234 {
	const char *name;
	struct module___234 *mod;
	const struct kernel_param_ops___234 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___234 *arr;
	};
};

struct kparam_array___234 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___234 *ops;
	void *elem;
};

struct kset___238;

struct kobj_type___238;

struct kernfs_node___238;

struct kobject___238 {
	const char *name;
	struct list_head entry;
	struct kobject___238 *parent;
	struct kset___238 *kset;
	struct kobj_type___238 *ktype;
	struct kernfs_node___238 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___235 {
	struct kobject___238 kobj;
	struct module___234 *mod;
	struct kobject___238 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___234 {
	struct module___234 *mod;
	struct latch_tree_node node;
};

struct module_layout___234 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___234 mtn;
};

struct module_attribute___234;

struct module___234 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___235 mkobj;
	struct module_attribute___234 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___238 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___234 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___234 core_layout;
	struct module_layout___234 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___255 {
	u64 seqnum;
	struct vm_area_struct___255 *vmas[4];
};

struct page_frag___255 {
	struct page___255 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___256;

struct pid___227;

struct nsproxy___236;

struct signal_struct___251;

struct bio_list___142;

struct backing_dev_info___128;

struct io_context___142;

struct css_set___177;

struct mem_cgroup___116;

struct request_queue___142;

struct vm_struct___233;

struct task_struct___257 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___257 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___256 *mm;
	struct mm_struct___256 *active_mm;
	struct vmacache___255 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___257 *real_parent;
	struct task_struct___257 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___257 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___227 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___236 *nsproxy;
	struct signal_struct___251 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___257 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___142 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___128 *backing_dev_info;
	struct io_context___142 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___177 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___91 *splice_pipe;
	struct page_frag___255 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___116 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___116 *active_memcg;
	struct request_queue___142 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___257 *oom_reaper_list;
	struct vm_struct___233 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___83 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___227;

struct upid___227 {
	int nr;
	struct pid_namespace___227 *ns;
};

struct pid_namespace___227 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___257 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___227 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___227 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___227 numbers[1];
};

typedef struct page___255 *pgtable_t___255;

struct address_space___250;

struct page_pool___79;

struct dev_pagemap___245;

struct page___255 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___250 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___79 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___255 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___255 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___256 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___245 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___245;

struct vm_area_struct___255 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___255 *vm_next;
	struct vm_area_struct___255 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___256 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___245 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___250 *vm_file;
	struct file___250 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___251 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___257 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___257 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___227 *pids[4];
	struct pid___227 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___256 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___255;

struct mm_struct___256 {
	struct {
		struct vm_area_struct___255 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___250 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___255 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___257 *owner;
		struct user_namespace___26 *user_ns;
		struct file___250 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___64;

struct cgroup_namespace___177;

struct nsproxy___236 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___227 *pid_ns_for_children;
	struct net___64 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___177 *cgroup_ns;
};

struct bio___142;

struct bio_list___142 {
	struct bio___142 *head;
	struct bio___142 *tail;
};

struct cgroup_subsys_state___177;

struct bdi_writeback___128 {
	struct backing_dev_info___128 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___177 *memcg_css;
	struct cgroup_subsys_state___177 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___231;

struct backing_dev_info___128 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___128 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___231 *dev;
	char dev_name[64];
	struct device___231 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___250 *debug_dir;
};

struct io_cq___142;

struct io_context___142 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___142 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___177;

struct css_set___177 {
	struct cgroup_subsys_state___177 *subsys[14];
	refcount_t refcount;
	struct css_set___177 *dom_cset;
	struct cgroup___177 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___177 *mg_src_cgrp;
	struct cgroup___177 *mg_dst_cgrp;
	struct css_set___177 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___250;

struct pipe_buffer___91;

struct pipe_inode_info___91 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___255 *tmp_page;
	struct fasync_struct___250 *fasync_readers;
	struct fasync_struct___250 *fasync_writers;
	struct pipe_buffer___91 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___177;

struct cgroup_subsys_state___177 {
	struct cgroup___177 *cgroup;
	struct cgroup_subsys___177 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___177 *parent;
};

struct cgroup_file___177 {
	struct kernfs_node___238 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___116;

struct mem_cgroup_per_node___116;

struct mem_cgroup___116 {
	struct cgroup_subsys_state___177 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___177 events_file;
	struct cgroup_file___177 events_local_file;
	struct cgroup_file___177 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___116 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___257 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___116 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___142;

struct blk_integrity___142 {
	const struct blk_integrity_profile___142 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___142 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___142 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___142;

struct elevator_queue___142;

struct blk_mq_ops___137;

struct blk_mq_hw_ctx___137;

struct gendisk___145;

struct blkcg_gq___130;

struct blk_mq_tag_set___137;

struct request_queue___142 {
	struct request___142 *last_merge;
	struct elevator_queue___142 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___137 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___137 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___145 *disk;
	struct kobject___238 kobj;
	struct kobject___238 *mq_kobj;
	struct blk_integrity___142 integrity;
	struct device___231 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___130 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___137 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___142 bio_split;
	struct dentry___250 *debugfs_dir;
	struct dentry___250 *sched_debugfs_dir;
	struct dentry___250 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___233 {
	struct vm_struct___233 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___255 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___167 {
	struct page___255 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___170 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___167 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___91 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___49 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___170 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___250 *msg_iocb;
};

struct kiocb___250 {
	struct file___250 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___250 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___59;

struct sock___47;

struct sk_buff___60 {
	union {
		struct {
			struct sk_buff___60 *next;
			struct sk_buff___60 *prev;
			union {
				struct net_device___59 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___47 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___60 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___64;

struct fqdir___64 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___64 *f;
	struct net___64 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___64;

struct inet_frags___64 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___64 *, const void *);
	void (*destructor)(struct inet_frag_queue___64 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___26;

struct fib_rules_ops___47;

struct tcp_congestion_ops___10;

struct fib_notifier_ops___47;

struct netns_ipv4___64 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___26 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___47 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___47 *fibnl;
	struct sock___47 **icmp_sk;
	struct sock___47 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___47 **tcp_sk;
	struct fqdir___64 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___10 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___47 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___47 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___47 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___47;

struct neighbour___47;

struct dst_ops___64 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___64 *);
	struct dst_entry___47 * (*check)(struct dst_entry___47 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___47 *);
	unsigned int (*mtu)(const struct dst_entry___47 *);
	u32 * (*cow_metrics)(struct dst_entry___47 *, long unsigned int);
	void (*destroy)(struct dst_entry___47 *);
	void (*ifdown)(struct dst_entry___47 *, struct net_device___59 *, int);
	struct dst_entry___47 * (*negative_advice)(struct dst_entry___47 *);
	void (*link_failure)(struct sk_buff___60 *);
	void (*update_pmtu)(struct dst_entry___47 *, struct sock___47 *, struct sk_buff___60 *, u32, bool);
	void (*redirect)(struct dst_entry___47 *, struct sock___47 *, struct sk_buff___60 *);
	int (*local_out)(struct net___64 *, struct sock___47 *, struct sk_buff___60 *);
	struct neighbour___47 * (*neigh_lookup)(const struct dst_entry___47 *, struct sk_buff___60 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___47 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___64 {
	struct dst_ops___64 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___64 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___47 *fib6_rules_ops;
	struct sock___47 **icmp_sk;
	struct sock___47 *ndisc_sk;
	struct sock___47 *tcp_sk;
	struct sock___47 *igmp_sk;
	struct sock___47 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___47 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___47 *notifier_ops;
	struct fib_notifier_ops___47 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___64 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___64 *fqdir;
};

struct netns_sctp___47 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___47 *ctl_sock;
	struct sock___47 *udp4_sock;
	struct sock___47 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___59 {
	struct sk_buff___60 *next;
	struct sk_buff___60 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___54;

struct bpf_prog___54;

struct netns_bpf___54 {
	struct bpf_prog_array___54 *run_array[2];
	struct bpf_prog___54 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___64 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___47 *nlsk;
	struct sock___47 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___64 xfrm4_dst_ops;
	struct dst_ops___64 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___64 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___47 *rtnl;
	struct sock___47 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___59 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___64 ipv4;
	struct netns_ipv6___64 ipv6;
	struct netns_ieee802154_lowpan___64 ieee802154_lowpan;
	struct netns_sctp___47 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___59 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___54 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___64 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___47 *crypto_nlsk;
	struct sock___47 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___64 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___60 *fragments_tail;
	struct sk_buff___60 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___64 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___26 {
	struct ip_ra_chain___26 *next;
	struct sock___47 *sk;
	union {
		void (*destructor)(struct sock___47 *);
		struct sock___47 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___47;

struct fib_lookup_arg___47;

struct fib_rules_ops___47 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___47 *, struct flowi *, int, struct fib_lookup_arg___47 *);
	bool (*suppress)(struct fib_rule___47 *, int, struct fib_lookup_arg___47 *);
	int (*match)(struct fib_rule___47 *, struct flowi *, int);
	int (*configure)(struct fib_rule___47 *, struct sk_buff___60 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___47 *);
	int (*compare)(struct fib_rule___47 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___47 *, struct sk_buff___60 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___47 *);
	void (*flush_cache)(struct fib_rules_ops___47 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___234 *owner;
	struct net___64 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___64 *net;
} possible_net_t___59;

struct proto___47;

struct sock_common___47 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___47 *skc_prot;
	possible_net_t___59 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___47 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___47 {
	struct cgroup___177 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___47;

struct socket_wq___48;

struct socket___49;

struct sock_reuseport___11;

struct sock___47 {
	struct sock_common___47 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___59 sk_error_queue;
	struct sk_buff___60 *sk_rx_skb_cache;
	struct sk_buff_head___59 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___60 *head;
		struct sk_buff___60 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___47 *sk_filter;
	union {
		struct socket_wq___48 *sk_wq;
		struct socket_wq___48 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___47 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___47 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___60 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___60 *sk_tx_skb_cache;
	struct sk_buff_head___59 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___255 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___47 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___227 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___49 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___47 sk_cgrp_data;
	struct mem_cgroup___116 *sk_memcg;
	void (*sk_state_change)(struct sock___47 *);
	void (*sk_data_ready)(struct sock___47 *);
	void (*sk_write_space)(struct sock___47 *);
	void (*sk_error_report)(struct sock___47 *);
	int (*sk_backlog_rcv)(struct sock___47 *, struct sk_buff___60 *);
	struct sk_buff___60 * (*sk_validate_xmit_skb)(struct sock___47 *, struct net_device___59 *, struct sk_buff___60 *);
	void (*sk_destruct)(struct sock___47 *);
	struct sock_reuseport___11 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct tcp_congestion_ops___10 {
	u32 (*ssthresh)(struct sock___47 *);
	void (*cong_avoid)(struct sock___47 *, u32, u32);
	void (*set_state)(struct sock___47 *, u8);
	void (*cwnd_event)(struct sock___47 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___47 *, u32);
	void (*pkts_acked)(struct sock___47 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___47 *);
	void (*cong_control)(struct sock___47 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___47 *);
	u32 (*sndbuf_expand)(struct sock___47 *);
	size_t (*get_info)(struct sock___47 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___234 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___47 *);
	void (*release)(struct sock___47 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___47 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___64 *);
	int (*fib_dump)(struct net___64 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___234 *owner;
	struct callback_head rcu;
};

struct address_space_operations___250;

struct address_space___250 {
	struct inode___250 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___250 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___79 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___231 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___79 {
	u32 count;
	struct page___255 *cache[128];
};

struct page_pool___79 {
	struct page_pool_params___79 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___255 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___79 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___245;

struct dev_pagemap___245 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___245 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___250;

struct path___250 {
	struct vfsmount___250 *mnt;
	struct dentry___250 *dentry;
};

struct fown_struct___227 {
	rwlock_t lock;
	struct pid___227 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___250 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___250 f_path;
	struct inode___250 *f_inode;
	const struct file_operations___251 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___227 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___250 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___245;

struct vm_operations_struct___245 {
	void (*open)(struct vm_area_struct___255 *);
	void (*close)(struct vm_area_struct___255 *);
	int (*may_split)(struct vm_area_struct___255 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___255 *);
	int (*mprotect)(struct vm_area_struct___255 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___245 *);
	vm_fault_t (*huge_fault)(struct vm_fault___245 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___245 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___255 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___245 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___245 *);
	int (*access)(struct vm_area_struct___255 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___255 *);
	int (*set_policy)(struct vm_area_struct___255 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___255 *, long unsigned int);
	struct page___255 * (*find_special_page)(struct vm_area_struct___255 *, long unsigned int);
};

struct core_thread___255 {
	struct task_struct___257 *task;
	struct core_thread___255 *next;
};

struct core_state___255 {
	atomic_t nr_threads;
	struct core_thread___255 dumper;
	struct completion startup;
};

struct vm_fault___245 {
	const struct {
		struct vm_area_struct___255 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___255 *cow_page;
	struct page___255 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___255 prealloc_pte;
};

struct pglist_data___124;

struct lruvec___124 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___124 *pgdat;
};

struct zone___124 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___124 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___124 {
	struct zone___124 *zone;
	int zone_idx;
};

struct zonelist___124 {
	struct zoneref___124 _zonerefs[321];
};

struct pglist_data___124 {
	struct zone___124 node_zones[5];
	struct zonelist___124 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___257 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___257 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___124 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct lwtunnel_state___27;

struct dst_entry___47 {
	struct net_device___59 *dev;
	struct dst_ops___64 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___60 *);
	int (*output)(struct net___64 *, struct sock___47 *, struct sk_buff___60 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___27 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___59(struct sk_buff___60 **);

struct wakeup_source___231;

struct dev_pm_info___231 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___231 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___231 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___231;

struct bus_type___231;

struct device_driver___231;

struct dev_pm_domain___231;

struct fwnode_handle___227;

struct class___231;

struct attribute_group___238;

struct device___231 {
	struct kobject___238 kobj;
	struct device___231 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___231 *type;
	struct bus_type___231 *bus;
	struct device_driver___231 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___231 power;
	struct dev_pm_domain___231 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___227 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___231 *class;
	const struct attribute_group___238 **groups;
	void (*release)(struct device___231 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___54 {
	struct bpf_prog___54 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___59;

struct net_device_ops___59;

struct l3mdev_ops___47;

struct ndisc_ops___33;

struct xfrmdev_ops___59;

struct header_ops___59;

struct in_device___4;

struct inet6_dev___33;

struct netdev_rx_queue___59;

struct mini_Qdisc___54;

struct netdev_queue___59;

struct Qdisc___54;

struct netpoll_info___2;

struct rtnl_link_ops___54;

struct dcbnl_rtnl_ops___59;

struct net_device___59 {
	char name[16];
	struct netdev_name_node___59 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___59 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___47 *l3mdev_ops;
	const struct ndisc_ops___33 *ndisc_ops;
	const struct xfrmdev_ops___59 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___59 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___238 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___4 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___33 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___59 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___54 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___59 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___54 *miniq_ingress;
	struct netdev_queue___59 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___59 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___54 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___54 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___59 = 0,
		NETREG_REGISTERED___59 = 1,
		NETREG_UNREGISTERING___59 = 2,
		NETREG_UNREGISTERED___59 = 3,
		NETREG_RELEASED___59 = 4,
		NETREG_DUMMY___59 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___59 = 0,
		RTNL_LINK_INITIALIZING___59 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___59 *);
	struct netpoll_info___2 *npinfo;
	possible_net_t___59 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___231 dev;
	const struct attribute_group___238 *sysfs_groups[4];
	const struct attribute_group___238 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___54 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___59 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___54 xdp_state[3];
	long: 64;
};

struct neigh_table___47;

struct neigh_parms___47;

struct neigh_ops___47;

struct neighbour___47 {
	struct neighbour___47 *next;
	struct neigh_table___47 *tbl;
	struct neigh_parms___47 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___59 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___47 *, struct sk_buff___60 *);
	const struct neigh_ops___47 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___59 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___54 {
	struct bpf_prog___54 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___54 {
	struct callback_head rcu;
	struct bpf_prog_array_item___54 items[0];
};

struct bpf_prog_aux___62;

struct bpf_prog___54 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___62 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___250;

struct dentry___250 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___250 *d_parent;
	struct qstr d_name;
	struct inode___250 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___250 *d_op;
	struct super_block___250 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___250;

struct inode___250 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___250 *i_op;
	struct super_block___250 *i_sb;
	struct address_space___250 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___128 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___251 *i_fop;
		void (*free_inode)(struct inode___250 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___250 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___91 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___250 {
	int (*d_revalidate)(struct dentry___250 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___250 *, unsigned int);
	int (*d_hash)(const struct dentry___250 *, struct qstr *);
	int (*d_compare)(const struct dentry___250 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___250 *);
	int (*d_init)(struct dentry___250 *);
	void (*d_release)(struct dentry___250 *);
	void (*d_prune)(struct dentry___250 *);
	void (*d_iput)(struct dentry___250 *, struct inode___250 *);
	char * (*d_dname)(struct dentry___250 *, char *, int);
	struct vfsmount___250 * (*d_automount)(struct path___250 *);
	int (*d_manage)(const struct path___250 *, bool);
	struct dentry___250 * (*d_real)(struct dentry___250 *, const struct inode___250 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___250;

struct mem_dqinfo___250 {
	struct quota_format_type___250 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___250;

struct quota_info___250 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___250 *files[3];
	struct mem_dqinfo___250 info[3];
	const struct quota_format_ops___250 *ops[3];
};

struct rcuwait___251 {
	struct task_struct___257 *task;
};

struct percpu_rw_semaphore___251 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___251 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___250 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___251 rw_sem[3];
};

struct shrink_control___116;

struct shrinker___116 {
	long unsigned int (*count_objects)(struct shrinker___116 *, struct shrink_control___116 *);
	long unsigned int (*scan_objects)(struct shrinker___116 *, struct shrink_control___116 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___250;

struct dquot_operations___250;

struct quotactl_ops___250;

struct block_device___145;

struct super_block___250 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___250 *s_type;
	const struct super_operations___250 *s_op;
	const struct dquot_operations___250 *dq_op;
	const struct quotactl_ops___250 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___250 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___145 *s_bdev;
	struct backing_dev_info___128 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___250 s_dquot;
	struct sb_writers___250 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___250 *s_d_op;
	int cleancache_poolid;
	struct shrinker___116 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___250 {
	struct dentry___250 *mnt_root;
	struct super_block___250 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___116 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___116 *memcg;
};

struct psi_group___177 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___257 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___54 {
	struct bpf_prog_array___54 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___54 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___177;

struct cgroup_rstat_cpu___177;

struct cgroup___177 {
	struct cgroup_subsys_state___177 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___238 *kn;
	struct cgroup_file___177 procs_file;
	struct cgroup_file___177 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___177 *subsys[14];
	struct cgroup_root___177 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___177 *dom_cgrp;
	struct cgroup___177 *old_dom_cgrp;
	struct cgroup_rstat_cpu___177 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___177 psi;
	struct cgroup_bpf___54 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___142 {
	struct request_queue___142 *q;
	struct io_context___142 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___250 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___250 *ia_file;
};

struct dquot___250 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___250 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___250 {
	int qf_fmt_id;
	const struct quota_format_ops___250 *qf_ops;
	struct module___234 *qf_owner;
	struct quota_format_type___250 *qf_next;
};

struct quota_format_ops___250 {
	int (*check_quota_file)(struct super_block___250 *, int);
	int (*read_file_info)(struct super_block___250 *, int);
	int (*write_file_info)(struct super_block___250 *, int);
	int (*free_file_info)(struct super_block___250 *, int);
	int (*read_dqblk)(struct dquot___250 *);
	int (*commit_dqblk)(struct dquot___250 *);
	int (*release_dqblk)(struct dquot___250 *);
	int (*get_next_id)(struct super_block___250 *, struct kqid *);
};

struct dquot_operations___250 {
	int (*write_dquot)(struct dquot___250 *);
	struct dquot___250 * (*alloc_dquot)(struct super_block___250 *, int);
	void (*destroy_dquot)(struct dquot___250 *);
	int (*acquire_dquot)(struct dquot___250 *);
	int (*release_dquot)(struct dquot___250 *);
	int (*mark_dirty)(struct dquot___250 *);
	int (*write_info)(struct super_block___250 *, int);
	qsize_t * (*get_reserved_space)(struct inode___250 *);
	int (*get_projid)(struct inode___250 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___250 *, qsize_t *);
	int (*get_next_id)(struct super_block___250 *, struct kqid *);
};

struct quotactl_ops___250 {
	int (*quota_on)(struct super_block___250 *, int, int, const struct path___250 *);
	int (*quota_off)(struct super_block___250 *, int);
	int (*quota_enable)(struct super_block___250 *, unsigned int);
	int (*quota_disable)(struct super_block___250 *, unsigned int);
	int (*quota_sync)(struct super_block___250 *, int);
	int (*set_info)(struct super_block___250 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___250 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___250 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___250 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___250 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___250 *, unsigned int);
};

struct writeback_control___128;

struct address_space_operations___250 {
	int (*writepage)(struct page___255 *, struct writeback_control___128 *);
	int (*readpage)(struct file___250 *, struct page___255 *);
	int (*writepages)(struct address_space___250 *, struct writeback_control___128 *);
	int (*set_page_dirty)(struct page___255 *);
	int (*readpages)(struct file___250 *, struct address_space___250 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___250 *, struct address_space___250 *, loff_t, unsigned int, unsigned int, struct page___255 **, void **);
	int (*write_end)(struct file___250 *, struct address_space___250 *, loff_t, unsigned int, unsigned int, struct page___255 *, void *);
	sector_t (*bmap)(struct address_space___250 *, sector_t);
	void (*invalidatepage)(struct page___255 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___255 *, gfp_t);
	void (*freepage)(struct page___255 *);
	ssize_t (*direct_IO)(struct kiocb___250 *, struct iov_iter___170 *);
	int (*migratepage)(struct address_space___250 *, struct page___255 *, struct page___255 *, enum migrate_mode);
	bool (*isolate_page)(struct page___255 *, isolate_mode_t);
	void (*putback_page)(struct page___255 *);
	int (*launder_page)(struct page___255 *);
	int (*is_partially_uptodate)(struct page___255 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___255 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___250 *, struct page___255 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___250 *, sector_t *);
	void (*swap_deactivate)(struct file___250 *);
};

struct writeback_control___128 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___128 *wb;
	struct inode___250 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___250 {
	struct dentry___250 * (*lookup)(struct inode___250 *, struct dentry___250 *, unsigned int);
	const char * (*get_link)(struct dentry___250 *, struct inode___250 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___250 *, int);
	struct posix_acl * (*get_acl)(struct inode___250 *, int, bool);
	int (*readlink)(struct dentry___250 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___250 *, struct dentry___250 *, umode_t, bool);
	int (*link)(struct dentry___250 *, struct inode___250 *, struct dentry___250 *);
	int (*unlink)(struct inode___250 *, struct dentry___250 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___250 *, struct dentry___250 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___250 *, struct dentry___250 *, umode_t);
	int (*rmdir)(struct inode___250 *, struct dentry___250 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___250 *, struct dentry___250 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___250 *, struct dentry___250 *, struct inode___250 *, struct dentry___250 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___250 *, struct iattr___250 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___250 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___250 *, char *, size_t);
	int (*fiemap)(struct inode___250 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___250 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___250 *, struct dentry___250 *, struct file___250 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___250 *, struct dentry___250 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___250 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___250 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___250 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___250 {
	void (*fl_copy_lock)(struct file_lock___250 *, struct file_lock___250 *);
	void (*fl_release_private)(struct file_lock___250 *);
};

struct lock_manager_operations___250;

struct file_lock___250 {
	struct file_lock___250 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___250 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___250 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___250 *fl_ops;
	const struct lock_manager_operations___250 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___250 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___250 *);
	int (*lm_grant)(struct file_lock___250 *, int);
	bool (*lm_break)(struct file_lock___250 *);
	int (*lm_change)(struct file_lock___250 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___250 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___250 *);
};

struct fasync_struct___250 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___250 *fa_next;
	struct file___250 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___250 {
	struct inode___250 * (*alloc_inode)(struct super_block___250 *);
	void (*destroy_inode)(struct inode___250 *);
	void (*free_inode)(struct inode___250 *);
	void (*dirty_inode)(struct inode___250 *, int);
	int (*write_inode)(struct inode___250 *, struct writeback_control___128 *);
	int (*drop_inode)(struct inode___250 *);
	void (*evict_inode)(struct inode___250 *);
	void (*put_super)(struct super_block___250 *);
	int (*sync_fs)(struct super_block___250 *, int);
	int (*freeze_super)(struct super_block___250 *);
	int (*freeze_fs)(struct super_block___250 *);
	int (*thaw_super)(struct super_block___250 *);
	int (*unfreeze_fs)(struct super_block___250 *);
	int (*statfs)(struct dentry___250 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___250 *, int *, char *);
	void (*umount_begin)(struct super_block___250 *);
	int (*show_options)(struct seq_file___225 *, struct dentry___250 *);
	int (*show_devname)(struct seq_file___225 *, struct dentry___250 *);
	int (*show_path)(struct seq_file___225 *, struct dentry___250 *);
	int (*show_stats)(struct seq_file___225 *, struct dentry___250 *);
	ssize_t (*quota_read)(struct super_block___250 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___250 *, int, const char *, size_t, loff_t);
	struct dquot___250 ** (*get_dquots)(struct inode___250 *);
	long int (*nr_cached_objects)(struct super_block___250 *, struct shrink_control___116 *);
	long int (*free_cached_objects)(struct super_block___250 *, struct shrink_control___116 *);
	struct file___250 * (*real_loop)(struct file___250 *);
};

struct block_device___145 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___250 *bd_inode;
	struct super_block___250 *bd_super;
	void *bd_claiming;
	struct device___231 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___238 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___145 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___250 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___180)(struct file___250 *, wait_queue_head_t *, struct poll_table_struct___172 *);

struct poll_table_struct___172 {
	poll_queue_proc___180 _qproc;
	__poll_t _key;
};

struct seq_operations___225;

struct seq_file___225 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___225 *op;
	int poll_event;
	const struct file___250 *file;
	void *private;
};

typedef void bio_end_io_t___142(struct bio___142 *);

struct bio_integrity_payload___142;

struct bio___142 {
	struct bio___142 *bi_next;
	struct block_device___145 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___142 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___130 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___142 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___167 *bi_io_vec;
	struct bio_set___142 *bi_pool;
	struct bio_vec___167 bi_inline_vecs[0];
};

struct dev_pagemap_ops___245 {
	void (*page_free)(struct page___255 *);
	void (*kill)(struct dev_pagemap___245 *);
	void (*cleanup)(struct dev_pagemap___245 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___245 *);
};

struct fwnode_operations___227;

struct fwnode_handle___227 {
	struct fwnode_handle___227 *secondary;
	const struct fwnode_operations___227 *ops;
	struct device___231 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___227;

struct fwnode_endpoint___227;

struct fwnode_operations___227 {
	struct fwnode_handle___227 * (*get)(struct fwnode_handle___227 *);
	void (*put)(struct fwnode_handle___227 *);
	bool (*device_is_available)(const struct fwnode_handle___227 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___227 *, const struct device___231 *);
	bool (*property_present)(const struct fwnode_handle___227 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___227 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___227 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___227 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*get_parent)(const struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*get_next_child_node)(const struct fwnode_handle___227 *, struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*get_named_child_node)(const struct fwnode_handle___227 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___227 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___227 *);
	struct fwnode_handle___227 * (*graph_get_next_endpoint)(const struct fwnode_handle___227 *, struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*graph_get_remote_endpoint)(const struct fwnode_handle___227 *);
	struct fwnode_handle___227 * (*graph_get_port_parent)(struct fwnode_handle___227 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___227 *, struct fwnode_endpoint___227 *);
	int (*add_links)(struct fwnode_handle___227 *);
};

struct fwnode_endpoint___227 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___227 *local_fwnode;
};

struct fwnode_reference_args___227 {
	struct fwnode_handle___227 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___238;

struct kernfs_elem_dir___238 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___238 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___238;

struct kernfs_root___238 {
	struct kernfs_node___238 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___238 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___238 {
	struct kernfs_node___238 *target_kn;
};

struct kernfs_ops___238;

struct kernfs_elem_attr___238 {
	const struct kernfs_ops___238 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___238 *notify_next;
};

struct kernfs_node___238 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___238 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___238 dir;
		struct kernfs_elem_symlink___238 symlink;
		struct kernfs_elem_attr___238 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___238;

struct kernfs_ops___238 {
	int (*open)(struct kernfs_open_file___238 *);
	void (*release)(struct kernfs_open_file___238 *);
	int (*seq_show)(struct seq_file___225 *, void *);
	void * (*seq_start)(struct seq_file___225 *, loff_t *);
	void * (*seq_next)(struct seq_file___225 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___225 *, void *);
	ssize_t (*read)(struct kernfs_open_file___238 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___238 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___238 *, struct poll_table_struct___172 *);
	int (*mmap)(struct kernfs_open_file___238 *, struct vm_area_struct___255 *);
};

struct kernfs_syscall_ops___238 {
	int (*show_options)(struct seq_file___225 *, struct kernfs_root___238 *);
	int (*mkdir)(struct kernfs_node___238 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___238 *);
	int (*rename)(struct kernfs_node___238 *, struct kernfs_node___238 *, const char *);
	int (*show_path)(struct seq_file___225 *, struct kernfs_node___238 *, struct kernfs_root___238 *);
};

struct kernfs_open_file___238 {
	struct kernfs_node___238 *kn;
	struct file___250 *file;
	struct seq_file___225 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___245 *vm_ops;
};

struct kobj_ns_type_operations___47 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___47 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___238;

struct attribute_group___238 {
	const char *name;
	umode_t (*is_visible)(struct kobject___238 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___238 *, struct bin_attribute___238 *, int);
	struct attribute **attrs;
	struct bin_attribute___238 **bin_attrs;
};

struct bin_attribute___238 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___250 * (*f_mapping)();
	ssize_t (*read)(struct file___250 *, struct kobject___238 *, struct bin_attribute___238 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___250 *, struct kobject___238 *, struct bin_attribute___238 *, char *, loff_t, size_t);
	int (*mmap)(struct file___250 *, struct kobject___238 *, struct bin_attribute___238 *, struct vm_area_struct___255 *);
};

struct sysfs_ops___238 {
	ssize_t (*show)(struct kobject___238 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___238 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___238;

struct kset___238 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___238 kobj;
	const struct kset_uevent_ops___238 *uevent_ops;
};

struct kobj_type___238 {
	void (*release)(struct kobject___238 *);
	const struct sysfs_ops___238 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___238 **default_groups;
	const struct kobj_ns_type_operations___47 * (*child_ns_type)(struct kobject___238 *);
	const void * (*namespace)(struct kobject___238 *);
	void (*get_ownership)(struct kobject___238 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___238 {
	int (* const filter)(struct kset___238 *, struct kobject___238 *);
	const char * (* const name)(struct kset___238 *, struct kobject___238 *);
	int (* const uevent)(struct kset___238 *, struct kobject___238 *, struct kobj_uevent_env *);
};

struct module_attribute___234 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___234 *, struct module_kobject___235 *, char *);
	ssize_t (*store)(struct module_attribute___234 *, struct module_kobject___235 *, const char *, size_t);
	void (*setup)(struct module___234 *, const char *);
	int (*test)(struct module___234 *);
	void (*free)(struct module___234 *);
};

struct cgroup_namespace___177 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___177 *root_cset;
};

struct socket_wq___48 {
	wait_queue_head_t wait;
	struct fasync_struct___250 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___48;

struct socket___49 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___250 *file;
	struct sock___47 *sk;
	const struct proto_ops___48 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___48 wq;
};

typedef int (*sk_read_actor_t___47)(read_descriptor_t *, struct sk_buff___60 *, unsigned int, size_t);

struct proto_ops___48 {
	int family;
	struct module___234 *owner;
	int (*release)(struct socket___49 *);
	int (*bind)(struct socket___49 *, struct sockaddr *, int);
	int (*connect)(struct socket___49 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___49 *, struct socket___49 *);
	int (*accept)(struct socket___49 *, struct socket___49 *, int, bool);
	int (*getname)(struct socket___49 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___250 *, struct socket___49 *, struct poll_table_struct___172 *);
	int (*ioctl)(struct socket___49 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___49 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___49 *, void *, bool, bool);
	int (*listen)(struct socket___49 *, int);
	int (*shutdown)(struct socket___49 *, int);
	int (*setsockopt)(struct socket___49 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___49 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___225 *, struct socket___49 *);
	int (*sendmsg)(struct socket___49 *, struct msghdr___49 *, size_t);
	int (*recvmsg)(struct socket___49 *, struct msghdr___49 *, size_t, int);
	int (*mmap)(struct file___250 *, struct socket___49 *, struct vm_area_struct___255 *);
	ssize_t (*sendpage)(struct socket___49 *, struct page___255 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___49 *, loff_t *, struct pipe_inode_info___91 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___47 *, int);
	int (*peek_len)(struct socket___49 *);
	int (*read_sock)(struct sock___47 *, read_descriptor_t *, sk_read_actor_t___47);
	int (*sendpage_locked)(struct sock___47 *, struct page___255 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___47 *, struct msghdr___49 *, size_t);
	int (*set_rcvlowat)(struct sock___47 *, int);
};

struct dev_pm_ops___231 {
	int (*prepare)(struct device___231 *);
	void (*complete)(struct device___231 *);
	int (*suspend)(struct device___231 *);
	int (*resume)(struct device___231 *);
	int (*freeze)(struct device___231 *);
	int (*thaw)(struct device___231 *);
	int (*poweroff)(struct device___231 *);
	int (*restore)(struct device___231 *);
	int (*suspend_late)(struct device___231 *);
	int (*resume_early)(struct device___231 *);
	int (*freeze_late)(struct device___231 *);
	int (*thaw_early)(struct device___231 *);
	int (*poweroff_late)(struct device___231 *);
	int (*restore_early)(struct device___231 *);
	int (*suspend_noirq)(struct device___231 *);
	int (*resume_noirq)(struct device___231 *);
	int (*freeze_noirq)(struct device___231 *);
	int (*thaw_noirq)(struct device___231 *);
	int (*poweroff_noirq)(struct device___231 *);
	int (*restore_noirq)(struct device___231 *);
	int (*runtime_suspend)(struct device___231 *);
	int (*runtime_resume)(struct device___231 *);
	int (*runtime_idle)(struct device___231 *);
};

struct wakeup_source___231 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___231 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___231 {
	struct dev_pm_ops___231 ops;
	int (*start)(struct device___231 *);
	void (*detach)(struct device___231 *, bool);
	int (*activate)(struct device___231 *);
	void (*sync)(struct device___231 *);
	void (*dismiss)(struct device___231 *);
};

struct bus_type___231 {
	const char *name;
	const char *dev_name;
	struct device___231 *dev_root;
	const struct attribute_group___238 **bus_groups;
	const struct attribute_group___238 **dev_groups;
	const struct attribute_group___238 **drv_groups;
	int (*match)(struct device___231 *, struct device_driver___231 *);
	int (*uevent)(struct device___231 *, struct kobj_uevent_env *);
	int (*probe)(struct device___231 *);
	void (*sync_state)(struct device___231 *);
	void (*remove)(struct device___231 *);
	void (*shutdown)(struct device___231 *);
	int (*online)(struct device___231 *);
	int (*offline)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	int (*num_vf)(struct device___231 *);
	int (*dma_configure)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___231 {
	const char *name;
	struct bus_type___231 *bus;
	struct module___234 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___231 *);
	void (*sync_state)(struct device___231 *);
	int (*remove)(struct device___231 *);
	void (*shutdown)(struct device___231 *);
	int (*suspend)(struct device___231 *, pm_message_t);
	int (*resume)(struct device___231 *);
	const struct attribute_group___238 **groups;
	const struct attribute_group___238 **dev_groups;
	const struct dev_pm_ops___231 *pm;
	void (*coredump)(struct device___231 *);
	struct driver_private *p;
};

struct device_type___231 {
	const char *name;
	const struct attribute_group___238 **groups;
	int (*uevent)(struct device___231 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___231 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___231 *);
	const struct dev_pm_ops___231 *pm;
};

struct class___231 {
	const char *name;
	struct module___234 *owner;
	const struct attribute_group___238 **class_groups;
	const struct attribute_group___238 **dev_groups;
	struct kobject___238 *dev_kobj;
	int (*dev_uevent)(struct device___231 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___231 *, umode_t *);
	void (*class_release)(struct class___231 *);
	void (*dev_release)(struct device___231 *);
	int (*shutdown_pre)(struct device___231 *);
	const struct kobj_ns_type_operations___47 *ns_type;
	const void * (*namespace)(struct device___231 *);
	void (*get_ownership)(struct device___231 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___231 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___91;

struct pipe_buffer___91 {
	struct page___255 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___91 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___91 {
	int (*confirm)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
	void (*release)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
	bool (*try_steal)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
	bool (*get)(struct pipe_inode_info___91 *, struct pipe_buffer___91 *);
};

typedef struct bio_vec___167 skb_frag_t___14;

struct skb_shared_info___14 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___60 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___14 frags[17];
};

struct seq_operations___225 {
	void * (*start)(struct seq_file___225 *, loff_t *);
	void (*stop)(struct seq_file___225 *, void *);
	void * (*next)(struct seq_file___225 *, void *, loff_t *);
	int (*show)(struct seq_file___225 *, void *);
};

struct dcbnl_rtnl_ops___59 {
	int (*ieee_getets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___59 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___59 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___59 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___59 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___59 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___59 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___59 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___59 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___59 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___59 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___59 *);
	u8 (*setstate)(struct net_device___59 *, u8);
	void (*getpermhwaddr)(struct net_device___59 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___59 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___59 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___59 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___59 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___59 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___59 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___59 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___59 *, int, u8 *);
	void (*setpfccfg)(struct net_device___59 *, int, u8);
	void (*getpfccfg)(struct net_device___59 *, int, u8 *);
	u8 (*setall)(struct net_device___59 *);
	u8 (*getcap)(struct net_device___59 *, int, u8 *);
	int (*getnumtcs)(struct net_device___59 *, int, u8 *);
	int (*setnumtcs)(struct net_device___59 *, int, u8);
	u8 (*getpfcstate)(struct net_device___59 *);
	void (*setpfcstate)(struct net_device___59 *, u8);
	void (*getbcncfg)(struct net_device___59 *, int, u32 *);
	void (*setbcncfg)(struct net_device___59 *, int, u32);
	void (*getbcnrp)(struct net_device___59 *, int, u8 *);
	void (*setbcnrp)(struct net_device___59 *, int, u8);
	int (*setapp)(struct net_device___59 *, u8, u16, u8);
	int (*getapp)(struct net_device___59 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___59 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___59 *, int, u8);
	u8 (*getdcbx)(struct net_device___59 *);
	u8 (*setdcbx)(struct net_device___59 *, u8);
	int (*peer_getappinfo)(struct net_device___59 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___59 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___59 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___59 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___59 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___59 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___62;

typedef int (*bpf_iter_init_seq_priv_t___61)(void *, struct bpf_iter_aux_info___62 *);

struct bpf_map___62;

struct bpf_iter_aux_info___62 {
	struct bpf_map___62 *map;
};

struct bpf_iter_seq_info___61 {
	const struct seq_operations___225 *seq_ops;
	bpf_iter_init_seq_priv_t___61 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___61 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___62 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___62 *, struct file___250 *);
	void (*map_free)(struct bpf_map___62 *);
	int (*map_get_next_key)(struct bpf_map___62 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___62 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___62 *, void *);
	int (*map_lookup_batch)(struct bpf_map___62 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___62 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___62 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___62 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___62 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___62 *, void *);
	int (*map_update_elem)(struct bpf_map___62 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___62 *, void *);
	int (*map_push_elem)(struct bpf_map___62 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___62 *, void *);
	int (*map_peek_elem)(struct bpf_map___62 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___62 *, struct file___250 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___62 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___62 *, void *, struct seq_file___225 *);
	int (*map_check_btf)(const struct bpf_map___62 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___62 *, struct bpf_prog_aux___62 *);
	void (*map_poke_untrack)(struct bpf_map___62 *, struct bpf_prog_aux___62 *);
	void (*map_poke_run)(struct bpf_map___62 *, u32, struct bpf_prog___54 *, struct bpf_prog___54 *);
	int (*map_direct_value_addr)(const struct bpf_map___62 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___62 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___62 *, struct vm_area_struct___255 *);
	__poll_t (*map_poll)(struct bpf_map___62 *, struct file___250 *, struct poll_table_struct___172 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___62 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___62 *, const struct bpf_map___62 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___62 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___61 *iter_seq_info;
};

struct bpf_map___62 {
	const struct bpf_map_ops___61 *ops;
	struct bpf_map___62 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___116 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___61;

struct bpf_jit_poke_descriptor___61;

struct bpf_prog_ops___54;

struct btf_mod_pair___61;

struct bpf_prog_offload___59;

struct bpf_prog_aux___62 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___54 *dst_prog;
	struct bpf_trampoline___61 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___54 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___61 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___54 *ops;
	struct bpf_map___62 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___61 *used_btfs;
	struct bpf_prog___54 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___62 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___59 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___59;

struct bpf_map_dev_ops___59 {
	int (*map_get_next_key)(struct bpf_offloaded_map___59 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___59 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___59 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___59 *, void *);
};

struct bpf_offloaded_map___59 {
	struct bpf_map___62 map;
	struct net_device___59 *netdev;
	const struct bpf_map_dev_ops___59 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___54 {
	int (*test_run)(struct bpf_prog___54 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___59 {
	struct bpf_prog___54 *prog;
	struct net_device___59 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___61 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___54 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___234 *mod;
};

struct bpf_jit_poke_descriptor___61 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___62 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___61 {
	struct btf *btf;
	struct module___234 *module;
};

struct cftype___177;

struct cgroup_subsys___177 {
	struct cgroup_subsys_state___177 * (*css_alloc)(struct cgroup_subsys_state___177 *);
	int (*css_online)(struct cgroup_subsys_state___177 *);
	void (*css_offline)(struct cgroup_subsys_state___177 *);
	void (*css_released)(struct cgroup_subsys_state___177 *);
	void (*css_free)(struct cgroup_subsys_state___177 *);
	void (*css_reset)(struct cgroup_subsys_state___177 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___177 *, int);
	int (*css_extra_stat_show)(struct seq_file___225 *, struct cgroup_subsys_state___177 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___257 *, struct css_set___177 *);
	void (*cancel_fork)(struct task_struct___257 *, struct css_set___177 *);
	void (*fork)(struct task_struct___257 *);
	void (*exit)(struct task_struct___257 *);
	void (*release)(struct task_struct___257 *);
	void (*bind)(struct cgroup_subsys_state___177 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___177 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___177 *dfl_cftypes;
	struct cftype___177 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___177 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___177 *updated_children;
	struct cgroup___177 *updated_next;
};

struct cgroup_root___177 {
	struct kernfs_root___238 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___177 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___177 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___177 *ss;
	struct list_head node;
	struct kernfs_ops___238 *kf_ops;
	int (*open)(struct kernfs_open_file___238 *);
	void (*release)(struct kernfs_open_file___238 *);
	u64 (*read_u64)(struct cgroup_subsys_state___177 *, struct cftype___177 *);
	s64 (*read_s64)(struct cgroup_subsys_state___177 *, struct cftype___177 *);
	int (*seq_show)(struct seq_file___225 *, void *);
	void * (*seq_start)(struct seq_file___225 *, loff_t *);
	void * (*seq_next)(struct seq_file___225 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___225 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___177 *, struct cftype___177 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___177 *, struct cftype___177 *, s64);
	ssize_t (*write)(struct kernfs_open_file___238 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___238 *, struct poll_table_struct___172 *);
};

struct xdp_rxq_info___59 {
	struct net_device___59 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___59 {
	struct net_device___59 *dev;
};

struct xdp_buff___59 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___59 *rxq;
	struct xdp_txq_info___59 *txq;
	u32 frame_sz;
};

struct xdp_frame___59 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___59 *dev_rx;
};

struct netlink_callback___59 {
	struct sk_buff___60 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___60 *, struct netlink_callback___59 *);
	int (*done)(struct netlink_callback___59 *);
	void *data;
	struct module___234 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___59 {
	int (*create)(struct sk_buff___60 *, struct net_device___59 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___60 *, unsigned char *);
	int (*cache)(const struct neighbour___47 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___59 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___60 *);
};

struct napi_struct___12 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___12 *, int);
	int poll_owner;
	struct net_device___59 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___60 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___257 *thread;
};

struct netdev_queue___59 {
	struct net_device___59 *dev;
	struct Qdisc___54 *qdisc;
	struct Qdisc___54 *qdisc_sleeping;
	struct kobject___238 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___59 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___54 {
	struct sk_buff___60 *head;
	struct sk_buff___60 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___54;

struct Qdisc___54 {
	int (*enqueue)(struct sk_buff___60 *, struct Qdisc___54 *, struct sk_buff___60 **);
	struct sk_buff___60 * (*dequeue)(struct Qdisc___54 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___54 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___59 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___59 gso_skb;
	struct qdisc_skb_head___54 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___54 *next_sched;
	struct sk_buff_head___59 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___59 {
	struct xdp_rxq_info___59 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___238 kobj;
	struct net_device___59 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___59 {
	enum net_device_path_type type;
	const struct net_device___59 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___59 = 0,
				DEV_PATH_BR_VLAN_TAG___59 = 1,
				DEV_PATH_BR_VLAN_UNTAG___59 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___59 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___59 {
	const struct net_device___59 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___59 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___54 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___59 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___59 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___60 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___59 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___59 *dev;
	const char *name;
};

struct net_device_ops___59 {
	int (*ndo_init)(struct net_device___59 *);
	void (*ndo_uninit)(struct net_device___59 *);
	int (*ndo_open)(struct net_device___59 *);
	int (*ndo_stop)(struct net_device___59 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___60 *, struct net_device___59 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___60 *, struct net_device___59 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___59 *, struct sk_buff___60 *, struct net_device___59 *);
	void (*ndo_change_rx_flags)(struct net_device___59 *, int);
	void (*ndo_set_rx_mode)(struct net_device___59 *);
	int (*ndo_set_mac_address)(struct net_device___59 *, void *);
	int (*ndo_validate_addr)(struct net_device___59 *);
	int (*ndo_do_ioctl)(struct net_device___59 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___59 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___59 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___59 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___59 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___59 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___59 *, int);
	int (*ndo_neigh_setup)(struct net_device___59 *, struct neigh_parms___47 *);
	void (*ndo_tx_timeout)(struct net_device___59 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___59 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___59 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___59 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___59 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___59 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___59 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___59 *);
	int (*ndo_netpoll_setup)(struct net_device___59 *, struct netpoll_info___2 *);
	void (*ndo_netpoll_cleanup)(struct net_device___59 *);
	int (*ndo_set_vf_mac)(struct net_device___59 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___59 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___59 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___59 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___59 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___59 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___59 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___59 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___59 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___59 *, int, struct sk_buff___60 *);
	int (*ndo_get_vf_guid)(struct net_device___59 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___59 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___59 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___59 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___59 *);
	int (*ndo_fcoe_disable)(struct net_device___59 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___59 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___59 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___59 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___59 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___59 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___59 *, const struct sk_buff___60 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___59 *, struct net_device___59 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___59 *, struct net_device___59 *);
	struct net_device___59 * (*ndo_get_xmit_slave)(struct net_device___59 *, struct sk_buff___60 *, bool);
	struct net_device___59 * (*ndo_sk_get_lower_dev)(struct net_device___59 *, struct sock___47 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___59 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___59 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___59 *, struct neighbour___47 *);
	void (*ndo_neigh_destroy)(struct net_device___59 *, struct neighbour___47 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___60 *, struct netlink_callback___59 *, struct net_device___59 *, struct net_device___59 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___60 *, struct nlattr **, struct net_device___59 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___59 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___60 *, u32, u32, struct net_device___59 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___59 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___59 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___59 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___59 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___59 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___59 *, struct net_device___59 *);
	void (*ndo_dfwd_del_station)(struct net_device___59 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___59 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___59 *);
	int (*ndo_change_proto_down)(struct net_device___59 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___59 *, struct sk_buff___60 *);
	void (*ndo_set_rx_headroom)(struct net_device___59 *, int);
	int (*ndo_bpf)(struct net_device___59 *, struct netdev_bpf___59 *);
	int (*ndo_xdp_xmit)(struct net_device___59 *, int, struct xdp_frame___59 **, u32);
	struct net_device___59 * (*ndo_xdp_get_xmit_slave)(struct net_device___59 *, struct xdp_buff___59 *);
	int (*ndo_xsk_wakeup)(struct net_device___59 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___59 *);
	int (*ndo_tunnel_ctl)(struct net_device___59 *, struct ip_tunnel_parm *, int);
	struct net_device___59 * (*ndo_get_peer_dev)(struct net_device___59 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___59 *, struct net_device_path___59 *);
};

struct neigh_parms___47 {
	possible_net_t___59 net;
	struct net_device___59 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___47 *);
	struct neigh_table___47 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll___2;

struct netpoll_info___2 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___59 txq;
	struct delayed_work tx_work;
	struct netpoll___2 *netpoll;
	struct callback_head rcu;
};

struct l3mdev_ops___47 {
	u32 (*l3mdev_fib_table)(const struct net_device___59 *);
	struct sk_buff___60 * (*l3mdev_l3_rcv)(struct net_device___59 *, struct sk_buff___60 *, u16);
	struct sk_buff___60 * (*l3mdev_l3_out)(struct net_device___59 *, struct sock___47 *, struct sk_buff___60 *, u16);
	struct dst_entry___47 * (*l3mdev_link_scope_lookup)(const struct net_device___59 *, struct flowi6 *);
};

struct ndisc_ops___33 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___59 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___59 *, struct neighbour___47 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___59 *, u8, struct neighbour___47 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___59 *, struct sk_buff___60 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___64 *, struct net_device___59 *, const struct prefix_info *, struct inet6_dev___33 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___4;

struct in_device___4 {
	struct net_device___59 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___4 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___47 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___33;

struct inet6_dev___33 {
	struct net_device___59 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___33 *mc_list;
	struct ifmcaddr6___33 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___59 mc_query_queue;
	struct sk_buff_head___59 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___8 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___47 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___54;

struct tcf_block___54;

struct mini_Qdisc___54 {
	struct tcf_proto___54 *filter_list;
	struct tcf_block___54 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___54 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___59 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___59 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___64 *, struct net_device___59 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___59 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___59 *, struct list_head *);
	size_t (*get_size)(const struct net_device___59 *);
	int (*fill_info)(struct sk_buff___60 *, const struct net_device___59 *);
	size_t (*get_xstats_size)(const struct net_device___59 *);
	int (*fill_xstats)(struct sk_buff___60 *, const struct net_device___59 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___59 *, struct net_device___59 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___59 *, const struct net_device___59 *);
	int (*fill_slave_info)(struct sk_buff___60 *, const struct net_device___59 *, const struct net_device___59 *);
	struct net___64 * (*get_link_net)(const struct net_device___59 *);
	size_t (*get_linkxstats_size)(const struct net_device___59 *, int);
	int (*fill_linkxstats)(struct sk_buff___60 *, const struct net_device___59 *, int *, int);
};

struct softnet_data___6 {
	struct list_head poll_list;
	struct sk_buff_head___59 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___6 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___54 *output_queue;
	struct Qdisc___54 **output_queue_tailp;
	struct sk_buff___60 *completion_queue;
	struct sk_buff_head___59 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___6 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___59 input_pkt_queue;
	struct napi_struct___12 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct in_ifaddr___4 {
	struct hlist_node hash;
	struct in_ifaddr___4 *ifa_next;
	struct in_device___4 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___2 {
	struct net_device___59 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
};

struct block_device_operations___142;

struct gendisk___145 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___145 *part0;
	const struct block_device_operations___142 *fops;
	struct request_queue___142 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___128 *bdi;
	struct kobject___238 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___238 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___142 {
	struct bio___142 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___167 *bip_vec;
	struct bio_vec___167 bip_inline_vecs[0];
};

struct blkcg___130;

struct blkg_policy_data___130;

struct blkcg_gq___130 {
	struct request_queue___142 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___130 *blkcg;
	struct blkcg_gq___130 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___130 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___142 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___142(struct request___142 *);

typedef void integrity_complete_fn___142(struct request___142 *, unsigned int);

struct blk_integrity_profile___142 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___142 *prepare_fn;
	integrity_complete_fn___142 *complete_fn;
	const char *name;
};

struct block_device_operations___142 {
	blk_qc_t (*submit_bio)(struct bio___142 *);
	int (*open)(struct block_device___145 *, fmode_t);
	void (*release)(struct gendisk___145 *, fmode_t);
	int (*rw_page)(struct block_device___145 *, sector_t, struct page___255 *, unsigned int);
	int (*ioctl)(struct block_device___145 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___145 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___145 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___145 *);
	int (*getgeo)(struct block_device___145 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___145 *, bool);
	void (*swap_slot_free_notify)(struct block_device___145 *, long unsigned int);
	int (*report_zones)(struct gendisk___145 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___145 *, umode_t *);
	struct module___234 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___145 *, sector_t *);
};

typedef void rq_end_io_fn___142(struct request___142 *, blk_status_t);

struct request___142 {
	struct request_queue___142 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___137 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___142 *bio;
	struct bio___142 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___167 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___142 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___142 *saved_end_io;
		} flush;
	};
	struct gendisk___145 *rq_disk;
	struct block_device___145 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___142 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___137 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___142 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___238 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___250 *debugfs_dir;
	struct dentry___250 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___142;

struct elevator_mq_ops___142 {
	int (*init_sched)(struct request_queue___142 *, struct elevator_type___142 *);
	void (*exit_sched)(struct elevator_queue___142 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___137 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___137 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___137 *);
	bool (*allow_merge)(struct request_queue___142 *, struct request___142 *, struct bio___142 *);
	bool (*bio_merge)(struct request_queue___142 *, struct bio___142 *, unsigned int);
	int (*request_merge)(struct request_queue___142 *, struct request___142 **, struct bio___142 *);
	void (*request_merged)(struct request_queue___142 *, struct request___142 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___142 *, struct request___142 *, struct request___142 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___142 *);
	void (*finish_request)(struct request___142 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___137 *, struct list_head *, bool);
	struct request___142 * (*dispatch_request)(struct blk_mq_hw_ctx___137 *);
	bool (*has_work)(struct blk_mq_hw_ctx___137 *);
	void (*completed_request)(struct request___142 *, u64);
	void (*requeue_request)(struct request___142 *);
	struct request___142 * (*former_request)(struct request_queue___142 *, struct request___142 *);
	struct request___142 * (*next_request)(struct request_queue___142 *, struct request___142 *);
	void (*init_icq)(struct io_cq___142 *);
	void (*exit_icq)(struct io_cq___142 *);
};

struct elv_fs_entry___142;

struct elevator_type___142 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___142 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___142 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___234 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___142 {
	struct elevator_type___142 *type;
	void *elevator_data;
	struct kobject___238 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___142 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___142 *, char *);
	ssize_t (*store)(struct elevator_queue___142 *, const char *, size_t);
};

struct blk_mq_queue_data___137;

struct blk_mq_ops___137 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___137 *, const struct blk_mq_queue_data___137 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___137 *);
	int (*get_budget)(struct request_queue___142 *);
	void (*put_budget)(struct request_queue___142 *, int);
	void (*set_rq_budget_token)(struct request___142 *, int);
	int (*get_rq_budget_token)(struct request___142 *);
	enum blk_eh_timer_return (*timeout)(struct request___142 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___137 *);
	void (*complete)(struct request___142 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___137 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___137 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___137 *, struct request___142 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___137 *, struct request___142 *, unsigned int);
	void (*initialize_rq_fn)(struct request___142 *);
	void (*cleanup_rq)(struct request___142 *);
	bool (*busy)(struct request_queue___142 *);
	int (*map_queues)(struct blk_mq_tag_set___137 *);
	void (*show_rq)(struct seq_file___225 *, struct request___142 *);
};

struct blk_mq_tag_set___137 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___137 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___137 {
	struct request___142 *rq;
	bool last;
};

struct blkcg_policy_data___130;

struct blkcg___130 {
	struct cgroup_subsys_state___177 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___130 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___130 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___130 {
	struct blkcg___130 *blkcg;
	int plid;
};

struct blkg_policy_data___130 {
	struct blkcg_gq___130 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___116 {
	struct mem_cgroup___116 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___116 {
	struct lruvec___124 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___116 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___116 *memcg;
};

struct obj_cgroup___116 {
	struct percpu_ref refcnt;
	struct mem_cgroup___116 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___54 {
	spinlock_t *lock;
	struct sk_buff___60 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___54;

struct Qdisc_ops___54 {
	struct Qdisc_ops___54 *next;
	const struct Qdisc_class_ops___54 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___60 *, struct Qdisc___54 *, struct sk_buff___60 **);
	struct sk_buff___60 * (*dequeue)(struct Qdisc___54 *);
	struct sk_buff___60 * (*peek)(struct Qdisc___54 *);
	int (*init)(struct Qdisc___54 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___54 *);
	void (*destroy)(struct Qdisc___54 *);
	int (*change)(struct Qdisc___54 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___54 *);
	int (*change_tx_queue_len)(struct Qdisc___54 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___54 *, unsigned int);
	int (*dump)(struct Qdisc___54 *, struct sk_buff___60 *);
	int (*dump_stats)(struct Qdisc___54 *, struct gnet_dump___54 *);
	void (*ingress_block_set)(struct Qdisc___54 *, u32);
	void (*egress_block_set)(struct Qdisc___54 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___54 *);
	u32 (*egress_block_get)(struct Qdisc___54 *);
	struct module___234 *owner;
};

struct Qdisc_class_ops___54 {
	unsigned int flags;
	struct netdev_queue___59 * (*select_queue)(struct Qdisc___54 *, struct tcmsg *);
	int (*graft)(struct Qdisc___54 *, long unsigned int, struct Qdisc___54 *, struct Qdisc___54 **, struct netlink_ext_ack *);
	struct Qdisc___54 * (*leaf)(struct Qdisc___54 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___54 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___54 *, u32);
	int (*change)(struct Qdisc___54 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___54 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___54 *, struct qdisc_walker *);
	struct tcf_block___54 * (*tcf_block)(struct Qdisc___54 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___54 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___54 *, long unsigned int);
	int (*dump)(struct Qdisc___54 *, long unsigned int, struct sk_buff___60 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___54 *, long unsigned int, struct gnet_dump___54 *);
};

struct tcf_chain___54;

struct tcf_block___54 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___64 *net;
	struct Qdisc___54 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___54 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___54;

struct tcf_proto_ops___54;

struct tcf_proto___54 {
	struct tcf_proto___54 *next;
	void *root;
	int (*classify)(struct sk_buff___60 *, const struct tcf_proto___54 *, struct tcf_result___54 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___54 *ops;
	struct tcf_chain___54 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___54 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___54 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___54 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___60 *, const struct tcf_proto___54 *, struct tcf_result___54 *);
	int (*init)(struct tcf_proto___54 *);
	void (*destroy)(struct tcf_proto___54 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___54 *, u32);
	void (*put)(struct tcf_proto___54 *, void *);
	int (*change)(struct net___64 *, struct sk_buff___60 *, struct tcf_proto___54 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___54 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___54 *);
	void (*walk)(struct tcf_proto___54 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___54 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___54 *, void *);
	void (*hw_del)(struct tcf_proto___54 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___64 *, struct tcf_chain___54 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___64 *, struct tcf_proto___54 *, void *, struct sk_buff___60 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___64 *, struct tcf_proto___54 *, void *, struct sk_buff___60 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___60 *, struct net___64 *, void *);
	struct module___234 *owner;
	int flags;
};

struct tcf_chain___54 {
	struct mutex filter_chain_lock;
	struct tcf_proto___54 *filter_chain;
	struct list_head list;
	struct tcf_block___54 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___54 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___47 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___54 *prog;
};

struct pneigh_entry___47;

struct neigh_hash_table___47;

struct neigh_table___47 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___59 *, __u32 *);
	bool (*key_eq)(const struct neighbour___47 *, const void *);
	int (*constructor)(struct neighbour___47 *);
	int (*pconstructor)(struct pneigh_entry___47 *);
	void (*pdestructor)(struct pneigh_entry___47 *);
	void (*proxy_redo)(struct sk_buff___60 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___59 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___47 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___59 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___47 *nht;
	struct pneigh_entry___47 **phash_buckets;
};

struct neigh_ops___47 {
	int family;
	void (*solicit)(struct neighbour___47 *, struct sk_buff___60 *);
	void (*error_report)(struct neighbour___47 *, struct sk_buff___60 *);
	int (*output)(struct neighbour___47 *, struct sk_buff___60 *);
	int (*connected_output)(struct neighbour___47 *, struct sk_buff___60 *);
};

struct pneigh_entry___47 {
	struct pneigh_entry___47 *next;
	possible_net_t___59 net;
	struct net_device___59 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___47 {
	struct neighbour___47 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___27 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___64 *, struct sock___47 *, struct sk_buff___60 *);
	int (*orig_input)(struct sk_buff___60 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___47 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___47 *ctarget;
	struct net___64 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___47 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___47 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___35;

struct timewait_sock_ops___35;

struct proto___47 {
	void (*close)(struct sock___47 *, long int);
	int (*pre_connect)(struct sock___47 *, struct sockaddr *, int);
	int (*connect)(struct sock___47 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___47 *, int);
	struct sock___47 * (*accept)(struct sock___47 *, int, int *, bool);
	int (*ioctl)(struct sock___47 *, int, long unsigned int);
	int (*init)(struct sock___47 *);
	void (*destroy)(struct sock___47 *);
	void (*shutdown)(struct sock___47 *, int);
	int (*setsockopt)(struct sock___47 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___47 *, int, int, char *, int *);
	void (*keepalive)(struct sock___47 *, int);
	int (*compat_ioctl)(struct sock___47 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___47 *, struct msghdr___49 *, size_t);
	int (*recvmsg)(struct sock___47 *, struct msghdr___49 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___47 *, struct page___255 *, int, size_t, int);
	int (*bind)(struct sock___47 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___47 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___47 *, struct sk_buff___60 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___47 *);
	int (*hash)(struct sock___47 *);
	void (*unhash)(struct sock___47 *);
	void (*rehash)(struct sock___47 *);
	int (*get_port)(struct sock___47 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___47 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___47 *, int);
	bool (*sock_is_readable)(struct sock___47 *);
	void (*enter_memory_pressure)(struct sock___47 *);
	void (*leave_memory_pressure)(struct sock___47 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___35 *rsk_prot;
	struct timewait_sock_ops___35 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___234 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___47 *, int);
};

struct sock_reuseport___11 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___54 *prog;
	struct sock___47 *socks[0];
};

struct request_sock___36;

struct request_sock_ops___35 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___47 *, struct request_sock___36 *);
	void (*send_ack)(const struct sock___47 *, struct sk_buff___60 *, struct request_sock___36 *);
	void (*send_reset)(const struct sock___47 *, struct sk_buff___60 *);
	void (*destructor)(struct request_sock___36 *);
	void (*syn_ack_timeout)(const struct request_sock___36 *);
};

struct timewait_sock_ops___35 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___47 *, struct sock___47 *, void *);
	void (*twsk_destructor)(struct sock___47 *);
};

struct request_sock___36 {
	struct sock_common___47 __req_common;
	struct request_sock___36 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___35 *rsk_ops;
	struct sock___47 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet6_ifaddr {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___33 *idev;
	struct fib6_info *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___33 {
	struct in6_addr mca_addr;
	struct inet6_dev___33 *idev;
	struct ifmcaddr6___33 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct pernet_operations___14 {
	struct list_head list;
	int (*init)(struct net___58 *);
	void (*pre_exit)(struct net___58 *);
	void (*exit)(struct net___58 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct netlink_skb_parms___8 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___43 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netdev_notifier_info___9 {
	struct net_device___54 *dev;
	struct netlink_ext_ack *extack;
};

typedef int (*rtnl_doit_func___4)(struct sk_buff___54 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___4)(struct sk_buff___54 *, struct netlink_callback___53 *);

struct fib_rule_uid_range {
	__u32 start;
	__u32 end;
};

enum {
	FRA_UNSPEC = 0,
	FRA_DST = 1,
	FRA_SRC = 2,
	FRA_IIFNAME = 3,
	FRA_GOTO = 4,
	FRA_UNUSED2 = 5,
	FRA_PRIORITY = 6,
	FRA_UNUSED3 = 7,
	FRA_UNUSED4 = 8,
	FRA_UNUSED5 = 9,
	FRA_FWMARK = 10,
	FRA_FLOW = 11,
	FRA_TUN_ID = 12,
	FRA_SUPPRESS_IFGROUP = 13,
	FRA_SUPPRESS_PREFIXLEN = 14,
	FRA_TABLE = 15,
	FRA_FWMASK = 16,
	FRA_OIFNAME = 17,
	FRA_PAD = 18,
	FRA_L3MDEV = 19,
	FRA_UID_RANGE = 20,
	FRA_PROTOCOL = 21,
	FRA_IP_PROTO = 22,
	FRA_SPORT_RANGE = 23,
	FRA_DPORT_RANGE = 24,
	__FRA_MAX = 25,
};

enum {
	FR_ACT_UNSPEC = 0,
	FR_ACT_TO_TBL = 1,
	FR_ACT_GOTO = 2,
	FR_ACT_NOP = 3,
	FR_ACT_RES3 = 4,
	FR_ACT_RES4 = 5,
	FR_ACT_BLACKHOLE = 6,
	FR_ACT_UNREACHABLE = 7,
	FR_ACT_PROHIBIT = 8,
	__FR_ACT_MAX = 9,
};

struct fib_rule_notifier_info {
	struct fib_notifier_info info;
	struct fib_rule___42 *rule;
};

struct dentry___251;

struct super_block___251;

struct module___235;

struct file_system_type___251 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___251 * (*mount)(struct file_system_type___251 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___251 *);
	struct module___235 *owner;
	struct file_system_type___251 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___251;

struct kiocb___251;

struct iov_iter___171;

struct poll_table_struct___173;

struct vm_area_struct___256;

struct inode___251;

struct file_lock___251;

struct page___256;

struct pipe_inode_info___92;

struct seq_file___226;

struct file_operations___252 {
	struct module___235 *owner;
	loff_t (*llseek)(struct file___251 *, loff_t, int);
	ssize_t (*read)(struct file___251 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___251 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___251 *, struct iov_iter___171 *);
	ssize_t (*write_iter)(struct kiocb___251 *, struct iov_iter___171 *);
	int (*iopoll)(struct kiocb___251 *, bool);
	int (*iterate)(struct file___251 *, struct dir_context *);
	int (*iterate_shared)(struct file___251 *, struct dir_context *);
	__poll_t (*poll)(struct file___251 *, struct poll_table_struct___173 *);
	long int (*unlocked_ioctl)(struct file___251 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___251 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___251 *, struct vm_area_struct___256 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___251 *, struct file___251 *);
	int (*flush)(struct file___251 *, fl_owner_t);
	int (*release)(struct inode___251 *, struct file___251 *);
	int (*fsync)(struct file___251 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___251 *, int);
	int (*lock)(struct file___251 *, int, struct file_lock___251 *);
	ssize_t (*sendpage)(struct file___251 *, struct page___256 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___251 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___251 *, long unsigned int);
	int (*flock)(struct file___251 *, int, struct file_lock___251 *);
	ssize_t (*splice_write)(struct pipe_inode_info___92 *, struct file___251 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___251 *, loff_t *, struct pipe_inode_info___92 *, size_t, unsigned int);
	int (*setlease)(struct file___251 *, long int, struct file_lock___251 **, void **);
	long int (*fallocate)(struct file___251 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___226 *, struct file___251 *);
	ssize_t (*copy_file_range)(struct file___251 *, loff_t, struct file___251 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___251 *, loff_t, struct file___251 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___251 *, loff_t, loff_t, int);
};

struct vmacache___256 {
	u64 seqnum;
	struct vm_area_struct___256 *vmas[4];
};

struct page_frag___256 {
	struct page___256 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___84;

struct debug_info___84 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___84 *hbp_break[16];
	struct perf_event___84 *hbp_watch[16];
};

struct thread_struct___84 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___84 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___257;

struct pid___228;

struct nsproxy___237;

struct signal_struct___252;

struct bio_list___143;

struct backing_dev_info___129;

struct io_context___143;

struct css_set___178;

struct perf_event_context___84;

struct mem_cgroup___117;

struct request_queue___143;

struct vm_struct___234;

struct task_struct___258 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___258 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___257 *mm;
	struct mm_struct___257 *active_mm;
	struct vmacache___256 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___258 *real_parent;
	struct task_struct___258 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___258 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___228 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___237 *nsproxy;
	struct signal_struct___252 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___258 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___143 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___129 *backing_dev_info;
	struct io_context___143 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___178 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___84 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___92 *splice_pipe;
	struct page_frag___256 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___117 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___117 *active_memcg;
	struct request_queue___143 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___258 *oom_reaper_list;
	struct vm_struct___234 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___239;

struct kobj_type___239;

struct kernfs_node___239;

struct kobject___239 {
	const char *name;
	struct list_head entry;
	struct kobject___239 *parent;
	struct kset___239 *kset;
	struct kobj_type___239 *ktype;
	struct kernfs_node___239 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___236 {
	struct kobject___239 kobj;
	struct module___235 *mod;
	struct kobject___239 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___235 {
	struct module___235 *mod;
	struct latch_tree_node node;
};

struct module_layout___235 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___235 mtn;
};

struct module_attribute___235;

struct kernel_param___235;

struct trace_event_call___78;

struct module___235 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___236 mkobj;
	struct module_attribute___235 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___239 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___235 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___235 core_layout;
	struct module_layout___235 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___78 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___84 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___258 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___84)(struct perf_event___84 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___84;

struct fasync_struct___251;

struct pid_namespace___228;

struct bpf_prog___55;

struct perf_cgroup___84;

struct perf_event___84 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___84 *group_leader;
	struct pmu___84 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___84 hw;
	struct perf_event_context___84 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___84 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___258 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___251 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___84 *aux_event;
	void (*destroy)(struct perf_event___84 *);
	struct callback_head callback_head;
	struct pid_namespace___228 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___84 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___84 orig_overflow_handler;
	struct bpf_prog___55 *prog;
	u64 bpf_cookie;
	struct trace_event_call___78 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___84 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___228 {
	int nr;
	struct pid_namespace___228 *ns;
};

struct pid_namespace___228 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___258 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___228 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___228 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___228 numbers[1];
};

typedef struct page___256 *pgtable_t___256;

struct address_space___251;

struct page_pool___80;

struct dev_pagemap___246;

struct page___256 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___251 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___80 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___256 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___256 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___257 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___246 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___246;

struct vm_area_struct___256 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___256 *vm_next;
	struct vm_area_struct___256 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___257 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___246 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___251 *vm_file;
	struct file___251 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___252 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___258 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___258 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___228 *pids[4];
	struct pid___228 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___257 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___256;

struct mm_struct___257 {
	struct {
		struct vm_area_struct___256 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___251 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___256 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___258 *owner;
		struct user_namespace___26 *user_ns;
		struct file___251 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___65;

struct cgroup_namespace___178;

struct nsproxy___237 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___228 *pid_ns_for_children;
	struct net___65 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___178 *cgroup_ns;
};

struct bio___143;

struct bio_list___143 {
	struct bio___143 *head;
	struct bio___143 *tail;
};

struct cgroup_subsys_state___178;

struct bdi_writeback___129 {
	struct backing_dev_info___129 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___178 *memcg_css;
	struct cgroup_subsys_state___178 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___232;

struct backing_dev_info___129 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___129 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___232 *dev;
	char dev_name[64];
	struct device___232 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___251 *debug_dir;
};

struct io_cq___143;

struct io_context___143 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___143 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___178;

struct css_set___178 {
	struct cgroup_subsys_state___178 *subsys[14];
	refcount_t refcount;
	struct css_set___178 *dom_cset;
	struct cgroup___178 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___178 *mg_src_cgrp;
	struct cgroup___178 *mg_dst_cgrp;
	struct css_set___178 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___84 {
	struct pmu___84 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___258 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___84 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___92;

struct pipe_inode_info___92 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___256 *tmp_page;
	struct fasync_struct___251 *fasync_readers;
	struct fasync_struct___251 *fasync_writers;
	struct pipe_buffer___92 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___178;

struct cgroup_subsys_state___178 {
	struct cgroup___178 *cgroup;
	struct cgroup_subsys___178 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___178 *parent;
};

struct cgroup_file___178 {
	struct kernfs_node___239 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___117;

struct mem_cgroup_per_node___117;

struct mem_cgroup___117 {
	struct cgroup_subsys_state___178 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___178 events_file;
	struct cgroup_file___178 events_local_file;
	struct cgroup_file___178 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___117 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___258 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___117 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___143;

struct blk_integrity___143 {
	const struct blk_integrity_profile___143 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___143 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___143 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___143;

struct elevator_queue___143;

struct blk_mq_ops___138;

struct blk_mq_hw_ctx___138;

struct gendisk___146;

struct blkcg_gq___131;

struct blk_mq_tag_set___138;

struct request_queue___143 {
	struct request___143 *last_merge;
	struct elevator_queue___143 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___138 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___138 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___146 *disk;
	struct kobject___239 kobj;
	struct kobject___239 *mq_kobj;
	struct blk_integrity___143 integrity;
	struct device___232 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___131 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___138 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___143 bio_split;
	struct dentry___251 *debugfs_dir;
	struct dentry___251 *sched_debugfs_dir;
	struct dentry___251 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___234 {
	struct vm_struct___234 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___256 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___168 {
	struct page___256 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___171 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___168 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___92 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___50 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___171 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___251 *msg_iocb;
};

struct kiocb___251 {
	struct file___251 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___251 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___60;

struct sock___48;

struct sk_buff___61 {
	union {
		struct {
			struct sk_buff___61 *next;
			struct sk_buff___61 *prev;
			union {
				struct net_device___60 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___48 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___61 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___65;

struct fqdir___65 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___65 *f;
	struct net___65 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___65;

struct inet_frags___65 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___65 *, const void *);
	void (*destructor)(struct inet_frag_queue___65 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___27;

struct fib_rules_ops___48;

struct tcp_congestion_ops___11;

struct fib_notifier_ops___48;

struct netns_ipv4___65 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___27 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___48 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___48 *fibnl;
	struct sock___48 **icmp_sk;
	struct sock___48 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___48 **tcp_sk;
	struct fqdir___65 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___11 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___48 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___48 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___48 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___48;

struct neighbour___48;

struct dst_ops___65 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___65 *);
	struct dst_entry___48 * (*check)(struct dst_entry___48 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___48 *);
	unsigned int (*mtu)(const struct dst_entry___48 *);
	u32 * (*cow_metrics)(struct dst_entry___48 *, long unsigned int);
	void (*destroy)(struct dst_entry___48 *);
	void (*ifdown)(struct dst_entry___48 *, struct net_device___60 *, int);
	struct dst_entry___48 * (*negative_advice)(struct dst_entry___48 *);
	void (*link_failure)(struct sk_buff___61 *);
	void (*update_pmtu)(struct dst_entry___48 *, struct sock___48 *, struct sk_buff___61 *, u32, bool);
	void (*redirect)(struct dst_entry___48 *, struct sock___48 *, struct sk_buff___61 *);
	int (*local_out)(struct net___65 *, struct sock___48 *, struct sk_buff___61 *);
	struct neighbour___48 * (*neigh_lookup)(const struct dst_entry___48 *, struct sk_buff___61 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___48 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___9;

struct rt6_info___9;

struct fib6_table___9;

struct netns_ipv6___65 {
	struct dst_ops___65 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___65 *fqdir;
	struct fib6_info___9 *fib6_null_entry;
	struct rt6_info___9 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___9 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___9 *ip6_prohibit_entry;
	struct rt6_info___9 *ip6_blk_hole_entry;
	struct fib6_table___9 *fib6_local_tbl;
	struct fib_rules_ops___48 *fib6_rules_ops;
	struct sock___48 **icmp_sk;
	struct sock___48 *ndisc_sk;
	struct sock___48 *tcp_sk;
	struct sock___48 *igmp_sk;
	struct sock___48 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___48 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___48 *notifier_ops;
	struct fib_notifier_ops___48 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___65 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___65 *fqdir;
};

struct netns_sctp___48 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___48 *ctl_sock;
	struct sock___48 *udp4_sock;
	struct sock___48 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___60 {
	struct sk_buff___61 *next;
	struct sk_buff___61 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___55;

struct netns_bpf___55 {
	struct bpf_prog_array___55 *run_array[2];
	struct bpf_prog___55 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___65 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___48 *nlsk;
	struct sock___48 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___65 xfrm4_dst_ops;
	struct dst_ops___65 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___65 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___48 *rtnl;
	struct sock___48 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___60 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___65 ipv4;
	struct netns_ipv6___65 ipv6;
	struct netns_ieee802154_lowpan___65 ieee802154_lowpan;
	struct netns_sctp___48 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___60 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___55 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___65 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___48 *crypto_nlsk;
	struct sock___48 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___65 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___61 *fragments_tail;
	struct sk_buff___61 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___65 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___27 {
	struct ip_ra_chain___27 *next;
	struct sock___48 *sk;
	union {
		void (*destructor)(struct sock___48 *);
		struct sock___48 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___48;

struct fib_lookup_arg___48;

struct fib_rules_ops___48 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___48 *, struct flowi *, int, struct fib_lookup_arg___48 *);
	bool (*suppress)(struct fib_rule___48 *, int, struct fib_lookup_arg___48 *);
	int (*match)(struct fib_rule___48 *, struct flowi *, int);
	int (*configure)(struct fib_rule___48 *, struct sk_buff___61 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___48 *);
	int (*compare)(struct fib_rule___48 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___48 *, struct sk_buff___61 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___48 *);
	void (*flush_cache)(struct fib_rules_ops___48 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___235 *owner;
	struct net___65 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___65 *net;
} possible_net_t___60;

struct proto___48;

struct sock_common___48 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___48 *skc_prot;
	possible_net_t___60 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___48 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___48 {
	struct cgroup___178 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___48;

struct socket_wq___49;

struct socket___50;

struct sock_reuseport___12;

struct sock___48 {
	struct sock_common___48 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___60 sk_error_queue;
	struct sk_buff___61 *sk_rx_skb_cache;
	struct sk_buff_head___60 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___61 *head;
		struct sk_buff___61 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___48 *sk_filter;
	union {
		struct socket_wq___49 *sk_wq;
		struct socket_wq___49 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___48 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___48 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___61 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___61 *sk_tx_skb_cache;
	struct sk_buff_head___60 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___256 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___48 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___228 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___50 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___48 sk_cgrp_data;
	struct mem_cgroup___117 *sk_memcg;
	void (*sk_state_change)(struct sock___48 *);
	void (*sk_data_ready)(struct sock___48 *);
	void (*sk_write_space)(struct sock___48 *);
	void (*sk_error_report)(struct sock___48 *);
	int (*sk_backlog_rcv)(struct sock___48 *, struct sk_buff___61 *);
	struct sk_buff___61 * (*sk_validate_xmit_skb)(struct sock___48 *, struct net_device___60 *, struct sk_buff___61 *);
	void (*sk_destruct)(struct sock___48 *);
	struct sock_reuseport___12 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct tcp_congestion_ops___11 {
	u32 (*ssthresh)(struct sock___48 *);
	void (*cong_avoid)(struct sock___48 *, u32, u32);
	void (*set_state)(struct sock___48 *, u8);
	void (*cwnd_event)(struct sock___48 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___48 *, u32);
	void (*pkts_acked)(struct sock___48 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___48 *);
	void (*cong_control)(struct sock___48 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___48 *);
	u32 (*sndbuf_expand)(struct sock___48 *);
	size_t (*get_info)(struct sock___48 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___235 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___48 *);
	void (*release)(struct sock___48 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___48 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___65 *);
	int (*fib_dump)(struct net___65 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___235 *owner;
	struct callback_head rcu;
};

struct address_space_operations___251;

struct address_space___251 {
	struct inode___251 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___251 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___80 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___232 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___80 {
	u32 count;
	struct page___256 *cache[128];
};

struct page_pool___80 {
	struct page_pool_params___80 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___256 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___80 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___246;

struct dev_pagemap___246 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___246 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___251;

struct path___251 {
	struct vfsmount___251 *mnt;
	struct dentry___251 *dentry;
};

struct fown_struct___228 {
	rwlock_t lock;
	struct pid___228 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___251 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___251 f_path;
	struct inode___251 *f_inode;
	const struct file_operations___252 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___228 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___251 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___246;

struct vm_operations_struct___246 {
	void (*open)(struct vm_area_struct___256 *);
	void (*close)(struct vm_area_struct___256 *);
	int (*may_split)(struct vm_area_struct___256 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___256 *);
	int (*mprotect)(struct vm_area_struct___256 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___246 *);
	vm_fault_t (*huge_fault)(struct vm_fault___246 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___246 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___256 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___246 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___246 *);
	int (*access)(struct vm_area_struct___256 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___256 *);
	int (*set_policy)(struct vm_area_struct___256 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___256 *, long unsigned int);
	struct page___256 * (*find_special_page)(struct vm_area_struct___256 *, long unsigned int);
};

struct core_thread___256 {
	struct task_struct___258 *task;
	struct core_thread___256 *next;
};

struct core_state___256 {
	atomic_t nr_threads;
	struct core_thread___256 dumper;
	struct completion startup;
};

struct vm_fault___246 {
	const struct {
		struct vm_area_struct___256 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___256 *cow_page;
	struct page___256 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___256 prealloc_pte;
};

struct pglist_data___125;

struct lruvec___125 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___125 *pgdat;
};

struct zone___125 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___125 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___125 {
	struct zone___125 *zone;
	int zone_idx;
};

struct zonelist___125 {
	struct zoneref___125 _zonerefs[321];
};

struct pglist_data___125 {
	struct zone___125 node_zones[5];
	struct zonelist___125 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___258 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___258 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___125 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct lwtunnel_state___28;

struct dst_entry___48 {
	struct net_device___60 *dev;
	struct dst_ops___65 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___61 *);
	int (*output)(struct net___65 *, struct sock___48 *, struct sk_buff___61 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___28 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___60(struct sk_buff___61 **);

struct wakeup_source___232;

struct dev_pm_info___232 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___232 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___232 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___232;

struct bus_type___232;

struct device_driver___232;

struct dev_pm_domain___232;

struct fwnode_handle___228;

struct class___232;

struct attribute_group___239;

struct device___232 {
	struct kobject___239 kobj;
	struct device___232 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___232 *type;
	struct bus_type___232 *bus;
	struct device_driver___232 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___232 power;
	struct dev_pm_domain___232 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___228 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___232 *class;
	const struct attribute_group___239 **groups;
	void (*release)(struct device___232 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___55 {
	struct bpf_prog___55 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___60;

struct net_device_ops___60;

struct l3mdev_ops___48;

struct ndisc_ops___34;

struct xfrmdev_ops___60;

struct header_ops___60;

struct in_device___5;

struct inet6_dev___34;

struct netdev_rx_queue___60;

struct mini_Qdisc___55;

struct netdev_queue___60;

struct Qdisc___55;

struct netpoll_info___3;

struct rtnl_link_ops___55;

struct dcbnl_rtnl_ops___60;

struct net_device___60 {
	char name[16];
	struct netdev_name_node___60 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___60 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___48 *l3mdev_ops;
	const struct ndisc_ops___34 *ndisc_ops;
	const struct xfrmdev_ops___60 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___60 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___239 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___5 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___34 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___60 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___55 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___60 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___55 *miniq_ingress;
	struct netdev_queue___60 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___60 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___55 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___55 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___60 = 0,
		NETREG_REGISTERED___60 = 1,
		NETREG_UNREGISTERING___60 = 2,
		NETREG_UNREGISTERED___60 = 3,
		NETREG_RELEASED___60 = 4,
		NETREG_DUMMY___60 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___60 = 0,
		RTNL_LINK_INITIALIZING___60 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___60 *);
	struct netpoll_info___3 *npinfo;
	possible_net_t___60 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___232 dev;
	const struct attribute_group___239 *sysfs_groups[4];
	const struct attribute_group___239 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___55 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___60 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___55 xdp_state[3];
	long: 64;
};

struct neigh_table___48;

struct neigh_parms___48;

struct neigh_ops___48;

struct neighbour___48 {
	struct neighbour___48 *next;
	struct neigh_table___48 *tbl;
	struct neigh_parms___48 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___60 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___48 *, struct sk_buff___61 *);
	const struct neigh_ops___48 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___60 *dev;
	u8 primary_key[0];
};

struct rtable___9;

struct fnhe_hash_bucket___9;

struct fib_nh_common___9 {
	struct net_device___60 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___28 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___9 **nhc_pcpu_rth_output;
	struct rtable___9 *nhc_rth_input;
	struct fnhe_hash_bucket___9 *nhc_exceptions;
};

struct fib6_nh___9 {
	struct fib_nh_common___9 nh_common;
	long unsigned int last_probe;
	struct rt6_info___9 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___9;

struct fib6_info___9 {
	struct fib6_table___9 *fib6_table;
	struct fib6_info___9 *fib6_next;
	struct fib6_node___9 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___9 fib6_nh[0];
};

struct rt6_info___9 {
	struct dst_entry___48 dst;
	struct fib6_info___9 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___34 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___9 {
	struct fib6_node___9 *parent;
	struct fib6_node___9 *left;
	struct fib6_node___9 *right;
	struct fib6_node___9 *subtree;
	struct fib6_info___9 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___9 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___9 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___9 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___55 {
	struct bpf_prog___55 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___55 {
	struct callback_head rcu;
	struct bpf_prog_array_item___55 items[0];
};

struct bpf_prog_aux___63;

struct bpf_prog___55 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___63 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___251;

struct dentry___251 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___251 *d_parent;
	struct qstr d_name;
	struct inode___251 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___251 *d_op;
	struct super_block___251 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___251;

struct inode___251 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___251 *i_op;
	struct super_block___251 *i_sb;
	struct address_space___251 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___129 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___252 *i_fop;
		void (*free_inode)(struct inode___251 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___251 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___92 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___251 {
	int (*d_revalidate)(struct dentry___251 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___251 *, unsigned int);
	int (*d_hash)(const struct dentry___251 *, struct qstr *);
	int (*d_compare)(const struct dentry___251 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___251 *);
	int (*d_init)(struct dentry___251 *);
	void (*d_release)(struct dentry___251 *);
	void (*d_prune)(struct dentry___251 *);
	void (*d_iput)(struct dentry___251 *, struct inode___251 *);
	char * (*d_dname)(struct dentry___251 *, char *, int);
	struct vfsmount___251 * (*d_automount)(struct path___251 *);
	int (*d_manage)(const struct path___251 *, bool);
	struct dentry___251 * (*d_real)(struct dentry___251 *, const struct inode___251 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___251;

struct mem_dqinfo___251 {
	struct quota_format_type___251 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___251;

struct quota_info___251 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___251 *files[3];
	struct mem_dqinfo___251 info[3];
	const struct quota_format_ops___251 *ops[3];
};

struct rcuwait___252 {
	struct task_struct___258 *task;
};

struct percpu_rw_semaphore___252 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___252 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___251 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___252 rw_sem[3];
};

struct shrink_control___117;

struct shrinker___117 {
	long unsigned int (*count_objects)(struct shrinker___117 *, struct shrink_control___117 *);
	long unsigned int (*scan_objects)(struct shrinker___117 *, struct shrink_control___117 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___251;

struct dquot_operations___251;

struct quotactl_ops___251;

struct block_device___146;

struct super_block___251 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___251 *s_type;
	const struct super_operations___251 *s_op;
	const struct dquot_operations___251 *dq_op;
	const struct quotactl_ops___251 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___251 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___146 *s_bdev;
	struct backing_dev_info___129 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___251 s_dquot;
	struct sb_writers___251 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___251 *s_d_op;
	int cleancache_poolid;
	struct shrinker___117 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___251 {
	struct dentry___251 *mnt_root;
	struct super_block___251 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___117 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___117 *memcg;
};

struct psi_group___178 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___258 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___55 {
	struct bpf_prog_array___55 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___55 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___178;

struct cgroup_rstat_cpu___178;

struct cgroup___178 {
	struct cgroup_subsys_state___178 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___239 *kn;
	struct cgroup_file___178 procs_file;
	struct cgroup_file___178 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___178 *subsys[14];
	struct cgroup_root___178 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___178 *dom_cgrp;
	struct cgroup___178 *old_dom_cgrp;
	struct cgroup_rstat_cpu___178 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___178 psi;
	struct cgroup_bpf___55 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___143 {
	struct request_queue___143 *q;
	struct io_context___143 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___251 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___251 *ia_file;
};

struct dquot___251 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___251 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___251 {
	int qf_fmt_id;
	const struct quota_format_ops___251 *qf_ops;
	struct module___235 *qf_owner;
	struct quota_format_type___251 *qf_next;
};

struct quota_format_ops___251 {
	int (*check_quota_file)(struct super_block___251 *, int);
	int (*read_file_info)(struct super_block___251 *, int);
	int (*write_file_info)(struct super_block___251 *, int);
	int (*free_file_info)(struct super_block___251 *, int);
	int (*read_dqblk)(struct dquot___251 *);
	int (*commit_dqblk)(struct dquot___251 *);
	int (*release_dqblk)(struct dquot___251 *);
	int (*get_next_id)(struct super_block___251 *, struct kqid *);
};

struct dquot_operations___251 {
	int (*write_dquot)(struct dquot___251 *);
	struct dquot___251 * (*alloc_dquot)(struct super_block___251 *, int);
	void (*destroy_dquot)(struct dquot___251 *);
	int (*acquire_dquot)(struct dquot___251 *);
	int (*release_dquot)(struct dquot___251 *);
	int (*mark_dirty)(struct dquot___251 *);
	int (*write_info)(struct super_block___251 *, int);
	qsize_t * (*get_reserved_space)(struct inode___251 *);
	int (*get_projid)(struct inode___251 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___251 *, qsize_t *);
	int (*get_next_id)(struct super_block___251 *, struct kqid *);
};

struct quotactl_ops___251 {
	int (*quota_on)(struct super_block___251 *, int, int, const struct path___251 *);
	int (*quota_off)(struct super_block___251 *, int);
	int (*quota_enable)(struct super_block___251 *, unsigned int);
	int (*quota_disable)(struct super_block___251 *, unsigned int);
	int (*quota_sync)(struct super_block___251 *, int);
	int (*set_info)(struct super_block___251 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___251 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___251 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___251 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___251 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___251 *, unsigned int);
};

struct writeback_control___129;

struct address_space_operations___251 {
	int (*writepage)(struct page___256 *, struct writeback_control___129 *);
	int (*readpage)(struct file___251 *, struct page___256 *);
	int (*writepages)(struct address_space___251 *, struct writeback_control___129 *);
	int (*set_page_dirty)(struct page___256 *);
	int (*readpages)(struct file___251 *, struct address_space___251 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___251 *, struct address_space___251 *, loff_t, unsigned int, unsigned int, struct page___256 **, void **);
	int (*write_end)(struct file___251 *, struct address_space___251 *, loff_t, unsigned int, unsigned int, struct page___256 *, void *);
	sector_t (*bmap)(struct address_space___251 *, sector_t);
	void (*invalidatepage)(struct page___256 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___256 *, gfp_t);
	void (*freepage)(struct page___256 *);
	ssize_t (*direct_IO)(struct kiocb___251 *, struct iov_iter___171 *);
	int (*migratepage)(struct address_space___251 *, struct page___256 *, struct page___256 *, enum migrate_mode);
	bool (*isolate_page)(struct page___256 *, isolate_mode_t);
	void (*putback_page)(struct page___256 *);
	int (*launder_page)(struct page___256 *);
	int (*is_partially_uptodate)(struct page___256 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___256 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___251 *, struct page___256 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___251 *, sector_t *);
	void (*swap_deactivate)(struct file___251 *);
};

struct writeback_control___129 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___129 *wb;
	struct inode___251 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___251 {
	struct dentry___251 * (*lookup)(struct inode___251 *, struct dentry___251 *, unsigned int);
	const char * (*get_link)(struct dentry___251 *, struct inode___251 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___251 *, int);
	struct posix_acl * (*get_acl)(struct inode___251 *, int, bool);
	int (*readlink)(struct dentry___251 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___251 *, struct dentry___251 *, umode_t, bool);
	int (*link)(struct dentry___251 *, struct inode___251 *, struct dentry___251 *);
	int (*unlink)(struct inode___251 *, struct dentry___251 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___251 *, struct dentry___251 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___251 *, struct dentry___251 *, umode_t);
	int (*rmdir)(struct inode___251 *, struct dentry___251 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___251 *, struct dentry___251 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___251 *, struct dentry___251 *, struct inode___251 *, struct dentry___251 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___251 *, struct iattr___251 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___251 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___251 *, char *, size_t);
	int (*fiemap)(struct inode___251 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___251 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___251 *, struct dentry___251 *, struct file___251 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___251 *, struct dentry___251 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___251 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___251 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___251 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___251 {
	void (*fl_copy_lock)(struct file_lock___251 *, struct file_lock___251 *);
	void (*fl_release_private)(struct file_lock___251 *);
};

struct lock_manager_operations___251;

struct file_lock___251 {
	struct file_lock___251 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___251 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___251 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___251 *fl_ops;
	const struct lock_manager_operations___251 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___251 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___251 *);
	int (*lm_grant)(struct file_lock___251 *, int);
	bool (*lm_break)(struct file_lock___251 *);
	int (*lm_change)(struct file_lock___251 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___251 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___251 *);
};

struct fasync_struct___251 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___251 *fa_next;
	struct file___251 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___251 {
	struct inode___251 * (*alloc_inode)(struct super_block___251 *);
	void (*destroy_inode)(struct inode___251 *);
	void (*free_inode)(struct inode___251 *);
	void (*dirty_inode)(struct inode___251 *, int);
	int (*write_inode)(struct inode___251 *, struct writeback_control___129 *);
	int (*drop_inode)(struct inode___251 *);
	void (*evict_inode)(struct inode___251 *);
	void (*put_super)(struct super_block___251 *);
	int (*sync_fs)(struct super_block___251 *, int);
	int (*freeze_super)(struct super_block___251 *);
	int (*freeze_fs)(struct super_block___251 *);
	int (*thaw_super)(struct super_block___251 *);
	int (*unfreeze_fs)(struct super_block___251 *);
	int (*statfs)(struct dentry___251 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___251 *, int *, char *);
	void (*umount_begin)(struct super_block___251 *);
	int (*show_options)(struct seq_file___226 *, struct dentry___251 *);
	int (*show_devname)(struct seq_file___226 *, struct dentry___251 *);
	int (*show_path)(struct seq_file___226 *, struct dentry___251 *);
	int (*show_stats)(struct seq_file___226 *, struct dentry___251 *);
	ssize_t (*quota_read)(struct super_block___251 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___251 *, int, const char *, size_t, loff_t);
	struct dquot___251 ** (*get_dquots)(struct inode___251 *);
	long int (*nr_cached_objects)(struct super_block___251 *, struct shrink_control___117 *);
	long int (*free_cached_objects)(struct super_block___251 *, struct shrink_control___117 *);
	struct file___251 * (*real_loop)(struct file___251 *);
};

struct block_device___146 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___251 *bd_inode;
	struct super_block___251 *bd_super;
	void *bd_claiming;
	struct device___232 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___239 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___146 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___251 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___181)(struct file___251 *, wait_queue_head_t *, struct poll_table_struct___173 *);

struct poll_table_struct___173 {
	poll_queue_proc___181 _qproc;
	__poll_t _key;
};

struct seq_operations___226;

struct seq_file___226 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___226 *op;
	int poll_event;
	const struct file___251 *file;
	void *private;
};

typedef void bio_end_io_t___143(struct bio___143 *);

struct bio_integrity_payload___143;

struct bio___143 {
	struct bio___143 *bi_next;
	struct block_device___146 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___143 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___131 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___143 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___168 *bi_io_vec;
	struct bio_set___143 *bi_pool;
	struct bio_vec___168 bi_inline_vecs[0];
};

struct dev_pagemap_ops___246 {
	void (*page_free)(struct page___256 *);
	void (*kill)(struct dev_pagemap___246 *);
	void (*cleanup)(struct dev_pagemap___246 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___246 *);
};

struct fwnode_operations___228;

struct fwnode_handle___228 {
	struct fwnode_handle___228 *secondary;
	const struct fwnode_operations___228 *ops;
	struct device___232 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___228;

struct fwnode_endpoint___228;

struct fwnode_operations___228 {
	struct fwnode_handle___228 * (*get)(struct fwnode_handle___228 *);
	void (*put)(struct fwnode_handle___228 *);
	bool (*device_is_available)(const struct fwnode_handle___228 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___228 *, const struct device___232 *);
	bool (*property_present)(const struct fwnode_handle___228 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___228 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___228 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___228 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*get_parent)(const struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*get_next_child_node)(const struct fwnode_handle___228 *, struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*get_named_child_node)(const struct fwnode_handle___228 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___228 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___228 *);
	struct fwnode_handle___228 * (*graph_get_next_endpoint)(const struct fwnode_handle___228 *, struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*graph_get_remote_endpoint)(const struct fwnode_handle___228 *);
	struct fwnode_handle___228 * (*graph_get_port_parent)(struct fwnode_handle___228 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___228 *, struct fwnode_endpoint___228 *);
	int (*add_links)(struct fwnode_handle___228 *);
};

struct fwnode_endpoint___228 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___228 *local_fwnode;
};

struct fwnode_reference_args___228 {
	struct fwnode_handle___228 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___239;

struct kernfs_elem_dir___239 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___239 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___239;

struct kernfs_root___239 {
	struct kernfs_node___239 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___239 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___239 {
	struct kernfs_node___239 *target_kn;
};

struct kernfs_ops___239;

struct kernfs_elem_attr___239 {
	const struct kernfs_ops___239 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___239 *notify_next;
};

struct kernfs_node___239 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___239 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___239 dir;
		struct kernfs_elem_symlink___239 symlink;
		struct kernfs_elem_attr___239 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___239;

struct kernfs_ops___239 {
	int (*open)(struct kernfs_open_file___239 *);
	void (*release)(struct kernfs_open_file___239 *);
	int (*seq_show)(struct seq_file___226 *, void *);
	void * (*seq_start)(struct seq_file___226 *, loff_t *);
	void * (*seq_next)(struct seq_file___226 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___226 *, void *);
	ssize_t (*read)(struct kernfs_open_file___239 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___239 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___239 *, struct poll_table_struct___173 *);
	int (*mmap)(struct kernfs_open_file___239 *, struct vm_area_struct___256 *);
};

struct kernfs_syscall_ops___239 {
	int (*show_options)(struct seq_file___226 *, struct kernfs_root___239 *);
	int (*mkdir)(struct kernfs_node___239 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___239 *);
	int (*rename)(struct kernfs_node___239 *, struct kernfs_node___239 *, const char *);
	int (*show_path)(struct seq_file___226 *, struct kernfs_node___239 *, struct kernfs_root___239 *);
};

struct kernfs_open_file___239 {
	struct kernfs_node___239 *kn;
	struct file___251 *file;
	struct seq_file___226 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___246 *vm_ops;
};

struct kobj_ns_type_operations___48 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___48 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___239;

struct attribute_group___239 {
	const char *name;
	umode_t (*is_visible)(struct kobject___239 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___239 *, struct bin_attribute___239 *, int);
	struct attribute **attrs;
	struct bin_attribute___239 **bin_attrs;
};

struct bin_attribute___239 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___251 * (*f_mapping)();
	ssize_t (*read)(struct file___251 *, struct kobject___239 *, struct bin_attribute___239 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___251 *, struct kobject___239 *, struct bin_attribute___239 *, char *, loff_t, size_t);
	int (*mmap)(struct file___251 *, struct kobject___239 *, struct bin_attribute___239 *, struct vm_area_struct___256 *);
};

struct sysfs_ops___239 {
	ssize_t (*show)(struct kobject___239 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___239 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___239;

struct kset___239 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___239 kobj;
	const struct kset_uevent_ops___239 *uevent_ops;
};

struct kobj_type___239 {
	void (*release)(struct kobject___239 *);
	const struct sysfs_ops___239 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___239 **default_groups;
	const struct kobj_ns_type_operations___48 * (*child_ns_type)(struct kobject___239 *);
	const void * (*namespace)(struct kobject___239 *);
	void (*get_ownership)(struct kobject___239 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___239 {
	int (* const filter)(struct kset___239 *, struct kobject___239 *);
	const char * (* const name)(struct kset___239 *, struct kobject___239 *);
	int (* const uevent)(struct kset___239 *, struct kobject___239 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___235 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___235 *);
	int (*get)(char *, const struct kernel_param___235 *);
	void (*free)(void *);
};

struct kparam_array___235;

struct kernel_param___235 {
	const char *name;
	struct module___235 *mod;
	const struct kernel_param_ops___235 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___235 *arr;
	};
};

struct kparam_array___235 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___235 *ops;
	void *elem;
};

struct module_attribute___235 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___235 *, struct module_kobject___236 *, char *);
	ssize_t (*store)(struct module_attribute___235 *, struct module_kobject___236 *, const char *, size_t);
	void (*setup)(struct module___235 *, const char *);
	int (*test)(struct module___235 *);
	void (*free)(struct module___235 *);
};

struct trace_event_class___78;

struct trace_event_call___78 {
	struct list_head list;
	struct trace_event_class___78 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___55 *prog_array;
	int (*perf_perm)(struct trace_event_call___78 *, struct perf_event___84 *);
};

struct cgroup_namespace___178 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___178 *root_cset;
};

struct socket_wq___49 {
	wait_queue_head_t wait;
	struct fasync_struct___251 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___49;

struct socket___50 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___251 *file;
	struct sock___48 *sk;
	const struct proto_ops___49 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___49 wq;
};

typedef int (*sk_read_actor_t___48)(read_descriptor_t *, struct sk_buff___61 *, unsigned int, size_t);

struct proto_ops___49 {
	int family;
	struct module___235 *owner;
	int (*release)(struct socket___50 *);
	int (*bind)(struct socket___50 *, struct sockaddr *, int);
	int (*connect)(struct socket___50 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___50 *, struct socket___50 *);
	int (*accept)(struct socket___50 *, struct socket___50 *, int, bool);
	int (*getname)(struct socket___50 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___251 *, struct socket___50 *, struct poll_table_struct___173 *);
	int (*ioctl)(struct socket___50 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___50 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___50 *, void *, bool, bool);
	int (*listen)(struct socket___50 *, int);
	int (*shutdown)(struct socket___50 *, int);
	int (*setsockopt)(struct socket___50 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___50 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___226 *, struct socket___50 *);
	int (*sendmsg)(struct socket___50 *, struct msghdr___50 *, size_t);
	int (*recvmsg)(struct socket___50 *, struct msghdr___50 *, size_t, int);
	int (*mmap)(struct file___251 *, struct socket___50 *, struct vm_area_struct___256 *);
	ssize_t (*sendpage)(struct socket___50 *, struct page___256 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___50 *, loff_t *, struct pipe_inode_info___92 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___48 *, int);
	int (*peek_len)(struct socket___50 *);
	int (*read_sock)(struct sock___48 *, read_descriptor_t *, sk_read_actor_t___48);
	int (*sendpage_locked)(struct sock___48 *, struct page___256 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___48 *, struct msghdr___50 *, size_t);
	int (*set_rcvlowat)(struct sock___48 *, int);
};

struct dev_pm_ops___232 {
	int (*prepare)(struct device___232 *);
	void (*complete)(struct device___232 *);
	int (*suspend)(struct device___232 *);
	int (*resume)(struct device___232 *);
	int (*freeze)(struct device___232 *);
	int (*thaw)(struct device___232 *);
	int (*poweroff)(struct device___232 *);
	int (*restore)(struct device___232 *);
	int (*suspend_late)(struct device___232 *);
	int (*resume_early)(struct device___232 *);
	int (*freeze_late)(struct device___232 *);
	int (*thaw_early)(struct device___232 *);
	int (*poweroff_late)(struct device___232 *);
	int (*restore_early)(struct device___232 *);
	int (*suspend_noirq)(struct device___232 *);
	int (*resume_noirq)(struct device___232 *);
	int (*freeze_noirq)(struct device___232 *);
	int (*thaw_noirq)(struct device___232 *);
	int (*poweroff_noirq)(struct device___232 *);
	int (*restore_noirq)(struct device___232 *);
	int (*runtime_suspend)(struct device___232 *);
	int (*runtime_resume)(struct device___232 *);
	int (*runtime_idle)(struct device___232 *);
};

struct wakeup_source___232 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___232 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___232 {
	struct dev_pm_ops___232 ops;
	int (*start)(struct device___232 *);
	void (*detach)(struct device___232 *, bool);
	int (*activate)(struct device___232 *);
	void (*sync)(struct device___232 *);
	void (*dismiss)(struct device___232 *);
};

struct bus_type___232 {
	const char *name;
	const char *dev_name;
	struct device___232 *dev_root;
	const struct attribute_group___239 **bus_groups;
	const struct attribute_group___239 **dev_groups;
	const struct attribute_group___239 **drv_groups;
	int (*match)(struct device___232 *, struct device_driver___232 *);
	int (*uevent)(struct device___232 *, struct kobj_uevent_env *);
	int (*probe)(struct device___232 *);
	void (*sync_state)(struct device___232 *);
	void (*remove)(struct device___232 *);
	void (*shutdown)(struct device___232 *);
	int (*online)(struct device___232 *);
	int (*offline)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	int (*num_vf)(struct device___232 *);
	int (*dma_configure)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___232 {
	const char *name;
	struct bus_type___232 *bus;
	struct module___235 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___232 *);
	void (*sync_state)(struct device___232 *);
	int (*remove)(struct device___232 *);
	void (*shutdown)(struct device___232 *);
	int (*suspend)(struct device___232 *, pm_message_t);
	int (*resume)(struct device___232 *);
	const struct attribute_group___239 **groups;
	const struct attribute_group___239 **dev_groups;
	const struct dev_pm_ops___232 *pm;
	void (*coredump)(struct device___232 *);
	struct driver_private *p;
};

struct device_type___232 {
	const char *name;
	const struct attribute_group___239 **groups;
	int (*uevent)(struct device___232 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___232 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___232 *);
	const struct dev_pm_ops___232 *pm;
};

struct class___232 {
	const char *name;
	struct module___235 *owner;
	const struct attribute_group___239 **class_groups;
	const struct attribute_group___239 **dev_groups;
	struct kobject___239 *dev_kobj;
	int (*dev_uevent)(struct device___232 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___232 *, umode_t *);
	void (*class_release)(struct class___232 *);
	void (*dev_release)(struct device___232 *);
	int (*shutdown_pre)(struct device___232 *);
	const struct kobj_ns_type_operations___48 *ns_type;
	const void * (*namespace)(struct device___232 *);
	void (*get_ownership)(struct device___232 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___232 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___92;

struct pipe_buffer___92 {
	struct page___256 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___92 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___92 {
	int (*confirm)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
	void (*release)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
	bool (*try_steal)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
	bool (*get)(struct pipe_inode_info___92 *, struct pipe_buffer___92 *);
};

typedef struct bio_vec___168 skb_frag_t___15;

struct ubuf_info___6 {
	void (*callback)(struct sk_buff___61 *, struct ubuf_info___6 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___15 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___61 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___15 frags[17];
};

struct seq_operations___226 {
	void * (*start)(struct seq_file___226 *, loff_t *);
	void (*stop)(struct seq_file___226 *, void *);
	void * (*next)(struct seq_file___226 *, void *, loff_t *);
	int (*show)(struct seq_file___226 *, void *);
};

struct dcbnl_rtnl_ops___60 {
	int (*ieee_getets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___60 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___60 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___60 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___60 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___60 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___60 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___60 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___60 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___60 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___60 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___60 *);
	u8 (*setstate)(struct net_device___60 *, u8);
	void (*getpermhwaddr)(struct net_device___60 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___60 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___60 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___60 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___60 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___60 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___60 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___60 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___60 *, int, u8 *);
	void (*setpfccfg)(struct net_device___60 *, int, u8);
	void (*getpfccfg)(struct net_device___60 *, int, u8 *);
	u8 (*setall)(struct net_device___60 *);
	u8 (*getcap)(struct net_device___60 *, int, u8 *);
	int (*getnumtcs)(struct net_device___60 *, int, u8 *);
	int (*setnumtcs)(struct net_device___60 *, int, u8);
	u8 (*getpfcstate)(struct net_device___60 *);
	void (*setpfcstate)(struct net_device___60 *, u8);
	void (*getbcncfg)(struct net_device___60 *, int, u32 *);
	void (*setbcncfg)(struct net_device___60 *, int, u32);
	void (*getbcnrp)(struct net_device___60 *, int, u8 *);
	void (*setbcnrp)(struct net_device___60 *, int, u8);
	int (*setapp)(struct net_device___60 *, u8, u16, u8);
	int (*getapp)(struct net_device___60 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___60 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___60 *, int, u8);
	u8 (*getdcbx)(struct net_device___60 *);
	u8 (*setdcbx)(struct net_device___60 *, u8);
	int (*peer_getappinfo)(struct net_device___60 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___60 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___60 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___60 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___60 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___60 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___63;

typedef int (*bpf_iter_init_seq_priv_t___62)(void *, struct bpf_iter_aux_info___63 *);

struct bpf_map___63;

struct bpf_iter_aux_info___63 {
	struct bpf_map___63 *map;
};

struct bpf_iter_seq_info___62 {
	const struct seq_operations___226 *seq_ops;
	bpf_iter_init_seq_priv_t___62 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___62 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___63 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___63 *, struct file___251 *);
	void (*map_free)(struct bpf_map___63 *);
	int (*map_get_next_key)(struct bpf_map___63 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___63 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___63 *, void *);
	int (*map_lookup_batch)(struct bpf_map___63 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___63 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___63 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___63 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___63 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___63 *, void *);
	int (*map_update_elem)(struct bpf_map___63 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___63 *, void *);
	int (*map_push_elem)(struct bpf_map___63 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___63 *, void *);
	int (*map_peek_elem)(struct bpf_map___63 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___63 *, struct file___251 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___63 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___63 *, void *, struct seq_file___226 *);
	int (*map_check_btf)(const struct bpf_map___63 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___63 *, struct bpf_prog_aux___63 *);
	void (*map_poke_untrack)(struct bpf_map___63 *, struct bpf_prog_aux___63 *);
	void (*map_poke_run)(struct bpf_map___63 *, u32, struct bpf_prog___55 *, struct bpf_prog___55 *);
	int (*map_direct_value_addr)(const struct bpf_map___63 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___63 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___63 *, struct vm_area_struct___256 *);
	__poll_t (*map_poll)(struct bpf_map___63 *, struct file___251 *, struct poll_table_struct___173 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___63 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___63 *, const struct bpf_map___63 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___63 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___62 *iter_seq_info;
};

struct bpf_map___63 {
	const struct bpf_map_ops___62 *ops;
	struct bpf_map___63 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___117 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___62;

struct bpf_jit_poke_descriptor___62;

struct bpf_prog_ops___55;

struct btf_mod_pair___62;

struct bpf_prog_offload___60;

struct bpf_prog_aux___63 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___55 *dst_prog;
	struct bpf_trampoline___62 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___55 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___62 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___55 *ops;
	struct bpf_map___63 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___62 *used_btfs;
	struct bpf_prog___55 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___63 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___60 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___60;

struct bpf_map_dev_ops___60 {
	int (*map_get_next_key)(struct bpf_offloaded_map___60 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___60 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___60 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___60 *, void *);
};

struct bpf_offloaded_map___60 {
	struct bpf_map___63 map;
	struct net_device___60 *netdev;
	const struct bpf_map_dev_ops___60 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___55 {
	int (*test_run)(struct bpf_prog___55 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___60 {
	struct bpf_prog___55 *prog;
	struct net_device___60 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___62 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___55 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___235 *mod;
};

struct bpf_jit_poke_descriptor___62 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___63 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___62 {
	struct btf *btf;
	struct module___235 *module;
};

struct cftype___178;

struct cgroup_subsys___178 {
	struct cgroup_subsys_state___178 * (*css_alloc)(struct cgroup_subsys_state___178 *);
	int (*css_online)(struct cgroup_subsys_state___178 *);
	void (*css_offline)(struct cgroup_subsys_state___178 *);
	void (*css_released)(struct cgroup_subsys_state___178 *);
	void (*css_free)(struct cgroup_subsys_state___178 *);
	void (*css_reset)(struct cgroup_subsys_state___178 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___178 *, int);
	int (*css_extra_stat_show)(struct seq_file___226 *, struct cgroup_subsys_state___178 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___258 *, struct css_set___178 *);
	void (*cancel_fork)(struct task_struct___258 *, struct css_set___178 *);
	void (*fork)(struct task_struct___258 *);
	void (*exit)(struct task_struct___258 *);
	void (*release)(struct task_struct___258 *);
	void (*bind)(struct cgroup_subsys_state___178 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___178 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___178 *dfl_cftypes;
	struct cftype___178 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___178 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___178 *updated_children;
	struct cgroup___178 *updated_next;
};

struct cgroup_root___178 {
	struct kernfs_root___239 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___178 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___178 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___178 *ss;
	struct list_head node;
	struct kernfs_ops___239 *kf_ops;
	int (*open)(struct kernfs_open_file___239 *);
	void (*release)(struct kernfs_open_file___239 *);
	u64 (*read_u64)(struct cgroup_subsys_state___178 *, struct cftype___178 *);
	s64 (*read_s64)(struct cgroup_subsys_state___178 *, struct cftype___178 *);
	int (*seq_show)(struct seq_file___226 *, void *);
	void * (*seq_start)(struct seq_file___226 *, loff_t *);
	void * (*seq_next)(struct seq_file___226 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___226 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___178 *, struct cftype___178 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___178 *, struct cftype___178 *, s64);
	ssize_t (*write)(struct kernfs_open_file___239 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___239 *, struct poll_table_struct___173 *);
};

struct xdp_rxq_info___60 {
	struct net_device___60 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___60 {
	struct net_device___60 *dev;
};

struct xdp_buff___60 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___60 *rxq;
	struct xdp_txq_info___60 *txq;
	u32 frame_sz;
};

struct xdp_frame___60 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___60 *dev_rx;
};

struct netlink_callback___60 {
	struct sk_buff___61 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___61 *, struct netlink_callback___60 *);
	int (*done)(struct netlink_callback___60 *);
	void *data;
	struct module___235 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___60 {
	int (*create)(struct sk_buff___61 *, struct net_device___60 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___61 *, unsigned char *);
	int (*cache)(const struct neighbour___48 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___60 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___61 *);
};

struct napi_struct___13 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___13 *, int);
	int poll_owner;
	struct net_device___60 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___61 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___258 *thread;
};

struct netdev_queue___60 {
	struct net_device___60 *dev;
	struct Qdisc___55 *qdisc;
	struct Qdisc___55 *qdisc_sleeping;
	struct kobject___239 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___60 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___55 {
	struct sk_buff___61 *head;
	struct sk_buff___61 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___55;

struct Qdisc___55 {
	int (*enqueue)(struct sk_buff___61 *, struct Qdisc___55 *, struct sk_buff___61 **);
	struct sk_buff___61 * (*dequeue)(struct Qdisc___55 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___55 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___60 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___60 gso_skb;
	struct qdisc_skb_head___55 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___55 *next_sched;
	struct sk_buff_head___60 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___60 {
	struct xdp_rxq_info___60 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___239 kobj;
	struct net_device___60 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___60 {
	enum net_device_path_type type;
	const struct net_device___60 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___60 = 0,
				DEV_PATH_BR_VLAN_TAG___60 = 1,
				DEV_PATH_BR_VLAN_UNTAG___60 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___60 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___60 {
	const struct net_device___60 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___60 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___55 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___60 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___60 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___61 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___60 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___60 *dev;
	const char *name;
};

struct net_device_ops___60 {
	int (*ndo_init)(struct net_device___60 *);
	void (*ndo_uninit)(struct net_device___60 *);
	int (*ndo_open)(struct net_device___60 *);
	int (*ndo_stop)(struct net_device___60 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___61 *, struct net_device___60 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___61 *, struct net_device___60 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___60 *, struct sk_buff___61 *, struct net_device___60 *);
	void (*ndo_change_rx_flags)(struct net_device___60 *, int);
	void (*ndo_set_rx_mode)(struct net_device___60 *);
	int (*ndo_set_mac_address)(struct net_device___60 *, void *);
	int (*ndo_validate_addr)(struct net_device___60 *);
	int (*ndo_do_ioctl)(struct net_device___60 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___60 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___60 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___60 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___60 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___60 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___60 *, int);
	int (*ndo_neigh_setup)(struct net_device___60 *, struct neigh_parms___48 *);
	void (*ndo_tx_timeout)(struct net_device___60 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___60 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___60 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___60 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___60 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___60 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___60 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___60 *);
	int (*ndo_netpoll_setup)(struct net_device___60 *, struct netpoll_info___3 *);
	void (*ndo_netpoll_cleanup)(struct net_device___60 *);
	int (*ndo_set_vf_mac)(struct net_device___60 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___60 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___60 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___60 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___60 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___60 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___60 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___60 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___60 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___60 *, int, struct sk_buff___61 *);
	int (*ndo_get_vf_guid)(struct net_device___60 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___60 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___60 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___60 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___60 *);
	int (*ndo_fcoe_disable)(struct net_device___60 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___60 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___60 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___60 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___60 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___60 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___60 *, const struct sk_buff___61 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___60 *, struct net_device___60 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___60 *, struct net_device___60 *);
	struct net_device___60 * (*ndo_get_xmit_slave)(struct net_device___60 *, struct sk_buff___61 *, bool);
	struct net_device___60 * (*ndo_sk_get_lower_dev)(struct net_device___60 *, struct sock___48 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___60 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___60 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___60 *, struct neighbour___48 *);
	void (*ndo_neigh_destroy)(struct net_device___60 *, struct neighbour___48 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___61 *, struct netlink_callback___60 *, struct net_device___60 *, struct net_device___60 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___61 *, struct nlattr **, struct net_device___60 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___60 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___61 *, u32, u32, struct net_device___60 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___60 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___60 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___60 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___60 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___60 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___60 *, struct net_device___60 *);
	void (*ndo_dfwd_del_station)(struct net_device___60 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___60 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___60 *);
	int (*ndo_change_proto_down)(struct net_device___60 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___60 *, struct sk_buff___61 *);
	void (*ndo_set_rx_headroom)(struct net_device___60 *, int);
	int (*ndo_bpf)(struct net_device___60 *, struct netdev_bpf___60 *);
	int (*ndo_xdp_xmit)(struct net_device___60 *, int, struct xdp_frame___60 **, u32);
	struct net_device___60 * (*ndo_xdp_get_xmit_slave)(struct net_device___60 *, struct xdp_buff___60 *);
	int (*ndo_xsk_wakeup)(struct net_device___60 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___60 *);
	int (*ndo_tunnel_ctl)(struct net_device___60 *, struct ip_tunnel_parm *, int);
	struct net_device___60 * (*ndo_get_peer_dev)(struct net_device___60 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___60 *, struct net_device_path___60 *);
};

struct neigh_parms___48 {
	possible_net_t___60 net;
	struct net_device___60 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___48 *);
	struct neigh_table___48 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll___3;

struct netpoll_info___3 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___60 txq;
	struct delayed_work tx_work;
	struct netpoll___3 *netpoll;
	struct callback_head rcu;
};

struct l3mdev_ops___48 {
	u32 (*l3mdev_fib_table)(const struct net_device___60 *);
	struct sk_buff___61 * (*l3mdev_l3_rcv)(struct net_device___60 *, struct sk_buff___61 *, u16);
	struct sk_buff___61 * (*l3mdev_l3_out)(struct net_device___60 *, struct sock___48 *, struct sk_buff___61 *, u16);
	struct dst_entry___48 * (*l3mdev_link_scope_lookup)(const struct net_device___60 *, struct flowi6 *);
};

struct ndisc_ops___34 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___60 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___60 *, struct neighbour___48 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___60 *, u8, struct neighbour___48 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___60 *, struct sk_buff___61 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___65 *, struct net_device___60 *, const struct prefix_info *, struct inet6_dev___34 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___5;

struct in_device___5 {
	struct net_device___60 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___5 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___48 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___34;

struct ifacaddr6___9;

struct inet6_dev___34 {
	struct net_device___60 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___34 *mc_list;
	struct ifmcaddr6___34 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___60 mc_query_queue;
	struct sk_buff_head___60 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___48 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___55;

struct tcf_block___55;

struct mini_Qdisc___55 {
	struct tcf_proto___55 *filter_list;
	struct tcf_block___55 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___55 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___60 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___60 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___65 *, struct net_device___60 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___60 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___60 *, struct list_head *);
	size_t (*get_size)(const struct net_device___60 *);
	int (*fill_info)(struct sk_buff___61 *, const struct net_device___60 *);
	size_t (*get_xstats_size)(const struct net_device___60 *);
	int (*fill_xstats)(struct sk_buff___61 *, const struct net_device___60 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___60 *, struct net_device___60 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___60 *, const struct net_device___60 *);
	int (*fill_slave_info)(struct sk_buff___61 *, const struct net_device___60 *, const struct net_device___60 *);
	struct net___65 * (*get_link_net)(const struct net_device___60 *);
	size_t (*get_linkxstats_size)(const struct net_device___60 *, int);
	int (*fill_linkxstats)(struct sk_buff___61 *, const struct net_device___60 *, int *, int);
};

struct in_ifaddr___5 {
	struct hlist_node hash;
	struct in_ifaddr___5 *ifa_next;
	struct in_device___5 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___3 {
	struct net_device___60 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
};

struct perf_cpu_context___84;

struct perf_output_handle___84;

struct pmu___84 {
	struct list_head entry;
	struct module___235 *module;
	struct device___232 *dev;
	const struct attribute_group___239 **attr_groups;
	const struct attribute_group___239 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___84 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___84 *);
	void (*pmu_disable)(struct pmu___84 *);
	int (*event_init)(struct perf_event___84 *);
	void (*event_mapped)(struct perf_event___84 *, struct mm_struct___257 *);
	void (*event_unmapped)(struct perf_event___84 *, struct mm_struct___257 *);
	int (*add)(struct perf_event___84 *, int);
	void (*del)(struct perf_event___84 *, int);
	void (*start)(struct perf_event___84 *, int);
	void (*stop)(struct perf_event___84 *, int);
	void (*read)(struct perf_event___84 *);
	void (*start_txn)(struct pmu___84 *, unsigned int);
	int (*commit_txn)(struct pmu___84 *);
	void (*cancel_txn)(struct pmu___84 *);
	int (*event_idx)(struct perf_event___84 *);
	void (*sched_task)(struct perf_event_context___84 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___84 *, struct perf_event_context___84 *);
	void * (*setup_aux)(struct perf_event___84 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___84 *, struct perf_output_handle___84 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___84 *);
	int (*aux_output_match)(struct perf_event___84 *);
	int (*filter_match)(struct perf_event___84 *);
	int (*check_period)(struct perf_event___84 *, u64);
};

struct perf_cpu_context___84 {
	struct perf_event_context___84 ctx;
	struct perf_event_context___84 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___84 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___84 **heap;
	struct perf_event___84 *heap_default[2];
};

struct perf_output_handle___84 {
	struct perf_event___84 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___84 {
	struct cgroup_subsys_state___178 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___78 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___78 *);
	};
};

struct trace_event_class___78 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___78 *, enum trace_reg, void *);
	struct trace_event_fields___78 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___78 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___78 *);
};

struct trace_event_file___39;

struct trace_event_buffer___38 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___39 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___39 {
	struct list_head list;
	struct trace_event_call___78 *event_call;
	struct event_filter *filter;
	struct dentry___251 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_kfree_skb {
	struct trace_entry ent;
	void *skbaddr;
	void *location;
	short unsigned int protocol;
	char __data[0];
};

struct trace_event_raw_consume_skb {
	struct trace_entry ent;
	void *skbaddr;
	char __data[0];
};

struct trace_event_raw_skb_copy_datagram_iovec {
	struct trace_entry ent;
	const void *skbaddr;
	int len;
	char __data[0];
};

struct trace_event_data_offsets_kfree_skb {};

struct trace_event_data_offsets_consume_skb {};

struct trace_event_data_offsets_skb_copy_datagram_iovec {};

typedef void (*btf_trace_kfree_skb)(void *, struct sk_buff___61 *, void *);

typedef void (*btf_trace_consume_skb)(void *, struct sk_buff___61 *);

typedef void (*btf_trace_skb_copy_datagram_iovec)(void *, const struct sk_buff___61 *, int);

struct trace_event_raw_net_dev_start_xmit {
	struct trace_entry ent;
	u32 __data_loc_name;
	u16 queue_mapping;
	const void *skbaddr;
	bool vlan_tagged;
	u16 vlan_proto;
	u16 vlan_tci;
	u16 protocol;
	u8 ip_summed;
	unsigned int len;
	unsigned int data_len;
	int network_offset;
	bool transport_offset_valid;
	int transport_offset;
	u8 tx_flags;
	u16 gso_size;
	u16 gso_segs;
	u16 gso_type;
	char __data[0];
};

struct trace_event_raw_net_dev_xmit {
	struct trace_entry ent;
	void *skbaddr;
	unsigned int len;
	int rc;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_net_dev_xmit_timeout {
	struct trace_entry ent;
	u32 __data_loc_name;
	u32 __data_loc_driver;
	int queue_index;
	char __data[0];
};

struct trace_event_raw_net_dev_template {
	struct trace_entry ent;
	void *skbaddr;
	unsigned int len;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_raw_net_dev_rx_verbose_template {
	struct trace_entry ent;
	u32 __data_loc_name;
	unsigned int napi_id;
	u16 queue_mapping;
	const void *skbaddr;
	bool vlan_tagged;
	u16 vlan_proto;
	u16 vlan_tci;
	u16 protocol;
	u8 ip_summed;
	u32 hash;
	bool l4_hash;
	unsigned int len;
	unsigned int data_len;
	unsigned int truesize;
	bool mac_header_valid;
	int mac_header;
	unsigned char nr_frags;
	u16 gso_size;
	u16 gso_type;
	char __data[0];
};

struct trace_event_raw_net_dev_rx_exit_template {
	struct trace_entry ent;
	int ret;
	char __data[0];
};

struct trace_event_data_offsets_net_dev_start_xmit {
	u32 name;
};

struct trace_event_data_offsets_net_dev_xmit {
	u32 name;
};

struct trace_event_data_offsets_net_dev_xmit_timeout {
	u32 name;
	u32 driver;
};

struct trace_event_data_offsets_net_dev_template {
	u32 name;
};

struct trace_event_data_offsets_net_dev_rx_verbose_template {
	u32 name;
};

struct trace_event_data_offsets_net_dev_rx_exit_template {};

typedef void (*btf_trace_net_dev_start_xmit)(void *, const struct sk_buff___61 *, const struct net_device___60 *);

typedef void (*btf_trace_net_dev_xmit)(void *, struct sk_buff___61 *, int, struct net_device___60 *, unsigned int);

typedef void (*btf_trace_net_dev_xmit_timeout)(void *, struct net_device___60 *, int);

typedef void (*btf_trace_net_dev_queue)(void *, struct sk_buff___61 *);

typedef void (*btf_trace_netif_receive_skb)(void *, struct sk_buff___61 *);

typedef void (*btf_trace_netif_rx)(void *, struct sk_buff___61 *);

typedef void (*btf_trace_napi_gro_frags_entry)(void *, const struct sk_buff___61 *);

typedef void (*btf_trace_napi_gro_receive_entry)(void *, const struct sk_buff___61 *);

typedef void (*btf_trace_netif_receive_skb_entry)(void *, const struct sk_buff___61 *);

typedef void (*btf_trace_netif_receive_skb_list_entry)(void *, const struct sk_buff___61 *);

typedef void (*btf_trace_netif_rx_entry)(void *, const struct sk_buff___61 *);

typedef void (*btf_trace_netif_rx_ni_entry)(void *, const struct sk_buff___61 *);

typedef void (*btf_trace_napi_gro_frags_exit)(void *, int);

typedef void (*btf_trace_napi_gro_receive_exit)(void *, int);

typedef void (*btf_trace_netif_receive_skb_exit)(void *, int);

typedef void (*btf_trace_netif_rx_exit)(void *, int);

typedef void (*btf_trace_netif_rx_ni_exit)(void *, int);

typedef void (*btf_trace_netif_receive_skb_list_exit)(void *, int);

struct trace_event_raw_napi_poll {
	struct trace_entry ent;
	struct napi_struct___13 *napi;
	u32 __data_loc_dev_name;
	int work;
	int budget;
	char __data[0];
};

struct trace_event_data_offsets_napi_poll {
	u32 dev_name;
};

typedef void (*btf_trace_napi_poll)(void *, struct napi_struct___13 *, int, int);

struct block_device_operations___143;

struct gendisk___146 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___146 *part0;
	const struct block_device_operations___143 *fops;
	struct request_queue___143 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___129 *bdi;
	struct kobject___239 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___239 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___143 {
	struct bio___143 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___168 *bip_vec;
	struct bio_vec___168 bip_inline_vecs[0];
};

struct blkcg___131;

struct blkg_policy_data___131;

struct blkcg_gq___131 {
	struct request_queue___143 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___131 *blkcg;
	struct blkcg_gq___131 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___131 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___143 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___143(struct request___143 *);

typedef void integrity_complete_fn___143(struct request___143 *, unsigned int);

struct blk_integrity_profile___143 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___143 *prepare_fn;
	integrity_complete_fn___143 *complete_fn;
	const char *name;
};

struct block_device_operations___143 {
	blk_qc_t (*submit_bio)(struct bio___143 *);
	int (*open)(struct block_device___146 *, fmode_t);
	void (*release)(struct gendisk___146 *, fmode_t);
	int (*rw_page)(struct block_device___146 *, sector_t, struct page___256 *, unsigned int);
	int (*ioctl)(struct block_device___146 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___146 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___146 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___146 *);
	int (*getgeo)(struct block_device___146 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___146 *, bool);
	void (*swap_slot_free_notify)(struct block_device___146 *, long unsigned int);
	int (*report_zones)(struct gendisk___146 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___146 *, umode_t *);
	struct module___235 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___146 *, sector_t *);
};

typedef void rq_end_io_fn___143(struct request___143 *, blk_status_t);

struct request___143 {
	struct request_queue___143 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___138 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___143 *bio;
	struct bio___143 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___168 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___143 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___143 *saved_end_io;
		} flush;
	};
	struct gendisk___146 *rq_disk;
	struct block_device___146 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___143 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___138 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___143 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___239 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___251 *debugfs_dir;
	struct dentry___251 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___143;

struct elevator_mq_ops___143 {
	int (*init_sched)(struct request_queue___143 *, struct elevator_type___143 *);
	void (*exit_sched)(struct elevator_queue___143 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___138 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___138 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___138 *);
	bool (*allow_merge)(struct request_queue___143 *, struct request___143 *, struct bio___143 *);
	bool (*bio_merge)(struct request_queue___143 *, struct bio___143 *, unsigned int);
	int (*request_merge)(struct request_queue___143 *, struct request___143 **, struct bio___143 *);
	void (*request_merged)(struct request_queue___143 *, struct request___143 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___143 *, struct request___143 *, struct request___143 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___143 *);
	void (*finish_request)(struct request___143 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___138 *, struct list_head *, bool);
	struct request___143 * (*dispatch_request)(struct blk_mq_hw_ctx___138 *);
	bool (*has_work)(struct blk_mq_hw_ctx___138 *);
	void (*completed_request)(struct request___143 *, u64);
	void (*requeue_request)(struct request___143 *);
	struct request___143 * (*former_request)(struct request_queue___143 *, struct request___143 *);
	struct request___143 * (*next_request)(struct request_queue___143 *, struct request___143 *);
	void (*init_icq)(struct io_cq___143 *);
	void (*exit_icq)(struct io_cq___143 *);
};

struct elv_fs_entry___143;

struct elevator_type___143 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___143 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___143 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___235 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___143 {
	struct elevator_type___143 *type;
	void *elevator_data;
	struct kobject___239 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___143 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___143 *, char *);
	ssize_t (*store)(struct elevator_queue___143 *, const char *, size_t);
};

struct blk_mq_queue_data___138;

struct blk_mq_ops___138 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___138 *, const struct blk_mq_queue_data___138 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___138 *);
	int (*get_budget)(struct request_queue___143 *);
	void (*put_budget)(struct request_queue___143 *, int);
	void (*set_rq_budget_token)(struct request___143 *, int);
	int (*get_rq_budget_token)(struct request___143 *);
	enum blk_eh_timer_return (*timeout)(struct request___143 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___138 *);
	void (*complete)(struct request___143 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___138 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___138 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___138 *, struct request___143 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___138 *, struct request___143 *, unsigned int);
	void (*initialize_rq_fn)(struct request___143 *);
	void (*cleanup_rq)(struct request___143 *);
	bool (*busy)(struct request_queue___143 *);
	int (*map_queues)(struct blk_mq_tag_set___138 *);
	void (*show_rq)(struct seq_file___226 *, struct request___143 *);
};

struct blk_mq_tag_set___138 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___138 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___138 {
	struct request___143 *rq;
	bool last;
};

struct blkcg_policy_data___131;

struct blkcg___131 {
	struct cgroup_subsys_state___178 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___131 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___131 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___131 {
	struct blkcg___131 *blkcg;
	int plid;
};

struct blkg_policy_data___131 {
	struct blkcg_gq___131 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___117 {
	struct mem_cgroup___117 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___117 {
	struct lruvec___125 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___117 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___117 *memcg;
};

struct obj_cgroup___117 {
	struct percpu_ref refcnt;
	struct mem_cgroup___117 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___55 {
	spinlock_t *lock;
	struct sk_buff___61 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___55;

struct Qdisc_ops___55 {
	struct Qdisc_ops___55 *next;
	const struct Qdisc_class_ops___55 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___61 *, struct Qdisc___55 *, struct sk_buff___61 **);
	struct sk_buff___61 * (*dequeue)(struct Qdisc___55 *);
	struct sk_buff___61 * (*peek)(struct Qdisc___55 *);
	int (*init)(struct Qdisc___55 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___55 *);
	void (*destroy)(struct Qdisc___55 *);
	int (*change)(struct Qdisc___55 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___55 *);
	int (*change_tx_queue_len)(struct Qdisc___55 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___55 *, unsigned int);
	int (*dump)(struct Qdisc___55 *, struct sk_buff___61 *);
	int (*dump_stats)(struct Qdisc___55 *, struct gnet_dump___55 *);
	void (*ingress_block_set)(struct Qdisc___55 *, u32);
	void (*egress_block_set)(struct Qdisc___55 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___55 *);
	u32 (*egress_block_get)(struct Qdisc___55 *);
	struct module___235 *owner;
};

struct Qdisc_class_ops___55 {
	unsigned int flags;
	struct netdev_queue___60 * (*select_queue)(struct Qdisc___55 *, struct tcmsg *);
	int (*graft)(struct Qdisc___55 *, long unsigned int, struct Qdisc___55 *, struct Qdisc___55 **, struct netlink_ext_ack *);
	struct Qdisc___55 * (*leaf)(struct Qdisc___55 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___55 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___55 *, u32);
	int (*change)(struct Qdisc___55 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___55 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___55 *, struct qdisc_walker *);
	struct tcf_block___55 * (*tcf_block)(struct Qdisc___55 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___55 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___55 *, long unsigned int);
	int (*dump)(struct Qdisc___55 *, long unsigned int, struct sk_buff___61 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___55 *, long unsigned int, struct gnet_dump___55 *);
};

struct tcf_chain___55;

struct tcf_block___55 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___65 *net;
	struct Qdisc___55 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___55 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___55;

struct tcf_proto_ops___55;

struct tcf_proto___55 {
	struct tcf_proto___55 *next;
	void *root;
	int (*classify)(struct sk_buff___61 *, const struct tcf_proto___55 *, struct tcf_result___55 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___55 *ops;
	struct tcf_chain___55 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___55 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___55 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___55 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___61 *, const struct tcf_proto___55 *, struct tcf_result___55 *);
	int (*init)(struct tcf_proto___55 *);
	void (*destroy)(struct tcf_proto___55 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___55 *, u32);
	void (*put)(struct tcf_proto___55 *, void *);
	int (*change)(struct net___65 *, struct sk_buff___61 *, struct tcf_proto___55 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___55 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___55 *);
	void (*walk)(struct tcf_proto___55 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___55 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___55 *, void *);
	void (*hw_del)(struct tcf_proto___55 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___65 *, struct tcf_chain___55 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___65 *, struct tcf_proto___55 *, void *, struct sk_buff___61 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___65 *, struct tcf_proto___55 *, void *, struct sk_buff___61 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___61 *, struct net___65 *, void *);
	struct module___235 *owner;
	int flags;
};

struct tcf_chain___55 {
	struct mutex filter_chain_lock;
	struct tcf_proto___55 *filter_chain;
	struct list_head list;
	struct tcf_block___55 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___55 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___48 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___55 *prog;
};

struct pneigh_entry___48;

struct neigh_hash_table___48;

struct neigh_table___48 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___60 *, __u32 *);
	bool (*key_eq)(const struct neighbour___48 *, const void *);
	int (*constructor)(struct neighbour___48 *);
	int (*pconstructor)(struct pneigh_entry___48 *);
	void (*pdestructor)(struct pneigh_entry___48 *);
	void (*proxy_redo)(struct sk_buff___61 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___60 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___48 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___60 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___48 *nht;
	struct pneigh_entry___48 **phash_buckets;
};

struct neigh_ops___48 {
	int family;
	void (*solicit)(struct neighbour___48 *, struct sk_buff___61 *);
	void (*error_report)(struct neighbour___48 *, struct sk_buff___61 *);
	int (*output)(struct neighbour___48 *, struct sk_buff___61 *);
	int (*connected_output)(struct neighbour___48 *, struct sk_buff___61 *);
};

struct pneigh_entry___48 {
	struct pneigh_entry___48 *next;
	possible_net_t___60 net;
	struct net_device___60 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___48 {
	struct neighbour___48 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___28 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___65 *, struct sock___48 *, struct sk_buff___61 *);
	int (*orig_input)(struct sk_buff___61 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___48 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___48 *ctarget;
	struct net___65 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___48 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___48 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___36;

struct timewait_sock_ops___36;

struct proto___48 {
	void (*close)(struct sock___48 *, long int);
	int (*pre_connect)(struct sock___48 *, struct sockaddr *, int);
	int (*connect)(struct sock___48 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___48 *, int);
	struct sock___48 * (*accept)(struct sock___48 *, int, int *, bool);
	int (*ioctl)(struct sock___48 *, int, long unsigned int);
	int (*init)(struct sock___48 *);
	void (*destroy)(struct sock___48 *);
	void (*shutdown)(struct sock___48 *, int);
	int (*setsockopt)(struct sock___48 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___48 *, int, int, char *, int *);
	void (*keepalive)(struct sock___48 *, int);
	int (*compat_ioctl)(struct sock___48 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___48 *, struct msghdr___50 *, size_t);
	int (*recvmsg)(struct sock___48 *, struct msghdr___50 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___48 *, struct page___256 *, int, size_t, int);
	int (*bind)(struct sock___48 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___48 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___48 *, struct sk_buff___61 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___48 *);
	int (*hash)(struct sock___48 *);
	void (*unhash)(struct sock___48 *);
	void (*rehash)(struct sock___48 *);
	int (*get_port)(struct sock___48 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___48 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___48 *, int);
	bool (*sock_is_readable)(struct sock___48 *);
	void (*enter_memory_pressure)(struct sock___48 *);
	void (*leave_memory_pressure)(struct sock___48 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___36 *rsk_prot;
	struct timewait_sock_ops___36 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___235 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___48 *, int);
};

struct sock_reuseport___12 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___55 *prog;
	struct sock___48 *socks[0];
};

struct request_sock___37;

struct request_sock_ops___36 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___48 *, struct request_sock___37 *);
	void (*send_ack)(const struct sock___48 *, struct sk_buff___61 *, struct request_sock___37 *);
	void (*send_reset)(const struct sock___48 *, struct sk_buff___61 *);
	void (*destructor)(struct request_sock___37 *);
	void (*syn_ack_timeout)(const struct request_sock___37 *);
};

struct timewait_sock_ops___36 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___48 *, struct sock___48 *, void *);
	void (*twsk_destructor)(struct sock___48 *);
};

struct request_sock___37 {
	struct sock_common___48 __req_common;
	struct request_sock___37 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___36 *rsk_ops;
	struct sock___48 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___3 {
	struct request_sock___37 *rskq_rst_head;
	struct request_sock___37 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___3 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___37 *rskq_accept_head;
	struct request_sock___37 *rskq_accept_tail;
	struct fastopen_queue___3 fastopenq;
};

struct inet_request_sock___2 {
	struct request_sock___37 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___61 *pktopts;
		};
	};
};

struct inet_cork___4 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___48 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___4 {
	struct inet_cork___4 base;
	struct flowi fl;
};

struct ipv6_pinfo___4;

struct inet_sock___4 {
	struct sock___48 sk;
	struct ipv6_pinfo___4 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___4 cork;
};

struct ipv6_fl_socklist___4;

struct ipv6_pinfo___4 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___4 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___61 *pktoptions;
	struct sk_buff___61 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___3 {
	int (*queue_xmit)(struct sock___48 *, struct sk_buff___61 *, struct flowi *);
	void (*send_check)(struct sock___48 *, struct sk_buff___61 *);
	int (*rebuild_header)(struct sock___48 *);
	void (*sk_rx_dst_set)(struct sock___48 *, const struct sk_buff___61 *);
	int (*conn_request)(struct sock___48 *, struct sk_buff___61 *);
	struct sock___48 * (*syn_recv_sock)(const struct sock___48 *, struct sk_buff___61 *, struct request_sock___37 *, struct dst_entry___48 *, struct request_sock___37 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___48 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___48 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___48 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___48 *);
};

struct inet_bind_bucket___3;

struct tcp_ulp_ops___3;

struct inet_connection_sock___3 {
	struct inet_sock___4 icsk_inet;
	struct request_sock_queue___3 icsk_accept_queue;
	struct inet_bind_bucket___3 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___11 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___3 *icsk_af_ops;
	const struct tcp_ulp_ops___3 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___48 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___48 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___3 {
	possible_net_t___60 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___3 {
	struct list_head list;
	int (*init)(struct sock___48 *);
	void (*update)(struct sock___48 *, struct proto___48 *, void (*)(struct sock___48 *));
	void (*release)(struct sock___48 *);
	int (*get_info)(const struct sock___48 *, struct sk_buff___61 *);
	size_t (*get_info_size)(const struct sock___48 *);
	void (*clone)(const struct request_sock___37 *, struct sock___48 *, const gfp_t);
	char name[16];
	struct module___235 *owner;
};

enum tcp_ca_state {
	TCP_CA_Open = 0,
	TCP_CA_Disorder = 1,
	TCP_CA_CWR = 2,
	TCP_CA_Recovery = 3,
	TCP_CA_Loss = 4,
};

struct tcp_sock_af_ops___4;

struct tcp_fastopen_request___4;

struct tcp_sock___4 {
	struct inet_connection_sock___3 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___61 *lost_skb_hint;
	struct sk_buff___61 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___61 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___61 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___4 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___4 *fastopen_req;
	struct request_sock___37 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___4 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___48 *, const struct sock___48 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___48 *, const struct sk_buff___61 *);
	int (*md5_parse)(struct sock___48 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___4 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___50 *data;
	size_t size;
	int copied;
	struct ubuf_info___6 *uarg;
};

struct ip6_flowlabel___4;

struct ipv6_fl_socklist___4 {
	struct ipv6_fl_socklist___4 *next;
	struct ip6_flowlabel___4 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___34 {
	struct in6_addr mca_addr;
	struct inet6_dev___34 *idev;
	struct ifmcaddr6___34 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___9 {
	struct in6_addr aca_addr;
	struct fib6_info___9 *aca_rt;
	struct ifacaddr6___9 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___4 {
	struct ip6_flowlabel___4 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___228 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___65 *fl_net;
};

struct trace_event_raw_sock_rcvqueue_full {
	struct trace_entry ent;
	int rmem_alloc;
	unsigned int truesize;
	int sk_rcvbuf;
	char __data[0];
};

struct trace_event_raw_sock_exceed_buf_limit {
	struct trace_entry ent;
	char name[32];
	long int *sysctl_mem;
	long int allocated;
	int sysctl_rmem;
	int rmem_alloc;
	int sysctl_wmem;
	int wmem_alloc;
	int wmem_queued;
	int kind;
	char __data[0];
};

struct trace_event_raw_inet_sock_set_state {
	struct trace_entry ent;
	const void *skaddr;
	int oldstate;
	int newstate;
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u16 protocol;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_raw_inet_sk_error_report {
	struct trace_entry ent;
	int error;
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u16 protocol;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_data_offsets_sock_rcvqueue_full {};

struct trace_event_data_offsets_sock_exceed_buf_limit {};

struct trace_event_data_offsets_inet_sock_set_state {};

struct trace_event_data_offsets_inet_sk_error_report {};

typedef void (*btf_trace_sock_rcvqueue_full)(void *, struct sock___48 *, struct sk_buff___61 *);

typedef void (*btf_trace_sock_exceed_buf_limit)(void *, struct sock___48 *, struct proto___48 *, long int, int);

typedef void (*btf_trace_inet_sock_set_state)(void *, const struct sock___48 *, const int, const int);

typedef void (*btf_trace_inet_sk_error_report)(void *, const struct sock___48 *);

struct trace_event_raw_udp_fail_queue_rcv_skb {
	struct trace_entry ent;
	int rc;
	__u16 lport;
	char __data[0];
};

struct trace_event_data_offsets_udp_fail_queue_rcv_skb {};

typedef void (*btf_trace_udp_fail_queue_rcv_skb)(void *, int, struct sock___48 *);

struct fib_nh_exception___9 {
	struct fib_nh_exception___9 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___9 *fnhe_rth_input;
	struct rtable___9 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___9 {
	struct dst_entry___48 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___9 {
	struct fib_nh_exception___9 *chain;
};

struct trace_event_raw_tcp_event_sk_skb {
	struct trace_entry ent;
	const void *skbaddr;
	const void *skaddr;
	int state;
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_raw_tcp_event_sk {
	struct trace_entry ent;
	const void *skaddr;
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	__u64 sock_cookie;
	char __data[0];
};

struct trace_event_raw_tcp_retransmit_synack {
	struct trace_entry ent;
	const void *skaddr;
	const void *req;
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u8 saddr[4];
	__u8 daddr[4];
	__u8 saddr_v6[16];
	__u8 daddr_v6[16];
	char __data[0];
};

struct trace_event_raw_tcp_probe {
	struct trace_entry ent;
	__u8 saddr[28];
	__u8 daddr[28];
	__u16 sport;
	__u16 dport;
	__u16 family;
	__u32 mark;
	__u16 data_len;
	__u32 snd_nxt;
	__u32 snd_una;
	__u32 snd_cwnd;
	__u32 ssthresh;
	__u32 snd_wnd;
	__u32 srtt;
	__u32 rcv_wnd;
	__u64 sock_cookie;
	char __data[0];
};

struct trace_event_raw_tcp_event_skb {
	struct trace_entry ent;
	const void *skbaddr;
	__u8 saddr[28];
	__u8 daddr[28];
	char __data[0];
};

struct trace_event_data_offsets_tcp_event_sk_skb {};

struct trace_event_data_offsets_tcp_event_sk {};

struct trace_event_data_offsets_tcp_retransmit_synack {};

struct trace_event_data_offsets_tcp_probe {};

struct trace_event_data_offsets_tcp_event_skb {};

typedef void (*btf_trace_tcp_retransmit_skb)(void *, const struct sock___48 *, const struct sk_buff___61 *);

typedef void (*btf_trace_tcp_send_reset)(void *, const struct sock___48 *, const struct sk_buff___61 *);

typedef void (*btf_trace_tcp_receive_reset)(void *, struct sock___48 *);

typedef void (*btf_trace_tcp_destroy_sock)(void *, struct sock___48 *);

typedef void (*btf_trace_tcp_rcv_space_adjust)(void *, struct sock___48 *);

typedef void (*btf_trace_tcp_retransmit_synack)(void *, const struct sock___48 *, const struct request_sock___37 *);

typedef void (*btf_trace_tcp_probe)(void *, struct sock___48 *, struct sk_buff___61 *);

typedef void (*btf_trace_tcp_bad_csum)(void *, const struct sk_buff___61 *);

struct trace_event_raw_fib_table_lookup {
	struct trace_entry ent;
	u32 tb_id;
	int err;
	int oif;
	int iif;
	u8 proto;
	__u8 tos;
	__u8 scope;
	__u8 flags;
	__u8 src[4];
	__u8 dst[4];
	__u8 gw4[4];
	__u8 gw6[16];
	u16 sport;
	u16 dport;
	u32 __data_loc_name;
	char __data[0];
};

struct trace_event_data_offsets_fib_table_lookup {
	u32 name;
};

typedef void (*btf_trace_fib_table_lookup)(void *, u32, const struct flowi4 *, const struct fib_nh_common___9 *, int);

struct trace_event_raw_qdisc_dequeue {
	struct trace_entry ent;
	struct Qdisc___55 *qdisc;
	const struct netdev_queue___60 *txq;
	int packets;
	void *skbaddr;
	int ifindex;
	u32 handle;
	u32 parent;
	long unsigned int txq_state;
	char __data[0];
};

struct trace_event_raw_qdisc_enqueue {
	struct trace_entry ent;
	struct Qdisc___55 *qdisc;
	const struct netdev_queue___60 *txq;
	void *skbaddr;
	int ifindex;
	u32 handle;
	u32 parent;
	char __data[0];
};

struct trace_event_raw_qdisc_reset {
	struct trace_entry ent;
	u32 __data_loc_dev;
	u32 __data_loc_kind;
	u32 parent;
	u32 handle;
	char __data[0];
};

struct trace_event_raw_qdisc_destroy {
	struct trace_entry ent;
	u32 __data_loc_dev;
	u32 __data_loc_kind;
	u32 parent;
	u32 handle;
	char __data[0];
};

struct trace_event_raw_qdisc_create {
	struct trace_entry ent;
	u32 __data_loc_dev;
	u32 __data_loc_kind;
	u32 parent;
	char __data[0];
};

struct trace_event_data_offsets_qdisc_dequeue {};

struct trace_event_data_offsets_qdisc_enqueue {};

struct trace_event_data_offsets_qdisc_reset {
	u32 dev;
	u32 kind;
};

struct trace_event_data_offsets_qdisc_destroy {
	u32 dev;
	u32 kind;
};

struct trace_event_data_offsets_qdisc_create {
	u32 dev;
	u32 kind;
};

typedef void (*btf_trace_qdisc_dequeue)(void *, struct Qdisc___55 *, const struct netdev_queue___60 *, int, struct sk_buff___61 *);

typedef void (*btf_trace_qdisc_enqueue)(void *, struct Qdisc___55 *, const struct netdev_queue___60 *, struct sk_buff___61 *);

typedef void (*btf_trace_qdisc_reset)(void *, struct Qdisc___55 *);

typedef void (*btf_trace_qdisc_destroy)(void *, struct Qdisc___55 *);

typedef void (*btf_trace_qdisc_create)(void *, const struct Qdisc_ops___55 *, struct net_device___60 *, u32);

struct bridge_stp_xstats {
	__u64 transition_blk;
	__u64 transition_fwd;
	__u64 rx_bpdu;
	__u64 tx_bpdu;
	__u64 rx_tcn;
	__u64 tx_tcn;
};

struct br_mcast_stats {
	__u64 igmp_v1queries[2];
	__u64 igmp_v2queries[2];
	__u64 igmp_v3queries[2];
	__u64 igmp_leaves[2];
	__u64 igmp_v1reports[2];
	__u64 igmp_v2reports[2];
	__u64 igmp_v3reports[2];
	__u64 igmp_parse_errors;
	__u64 mld_v1queries[2];
	__u64 mld_v2queries[2];
	__u64 mld_leaves[2];
	__u64 mld_v1reports[2];
	__u64 mld_v2reports[2];
	__u64 mld_parse_errors;
	__u64 mcast_bytes[2];
	__u64 mcast_packets[2];
};

struct br_ip {
	union {
		__be32 ip4;
		struct in6_addr ip6;
	} src;
	union {
		__be32 ip4;
		struct in6_addr ip6;
		unsigned char mac_addr[6];
	} dst;
	__be16 proto;
	__u16 vid;
};

struct bridge_id {
	unsigned char prio[2];
	unsigned char addr[6];
};

typedef struct bridge_id bridge_id;

struct mac_addr___2 {
	unsigned char addr[6];
};

typedef struct mac_addr___2 mac_addr;

typedef __u16 port_id;

struct bridge_mcast_own_query {
	struct timer_list timer;
	u32 startup_sent;
};

struct bridge_mcast_other_query {
	struct timer_list timer;
	long unsigned int delay_time;
};

struct bridge_mcast_querier {
	struct br_ip addr;
	int port_ifidx;
	seqcount_spinlock_t seq;
};

struct bridge_mcast_stats {
	struct br_mcast_stats mstats;
	struct u64_stats_sync syncp;
};

struct net_bridge_port;

struct net_bridge_vlan;

struct net_bridge_mcast_port {
	struct net_bridge_port *port;
	struct net_bridge_vlan *vlan;
	struct bridge_mcast_own_query ip4_own_query;
	struct timer_list ip4_mc_router_timer;
	struct hlist_node ip4_rlist;
	struct bridge_mcast_own_query ip6_own_query;
	struct timer_list ip6_mc_router_timer;
	struct hlist_node ip6_rlist;
	unsigned char multicast_router;
};

struct net_bridge___2;

struct net_bridge_vlan_group;

struct net_bridge_port {
	struct net_bridge___2 *br;
	struct net_device___60 *dev;
	struct list_head list;
	long unsigned int flags;
	struct net_bridge_vlan_group *vlgrp;
	struct net_bridge_port *backup_port;
	u8 priority;
	u8 state;
	u16 port_no;
	unsigned char topology_change_ack;
	unsigned char config_pending;
	port_id port_id;
	port_id designated_port;
	bridge_id designated_root;
	bridge_id designated_bridge;
	u32 path_cost;
	u32 designated_cost;
	long unsigned int designated_age;
	struct timer_list forward_delay_timer;
	struct timer_list hold_timer;
	struct timer_list message_age_timer;
	struct kobject___239 kobj;
	struct callback_head rcu;
	struct net_bridge_mcast_port multicast_ctx;
	struct bridge_mcast_stats *mcast_stats;
	u32 multicast_eht_hosts_limit;
	u32 multicast_eht_hosts_cnt;
	struct hlist_head mglist;
	char sysfs_name[16];
	struct netpoll___3 *np;
	int hwdom;
	int offload_count;
	struct netdev_phys_item_id ppid;
	u16 group_fwd_mask;
	u16 backup_redirected_cnt;
	struct bridge_stp_xstats stp_xstats;
};

struct metadata_dst___5;

struct br_tunnel_info {
	__be64 tunnel_id;
	struct metadata_dst___5 *tunnel_dst;
};

struct net_bridge_mcast {
	struct net_bridge___2 *br;
	struct net_bridge_vlan *vlan;
	u32 multicast_last_member_count;
	u32 multicast_startup_query_count;
	u8 multicast_querier;
	u8 multicast_igmp_version;
	u8 multicast_router;
	u8 multicast_mld_version;
	long unsigned int multicast_last_member_interval;
	long unsigned int multicast_membership_interval;
	long unsigned int multicast_querier_interval;
	long unsigned int multicast_query_interval;
	long unsigned int multicast_query_response_interval;
	long unsigned int multicast_startup_query_interval;
	struct hlist_head ip4_mc_router_list;
	struct timer_list ip4_mc_router_timer;
	struct bridge_mcast_other_query ip4_other_query;
	struct bridge_mcast_own_query ip4_own_query;
	struct bridge_mcast_querier ip4_querier;
	struct hlist_head ip6_mc_router_list;
	struct timer_list ip6_mc_router_timer;
	struct bridge_mcast_other_query ip6_other_query;
	struct bridge_mcast_own_query ip6_own_query;
	struct bridge_mcast_querier ip6_querier;
};

struct net_bridge_vlan {
	struct rhash_head vnode;
	struct rhash_head tnode;
	u16 vid;
	u16 flags;
	u16 priv_flags;
	u8 state;
	struct pcpu_sw_netstats *stats;
	union {
		struct net_bridge___2 *br;
		struct net_bridge_port *port;
	};
	union {
		refcount_t refcnt;
		struct net_bridge_vlan *brvlan;
	};
	struct br_tunnel_info tinfo;
	union {
		struct net_bridge_mcast br_mcast_ctx;
		struct net_bridge_mcast_port port_mcast_ctx;
	};
	struct list_head vlist;
	struct callback_head rcu;
};

struct net_bridge___2 {
	spinlock_t lock;
	spinlock_t hash_lock;
	struct hlist_head frame_type_list;
	struct net_device___60 *dev;
	long unsigned int options;
	__be16 vlan_proto;
	u16 default_pvid;
	struct net_bridge_vlan_group *vlgrp;
	struct rhashtable fdb_hash_tbl;
	struct list_head port_list;
	union {
		struct rtable___9 fake_rtable;
		struct rt6_info___9 fake_rt6_info;
	};
	u16 group_fwd_mask;
	u16 group_fwd_mask_required;
	bridge_id designated_root;
	bridge_id bridge_id;
	unsigned char topology_change;
	unsigned char topology_change_detected;
	u16 root_port;
	long unsigned int max_age;
	long unsigned int hello_time;
	long unsigned int forward_delay;
	long unsigned int ageing_time;
	long unsigned int bridge_max_age;
	long unsigned int bridge_hello_time;
	long unsigned int bridge_forward_delay;
	long unsigned int bridge_ageing_time;
	u32 root_path_cost;
	u8 group_addr[6];
	enum {
		BR_NO_STP = 0,
		BR_KERNEL_STP = 1,
		BR_USER_STP = 2,
	} stp_enabled;
	struct net_bridge_mcast multicast_ctx;
	struct bridge_mcast_stats *mcast_stats;
	u32 hash_max;
	spinlock_t multicast_lock;
	struct rhashtable mdb_hash_tbl;
	struct rhashtable sg_port_tbl;
	struct hlist_head mcast_gc_list;
	struct hlist_head mdb_list;
	struct work_struct mcast_gc_work;
	struct timer_list hello_timer;
	struct timer_list tcn_timer;
	struct timer_list topology_change_timer;
	struct delayed_work gc_work;
	struct kobject___239 *ifobj;
	u32 auto_cnt;
	int last_hwdom;
	long unsigned int busy_hwdoms;
	struct hlist_head fdb_list;
	struct hlist_head mrp_list;
	struct hlist_head mep_list;
};

struct net_bridge_vlan_group {
	struct rhashtable vlan_hash;
	struct rhashtable tunnel_hash;
	struct list_head vlan_list;
	u16 num_vlans;
	u16 pvid;
	u8 pvid_state;
};

struct net_bridge_fdb_key {
	mac_addr addr;
	u16 vlan_id;
};

struct net_bridge_fdb_entry {
	struct rhash_head rhnode;
	struct net_bridge_port *dst;
	struct net_bridge_fdb_key key;
	struct hlist_node fdb_node;
	long unsigned int flags;
	long: 64;
	long: 64;
	long unsigned int updated;
	long unsigned int used;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct trace_event_raw_br_fdb_add {
	struct trace_entry ent;
	u8 ndm_flags;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	u16 nlh_flags;
	char __data[0];
};

struct trace_event_raw_br_fdb_external_learn_add {
	struct trace_entry ent;
	u32 __data_loc_br_dev;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	char __data[0];
};

struct trace_event_raw_fdb_delete {
	struct trace_entry ent;
	u32 __data_loc_br_dev;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	char __data[0];
};

struct trace_event_raw_br_fdb_update {
	struct trace_entry ent;
	u32 __data_loc_br_dev;
	u32 __data_loc_dev;
	unsigned char addr[6];
	u16 vid;
	long unsigned int flags;
	char __data[0];
};

struct trace_event_data_offsets_br_fdb_add {
	u32 dev;
};

struct trace_event_data_offsets_br_fdb_external_learn_add {
	u32 br_dev;
	u32 dev;
};

struct trace_event_data_offsets_fdb_delete {
	u32 br_dev;
	u32 dev;
};

struct trace_event_data_offsets_br_fdb_update {
	u32 br_dev;
	u32 dev;
};

typedef void (*btf_trace_br_fdb_add)(void *, struct ndmsg *, struct net_device___60 *, const unsigned char *, u16, u16);

typedef void (*btf_trace_br_fdb_external_learn_add)(void *, struct net_bridge___2 *, struct net_bridge_port *, const unsigned char *, u16);

typedef void (*btf_trace_fdb_delete)(void *, struct net_bridge___2 *, struct net_bridge_fdb_entry *);

typedef void (*btf_trace_br_fdb_update)(void *, struct net_bridge___2 *, struct net_bridge_port *, const unsigned char *, u16, long unsigned int);

struct trace_event_raw_page_pool_release {
	struct trace_entry ent;
	const struct page_pool___80 *pool;
	s32 inflight;
	u32 hold;
	u32 release;
	u64 cnt;
	char __data[0];
};

struct trace_event_raw_page_pool_state_release {
	struct trace_entry ent;
	const struct page_pool___80 *pool;
	const struct page___256 *page;
	u32 release;
	long unsigned int pfn;
	char __data[0];
};

struct trace_event_raw_page_pool_state_hold {
	struct trace_entry ent;
	const struct page_pool___80 *pool;
	const struct page___256 *page;
	u32 hold;
	long unsigned int pfn;
	char __data[0];
};

struct trace_event_raw_page_pool_update_nid {
	struct trace_entry ent;
	const struct page_pool___80 *pool;
	int pool_nid;
	int new_nid;
	char __data[0];
};

struct trace_event_data_offsets_page_pool_release {};

struct trace_event_data_offsets_page_pool_state_release {};

struct trace_event_data_offsets_page_pool_state_hold {};

struct trace_event_data_offsets_page_pool_update_nid {};

typedef void (*btf_trace_page_pool_release)(void *, const struct page_pool___80 *, s32, u32, u32);

typedef void (*btf_trace_page_pool_state_release)(void *, const struct page_pool___80 *, const struct page___256 *, u32);

typedef void (*btf_trace_page_pool_state_hold)(void *, const struct page_pool___80 *, const struct page___256 *, u32);

typedef void (*btf_trace_page_pool_update_nid)(void *, const struct page_pool___80 *, int);

struct trace_event_raw_neigh_create {
	struct trace_entry ent;
	u32 family;
	u32 __data_loc_dev;
	int entries;
	u8 created;
	u8 gc_exempt;
	u8 primary_key4[4];
	u8 primary_key6[16];
	char __data[0];
};

struct trace_event_raw_neigh_update {
	struct trace_entry ent;
	u32 family;
	u32 __data_loc_dev;
	u8 lladdr[32];
	u8 lladdr_len;
	u8 flags;
	u8 nud_state;
	u8 type;
	u8 dead;
	int refcnt;
	__u8 primary_key4[4];
	__u8 primary_key6[16];
	long unsigned int confirmed;
	long unsigned int updated;
	long unsigned int used;
	u8 new_lladdr[32];
	u8 new_state;
	u32 update_flags;
	u32 pid;
	char __data[0];
};

struct trace_event_raw_neigh__update {
	struct trace_entry ent;
	u32 family;
	u32 __data_loc_dev;
	u8 lladdr[32];
	u8 lladdr_len;
	u8 flags;
	u8 nud_state;
	u8 type;
	u8 dead;
	int refcnt;
	__u8 primary_key4[4];
	__u8 primary_key6[16];
	long unsigned int confirmed;
	long unsigned int updated;
	long unsigned int used;
	u32 err;
	char __data[0];
};

struct trace_event_data_offsets_neigh_create {
	u32 dev;
};

struct trace_event_data_offsets_neigh_update {
	u32 dev;
};

struct trace_event_data_offsets_neigh__update {
	u32 dev;
};

typedef void (*btf_trace_neigh_create)(void *, struct neigh_table___48 *, struct net_device___60 *, const void *, const struct neighbour___48 *, bool);

typedef void (*btf_trace_neigh_update)(void *, struct neighbour___48 *, const u8 *, u8, u32, u32);

typedef void (*btf_trace_neigh_update_done)(void *, struct neighbour___48 *, int);

typedef void (*btf_trace_neigh_timer_handler)(void *, struct neighbour___48 *, int);

typedef void (*btf_trace_neigh_event_send_done)(void *, struct neighbour___48 *, int);

typedef void (*btf_trace_neigh_event_send_dead)(void *, struct neighbour___48 *, int);

typedef void (*btf_trace_neigh_cleanup_and_release)(void *, struct neighbour___48 *, int);

struct dentry___252;

struct super_block___252;

struct module___236;

struct file_system_type___252 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___252 * (*mount)(struct file_system_type___252 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___252 *);
	struct module___236 *owner;
	struct file_system_type___252 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___252;

struct kiocb___252;

struct iov_iter___172;

struct vm_area_struct___257;

struct inode___252;

struct file_lock___252;

struct page___257;

struct pipe_inode_info___93;

struct seq_file___227;

struct file_operations___253 {
	struct module___236 *owner;
	loff_t (*llseek)(struct file___252 *, loff_t, int);
	ssize_t (*read)(struct file___252 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___252 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___252 *, struct iov_iter___172 *);
	ssize_t (*write_iter)(struct kiocb___252 *, struct iov_iter___172 *);
	int (*iopoll)(struct kiocb___252 *, bool);
	int (*iterate)(struct file___252 *, struct dir_context *);
	int (*iterate_shared)(struct file___252 *, struct dir_context *);
	__poll_t (*poll)(struct file___252 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___252 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___252 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___252 *, struct vm_area_struct___257 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___252 *, struct file___252 *);
	int (*flush)(struct file___252 *, fl_owner_t);
	int (*release)(struct inode___252 *, struct file___252 *);
	int (*fsync)(struct file___252 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___252 *, int);
	int (*lock)(struct file___252 *, int, struct file_lock___252 *);
	ssize_t (*sendpage)(struct file___252 *, struct page___257 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___252 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___252 *, long unsigned int);
	int (*flock)(struct file___252 *, int, struct file_lock___252 *);
	ssize_t (*splice_write)(struct pipe_inode_info___93 *, struct file___252 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___252 *, loff_t *, struct pipe_inode_info___93 *, size_t, unsigned int);
	int (*setlease)(struct file___252 *, long int, struct file_lock___252 **, void **);
	long int (*fallocate)(struct file___252 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___227 *, struct file___252 *);
	ssize_t (*copy_file_range)(struct file___252 *, loff_t, struct file___252 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___252 *, loff_t, struct file___252 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___252 *, loff_t, loff_t, int);
};

struct vmacache___257 {
	u64 seqnum;
	struct vm_area_struct___257 *vmas[4];
};

struct page_frag___257 {
	struct page___257 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___258;

struct pid___229;

struct nsproxy___238;

struct signal_struct___253;

struct css_set___179;

struct vm_struct___235;

struct task_struct___259 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___259 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___258 *mm;
	struct mm_struct___258 *active_mm;
	struct vmacache___257 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___259 *real_parent;
	struct task_struct___259 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___259 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___229 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___238 *nsproxy;
	struct signal_struct___253 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___259 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___143 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___179 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___93 *splice_pipe;
	struct page_frag___257 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___259 *oom_reaper_list;
	struct vm_struct___235 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___240;

struct kobj_type___240;

struct kernfs_node___240;

struct kobject___240 {
	const char *name;
	struct list_head entry;
	struct kobject___240 *parent;
	struct kset___240 *kset;
	struct kobj_type___240 *ktype;
	struct kernfs_node___240 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___237 {
	struct kobject___240 kobj;
	struct module___236 *mod;
	struct kobject___240 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___236 {
	struct module___236 *mod;
	struct latch_tree_node node;
};

struct module_layout___236 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___236 mtn;
};

struct module_attribute___236;

struct kernel_param___236;

struct module___236 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___237 mkobj;
	struct module_attribute___236 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___240 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___236 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___236 core_layout;
	struct module_layout___236 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___229;

struct upid___229 {
	int nr;
	struct pid_namespace___229 *ns;
};

struct pid_namespace___229 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___259 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___229 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___229 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___229 numbers[1];
};

typedef struct page___257 *pgtable_t___257;

struct address_space___252;

struct page_pool___81;

struct dev_pagemap___247;

struct page___257 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___252 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___81 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___257 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___257 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___258 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___247 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___247;

struct vm_area_struct___257 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___257 *vm_next;
	struct vm_area_struct___257 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___258 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___247 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___252 *vm_file;
	struct file___252 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___253 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___259 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___259 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___229 *pids[4];
	struct pid___229 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___258 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___257;

struct mm_struct___258 {
	struct {
		struct vm_area_struct___257 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___252 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___257 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___259 *owner;
		struct user_namespace___26 *user_ns;
		struct file___252 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___66;

struct cgroup_namespace___179;

struct nsproxy___238 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___229 *pid_ns_for_children;
	struct net___66 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___179 *cgroup_ns;
};

struct cgroup_subsys_state___179;

struct cgroup___179;

struct css_set___179 {
	struct cgroup_subsys_state___179 *subsys[14];
	refcount_t refcount;
	struct css_set___179 *dom_cset;
	struct cgroup___179 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___179 *mg_src_cgrp;
	struct cgroup___179 *mg_dst_cgrp;
	struct css_set___179 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___252;

struct pipe_buffer___93;

struct pipe_inode_info___93 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___257 *tmp_page;
	struct fasync_struct___252 *fasync_readers;
	struct fasync_struct___252 *fasync_writers;
	struct pipe_buffer___93 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___235 {
	struct vm_struct___235 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___257 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___169 {
	struct page___257 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___172 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___169 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___93 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct kiocb___252 {
	struct file___252 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___252 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct net_device___61;

struct sk_buff___62 {
	union {
		struct {
			struct sk_buff___62 *next;
			struct sk_buff___62 *prev;
			union {
				struct net_device___61 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___48 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___62 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___66;

struct fqdir___66 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___66 *f;
	struct net___66 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___66;

struct inet_frags___66 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___66 *, const void *);
	void (*destructor)(struct inet_frag_queue___66 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct netns_ipv4___66 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___66 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___66 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___66 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___61 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___62 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___62 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___62 *);
	int (*local_out)(struct net___66 *, struct sock *, struct sk_buff___62 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___62 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___66 {
	struct dst_ops___66 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___66 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___66 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___66 *fqdir;
};

struct sk_buff_head___61 {
	struct sk_buff___62 *next;
	struct sk_buff___62 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___66 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___66 xfrm4_dst_ops;
	struct dst_ops___66 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___66 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___61 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___66 ipv4;
	struct netns_ipv6___66 ipv6;
	struct netns_ieee802154_lowpan___66 ieee802154_lowpan;
	struct netns_sctp___48 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___61 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___55 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___66 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___66 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___62 *fragments_tail;
	struct sk_buff___62 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___66 *fqdir;
	struct callback_head rcu;
};

struct address_space_operations___252;

struct address_space___252 {
	struct inode___252 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___252 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___233;

struct page_pool_params___81 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___233 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___81 {
	u32 count;
	struct page___257 *cache[128];
};

struct page_pool___81 {
	struct page_pool_params___81 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___257 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___81 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___247;

struct dev_pagemap___247 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___247 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___252;

struct path___252 {
	struct vfsmount___252 *mnt;
	struct dentry___252 *dentry;
};

struct fown_struct___229 {
	rwlock_t lock;
	struct pid___229 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___252 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___252 f_path;
	struct inode___252 *f_inode;
	const struct file_operations___253 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___229 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___252 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___247;

struct vm_operations_struct___247 {
	void (*open)(struct vm_area_struct___257 *);
	void (*close)(struct vm_area_struct___257 *);
	int (*may_split)(struct vm_area_struct___257 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___257 *);
	int (*mprotect)(struct vm_area_struct___257 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___247 *);
	vm_fault_t (*huge_fault)(struct vm_fault___247 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___247 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___257 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___247 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___247 *);
	int (*access)(struct vm_area_struct___257 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___257 *);
	int (*set_policy)(struct vm_area_struct___257 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___257 *, long unsigned int);
	struct page___257 * (*find_special_page)(struct vm_area_struct___257 *, long unsigned int);
};

struct core_thread___257 {
	struct task_struct___259 *task;
	struct core_thread___257 *next;
};

struct core_state___257 {
	atomic_t nr_threads;
	struct core_thread___257 dumper;
	struct completion startup;
};

struct vm_fault___247 {
	const struct {
		struct vm_area_struct___257 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___257 *cow_page;
	struct page___257 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___257 prealloc_pte;
};

typedef rx_handler_result_t rx_handler_func_t___61(struct sk_buff___62 **);

typedef struct {
	struct net___66 *net;
} possible_net_t___61;

struct wakeup_source___233;

struct dev_pm_info___233 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___233 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___233 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___233;

struct bus_type___233;

struct device_driver___233;

struct dev_pm_domain___233;

struct fwnode_handle___229;

struct class___233;

struct attribute_group___240;

struct device___233 {
	struct kobject___240 kobj;
	struct device___233 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___233 *type;
	struct bus_type___233 *bus;
	struct device_driver___233 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___233 power;
	struct dev_pm_domain___233 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___229 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___233 *class;
	const struct attribute_group___240 **groups;
	void (*release)(struct device___233 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_name_node___61;

struct net_device_ops___61;

struct xfrmdev_ops___61;

struct header_ops___61;

struct in_device___6;

struct netdev_rx_queue___61;

struct netdev_queue___61;

struct netpoll_info___4;

struct dcbnl_rtnl_ops___61;

struct net_device___61 {
	char name[16];
	struct netdev_name_node___61 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___61 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___61 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___61 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___240 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___6 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___61 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___61 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___61 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___61 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___61 = 0,
		NETREG_REGISTERED___61 = 1,
		NETREG_UNREGISTERING___61 = 2,
		NETREG_UNREGISTERED___61 = 3,
		NETREG_RELEASED___61 = 4,
		NETREG_DUMMY___61 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___61 = 0,
		RTNL_LINK_INITIALIZING___61 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___61 *);
	struct netpoll_info___4 *npinfo;
	possible_net_t___61 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___233 dev;
	const struct attribute_group___240 *sysfs_groups[4];
	const struct attribute_group___240 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___61 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___55 xdp_state[3];
	long: 64;
};

struct dentry_operations___252;

struct dentry___252 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___252 *d_parent;
	struct qstr d_name;
	struct inode___252 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___252 *d_op;
	struct super_block___252 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___252;

struct inode___252 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___252 *i_op;
	struct super_block___252 *i_sb;
	struct address_space___252 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___253 *i_fop;
		void (*free_inode)(struct inode___252 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___252 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___93 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___252 {
	int (*d_revalidate)(struct dentry___252 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___252 *, unsigned int);
	int (*d_hash)(const struct dentry___252 *, struct qstr *);
	int (*d_compare)(const struct dentry___252 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___252 *);
	int (*d_init)(struct dentry___252 *);
	void (*d_release)(struct dentry___252 *);
	void (*d_prune)(struct dentry___252 *);
	void (*d_iput)(struct dentry___252 *, struct inode___252 *);
	char * (*d_dname)(struct dentry___252 *, char *, int);
	struct vfsmount___252 * (*d_automount)(struct path___252 *);
	int (*d_manage)(const struct path___252 *, bool);
	struct dentry___252 * (*d_real)(struct dentry___252 *, const struct inode___252 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___252;

struct mem_dqinfo___252 {
	struct quota_format_type___252 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___252;

struct quota_info___252 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___252 *files[3];
	struct mem_dqinfo___252 info[3];
	const struct quota_format_ops___252 *ops[3];
};

struct rcuwait___253 {
	struct task_struct___259 *task;
};

struct percpu_rw_semaphore___253 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___253 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___252 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___253 rw_sem[3];
};

struct super_operations___252;

struct dquot_operations___252;

struct quotactl_ops___252;

struct super_block___252 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___252 *s_type;
	const struct super_operations___252 *s_op;
	const struct dquot_operations___252 *dq_op;
	const struct quotactl_ops___252 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___252 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___252 s_dquot;
	struct sb_writers___252 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___252 *s_d_op;
	int cleancache_poolid;
	struct shrinker___117 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___252 {
	struct dentry___252 *mnt_root;
	struct super_block___252 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct cgroup_subsys___179;

struct cgroup_subsys_state___179 {
	struct cgroup___179 *cgroup;
	struct cgroup_subsys___179 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___179 *parent;
};

struct cgroup_file___179 {
	struct kernfs_node___240 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___179 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___259 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___179;

struct cgroup_rstat_cpu___179;

struct cgroup___179 {
	struct cgroup_subsys_state___179 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___240 *kn;
	struct cgroup_file___179 procs_file;
	struct cgroup_file___179 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___179 *subsys[14];
	struct cgroup_root___179 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___179 *dom_cgrp;
	struct cgroup___179 *old_dom_cgrp;
	struct cgroup_rstat_cpu___179 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___179 psi;
	struct cgroup_bpf___55 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___252 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___252 *ia_file;
};

struct dquot___252 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___252 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___252 {
	int qf_fmt_id;
	const struct quota_format_ops___252 *qf_ops;
	struct module___236 *qf_owner;
	struct quota_format_type___252 *qf_next;
};

struct quota_format_ops___252 {
	int (*check_quota_file)(struct super_block___252 *, int);
	int (*read_file_info)(struct super_block___252 *, int);
	int (*write_file_info)(struct super_block___252 *, int);
	int (*free_file_info)(struct super_block___252 *, int);
	int (*read_dqblk)(struct dquot___252 *);
	int (*commit_dqblk)(struct dquot___252 *);
	int (*release_dqblk)(struct dquot___252 *);
	int (*get_next_id)(struct super_block___252 *, struct kqid *);
};

struct dquot_operations___252 {
	int (*write_dquot)(struct dquot___252 *);
	struct dquot___252 * (*alloc_dquot)(struct super_block___252 *, int);
	void (*destroy_dquot)(struct dquot___252 *);
	int (*acquire_dquot)(struct dquot___252 *);
	int (*release_dquot)(struct dquot___252 *);
	int (*mark_dirty)(struct dquot___252 *);
	int (*write_info)(struct super_block___252 *, int);
	qsize_t * (*get_reserved_space)(struct inode___252 *);
	int (*get_projid)(struct inode___252 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___252 *, qsize_t *);
	int (*get_next_id)(struct super_block___252 *, struct kqid *);
};

struct quotactl_ops___252 {
	int (*quota_on)(struct super_block___252 *, int, int, const struct path___252 *);
	int (*quota_off)(struct super_block___252 *, int);
	int (*quota_enable)(struct super_block___252 *, unsigned int);
	int (*quota_disable)(struct super_block___252 *, unsigned int);
	int (*quota_sync)(struct super_block___252 *, int);
	int (*set_info)(struct super_block___252 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___252 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___252 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___252 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___252 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___252 *, unsigned int);
};

struct address_space_operations___252 {
	int (*writepage)(struct page___257 *, struct writeback_control___3 *);
	int (*readpage)(struct file___252 *, struct page___257 *);
	int (*writepages)(struct address_space___252 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___257 *);
	int (*readpages)(struct file___252 *, struct address_space___252 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___252 *, struct address_space___252 *, loff_t, unsigned int, unsigned int, struct page___257 **, void **);
	int (*write_end)(struct file___252 *, struct address_space___252 *, loff_t, unsigned int, unsigned int, struct page___257 *, void *);
	sector_t (*bmap)(struct address_space___252 *, sector_t);
	void (*invalidatepage)(struct page___257 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___257 *, gfp_t);
	void (*freepage)(struct page___257 *);
	ssize_t (*direct_IO)(struct kiocb___252 *, struct iov_iter___172 *);
	int (*migratepage)(struct address_space___252 *, struct page___257 *, struct page___257 *, enum migrate_mode);
	bool (*isolate_page)(struct page___257 *, isolate_mode_t);
	void (*putback_page)(struct page___257 *);
	int (*launder_page)(struct page___257 *);
	int (*is_partially_uptodate)(struct page___257 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___257 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___252 *, struct page___257 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___252 *, sector_t *);
	void (*swap_deactivate)(struct file___252 *);
};

struct inode_operations___252 {
	struct dentry___252 * (*lookup)(struct inode___252 *, struct dentry___252 *, unsigned int);
	const char * (*get_link)(struct dentry___252 *, struct inode___252 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___252 *, int);
	struct posix_acl * (*get_acl)(struct inode___252 *, int, bool);
	int (*readlink)(struct dentry___252 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___252 *, struct dentry___252 *, umode_t, bool);
	int (*link)(struct dentry___252 *, struct inode___252 *, struct dentry___252 *);
	int (*unlink)(struct inode___252 *, struct dentry___252 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___252 *, struct dentry___252 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___252 *, struct dentry___252 *, umode_t);
	int (*rmdir)(struct inode___252 *, struct dentry___252 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___252 *, struct dentry___252 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___252 *, struct dentry___252 *, struct inode___252 *, struct dentry___252 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___252 *, struct iattr___252 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___252 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___252 *, char *, size_t);
	int (*fiemap)(struct inode___252 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___252 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___252 *, struct dentry___252 *, struct file___252 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___252 *, struct dentry___252 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___252 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___252 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___252 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___252 {
	void (*fl_copy_lock)(struct file_lock___252 *, struct file_lock___252 *);
	void (*fl_release_private)(struct file_lock___252 *);
};

struct lock_manager_operations___252;

struct file_lock___252 {
	struct file_lock___252 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___252 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___252 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___252 *fl_ops;
	const struct lock_manager_operations___252 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___252 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___252 *);
	int (*lm_grant)(struct file_lock___252 *, int);
	bool (*lm_break)(struct file_lock___252 *);
	int (*lm_change)(struct file_lock___252 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___252 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___252 *);
};

struct fasync_struct___252 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___252 *fa_next;
	struct file___252 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___252 {
	struct inode___252 * (*alloc_inode)(struct super_block___252 *);
	void (*destroy_inode)(struct inode___252 *);
	void (*free_inode)(struct inode___252 *);
	void (*dirty_inode)(struct inode___252 *, int);
	int (*write_inode)(struct inode___252 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___252 *);
	void (*evict_inode)(struct inode___252 *);
	void (*put_super)(struct super_block___252 *);
	int (*sync_fs)(struct super_block___252 *, int);
	int (*freeze_super)(struct super_block___252 *);
	int (*freeze_fs)(struct super_block___252 *);
	int (*thaw_super)(struct super_block___252 *);
	int (*unfreeze_fs)(struct super_block___252 *);
	int (*statfs)(struct dentry___252 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___252 *, int *, char *);
	void (*umount_begin)(struct super_block___252 *);
	int (*show_options)(struct seq_file___227 *, struct dentry___252 *);
	int (*show_devname)(struct seq_file___227 *, struct dentry___252 *);
	int (*show_path)(struct seq_file___227 *, struct dentry___252 *);
	int (*show_stats)(struct seq_file___227 *, struct dentry___252 *);
	ssize_t (*quota_read)(struct super_block___252 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___252 *, int, const char *, size_t, loff_t);
	struct dquot___252 ** (*get_dquots)(struct inode___252 *);
	long int (*nr_cached_objects)(struct super_block___252 *, struct shrink_control___117 *);
	long int (*free_cached_objects)(struct super_block___252 *, struct shrink_control___117 *);
	struct file___252 * (*real_loop)(struct file___252 *);
};

struct seq_operations___227;

struct seq_file___227 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___227 *op;
	int poll_event;
	const struct file___252 *file;
	void *private;
};

struct dev_pagemap_ops___247 {
	void (*page_free)(struct page___257 *);
	void (*kill)(struct dev_pagemap___247 *);
	void (*cleanup)(struct dev_pagemap___247 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___247 *);
};

struct fwnode_operations___229;

struct fwnode_handle___229 {
	struct fwnode_handle___229 *secondary;
	const struct fwnode_operations___229 *ops;
	struct device___233 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___229;

struct fwnode_endpoint___229;

struct fwnode_operations___229 {
	struct fwnode_handle___229 * (*get)(struct fwnode_handle___229 *);
	void (*put)(struct fwnode_handle___229 *);
	bool (*device_is_available)(const struct fwnode_handle___229 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___229 *, const struct device___233 *);
	bool (*property_present)(const struct fwnode_handle___229 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___229 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___229 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___229 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*get_parent)(const struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*get_next_child_node)(const struct fwnode_handle___229 *, struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*get_named_child_node)(const struct fwnode_handle___229 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___229 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___229 *);
	struct fwnode_handle___229 * (*graph_get_next_endpoint)(const struct fwnode_handle___229 *, struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*graph_get_remote_endpoint)(const struct fwnode_handle___229 *);
	struct fwnode_handle___229 * (*graph_get_port_parent)(struct fwnode_handle___229 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___229 *, struct fwnode_endpoint___229 *);
	int (*add_links)(struct fwnode_handle___229 *);
};

struct fwnode_endpoint___229 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___229 *local_fwnode;
};

struct fwnode_reference_args___229 {
	struct fwnode_handle___229 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___240;

struct kernfs_elem_dir___240 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___240 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___240;

struct kernfs_root___240 {
	struct kernfs_node___240 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___240 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___240 {
	struct kernfs_node___240 *target_kn;
};

struct kernfs_ops___240;

struct kernfs_elem_attr___240 {
	const struct kernfs_ops___240 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___240 *notify_next;
};

struct kernfs_node___240 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___240 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___240 dir;
		struct kernfs_elem_symlink___240 symlink;
		struct kernfs_elem_attr___240 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___240;

struct kernfs_ops___240 {
	int (*open)(struct kernfs_open_file___240 *);
	void (*release)(struct kernfs_open_file___240 *);
	int (*seq_show)(struct seq_file___227 *, void *);
	void * (*seq_start)(struct seq_file___227 *, loff_t *);
	void * (*seq_next)(struct seq_file___227 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___227 *, void *);
	ssize_t (*read)(struct kernfs_open_file___240 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___240 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___240 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___240 *, struct vm_area_struct___257 *);
};

struct kernfs_syscall_ops___240 {
	int (*show_options)(struct seq_file___227 *, struct kernfs_root___240 *);
	int (*mkdir)(struct kernfs_node___240 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___240 *);
	int (*rename)(struct kernfs_node___240 *, struct kernfs_node___240 *, const char *);
	int (*show_path)(struct seq_file___227 *, struct kernfs_node___240 *, struct kernfs_root___240 *);
};

struct kernfs_open_file___240 {
	struct kernfs_node___240 *kn;
	struct file___252 *file;
	struct seq_file___227 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___247 *vm_ops;
};

struct bin_attribute___240;

struct attribute_group___240 {
	const char *name;
	umode_t (*is_visible)(struct kobject___240 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___240 *, struct bin_attribute___240 *, int);
	struct attribute **attrs;
	struct bin_attribute___240 **bin_attrs;
};

struct bin_attribute___240 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___252 * (*f_mapping)();
	ssize_t (*read)(struct file___252 *, struct kobject___240 *, struct bin_attribute___240 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___252 *, struct kobject___240 *, struct bin_attribute___240 *, char *, loff_t, size_t);
	int (*mmap)(struct file___252 *, struct kobject___240 *, struct bin_attribute___240 *, struct vm_area_struct___257 *);
};

struct sysfs_ops___240 {
	ssize_t (*show)(struct kobject___240 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___240 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___240;

struct kset___240 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___240 kobj;
	const struct kset_uevent_ops___240 *uevent_ops;
};

struct kobj_type___240 {
	void (*release)(struct kobject___240 *);
	const struct sysfs_ops___240 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___240 **default_groups;
	const struct kobj_ns_type_operations___48 * (*child_ns_type)(struct kobject___240 *);
	const void * (*namespace)(struct kobject___240 *);
	void (*get_ownership)(struct kobject___240 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___240 {
	int (* const filter)(struct kset___240 *, struct kobject___240 *);
	const char * (* const name)(struct kset___240 *, struct kobject___240 *);
	int (* const uevent)(struct kset___240 *, struct kobject___240 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___236 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___236 *);
	int (*get)(char *, const struct kernel_param___236 *);
	void (*free)(void *);
};

struct kparam_array___236;

struct kernel_param___236 {
	const char *name;
	struct module___236 *mod;
	const struct kernel_param_ops___236 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___236 *arr;
	};
};

struct kparam_array___236 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___236 *ops;
	void *elem;
};

struct module_attribute___236 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___236 *, struct module_kobject___237 *, char *);
	ssize_t (*store)(struct module_attribute___236 *, struct module_kobject___237 *, const char *, size_t);
	void (*setup)(struct module___236 *, const char *);
	int (*test)(struct module___236 *);
	void (*free)(struct module___236 *);
};

struct cgroup_namespace___179 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___179 *root_cset;
};

struct dev_pm_ops___233 {
	int (*prepare)(struct device___233 *);
	void (*complete)(struct device___233 *);
	int (*suspend)(struct device___233 *);
	int (*resume)(struct device___233 *);
	int (*freeze)(struct device___233 *);
	int (*thaw)(struct device___233 *);
	int (*poweroff)(struct device___233 *);
	int (*restore)(struct device___233 *);
	int (*suspend_late)(struct device___233 *);
	int (*resume_early)(struct device___233 *);
	int (*freeze_late)(struct device___233 *);
	int (*thaw_early)(struct device___233 *);
	int (*poweroff_late)(struct device___233 *);
	int (*restore_early)(struct device___233 *);
	int (*suspend_noirq)(struct device___233 *);
	int (*resume_noirq)(struct device___233 *);
	int (*freeze_noirq)(struct device___233 *);
	int (*thaw_noirq)(struct device___233 *);
	int (*poweroff_noirq)(struct device___233 *);
	int (*restore_noirq)(struct device___233 *);
	int (*runtime_suspend)(struct device___233 *);
	int (*runtime_resume)(struct device___233 *);
	int (*runtime_idle)(struct device___233 *);
};

struct wakeup_source___233 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___233 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___233 {
	struct dev_pm_ops___233 ops;
	int (*start)(struct device___233 *);
	void (*detach)(struct device___233 *, bool);
	int (*activate)(struct device___233 *);
	void (*sync)(struct device___233 *);
	void (*dismiss)(struct device___233 *);
};

struct bus_type___233 {
	const char *name;
	const char *dev_name;
	struct device___233 *dev_root;
	const struct attribute_group___240 **bus_groups;
	const struct attribute_group___240 **dev_groups;
	const struct attribute_group___240 **drv_groups;
	int (*match)(struct device___233 *, struct device_driver___233 *);
	int (*uevent)(struct device___233 *, struct kobj_uevent_env *);
	int (*probe)(struct device___233 *);
	void (*sync_state)(struct device___233 *);
	void (*remove)(struct device___233 *);
	void (*shutdown)(struct device___233 *);
	int (*online)(struct device___233 *);
	int (*offline)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	int (*num_vf)(struct device___233 *);
	int (*dma_configure)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___233 {
	const char *name;
	struct bus_type___233 *bus;
	struct module___236 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___233 *);
	void (*sync_state)(struct device___233 *);
	int (*remove)(struct device___233 *);
	void (*shutdown)(struct device___233 *);
	int (*suspend)(struct device___233 *, pm_message_t);
	int (*resume)(struct device___233 *);
	const struct attribute_group___240 **groups;
	const struct attribute_group___240 **dev_groups;
	const struct dev_pm_ops___233 *pm;
	void (*coredump)(struct device___233 *);
	struct driver_private *p;
};

struct device_type___233 {
	const char *name;
	const struct attribute_group___240 **groups;
	int (*uevent)(struct device___233 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___233 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___233 *);
	const struct dev_pm_ops___233 *pm;
};

struct class___233 {
	const char *name;
	struct module___236 *owner;
	const struct attribute_group___240 **class_groups;
	const struct attribute_group___240 **dev_groups;
	struct kobject___240 *dev_kobj;
	int (*dev_uevent)(struct device___233 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___233 *, umode_t *);
	void (*class_release)(struct class___233 *);
	void (*dev_release)(struct device___233 *);
	int (*shutdown_pre)(struct device___233 *);
	const struct kobj_ns_type_operations___48 *ns_type;
	const void * (*namespace)(struct device___233 *);
	void (*get_ownership)(struct device___233 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___233 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___93;

struct pipe_buffer___93 {
	struct page___257 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___93 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___93 {
	int (*confirm)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
	void (*release)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
	bool (*try_steal)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
	bool (*get)(struct pipe_inode_info___93 *, struct pipe_buffer___93 *);
};

struct seq_operations___227 {
	void * (*start)(struct seq_file___227 *, loff_t *);
	void (*stop)(struct seq_file___227 *, void *);
	void * (*next)(struct seq_file___227 *, void *, loff_t *);
	int (*show)(struct seq_file___227 *, void *);
};

struct dcbnl_rtnl_ops___61 {
	int (*ieee_getets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___61 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___61 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___61 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___61 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___61 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___61 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___61 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___61 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___61 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___61 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___61 *);
	u8 (*setstate)(struct net_device___61 *, u8);
	void (*getpermhwaddr)(struct net_device___61 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___61 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___61 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___61 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___61 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___61 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___61 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___61 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___61 *, int, u8 *);
	void (*setpfccfg)(struct net_device___61 *, int, u8);
	void (*getpfccfg)(struct net_device___61 *, int, u8 *);
	u8 (*setall)(struct net_device___61 *);
	u8 (*getcap)(struct net_device___61 *, int, u8 *);
	int (*getnumtcs)(struct net_device___61 *, int, u8 *);
	int (*setnumtcs)(struct net_device___61 *, int, u8);
	u8 (*getpfcstate)(struct net_device___61 *);
	void (*setpfcstate)(struct net_device___61 *, u8);
	void (*getbcncfg)(struct net_device___61 *, int, u32 *);
	void (*setbcncfg)(struct net_device___61 *, int, u32);
	void (*getbcnrp)(struct net_device___61 *, int, u8 *);
	void (*setbcnrp)(struct net_device___61 *, int, u8);
	int (*setapp)(struct net_device___61 *, u8, u16, u8);
	int (*getapp)(struct net_device___61 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___61 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___61 *, int, u8);
	u8 (*getdcbx)(struct net_device___61 *);
	u8 (*setdcbx)(struct net_device___61 *, u8);
	int (*peer_getappinfo)(struct net_device___61 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___61 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___61 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___61 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___61 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___61 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___64;

typedef int (*bpf_iter_init_seq_priv_t___63)(void *, struct bpf_iter_aux_info___64 *);

struct bpf_map___64;

struct bpf_iter_aux_info___64 {
	struct bpf_map___64 *map;
};

struct bpf_iter_seq_info___63 {
	const struct seq_operations___227 *seq_ops;
	bpf_iter_init_seq_priv_t___63 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___64;

struct bpf_map_ops___63 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___64 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___64 *, struct file___252 *);
	void (*map_free)(struct bpf_map___64 *);
	int (*map_get_next_key)(struct bpf_map___64 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___64 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___64 *, void *);
	int (*map_lookup_batch)(struct bpf_map___64 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___64 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___64 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___64 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___64 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___64 *, void *);
	int (*map_update_elem)(struct bpf_map___64 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___64 *, void *);
	int (*map_push_elem)(struct bpf_map___64 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___64 *, void *);
	int (*map_peek_elem)(struct bpf_map___64 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___64 *, struct file___252 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___64 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___64 *, void *, struct seq_file___227 *);
	int (*map_check_btf)(const struct bpf_map___64 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___64 *, struct bpf_prog_aux___64 *);
	void (*map_poke_untrack)(struct bpf_map___64 *, struct bpf_prog_aux___64 *);
	void (*map_poke_run)(struct bpf_map___64 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___64 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___64 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___64 *, struct vm_area_struct___257 *);
	__poll_t (*map_poll)(struct bpf_map___64 *, struct file___252 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___64 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___64 *, const struct bpf_map___64 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___64 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___63 *iter_seq_info;
};

struct bpf_map___64 {
	const struct bpf_map_ops___63 *ops;
	struct bpf_map___64 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___63;

struct bpf_jit_poke_descriptor___63;

struct btf_mod_pair___63;

struct bpf_prog_offload___61;

struct bpf_prog_aux___64 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___63 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___63 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___55 *ops;
	struct bpf_map___64 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___63 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___64 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___61 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___61;

struct bpf_map_dev_ops___61 {
	int (*map_get_next_key)(struct bpf_offloaded_map___61 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___61 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___61 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___61 *, void *);
};

struct bpf_offloaded_map___61 {
	struct bpf_map___64 map;
	struct net_device___61 *netdev;
	const struct bpf_map_dev_ops___61 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___61 {
	struct bpf_prog *prog;
	struct net_device___61 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___63 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___236 *mod;
};

struct bpf_jit_poke_descriptor___63 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___64 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___63 {
	struct btf *btf;
	struct module___236 *module;
};

struct cftype___179;

struct cgroup_subsys___179 {
	struct cgroup_subsys_state___179 * (*css_alloc)(struct cgroup_subsys_state___179 *);
	int (*css_online)(struct cgroup_subsys_state___179 *);
	void (*css_offline)(struct cgroup_subsys_state___179 *);
	void (*css_released)(struct cgroup_subsys_state___179 *);
	void (*css_free)(struct cgroup_subsys_state___179 *);
	void (*css_reset)(struct cgroup_subsys_state___179 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___179 *, int);
	int (*css_extra_stat_show)(struct seq_file___227 *, struct cgroup_subsys_state___179 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___259 *, struct css_set___179 *);
	void (*cancel_fork)(struct task_struct___259 *, struct css_set___179 *);
	void (*fork)(struct task_struct___259 *);
	void (*exit)(struct task_struct___259 *);
	void (*release)(struct task_struct___259 *);
	void (*bind)(struct cgroup_subsys_state___179 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___179 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___179 *dfl_cftypes;
	struct cftype___179 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___179 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___179 *updated_children;
	struct cgroup___179 *updated_next;
};

struct cgroup_root___179 {
	struct kernfs_root___240 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___179 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___179 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___179 *ss;
	struct list_head node;
	struct kernfs_ops___240 *kf_ops;
	int (*open)(struct kernfs_open_file___240 *);
	void (*release)(struct kernfs_open_file___240 *);
	u64 (*read_u64)(struct cgroup_subsys_state___179 *, struct cftype___179 *);
	s64 (*read_s64)(struct cgroup_subsys_state___179 *, struct cftype___179 *);
	int (*seq_show)(struct seq_file___227 *, void *);
	void * (*seq_start)(struct seq_file___227 *, loff_t *);
	void * (*seq_next)(struct seq_file___227 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___227 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___179 *, struct cftype___179 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___179 *, struct cftype___179 *, s64);
	ssize_t (*write)(struct kernfs_open_file___240 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___240 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___61 {
	struct net_device___61 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___61 {
	struct net_device___61 *dev;
};

struct xdp_buff___61 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___61 *rxq;
	struct xdp_txq_info___61 *txq;
	u32 frame_sz;
};

struct xdp_frame___61 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___61 *dev_rx;
};

struct netlink_callback___61 {
	struct sk_buff___62 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___62 *, struct netlink_callback___61 *);
	int (*done)(struct netlink_callback___61 *);
	void *data;
	struct module___236 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___61 {
	int (*create)(struct sk_buff___62 *, struct net_device___61 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___62 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___61 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___62 *);
};

struct napi_struct___14 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___14 *, int);
	int poll_owner;
	struct net_device___61 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___62 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___259 *thread;
};

struct netdev_queue___61 {
	struct net_device___61 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___240 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___61 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___61 {
	struct xdp_rxq_info___61 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___240 kobj;
	struct net_device___61 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___61 {
	enum net_device_path_type type;
	const struct net_device___61 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___61 = 0,
				DEV_PATH_BR_VLAN_TAG___61 = 1,
				DEV_PATH_BR_VLAN_UNTAG___61 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___61 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___61 {
	const struct net_device___61 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___61 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___55 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___61 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___61 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___62 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___61 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___61 *dev;
	const char *name;
};

struct devlink_port___5;

struct net_device_ops___61 {
	int (*ndo_init)(struct net_device___61 *);
	void (*ndo_uninit)(struct net_device___61 *);
	int (*ndo_open)(struct net_device___61 *);
	int (*ndo_stop)(struct net_device___61 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___62 *, struct net_device___61 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___62 *, struct net_device___61 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___61 *, struct sk_buff___62 *, struct net_device___61 *);
	void (*ndo_change_rx_flags)(struct net_device___61 *, int);
	void (*ndo_set_rx_mode)(struct net_device___61 *);
	int (*ndo_set_mac_address)(struct net_device___61 *, void *);
	int (*ndo_validate_addr)(struct net_device___61 *);
	int (*ndo_do_ioctl)(struct net_device___61 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___61 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___61 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___61 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___61 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___61 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___61 *, int);
	int (*ndo_neigh_setup)(struct net_device___61 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___61 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___61 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___61 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___61 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___61 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___61 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___61 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___61 *);
	int (*ndo_netpoll_setup)(struct net_device___61 *, struct netpoll_info___4 *);
	void (*ndo_netpoll_cleanup)(struct net_device___61 *);
	int (*ndo_set_vf_mac)(struct net_device___61 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___61 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___61 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___61 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___61 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___61 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___61 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___61 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___61 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___61 *, int, struct sk_buff___62 *);
	int (*ndo_get_vf_guid)(struct net_device___61 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___61 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___61 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___61 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___61 *);
	int (*ndo_fcoe_disable)(struct net_device___61 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___61 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___61 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___61 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___61 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___61 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___61 *, const struct sk_buff___62 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___61 *, struct net_device___61 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___61 *, struct net_device___61 *);
	struct net_device___61 * (*ndo_get_xmit_slave)(struct net_device___61 *, struct sk_buff___62 *, bool);
	struct net_device___61 * (*ndo_sk_get_lower_dev)(struct net_device___61 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___61 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___61 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___61 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___61 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___62 *, struct netlink_callback___61 *, struct net_device___61 *, struct net_device___61 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___62 *, struct nlattr **, struct net_device___61 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___61 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___62 *, u32, u32, struct net_device___61 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___61 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___61 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___61 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___61 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___61 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___61 *, struct net_device___61 *);
	void (*ndo_dfwd_del_station)(struct net_device___61 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___61 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___61 *);
	int (*ndo_change_proto_down)(struct net_device___61 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___61 *, struct sk_buff___62 *);
	void (*ndo_set_rx_headroom)(struct net_device___61 *, int);
	int (*ndo_bpf)(struct net_device___61 *, struct netdev_bpf___61 *);
	int (*ndo_xdp_xmit)(struct net_device___61 *, int, struct xdp_frame___61 **, u32);
	struct net_device___61 * (*ndo_xdp_get_xmit_slave)(struct net_device___61 *, struct xdp_buff___61 *);
	int (*ndo_xsk_wakeup)(struct net_device___61 *, u32, u32);
	struct devlink_port___5 * (*ndo_get_devlink_port)(struct net_device___61 *);
	int (*ndo_tunnel_ctl)(struct net_device___61 *, struct ip_tunnel_parm *, int);
	struct net_device___61 * (*ndo_get_peer_dev)(struct net_device___61 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___61 *, struct net_device_path___61 *);
};

struct netpoll___4;

struct netpoll_info___4 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___61 txq;
	struct delayed_work tx_work;
	struct netpoll___4 *netpoll;
	struct callback_head rcu;
};

struct devlink___5;

struct devlink_rate___5;

struct devlink_port___5 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___5 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set;
	u8 switch_port;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___5 *devlink_rate;
};

struct in_ifaddr___6;

struct in_device___6 {
	struct net_device___61 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___6 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___2 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct netdev_notifier_info___10 {
	struct net_device___61 *dev;
	struct netlink_ext_ack *extack;
};

struct in_ifaddr___6 {
	struct hlist_node hash;
	struct in_ifaddr___6 *ifa_next;
	struct in_device___6 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct netpoll___4 {
	struct net_device___61 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
};

struct net_dm_drop_point {
	__u8 pc[8];
	__u32 count;
};

struct net_dm_alert_msg {
	__u32 entries;
	struct net_dm_drop_point points[0];
};

enum {
	NET_DM_CMD_UNSPEC = 0,
	NET_DM_CMD_ALERT = 1,
	NET_DM_CMD_CONFIG = 2,
	NET_DM_CMD_START = 3,
	NET_DM_CMD_STOP = 4,
	NET_DM_CMD_PACKET_ALERT = 5,
	NET_DM_CMD_CONFIG_GET = 6,
	NET_DM_CMD_CONFIG_NEW = 7,
	NET_DM_CMD_STATS_GET = 8,
	NET_DM_CMD_STATS_NEW = 9,
	_NET_DM_CMD_MAX = 10,
};

enum net_dm_attr {
	NET_DM_ATTR_UNSPEC = 0,
	NET_DM_ATTR_ALERT_MODE = 1,
	NET_DM_ATTR_PC = 2,
	NET_DM_ATTR_SYMBOL = 3,
	NET_DM_ATTR_IN_PORT = 4,
	NET_DM_ATTR_TIMESTAMP = 5,
	NET_DM_ATTR_PROTO = 6,
	NET_DM_ATTR_PAYLOAD = 7,
	NET_DM_ATTR_PAD = 8,
	NET_DM_ATTR_TRUNC_LEN = 9,
	NET_DM_ATTR_ORIG_LEN = 10,
	NET_DM_ATTR_QUEUE_LEN = 11,
	NET_DM_ATTR_STATS = 12,
	NET_DM_ATTR_HW_STATS = 13,
	NET_DM_ATTR_ORIGIN = 14,
	NET_DM_ATTR_HW_TRAP_GROUP_NAME = 15,
	NET_DM_ATTR_HW_TRAP_NAME = 16,
	NET_DM_ATTR_HW_ENTRIES = 17,
	NET_DM_ATTR_HW_ENTRY = 18,
	NET_DM_ATTR_HW_TRAP_COUNT = 19,
	NET_DM_ATTR_SW_DROPS = 20,
	NET_DM_ATTR_HW_DROPS = 21,
	NET_DM_ATTR_FLOW_ACTION_COOKIE = 22,
	__NET_DM_ATTR_MAX = 23,
	NET_DM_ATTR_MAX = 22,
};

enum net_dm_alert_mode {
	NET_DM_ALERT_MODE_SUMMARY = 0,
	NET_DM_ALERT_MODE_PACKET = 1,
};

enum {
	NET_DM_ATTR_PORT_NETDEV_IFINDEX = 0,
	NET_DM_ATTR_PORT_NETDEV_NAME = 1,
	__NET_DM_ATTR_PORT_MAX = 2,
	NET_DM_ATTR_PORT_MAX = 1,
};

enum {
	NET_DM_ATTR_STATS_DROPPED = 0,
	__NET_DM_ATTR_STATS_MAX = 1,
	NET_DM_ATTR_STATS_MAX = 0,
};

enum net_dm_origin {
	NET_DM_ORIGIN_SW = 0,
	NET_DM_ORIGIN_HW = 1,
};

struct genl_ops___3;

struct genl_info___2;

struct genl_small_ops___3;

struct genl_family___3 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___3 *, struct sk_buff___62 *, struct genl_info___2 *);
	void (*post_doit)(const struct genl_ops___3 *, struct sk_buff___62 *, struct genl_info___2 *);
	const struct genl_ops___3 *ops;
	const struct genl_small_ops___3 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___236 *module;
};

struct genl_ops___3 {
	int (*doit)(struct sk_buff___62 *, struct genl_info___2 *);
	int (*start)(struct netlink_callback___61 *);
	int (*dumpit)(struct sk_buff___62 *, struct netlink_callback___61 *);
	int (*done)(struct netlink_callback___61 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___2 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___61 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___3 {
	int (*doit)(struct sk_buff___62 *, struct genl_info___2 *);
	int (*dumpit)(struct sk_buff___62 *, struct netlink_callback___61 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct devlink_ops___5;

struct devlink___5 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___5 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___233 *dev;
	possible_net_t___61 _net;
	struct mutex lock;
	u8 reload_failed;
	u8 reload_enabled;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_ops___5 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___5 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___5 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___5 *, enum devlink_port_type);
	int (*port_split)(struct devlink___5 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___5 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___5 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___5 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___5 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___5 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___5 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___5 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___5 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___5 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___5 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___5 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___5 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___5 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___5 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___5 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___5 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___5 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___5 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___5 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___5 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___5 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___5 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___5 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___5 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___5 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___5 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___5 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___5 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___5 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___5 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___5 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___5 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___5 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___5 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___5 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___5 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___5 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___5 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___5 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___5 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___5 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___5 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___5 *, struct devlink_rate___5 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___5 *, struct devlink_rate___5 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___5 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___5 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___5 *parent;
	union {
		struct devlink_port___5 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct devlink_trap_metadata {
	const char *trap_name;
	const char *trap_group_name;
	struct net_device___61 *input_dev;
	const struct flow_action_cookie *fa_cookie;
	enum devlink_trap_type trap_type;
};

struct net_dm_stats {
	u64 dropped;
	struct u64_stats_sync syncp;
};

struct net_dm_hw_entry {
	char trap_name[40];
	u32 count;
};

struct net_dm_hw_entries {
	u32 num_entries;
	struct net_dm_hw_entry entries[0];
};

struct per_cpu_dm_data {
	spinlock_t lock;
	union {
		struct sk_buff___62 *skb;
		struct net_dm_hw_entries *hw_entries;
	};
	struct sk_buff_head___61 drop_queue;
	struct work_struct dm_alert_work;
	struct timer_list send_timer;
	struct net_dm_stats stats;
};

struct dm_hw_stat_delta {
	struct net_device___61 *dev;
	long unsigned int last_rx;
	struct list_head list;
	struct callback_head rcu;
	long unsigned int last_drop_val;
};

struct net_dm_alert_ops {
	void (*kfree_skb_probe)(void *, struct sk_buff___62 *, void *);
	void (*napi_poll_probe)(void *, struct napi_struct___14 *, int, int);
	void (*work_item_func)(struct work_struct *);
	void (*hw_work_item_func)(struct work_struct *);
	void (*hw_trap_probe)(void *, const struct devlink___5 *, struct sk_buff___62 *, const struct devlink_trap_metadata *);
};

struct net_dm_skb_cb {
	union {
		struct devlink_trap_metadata *hw_metadata;
		void *pc;
	};
};

struct dentry___253;

struct super_block___253;

struct module___237;

struct file_system_type___253 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___253 * (*mount)(struct file_system_type___253 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___253 *);
	struct module___237 *owner;
	struct file_system_type___253 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___253;

struct kiocb___253;

struct iov_iter___173;

struct poll_table_struct___174;

struct vm_area_struct___258;

struct inode___253;

struct file_lock___253;

struct page___258;

struct pipe_inode_info___94;

struct seq_file___228;

struct file_operations___254 {
	struct module___237 *owner;
	loff_t (*llseek)(struct file___253 *, loff_t, int);
	ssize_t (*read)(struct file___253 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___253 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___253 *, struct iov_iter___173 *);
	ssize_t (*write_iter)(struct kiocb___253 *, struct iov_iter___173 *);
	int (*iopoll)(struct kiocb___253 *, bool);
	int (*iterate)(struct file___253 *, struct dir_context *);
	int (*iterate_shared)(struct file___253 *, struct dir_context *);
	__poll_t (*poll)(struct file___253 *, struct poll_table_struct___174 *);
	long int (*unlocked_ioctl)(struct file___253 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___253 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___253 *, struct vm_area_struct___258 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___253 *, struct file___253 *);
	int (*flush)(struct file___253 *, fl_owner_t);
	int (*release)(struct inode___253 *, struct file___253 *);
	int (*fsync)(struct file___253 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___253 *, int);
	int (*lock)(struct file___253 *, int, struct file_lock___253 *);
	ssize_t (*sendpage)(struct file___253 *, struct page___258 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___253 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___253 *, long unsigned int);
	int (*flock)(struct file___253 *, int, struct file_lock___253 *);
	ssize_t (*splice_write)(struct pipe_inode_info___94 *, struct file___253 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___253 *, loff_t *, struct pipe_inode_info___94 *, size_t, unsigned int);
	int (*setlease)(struct file___253 *, long int, struct file_lock___253 **, void **);
	long int (*fallocate)(struct file___253 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___228 *, struct file___253 *);
	ssize_t (*copy_file_range)(struct file___253 *, loff_t, struct file___253 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___253 *, loff_t, struct file___253 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___253 *, loff_t, loff_t, int);
};

struct vmacache___258 {
	u64 seqnum;
	struct vm_area_struct___258 *vmas[4];
};

struct page_frag___258 {
	struct page___258 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___259;

struct pid___230;

struct nsproxy___239;

struct signal_struct___254;

struct bio_list___144;

struct backing_dev_info___130;

struct io_context___144;

struct css_set___180;

struct mem_cgroup___118;

struct request_queue___144;

struct vm_struct___236;

struct task_struct___260 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___260 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___259 *mm;
	struct mm_struct___259 *active_mm;
	struct vmacache___258 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___260 *real_parent;
	struct task_struct___260 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___260 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___230 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___239 *nsproxy;
	struct signal_struct___254 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___260 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___144 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___130 *backing_dev_info;
	struct io_context___144 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___180 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___94 *splice_pipe;
	struct page_frag___258 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___118 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___118 *active_memcg;
	struct request_queue___144 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___260 *oom_reaper_list;
	struct vm_struct___236 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___241;

struct kobj_type___241;

struct kernfs_node___241;

struct kobject___241 {
	const char *name;
	struct list_head entry;
	struct kobject___241 *parent;
	struct kset___241 *kset;
	struct kobj_type___241 *ktype;
	struct kernfs_node___241 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___238 {
	struct kobject___241 kobj;
	struct module___237 *mod;
	struct kobject___241 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___237 {
	struct module___237 *mod;
	struct latch_tree_node node;
};

struct module_layout___237 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___237 mtn;
};

struct module_attribute___237;

struct kernel_param___237;

struct module___237 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___238 mkobj;
	struct module_attribute___237 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___241 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___237 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___237 core_layout;
	struct module_layout___237 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___230;

struct upid___230 {
	int nr;
	struct pid_namespace___230 *ns;
};

struct pid_namespace___230 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___260 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___230 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___230 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___230 numbers[1];
};

typedef struct page___258 *pgtable_t___258;

struct address_space___253;

struct page_pool___82;

struct dev_pagemap___248;

struct page___258 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___253 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___82 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___258 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___258 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___259 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___248 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___248;

struct vm_area_struct___258 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___258 *vm_next;
	struct vm_area_struct___258 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___259 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___248 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___253 *vm_file;
	struct file___253 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___254 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___260 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___260 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___230 *pids[4];
	struct pid___230 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___259 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___258;

struct mm_struct___259 {
	struct {
		struct vm_area_struct___258 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___253 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___258 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___260 *owner;
		struct user_namespace___26 *user_ns;
		struct file___253 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___67;

struct cgroup_namespace___180;

struct nsproxy___239 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___230 *pid_ns_for_children;
	struct net___67 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___180 *cgroup_ns;
};

struct bio___144;

struct bio_list___144 {
	struct bio___144 *head;
	struct bio___144 *tail;
};

struct cgroup_subsys_state___180;

struct bdi_writeback___130 {
	struct backing_dev_info___130 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___180 *memcg_css;
	struct cgroup_subsys_state___180 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___234;

struct backing_dev_info___130 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___130 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___234 *dev;
	char dev_name[64];
	struct device___234 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___253 *debug_dir;
};

struct io_cq___144;

struct io_context___144 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___144 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___180;

struct css_set___180 {
	struct cgroup_subsys_state___180 *subsys[14];
	refcount_t refcount;
	struct css_set___180 *dom_cset;
	struct cgroup___180 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___180 *mg_src_cgrp;
	struct cgroup___180 *mg_dst_cgrp;
	struct css_set___180 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___253;

struct pipe_buffer___94;

struct pipe_inode_info___94 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___258 *tmp_page;
	struct fasync_struct___253 *fasync_readers;
	struct fasync_struct___253 *fasync_writers;
	struct pipe_buffer___94 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___180;

struct cgroup_subsys_state___180 {
	struct cgroup___180 *cgroup;
	struct cgroup_subsys___180 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___180 *parent;
};

struct cgroup_file___180 {
	struct kernfs_node___241 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___118;

struct mem_cgroup_per_node___118;

struct mem_cgroup___118 {
	struct cgroup_subsys_state___180 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___180 events_file;
	struct cgroup_file___180 events_local_file;
	struct cgroup_file___180 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___118 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___260 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___118 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___144;

struct blk_integrity___144 {
	const struct blk_integrity_profile___144 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___144 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___144 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___144;

struct elevator_queue___144;

struct blk_mq_ops___139;

struct blk_mq_hw_ctx___139;

struct gendisk___147;

struct blkcg_gq___132;

struct blk_mq_tag_set___139;

struct request_queue___144 {
	struct request___144 *last_merge;
	struct elevator_queue___144 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___139 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___139 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___147 *disk;
	struct kobject___241 kobj;
	struct kobject___241 *mq_kobj;
	struct blk_integrity___144 integrity;
	struct device___234 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___132 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___139 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___144 bio_split;
	struct dentry___253 *debugfs_dir;
	struct dentry___253 *sched_debugfs_dir;
	struct dentry___253 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___236 {
	struct vm_struct___236 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___258 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___170 {
	struct page___258 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___173 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___170 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___94 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___51 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___173 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___253 *msg_iocb;
};

struct kiocb___253 {
	struct file___253 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___253 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct dentry_operations___253;

struct dentry___253 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___253 *d_parent;
	struct qstr d_name;
	struct inode___253 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___253 *d_op;
	struct super_block___253 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___253;

struct address_space___253 {
	struct inode___253 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___253 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___253;

struct inode___253 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___253 *i_op;
	struct super_block___253 *i_sb;
	struct address_space___253 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___130 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___254 *i_fop;
		void (*free_inode)(struct inode___253 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___253 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___94 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___253;

struct path___253;

struct dentry_operations___253 {
	int (*d_revalidate)(struct dentry___253 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___253 *, unsigned int);
	int (*d_hash)(const struct dentry___253 *, struct qstr *);
	int (*d_compare)(const struct dentry___253 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___253 *);
	int (*d_init)(struct dentry___253 *);
	void (*d_release)(struct dentry___253 *);
	void (*d_prune)(struct dentry___253 *);
	void (*d_iput)(struct dentry___253 *, struct inode___253 *);
	char * (*d_dname)(struct dentry___253 *, char *, int);
	struct vfsmount___253 * (*d_automount)(struct path___253 *);
	int (*d_manage)(const struct path___253 *, bool);
	struct dentry___253 * (*d_real)(struct dentry___253 *, const struct inode___253 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___253;

struct mem_dqinfo___253 {
	struct quota_format_type___253 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___253;

struct quota_info___253 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___253 *files[3];
	struct mem_dqinfo___253 info[3];
	const struct quota_format_ops___253 *ops[3];
};

struct rcuwait___254 {
	struct task_struct___260 *task;
};

struct percpu_rw_semaphore___254 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___254 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___253 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___254 rw_sem[3];
};

struct shrink_control___118;

struct shrinker___118 {
	long unsigned int (*count_objects)(struct shrinker___118 *, struct shrink_control___118 *);
	long unsigned int (*scan_objects)(struct shrinker___118 *, struct shrink_control___118 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___253;

struct dquot_operations___253;

struct quotactl_ops___253;

struct block_device___147;

struct super_block___253 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___253 *s_type;
	const struct super_operations___253 *s_op;
	const struct dquot_operations___253 *dq_op;
	const struct quotactl_ops___253 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___253 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___147 *s_bdev;
	struct backing_dev_info___130 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___253 s_dquot;
	struct sb_writers___253 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___253 *s_d_op;
	int cleancache_poolid;
	struct shrinker___118 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___253 {
	struct dentry___253 *mnt_root;
	struct super_block___253 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___253 {
	struct vfsmount___253 *mnt;
	struct dentry___253 *dentry;
};

struct shrink_control___118 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___118 *memcg;
};

struct page_pool_params___82 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___234 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___82 {
	u32 count;
	struct page___258 *cache[128];
};

struct page_pool___82 {
	struct page_pool_params___82 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___258 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___82 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___248;

struct dev_pagemap___248 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___248 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___230 {
	rwlock_t lock;
	struct pid___230 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___253 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___253 f_path;
	struct inode___253 *f_inode;
	const struct file_operations___254 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___230 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___253 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___248;

struct vm_operations_struct___248 {
	void (*open)(struct vm_area_struct___258 *);
	void (*close)(struct vm_area_struct___258 *);
	int (*may_split)(struct vm_area_struct___258 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___258 *);
	int (*mprotect)(struct vm_area_struct___258 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___248 *);
	vm_fault_t (*huge_fault)(struct vm_fault___248 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___248 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___258 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___248 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___248 *);
	int (*access)(struct vm_area_struct___258 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___258 *);
	int (*set_policy)(struct vm_area_struct___258 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___258 *, long unsigned int);
	struct page___258 * (*find_special_page)(struct vm_area_struct___258 *, long unsigned int);
};

struct core_thread___258 {
	struct task_struct___260 *task;
	struct core_thread___258 *next;
};

struct core_state___258 {
	atomic_t nr_threads;
	struct core_thread___258 dumper;
	struct completion startup;
};

struct vm_fault___248 {
	const struct {
		struct vm_area_struct___258 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___258 *cow_page;
	struct page___258 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___258 prealloc_pte;
};

struct pglist_data___126;

struct lruvec___126 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___126 *pgdat;
};

struct zone___126 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___126 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___126 {
	struct zone___126 *zone;
	int zone_idx;
};

struct zonelist___126 {
	struct zoneref___126 _zonerefs[321];
};

struct pglist_data___126 {
	struct zone___126 node_zones[5];
	struct zonelist___126 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___260 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___260 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___126 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___180 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___260 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___56;

struct cgroup_bpf___56 {
	struct bpf_prog_array___56 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___56 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___180;

struct cgroup_rstat_cpu___180;

struct cgroup___180 {
	struct cgroup_subsys_state___180 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___241 *kn;
	struct cgroup_file___180 procs_file;
	struct cgroup_file___180 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___180 *subsys[14];
	struct cgroup_root___180 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___180 *dom_cgrp;
	struct cgroup___180 *old_dom_cgrp;
	struct cgroup_rstat_cpu___180 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___180 psi;
	struct cgroup_bpf___56 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___144 {
	struct request_queue___144 *q;
	struct io_context___144 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___253 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___253 *ia_file;
};

struct dquot___253 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___253 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___253 {
	int qf_fmt_id;
	const struct quota_format_ops___253 *qf_ops;
	struct module___237 *qf_owner;
	struct quota_format_type___253 *qf_next;
};

struct quota_format_ops___253 {
	int (*check_quota_file)(struct super_block___253 *, int);
	int (*read_file_info)(struct super_block___253 *, int);
	int (*write_file_info)(struct super_block___253 *, int);
	int (*free_file_info)(struct super_block___253 *, int);
	int (*read_dqblk)(struct dquot___253 *);
	int (*commit_dqblk)(struct dquot___253 *);
	int (*release_dqblk)(struct dquot___253 *);
	int (*get_next_id)(struct super_block___253 *, struct kqid *);
};

struct dquot_operations___253 {
	int (*write_dquot)(struct dquot___253 *);
	struct dquot___253 * (*alloc_dquot)(struct super_block___253 *, int);
	void (*destroy_dquot)(struct dquot___253 *);
	int (*acquire_dquot)(struct dquot___253 *);
	int (*release_dquot)(struct dquot___253 *);
	int (*mark_dirty)(struct dquot___253 *);
	int (*write_info)(struct super_block___253 *, int);
	qsize_t * (*get_reserved_space)(struct inode___253 *);
	int (*get_projid)(struct inode___253 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___253 *, qsize_t *);
	int (*get_next_id)(struct super_block___253 *, struct kqid *);
};

struct quotactl_ops___253 {
	int (*quota_on)(struct super_block___253 *, int, int, const struct path___253 *);
	int (*quota_off)(struct super_block___253 *, int);
	int (*quota_enable)(struct super_block___253 *, unsigned int);
	int (*quota_disable)(struct super_block___253 *, unsigned int);
	int (*quota_sync)(struct super_block___253 *, int);
	int (*set_info)(struct super_block___253 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___253 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___253 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___253 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___253 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___253 *, unsigned int);
};

struct writeback_control___130;

struct address_space_operations___253 {
	int (*writepage)(struct page___258 *, struct writeback_control___130 *);
	int (*readpage)(struct file___253 *, struct page___258 *);
	int (*writepages)(struct address_space___253 *, struct writeback_control___130 *);
	int (*set_page_dirty)(struct page___258 *);
	int (*readpages)(struct file___253 *, struct address_space___253 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___253 *, struct address_space___253 *, loff_t, unsigned int, unsigned int, struct page___258 **, void **);
	int (*write_end)(struct file___253 *, struct address_space___253 *, loff_t, unsigned int, unsigned int, struct page___258 *, void *);
	sector_t (*bmap)(struct address_space___253 *, sector_t);
	void (*invalidatepage)(struct page___258 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___258 *, gfp_t);
	void (*freepage)(struct page___258 *);
	ssize_t (*direct_IO)(struct kiocb___253 *, struct iov_iter___173 *);
	int (*migratepage)(struct address_space___253 *, struct page___258 *, struct page___258 *, enum migrate_mode);
	bool (*isolate_page)(struct page___258 *, isolate_mode_t);
	void (*putback_page)(struct page___258 *);
	int (*launder_page)(struct page___258 *);
	int (*is_partially_uptodate)(struct page___258 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___258 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___253 *, struct page___258 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___253 *, sector_t *);
	void (*swap_deactivate)(struct file___253 *);
};

struct writeback_control___130 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___130 *wb;
	struct inode___253 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___253 {
	struct dentry___253 * (*lookup)(struct inode___253 *, struct dentry___253 *, unsigned int);
	const char * (*get_link)(struct dentry___253 *, struct inode___253 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___253 *, int);
	struct posix_acl * (*get_acl)(struct inode___253 *, int, bool);
	int (*readlink)(struct dentry___253 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___253 *, struct dentry___253 *, umode_t, bool);
	int (*link)(struct dentry___253 *, struct inode___253 *, struct dentry___253 *);
	int (*unlink)(struct inode___253 *, struct dentry___253 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___253 *, struct dentry___253 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___253 *, struct dentry___253 *, umode_t);
	int (*rmdir)(struct inode___253 *, struct dentry___253 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___253 *, struct dentry___253 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___253 *, struct dentry___253 *, struct inode___253 *, struct dentry___253 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___253 *, struct iattr___253 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___253 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___253 *, char *, size_t);
	int (*fiemap)(struct inode___253 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___253 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___253 *, struct dentry___253 *, struct file___253 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___253 *, struct dentry___253 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___253 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___253 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___253 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___253 {
	void (*fl_copy_lock)(struct file_lock___253 *, struct file_lock___253 *);
	void (*fl_release_private)(struct file_lock___253 *);
};

struct lock_manager_operations___253;

struct file_lock___253 {
	struct file_lock___253 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___253 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___253 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___253 *fl_ops;
	const struct lock_manager_operations___253 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___253 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___253 *);
	int (*lm_grant)(struct file_lock___253 *, int);
	bool (*lm_break)(struct file_lock___253 *);
	int (*lm_change)(struct file_lock___253 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___253 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___253 *);
};

struct fasync_struct___253 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___253 *fa_next;
	struct file___253 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___253 {
	struct inode___253 * (*alloc_inode)(struct super_block___253 *);
	void (*destroy_inode)(struct inode___253 *);
	void (*free_inode)(struct inode___253 *);
	void (*dirty_inode)(struct inode___253 *, int);
	int (*write_inode)(struct inode___253 *, struct writeback_control___130 *);
	int (*drop_inode)(struct inode___253 *);
	void (*evict_inode)(struct inode___253 *);
	void (*put_super)(struct super_block___253 *);
	int (*sync_fs)(struct super_block___253 *, int);
	int (*freeze_super)(struct super_block___253 *);
	int (*freeze_fs)(struct super_block___253 *);
	int (*thaw_super)(struct super_block___253 *);
	int (*unfreeze_fs)(struct super_block___253 *);
	int (*statfs)(struct dentry___253 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___253 *, int *, char *);
	void (*umount_begin)(struct super_block___253 *);
	int (*show_options)(struct seq_file___228 *, struct dentry___253 *);
	int (*show_devname)(struct seq_file___228 *, struct dentry___253 *);
	int (*show_path)(struct seq_file___228 *, struct dentry___253 *);
	int (*show_stats)(struct seq_file___228 *, struct dentry___253 *);
	ssize_t (*quota_read)(struct super_block___253 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___253 *, int, const char *, size_t, loff_t);
	struct dquot___253 ** (*get_dquots)(struct inode___253 *);
	long int (*nr_cached_objects)(struct super_block___253 *, struct shrink_control___118 *);
	long int (*free_cached_objects)(struct super_block___253 *, struct shrink_control___118 *);
	struct file___253 * (*real_loop)(struct file___253 *);
};

struct wakeup_source___234;

struct dev_pm_info___234 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___234 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___234 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___234;

struct bus_type___234;

struct device_driver___234;

struct dev_pm_domain___234;

struct fwnode_handle___230;

struct class___234;

struct attribute_group___241;

struct device___234 {
	struct kobject___241 kobj;
	struct device___234 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___234 *type;
	struct bus_type___234 *bus;
	struct device_driver___234 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___234 power;
	struct dev_pm_domain___234 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___230 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___234 *class;
	const struct attribute_group___241 **groups;
	void (*release)(struct device___234 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___147 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___253 *bd_inode;
	struct super_block___253 *bd_super;
	void *bd_claiming;
	struct device___234 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___241 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___147 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___253 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___182)(struct file___253 *, wait_queue_head_t *, struct poll_table_struct___174 *);

struct poll_table_struct___174 {
	poll_queue_proc___182 _qproc;
	__poll_t _key;
};

struct seq_operations___228;

struct seq_file___228 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___228 *op;
	int poll_event;
	const struct file___253 *file;
	void *private;
};

typedef void bio_end_io_t___144(struct bio___144 *);

struct bio_integrity_payload___144;

struct bio___144 {
	struct bio___144 *bi_next;
	struct block_device___147 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___144 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___132 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___144 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___170 *bi_io_vec;
	struct bio_set___144 *bi_pool;
	struct bio_vec___170 bi_inline_vecs[0];
};

struct dev_pagemap_ops___248 {
	void (*page_free)(struct page___258 *);
	void (*kill)(struct dev_pagemap___248 *);
	void (*cleanup)(struct dev_pagemap___248 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___248 *);
};

struct fwnode_operations___230;

struct fwnode_handle___230 {
	struct fwnode_handle___230 *secondary;
	const struct fwnode_operations___230 *ops;
	struct device___234 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___230;

struct fwnode_endpoint___230;

struct fwnode_operations___230 {
	struct fwnode_handle___230 * (*get)(struct fwnode_handle___230 *);
	void (*put)(struct fwnode_handle___230 *);
	bool (*device_is_available)(const struct fwnode_handle___230 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___230 *, const struct device___234 *);
	bool (*property_present)(const struct fwnode_handle___230 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___230 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___230 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___230 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*get_parent)(const struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*get_next_child_node)(const struct fwnode_handle___230 *, struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*get_named_child_node)(const struct fwnode_handle___230 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___230 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___230 *);
	struct fwnode_handle___230 * (*graph_get_next_endpoint)(const struct fwnode_handle___230 *, struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*graph_get_remote_endpoint)(const struct fwnode_handle___230 *);
	struct fwnode_handle___230 * (*graph_get_port_parent)(struct fwnode_handle___230 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___230 *, struct fwnode_endpoint___230 *);
	int (*add_links)(struct fwnode_handle___230 *);
};

struct fwnode_endpoint___230 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___230 *local_fwnode;
};

struct fwnode_reference_args___230 {
	struct fwnode_handle___230 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___241;

struct kernfs_elem_dir___241 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___241 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___241;

struct kernfs_root___241 {
	struct kernfs_node___241 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___241 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___241 {
	struct kernfs_node___241 *target_kn;
};

struct kernfs_ops___241;

struct kernfs_elem_attr___241 {
	const struct kernfs_ops___241 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___241 *notify_next;
};

struct kernfs_node___241 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___241 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___241 dir;
		struct kernfs_elem_symlink___241 symlink;
		struct kernfs_elem_attr___241 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___241;

struct kernfs_ops___241 {
	int (*open)(struct kernfs_open_file___241 *);
	void (*release)(struct kernfs_open_file___241 *);
	int (*seq_show)(struct seq_file___228 *, void *);
	void * (*seq_start)(struct seq_file___228 *, loff_t *);
	void * (*seq_next)(struct seq_file___228 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___228 *, void *);
	ssize_t (*read)(struct kernfs_open_file___241 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___241 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___241 *, struct poll_table_struct___174 *);
	int (*mmap)(struct kernfs_open_file___241 *, struct vm_area_struct___258 *);
};

struct kernfs_syscall_ops___241 {
	int (*show_options)(struct seq_file___228 *, struct kernfs_root___241 *);
	int (*mkdir)(struct kernfs_node___241 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___241 *);
	int (*rename)(struct kernfs_node___241 *, struct kernfs_node___241 *, const char *);
	int (*show_path)(struct seq_file___228 *, struct kernfs_node___241 *, struct kernfs_root___241 *);
};

struct kernfs_open_file___241 {
	struct kernfs_node___241 *kn;
	struct file___253 *file;
	struct seq_file___228 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___248 *vm_ops;
};

struct sock___49;

struct kobj_ns_type_operations___49 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___49 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___67 *net;
} possible_net_t___62;

struct proto___49;

struct sock_common___49 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___49 *skc_prot;
	possible_net_t___62 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___49 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___63;

struct sk_buff_head___62 {
	struct sk_buff___63 *next;
	struct sk_buff___63 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___49 {
	struct cgroup___180 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___49;

struct socket_wq___50;

struct dst_entry___49;

struct socket___51;

struct net_device___62;

struct sock_reuseport___13;

struct sock___49 {
	struct sock_common___49 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___62 sk_error_queue;
	struct sk_buff___63 *sk_rx_skb_cache;
	struct sk_buff_head___62 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___63 *head;
		struct sk_buff___63 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___49 *sk_filter;
	union {
		struct socket_wq___50 *sk_wq;
		struct socket_wq___50 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___49 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___49 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___63 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___63 *sk_tx_skb_cache;
	struct sk_buff_head___62 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___258 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___49 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___230 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___51 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___49 sk_cgrp_data;
	struct mem_cgroup___118 *sk_memcg;
	void (*sk_state_change)(struct sock___49 *);
	void (*sk_data_ready)(struct sock___49 *);
	void (*sk_write_space)(struct sock___49 *);
	void (*sk_error_report)(struct sock___49 *);
	int (*sk_backlog_rcv)(struct sock___49 *, struct sk_buff___63 *);
	struct sk_buff___63 * (*sk_validate_xmit_skb)(struct sock___49 *, struct net_device___62 *, struct sk_buff___63 *);
	void (*sk_destruct)(struct sock___49 *);
	struct sock_reuseport___13 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___241;

struct attribute_group___241 {
	const char *name;
	umode_t (*is_visible)(struct kobject___241 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___241 *, struct bin_attribute___241 *, int);
	struct attribute **attrs;
	struct bin_attribute___241 **bin_attrs;
};

struct bin_attribute___241 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___253 * (*f_mapping)();
	ssize_t (*read)(struct file___253 *, struct kobject___241 *, struct bin_attribute___241 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___253 *, struct kobject___241 *, struct bin_attribute___241 *, char *, loff_t, size_t);
	int (*mmap)(struct file___253 *, struct kobject___241 *, struct bin_attribute___241 *, struct vm_area_struct___258 *);
};

struct sysfs_ops___241 {
	ssize_t (*show)(struct kobject___241 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___241 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___241;

struct kset___241 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___241 kobj;
	const struct kset_uevent_ops___241 *uevent_ops;
};

struct kobj_type___241 {
	void (*release)(struct kobject___241 *);
	const struct sysfs_ops___241 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___241 **default_groups;
	const struct kobj_ns_type_operations___49 * (*child_ns_type)(struct kobject___241 *);
	const void * (*namespace)(struct kobject___241 *);
	void (*get_ownership)(struct kobject___241 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___241 {
	int (* const filter)(struct kset___241 *, struct kobject___241 *);
	const char * (* const name)(struct kset___241 *, struct kobject___241 *);
	int (* const uevent)(struct kset___241 *, struct kobject___241 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___237 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___237 *);
	int (*get)(char *, const struct kernel_param___237 *);
	void (*free)(void *);
};

struct kparam_array___237;

struct kernel_param___237 {
	const char *name;
	struct module___237 *mod;
	const struct kernel_param_ops___237 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___237 *arr;
	};
};

struct kparam_array___237 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___237 *ops;
	void *elem;
};

struct module_attribute___237 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___237 *, struct module_kobject___238 *, char *);
	ssize_t (*store)(struct module_attribute___237 *, struct module_kobject___238 *, const char *, size_t);
	void (*setup)(struct module___237 *, const char *);
	int (*test)(struct module___237 *);
	void (*free)(struct module___237 *);
};

struct ip_ra_chain___28;

struct fib_rules_ops___49;

struct fqdir___67;

struct tcp_congestion_ops___12;

struct fib_notifier_ops___49;

struct netns_ipv4___67 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___28 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___49 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___49 *fibnl;
	struct sock___49 **icmp_sk;
	struct sock___49 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___49 **tcp_sk;
	struct fqdir___67 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___12 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___49 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___49 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___49 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___49;

struct dst_ops___67 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___67 *);
	struct dst_entry___49 * (*check)(struct dst_entry___49 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___49 *);
	unsigned int (*mtu)(const struct dst_entry___49 *);
	u32 * (*cow_metrics)(struct dst_entry___49 *, long unsigned int);
	void (*destroy)(struct dst_entry___49 *);
	void (*ifdown)(struct dst_entry___49 *, struct net_device___62 *, int);
	struct dst_entry___49 * (*negative_advice)(struct dst_entry___49 *);
	void (*link_failure)(struct sk_buff___63 *);
	void (*update_pmtu)(struct dst_entry___49 *, struct sock___49 *, struct sk_buff___63 *, u32, bool);
	void (*redirect)(struct dst_entry___49 *, struct sock___49 *, struct sk_buff___63 *);
	int (*local_out)(struct net___67 *, struct sock___49 *, struct sk_buff___63 *);
	struct neighbour___49 * (*neigh_lookup)(const struct dst_entry___49 *, struct sk_buff___63 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___49 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___67 {
	struct dst_ops___67 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___67 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___49 *fib6_rules_ops;
	struct sock___49 **icmp_sk;
	struct sock___49 *ndisc_sk;
	struct sock___49 *tcp_sk;
	struct sock___49 *igmp_sk;
	struct sock___49 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___49 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___49 *notifier_ops;
	struct fib_notifier_ops___49 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___67 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___67 *fqdir;
};

struct netns_sctp___49 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___49 *ctl_sock;
	struct sock___49 *udp4_sock;
	struct sock___49 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___56;

struct netns_bpf___56 {
	struct bpf_prog_array___56 *run_array[2];
	struct bpf_prog___56 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___67 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___49 *nlsk;
	struct sock___49 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___67 xfrm4_dst_ops;
	struct dst_ops___67 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___67 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___49 *rtnl;
	struct sock___49 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___62 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___67 ipv4;
	struct netns_ipv6___67 ipv6;
	struct netns_ieee802154_lowpan___67 ieee802154_lowpan;
	struct netns_sctp___49 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___62 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___56 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___67 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___49 *crypto_nlsk;
	struct sock___49 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___180 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___180 *root_cset;
};

struct socket_wq___50 {
	wait_queue_head_t wait;
	struct fasync_struct___253 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___50;

struct socket___51 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___253 *file;
	struct sock___49 *sk;
	const struct proto_ops___50 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___50 wq;
};

typedef int (*sk_read_actor_t___49)(read_descriptor_t *, struct sk_buff___63 *, unsigned int, size_t);

struct proto_ops___50 {
	int family;
	struct module___237 *owner;
	int (*release)(struct socket___51 *);
	int (*bind)(struct socket___51 *, struct sockaddr *, int);
	int (*connect)(struct socket___51 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___51 *, struct socket___51 *);
	int (*accept)(struct socket___51 *, struct socket___51 *, int, bool);
	int (*getname)(struct socket___51 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___253 *, struct socket___51 *, struct poll_table_struct___174 *);
	int (*ioctl)(struct socket___51 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___51 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___51 *, void *, bool, bool);
	int (*listen)(struct socket___51 *, int);
	int (*shutdown)(struct socket___51 *, int);
	int (*setsockopt)(struct socket___51 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___51 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___228 *, struct socket___51 *);
	int (*sendmsg)(struct socket___51 *, struct msghdr___51 *, size_t);
	int (*recvmsg)(struct socket___51 *, struct msghdr___51 *, size_t, int);
	int (*mmap)(struct file___253 *, struct socket___51 *, struct vm_area_struct___258 *);
	ssize_t (*sendpage)(struct socket___51 *, struct page___258 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___51 *, loff_t *, struct pipe_inode_info___94 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___49 *, int);
	int (*peek_len)(struct socket___51 *);
	int (*read_sock)(struct sock___49 *, read_descriptor_t *, sk_read_actor_t___49);
	int (*sendpage_locked)(struct sock___49 *, struct page___258 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___49 *, struct msghdr___51 *, size_t);
	int (*set_rcvlowat)(struct sock___49 *, int);
};

struct sk_buff___63 {
	union {
		struct {
			struct sk_buff___63 *next;
			struct sk_buff___63 *prev;
			union {
				struct net_device___62 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___49 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___63 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___234 {
	int (*prepare)(struct device___234 *);
	void (*complete)(struct device___234 *);
	int (*suspend)(struct device___234 *);
	int (*resume)(struct device___234 *);
	int (*freeze)(struct device___234 *);
	int (*thaw)(struct device___234 *);
	int (*poweroff)(struct device___234 *);
	int (*restore)(struct device___234 *);
	int (*suspend_late)(struct device___234 *);
	int (*resume_early)(struct device___234 *);
	int (*freeze_late)(struct device___234 *);
	int (*thaw_early)(struct device___234 *);
	int (*poweroff_late)(struct device___234 *);
	int (*restore_early)(struct device___234 *);
	int (*suspend_noirq)(struct device___234 *);
	int (*resume_noirq)(struct device___234 *);
	int (*freeze_noirq)(struct device___234 *);
	int (*thaw_noirq)(struct device___234 *);
	int (*poweroff_noirq)(struct device___234 *);
	int (*restore_noirq)(struct device___234 *);
	int (*runtime_suspend)(struct device___234 *);
	int (*runtime_resume)(struct device___234 *);
	int (*runtime_idle)(struct device___234 *);
};

struct wakeup_source___234 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___234 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___234 {
	struct dev_pm_ops___234 ops;
	int (*start)(struct device___234 *);
	void (*detach)(struct device___234 *, bool);
	int (*activate)(struct device___234 *);
	void (*sync)(struct device___234 *);
	void (*dismiss)(struct device___234 *);
};

struct bus_type___234 {
	const char *name;
	const char *dev_name;
	struct device___234 *dev_root;
	const struct attribute_group___241 **bus_groups;
	const struct attribute_group___241 **dev_groups;
	const struct attribute_group___241 **drv_groups;
	int (*match)(struct device___234 *, struct device_driver___234 *);
	int (*uevent)(struct device___234 *, struct kobj_uevent_env *);
	int (*probe)(struct device___234 *);
	void (*sync_state)(struct device___234 *);
	void (*remove)(struct device___234 *);
	void (*shutdown)(struct device___234 *);
	int (*online)(struct device___234 *);
	int (*offline)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	int (*num_vf)(struct device___234 *);
	int (*dma_configure)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___234 {
	const char *name;
	struct bus_type___234 *bus;
	struct module___237 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___234 *);
	void (*sync_state)(struct device___234 *);
	int (*remove)(struct device___234 *);
	void (*shutdown)(struct device___234 *);
	int (*suspend)(struct device___234 *, pm_message_t);
	int (*resume)(struct device___234 *);
	const struct attribute_group___241 **groups;
	const struct attribute_group___241 **dev_groups;
	const struct dev_pm_ops___234 *pm;
	void (*coredump)(struct device___234 *);
	struct driver_private *p;
};

struct device_type___234 {
	const char *name;
	const struct attribute_group___241 **groups;
	int (*uevent)(struct device___234 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___234 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___234 *);
	const struct dev_pm_ops___234 *pm;
};

struct class___234 {
	const char *name;
	struct module___237 *owner;
	const struct attribute_group___241 **class_groups;
	const struct attribute_group___241 **dev_groups;
	struct kobject___241 *dev_kobj;
	int (*dev_uevent)(struct device___234 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___234 *, umode_t *);
	void (*class_release)(struct class___234 *);
	void (*dev_release)(struct device___234 *);
	int (*shutdown_pre)(struct device___234 *);
	const struct kobj_ns_type_operations___49 *ns_type;
	const void * (*namespace)(struct device___234 *);
	void (*get_ownership)(struct device___234 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___234 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___94;

struct pipe_buffer___94 {
	struct page___258 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___94 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___94 {
	int (*confirm)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
	void (*release)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
	bool (*try_steal)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
	bool (*get)(struct pipe_inode_info___94 *, struct pipe_buffer___94 *);
};

typedef rx_handler_result_t rx_handler_func_t___62(struct sk_buff___63 **);

struct bpf_xdp_entity___56 {
	struct bpf_prog___56 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___62;

struct net_device_ops___62;

struct ethtool_ops___27;

struct l3mdev_ops___49;

struct ndisc_ops___35;

struct xfrmdev_ops___62;

struct header_ops___62;

struct inet6_dev___35;

struct netdev_rx_queue___62;

struct mini_Qdisc___56;

struct netdev_queue___62;

struct Qdisc___56;

struct rtnl_link_ops___56;

struct dcbnl_rtnl_ops___62;

struct phy_device___11;

struct net_device___62 {
	char name[16];
	struct netdev_name_node___62 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___62 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___27 *ethtool_ops;
	const struct l3mdev_ops___49 *l3mdev_ops;
	const struct ndisc_ops___35 *ndisc_ops;
	const struct xfrmdev_ops___62 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___62 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___241 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___35 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___62 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___56 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___62 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___56 *miniq_ingress;
	struct netdev_queue___62 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___62 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___56 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___56 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___62 = 0,
		NETREG_REGISTERED___62 = 1,
		NETREG_UNREGISTERING___62 = 2,
		NETREG_UNREGISTERED___62 = 3,
		NETREG_RELEASED___62 = 4,
		NETREG_DUMMY___62 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___62 = 0,
		RTNL_LINK_INITIALIZING___62 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___62 *);
	struct netpoll_info *npinfo;
	possible_net_t___62 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___234 dev;
	const struct attribute_group___241 *sysfs_groups[4];
	const struct attribute_group___241 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___56 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___62 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___11 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___56 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___170 skb_frag_t___16;

struct skb_shared_info___16 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___63 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___16 frags[17];
};

struct netlink_callback___62 {
	struct sk_buff___63 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___63 *, struct netlink_callback___62 *);
	int (*done)(struct netlink_callback___62 *);
	void *data;
	struct module___237 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum ethtool_test_flags {
	ETH_TEST_FL_OFFLINE = 1,
	ETH_TEST_FL_FAILED = 2,
	ETH_TEST_FL_EXTERNAL_LB = 4,
	ETH_TEST_FL_EXTERNAL_LB_DONE = 8,
};

struct ethtool_ops___27 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___62 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___62 *);
	void (*get_regs)(struct net_device___62 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___62 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___62 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___62 *);
	void (*set_msglevel)(struct net_device___62 *, u32);
	int (*nway_reset)(struct net_device___62 *);
	u32 (*get_link)(struct net_device___62 *);
	int (*get_link_ext_state)(struct net_device___62 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___62 *);
	int (*get_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___62 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___62 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___62 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___62 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___62 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___62 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___62 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___62 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___62 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___62 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___62 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___62 *);
	void (*complete)(struct net_device___62 *);
	u32 (*get_priv_flags)(struct net_device___62 *);
	int (*set_priv_flags)(struct net_device___62 *, u32);
	int (*get_sset_count)(struct net_device___62 *, int);
	int (*get_rxnfc)(struct net_device___62 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___62 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___62 *, struct ethtool_flash *);
	int (*reset)(struct net_device___62 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___62 *);
	u32 (*get_rxfh_indir_size)(struct net_device___62 *);
	int (*get_rxfh)(struct net_device___62 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___62 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___62 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___62 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___62 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___62 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___62 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___62 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___62 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___62 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___62 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___62 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___62 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___62 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___62 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___62 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___62 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___62 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___62 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___62 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___62 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___62 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___62 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___62 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___62 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___62 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___62 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___62 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___62 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___62 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___62 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct mii_bus___14;

struct mdio_device___14 {
	struct device___234 dev;
	struct mii_bus___14 *bus;
	char modalias[32];
	int (*bus_match)(struct device___234 *, struct device_driver___234 *);
	void (*device_free)(struct mdio_device___14 *);
	void (*device_remove)(struct mdio_device___14 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___11;

struct mii_timestamper___11;

struct phy_device___11 {
	struct mdio_device___14 mdio;
	struct phy_driver___11 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___63 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___62 *attached_dev;
	struct mii_timestamper___11 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___11 *, bool);
	void (*adjust_link)(struct net_device___62 *);
	const struct macsec_ops *macsec_ops;
};

struct mii_bus___14 {
	struct module___237 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___14 *, int, int);
	int (*write)(struct mii_bus___14 *, int, int, u16);
	int (*reset)(struct mii_bus___14 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___234 *parent;
	enum {
		MDIOBUS_ALLOCATED___14 = 1,
		MDIOBUS_REGISTERED___14 = 2,
		MDIOBUS_UNREGISTERED___14 = 3,
		MDIOBUS_RELEASED___14 = 4,
	} state;
	struct device___234 dev;
	struct mdio_device___14 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___14 = 0,
		MDIOBUS_C22___14 = 1,
		MDIOBUS_C45___14 = 2,
		MDIOBUS_C22_C45___14 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___13 {
	struct device_driver___234 driver;
	int flags;
};

struct mii_timestamper___11 {
	bool (*rxtstamp)(struct mii_timestamper___11 *, struct sk_buff___63 *, int);
	void (*txtstamp)(struct mii_timestamper___11 *, struct sk_buff___63 *, int);
	int (*hwtstamp)(struct mii_timestamper___11 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___11 *, struct phy_device___11 *);
	int (*ts_info)(struct mii_timestamper___11 *, struct ethtool_ts_info *);
	struct device___234 *device;
};

struct phy_driver___11 {
	struct mdio_driver_common___13 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___11 *);
	int (*config_init)(struct phy_device___11 *);
	int (*probe)(struct phy_device___11 *);
	int (*get_features)(struct phy_device___11 *);
	int (*suspend)(struct phy_device___11 *);
	int (*resume)(struct phy_device___11 *);
	int (*config_aneg)(struct phy_device___11 *);
	int (*aneg_done)(struct phy_device___11 *);
	int (*read_status)(struct phy_device___11 *);
	int (*config_intr)(struct phy_device___11 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___11 *);
	void (*remove)(struct phy_device___11 *);
	int (*match_phy_device)(struct phy_device___11 *);
	int (*set_wol)(struct phy_device___11 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___11 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___11 *);
	int (*read_mmd)(struct phy_device___11 *, int, u16);
	int (*write_mmd)(struct phy_device___11 *, int, u16, u16);
	int (*read_page)(struct phy_device___11 *);
	int (*write_page)(struct phy_device___11 *, int);
	int (*module_info)(struct phy_device___11 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___11 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___11 *);
	int (*cable_test_tdr_start)(struct phy_device___11 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___11 *, bool *);
	int (*get_sset_count)(struct phy_device___11 *);
	void (*get_strings)(struct phy_device___11 *, u8 *);
	void (*get_stats)(struct phy_device___11 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___11 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___11 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___11 *, bool);
	int (*get_sqi)(struct phy_device___11 *);
	int (*get_sqi_max)(struct phy_device___11 *);
};

struct inet_frags___67;

struct fqdir___67 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___67 *f;
	struct net___67 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___67;

struct inet_frags___67 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___67 *, const void *);
	void (*destructor)(struct inet_frag_queue___67 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___67 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___63 *fragments_tail;
	struct sk_buff___63 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___67 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___28 {
	struct ip_ra_chain___28 *next;
	struct sock___49 *sk;
	union {
		void (*destructor)(struct sock___49 *);
		struct sock___49 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___49;

struct fib_lookup_arg___49;

struct fib_rules_ops___49 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___49 *, struct flowi *, int, struct fib_lookup_arg___49 *);
	bool (*suppress)(struct fib_rule___49 *, int, struct fib_lookup_arg___49 *);
	int (*match)(struct fib_rule___49 *, struct flowi *, int);
	int (*configure)(struct fib_rule___49 *, struct sk_buff___63 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___49 *);
	int (*compare)(struct fib_rule___49 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___49 *, struct sk_buff___63 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___49 *);
	void (*flush_cache)(struct fib_rules_ops___49 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___237 *owner;
	struct net___67 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___12 {
	u32 (*ssthresh)(struct sock___49 *);
	void (*cong_avoid)(struct sock___49 *, u32, u32);
	void (*set_state)(struct sock___49 *, u8);
	void (*cwnd_event)(struct sock___49 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___49 *, u32);
	void (*pkts_acked)(struct sock___49 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___49 *);
	void (*cong_control)(struct sock___49 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___49 *);
	u32 (*sndbuf_expand)(struct sock___49 *);
	size_t (*get_info)(struct sock___49 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___237 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___49 *);
	void (*release)(struct sock___49 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___49 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___67 *);
	int (*fib_dump)(struct net___67 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___237 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___29;

struct dst_entry___49 {
	struct net_device___62 *dev;
	struct dst_ops___67 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___63 *);
	int (*output)(struct net___67 *, struct sock___49 *, struct sk_buff___63 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___29 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___49;

struct neigh_parms___49;

struct neigh_ops___49;

struct neighbour___49 {
	struct neighbour___49 *next;
	struct neigh_table___49 *tbl;
	struct neigh_parms___49 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___62 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___49 *, struct sk_buff___63 *);
	const struct neigh_ops___49 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___62 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___56 {
	struct bpf_prog___56 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___56 {
	struct callback_head rcu;
	struct bpf_prog_array_item___56 items[0];
};

struct bpf_prog_aux___65;

struct bpf_prog___56 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___65 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___228 {
	void * (*start)(struct seq_file___228 *, loff_t *);
	void (*stop)(struct seq_file___228 *, void *);
	void * (*next)(struct seq_file___228 *, void *, loff_t *);
	int (*show)(struct seq_file___228 *, void *);
};

struct dcbnl_rtnl_ops___62 {
	int (*ieee_getets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___62 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___62 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___62 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___62 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___62 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___62 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___62 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___62 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___62 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___62 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___62 *);
	u8 (*setstate)(struct net_device___62 *, u8);
	void (*getpermhwaddr)(struct net_device___62 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___62 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___62 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___62 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___62 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___62 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___62 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___62 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___62 *, int, u8 *);
	void (*setpfccfg)(struct net_device___62 *, int, u8);
	void (*getpfccfg)(struct net_device___62 *, int, u8 *);
	u8 (*setall)(struct net_device___62 *);
	u8 (*getcap)(struct net_device___62 *, int, u8 *);
	int (*getnumtcs)(struct net_device___62 *, int, u8 *);
	int (*setnumtcs)(struct net_device___62 *, int, u8);
	u8 (*getpfcstate)(struct net_device___62 *);
	void (*setpfcstate)(struct net_device___62 *, u8);
	void (*getbcncfg)(struct net_device___62 *, int, u32 *);
	void (*setbcncfg)(struct net_device___62 *, int, u32);
	void (*getbcnrp)(struct net_device___62 *, int, u8 *);
	void (*setbcnrp)(struct net_device___62 *, int, u8);
	int (*setapp)(struct net_device___62 *, u8, u16, u8);
	int (*getapp)(struct net_device___62 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___62 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___62 *, int, u8);
	u8 (*getdcbx)(struct net_device___62 *);
	u8 (*setdcbx)(struct net_device___62 *, u8);
	int (*peer_getappinfo)(struct net_device___62 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___62 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___62 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___62 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___62 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___62 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___65;

typedef int (*bpf_iter_init_seq_priv_t___64)(void *, struct bpf_iter_aux_info___65 *);

struct bpf_map___65;

struct bpf_iter_aux_info___65 {
	struct bpf_map___65 *map;
};

struct bpf_iter_seq_info___64 {
	const struct seq_operations___228 *seq_ops;
	bpf_iter_init_seq_priv_t___64 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___64 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___65 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___65 *, struct file___253 *);
	void (*map_free)(struct bpf_map___65 *);
	int (*map_get_next_key)(struct bpf_map___65 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___65 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___65 *, void *);
	int (*map_lookup_batch)(struct bpf_map___65 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___65 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___65 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___65 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___65 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___65 *, void *);
	int (*map_update_elem)(struct bpf_map___65 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___65 *, void *);
	int (*map_push_elem)(struct bpf_map___65 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___65 *, void *);
	int (*map_peek_elem)(struct bpf_map___65 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___65 *, struct file___253 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___65 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___65 *, void *, struct seq_file___228 *);
	int (*map_check_btf)(const struct bpf_map___65 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___65 *, struct bpf_prog_aux___65 *);
	void (*map_poke_untrack)(struct bpf_map___65 *, struct bpf_prog_aux___65 *);
	void (*map_poke_run)(struct bpf_map___65 *, u32, struct bpf_prog___56 *, struct bpf_prog___56 *);
	int (*map_direct_value_addr)(const struct bpf_map___65 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___65 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___65 *, struct vm_area_struct___258 *);
	__poll_t (*map_poll)(struct bpf_map___65 *, struct file___253 *, struct poll_table_struct___174 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___65 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___65 *, const struct bpf_map___65 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___65 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___64 *iter_seq_info;
};

struct bpf_map___65 {
	const struct bpf_map_ops___64 *ops;
	struct bpf_map___65 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___118 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___64;

struct bpf_jit_poke_descriptor___64;

struct bpf_prog_ops___56;

struct btf_mod_pair___64;

struct bpf_prog_offload___62;

struct bpf_prog_aux___65 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___56 *dst_prog;
	struct bpf_trampoline___64 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___56 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___64 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___56 *ops;
	struct bpf_map___65 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___64 *used_btfs;
	struct bpf_prog___56 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___65 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___62 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___62;

struct bpf_map_dev_ops___62 {
	int (*map_get_next_key)(struct bpf_offloaded_map___62 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___62 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___62 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___62 *, void *);
};

struct bpf_offloaded_map___62 {
	struct bpf_map___65 map;
	struct net_device___62 *netdev;
	const struct bpf_map_dev_ops___62 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___56 {
	int (*test_run)(struct bpf_prog___56 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___62 {
	struct bpf_prog___56 *prog;
	struct net_device___62 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___64 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___56 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___237 *mod;
};

struct bpf_jit_poke_descriptor___64 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___65 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___64 {
	struct btf *btf;
	struct module___237 *module;
};

struct cftype___180;

struct cgroup_subsys___180 {
	struct cgroup_subsys_state___180 * (*css_alloc)(struct cgroup_subsys_state___180 *);
	int (*css_online)(struct cgroup_subsys_state___180 *);
	void (*css_offline)(struct cgroup_subsys_state___180 *);
	void (*css_released)(struct cgroup_subsys_state___180 *);
	void (*css_free)(struct cgroup_subsys_state___180 *);
	void (*css_reset)(struct cgroup_subsys_state___180 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___180 *, int);
	int (*css_extra_stat_show)(struct seq_file___228 *, struct cgroup_subsys_state___180 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___260 *, struct css_set___180 *);
	void (*cancel_fork)(struct task_struct___260 *, struct css_set___180 *);
	void (*fork)(struct task_struct___260 *);
	void (*exit)(struct task_struct___260 *);
	void (*release)(struct task_struct___260 *);
	void (*bind)(struct cgroup_subsys_state___180 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___180 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___180 *dfl_cftypes;
	struct cftype___180 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___180 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___180 *updated_children;
	struct cgroup___180 *updated_next;
};

struct cgroup_root___180 {
	struct kernfs_root___241 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___180 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___180 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___180 *ss;
	struct list_head node;
	struct kernfs_ops___241 *kf_ops;
	int (*open)(struct kernfs_open_file___241 *);
	void (*release)(struct kernfs_open_file___241 *);
	u64 (*read_u64)(struct cgroup_subsys_state___180 *, struct cftype___180 *);
	s64 (*read_s64)(struct cgroup_subsys_state___180 *, struct cftype___180 *);
	int (*seq_show)(struct seq_file___228 *, void *);
	void * (*seq_start)(struct seq_file___228 *, loff_t *);
	void * (*seq_next)(struct seq_file___228 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___228 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___180 *, struct cftype___180 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___180 *, struct cftype___180 *, s64);
	ssize_t (*write)(struct kernfs_open_file___241 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___241 *, struct poll_table_struct___174 *);
};

struct xdp_rxq_info___62 {
	struct net_device___62 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___62 {
	struct net_device___62 *dev;
};

struct xdp_buff___62 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___62 *rxq;
	struct xdp_txq_info___62 *txq;
	u32 frame_sz;
};

struct xdp_frame___62 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___62 *dev_rx;
};

struct header_ops___62 {
	int (*create)(struct sk_buff___63 *, struct net_device___62 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___63 *, unsigned char *);
	int (*cache)(const struct neighbour___49 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___62 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___63 *);
};

struct netdev_queue___62 {
	struct net_device___62 *dev;
	struct Qdisc___56 *qdisc;
	struct Qdisc___56 *qdisc_sleeping;
	struct kobject___241 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___62 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___56 {
	struct sk_buff___63 *head;
	struct sk_buff___63 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___56;

struct Qdisc___56 {
	int (*enqueue)(struct sk_buff___63 *, struct Qdisc___56 *, struct sk_buff___63 **);
	struct sk_buff___63 * (*dequeue)(struct Qdisc___56 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___56 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___62 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___62 gso_skb;
	struct qdisc_skb_head___56 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___56 *next_sched;
	struct sk_buff_head___62 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___62 {
	struct xdp_rxq_info___62 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___241 kobj;
	struct net_device___62 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___62 {
	enum net_device_path_type type;
	const struct net_device___62 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___62 = 0,
				DEV_PATH_BR_VLAN_TAG___62 = 1,
				DEV_PATH_BR_VLAN_UNTAG___62 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___62 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___62 {
	const struct net_device___62 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___62 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___56 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___62 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___62 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___63 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___62 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___62 *dev;
	const char *name;
};

struct net_device_ops___62 {
	int (*ndo_init)(struct net_device___62 *);
	void (*ndo_uninit)(struct net_device___62 *);
	int (*ndo_open)(struct net_device___62 *);
	int (*ndo_stop)(struct net_device___62 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___63 *, struct net_device___62 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___63 *, struct net_device___62 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___62 *, struct sk_buff___63 *, struct net_device___62 *);
	void (*ndo_change_rx_flags)(struct net_device___62 *, int);
	void (*ndo_set_rx_mode)(struct net_device___62 *);
	int (*ndo_set_mac_address)(struct net_device___62 *, void *);
	int (*ndo_validate_addr)(struct net_device___62 *);
	int (*ndo_do_ioctl)(struct net_device___62 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___62 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___62 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___62 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___62 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___62 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___62 *, int);
	int (*ndo_neigh_setup)(struct net_device___62 *, struct neigh_parms___49 *);
	void (*ndo_tx_timeout)(struct net_device___62 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___62 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___62 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___62 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___62 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___62 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___62 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___62 *);
	int (*ndo_netpoll_setup)(struct net_device___62 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___62 *);
	int (*ndo_set_vf_mac)(struct net_device___62 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___62 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___62 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___62 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___62 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___62 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___62 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___62 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___62 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___62 *, int, struct sk_buff___63 *);
	int (*ndo_get_vf_guid)(struct net_device___62 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___62 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___62 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___62 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___62 *);
	int (*ndo_fcoe_disable)(struct net_device___62 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___62 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___62 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___62 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___62 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___62 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___62 *, const struct sk_buff___63 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___62 *, struct net_device___62 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___62 *, struct net_device___62 *);
	struct net_device___62 * (*ndo_get_xmit_slave)(struct net_device___62 *, struct sk_buff___63 *, bool);
	struct net_device___62 * (*ndo_sk_get_lower_dev)(struct net_device___62 *, struct sock___49 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___62 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___62 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___62 *, struct neighbour___49 *);
	void (*ndo_neigh_destroy)(struct net_device___62 *, struct neighbour___49 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___63 *, struct netlink_callback___62 *, struct net_device___62 *, struct net_device___62 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___63 *, struct nlattr **, struct net_device___62 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___62 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___63 *, u32, u32, struct net_device___62 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___62 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___62 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___62 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___62 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___62 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___62 *, struct net_device___62 *);
	void (*ndo_dfwd_del_station)(struct net_device___62 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___62 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___62 *);
	int (*ndo_change_proto_down)(struct net_device___62 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___62 *, struct sk_buff___63 *);
	void (*ndo_set_rx_headroom)(struct net_device___62 *, int);
	int (*ndo_bpf)(struct net_device___62 *, struct netdev_bpf___62 *);
	int (*ndo_xdp_xmit)(struct net_device___62 *, int, struct xdp_frame___62 **, u32);
	struct net_device___62 * (*ndo_xdp_get_xmit_slave)(struct net_device___62 *, struct xdp_buff___62 *);
	int (*ndo_xsk_wakeup)(struct net_device___62 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___62 *);
	int (*ndo_tunnel_ctl)(struct net_device___62 *, struct ip_tunnel_parm *, int);
	struct net_device___62 * (*ndo_get_peer_dev)(struct net_device___62 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___62 *, struct net_device_path___62 *);
};

struct neigh_parms___49 {
	possible_net_t___62 net;
	struct net_device___62 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___49 *);
	struct neigh_table___49 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___49 {
	u32 (*l3mdev_fib_table)(const struct net_device___62 *);
	struct sk_buff___63 * (*l3mdev_l3_rcv)(struct net_device___62 *, struct sk_buff___63 *, u16);
	struct sk_buff___63 * (*l3mdev_l3_out)(struct net_device___62 *, struct sock___49 *, struct sk_buff___63 *, u16);
	struct dst_entry___49 * (*l3mdev_link_scope_lookup)(const struct net_device___62 *, struct flowi6 *);
};

struct ndisc_ops___35 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___62 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___62 *, struct neighbour___49 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___62 *, u8, struct neighbour___49 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___62 *, struct sk_buff___63 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___67 *, struct net_device___62 *, const struct prefix_info *, struct inet6_dev___35 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___35;

struct inet6_dev___35 {
	struct net_device___62 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___35 *mc_list;
	struct ifmcaddr6___35 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___62 mc_query_queue;
	struct sk_buff_head___62 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___49 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___56;

struct tcf_block___56;

struct mini_Qdisc___56 {
	struct tcf_proto___56 *filter_list;
	struct tcf_block___56 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___56 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___62 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___62 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___67 *, struct net_device___62 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___62 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___62 *, struct list_head *);
	size_t (*get_size)(const struct net_device___62 *);
	int (*fill_info)(struct sk_buff___63 *, const struct net_device___62 *);
	size_t (*get_xstats_size)(const struct net_device___62 *);
	int (*fill_xstats)(struct sk_buff___63 *, const struct net_device___62 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___62 *, struct net_device___62 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___62 *, const struct net_device___62 *);
	int (*fill_slave_info)(struct sk_buff___63 *, const struct net_device___62 *, const struct net_device___62 *);
	struct net___67 * (*get_link_net)(const struct net_device___62 *);
	size_t (*get_linkxstats_size)(const struct net_device___62 *, int);
	int (*fill_linkxstats)(struct sk_buff___63 *, const struct net_device___62 *, int *, int);
};

struct packet_type___3 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___62 *dev;
	int (*func)(struct sk_buff___63 *, struct net_device___62 *, struct packet_type___3 *, struct net_device___62 *);
	void (*list_func)(struct list_head *, struct packet_type___3 *, struct net_device___62 *);
	bool (*id_match)(struct packet_type___3 *, struct sock___49 *);
	struct net___67 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct block_device_operations___144;

struct gendisk___147 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___147 *part0;
	const struct block_device_operations___144 *fops;
	struct request_queue___144 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___130 *bdi;
	struct kobject___241 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___241 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___144 {
	struct bio___144 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___170 *bip_vec;
	struct bio_vec___170 bip_inline_vecs[0];
};

struct blkcg___132;

struct blkg_policy_data___132;

struct blkcg_gq___132 {
	struct request_queue___144 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___132 *blkcg;
	struct blkcg_gq___132 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___132 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___144 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___144(struct request___144 *);

typedef void integrity_complete_fn___144(struct request___144 *, unsigned int);

struct blk_integrity_profile___144 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___144 *prepare_fn;
	integrity_complete_fn___144 *complete_fn;
	const char *name;
};

struct block_device_operations___144 {
	blk_qc_t (*submit_bio)(struct bio___144 *);
	int (*open)(struct block_device___147 *, fmode_t);
	void (*release)(struct gendisk___147 *, fmode_t);
	int (*rw_page)(struct block_device___147 *, sector_t, struct page___258 *, unsigned int);
	int (*ioctl)(struct block_device___147 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___147 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___147 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___147 *);
	int (*getgeo)(struct block_device___147 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___147 *, bool);
	void (*swap_slot_free_notify)(struct block_device___147 *, long unsigned int);
	int (*report_zones)(struct gendisk___147 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___147 *, umode_t *);
	struct module___237 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___147 *, sector_t *);
};

typedef void rq_end_io_fn___144(struct request___144 *, blk_status_t);

struct request___144 {
	struct request_queue___144 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___139 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___144 *bio;
	struct bio___144 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___170 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___144 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___144 *saved_end_io;
		} flush;
	};
	struct gendisk___147 *rq_disk;
	struct block_device___147 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___144 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___139 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___144 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___241 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___253 *debugfs_dir;
	struct dentry___253 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___144;

struct elevator_mq_ops___144 {
	int (*init_sched)(struct request_queue___144 *, struct elevator_type___144 *);
	void (*exit_sched)(struct elevator_queue___144 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___139 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___139 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___139 *);
	bool (*allow_merge)(struct request_queue___144 *, struct request___144 *, struct bio___144 *);
	bool (*bio_merge)(struct request_queue___144 *, struct bio___144 *, unsigned int);
	int (*request_merge)(struct request_queue___144 *, struct request___144 **, struct bio___144 *);
	void (*request_merged)(struct request_queue___144 *, struct request___144 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___144 *, struct request___144 *, struct request___144 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___144 *);
	void (*finish_request)(struct request___144 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___139 *, struct list_head *, bool);
	struct request___144 * (*dispatch_request)(struct blk_mq_hw_ctx___139 *);
	bool (*has_work)(struct blk_mq_hw_ctx___139 *);
	void (*completed_request)(struct request___144 *, u64);
	void (*requeue_request)(struct request___144 *);
	struct request___144 * (*former_request)(struct request_queue___144 *, struct request___144 *);
	struct request___144 * (*next_request)(struct request_queue___144 *, struct request___144 *);
	void (*init_icq)(struct io_cq___144 *);
	void (*exit_icq)(struct io_cq___144 *);
};

struct elv_fs_entry___144;

struct elevator_type___144 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___144 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___144 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___237 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___144 {
	struct elevator_type___144 *type;
	void *elevator_data;
	struct kobject___241 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___144 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___144 *, char *);
	ssize_t (*store)(struct elevator_queue___144 *, const char *, size_t);
};

struct blk_mq_queue_data___139;

struct blk_mq_ops___139 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___139 *, const struct blk_mq_queue_data___139 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___139 *);
	int (*get_budget)(struct request_queue___144 *);
	void (*put_budget)(struct request_queue___144 *, int);
	void (*set_rq_budget_token)(struct request___144 *, int);
	int (*get_rq_budget_token)(struct request___144 *);
	enum blk_eh_timer_return (*timeout)(struct request___144 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___139 *);
	void (*complete)(struct request___144 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___139 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___139 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___139 *, struct request___144 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___139 *, struct request___144 *, unsigned int);
	void (*initialize_rq_fn)(struct request___144 *);
	void (*cleanup_rq)(struct request___144 *);
	bool (*busy)(struct request_queue___144 *);
	int (*map_queues)(struct blk_mq_tag_set___139 *);
	void (*show_rq)(struct seq_file___228 *, struct request___144 *);
};

struct blk_mq_tag_set___139 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___139 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___139 {
	struct request___144 *rq;
	bool last;
};

struct blkcg_policy_data___132;

struct blkcg___132 {
	struct cgroup_subsys_state___180 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___132 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___132 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___132 {
	struct blkcg___132 *blkcg;
	int plid;
};

struct blkg_policy_data___132 {
	struct blkcg_gq___132 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___118 {
	struct mem_cgroup___118 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___118 {
	struct lruvec___126 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___118 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___118 *memcg;
};

struct obj_cgroup___118 {
	struct percpu_ref refcnt;
	struct mem_cgroup___118 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___56 {
	spinlock_t *lock;
	struct sk_buff___63 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___56;

struct Qdisc_ops___56 {
	struct Qdisc_ops___56 *next;
	const struct Qdisc_class_ops___56 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___63 *, struct Qdisc___56 *, struct sk_buff___63 **);
	struct sk_buff___63 * (*dequeue)(struct Qdisc___56 *);
	struct sk_buff___63 * (*peek)(struct Qdisc___56 *);
	int (*init)(struct Qdisc___56 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___56 *);
	void (*destroy)(struct Qdisc___56 *);
	int (*change)(struct Qdisc___56 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___56 *);
	int (*change_tx_queue_len)(struct Qdisc___56 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___56 *, unsigned int);
	int (*dump)(struct Qdisc___56 *, struct sk_buff___63 *);
	int (*dump_stats)(struct Qdisc___56 *, struct gnet_dump___56 *);
	void (*ingress_block_set)(struct Qdisc___56 *, u32);
	void (*egress_block_set)(struct Qdisc___56 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___56 *);
	u32 (*egress_block_get)(struct Qdisc___56 *);
	struct module___237 *owner;
};

struct Qdisc_class_ops___56 {
	unsigned int flags;
	struct netdev_queue___62 * (*select_queue)(struct Qdisc___56 *, struct tcmsg *);
	int (*graft)(struct Qdisc___56 *, long unsigned int, struct Qdisc___56 *, struct Qdisc___56 **, struct netlink_ext_ack *);
	struct Qdisc___56 * (*leaf)(struct Qdisc___56 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___56 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___56 *, u32);
	int (*change)(struct Qdisc___56 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___56 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___56 *, struct qdisc_walker *);
	struct tcf_block___56 * (*tcf_block)(struct Qdisc___56 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___56 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___56 *, long unsigned int);
	int (*dump)(struct Qdisc___56 *, long unsigned int, struct sk_buff___63 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___56 *, long unsigned int, struct gnet_dump___56 *);
};

struct tcf_chain___56;

struct tcf_block___56 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___67 *net;
	struct Qdisc___56 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___56 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___56;

struct tcf_proto_ops___56;

struct tcf_proto___56 {
	struct tcf_proto___56 *next;
	void *root;
	int (*classify)(struct sk_buff___63 *, const struct tcf_proto___56 *, struct tcf_result___56 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___56 *ops;
	struct tcf_chain___56 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___56 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___56 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___56 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___63 *, const struct tcf_proto___56 *, struct tcf_result___56 *);
	int (*init)(struct tcf_proto___56 *);
	void (*destroy)(struct tcf_proto___56 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___56 *, u32);
	void (*put)(struct tcf_proto___56 *, void *);
	int (*change)(struct net___67 *, struct sk_buff___63 *, struct tcf_proto___56 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___56 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___56 *);
	void (*walk)(struct tcf_proto___56 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___56 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___56 *, void *);
	void (*hw_del)(struct tcf_proto___56 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___67 *, struct tcf_chain___56 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___67 *, struct tcf_proto___56 *, void *, struct sk_buff___63 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___67 *, struct tcf_proto___56 *, void *, struct sk_buff___63 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___63 *, struct net___67 *, void *);
	struct module___237 *owner;
	int flags;
};

struct tcf_chain___56 {
	struct mutex filter_chain_lock;
	struct tcf_proto___56 *filter_chain;
	struct list_head list;
	struct tcf_block___56 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___56 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___49 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___56 *prog;
};

struct pneigh_entry___49;

struct neigh_hash_table___49;

struct neigh_table___49 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___62 *, __u32 *);
	bool (*key_eq)(const struct neighbour___49 *, const void *);
	int (*constructor)(struct neighbour___49 *);
	int (*pconstructor)(struct pneigh_entry___49 *);
	void (*pdestructor)(struct pneigh_entry___49 *);
	void (*proxy_redo)(struct sk_buff___63 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___62 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___49 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___62 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___49 *nht;
	struct pneigh_entry___49 **phash_buckets;
};

struct neigh_ops___49 {
	int family;
	void (*solicit)(struct neighbour___49 *, struct sk_buff___63 *);
	void (*error_report)(struct neighbour___49 *, struct sk_buff___63 *);
	int (*output)(struct neighbour___49 *, struct sk_buff___63 *);
	int (*connected_output)(struct neighbour___49 *, struct sk_buff___63 *);
};

struct pneigh_entry___49 {
	struct pneigh_entry___49 *next;
	possible_net_t___62 net;
	struct net_device___62 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___49 {
	struct neighbour___49 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___29 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___67 *, struct sock___49 *, struct sk_buff___63 *);
	int (*orig_input)(struct sk_buff___63 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___49 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___49 *ctarget;
	struct net___67 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___49 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___49 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___37;

struct timewait_sock_ops___37;

struct proto___49 {
	void (*close)(struct sock___49 *, long int);
	int (*pre_connect)(struct sock___49 *, struct sockaddr *, int);
	int (*connect)(struct sock___49 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___49 *, int);
	struct sock___49 * (*accept)(struct sock___49 *, int, int *, bool);
	int (*ioctl)(struct sock___49 *, int, long unsigned int);
	int (*init)(struct sock___49 *);
	void (*destroy)(struct sock___49 *);
	void (*shutdown)(struct sock___49 *, int);
	int (*setsockopt)(struct sock___49 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___49 *, int, int, char *, int *);
	void (*keepalive)(struct sock___49 *, int);
	int (*compat_ioctl)(struct sock___49 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___49 *, struct msghdr___51 *, size_t);
	int (*recvmsg)(struct sock___49 *, struct msghdr___51 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___49 *, struct page___258 *, int, size_t, int);
	int (*bind)(struct sock___49 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___49 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___49 *, struct sk_buff___63 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___49 *);
	int (*hash)(struct sock___49 *);
	void (*unhash)(struct sock___49 *);
	void (*rehash)(struct sock___49 *);
	int (*get_port)(struct sock___49 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___49 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___49 *, int);
	bool (*sock_is_readable)(struct sock___49 *);
	void (*enter_memory_pressure)(struct sock___49 *);
	void (*leave_memory_pressure)(struct sock___49 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___37 *rsk_prot;
	struct timewait_sock_ops___37 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___237 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___49 *, int);
};

struct sock_reuseport___13 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___56 *prog;
	struct sock___49 *socks[0];
};

struct request_sock___38;

struct request_sock_ops___37 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___49 *, struct request_sock___38 *);
	void (*send_ack)(const struct sock___49 *, struct sk_buff___63 *, struct request_sock___38 *);
	void (*send_reset)(const struct sock___49 *, struct sk_buff___63 *);
	void (*destructor)(struct request_sock___38 *);
	void (*syn_ack_timeout)(const struct request_sock___38 *);
};

struct timewait_sock_ops___37 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___49 *, struct sock___49 *, void *);
	void (*twsk_destructor)(struct sock___49 *);
};

struct request_sock___38 {
	struct sock_common___49 __req_common;
	struct request_sock___38 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___37 *rsk_ops;
	struct sock___49 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___35 {
	struct in6_addr mca_addr;
	struct inet6_dev___35 *idev;
	struct ifmcaddr6___35 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct net_packet_attrs {
	unsigned char *src;
	unsigned char *dst;
	u32 ip_src;
	u32 ip_dst;
	bool tcp;
	u16 sport;
	u16 dport;
	int timeout;
	int size;
	int max_size;
	u8 id;
	u16 queue_mapping;
};

struct net_test_priv {
	struct net_packet_attrs *packet;
	struct packet_type___3 pt;
	struct completion comp;
	int double_vlan;
	int vlan_id;
	int ok;
};

struct netsfhdr {
	__be32 version;
	__be64 magic;
	u8 id;
} __attribute__((packed));

struct net_test {
	char name[32];
	int (*fn)(struct net_device___62 *);
};

struct dentry___254;

struct super_block___254;

struct module___238;

struct file_system_type___254 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___254 * (*mount)(struct file_system_type___254 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___254 *);
	struct module___238 *owner;
	struct file_system_type___254 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___254;

struct kiocb___254;

struct iov_iter___174;

struct poll_table_struct___175;

struct vm_area_struct___259;

struct inode___254;

struct file_lock___254;

struct page___259;

struct pipe_inode_info___95;

struct seq_file___229;

struct file_operations___255 {
	struct module___238 *owner;
	loff_t (*llseek)(struct file___254 *, loff_t, int);
	ssize_t (*read)(struct file___254 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___254 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___254 *, struct iov_iter___174 *);
	ssize_t (*write_iter)(struct kiocb___254 *, struct iov_iter___174 *);
	int (*iopoll)(struct kiocb___254 *, bool);
	int (*iterate)(struct file___254 *, struct dir_context *);
	int (*iterate_shared)(struct file___254 *, struct dir_context *);
	__poll_t (*poll)(struct file___254 *, struct poll_table_struct___175 *);
	long int (*unlocked_ioctl)(struct file___254 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___254 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___254 *, struct vm_area_struct___259 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___254 *, struct file___254 *);
	int (*flush)(struct file___254 *, fl_owner_t);
	int (*release)(struct inode___254 *, struct file___254 *);
	int (*fsync)(struct file___254 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___254 *, int);
	int (*lock)(struct file___254 *, int, struct file_lock___254 *);
	ssize_t (*sendpage)(struct file___254 *, struct page___259 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___254 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___254 *, long unsigned int);
	int (*flock)(struct file___254 *, int, struct file_lock___254 *);
	ssize_t (*splice_write)(struct pipe_inode_info___95 *, struct file___254 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___254 *, loff_t *, struct pipe_inode_info___95 *, size_t, unsigned int);
	int (*setlease)(struct file___254 *, long int, struct file_lock___254 **, void **);
	long int (*fallocate)(struct file___254 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___229 *, struct file___254 *);
	ssize_t (*copy_file_range)(struct file___254 *, loff_t, struct file___254 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___254 *, loff_t, struct file___254 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___254 *, loff_t, loff_t, int);
};

struct vmacache___259 {
	u64 seqnum;
	struct vm_area_struct___259 *vmas[4];
};

struct page_frag___259 {
	struct page___259 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___260;

struct pid___231;

struct nsproxy___240;

struct signal_struct___255;

struct bio_list___145;

struct backing_dev_info___131;

struct io_context___145;

struct css_set___181;

struct mem_cgroup___119;

struct request_queue___145;

struct vm_struct___237;

struct task_struct___261 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___261 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___260 *mm;
	struct mm_struct___260 *active_mm;
	struct vmacache___259 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___261 *real_parent;
	struct task_struct___261 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___261 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___231 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___240 *nsproxy;
	struct signal_struct___255 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___261 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___145 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___131 *backing_dev_info;
	struct io_context___145 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___181 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___95 *splice_pipe;
	struct page_frag___259 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___119 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___119 *active_memcg;
	struct request_queue___145 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___261 *oom_reaper_list;
	struct vm_struct___237 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___242;

struct kobj_type___242;

struct kernfs_node___242;

struct kobject___242 {
	const char *name;
	struct list_head entry;
	struct kobject___242 *parent;
	struct kset___242 *kset;
	struct kobj_type___242 *ktype;
	struct kernfs_node___242 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___239 {
	struct kobject___242 kobj;
	struct module___238 *mod;
	struct kobject___242 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___238 {
	struct module___238 *mod;
	struct latch_tree_node node;
};

struct module_layout___238 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___238 mtn;
};

struct module_attribute___238;

struct kernel_param___238;

struct module___238 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___239 mkobj;
	struct module_attribute___238 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___242 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___238 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___238 core_layout;
	struct module_layout___238 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___254;

struct dentry___254 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___254 *d_parent;
	struct qstr d_name;
	struct inode___254 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___254 *d_op;
	struct super_block___254 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___254;

struct address_space___254 {
	struct inode___254 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___254 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___254;

struct bdi_writeback___131;

struct inode___254 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___254 *i_op;
	struct super_block___254 *i_sb;
	struct address_space___254 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___131 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___255 *i_fop;
		void (*free_inode)(struct inode___254 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___254 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___95 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___254;

struct path___254;

struct dentry_operations___254 {
	int (*d_revalidate)(struct dentry___254 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___254 *, unsigned int);
	int (*d_hash)(const struct dentry___254 *, struct qstr *);
	int (*d_compare)(const struct dentry___254 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___254 *);
	int (*d_init)(struct dentry___254 *);
	void (*d_release)(struct dentry___254 *);
	void (*d_prune)(struct dentry___254 *);
	void (*d_iput)(struct dentry___254 *, struct inode___254 *);
	char * (*d_dname)(struct dentry___254 *, char *, int);
	struct vfsmount___254 * (*d_automount)(struct path___254 *);
	int (*d_manage)(const struct path___254 *, bool);
	struct dentry___254 * (*d_real)(struct dentry___254 *, const struct inode___254 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___254;

struct mem_dqinfo___254 {
	struct quota_format_type___254 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___254;

struct quota_info___254 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___254 *files[3];
	struct mem_dqinfo___254 info[3];
	const struct quota_format_ops___254 *ops[3];
};

struct rcuwait___255 {
	struct task_struct___261 *task;
};

struct percpu_rw_semaphore___255 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___255 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___254 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___255 rw_sem[3];
};

struct shrink_control___119;

struct shrinker___119 {
	long unsigned int (*count_objects)(struct shrinker___119 *, struct shrink_control___119 *);
	long unsigned int (*scan_objects)(struct shrinker___119 *, struct shrink_control___119 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___254;

struct dquot_operations___254;

struct quotactl_ops___254;

struct block_device___148;

struct super_block___254 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___254 *s_type;
	const struct super_operations___254 *s_op;
	const struct dquot_operations___254 *dq_op;
	const struct quotactl_ops___254 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___254 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___148 *s_bdev;
	struct backing_dev_info___131 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___254 s_dquot;
	struct sb_writers___254 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___254 *s_d_op;
	int cleancache_poolid;
	struct shrinker___119 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___254 {
	struct dentry___254 *mnt_root;
	struct super_block___254 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___254 {
	struct vfsmount___254 *mnt;
	struct dentry___254 *dentry;
};

struct pid_namespace___231;

struct upid___231 {
	int nr;
	struct pid_namespace___231 *ns;
};

struct pid_namespace___231 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___261 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___231 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___231 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___231 numbers[1];
};

typedef struct page___259 *pgtable_t___259;

struct page_pool___83;

struct dev_pagemap___249;

struct page___259 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___254 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___83 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___259 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___259 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___260 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___249 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___249;

struct vm_area_struct___259 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___259 *vm_next;
	struct vm_area_struct___259 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___260 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___249 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___254 *vm_file;
	struct file___254 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___255 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___261 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___261 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___231 *pids[4];
	struct pid___231 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___260 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___259;

struct mm_struct___260 {
	struct {
		struct vm_area_struct___259 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___254 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___259 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___261 *owner;
		struct user_namespace___26 *user_ns;
		struct file___254 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___68;

struct cgroup_namespace___181;

struct nsproxy___240 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___231 *pid_ns_for_children;
	struct net___68 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___181 *cgroup_ns;
};

struct bio___145;

struct bio_list___145 {
	struct bio___145 *head;
	struct bio___145 *tail;
};

struct cgroup_subsys_state___181;

struct bdi_writeback___131 {
	struct backing_dev_info___131 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___181 *memcg_css;
	struct cgroup_subsys_state___181 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___235;

struct backing_dev_info___131 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___131 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___235 *dev;
	char dev_name[64];
	struct device___235 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___254 *debug_dir;
};

struct io_cq___145;

struct io_context___145 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___145 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___181;

struct css_set___181 {
	struct cgroup_subsys_state___181 *subsys[14];
	refcount_t refcount;
	struct css_set___181 *dom_cset;
	struct cgroup___181 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___181 *mg_src_cgrp;
	struct cgroup___181 *mg_dst_cgrp;
	struct css_set___181 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___254;

struct pipe_buffer___95;

struct pipe_inode_info___95 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___259 *tmp_page;
	struct fasync_struct___254 *fasync_readers;
	struct fasync_struct___254 *fasync_writers;
	struct pipe_buffer___95 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___181;

struct cgroup_subsys_state___181 {
	struct cgroup___181 *cgroup;
	struct cgroup_subsys___181 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___181 *parent;
};

struct cgroup_file___181 {
	struct kernfs_node___242 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___119;

struct mem_cgroup_per_node___119;

struct mem_cgroup___119 {
	struct cgroup_subsys_state___181 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___181 events_file;
	struct cgroup_file___181 events_local_file;
	struct cgroup_file___181 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___119 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___261 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___119 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___145;

struct blk_integrity___145 {
	const struct blk_integrity_profile___145 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___145 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___145 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___145;

struct elevator_queue___145;

struct blk_mq_ops___140;

struct blk_mq_hw_ctx___140;

struct gendisk___148;

struct blkcg_gq___133;

struct blk_mq_tag_set___140;

struct request_queue___145 {
	struct request___145 *last_merge;
	struct elevator_queue___145 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___140 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___140 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___148 *disk;
	struct kobject___242 kobj;
	struct kobject___242 *mq_kobj;
	struct blk_integrity___145 integrity;
	struct device___235 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___133 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___140 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___145 bio_split;
	struct dentry___254 *debugfs_dir;
	struct dentry___254 *sched_debugfs_dir;
	struct dentry___254 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___237 {
	struct vm_struct___237 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___259 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___119 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___119 *memcg;
};

struct page_pool_params___83 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___235 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___83 {
	u32 count;
	struct page___259 *cache[128];
};

struct page_pool___83 {
	struct page_pool_params___83 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___259 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___83 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___249;

struct dev_pagemap___249 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___249 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___231 {
	rwlock_t lock;
	struct pid___231 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___254 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___254 f_path;
	struct inode___254 *f_inode;
	const struct file_operations___255 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___231 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___254 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___249;

struct vm_operations_struct___249 {
	void (*open)(struct vm_area_struct___259 *);
	void (*close)(struct vm_area_struct___259 *);
	int (*may_split)(struct vm_area_struct___259 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___259 *);
	int (*mprotect)(struct vm_area_struct___259 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___249 *);
	vm_fault_t (*huge_fault)(struct vm_fault___249 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___249 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___259 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___249 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___249 *);
	int (*access)(struct vm_area_struct___259 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___259 *);
	int (*set_policy)(struct vm_area_struct___259 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___259 *, long unsigned int);
	struct page___259 * (*find_special_page)(struct vm_area_struct___259 *, long unsigned int);
};

struct core_thread___259 {
	struct task_struct___261 *task;
	struct core_thread___259 *next;
};

struct core_state___259 {
	atomic_t nr_threads;
	struct core_thread___259 dumper;
	struct completion startup;
};

struct vm_fault___249 {
	const struct {
		struct vm_area_struct___259 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___259 *cow_page;
	struct page___259 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___259 prealloc_pte;
};

struct pglist_data___127;

struct lruvec___127 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___127 *pgdat;
};

struct zone___127 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___127 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___127 {
	struct zone___127 *zone;
	int zone_idx;
};

struct zonelist___127 {
	struct zoneref___127 _zonerefs[321];
};

struct pglist_data___127 {
	struct zone___127 node_zones[5];
	struct zonelist___127 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___261 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___261 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___127 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___181 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___261 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___57;

struct cgroup_bpf___57 {
	struct bpf_prog_array___57 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___57 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___181;

struct cgroup_rstat_cpu___181;

struct cgroup___181 {
	struct cgroup_subsys_state___181 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___242 *kn;
	struct cgroup_file___181 procs_file;
	struct cgroup_file___181 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___181 *subsys[14];
	struct cgroup_root___181 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___181 *dom_cgrp;
	struct cgroup___181 *old_dom_cgrp;
	struct cgroup_rstat_cpu___181 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___181 psi;
	struct cgroup_bpf___57 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___145 {
	struct request_queue___145 *q;
	struct io_context___145 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___254 {
	struct file___254 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___254 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___254 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___254 *ia_file;
};

struct dquot___254 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___254 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___254 {
	int qf_fmt_id;
	const struct quota_format_ops___254 *qf_ops;
	struct module___238 *qf_owner;
	struct quota_format_type___254 *qf_next;
};

struct quota_format_ops___254 {
	int (*check_quota_file)(struct super_block___254 *, int);
	int (*read_file_info)(struct super_block___254 *, int);
	int (*write_file_info)(struct super_block___254 *, int);
	int (*free_file_info)(struct super_block___254 *, int);
	int (*read_dqblk)(struct dquot___254 *);
	int (*commit_dqblk)(struct dquot___254 *);
	int (*release_dqblk)(struct dquot___254 *);
	int (*get_next_id)(struct super_block___254 *, struct kqid *);
};

struct dquot_operations___254 {
	int (*write_dquot)(struct dquot___254 *);
	struct dquot___254 * (*alloc_dquot)(struct super_block___254 *, int);
	void (*destroy_dquot)(struct dquot___254 *);
	int (*acquire_dquot)(struct dquot___254 *);
	int (*release_dquot)(struct dquot___254 *);
	int (*mark_dirty)(struct dquot___254 *);
	int (*write_info)(struct super_block___254 *, int);
	qsize_t * (*get_reserved_space)(struct inode___254 *);
	int (*get_projid)(struct inode___254 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___254 *, qsize_t *);
	int (*get_next_id)(struct super_block___254 *, struct kqid *);
};

struct quotactl_ops___254 {
	int (*quota_on)(struct super_block___254 *, int, int, const struct path___254 *);
	int (*quota_off)(struct super_block___254 *, int);
	int (*quota_enable)(struct super_block___254 *, unsigned int);
	int (*quota_disable)(struct super_block___254 *, unsigned int);
	int (*quota_sync)(struct super_block___254 *, int);
	int (*set_info)(struct super_block___254 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___254 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___254 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___254 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___254 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___254 *, unsigned int);
};

struct writeback_control___131;

struct address_space_operations___254 {
	int (*writepage)(struct page___259 *, struct writeback_control___131 *);
	int (*readpage)(struct file___254 *, struct page___259 *);
	int (*writepages)(struct address_space___254 *, struct writeback_control___131 *);
	int (*set_page_dirty)(struct page___259 *);
	int (*readpages)(struct file___254 *, struct address_space___254 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___254 *, struct address_space___254 *, loff_t, unsigned int, unsigned int, struct page___259 **, void **);
	int (*write_end)(struct file___254 *, struct address_space___254 *, loff_t, unsigned int, unsigned int, struct page___259 *, void *);
	sector_t (*bmap)(struct address_space___254 *, sector_t);
	void (*invalidatepage)(struct page___259 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___259 *, gfp_t);
	void (*freepage)(struct page___259 *);
	ssize_t (*direct_IO)(struct kiocb___254 *, struct iov_iter___174 *);
	int (*migratepage)(struct address_space___254 *, struct page___259 *, struct page___259 *, enum migrate_mode);
	bool (*isolate_page)(struct page___259 *, isolate_mode_t);
	void (*putback_page)(struct page___259 *);
	int (*launder_page)(struct page___259 *);
	int (*is_partially_uptodate)(struct page___259 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___259 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___254 *, struct page___259 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___254 *, sector_t *);
	void (*swap_deactivate)(struct file___254 *);
};

struct writeback_control___131 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___131 *wb;
	struct inode___254 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___171;

struct iov_iter___174 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___171 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___95 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___254 {
	struct dentry___254 * (*lookup)(struct inode___254 *, struct dentry___254 *, unsigned int);
	const char * (*get_link)(struct dentry___254 *, struct inode___254 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___254 *, int);
	struct posix_acl * (*get_acl)(struct inode___254 *, int, bool);
	int (*readlink)(struct dentry___254 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___254 *, struct dentry___254 *, umode_t, bool);
	int (*link)(struct dentry___254 *, struct inode___254 *, struct dentry___254 *);
	int (*unlink)(struct inode___254 *, struct dentry___254 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___254 *, struct dentry___254 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___254 *, struct dentry___254 *, umode_t);
	int (*rmdir)(struct inode___254 *, struct dentry___254 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___254 *, struct dentry___254 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___254 *, struct dentry___254 *, struct inode___254 *, struct dentry___254 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___254 *, struct iattr___254 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___254 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___254 *, char *, size_t);
	int (*fiemap)(struct inode___254 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___254 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___254 *, struct dentry___254 *, struct file___254 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___254 *, struct dentry___254 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___254 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___254 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___254 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___254 {
	void (*fl_copy_lock)(struct file_lock___254 *, struct file_lock___254 *);
	void (*fl_release_private)(struct file_lock___254 *);
};

struct lock_manager_operations___254;

struct file_lock___254 {
	struct file_lock___254 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___254 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___254 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___254 *fl_ops;
	const struct lock_manager_operations___254 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___254 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___254 *);
	int (*lm_grant)(struct file_lock___254 *, int);
	bool (*lm_break)(struct file_lock___254 *);
	int (*lm_change)(struct file_lock___254 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___254 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___254 *);
};

struct fasync_struct___254 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___254 *fa_next;
	struct file___254 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___254 {
	struct inode___254 * (*alloc_inode)(struct super_block___254 *);
	void (*destroy_inode)(struct inode___254 *);
	void (*free_inode)(struct inode___254 *);
	void (*dirty_inode)(struct inode___254 *, int);
	int (*write_inode)(struct inode___254 *, struct writeback_control___131 *);
	int (*drop_inode)(struct inode___254 *);
	void (*evict_inode)(struct inode___254 *);
	void (*put_super)(struct super_block___254 *);
	int (*sync_fs)(struct super_block___254 *, int);
	int (*freeze_super)(struct super_block___254 *);
	int (*freeze_fs)(struct super_block___254 *);
	int (*thaw_super)(struct super_block___254 *);
	int (*unfreeze_fs)(struct super_block___254 *);
	int (*statfs)(struct dentry___254 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___254 *, int *, char *);
	void (*umount_begin)(struct super_block___254 *);
	int (*show_options)(struct seq_file___229 *, struct dentry___254 *);
	int (*show_devname)(struct seq_file___229 *, struct dentry___254 *);
	int (*show_path)(struct seq_file___229 *, struct dentry___254 *);
	int (*show_stats)(struct seq_file___229 *, struct dentry___254 *);
	ssize_t (*quota_read)(struct super_block___254 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___254 *, int, const char *, size_t, loff_t);
	struct dquot___254 ** (*get_dquots)(struct inode___254 *);
	long int (*nr_cached_objects)(struct super_block___254 *, struct shrink_control___119 *);
	long int (*free_cached_objects)(struct super_block___254 *, struct shrink_control___119 *);
	struct file___254 * (*real_loop)(struct file___254 *);
};

struct wakeup_source___235;

struct dev_pm_info___235 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___235 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___235 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___235;

struct bus_type___235;

struct device_driver___235;

struct dev_pm_domain___235;

struct fwnode_handle___231;

struct class___235;

struct attribute_group___242;

struct device___235 {
	struct kobject___242 kobj;
	struct device___235 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___235 *type;
	struct bus_type___235 *bus;
	struct device_driver___235 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___235 power;
	struct dev_pm_domain___235 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___231 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___235 *class;
	const struct attribute_group___242 **groups;
	void (*release)(struct device___235 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___148 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___254 *bd_inode;
	struct super_block___254 *bd_super;
	void *bd_claiming;
	struct device___235 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___242 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___148 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___254 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___183)(struct file___254 *, wait_queue_head_t *, struct poll_table_struct___175 *);

struct poll_table_struct___175 {
	poll_queue_proc___183 _qproc;
	__poll_t _key;
};

struct seq_operations___229;

struct seq_file___229 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___229 *op;
	int poll_event;
	const struct file___254 *file;
	void *private;
};

typedef void bio_end_io_t___145(struct bio___145 *);

struct bio_vec___171 {
	struct page___259 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___145;

struct bio___145 {
	struct bio___145 *bi_next;
	struct block_device___148 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___145 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___133 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___145 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___171 *bi_io_vec;
	struct bio_set___145 *bi_pool;
	struct bio_vec___171 bi_inline_vecs[0];
};

struct dev_pagemap_ops___249 {
	void (*page_free)(struct page___259 *);
	void (*kill)(struct dev_pagemap___249 *);
	void (*cleanup)(struct dev_pagemap___249 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___249 *);
};

struct fwnode_operations___231;

struct fwnode_handle___231 {
	struct fwnode_handle___231 *secondary;
	const struct fwnode_operations___231 *ops;
	struct device___235 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___231;

struct fwnode_endpoint___231;

struct fwnode_operations___231 {
	struct fwnode_handle___231 * (*get)(struct fwnode_handle___231 *);
	void (*put)(struct fwnode_handle___231 *);
	bool (*device_is_available)(const struct fwnode_handle___231 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___231 *, const struct device___235 *);
	bool (*property_present)(const struct fwnode_handle___231 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___231 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___231 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___231 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*get_parent)(const struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*get_next_child_node)(const struct fwnode_handle___231 *, struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*get_named_child_node)(const struct fwnode_handle___231 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___231 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___231 *);
	struct fwnode_handle___231 * (*graph_get_next_endpoint)(const struct fwnode_handle___231 *, struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*graph_get_remote_endpoint)(const struct fwnode_handle___231 *);
	struct fwnode_handle___231 * (*graph_get_port_parent)(struct fwnode_handle___231 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___231 *, struct fwnode_endpoint___231 *);
	int (*add_links)(struct fwnode_handle___231 *);
};

struct fwnode_endpoint___231 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___231 *local_fwnode;
};

struct fwnode_reference_args___231 {
	struct fwnode_handle___231 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___242;

struct kernfs_elem_dir___242 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___242 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___242;

struct kernfs_root___242 {
	struct kernfs_node___242 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___242 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___242 {
	struct kernfs_node___242 *target_kn;
};

struct kernfs_ops___242;

struct kernfs_elem_attr___242 {
	const struct kernfs_ops___242 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___242 *notify_next;
};

struct kernfs_node___242 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___242 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___242 dir;
		struct kernfs_elem_symlink___242 symlink;
		struct kernfs_elem_attr___242 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___242;

struct kernfs_ops___242 {
	int (*open)(struct kernfs_open_file___242 *);
	void (*release)(struct kernfs_open_file___242 *);
	int (*seq_show)(struct seq_file___229 *, void *);
	void * (*seq_start)(struct seq_file___229 *, loff_t *);
	void * (*seq_next)(struct seq_file___229 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___229 *, void *);
	ssize_t (*read)(struct kernfs_open_file___242 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___242 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___242 *, struct poll_table_struct___175 *);
	int (*mmap)(struct kernfs_open_file___242 *, struct vm_area_struct___259 *);
};

struct kernfs_syscall_ops___242 {
	int (*show_options)(struct seq_file___229 *, struct kernfs_root___242 *);
	int (*mkdir)(struct kernfs_node___242 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___242 *);
	int (*rename)(struct kernfs_node___242 *, struct kernfs_node___242 *, const char *);
	int (*show_path)(struct seq_file___229 *, struct kernfs_node___242 *, struct kernfs_root___242 *);
};

struct kernfs_open_file___242 {
	struct kernfs_node___242 *kn;
	struct file___254 *file;
	struct seq_file___229 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___249 *vm_ops;
};

struct sock___50;

struct kobj_ns_type_operations___50 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___50 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___68 *net;
} possible_net_t___63;

struct proto___50;

struct sock_common___50 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___50 *skc_prot;
	possible_net_t___63 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___50 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___64;

struct sk_buff_head___63 {
	struct sk_buff___64 *next;
	struct sk_buff___64 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___50 {
	struct cgroup___181 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___50;

struct socket_wq___51;

struct dst_entry___50;

struct socket___52;

struct net_device___63;

struct sock___50 {
	struct sock_common___50 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___63 sk_error_queue;
	struct sk_buff___64 *sk_rx_skb_cache;
	struct sk_buff_head___63 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___64 *head;
		struct sk_buff___64 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___50 *sk_filter;
	union {
		struct socket_wq___51 *sk_wq;
		struct socket_wq___51 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___50 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___50 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___64 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___64 *sk_tx_skb_cache;
	struct sk_buff_head___63 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___259 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___50 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___231 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___52 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___50 sk_cgrp_data;
	struct mem_cgroup___119 *sk_memcg;
	void (*sk_state_change)(struct sock___50 *);
	void (*sk_data_ready)(struct sock___50 *);
	void (*sk_write_space)(struct sock___50 *);
	void (*sk_error_report)(struct sock___50 *);
	int (*sk_backlog_rcv)(struct sock___50 *, struct sk_buff___64 *);
	struct sk_buff___64 * (*sk_validate_xmit_skb)(struct sock___50 *, struct net_device___63 *, struct sk_buff___64 *);
	void (*sk_destruct)(struct sock___50 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___242;

struct attribute_group___242 {
	const char *name;
	umode_t (*is_visible)(struct kobject___242 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___242 *, struct bin_attribute___242 *, int);
	struct attribute **attrs;
	struct bin_attribute___242 **bin_attrs;
};

struct bin_attribute___242 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___254 * (*f_mapping)();
	ssize_t (*read)(struct file___254 *, struct kobject___242 *, struct bin_attribute___242 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___254 *, struct kobject___242 *, struct bin_attribute___242 *, char *, loff_t, size_t);
	int (*mmap)(struct file___254 *, struct kobject___242 *, struct bin_attribute___242 *, struct vm_area_struct___259 *);
};

struct sysfs_ops___242 {
	ssize_t (*show)(struct kobject___242 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___242 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___242;

struct kset___242 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___242 kobj;
	const struct kset_uevent_ops___242 *uevent_ops;
};

struct kobj_type___242 {
	void (*release)(struct kobject___242 *);
	const struct sysfs_ops___242 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___242 **default_groups;
	const struct kobj_ns_type_operations___50 * (*child_ns_type)(struct kobject___242 *);
	const void * (*namespace)(struct kobject___242 *);
	void (*get_ownership)(struct kobject___242 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___242 {
	int (* const filter)(struct kset___242 *, struct kobject___242 *);
	const char * (* const name)(struct kset___242 *, struct kobject___242 *);
	int (* const uevent)(struct kset___242 *, struct kobject___242 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___238 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___238 *);
	int (*get)(char *, const struct kernel_param___238 *);
	void (*free)(void *);
};

struct kparam_array___238;

struct kernel_param___238 {
	const char *name;
	struct module___238 *mod;
	const struct kernel_param_ops___238 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___238 *arr;
	};
};

struct kparam_array___238 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___238 *ops;
	void *elem;
};

struct module_attribute___238 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___238 *, struct module_kobject___239 *, char *);
	ssize_t (*store)(struct module_attribute___238 *, struct module_kobject___239 *, const char *, size_t);
	void (*setup)(struct module___238 *, const char *);
	int (*test)(struct module___238 *);
	void (*free)(struct module___238 *);
};

struct ip_ra_chain___29;

struct fib_rules_ops___50;

struct fqdir___68;

struct fib_notifier_ops___50;

struct netns_ipv4___68 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___29 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___50 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___50 *fibnl;
	struct sock___50 **icmp_sk;
	struct sock___50 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___50 **tcp_sk;
	struct fqdir___68 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___50 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___50 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___50 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___50;

struct dst_ops___68 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___68 *);
	struct dst_entry___50 * (*check)(struct dst_entry___50 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___50 *);
	unsigned int (*mtu)(const struct dst_entry___50 *);
	u32 * (*cow_metrics)(struct dst_entry___50 *, long unsigned int);
	void (*destroy)(struct dst_entry___50 *);
	void (*ifdown)(struct dst_entry___50 *, struct net_device___63 *, int);
	struct dst_entry___50 * (*negative_advice)(struct dst_entry___50 *);
	void (*link_failure)(struct sk_buff___64 *);
	void (*update_pmtu)(struct dst_entry___50 *, struct sock___50 *, struct sk_buff___64 *, u32, bool);
	void (*redirect)(struct dst_entry___50 *, struct sock___50 *, struct sk_buff___64 *);
	int (*local_out)(struct net___68 *, struct sock___50 *, struct sk_buff___64 *);
	struct neighbour___50 * (*neigh_lookup)(const struct dst_entry___50 *, struct sk_buff___64 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___50 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___68 {
	struct dst_ops___68 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___68 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___50 *fib6_rules_ops;
	struct sock___50 **icmp_sk;
	struct sock___50 *ndisc_sk;
	struct sock___50 *tcp_sk;
	struct sock___50 *igmp_sk;
	struct sock___50 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___50 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___50 *notifier_ops;
	struct fib_notifier_ops___50 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___68 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___68 *fqdir;
};

struct netns_sctp___50 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___50 *ctl_sock;
	struct sock___50 *udp4_sock;
	struct sock___50 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___57;

struct netns_bpf___57 {
	struct bpf_prog_array___57 *run_array[2];
	struct bpf_prog___57 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___68 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___50 *nlsk;
	struct sock___50 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___68 xfrm4_dst_ops;
	struct dst_ops___68 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___68 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___50 *rtnl;
	struct sock___50 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___63 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___68 ipv4;
	struct netns_ipv6___68 ipv6;
	struct netns_ieee802154_lowpan___68 ieee802154_lowpan;
	struct netns_sctp___50 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___63 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___57 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___68 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___50 *crypto_nlsk;
	struct sock___50 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___181 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___181 *root_cset;
};

struct msghdr___52 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___174 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___254 *msg_iocb;
};

struct socket_wq___51 {
	wait_queue_head_t wait;
	struct fasync_struct___254 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___51;

struct socket___52 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___254 *file;
	struct sock___50 *sk;
	const struct proto_ops___51 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___51 wq;
};

typedef int (*sk_read_actor_t___50)(read_descriptor_t *, struct sk_buff___64 *, unsigned int, size_t);

struct proto_ops___51 {
	int family;
	struct module___238 *owner;
	int (*release)(struct socket___52 *);
	int (*bind)(struct socket___52 *, struct sockaddr *, int);
	int (*connect)(struct socket___52 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___52 *, struct socket___52 *);
	int (*accept)(struct socket___52 *, struct socket___52 *, int, bool);
	int (*getname)(struct socket___52 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___254 *, struct socket___52 *, struct poll_table_struct___175 *);
	int (*ioctl)(struct socket___52 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___52 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___52 *, void *, bool, bool);
	int (*listen)(struct socket___52 *, int);
	int (*shutdown)(struct socket___52 *, int);
	int (*setsockopt)(struct socket___52 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___52 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___229 *, struct socket___52 *);
	int (*sendmsg)(struct socket___52 *, struct msghdr___52 *, size_t);
	int (*recvmsg)(struct socket___52 *, struct msghdr___52 *, size_t, int);
	int (*mmap)(struct file___254 *, struct socket___52 *, struct vm_area_struct___259 *);
	ssize_t (*sendpage)(struct socket___52 *, struct page___259 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___52 *, loff_t *, struct pipe_inode_info___95 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___50 *, int);
	int (*peek_len)(struct socket___52 *);
	int (*read_sock)(struct sock___50 *, read_descriptor_t *, sk_read_actor_t___50);
	int (*sendpage_locked)(struct sock___50 *, struct page___259 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___50 *, struct msghdr___52 *, size_t);
	int (*set_rcvlowat)(struct sock___50 *, int);
};

struct sk_buff___64 {
	union {
		struct {
			struct sk_buff___64 *next;
			struct sk_buff___64 *prev;
			union {
				struct net_device___63 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___50 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___64 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___235 {
	int (*prepare)(struct device___235 *);
	void (*complete)(struct device___235 *);
	int (*suspend)(struct device___235 *);
	int (*resume)(struct device___235 *);
	int (*freeze)(struct device___235 *);
	int (*thaw)(struct device___235 *);
	int (*poweroff)(struct device___235 *);
	int (*restore)(struct device___235 *);
	int (*suspend_late)(struct device___235 *);
	int (*resume_early)(struct device___235 *);
	int (*freeze_late)(struct device___235 *);
	int (*thaw_early)(struct device___235 *);
	int (*poweroff_late)(struct device___235 *);
	int (*restore_early)(struct device___235 *);
	int (*suspend_noirq)(struct device___235 *);
	int (*resume_noirq)(struct device___235 *);
	int (*freeze_noirq)(struct device___235 *);
	int (*thaw_noirq)(struct device___235 *);
	int (*poweroff_noirq)(struct device___235 *);
	int (*restore_noirq)(struct device___235 *);
	int (*runtime_suspend)(struct device___235 *);
	int (*runtime_resume)(struct device___235 *);
	int (*runtime_idle)(struct device___235 *);
};

struct wakeup_source___235 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___235 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___235 {
	struct dev_pm_ops___235 ops;
	int (*start)(struct device___235 *);
	void (*detach)(struct device___235 *, bool);
	int (*activate)(struct device___235 *);
	void (*sync)(struct device___235 *);
	void (*dismiss)(struct device___235 *);
};

struct bus_type___235 {
	const char *name;
	const char *dev_name;
	struct device___235 *dev_root;
	const struct attribute_group___242 **bus_groups;
	const struct attribute_group___242 **dev_groups;
	const struct attribute_group___242 **drv_groups;
	int (*match)(struct device___235 *, struct device_driver___235 *);
	int (*uevent)(struct device___235 *, struct kobj_uevent_env *);
	int (*probe)(struct device___235 *);
	void (*sync_state)(struct device___235 *);
	void (*remove)(struct device___235 *);
	void (*shutdown)(struct device___235 *);
	int (*online)(struct device___235 *);
	int (*offline)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	int (*num_vf)(struct device___235 *);
	int (*dma_configure)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___235 {
	const char *name;
	struct bus_type___235 *bus;
	struct module___238 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___235 *);
	void (*sync_state)(struct device___235 *);
	int (*remove)(struct device___235 *);
	void (*shutdown)(struct device___235 *);
	int (*suspend)(struct device___235 *, pm_message_t);
	int (*resume)(struct device___235 *);
	const struct attribute_group___242 **groups;
	const struct attribute_group___242 **dev_groups;
	const struct dev_pm_ops___235 *pm;
	void (*coredump)(struct device___235 *);
	struct driver_private *p;
};

struct device_type___235 {
	const char *name;
	const struct attribute_group___242 **groups;
	int (*uevent)(struct device___235 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___235 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___235 *);
	const struct dev_pm_ops___235 *pm;
};

struct class___235 {
	const char *name;
	struct module___238 *owner;
	const struct attribute_group___242 **class_groups;
	const struct attribute_group___242 **dev_groups;
	struct kobject___242 *dev_kobj;
	int (*dev_uevent)(struct device___235 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___235 *, umode_t *);
	void (*class_release)(struct class___235 *);
	void (*dev_release)(struct device___235 *);
	int (*shutdown_pre)(struct device___235 *);
	const struct kobj_ns_type_operations___50 *ns_type;
	const void * (*namespace)(struct device___235 *);
	void (*get_ownership)(struct device___235 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___235 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___95;

struct pipe_buffer___95 {
	struct page___259 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___95 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___95 {
	int (*confirm)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
	void (*release)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
	bool (*try_steal)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
	bool (*get)(struct pipe_inode_info___95 *, struct pipe_buffer___95 *);
};

typedef rx_handler_result_t rx_handler_func_t___63(struct sk_buff___64 **);

struct bpf_xdp_entity___57 {
	struct bpf_prog___57 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___63;

struct net_device_ops___63;

struct ethtool_ops___28;

struct l3mdev_ops___50;

struct ndisc_ops___36;

struct xfrmdev_ops___63;

struct header_ops___63;

struct inet6_dev___36;

struct netdev_rx_queue___63;

struct mini_Qdisc___57;

struct netdev_queue___63;

struct Qdisc___57;

struct rtnl_link_ops___57;

struct dcbnl_rtnl_ops___63;

struct phy_device___12;

struct net_device___63 {
	char name[16];
	struct netdev_name_node___63 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___63 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___28 *ethtool_ops;
	const struct l3mdev_ops___50 *l3mdev_ops;
	const struct ndisc_ops___36 *ndisc_ops;
	const struct xfrmdev_ops___63 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___63 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___242 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___36 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___63 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___57 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___63 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___57 *miniq_ingress;
	struct netdev_queue___63 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___63 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___57 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___57 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___63 = 0,
		NETREG_REGISTERED___63 = 1,
		NETREG_UNREGISTERING___63 = 2,
		NETREG_UNREGISTERED___63 = 3,
		NETREG_RELEASED___63 = 4,
		NETREG_DUMMY___63 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___63 = 0,
		RTNL_LINK_INITIALIZING___63 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___63 *);
	struct netpoll_info *npinfo;
	possible_net_t___63 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___235 dev;
	const struct attribute_group___242 *sysfs_groups[4];
	const struct attribute_group___242 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___57 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___63 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___12 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___57 xdp_state[3];
	long: 64;
};

struct inet_frags___68;

struct fqdir___68 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___68 *f;
	struct net___68 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___68;

struct inet_frags___68 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___68 *, const void *);
	void (*destructor)(struct inet_frag_queue___68 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___68 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___64 *fragments_tail;
	struct sk_buff___64 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___68 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___29 {
	struct ip_ra_chain___29 *next;
	struct sock___50 *sk;
	union {
		void (*destructor)(struct sock___50 *);
		struct sock___50 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___50;

struct fib_lookup_arg___50;

struct fib_rules_ops___50 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___50 *, struct flowi *, int, struct fib_lookup_arg___50 *);
	bool (*suppress)(struct fib_rule___50 *, int, struct fib_lookup_arg___50 *);
	int (*match)(struct fib_rule___50 *, struct flowi *, int);
	int (*configure)(struct fib_rule___50 *, struct sk_buff___64 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___50 *);
	int (*compare)(struct fib_rule___50 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___50 *, struct sk_buff___64 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___50 *);
	void (*flush_cache)(struct fib_rules_ops___50 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___238 *owner;
	struct net___68 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___50 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___68 *);
	int (*fib_dump)(struct net___68 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___238 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___30;

struct dst_entry___50 {
	struct net_device___63 *dev;
	struct dst_ops___68 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___64 *);
	int (*output)(struct net___68 *, struct sock___50 *, struct sk_buff___64 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___30 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___50;

struct neigh_parms___50;

struct neigh_ops___50;

struct neighbour___50 {
	struct neighbour___50 *next;
	struct neigh_table___50 *tbl;
	struct neigh_parms___50 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___63 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___50 *, struct sk_buff___64 *);
	const struct neigh_ops___50 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___63 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___57 {
	struct bpf_prog___57 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___57 {
	struct callback_head rcu;
	struct bpf_prog_array_item___57 items[0];
};

struct bpf_prog_aux___66;

struct bpf_prog___57 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___66 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___229 {
	void * (*start)(struct seq_file___229 *, loff_t *);
	void (*stop)(struct seq_file___229 *, void *);
	void * (*next)(struct seq_file___229 *, void *, loff_t *);
	int (*show)(struct seq_file___229 *, void *);
};

struct dcbnl_rtnl_ops___63 {
	int (*ieee_getets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___63 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___63 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___63 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___63 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___63 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___63 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___63 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___63 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___63 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___63 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___63 *);
	u8 (*setstate)(struct net_device___63 *, u8);
	void (*getpermhwaddr)(struct net_device___63 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___63 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___63 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___63 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___63 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___63 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___63 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___63 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___63 *, int, u8 *);
	void (*setpfccfg)(struct net_device___63 *, int, u8);
	void (*getpfccfg)(struct net_device___63 *, int, u8 *);
	u8 (*setall)(struct net_device___63 *);
	u8 (*getcap)(struct net_device___63 *, int, u8 *);
	int (*getnumtcs)(struct net_device___63 *, int, u8 *);
	int (*setnumtcs)(struct net_device___63 *, int, u8);
	u8 (*getpfcstate)(struct net_device___63 *);
	void (*setpfcstate)(struct net_device___63 *, u8);
	void (*getbcncfg)(struct net_device___63 *, int, u32 *);
	void (*setbcncfg)(struct net_device___63 *, int, u32);
	void (*getbcnrp)(struct net_device___63 *, int, u8 *);
	void (*setbcnrp)(struct net_device___63 *, int, u8);
	int (*setapp)(struct net_device___63 *, u8, u16, u8);
	int (*getapp)(struct net_device___63 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___63 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___63 *, int, u8);
	u8 (*getdcbx)(struct net_device___63 *);
	u8 (*setdcbx)(struct net_device___63 *, u8);
	int (*peer_getappinfo)(struct net_device___63 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___63 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___63 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___63 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___63 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___63 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___66;

typedef int (*bpf_iter_init_seq_priv_t___65)(void *, struct bpf_iter_aux_info___66 *);

struct bpf_map___66;

struct bpf_iter_aux_info___66 {
	struct bpf_map___66 *map;
};

struct bpf_iter_seq_info___65 {
	const struct seq_operations___229 *seq_ops;
	bpf_iter_init_seq_priv_t___65 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___65 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___66 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___66 *, struct file___254 *);
	void (*map_free)(struct bpf_map___66 *);
	int (*map_get_next_key)(struct bpf_map___66 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___66 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___66 *, void *);
	int (*map_lookup_batch)(struct bpf_map___66 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___66 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___66 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___66 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___66 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___66 *, void *);
	int (*map_update_elem)(struct bpf_map___66 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___66 *, void *);
	int (*map_push_elem)(struct bpf_map___66 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___66 *, void *);
	int (*map_peek_elem)(struct bpf_map___66 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___66 *, struct file___254 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___66 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___66 *, void *, struct seq_file___229 *);
	int (*map_check_btf)(const struct bpf_map___66 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___66 *, struct bpf_prog_aux___66 *);
	void (*map_poke_untrack)(struct bpf_map___66 *, struct bpf_prog_aux___66 *);
	void (*map_poke_run)(struct bpf_map___66 *, u32, struct bpf_prog___57 *, struct bpf_prog___57 *);
	int (*map_direct_value_addr)(const struct bpf_map___66 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___66 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___66 *, struct vm_area_struct___259 *);
	__poll_t (*map_poll)(struct bpf_map___66 *, struct file___254 *, struct poll_table_struct___175 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___66 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___66 *, const struct bpf_map___66 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___66 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___65 *iter_seq_info;
};

struct bpf_map___66 {
	const struct bpf_map_ops___65 *ops;
	struct bpf_map___66 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___119 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___65;

struct bpf_jit_poke_descriptor___65;

struct bpf_prog_ops___57;

struct btf_mod_pair___65;

struct bpf_prog_offload___63;

struct bpf_prog_aux___66 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___57 *dst_prog;
	struct bpf_trampoline___65 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___57 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___65 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___57 *ops;
	struct bpf_map___66 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___65 *used_btfs;
	struct bpf_prog___57 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___66 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___63 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___63;

struct bpf_map_dev_ops___63 {
	int (*map_get_next_key)(struct bpf_offloaded_map___63 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___63 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___63 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___63 *, void *);
};

struct bpf_offloaded_map___63 {
	struct bpf_map___66 map;
	struct net_device___63 *netdev;
	const struct bpf_map_dev_ops___63 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___57 {
	int (*test_run)(struct bpf_prog___57 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___63 {
	struct bpf_prog___57 *prog;
	struct net_device___63 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___65 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___57 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___238 *mod;
};

struct bpf_jit_poke_descriptor___65 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___66 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___65 {
	struct btf *btf;
	struct module___238 *module;
};

struct cftype___181;

struct cgroup_subsys___181 {
	struct cgroup_subsys_state___181 * (*css_alloc)(struct cgroup_subsys_state___181 *);
	int (*css_online)(struct cgroup_subsys_state___181 *);
	void (*css_offline)(struct cgroup_subsys_state___181 *);
	void (*css_released)(struct cgroup_subsys_state___181 *);
	void (*css_free)(struct cgroup_subsys_state___181 *);
	void (*css_reset)(struct cgroup_subsys_state___181 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___181 *, int);
	int (*css_extra_stat_show)(struct seq_file___229 *, struct cgroup_subsys_state___181 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___261 *, struct css_set___181 *);
	void (*cancel_fork)(struct task_struct___261 *, struct css_set___181 *);
	void (*fork)(struct task_struct___261 *);
	void (*exit)(struct task_struct___261 *);
	void (*release)(struct task_struct___261 *);
	void (*bind)(struct cgroup_subsys_state___181 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___181 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___181 *dfl_cftypes;
	struct cftype___181 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___181 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___181 *updated_children;
	struct cgroup___181 *updated_next;
};

struct cgroup_root___181 {
	struct kernfs_root___242 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___181 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___181 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___181 *ss;
	struct list_head node;
	struct kernfs_ops___242 *kf_ops;
	int (*open)(struct kernfs_open_file___242 *);
	void (*release)(struct kernfs_open_file___242 *);
	u64 (*read_u64)(struct cgroup_subsys_state___181 *, struct cftype___181 *);
	s64 (*read_s64)(struct cgroup_subsys_state___181 *, struct cftype___181 *);
	int (*seq_show)(struct seq_file___229 *, void *);
	void * (*seq_start)(struct seq_file___229 *, loff_t *);
	void * (*seq_next)(struct seq_file___229 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___229 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___181 *, struct cftype___181 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___181 *, struct cftype___181 *, s64);
	ssize_t (*write)(struct kernfs_open_file___242 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___242 *, struct poll_table_struct___175 *);
};

struct xdp_rxq_info___63 {
	struct net_device___63 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___63 {
	struct net_device___63 *dev;
};

struct xdp_buff___63 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___63 *rxq;
	struct xdp_txq_info___63 *txq;
	u32 frame_sz;
};

struct xdp_frame___63 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___63 *dev_rx;
};

struct netlink_callback___63 {
	struct sk_buff___64 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___64 *, struct netlink_callback___63 *);
	int (*done)(struct netlink_callback___63 *);
	void *data;
	struct module___238 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___63 {
	int (*create)(struct sk_buff___64 *, struct net_device___63 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___64 *, unsigned char *);
	int (*cache)(const struct neighbour___50 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___63 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___64 *);
};

struct netdev_queue___63 {
	struct net_device___63 *dev;
	struct Qdisc___57 *qdisc;
	struct Qdisc___57 *qdisc_sleeping;
	struct kobject___242 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___63 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___57 {
	struct sk_buff___64 *head;
	struct sk_buff___64 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___57;

struct Qdisc___57 {
	int (*enqueue)(struct sk_buff___64 *, struct Qdisc___57 *, struct sk_buff___64 **);
	struct sk_buff___64 * (*dequeue)(struct Qdisc___57 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___57 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___63 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___63 gso_skb;
	struct qdisc_skb_head___57 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___57 *next_sched;
	struct sk_buff_head___63 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___63 {
	struct xdp_rxq_info___63 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___242 kobj;
	struct net_device___63 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___63 {
	enum net_device_path_type type;
	const struct net_device___63 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___63 = 0,
				DEV_PATH_BR_VLAN_TAG___63 = 1,
				DEV_PATH_BR_VLAN_UNTAG___63 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___63 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___63 {
	const struct net_device___63 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___63 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___57 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___63 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___63 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___64 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___63 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___63 *dev;
	const char *name;
};

struct net_device_ops___63 {
	int (*ndo_init)(struct net_device___63 *);
	void (*ndo_uninit)(struct net_device___63 *);
	int (*ndo_open)(struct net_device___63 *);
	int (*ndo_stop)(struct net_device___63 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___64 *, struct net_device___63 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___64 *, struct net_device___63 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___63 *, struct sk_buff___64 *, struct net_device___63 *);
	void (*ndo_change_rx_flags)(struct net_device___63 *, int);
	void (*ndo_set_rx_mode)(struct net_device___63 *);
	int (*ndo_set_mac_address)(struct net_device___63 *, void *);
	int (*ndo_validate_addr)(struct net_device___63 *);
	int (*ndo_do_ioctl)(struct net_device___63 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___63 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___63 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___63 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___63 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___63 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___63 *, int);
	int (*ndo_neigh_setup)(struct net_device___63 *, struct neigh_parms___50 *);
	void (*ndo_tx_timeout)(struct net_device___63 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___63 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___63 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___63 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___63 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___63 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___63 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___63 *);
	int (*ndo_netpoll_setup)(struct net_device___63 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___63 *);
	int (*ndo_set_vf_mac)(struct net_device___63 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___63 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___63 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___63 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___63 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___63 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___63 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___63 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___63 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___63 *, int, struct sk_buff___64 *);
	int (*ndo_get_vf_guid)(struct net_device___63 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___63 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___63 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___63 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___63 *);
	int (*ndo_fcoe_disable)(struct net_device___63 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___63 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___63 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___63 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___63 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___63 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___63 *, const struct sk_buff___64 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___63 *, struct net_device___63 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___63 *, struct net_device___63 *);
	struct net_device___63 * (*ndo_get_xmit_slave)(struct net_device___63 *, struct sk_buff___64 *, bool);
	struct net_device___63 * (*ndo_sk_get_lower_dev)(struct net_device___63 *, struct sock___50 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___63 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___63 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___63 *, struct neighbour___50 *);
	void (*ndo_neigh_destroy)(struct net_device___63 *, struct neighbour___50 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___64 *, struct netlink_callback___63 *, struct net_device___63 *, struct net_device___63 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___64 *, struct nlattr **, struct net_device___63 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___63 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___64 *, u32, u32, struct net_device___63 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___63 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___63 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___63 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___63 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___63 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___63 *, struct net_device___63 *);
	void (*ndo_dfwd_del_station)(struct net_device___63 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___63 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___63 *);
	int (*ndo_change_proto_down)(struct net_device___63 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___63 *, struct sk_buff___64 *);
	void (*ndo_set_rx_headroom)(struct net_device___63 *, int);
	int (*ndo_bpf)(struct net_device___63 *, struct netdev_bpf___63 *);
	int (*ndo_xdp_xmit)(struct net_device___63 *, int, struct xdp_frame___63 **, u32);
	struct net_device___63 * (*ndo_xdp_get_xmit_slave)(struct net_device___63 *, struct xdp_buff___63 *);
	int (*ndo_xsk_wakeup)(struct net_device___63 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___63 *);
	int (*ndo_tunnel_ctl)(struct net_device___63 *, struct ip_tunnel_parm *, int);
	struct net_device___63 * (*ndo_get_peer_dev)(struct net_device___63 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___63 *, struct net_device_path___63 *);
};

struct neigh_parms___50 {
	possible_net_t___63 net;
	struct net_device___63 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___50 *);
	struct neigh_table___50 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ethtool_ops___28 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___63 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___63 *);
	void (*get_regs)(struct net_device___63 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___63 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___63 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___63 *);
	void (*set_msglevel)(struct net_device___63 *, u32);
	int (*nway_reset)(struct net_device___63 *);
	u32 (*get_link)(struct net_device___63 *);
	int (*get_link_ext_state)(struct net_device___63 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___63 *);
	int (*get_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___63 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___63 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___63 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___63 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___63 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___63 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___63 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___63 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___63 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___63 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___63 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___63 *);
	void (*complete)(struct net_device___63 *);
	u32 (*get_priv_flags)(struct net_device___63 *);
	int (*set_priv_flags)(struct net_device___63 *, u32);
	int (*get_sset_count)(struct net_device___63 *, int);
	int (*get_rxnfc)(struct net_device___63 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___63 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___63 *, struct ethtool_flash *);
	int (*reset)(struct net_device___63 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___63 *);
	u32 (*get_rxfh_indir_size)(struct net_device___63 *);
	int (*get_rxfh)(struct net_device___63 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___63 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___63 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___63 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___63 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___63 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___63 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___63 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___63 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___63 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___63 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___63 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___63 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___63 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___63 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___63 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___63 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___63 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___63 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___63 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___63 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___63 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___63 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___63 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___63 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___63 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___63 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___63 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___63 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___63 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___63 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___50 {
	u32 (*l3mdev_fib_table)(const struct net_device___63 *);
	struct sk_buff___64 * (*l3mdev_l3_rcv)(struct net_device___63 *, struct sk_buff___64 *, u16);
	struct sk_buff___64 * (*l3mdev_l3_out)(struct net_device___63 *, struct sock___50 *, struct sk_buff___64 *, u16);
	struct dst_entry___50 * (*l3mdev_link_scope_lookup)(const struct net_device___63 *, struct flowi6 *);
};

struct ndisc_ops___36 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___63 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___63 *, struct neighbour___50 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___63 *, u8, struct neighbour___50 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___63 *, struct sk_buff___64 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___68 *, struct net_device___63 *, const struct prefix_info *, struct inet6_dev___36 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___36;

struct inet6_dev___36 {
	struct net_device___63 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___36 *mc_list;
	struct ifmcaddr6___36 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___63 mc_query_queue;
	struct sk_buff_head___63 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___9 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___50 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___57;

struct tcf_block___57;

struct mini_Qdisc___57 {
	struct tcf_proto___57 *filter_list;
	struct tcf_block___57 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___57 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___63 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___63 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___68 *, struct net_device___63 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___63 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___63 *, struct list_head *);
	size_t (*get_size)(const struct net_device___63 *);
	int (*fill_info)(struct sk_buff___64 *, const struct net_device___63 *);
	size_t (*get_xstats_size)(const struct net_device___63 *);
	int (*fill_xstats)(struct sk_buff___64 *, const struct net_device___63 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___63 *, struct net_device___63 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___63 *, const struct net_device___63 *);
	int (*fill_slave_info)(struct sk_buff___64 *, const struct net_device___63 *, const struct net_device___63 *);
	struct net___68 * (*get_link_net)(const struct net_device___63 *);
	size_t (*get_linkxstats_size)(const struct net_device___63 *, int);
	int (*fill_linkxstats)(struct sk_buff___64 *, const struct net_device___63 *, int *, int);
};

struct mii_bus___15;

struct mdio_device___15 {
	struct device___235 dev;
	struct mii_bus___15 *bus;
	char modalias[32];
	int (*bus_match)(struct device___235 *, struct device_driver___235 *);
	void (*device_free)(struct mdio_device___15 *);
	void (*device_remove)(struct mdio_device___15 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___12;

struct mii_timestamper___12;

struct phy_device___12 {
	struct mdio_device___15 mdio;
	struct phy_driver___12 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___64 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___63 *attached_dev;
	struct mii_timestamper___12 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___12 *, bool);
	void (*adjust_link)(struct net_device___63 *);
	const struct macsec_ops *macsec_ops;
};

struct block_device_operations___145;

struct gendisk___148 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___148 *part0;
	const struct block_device_operations___145 *fops;
	struct request_queue___145 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___131 *bdi;
	struct kobject___242 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___242 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___145 {
	struct bio___145 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___171 *bip_vec;
	struct bio_vec___171 bip_inline_vecs[0];
};

struct blkcg___133;

struct blkg_policy_data___133;

struct blkcg_gq___133 {
	struct request_queue___145 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___133 *blkcg;
	struct blkcg_gq___133 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___133 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___145 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___145(struct request___145 *);

typedef void integrity_complete_fn___145(struct request___145 *, unsigned int);

struct blk_integrity_profile___145 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___145 *prepare_fn;
	integrity_complete_fn___145 *complete_fn;
	const char *name;
};

struct block_device_operations___145 {
	blk_qc_t (*submit_bio)(struct bio___145 *);
	int (*open)(struct block_device___148 *, fmode_t);
	void (*release)(struct gendisk___148 *, fmode_t);
	int (*rw_page)(struct block_device___148 *, sector_t, struct page___259 *, unsigned int);
	int (*ioctl)(struct block_device___148 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___148 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___148 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___148 *);
	int (*getgeo)(struct block_device___148 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___148 *, bool);
	void (*swap_slot_free_notify)(struct block_device___148 *, long unsigned int);
	int (*report_zones)(struct gendisk___148 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___148 *, umode_t *);
	struct module___238 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___148 *, sector_t *);
};

typedef void rq_end_io_fn___145(struct request___145 *, blk_status_t);

struct request___145 {
	struct request_queue___145 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___140 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___145 *bio;
	struct bio___145 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___171 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___145 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___145 *saved_end_io;
		} flush;
	};
	struct gendisk___148 *rq_disk;
	struct block_device___148 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___145 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___140 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___145 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___242 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___254 *debugfs_dir;
	struct dentry___254 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___145;

struct elevator_mq_ops___145 {
	int (*init_sched)(struct request_queue___145 *, struct elevator_type___145 *);
	void (*exit_sched)(struct elevator_queue___145 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___140 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___140 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___140 *);
	bool (*allow_merge)(struct request_queue___145 *, struct request___145 *, struct bio___145 *);
	bool (*bio_merge)(struct request_queue___145 *, struct bio___145 *, unsigned int);
	int (*request_merge)(struct request_queue___145 *, struct request___145 **, struct bio___145 *);
	void (*request_merged)(struct request_queue___145 *, struct request___145 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___145 *, struct request___145 *, struct request___145 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___145 *);
	void (*finish_request)(struct request___145 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___140 *, struct list_head *, bool);
	struct request___145 * (*dispatch_request)(struct blk_mq_hw_ctx___140 *);
	bool (*has_work)(struct blk_mq_hw_ctx___140 *);
	void (*completed_request)(struct request___145 *, u64);
	void (*requeue_request)(struct request___145 *);
	struct request___145 * (*former_request)(struct request_queue___145 *, struct request___145 *);
	struct request___145 * (*next_request)(struct request_queue___145 *, struct request___145 *);
	void (*init_icq)(struct io_cq___145 *);
	void (*exit_icq)(struct io_cq___145 *);
};

struct elv_fs_entry___145;

struct elevator_type___145 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___145 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___145 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___238 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___145 {
	struct elevator_type___145 *type;
	void *elevator_data;
	struct kobject___242 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___145 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___145 *, char *);
	ssize_t (*store)(struct elevator_queue___145 *, const char *, size_t);
};

struct blk_mq_queue_data___140;

struct blk_mq_ops___140 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___140 *, const struct blk_mq_queue_data___140 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___140 *);
	int (*get_budget)(struct request_queue___145 *);
	void (*put_budget)(struct request_queue___145 *, int);
	void (*set_rq_budget_token)(struct request___145 *, int);
	int (*get_rq_budget_token)(struct request___145 *);
	enum blk_eh_timer_return (*timeout)(struct request___145 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___140 *);
	void (*complete)(struct request___145 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___140 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___140 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___140 *, struct request___145 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___140 *, struct request___145 *, unsigned int);
	void (*initialize_rq_fn)(struct request___145 *);
	void (*cleanup_rq)(struct request___145 *);
	bool (*busy)(struct request_queue___145 *);
	int (*map_queues)(struct blk_mq_tag_set___140 *);
	void (*show_rq)(struct seq_file___229 *, struct request___145 *);
};

struct blk_mq_tag_set___140 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___140 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___140 {
	struct request___145 *rq;
	bool last;
};

struct blkcg_policy_data___133;

struct blkcg___133 {
	struct cgroup_subsys_state___181 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___133 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___133 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___133 {
	struct blkcg___133 *blkcg;
	int plid;
};

struct blkg_policy_data___133 {
	struct blkcg_gq___133 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___119 {
	struct mem_cgroup___119 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___119 {
	struct lruvec___127 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___119 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___119 *memcg;
};

struct obj_cgroup___119 {
	struct percpu_ref refcnt;
	struct mem_cgroup___119 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___57 {
	spinlock_t *lock;
	struct sk_buff___64 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___57;

struct Qdisc_ops___57 {
	struct Qdisc_ops___57 *next;
	const struct Qdisc_class_ops___57 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___64 *, struct Qdisc___57 *, struct sk_buff___64 **);
	struct sk_buff___64 * (*dequeue)(struct Qdisc___57 *);
	struct sk_buff___64 * (*peek)(struct Qdisc___57 *);
	int (*init)(struct Qdisc___57 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___57 *);
	void (*destroy)(struct Qdisc___57 *);
	int (*change)(struct Qdisc___57 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___57 *);
	int (*change_tx_queue_len)(struct Qdisc___57 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___57 *, unsigned int);
	int (*dump)(struct Qdisc___57 *, struct sk_buff___64 *);
	int (*dump_stats)(struct Qdisc___57 *, struct gnet_dump___57 *);
	void (*ingress_block_set)(struct Qdisc___57 *, u32);
	void (*egress_block_set)(struct Qdisc___57 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___57 *);
	u32 (*egress_block_get)(struct Qdisc___57 *);
	struct module___238 *owner;
};

struct Qdisc_class_ops___57 {
	unsigned int flags;
	struct netdev_queue___63 * (*select_queue)(struct Qdisc___57 *, struct tcmsg *);
	int (*graft)(struct Qdisc___57 *, long unsigned int, struct Qdisc___57 *, struct Qdisc___57 **, struct netlink_ext_ack *);
	struct Qdisc___57 * (*leaf)(struct Qdisc___57 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___57 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___57 *, u32);
	int (*change)(struct Qdisc___57 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___57 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___57 *, struct qdisc_walker *);
	struct tcf_block___57 * (*tcf_block)(struct Qdisc___57 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___57 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___57 *, long unsigned int);
	int (*dump)(struct Qdisc___57 *, long unsigned int, struct sk_buff___64 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___57 *, long unsigned int, struct gnet_dump___57 *);
};

struct tcf_chain___57;

struct tcf_block___57 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___68 *net;
	struct Qdisc___57 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___57 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___57;

struct tcf_proto_ops___57;

struct tcf_proto___57 {
	struct tcf_proto___57 *next;
	void *root;
	int (*classify)(struct sk_buff___64 *, const struct tcf_proto___57 *, struct tcf_result___57 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___57 *ops;
	struct tcf_chain___57 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___57 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___57 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___57 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___64 *, const struct tcf_proto___57 *, struct tcf_result___57 *);
	int (*init)(struct tcf_proto___57 *);
	void (*destroy)(struct tcf_proto___57 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___57 *, u32);
	void (*put)(struct tcf_proto___57 *, void *);
	int (*change)(struct net___68 *, struct sk_buff___64 *, struct tcf_proto___57 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___57 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___57 *);
	void (*walk)(struct tcf_proto___57 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___57 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___57 *, void *);
	void (*hw_del)(struct tcf_proto___57 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___68 *, struct tcf_chain___57 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___68 *, struct tcf_proto___57 *, void *, struct sk_buff___64 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___68 *, struct tcf_proto___57 *, void *, struct sk_buff___64 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___64 *, struct net___68 *, void *);
	struct module___238 *owner;
	int flags;
};

struct tcf_chain___57 {
	struct mutex filter_chain_lock;
	struct tcf_proto___57 *filter_chain;
	struct list_head list;
	struct tcf_block___57 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___57 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___50 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___57 *prog;
};

struct pneigh_entry___50;

struct neigh_hash_table___50;

struct neigh_table___50 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___63 *, __u32 *);
	bool (*key_eq)(const struct neighbour___50 *, const void *);
	int (*constructor)(struct neighbour___50 *);
	int (*pconstructor)(struct pneigh_entry___50 *);
	void (*pdestructor)(struct pneigh_entry___50 *);
	void (*proxy_redo)(struct sk_buff___64 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___63 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___50 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___63 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___50 *nht;
	struct pneigh_entry___50 **phash_buckets;
};

struct neigh_ops___50 {
	int family;
	void (*solicit)(struct neighbour___50 *, struct sk_buff___64 *);
	void (*error_report)(struct neighbour___50 *, struct sk_buff___64 *);
	int (*output)(struct neighbour___50 *, struct sk_buff___64 *);
	int (*connected_output)(struct neighbour___50 *, struct sk_buff___64 *);
};

struct pneigh_entry___50 {
	struct pneigh_entry___50 *next;
	possible_net_t___63 net;
	struct net_device___63 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___50 {
	struct neighbour___50 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___30 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___68 *, struct sock___50 *, struct sk_buff___64 *);
	int (*orig_input)(struct sk_buff___64 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___50 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___50 *ctarget;
	struct net___68 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___50 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___50 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___38;

struct timewait_sock_ops___38;

struct proto___50 {
	void (*close)(struct sock___50 *, long int);
	int (*pre_connect)(struct sock___50 *, struct sockaddr *, int);
	int (*connect)(struct sock___50 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___50 *, int);
	struct sock___50 * (*accept)(struct sock___50 *, int, int *, bool);
	int (*ioctl)(struct sock___50 *, int, long unsigned int);
	int (*init)(struct sock___50 *);
	void (*destroy)(struct sock___50 *);
	void (*shutdown)(struct sock___50 *, int);
	int (*setsockopt)(struct sock___50 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___50 *, int, int, char *, int *);
	void (*keepalive)(struct sock___50 *, int);
	int (*compat_ioctl)(struct sock___50 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___50 *, struct msghdr___52 *, size_t);
	int (*recvmsg)(struct sock___50 *, struct msghdr___52 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___50 *, struct page___259 *, int, size_t, int);
	int (*bind)(struct sock___50 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___50 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___50 *, struct sk_buff___64 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___50 *);
	int (*hash)(struct sock___50 *);
	void (*unhash)(struct sock___50 *);
	void (*rehash)(struct sock___50 *);
	int (*get_port)(struct sock___50 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___50 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___50 *, int);
	bool (*sock_is_readable)(struct sock___50 *);
	void (*enter_memory_pressure)(struct sock___50 *);
	void (*leave_memory_pressure)(struct sock___50 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___38 *rsk_prot;
	struct timewait_sock_ops___38 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___238 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___50 *, int);
};

struct request_sock___39;

struct request_sock_ops___38 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___50 *, struct request_sock___39 *);
	void (*send_ack)(const struct sock___50 *, struct sk_buff___64 *, struct request_sock___39 *);
	void (*send_reset)(const struct sock___50 *, struct sk_buff___64 *);
	void (*destructor)(struct request_sock___39 *);
	void (*syn_ack_timeout)(const struct request_sock___39 *);
};

struct timewait_sock_ops___38 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___50 *, struct sock___50 *, void *);
	void (*twsk_destructor)(struct sock___50 *);
};

struct request_sock___39 {
	struct sock_common___50 __req_common;
	struct request_sock___39 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___38 *rsk_ops;
	struct sock___50 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___36 {
	struct in6_addr mca_addr;
	struct inet6_dev___36 *idev;
	struct ifmcaddr6___36 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct mii_bus___15 {
	struct module___238 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___15 *, int, int);
	int (*write)(struct mii_bus___15 *, int, int, u16);
	int (*reset)(struct mii_bus___15 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___235 *parent;
	enum {
		MDIOBUS_ALLOCATED___15 = 1,
		MDIOBUS_REGISTERED___15 = 2,
		MDIOBUS_UNREGISTERED___15 = 3,
		MDIOBUS_RELEASED___15 = 4,
	} state;
	struct device___235 dev;
	struct mdio_device___15 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___15 = 0,
		MDIOBUS_C22___15 = 1,
		MDIOBUS_C45___15 = 2,
		MDIOBUS_C22_C45___15 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___14 {
	struct device_driver___235 driver;
	int flags;
};

struct mii_timestamper___12 {
	bool (*rxtstamp)(struct mii_timestamper___12 *, struct sk_buff___64 *, int);
	void (*txtstamp)(struct mii_timestamper___12 *, struct sk_buff___64 *, int);
	int (*hwtstamp)(struct mii_timestamper___12 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___12 *, struct phy_device___12 *);
	int (*ts_info)(struct mii_timestamper___12 *, struct ethtool_ts_info *);
	struct device___235 *device;
};

struct phy_driver___12 {
	struct mdio_driver_common___14 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___12 *);
	int (*config_init)(struct phy_device___12 *);
	int (*probe)(struct phy_device___12 *);
	int (*get_features)(struct phy_device___12 *);
	int (*suspend)(struct phy_device___12 *);
	int (*resume)(struct phy_device___12 *);
	int (*config_aneg)(struct phy_device___12 *);
	int (*aneg_done)(struct phy_device___12 *);
	int (*read_status)(struct phy_device___12 *);
	int (*config_intr)(struct phy_device___12 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___12 *);
	void (*remove)(struct phy_device___12 *);
	int (*match_phy_device)(struct phy_device___12 *);
	int (*set_wol)(struct phy_device___12 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___12 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___12 *);
	int (*read_mmd)(struct phy_device___12 *, int, u16);
	int (*write_mmd)(struct phy_device___12 *, int, u16, u16);
	int (*read_page)(struct phy_device___12 *);
	int (*write_page)(struct phy_device___12 *, int);
	int (*module_info)(struct phy_device___12 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___12 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___12 *);
	int (*cable_test_tdr_start)(struct phy_device___12 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___12 *, bool *);
	int (*get_sset_count)(struct phy_device___12 *);
	void (*get_strings)(struct phy_device___12 *, u8 *);
	void (*get_stats)(struct phy_device___12 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___12 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___12 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___12 *, bool);
	int (*get_sqi)(struct phy_device___12 *);
	int (*get_sqi_max)(struct phy_device___12 *);
};

struct dentry___255;

struct super_block___255;

struct module___239;

struct file_system_type___255 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___255 * (*mount)(struct file_system_type___255 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___255 *);
	struct module___239 *owner;
	struct file_system_type___255 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___255;

struct kiocb___255;

struct iov_iter___175;

struct poll_table_struct___176;

struct vm_area_struct___260;

struct inode___255;

struct file_lock___255;

struct page___260;

struct pipe_inode_info___96;

struct seq_file___230;

struct file_operations___256 {
	struct module___239 *owner;
	loff_t (*llseek)(struct file___255 *, loff_t, int);
	ssize_t (*read)(struct file___255 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___255 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___255 *, struct iov_iter___175 *);
	ssize_t (*write_iter)(struct kiocb___255 *, struct iov_iter___175 *);
	int (*iopoll)(struct kiocb___255 *, bool);
	int (*iterate)(struct file___255 *, struct dir_context *);
	int (*iterate_shared)(struct file___255 *, struct dir_context *);
	__poll_t (*poll)(struct file___255 *, struct poll_table_struct___176 *);
	long int (*unlocked_ioctl)(struct file___255 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___255 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___255 *, struct vm_area_struct___260 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___255 *, struct file___255 *);
	int (*flush)(struct file___255 *, fl_owner_t);
	int (*release)(struct inode___255 *, struct file___255 *);
	int (*fsync)(struct file___255 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___255 *, int);
	int (*lock)(struct file___255 *, int, struct file_lock___255 *);
	ssize_t (*sendpage)(struct file___255 *, struct page___260 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___255 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___255 *, long unsigned int);
	int (*flock)(struct file___255 *, int, struct file_lock___255 *);
	ssize_t (*splice_write)(struct pipe_inode_info___96 *, struct file___255 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___255 *, loff_t *, struct pipe_inode_info___96 *, size_t, unsigned int);
	int (*setlease)(struct file___255 *, long int, struct file_lock___255 **, void **);
	long int (*fallocate)(struct file___255 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___230 *, struct file___255 *);
	ssize_t (*copy_file_range)(struct file___255 *, loff_t, struct file___255 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___255 *, loff_t, struct file___255 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___255 *, loff_t, loff_t, int);
};

struct vmacache___260 {
	u64 seqnum;
	struct vm_area_struct___260 *vmas[4];
};

struct page_frag___260 {
	struct page___260 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___261;

struct pid___232;

struct files_struct___22;

struct nsproxy___241;

struct signal_struct___256;

struct bio_list___146;

struct backing_dev_info___132;

struct io_context___146;

struct css_set___182;

struct mem_cgroup___120;

struct request_queue___146;

struct vm_struct___238;

struct task_struct___262 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___262 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___261 *mm;
	struct mm_struct___261 *active_mm;
	struct vmacache___260 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___262 *real_parent;
	struct task_struct___262 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___262 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___232 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___22 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___241 *nsproxy;
	struct signal_struct___256 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___262 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___146 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___132 *backing_dev_info;
	struct io_context___146 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___182 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___96 *splice_pipe;
	struct page_frag___260 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___120 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___120 *active_memcg;
	struct request_queue___146 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___262 *oom_reaper_list;
	struct vm_struct___238 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___243;

struct kobj_type___243;

struct kernfs_node___243;

struct kobject___243 {
	const char *name;
	struct list_head entry;
	struct kobject___243 *parent;
	struct kset___243 *kset;
	struct kobj_type___243 *ktype;
	struct kernfs_node___243 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___240 {
	struct kobject___243 kobj;
	struct module___239 *mod;
	struct kobject___243 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___239 {
	struct module___239 *mod;
	struct latch_tree_node node;
};

struct module_layout___239 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___239 mtn;
};

struct module_attribute___239;

struct kernel_param___239;

struct module___239 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___240 mkobj;
	struct module_attribute___239 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___243 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___239 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___239 core_layout;
	struct module_layout___239 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___232;

struct upid___232 {
	int nr;
	struct pid_namespace___232 *ns;
};

struct pid_namespace___232 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___262 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___232 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___232 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___232 numbers[1];
};

typedef struct page___260 *pgtable_t___260;

struct address_space___255;

struct page_pool___84;

struct dev_pagemap___250;

struct page___260 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___255 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___84 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___260 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___260 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___261 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___250 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___250;

struct vm_area_struct___260 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___260 *vm_next;
	struct vm_area_struct___260 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___261 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___250 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___255 *vm_file;
	struct file___255 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___256 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___262 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___262 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___232 *pids[4];
	struct pid___232 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___261 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___260;

struct mm_struct___261 {
	struct {
		struct vm_area_struct___260 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___255 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___260 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___262 *owner;
		struct user_namespace___26 *user_ns;
		struct file___255 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct fdtable___22 {
	unsigned int max_fds;
	struct file___255 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___22 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___22 *fdt;
	struct fdtable___22 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___255 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___69;

struct cgroup_namespace___182;

struct nsproxy___241 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___232 *pid_ns_for_children;
	struct net___69 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___182 *cgroup_ns;
};

struct bio___146;

struct bio_list___146 {
	struct bio___146 *head;
	struct bio___146 *tail;
};

struct cgroup_subsys_state___182;

struct bdi_writeback___132 {
	struct backing_dev_info___132 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___182 *memcg_css;
	struct cgroup_subsys_state___182 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___236;

struct backing_dev_info___132 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___132 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___236 *dev;
	char dev_name[64];
	struct device___236 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___255 *debug_dir;
};

struct io_cq___146;

struct io_context___146 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___146 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___182;

struct css_set___182 {
	struct cgroup_subsys_state___182 *subsys[14];
	refcount_t refcount;
	struct css_set___182 *dom_cset;
	struct cgroup___182 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___182 *mg_src_cgrp;
	struct cgroup___182 *mg_dst_cgrp;
	struct css_set___182 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___255;

struct pipe_buffer___96;

struct pipe_inode_info___96 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___260 *tmp_page;
	struct fasync_struct___255 *fasync_readers;
	struct fasync_struct___255 *fasync_writers;
	struct pipe_buffer___96 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___182;

struct cgroup_subsys_state___182 {
	struct cgroup___182 *cgroup;
	struct cgroup_subsys___182 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___182 *parent;
};

struct cgroup_file___182 {
	struct kernfs_node___243 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___120;

struct mem_cgroup_per_node___120;

struct mem_cgroup___120 {
	struct cgroup_subsys_state___182 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___182 events_file;
	struct cgroup_file___182 events_local_file;
	struct cgroup_file___182 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___120 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___262 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___120 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___146;

struct blk_integrity___146 {
	const struct blk_integrity_profile___146 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___146 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___146 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___146;

struct elevator_queue___146;

struct blk_mq_ops___141;

struct blk_mq_hw_ctx___141;

struct gendisk___149;

struct blkcg_gq___134;

struct blk_mq_tag_set___141;

struct request_queue___146 {
	struct request___146 *last_merge;
	struct elevator_queue___146 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___141 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___141 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___149 *disk;
	struct kobject___243 kobj;
	struct kobject___243 *mq_kobj;
	struct blk_integrity___146 integrity;
	struct device___236 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___134 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___141 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___146 bio_split;
	struct dentry___255 *debugfs_dir;
	struct dentry___255 *sched_debugfs_dir;
	struct dentry___255 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___238 {
	struct vm_struct___238 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___260 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___255;

struct address_space___255 {
	struct inode___255 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___255 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___84 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___236 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___84 {
	u32 count;
	struct page___260 *cache[128];
};

struct page_pool___84 {
	struct page_pool_params___84 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___260 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___84 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___250;

struct dev_pagemap___250 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___250 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___255;

struct path___255 {
	struct vfsmount___255 *mnt;
	struct dentry___255 *dentry;
};

struct fown_struct___232 {
	rwlock_t lock;
	struct pid___232 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___255 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___255 f_path;
	struct inode___255 *f_inode;
	const struct file_operations___256 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___232 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___255 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___250;

struct vm_operations_struct___250 {
	void (*open)(struct vm_area_struct___260 *);
	void (*close)(struct vm_area_struct___260 *);
	int (*may_split)(struct vm_area_struct___260 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___260 *);
	int (*mprotect)(struct vm_area_struct___260 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___250 *);
	vm_fault_t (*huge_fault)(struct vm_fault___250 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___250 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___260 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___250 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___250 *);
	int (*access)(struct vm_area_struct___260 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___260 *);
	int (*set_policy)(struct vm_area_struct___260 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___260 *, long unsigned int);
	struct page___260 * (*find_special_page)(struct vm_area_struct___260 *, long unsigned int);
};

struct core_thread___260 {
	struct task_struct___262 *task;
	struct core_thread___260 *next;
};

struct core_state___260 {
	atomic_t nr_threads;
	struct core_thread___260 dumper;
	struct completion startup;
};

struct vm_fault___250 {
	const struct {
		struct vm_area_struct___260 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___260 *cow_page;
	struct page___260 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___260 prealloc_pte;
};

struct pglist_data___128;

struct lruvec___128 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___128 *pgdat;
};

struct zone___128 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___128 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___128 {
	struct zone___128 *zone;
	int zone_idx;
};

struct zonelist___128 {
	struct zoneref___128 _zonerefs[321];
};

struct pglist_data___128 {
	struct zone___128 node_zones[5];
	struct zonelist___128 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___262 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___262 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___128 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___255;

struct dentry___255 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___255 *d_parent;
	struct qstr d_name;
	struct inode___255 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___255 *d_op;
	struct super_block___255 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___255;

struct inode___255 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___255 *i_op;
	struct super_block___255 *i_sb;
	struct address_space___255 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___132 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___256 *i_fop;
		void (*free_inode)(struct inode___255 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___255 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___96 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___255 {
	int (*d_revalidate)(struct dentry___255 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___255 *, unsigned int);
	int (*d_hash)(const struct dentry___255 *, struct qstr *);
	int (*d_compare)(const struct dentry___255 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___255 *);
	int (*d_init)(struct dentry___255 *);
	void (*d_release)(struct dentry___255 *);
	void (*d_prune)(struct dentry___255 *);
	void (*d_iput)(struct dentry___255 *, struct inode___255 *);
	char * (*d_dname)(struct dentry___255 *, char *, int);
	struct vfsmount___255 * (*d_automount)(struct path___255 *);
	int (*d_manage)(const struct path___255 *, bool);
	struct dentry___255 * (*d_real)(struct dentry___255 *, const struct inode___255 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___255;

struct mem_dqinfo___255 {
	struct quota_format_type___255 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___255;

struct quota_info___255 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___255 *files[3];
	struct mem_dqinfo___255 info[3];
	const struct quota_format_ops___255 *ops[3];
};

struct rcuwait___256 {
	struct task_struct___262 *task;
};

struct percpu_rw_semaphore___256 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___256 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___255 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___256 rw_sem[3];
};

struct shrink_control___120;

struct shrinker___120 {
	long unsigned int (*count_objects)(struct shrinker___120 *, struct shrink_control___120 *);
	long unsigned int (*scan_objects)(struct shrinker___120 *, struct shrink_control___120 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___255;

struct dquot_operations___255;

struct quotactl_ops___255;

struct block_device___149;

struct super_block___255 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___255 *s_type;
	const struct super_operations___255 *s_op;
	const struct dquot_operations___255 *dq_op;
	const struct quotactl_ops___255 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___255 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___149 *s_bdev;
	struct backing_dev_info___132 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___255 s_dquot;
	struct sb_writers___255 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___255 *s_d_op;
	int cleancache_poolid;
	struct shrinker___120 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___255 {
	struct dentry___255 *mnt_root;
	struct super_block___255 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___120 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___120 *memcg;
};

struct psi_group___182 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___262 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___58;

struct cgroup_bpf___58 {
	struct bpf_prog_array___58 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___58 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___182;

struct cgroup_rstat_cpu___182;

struct cgroup___182 {
	struct cgroup_subsys_state___182 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___243 *kn;
	struct cgroup_file___182 procs_file;
	struct cgroup_file___182 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___182 *subsys[14];
	struct cgroup_root___182 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___182 *dom_cgrp;
	struct cgroup___182 *old_dom_cgrp;
	struct cgroup_rstat_cpu___182 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___182 psi;
	struct cgroup_bpf___58 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___146 {
	struct request_queue___146 *q;
	struct io_context___146 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___255 {
	struct file___255 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___255 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___255 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___255 *ia_file;
};

struct dquot___255 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___255 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___255 {
	int qf_fmt_id;
	const struct quota_format_ops___255 *qf_ops;
	struct module___239 *qf_owner;
	struct quota_format_type___255 *qf_next;
};

struct quota_format_ops___255 {
	int (*check_quota_file)(struct super_block___255 *, int);
	int (*read_file_info)(struct super_block___255 *, int);
	int (*write_file_info)(struct super_block___255 *, int);
	int (*free_file_info)(struct super_block___255 *, int);
	int (*read_dqblk)(struct dquot___255 *);
	int (*commit_dqblk)(struct dquot___255 *);
	int (*release_dqblk)(struct dquot___255 *);
	int (*get_next_id)(struct super_block___255 *, struct kqid *);
};

struct dquot_operations___255 {
	int (*write_dquot)(struct dquot___255 *);
	struct dquot___255 * (*alloc_dquot)(struct super_block___255 *, int);
	void (*destroy_dquot)(struct dquot___255 *);
	int (*acquire_dquot)(struct dquot___255 *);
	int (*release_dquot)(struct dquot___255 *);
	int (*mark_dirty)(struct dquot___255 *);
	int (*write_info)(struct super_block___255 *, int);
	qsize_t * (*get_reserved_space)(struct inode___255 *);
	int (*get_projid)(struct inode___255 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___255 *, qsize_t *);
	int (*get_next_id)(struct super_block___255 *, struct kqid *);
};

struct quotactl_ops___255 {
	int (*quota_on)(struct super_block___255 *, int, int, const struct path___255 *);
	int (*quota_off)(struct super_block___255 *, int);
	int (*quota_enable)(struct super_block___255 *, unsigned int);
	int (*quota_disable)(struct super_block___255 *, unsigned int);
	int (*quota_sync)(struct super_block___255 *, int);
	int (*set_info)(struct super_block___255 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___255 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___255 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___255 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___255 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___255 *, unsigned int);
};

struct writeback_control___132;

struct address_space_operations___255 {
	int (*writepage)(struct page___260 *, struct writeback_control___132 *);
	int (*readpage)(struct file___255 *, struct page___260 *);
	int (*writepages)(struct address_space___255 *, struct writeback_control___132 *);
	int (*set_page_dirty)(struct page___260 *);
	int (*readpages)(struct file___255 *, struct address_space___255 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___255 *, struct address_space___255 *, loff_t, unsigned int, unsigned int, struct page___260 **, void **);
	int (*write_end)(struct file___255 *, struct address_space___255 *, loff_t, unsigned int, unsigned int, struct page___260 *, void *);
	sector_t (*bmap)(struct address_space___255 *, sector_t);
	void (*invalidatepage)(struct page___260 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___260 *, gfp_t);
	void (*freepage)(struct page___260 *);
	ssize_t (*direct_IO)(struct kiocb___255 *, struct iov_iter___175 *);
	int (*migratepage)(struct address_space___255 *, struct page___260 *, struct page___260 *, enum migrate_mode);
	bool (*isolate_page)(struct page___260 *, isolate_mode_t);
	void (*putback_page)(struct page___260 *);
	int (*launder_page)(struct page___260 *);
	int (*is_partially_uptodate)(struct page___260 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___260 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___255 *, struct page___260 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___255 *, sector_t *);
	void (*swap_deactivate)(struct file___255 *);
};

struct writeback_control___132 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___132 *wb;
	struct inode___255 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___172;

struct iov_iter___175 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___172 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___96 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___255 {
	struct dentry___255 * (*lookup)(struct inode___255 *, struct dentry___255 *, unsigned int);
	const char * (*get_link)(struct dentry___255 *, struct inode___255 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___255 *, int);
	struct posix_acl * (*get_acl)(struct inode___255 *, int, bool);
	int (*readlink)(struct dentry___255 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___255 *, struct dentry___255 *, umode_t, bool);
	int (*link)(struct dentry___255 *, struct inode___255 *, struct dentry___255 *);
	int (*unlink)(struct inode___255 *, struct dentry___255 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___255 *, struct dentry___255 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___255 *, struct dentry___255 *, umode_t);
	int (*rmdir)(struct inode___255 *, struct dentry___255 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___255 *, struct dentry___255 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___255 *, struct dentry___255 *, struct inode___255 *, struct dentry___255 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___255 *, struct iattr___255 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___255 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___255 *, char *, size_t);
	int (*fiemap)(struct inode___255 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___255 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___255 *, struct dentry___255 *, struct file___255 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___255 *, struct dentry___255 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___255 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___255 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___255 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___255 {
	void (*fl_copy_lock)(struct file_lock___255 *, struct file_lock___255 *);
	void (*fl_release_private)(struct file_lock___255 *);
};

struct lock_manager_operations___255;

struct file_lock___255 {
	struct file_lock___255 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___255 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___255 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___255 *fl_ops;
	const struct lock_manager_operations___255 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___255 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___255 *);
	int (*lm_grant)(struct file_lock___255 *, int);
	bool (*lm_break)(struct file_lock___255 *);
	int (*lm_change)(struct file_lock___255 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___255 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___255 *);
};

struct fasync_struct___255 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___255 *fa_next;
	struct file___255 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___255 {
	struct inode___255 * (*alloc_inode)(struct super_block___255 *);
	void (*destroy_inode)(struct inode___255 *);
	void (*free_inode)(struct inode___255 *);
	void (*dirty_inode)(struct inode___255 *, int);
	int (*write_inode)(struct inode___255 *, struct writeback_control___132 *);
	int (*drop_inode)(struct inode___255 *);
	void (*evict_inode)(struct inode___255 *);
	void (*put_super)(struct super_block___255 *);
	int (*sync_fs)(struct super_block___255 *, int);
	int (*freeze_super)(struct super_block___255 *);
	int (*freeze_fs)(struct super_block___255 *);
	int (*thaw_super)(struct super_block___255 *);
	int (*unfreeze_fs)(struct super_block___255 *);
	int (*statfs)(struct dentry___255 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___255 *, int *, char *);
	void (*umount_begin)(struct super_block___255 *);
	int (*show_options)(struct seq_file___230 *, struct dentry___255 *);
	int (*show_devname)(struct seq_file___230 *, struct dentry___255 *);
	int (*show_path)(struct seq_file___230 *, struct dentry___255 *);
	int (*show_stats)(struct seq_file___230 *, struct dentry___255 *);
	ssize_t (*quota_read)(struct super_block___255 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___255 *, int, const char *, size_t, loff_t);
	struct dquot___255 ** (*get_dquots)(struct inode___255 *);
	long int (*nr_cached_objects)(struct super_block___255 *, struct shrink_control___120 *);
	long int (*free_cached_objects)(struct super_block___255 *, struct shrink_control___120 *);
	struct file___255 * (*real_loop)(struct file___255 *);
};

struct wakeup_source___236;

struct dev_pm_info___236 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___236 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___236 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___236;

struct bus_type___236;

struct device_driver___236;

struct dev_pm_domain___236;

struct fwnode_handle___232;

struct class___236;

struct attribute_group___243;

struct device___236 {
	struct kobject___243 kobj;
	struct device___236 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___236 *type;
	struct bus_type___236 *bus;
	struct device_driver___236 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___236 power;
	struct dev_pm_domain___236 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___232 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___236 *class;
	const struct attribute_group___243 **groups;
	void (*release)(struct device___236 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___149 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___255 *bd_inode;
	struct super_block___255 *bd_super;
	void *bd_claiming;
	struct device___236 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___243 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___149 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___255 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___184)(struct file___255 *, wait_queue_head_t *, struct poll_table_struct___176 *);

struct poll_table_struct___176 {
	poll_queue_proc___184 _qproc;
	__poll_t _key;
};

struct seq_operations___230;

struct seq_file___230 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___230 *op;
	int poll_event;
	const struct file___255 *file;
	void *private;
};

typedef void bio_end_io_t___146(struct bio___146 *);

struct bio_vec___172 {
	struct page___260 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___146;

struct bio___146 {
	struct bio___146 *bi_next;
	struct block_device___149 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___146 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___134 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___146 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___172 *bi_io_vec;
	struct bio_set___146 *bi_pool;
	struct bio_vec___172 bi_inline_vecs[0];
};

struct kernfs_root___243;

struct kernfs_elem_dir___243 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___243 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___243;

struct kernfs_root___243 {
	struct kernfs_node___243 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___243 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___243 {
	struct kernfs_node___243 *target_kn;
};

struct kernfs_ops___243;

struct kernfs_elem_attr___243 {
	const struct kernfs_ops___243 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___243 *notify_next;
};

struct kernfs_node___243 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___243 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___243 dir;
		struct kernfs_elem_symlink___243 symlink;
		struct kernfs_elem_attr___243 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___243;

struct kernfs_ops___243 {
	int (*open)(struct kernfs_open_file___243 *);
	void (*release)(struct kernfs_open_file___243 *);
	int (*seq_show)(struct seq_file___230 *, void *);
	void * (*seq_start)(struct seq_file___230 *, loff_t *);
	void * (*seq_next)(struct seq_file___230 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___230 *, void *);
	ssize_t (*read)(struct kernfs_open_file___243 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___243 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___243 *, struct poll_table_struct___176 *);
	int (*mmap)(struct kernfs_open_file___243 *, struct vm_area_struct___260 *);
};

struct kernfs_syscall_ops___243 {
	int (*show_options)(struct seq_file___230 *, struct kernfs_root___243 *);
	int (*mkdir)(struct kernfs_node___243 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___243 *);
	int (*rename)(struct kernfs_node___243 *, struct kernfs_node___243 *, const char *);
	int (*show_path)(struct seq_file___230 *, struct kernfs_node___243 *, struct kernfs_root___243 *);
};

struct kernfs_open_file___243 {
	struct kernfs_node___243 *kn;
	struct file___255 *file;
	struct seq_file___230 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___250 *vm_ops;
};

struct sock___51;

struct kobj_ns_type_operations___51 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___51 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___69 *net;
} possible_net_t___64;

struct proto___51;

struct sock_common___51 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___51 *skc_prot;
	possible_net_t___64 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___51 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___65;

struct sk_buff_head___64 {
	struct sk_buff___65 *next;
	struct sk_buff___65 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___51 {
	struct cgroup___182 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___51;

struct socket_wq___52;

struct dst_entry___51;

struct socket___53;

struct net_device___64;

struct sock___51 {
	struct sock_common___51 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___64 sk_error_queue;
	struct sk_buff___65 *sk_rx_skb_cache;
	struct sk_buff_head___64 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___65 *head;
		struct sk_buff___65 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___51 *sk_filter;
	union {
		struct socket_wq___52 *sk_wq;
		struct socket_wq___52 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___51 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___51 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___65 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___65 *sk_tx_skb_cache;
	struct sk_buff_head___64 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___260 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___51 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___232 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___53 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___51 sk_cgrp_data;
	struct mem_cgroup___120 *sk_memcg;
	void (*sk_state_change)(struct sock___51 *);
	void (*sk_data_ready)(struct sock___51 *);
	void (*sk_write_space)(struct sock___51 *);
	void (*sk_error_report)(struct sock___51 *);
	int (*sk_backlog_rcv)(struct sock___51 *, struct sk_buff___65 *);
	struct sk_buff___65 * (*sk_validate_xmit_skb)(struct sock___51 *, struct net_device___64 *, struct sk_buff___65 *);
	void (*sk_destruct)(struct sock___51 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___243;

struct attribute_group___243 {
	const char *name;
	umode_t (*is_visible)(struct kobject___243 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___243 *, struct bin_attribute___243 *, int);
	struct attribute **attrs;
	struct bin_attribute___243 **bin_attrs;
};

struct bin_attribute___243 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___255 * (*f_mapping)();
	ssize_t (*read)(struct file___255 *, struct kobject___243 *, struct bin_attribute___243 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___255 *, struct kobject___243 *, struct bin_attribute___243 *, char *, loff_t, size_t);
	int (*mmap)(struct file___255 *, struct kobject___243 *, struct bin_attribute___243 *, struct vm_area_struct___260 *);
};

struct sysfs_ops___243 {
	ssize_t (*show)(struct kobject___243 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___243 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___243;

struct kset___243 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___243 kobj;
	const struct kset_uevent_ops___243 *uevent_ops;
};

struct kobj_type___243 {
	void (*release)(struct kobject___243 *);
	const struct sysfs_ops___243 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___243 **default_groups;
	const struct kobj_ns_type_operations___51 * (*child_ns_type)(struct kobject___243 *);
	const void * (*namespace)(struct kobject___243 *);
	void (*get_ownership)(struct kobject___243 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___243 {
	int (* const filter)(struct kset___243 *, struct kobject___243 *);
	const char * (* const name)(struct kset___243 *, struct kobject___243 *);
	int (* const uevent)(struct kset___243 *, struct kobject___243 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___239 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___239 *);
	int (*get)(char *, const struct kernel_param___239 *);
	void (*free)(void *);
};

struct kparam_array___239;

struct kernel_param___239 {
	const char *name;
	struct module___239 *mod;
	const struct kernel_param_ops___239 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___239 *arr;
	};
};

struct kparam_array___239 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___239 *ops;
	void *elem;
};

struct module_attribute___239 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___239 *, struct module_kobject___240 *, char *);
	ssize_t (*store)(struct module_attribute___239 *, struct module_kobject___240 *, const char *, size_t);
	void (*setup)(struct module___239 *, const char *);
	int (*test)(struct module___239 *);
	void (*free)(struct module___239 *);
};

struct dev_pagemap_ops___250 {
	void (*page_free)(struct page___260 *);
	void (*kill)(struct dev_pagemap___250 *);
	void (*cleanup)(struct dev_pagemap___250 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___250 *);
};

struct fwnode_operations___232;

struct fwnode_handle___232 {
	struct fwnode_handle___232 *secondary;
	const struct fwnode_operations___232 *ops;
	struct device___236 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___232;

struct fwnode_endpoint___232;

struct fwnode_operations___232 {
	struct fwnode_handle___232 * (*get)(struct fwnode_handle___232 *);
	void (*put)(struct fwnode_handle___232 *);
	bool (*device_is_available)(const struct fwnode_handle___232 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___232 *, const struct device___236 *);
	bool (*property_present)(const struct fwnode_handle___232 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___232 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___232 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___232 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*get_parent)(const struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*get_next_child_node)(const struct fwnode_handle___232 *, struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*get_named_child_node)(const struct fwnode_handle___232 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___232 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___232 *);
	struct fwnode_handle___232 * (*graph_get_next_endpoint)(const struct fwnode_handle___232 *, struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*graph_get_remote_endpoint)(const struct fwnode_handle___232 *);
	struct fwnode_handle___232 * (*graph_get_port_parent)(struct fwnode_handle___232 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___232 *, struct fwnode_endpoint___232 *);
	int (*add_links)(struct fwnode_handle___232 *);
};

struct fwnode_endpoint___232 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___232 *local_fwnode;
};

struct fwnode_reference_args___232 {
	struct fwnode_handle___232 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___51;

struct fqdir___69;

struct fib_notifier_ops___51;

struct netns_ipv4___69 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___51 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___51 *fibnl;
	struct sock___51 **icmp_sk;
	struct sock___51 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___51 **tcp_sk;
	struct fqdir___69 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___51 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___51 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___51 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___51;

struct dst_ops___69 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___69 *);
	struct dst_entry___51 * (*check)(struct dst_entry___51 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___51 *);
	unsigned int (*mtu)(const struct dst_entry___51 *);
	u32 * (*cow_metrics)(struct dst_entry___51 *, long unsigned int);
	void (*destroy)(struct dst_entry___51 *);
	void (*ifdown)(struct dst_entry___51 *, struct net_device___64 *, int);
	struct dst_entry___51 * (*negative_advice)(struct dst_entry___51 *);
	void (*link_failure)(struct sk_buff___65 *);
	void (*update_pmtu)(struct dst_entry___51 *, struct sock___51 *, struct sk_buff___65 *, u32, bool);
	void (*redirect)(struct dst_entry___51 *, struct sock___51 *, struct sk_buff___65 *);
	int (*local_out)(struct net___69 *, struct sock___51 *, struct sk_buff___65 *);
	struct neighbour___51 * (*neigh_lookup)(const struct dst_entry___51 *, struct sk_buff___65 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___51 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___69 {
	struct dst_ops___69 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___69 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___51 *fib6_rules_ops;
	struct sock___51 **icmp_sk;
	struct sock___51 *ndisc_sk;
	struct sock___51 *tcp_sk;
	struct sock___51 *igmp_sk;
	struct sock___51 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___51 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___51 *notifier_ops;
	struct fib_notifier_ops___51 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___69 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___69 *fqdir;
};

struct netns_sctp___51 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___51 *ctl_sock;
	struct sock___51 *udp4_sock;
	struct sock___51 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___58;

struct netns_bpf___58 {
	struct bpf_prog_array___58 *run_array[2];
	struct bpf_prog___58 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___69 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___51 *nlsk;
	struct sock___51 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___69 xfrm4_dst_ops;
	struct dst_ops___69 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___69 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___51 *rtnl;
	struct sock___51 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___64 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___69 ipv4;
	struct netns_ipv6___69 ipv6;
	struct netns_ieee802154_lowpan___69 ieee802154_lowpan;
	struct netns_sctp___51 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___64 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___58 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___69 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___51 *crypto_nlsk;
	struct sock___51 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___182 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___182 *root_cset;
};

struct msghdr___53 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___175 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___255 *msg_iocb;
};

struct socket_wq___52 {
	wait_queue_head_t wait;
	struct fasync_struct___255 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___52;

struct socket___53 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___255 *file;
	struct sock___51 *sk;
	const struct proto_ops___52 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___52 wq;
};

typedef int (*sk_read_actor_t___51)(read_descriptor_t *, struct sk_buff___65 *, unsigned int, size_t);

struct proto_ops___52 {
	int family;
	struct module___239 *owner;
	int (*release)(struct socket___53 *);
	int (*bind)(struct socket___53 *, struct sockaddr *, int);
	int (*connect)(struct socket___53 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___53 *, struct socket___53 *);
	int (*accept)(struct socket___53 *, struct socket___53 *, int, bool);
	int (*getname)(struct socket___53 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___255 *, struct socket___53 *, struct poll_table_struct___176 *);
	int (*ioctl)(struct socket___53 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___53 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___53 *, void *, bool, bool);
	int (*listen)(struct socket___53 *, int);
	int (*shutdown)(struct socket___53 *, int);
	int (*setsockopt)(struct socket___53 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___53 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___230 *, struct socket___53 *);
	int (*sendmsg)(struct socket___53 *, struct msghdr___53 *, size_t);
	int (*recvmsg)(struct socket___53 *, struct msghdr___53 *, size_t, int);
	int (*mmap)(struct file___255 *, struct socket___53 *, struct vm_area_struct___260 *);
	ssize_t (*sendpage)(struct socket___53 *, struct page___260 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___53 *, loff_t *, struct pipe_inode_info___96 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___51 *, int);
	int (*peek_len)(struct socket___53 *);
	int (*read_sock)(struct sock___51 *, read_descriptor_t *, sk_read_actor_t___51);
	int (*sendpage_locked)(struct sock___51 *, struct page___260 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___51 *, struct msghdr___53 *, size_t);
	int (*set_rcvlowat)(struct sock___51 *, int);
};

struct sk_buff___65 {
	union {
		struct {
			struct sk_buff___65 *next;
			struct sk_buff___65 *prev;
			union {
				struct net_device___64 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___51 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___65 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___236 {
	int (*prepare)(struct device___236 *);
	void (*complete)(struct device___236 *);
	int (*suspend)(struct device___236 *);
	int (*resume)(struct device___236 *);
	int (*freeze)(struct device___236 *);
	int (*thaw)(struct device___236 *);
	int (*poweroff)(struct device___236 *);
	int (*restore)(struct device___236 *);
	int (*suspend_late)(struct device___236 *);
	int (*resume_early)(struct device___236 *);
	int (*freeze_late)(struct device___236 *);
	int (*thaw_early)(struct device___236 *);
	int (*poweroff_late)(struct device___236 *);
	int (*restore_early)(struct device___236 *);
	int (*suspend_noirq)(struct device___236 *);
	int (*resume_noirq)(struct device___236 *);
	int (*freeze_noirq)(struct device___236 *);
	int (*thaw_noirq)(struct device___236 *);
	int (*poweroff_noirq)(struct device___236 *);
	int (*restore_noirq)(struct device___236 *);
	int (*runtime_suspend)(struct device___236 *);
	int (*runtime_resume)(struct device___236 *);
	int (*runtime_idle)(struct device___236 *);
};

struct wakeup_source___236 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___236 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___236 {
	struct dev_pm_ops___236 ops;
	int (*start)(struct device___236 *);
	void (*detach)(struct device___236 *, bool);
	int (*activate)(struct device___236 *);
	void (*sync)(struct device___236 *);
	void (*dismiss)(struct device___236 *);
};

struct bus_type___236 {
	const char *name;
	const char *dev_name;
	struct device___236 *dev_root;
	const struct attribute_group___243 **bus_groups;
	const struct attribute_group___243 **dev_groups;
	const struct attribute_group___243 **drv_groups;
	int (*match)(struct device___236 *, struct device_driver___236 *);
	int (*uevent)(struct device___236 *, struct kobj_uevent_env *);
	int (*probe)(struct device___236 *);
	void (*sync_state)(struct device___236 *);
	void (*remove)(struct device___236 *);
	void (*shutdown)(struct device___236 *);
	int (*online)(struct device___236 *);
	int (*offline)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	int (*num_vf)(struct device___236 *);
	int (*dma_configure)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___236 {
	const char *name;
	struct bus_type___236 *bus;
	struct module___239 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___236 *);
	void (*sync_state)(struct device___236 *);
	int (*remove)(struct device___236 *);
	void (*shutdown)(struct device___236 *);
	int (*suspend)(struct device___236 *, pm_message_t);
	int (*resume)(struct device___236 *);
	const struct attribute_group___243 **groups;
	const struct attribute_group___243 **dev_groups;
	const struct dev_pm_ops___236 *pm;
	void (*coredump)(struct device___236 *);
	struct driver_private *p;
};

struct device_type___236 {
	const char *name;
	const struct attribute_group___243 **groups;
	int (*uevent)(struct device___236 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___236 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___236 *);
	const struct dev_pm_ops___236 *pm;
};

struct class___236 {
	const char *name;
	struct module___239 *owner;
	const struct attribute_group___243 **class_groups;
	const struct attribute_group___243 **dev_groups;
	struct kobject___243 *dev_kobj;
	int (*dev_uevent)(struct device___236 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___236 *, umode_t *);
	void (*class_release)(struct class___236 *);
	void (*dev_release)(struct device___236 *);
	int (*shutdown_pre)(struct device___236 *);
	const struct kobj_ns_type_operations___51 *ns_type;
	const void * (*namespace)(struct device___236 *);
	void (*get_ownership)(struct device___236 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___236 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___96;

struct pipe_buffer___96 {
	struct page___260 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___96 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___96 {
	int (*confirm)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
	void (*release)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
	bool (*try_steal)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
	bool (*get)(struct pipe_inode_info___96 *, struct pipe_buffer___96 *);
};

typedef rx_handler_result_t rx_handler_func_t___64(struct sk_buff___65 **);

struct bpf_xdp_entity___58 {
	struct bpf_prog___58 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___64;

struct net_device_ops___64;

struct l3mdev_ops___51;

struct xfrmdev_ops___64;

struct header_ops___64;

struct netdev_rx_queue___64;

struct mini_Qdisc___58;

struct netdev_queue___64;

struct Qdisc___58;

struct rtnl_link_ops___58;

struct dcbnl_rtnl_ops___64;

struct net_device___64 {
	char name[16];
	struct netdev_name_node___64 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___64 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___51 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___64 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___64 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___243 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___64 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___58 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___64 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___58 *miniq_ingress;
	struct netdev_queue___64 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___64 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___58 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___58 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___64 = 0,
		NETREG_REGISTERED___64 = 1,
		NETREG_UNREGISTERING___64 = 2,
		NETREG_UNREGISTERED___64 = 3,
		NETREG_RELEASED___64 = 4,
		NETREG_DUMMY___64 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___64 = 0,
		RTNL_LINK_INITIALIZING___64 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___64 *);
	struct netpoll_info *npinfo;
	possible_net_t___64 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___236 dev;
	const struct attribute_group___243 *sysfs_groups[4];
	const struct attribute_group___243 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___58 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___64 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___58 xdp_state[3];
	long: 64;
};

struct seq_operations___230 {
	void * (*start)(struct seq_file___230 *, loff_t *);
	void (*stop)(struct seq_file___230 *, void *);
	void * (*next)(struct seq_file___230 *, void *, loff_t *);
	int (*show)(struct seq_file___230 *, void *);
};

struct bpf_iter_aux_info___67;

typedef int (*bpf_iter_init_seq_priv_t___66)(void *, struct bpf_iter_aux_info___67 *);

struct bpf_map___67;

struct bpf_iter_aux_info___67 {
	struct bpf_map___67 *map;
};

struct bpf_iter_seq_info___66 {
	const struct seq_operations___230 *seq_ops;
	bpf_iter_init_seq_priv_t___66 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___67;

struct bpf_map_ops___66 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___67 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___67 *, struct file___255 *);
	void (*map_free)(struct bpf_map___67 *);
	int (*map_get_next_key)(struct bpf_map___67 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___67 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___67 *, void *);
	int (*map_lookup_batch)(struct bpf_map___67 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___67 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___67 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___67 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___67 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___67 *, void *);
	int (*map_update_elem)(struct bpf_map___67 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___67 *, void *);
	int (*map_push_elem)(struct bpf_map___67 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___67 *, void *);
	int (*map_peek_elem)(struct bpf_map___67 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___67 *, struct file___255 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___67 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___67 *, void *, struct seq_file___230 *);
	int (*map_check_btf)(const struct bpf_map___67 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___67 *, struct bpf_prog_aux___67 *);
	void (*map_poke_untrack)(struct bpf_map___67 *, struct bpf_prog_aux___67 *);
	void (*map_poke_run)(struct bpf_map___67 *, u32, struct bpf_prog___58 *, struct bpf_prog___58 *);
	int (*map_direct_value_addr)(const struct bpf_map___67 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___67 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___67 *, struct vm_area_struct___260 *);
	__poll_t (*map_poll)(struct bpf_map___67 *, struct file___255 *, struct poll_table_struct___176 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___67 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___67 *, const struct bpf_map___67 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___67 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___66 *iter_seq_info;
};

struct bpf_map___67 {
	const struct bpf_map_ops___66 *ops;
	struct bpf_map___67 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___120 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___66;

struct bpf_jit_poke_descriptor___66;

struct bpf_prog_ops___58;

struct btf_mod_pair___66;

struct bpf_prog_offload___64;

struct bpf_prog_aux___67 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___58 *dst_prog;
	struct bpf_trampoline___66 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___58 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___66 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___58 *ops;
	struct bpf_map___67 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___66 *used_btfs;
	struct bpf_prog___58 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___67 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___64 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___58 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___67 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___64;

struct bpf_map_dev_ops___64 {
	int (*map_get_next_key)(struct bpf_offloaded_map___64 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___64 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___64 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___64 *, void *);
};

struct bpf_offloaded_map___64 {
	struct bpf_map___67 map;
	struct net_device___64 *netdev;
	const struct bpf_map_dev_ops___64 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___58 {
	int (*test_run)(struct bpf_prog___58 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___64 {
	struct bpf_prog___58 *prog;
	struct net_device___64 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___66 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___58 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___239 *mod;
};

struct bpf_jit_poke_descriptor___66 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___67 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___66 {
	struct btf *btf;
	struct module___239 *module;
};

struct bpf_prog_array_item___58 {
	struct bpf_prog___58 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___58 {
	struct callback_head rcu;
	struct bpf_prog_array_item___58 items[0];
};

struct cftype___182;

struct cgroup_subsys___182 {
	struct cgroup_subsys_state___182 * (*css_alloc)(struct cgroup_subsys_state___182 *);
	int (*css_online)(struct cgroup_subsys_state___182 *);
	void (*css_offline)(struct cgroup_subsys_state___182 *);
	void (*css_released)(struct cgroup_subsys_state___182 *);
	void (*css_free)(struct cgroup_subsys_state___182 *);
	void (*css_reset)(struct cgroup_subsys_state___182 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___182 *, int);
	int (*css_extra_stat_show)(struct seq_file___230 *, struct cgroup_subsys_state___182 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___262 *, struct css_set___182 *);
	void (*cancel_fork)(struct task_struct___262 *, struct css_set___182 *);
	void (*fork)(struct task_struct___262 *);
	void (*exit)(struct task_struct___262 *);
	void (*release)(struct task_struct___262 *);
	void (*bind)(struct cgroup_subsys_state___182 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___182 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___182 *dfl_cftypes;
	struct cftype___182 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___182 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___182 *updated_children;
	struct cgroup___182 *updated_next;
};

struct cgroup_root___182 {
	struct kernfs_root___243 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___182 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___182 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___182 *ss;
	struct list_head node;
	struct kernfs_ops___243 *kf_ops;
	int (*open)(struct kernfs_open_file___243 *);
	void (*release)(struct kernfs_open_file___243 *);
	u64 (*read_u64)(struct cgroup_subsys_state___182 *, struct cftype___182 *);
	s64 (*read_s64)(struct cgroup_subsys_state___182 *, struct cftype___182 *);
	int (*seq_show)(struct seq_file___230 *, void *);
	void * (*seq_start)(struct seq_file___230 *, loff_t *);
	void * (*seq_next)(struct seq_file___230 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___230 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___182 *, struct cftype___182 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___182 *, struct cftype___182 *, s64);
	ssize_t (*write)(struct kernfs_open_file___243 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___243 *, struct poll_table_struct___176 *);
};

struct inet_frags___69;

struct fqdir___69 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___69 *f;
	struct net___69 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___69;

struct inet_frags___69 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___69 *, const void *);
	void (*destructor)(struct inet_frag_queue___69 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___69 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___65 *fragments_tail;
	struct sk_buff___65 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___69 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___51;

struct fib_lookup_arg___51;

struct fib_rules_ops___51 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___51 *, struct flowi *, int, struct fib_lookup_arg___51 *);
	bool (*suppress)(struct fib_rule___51 *, int, struct fib_lookup_arg___51 *);
	int (*match)(struct fib_rule___51 *, struct flowi *, int);
	int (*configure)(struct fib_rule___51 *, struct sk_buff___65 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___51 *);
	int (*compare)(struct fib_rule___51 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___51 *, struct sk_buff___65 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___51 *);
	void (*flush_cache)(struct fib_rules_ops___51 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___239 *owner;
	struct net___69 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___51 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___69 *);
	int (*fib_dump)(struct net___69 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___239 *owner;
	struct callback_head rcu;
};

struct dst_entry___51 {
	struct net_device___64 *dev;
	struct dst_ops___69 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___65 *);
	int (*output)(struct net___69 *, struct sock___51 *, struct sk_buff___65 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___51;

struct neigh_parms___51;

struct neigh_ops___51;

struct neighbour___51 {
	struct neighbour___51 *next;
	struct neigh_table___51 *tbl;
	struct neigh_parms___51 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___64 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___51 *, struct sk_buff___65 *);
	const struct neigh_ops___51 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___64 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___64 {
	int (*ieee_getets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___64 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___64 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___64 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___64 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___64 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___64 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___64 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___64 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___64 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___64 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___64 *);
	u8 (*setstate)(struct net_device___64 *, u8);
	void (*getpermhwaddr)(struct net_device___64 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___64 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___64 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___64 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___64 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___64 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___64 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___64 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___64 *, int, u8 *);
	void (*setpfccfg)(struct net_device___64 *, int, u8);
	void (*getpfccfg)(struct net_device___64 *, int, u8 *);
	u8 (*setall)(struct net_device___64 *);
	u8 (*getcap)(struct net_device___64 *, int, u8 *);
	int (*getnumtcs)(struct net_device___64 *, int, u8 *);
	int (*setnumtcs)(struct net_device___64 *, int, u8);
	u8 (*getpfcstate)(struct net_device___64 *);
	void (*setpfcstate)(struct net_device___64 *, u8);
	void (*getbcncfg)(struct net_device___64 *, int, u32 *);
	void (*setbcncfg)(struct net_device___64 *, int, u32);
	void (*getbcnrp)(struct net_device___64 *, int, u8 *);
	void (*setbcnrp)(struct net_device___64 *, int, u8);
	int (*setapp)(struct net_device___64 *, u8, u16, u8);
	int (*getapp)(struct net_device___64 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___64 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___64 *, int, u8);
	u8 (*getdcbx)(struct net_device___64 *);
	u8 (*setdcbx)(struct net_device___64 *, u8);
	int (*peer_getappinfo)(struct net_device___64 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___64 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___64 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___64 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___64 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___64 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___64 {
	struct net_device___64 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___64 {
	struct net_device___64 *dev;
};

struct xdp_buff___64 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___64 *rxq;
	struct xdp_txq_info___64 *txq;
	u32 frame_sz;
};

struct xdp_frame___64 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___64 *dev_rx;
};

struct netlink_callback___64 {
	struct sk_buff___65 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___65 *, struct netlink_callback___64 *);
	int (*done)(struct netlink_callback___64 *);
	void *data;
	struct module___239 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___64 {
	int (*create)(struct sk_buff___65 *, struct net_device___64 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___65 *, unsigned char *);
	int (*cache)(const struct neighbour___51 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___64 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___65 *);
};

struct netdev_queue___64 {
	struct net_device___64 *dev;
	struct Qdisc___58 *qdisc;
	struct Qdisc___58 *qdisc_sleeping;
	struct kobject___243 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___64 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___58 {
	struct sk_buff___65 *head;
	struct sk_buff___65 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___58;

struct Qdisc___58 {
	int (*enqueue)(struct sk_buff___65 *, struct Qdisc___58 *, struct sk_buff___65 **);
	struct sk_buff___65 * (*dequeue)(struct Qdisc___58 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___58 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___64 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___64 gso_skb;
	struct qdisc_skb_head___58 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___58 *next_sched;
	struct sk_buff_head___64 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___64 {
	struct xdp_rxq_info___64 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___243 kobj;
	struct net_device___64 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___64 {
	enum net_device_path_type type;
	const struct net_device___64 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___64 = 0,
				DEV_PATH_BR_VLAN_TAG___64 = 1,
				DEV_PATH_BR_VLAN_UNTAG___64 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___64 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___64 {
	const struct net_device___64 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___64 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___58 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___64 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___64 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___65 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___64 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___64 *dev;
	const char *name;
};

struct net_device_ops___64 {
	int (*ndo_init)(struct net_device___64 *);
	void (*ndo_uninit)(struct net_device___64 *);
	int (*ndo_open)(struct net_device___64 *);
	int (*ndo_stop)(struct net_device___64 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___65 *, struct net_device___64 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___65 *, struct net_device___64 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___64 *, struct sk_buff___65 *, struct net_device___64 *);
	void (*ndo_change_rx_flags)(struct net_device___64 *, int);
	void (*ndo_set_rx_mode)(struct net_device___64 *);
	int (*ndo_set_mac_address)(struct net_device___64 *, void *);
	int (*ndo_validate_addr)(struct net_device___64 *);
	int (*ndo_do_ioctl)(struct net_device___64 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___64 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___64 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___64 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___64 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___64 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___64 *, int);
	int (*ndo_neigh_setup)(struct net_device___64 *, struct neigh_parms___51 *);
	void (*ndo_tx_timeout)(struct net_device___64 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___64 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___64 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___64 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___64 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___64 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___64 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___64 *);
	int (*ndo_netpoll_setup)(struct net_device___64 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___64 *);
	int (*ndo_set_vf_mac)(struct net_device___64 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___64 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___64 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___64 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___64 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___64 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___64 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___64 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___64 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___64 *, int, struct sk_buff___65 *);
	int (*ndo_get_vf_guid)(struct net_device___64 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___64 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___64 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___64 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___64 *);
	int (*ndo_fcoe_disable)(struct net_device___64 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___64 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___64 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___64 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___64 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___64 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___64 *, const struct sk_buff___65 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___64 *, struct net_device___64 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___64 *, struct net_device___64 *);
	struct net_device___64 * (*ndo_get_xmit_slave)(struct net_device___64 *, struct sk_buff___65 *, bool);
	struct net_device___64 * (*ndo_sk_get_lower_dev)(struct net_device___64 *, struct sock___51 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___64 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___64 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___64 *, struct neighbour___51 *);
	void (*ndo_neigh_destroy)(struct net_device___64 *, struct neighbour___51 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___65 *, struct netlink_callback___64 *, struct net_device___64 *, struct net_device___64 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___65 *, struct nlattr **, struct net_device___64 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___64 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___65 *, u32, u32, struct net_device___64 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___64 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___64 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___64 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___64 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___64 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___64 *, struct net_device___64 *);
	void (*ndo_dfwd_del_station)(struct net_device___64 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___64 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___64 *);
	int (*ndo_change_proto_down)(struct net_device___64 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___64 *, struct sk_buff___65 *);
	void (*ndo_set_rx_headroom)(struct net_device___64 *, int);
	int (*ndo_bpf)(struct net_device___64 *, struct netdev_bpf___64 *);
	int (*ndo_xdp_xmit)(struct net_device___64 *, int, struct xdp_frame___64 **, u32);
	struct net_device___64 * (*ndo_xdp_get_xmit_slave)(struct net_device___64 *, struct xdp_buff___64 *);
	int (*ndo_xsk_wakeup)(struct net_device___64 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___64 *);
	int (*ndo_tunnel_ctl)(struct net_device___64 *, struct ip_tunnel_parm *, int);
	struct net_device___64 * (*ndo_get_peer_dev)(struct net_device___64 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___64 *, struct net_device_path___64 *);
};

struct neigh_parms___51 {
	possible_net_t___64 net;
	struct net_device___64 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___51 *);
	struct neigh_table___51 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___51 {
	u32 (*l3mdev_fib_table)(const struct net_device___64 *);
	struct sk_buff___65 * (*l3mdev_l3_rcv)(struct net_device___64 *, struct sk_buff___65 *, u16);
	struct sk_buff___65 * (*l3mdev_l3_out)(struct net_device___64 *, struct sock___51 *, struct sk_buff___65 *, u16);
	struct dst_entry___51 * (*l3mdev_link_scope_lookup)(const struct net_device___64 *, struct flowi6 *);
};

struct tcf_proto___58;

struct tcf_block___58;

struct mini_Qdisc___58 {
	struct tcf_proto___58 *filter_list;
	struct tcf_block___58 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___58 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___64 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___64 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___69 *, struct net_device___64 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___64 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___64 *, struct list_head *);
	size_t (*get_size)(const struct net_device___64 *);
	int (*fill_info)(struct sk_buff___65 *, const struct net_device___64 *);
	size_t (*get_xstats_size)(const struct net_device___64 *);
	int (*fill_xstats)(struct sk_buff___65 *, const struct net_device___64 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___64 *, struct net_device___64 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___64 *, const struct net_device___64 *);
	int (*fill_slave_info)(struct sk_buff___65 *, const struct net_device___64 *, const struct net_device___64 *);
	struct net___69 * (*get_link_net)(const struct net_device___64 *);
	size_t (*get_linkxstats_size)(const struct net_device___64 *, int);
	int (*fill_linkxstats)(struct sk_buff___65 *, const struct net_device___64 *, int *, int);
};

struct netdev_notifier_info___11 {
	struct net_device___64 *dev;
	struct netlink_ext_ack *extack;
};

struct gnet_dump___58 {
	spinlock_t *lock;
	struct sk_buff___65 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___58;

struct Qdisc_ops___58 {
	struct Qdisc_ops___58 *next;
	const struct Qdisc_class_ops___58 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___65 *, struct Qdisc___58 *, struct sk_buff___65 **);
	struct sk_buff___65 * (*dequeue)(struct Qdisc___58 *);
	struct sk_buff___65 * (*peek)(struct Qdisc___58 *);
	int (*init)(struct Qdisc___58 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___58 *);
	void (*destroy)(struct Qdisc___58 *);
	int (*change)(struct Qdisc___58 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___58 *);
	int (*change_tx_queue_len)(struct Qdisc___58 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___58 *, unsigned int);
	int (*dump)(struct Qdisc___58 *, struct sk_buff___65 *);
	int (*dump_stats)(struct Qdisc___58 *, struct gnet_dump___58 *);
	void (*ingress_block_set)(struct Qdisc___58 *, u32);
	void (*egress_block_set)(struct Qdisc___58 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___58 *);
	u32 (*egress_block_get)(struct Qdisc___58 *);
	struct module___239 *owner;
};

struct qdisc_walker___5;

struct Qdisc_class_ops___58 {
	unsigned int flags;
	struct netdev_queue___64 * (*select_queue)(struct Qdisc___58 *, struct tcmsg *);
	int (*graft)(struct Qdisc___58 *, long unsigned int, struct Qdisc___58 *, struct Qdisc___58 **, struct netlink_ext_ack *);
	struct Qdisc___58 * (*leaf)(struct Qdisc___58 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___58 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___58 *, u32);
	int (*change)(struct Qdisc___58 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___58 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___58 *, struct qdisc_walker___5 *);
	struct tcf_block___58 * (*tcf_block)(struct Qdisc___58 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___58 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___58 *, long unsigned int);
	int (*dump)(struct Qdisc___58 *, long unsigned int, struct sk_buff___65 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___58 *, long unsigned int, struct gnet_dump___58 *);
};

struct qdisc_walker___5 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___58 *, long unsigned int, struct qdisc_walker___5 *);
};

struct tcf_chain___58;

struct tcf_block___58 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___69 *net;
	struct Qdisc___58 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___58 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___58;

struct tcf_proto_ops___58;

struct tcf_proto___58 {
	struct tcf_proto___58 *next;
	void *root;
	int (*classify)(struct sk_buff___65 *, const struct tcf_proto___58 *, struct tcf_result___58 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___58 *ops;
	struct tcf_chain___58 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___58 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___58 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___2;

struct tcf_proto_ops___58 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___65 *, const struct tcf_proto___58 *, struct tcf_result___58 *);
	int (*init)(struct tcf_proto___58 *);
	void (*destroy)(struct tcf_proto___58 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___58 *, u32);
	void (*put)(struct tcf_proto___58 *, void *);
	int (*change)(struct net___69 *, struct sk_buff___65 *, struct tcf_proto___58 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___58 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___58 *);
	void (*walk)(struct tcf_proto___58 *, struct tcf_walker___2 *, bool);
	int (*reoffload)(struct tcf_proto___58 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___58 *, void *);
	void (*hw_del)(struct tcf_proto___58 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___69 *, struct tcf_chain___58 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___69 *, struct tcf_proto___58 *, void *, struct sk_buff___65 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___69 *, struct tcf_proto___58 *, void *, struct sk_buff___65 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___65 *, struct net___69 *, void *);
	struct module___239 *owner;
	int flags;
};

struct tcf_walker___2 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___58 *, void *, struct tcf_walker___2 *);
};

struct tcf_chain___58 {
	struct mutex filter_chain_lock;
	struct tcf_proto___58 *filter_chain;
	struct list_head list;
	struct tcf_block___58 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___58 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct block_device_operations___146;

struct gendisk___149 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___149 *part0;
	const struct block_device_operations___146 *fops;
	struct request_queue___146 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___132 *bdi;
	struct kobject___243 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___243 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___146 {
	struct bio___146 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___172 *bip_vec;
	struct bio_vec___172 bip_inline_vecs[0];
};

struct blkcg___134;

struct blkg_policy_data___134;

struct blkcg_gq___134 {
	struct request_queue___146 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___134 *blkcg;
	struct blkcg_gq___134 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___134 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___146 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___146(struct request___146 *);

typedef void integrity_complete_fn___146(struct request___146 *, unsigned int);

struct blk_integrity_profile___146 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___146 *prepare_fn;
	integrity_complete_fn___146 *complete_fn;
	const char *name;
};

struct block_device_operations___146 {
	blk_qc_t (*submit_bio)(struct bio___146 *);
	int (*open)(struct block_device___149 *, fmode_t);
	void (*release)(struct gendisk___149 *, fmode_t);
	int (*rw_page)(struct block_device___149 *, sector_t, struct page___260 *, unsigned int);
	int (*ioctl)(struct block_device___149 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___149 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___149 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___149 *);
	int (*getgeo)(struct block_device___149 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___149 *, bool);
	void (*swap_slot_free_notify)(struct block_device___149 *, long unsigned int);
	int (*report_zones)(struct gendisk___149 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___149 *, umode_t *);
	struct module___239 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___149 *, sector_t *);
};

typedef void rq_end_io_fn___146(struct request___146 *, blk_status_t);

struct request___146 {
	struct request_queue___146 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___141 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___146 *bio;
	struct bio___146 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___172 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___146 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___146 *saved_end_io;
		} flush;
	};
	struct gendisk___149 *rq_disk;
	struct block_device___149 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___146 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___141 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___146 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___243 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___255 *debugfs_dir;
	struct dentry___255 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___146;

struct elevator_mq_ops___146 {
	int (*init_sched)(struct request_queue___146 *, struct elevator_type___146 *);
	void (*exit_sched)(struct elevator_queue___146 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___141 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___141 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___141 *);
	bool (*allow_merge)(struct request_queue___146 *, struct request___146 *, struct bio___146 *);
	bool (*bio_merge)(struct request_queue___146 *, struct bio___146 *, unsigned int);
	int (*request_merge)(struct request_queue___146 *, struct request___146 **, struct bio___146 *);
	void (*request_merged)(struct request_queue___146 *, struct request___146 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___146 *, struct request___146 *, struct request___146 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___146 *);
	void (*finish_request)(struct request___146 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___141 *, struct list_head *, bool);
	struct request___146 * (*dispatch_request)(struct blk_mq_hw_ctx___141 *);
	bool (*has_work)(struct blk_mq_hw_ctx___141 *);
	void (*completed_request)(struct request___146 *, u64);
	void (*requeue_request)(struct request___146 *);
	struct request___146 * (*former_request)(struct request_queue___146 *, struct request___146 *);
	struct request___146 * (*next_request)(struct request_queue___146 *, struct request___146 *);
	void (*init_icq)(struct io_cq___146 *);
	void (*exit_icq)(struct io_cq___146 *);
};

struct elv_fs_entry___146;

struct elevator_type___146 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___146 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___146 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___239 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___146 {
	struct elevator_type___146 *type;
	void *elevator_data;
	struct kobject___243 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___146 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___146 *, char *);
	ssize_t (*store)(struct elevator_queue___146 *, const char *, size_t);
};

struct blk_mq_queue_data___141;

struct blk_mq_ops___141 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___141 *, const struct blk_mq_queue_data___141 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___141 *);
	int (*get_budget)(struct request_queue___146 *);
	void (*put_budget)(struct request_queue___146 *, int);
	void (*set_rq_budget_token)(struct request___146 *, int);
	int (*get_rq_budget_token)(struct request___146 *);
	enum blk_eh_timer_return (*timeout)(struct request___146 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___141 *);
	void (*complete)(struct request___146 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___141 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___141 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___141 *, struct request___146 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___141 *, struct request___146 *, unsigned int);
	void (*initialize_rq_fn)(struct request___146 *);
	void (*cleanup_rq)(struct request___146 *);
	bool (*busy)(struct request_queue___146 *);
	int (*map_queues)(struct blk_mq_tag_set___141 *);
	void (*show_rq)(struct seq_file___230 *, struct request___146 *);
};

struct blk_mq_tag_set___141 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___141 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___141 {
	struct request___146 *rq;
	bool last;
};

struct blkcg_policy_data___134;

struct blkcg___134 {
	struct cgroup_subsys_state___182 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___134 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___134 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___134 {
	struct blkcg___134 *blkcg;
	int plid;
};

struct blkg_policy_data___134 {
	struct blkcg_gq___134 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___120 {
	struct mem_cgroup___120 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___120 {
	struct lruvec___128 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___120 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___120 *memcg;
};

struct obj_cgroup___120 {
	struct percpu_ref refcnt;
	struct mem_cgroup___120 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct sk_filter___51 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___58 *prog;
};

struct pneigh_entry___51;

struct neigh_hash_table___51;

struct neigh_table___51 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___64 *, __u32 *);
	bool (*key_eq)(const struct neighbour___51 *, const void *);
	int (*constructor)(struct neighbour___51 *);
	int (*pconstructor)(struct pneigh_entry___51 *);
	void (*pdestructor)(struct pneigh_entry___51 *);
	void (*proxy_redo)(struct sk_buff___65 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___64 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___51 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___64 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___51 *nht;
	struct pneigh_entry___51 **phash_buckets;
};

struct neigh_ops___51 {
	int family;
	void (*solicit)(struct neighbour___51 *, struct sk_buff___65 *);
	void (*error_report)(struct neighbour___51 *, struct sk_buff___65 *);
	int (*output)(struct neighbour___51 *, struct sk_buff___65 *);
	int (*connected_output)(struct neighbour___51 *, struct sk_buff___65 *);
};

struct pneigh_entry___51 {
	struct pneigh_entry___51 *next;
	possible_net_t___64 net;
	struct net_device___64 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___51 {
	struct neighbour___51 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___51 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___51 *ctarget;
	struct net___69 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___51 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___51 *rule;
	u32 table;
	int flags;
};

struct proto___51 {
	void (*close)(struct sock___51 *, long int);
	int (*pre_connect)(struct sock___51 *, struct sockaddr *, int);
	int (*connect)(struct sock___51 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___51 *, int);
	struct sock___51 * (*accept)(struct sock___51 *, int, int *, bool);
	int (*ioctl)(struct sock___51 *, int, long unsigned int);
	int (*init)(struct sock___51 *);
	void (*destroy)(struct sock___51 *);
	void (*shutdown)(struct sock___51 *, int);
	int (*setsockopt)(struct sock___51 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___51 *, int, int, char *, int *);
	void (*keepalive)(struct sock___51 *, int);
	int (*compat_ioctl)(struct sock___51 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___51 *, struct msghdr___53 *, size_t);
	int (*recvmsg)(struct sock___51 *, struct msghdr___53 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___51 *, struct page___260 *, int, size_t, int);
	int (*bind)(struct sock___51 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___51 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___51 *, struct sk_buff___65 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___51 *);
	int (*hash)(struct sock___51 *);
	void (*unhash)(struct sock___51 *);
	void (*rehash)(struct sock___51 *);
	int (*get_port)(struct sock___51 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___51 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___51 *, int);
	bool (*sock_is_readable)(struct sock___51 *);
	void (*enter_memory_pressure)(struct sock___51 *);
	void (*leave_memory_pressure)(struct sock___51 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___239 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___51 *, int);
};

struct dentry___256;

struct super_block___256;

struct module___240;

struct file_system_type___256 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___256 * (*mount)(struct file_system_type___256 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___256 *);
	struct module___240 *owner;
	struct file_system_type___256 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___256;

struct kiocb___256;

struct iov_iter___176;

struct poll_table_struct___177;

struct vm_area_struct___261;

struct inode___256;

struct file_lock___256;

struct page___261;

struct pipe_inode_info___97;

struct seq_file___231;

struct file_operations___257 {
	struct module___240 *owner;
	loff_t (*llseek)(struct file___256 *, loff_t, int);
	ssize_t (*read)(struct file___256 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___256 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___256 *, struct iov_iter___176 *);
	ssize_t (*write_iter)(struct kiocb___256 *, struct iov_iter___176 *);
	int (*iopoll)(struct kiocb___256 *, bool);
	int (*iterate)(struct file___256 *, struct dir_context *);
	int (*iterate_shared)(struct file___256 *, struct dir_context *);
	__poll_t (*poll)(struct file___256 *, struct poll_table_struct___177 *);
	long int (*unlocked_ioctl)(struct file___256 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___256 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___256 *, struct vm_area_struct___261 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___256 *, struct file___256 *);
	int (*flush)(struct file___256 *, fl_owner_t);
	int (*release)(struct inode___256 *, struct file___256 *);
	int (*fsync)(struct file___256 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___256 *, int);
	int (*lock)(struct file___256 *, int, struct file_lock___256 *);
	ssize_t (*sendpage)(struct file___256 *, struct page___261 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___256 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___256 *, long unsigned int);
	int (*flock)(struct file___256 *, int, struct file_lock___256 *);
	ssize_t (*splice_write)(struct pipe_inode_info___97 *, struct file___256 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___256 *, loff_t *, struct pipe_inode_info___97 *, size_t, unsigned int);
	int (*setlease)(struct file___256 *, long int, struct file_lock___256 **, void **);
	long int (*fallocate)(struct file___256 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___231 *, struct file___256 *);
	ssize_t (*copy_file_range)(struct file___256 *, loff_t, struct file___256 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___256 *, loff_t, struct file___256 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___256 *, loff_t, loff_t, int);
};

struct vmacache___261 {
	u64 seqnum;
	struct vm_area_struct___261 *vmas[4];
};

struct page_frag___261 {
	struct page___261 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___262;

struct pid___233;

struct files_struct___23;

struct nsproxy___242;

struct signal_struct___257;

struct bio_list___147;

struct backing_dev_info___133;

struct io_context___147;

struct css_set___183;

struct mem_cgroup___121;

struct request_queue___147;

struct vm_struct___239;

struct task_struct___263 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___263 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___262 *mm;
	struct mm_struct___262 *active_mm;
	struct vmacache___261 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___263 *real_parent;
	struct task_struct___263 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___263 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___233 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct___23 *files;
	struct io_uring_task *io_uring;
	struct nsproxy___242 *nsproxy;
	struct signal_struct___257 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___263 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___147 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___133 *backing_dev_info;
	struct io_context___147 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___183 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___97 *splice_pipe;
	struct page_frag___261 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___121 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___121 *active_memcg;
	struct request_queue___147 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___263 *oom_reaper_list;
	struct vm_struct___239 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___244;

struct kobj_type___244;

struct kernfs_node___244;

struct kobject___244 {
	const char *name;
	struct list_head entry;
	struct kobject___244 *parent;
	struct kset___244 *kset;
	struct kobj_type___244 *ktype;
	struct kernfs_node___244 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___241 {
	struct kobject___244 kobj;
	struct module___240 *mod;
	struct kobject___244 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___240 {
	struct module___240 *mod;
	struct latch_tree_node node;
};

struct module_layout___240 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___240 mtn;
};

struct module_attribute___240;

struct kernel_param___240;

struct module___240 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___241 mkobj;
	struct module_attribute___240 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___244 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___240 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___240 core_layout;
	struct module_layout___240 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___261 *pgtable_t___261;

struct address_space___256;

struct page_pool___85;

struct dev_pagemap___251;

struct page___261 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___256 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___85 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___261 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___261 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___262 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___251 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___251;

struct vm_area_struct___261 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___261 *vm_next;
	struct vm_area_struct___261 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___262 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___251 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___256 *vm_file;
	struct file___256 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___261;

struct mm_struct___262 {
	struct {
		struct vm_area_struct___261 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___256 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___261 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___263 *owner;
		struct user_namespace___26 *user_ns;
		struct file___256 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___256;

struct address_space___256 {
	struct inode___256 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___256 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___237;

struct page_pool_params___85 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___237 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___85 {
	u32 count;
	struct page___261 *cache[128];
};

struct page_pool___85 {
	struct page_pool_params___85 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___261 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___85 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___251;

struct dev_pagemap___251 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___251 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___256;

struct path___256 {
	struct vfsmount___256 *mnt;
	struct dentry___256 *dentry;
};

struct fown_struct___233 {
	rwlock_t lock;
	struct pid___233 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___256 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___256 f_path;
	struct inode___256 *f_inode;
	const struct file_operations___257 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___233 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___256 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___251;

struct vm_operations_struct___251 {
	void (*open)(struct vm_area_struct___261 *);
	void (*close)(struct vm_area_struct___261 *);
	int (*may_split)(struct vm_area_struct___261 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___261 *);
	int (*mprotect)(struct vm_area_struct___261 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___251 *);
	vm_fault_t (*huge_fault)(struct vm_fault___251 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___251 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___261 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___251 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___251 *);
	int (*access)(struct vm_area_struct___261 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___261 *);
	int (*set_policy)(struct vm_area_struct___261 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___261 *, long unsigned int);
	struct page___261 * (*find_special_page)(struct vm_area_struct___261 *, long unsigned int);
};

struct core_thread___261 {
	struct task_struct___263 *task;
	struct core_thread___261 *next;
};

struct core_state___261 {
	atomic_t nr_threads;
	struct core_thread___261 dumper;
	struct completion startup;
};

struct vm_fault___251 {
	const struct {
		struct vm_area_struct___261 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___261 *cow_page;
	struct page___261 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___261 prealloc_pte;
};

struct pglist_data___129;

struct lruvec___129 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___129 *pgdat;
};

struct zone___129 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___129 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___129 {
	struct zone___129 *zone;
	int zone_idx;
};

struct zonelist___129 {
	struct zoneref___129 _zonerefs[321];
};

struct pglist_data___129 {
	struct zone___129 node_zones[5];
	struct zonelist___129 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___263 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___263 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___129 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___233;

struct upid___233 {
	int nr;
	struct pid_namespace___233 *ns;
};

struct pid_namespace___233 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___263 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___233 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___233 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___233 numbers[1];
};

struct signal_struct___257 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___263 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___263 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___233 *pids[4];
	struct pid___233 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___262 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct fdtable___23 {
	unsigned int max_fds;
	struct file___256 **fd;
	long unsigned int *close_on_exec;
	long unsigned int *open_fds;
	long unsigned int *full_fds_bits;
	struct callback_head rcu;
};

struct files_struct___23 {
	atomic_t count;
	bool resize_in_progress;
	wait_queue_head_t resize_wait;
	struct fdtable___23 *fdt;
	struct fdtable___23 fdtab;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t file_lock;
	unsigned int next_fd;
	long unsigned int close_on_exec_init[1];
	long unsigned int open_fds_init[1];
	long unsigned int full_fds_bits_init[1];
	struct file___256 *fd_array[64];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net___70;

struct cgroup_namespace___183;

struct nsproxy___242 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___233 *pid_ns_for_children;
	struct net___70 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___183 *cgroup_ns;
};

struct bio___147;

struct bio_list___147 {
	struct bio___147 *head;
	struct bio___147 *tail;
};

struct cgroup_subsys_state___183;

struct bdi_writeback___133 {
	struct backing_dev_info___133 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___183 *memcg_css;
	struct cgroup_subsys_state___183 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___133 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___133 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___237 *dev;
	char dev_name[64];
	struct device___237 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___256 *debug_dir;
};

struct io_cq___147;

struct io_context___147 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___147 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___183;

struct css_set___183 {
	struct cgroup_subsys_state___183 *subsys[14];
	refcount_t refcount;
	struct css_set___183 *dom_cset;
	struct cgroup___183 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___183 *mg_src_cgrp;
	struct cgroup___183 *mg_dst_cgrp;
	struct css_set___183 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___256;

struct pipe_buffer___97;

struct pipe_inode_info___97 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___261 *tmp_page;
	struct fasync_struct___256 *fasync_readers;
	struct fasync_struct___256 *fasync_writers;
	struct pipe_buffer___97 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___183;

struct cgroup_subsys_state___183 {
	struct cgroup___183 *cgroup;
	struct cgroup_subsys___183 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___183 *parent;
};

struct cgroup_file___183 {
	struct kernfs_node___244 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___121;

struct mem_cgroup_per_node___121;

struct mem_cgroup___121 {
	struct cgroup_subsys_state___183 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___183 events_file;
	struct cgroup_file___183 events_local_file;
	struct cgroup_file___183 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___121 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___263 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___121 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___147;

struct blk_integrity___147 {
	const struct blk_integrity_profile___147 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___147 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___147 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___147;

struct elevator_queue___147;

struct blk_mq_ops___142;

struct blk_mq_hw_ctx___142;

struct gendisk___150;

struct blkcg_gq___135;

struct blk_mq_tag_set___142;

struct request_queue___147 {
	struct request___147 *last_merge;
	struct elevator_queue___147 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___142 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___142 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___150 *disk;
	struct kobject___244 kobj;
	struct kobject___244 *mq_kobj;
	struct blk_integrity___147 integrity;
	struct device___237 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___135 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___142 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___147 bio_split;
	struct dentry___256 *debugfs_dir;
	struct dentry___256 *sched_debugfs_dir;
	struct dentry___256 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___239 {
	struct vm_struct___239 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___261 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___256;

struct dentry___256 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___256 *d_parent;
	struct qstr d_name;
	struct inode___256 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___256 *d_op;
	struct super_block___256 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___256;

struct inode___256 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___256 *i_op;
	struct super_block___256 *i_sb;
	struct address_space___256 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___133 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___257 *i_fop;
		void (*free_inode)(struct inode___256 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___256 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___97 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___256 {
	int (*d_revalidate)(struct dentry___256 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___256 *, unsigned int);
	int (*d_hash)(const struct dentry___256 *, struct qstr *);
	int (*d_compare)(const struct dentry___256 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___256 *);
	int (*d_init)(struct dentry___256 *);
	void (*d_release)(struct dentry___256 *);
	void (*d_prune)(struct dentry___256 *);
	void (*d_iput)(struct dentry___256 *, struct inode___256 *);
	char * (*d_dname)(struct dentry___256 *, char *, int);
	struct vfsmount___256 * (*d_automount)(struct path___256 *);
	int (*d_manage)(const struct path___256 *, bool);
	struct dentry___256 * (*d_real)(struct dentry___256 *, const struct inode___256 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___256;

struct mem_dqinfo___256 {
	struct quota_format_type___256 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___256;

struct quota_info___256 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___256 *files[3];
	struct mem_dqinfo___256 info[3];
	const struct quota_format_ops___256 *ops[3];
};

struct rcuwait___257 {
	struct task_struct___263 *task;
};

struct percpu_rw_semaphore___257 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___257 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___256 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___257 rw_sem[3];
};

struct shrink_control___121;

struct shrinker___121 {
	long unsigned int (*count_objects)(struct shrinker___121 *, struct shrink_control___121 *);
	long unsigned int (*scan_objects)(struct shrinker___121 *, struct shrink_control___121 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___256;

struct dquot_operations___256;

struct quotactl_ops___256;

struct block_device___150;

struct super_block___256 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___256 *s_type;
	const struct super_operations___256 *s_op;
	const struct dquot_operations___256 *dq_op;
	const struct quotactl_ops___256 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___256 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___150 *s_bdev;
	struct backing_dev_info___133 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___256 s_dquot;
	struct sb_writers___256 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___256 *s_d_op;
	int cleancache_poolid;
	struct shrinker___121 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___256 {
	struct dentry___256 *mnt_root;
	struct super_block___256 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___121 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___121 *memcg;
};

struct psi_group___183 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___263 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___59;

struct cgroup_bpf___59 {
	struct bpf_prog_array___59 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___59 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___183;

struct cgroup_rstat_cpu___183;

struct cgroup___183 {
	struct cgroup_subsys_state___183 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___244 *kn;
	struct cgroup_file___183 procs_file;
	struct cgroup_file___183 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___183 *subsys[14];
	struct cgroup_root___183 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___183 *dom_cgrp;
	struct cgroup___183 *old_dom_cgrp;
	struct cgroup_rstat_cpu___183 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___183 psi;
	struct cgroup_bpf___59 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___147 {
	struct request_queue___147 *q;
	struct io_context___147 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___256 {
	struct file___256 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___256 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___256 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___256 *ia_file;
};

struct dquot___256 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___256 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___256 {
	int qf_fmt_id;
	const struct quota_format_ops___256 *qf_ops;
	struct module___240 *qf_owner;
	struct quota_format_type___256 *qf_next;
};

struct quota_format_ops___256 {
	int (*check_quota_file)(struct super_block___256 *, int);
	int (*read_file_info)(struct super_block___256 *, int);
	int (*write_file_info)(struct super_block___256 *, int);
	int (*free_file_info)(struct super_block___256 *, int);
	int (*read_dqblk)(struct dquot___256 *);
	int (*commit_dqblk)(struct dquot___256 *);
	int (*release_dqblk)(struct dquot___256 *);
	int (*get_next_id)(struct super_block___256 *, struct kqid *);
};

struct dquot_operations___256 {
	int (*write_dquot)(struct dquot___256 *);
	struct dquot___256 * (*alloc_dquot)(struct super_block___256 *, int);
	void (*destroy_dquot)(struct dquot___256 *);
	int (*acquire_dquot)(struct dquot___256 *);
	int (*release_dquot)(struct dquot___256 *);
	int (*mark_dirty)(struct dquot___256 *);
	int (*write_info)(struct super_block___256 *, int);
	qsize_t * (*get_reserved_space)(struct inode___256 *);
	int (*get_projid)(struct inode___256 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___256 *, qsize_t *);
	int (*get_next_id)(struct super_block___256 *, struct kqid *);
};

struct quotactl_ops___256 {
	int (*quota_on)(struct super_block___256 *, int, int, const struct path___256 *);
	int (*quota_off)(struct super_block___256 *, int);
	int (*quota_enable)(struct super_block___256 *, unsigned int);
	int (*quota_disable)(struct super_block___256 *, unsigned int);
	int (*quota_sync)(struct super_block___256 *, int);
	int (*set_info)(struct super_block___256 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___256 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___256 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___256 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___256 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___256 *, unsigned int);
};

struct writeback_control___133;

struct address_space_operations___256 {
	int (*writepage)(struct page___261 *, struct writeback_control___133 *);
	int (*readpage)(struct file___256 *, struct page___261 *);
	int (*writepages)(struct address_space___256 *, struct writeback_control___133 *);
	int (*set_page_dirty)(struct page___261 *);
	int (*readpages)(struct file___256 *, struct address_space___256 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___256 *, struct address_space___256 *, loff_t, unsigned int, unsigned int, struct page___261 **, void **);
	int (*write_end)(struct file___256 *, struct address_space___256 *, loff_t, unsigned int, unsigned int, struct page___261 *, void *);
	sector_t (*bmap)(struct address_space___256 *, sector_t);
	void (*invalidatepage)(struct page___261 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___261 *, gfp_t);
	void (*freepage)(struct page___261 *);
	ssize_t (*direct_IO)(struct kiocb___256 *, struct iov_iter___176 *);
	int (*migratepage)(struct address_space___256 *, struct page___261 *, struct page___261 *, enum migrate_mode);
	bool (*isolate_page)(struct page___261 *, isolate_mode_t);
	void (*putback_page)(struct page___261 *);
	int (*launder_page)(struct page___261 *);
	int (*is_partially_uptodate)(struct page___261 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___261 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___256 *, struct page___261 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___256 *, sector_t *);
	void (*swap_deactivate)(struct file___256 *);
};

struct writeback_control___133 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___133 *wb;
	struct inode___256 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___173;

struct iov_iter___176 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___173 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___97 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___256 {
	struct dentry___256 * (*lookup)(struct inode___256 *, struct dentry___256 *, unsigned int);
	const char * (*get_link)(struct dentry___256 *, struct inode___256 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___256 *, int);
	struct posix_acl * (*get_acl)(struct inode___256 *, int, bool);
	int (*readlink)(struct dentry___256 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___256 *, struct dentry___256 *, umode_t, bool);
	int (*link)(struct dentry___256 *, struct inode___256 *, struct dentry___256 *);
	int (*unlink)(struct inode___256 *, struct dentry___256 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___256 *, struct dentry___256 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___256 *, struct dentry___256 *, umode_t);
	int (*rmdir)(struct inode___256 *, struct dentry___256 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___256 *, struct dentry___256 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___256 *, struct dentry___256 *, struct inode___256 *, struct dentry___256 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___256 *, struct iattr___256 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___256 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___256 *, char *, size_t);
	int (*fiemap)(struct inode___256 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___256 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___256 *, struct dentry___256 *, struct file___256 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___256 *, struct dentry___256 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___256 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___256 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___256 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___256 {
	void (*fl_copy_lock)(struct file_lock___256 *, struct file_lock___256 *);
	void (*fl_release_private)(struct file_lock___256 *);
};

struct lock_manager_operations___256;

struct file_lock___256 {
	struct file_lock___256 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___256 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___256 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___256 *fl_ops;
	const struct lock_manager_operations___256 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___256 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___256 *);
	int (*lm_grant)(struct file_lock___256 *, int);
	bool (*lm_break)(struct file_lock___256 *);
	int (*lm_change)(struct file_lock___256 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___256 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___256 *);
};

struct fasync_struct___256 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___256 *fa_next;
	struct file___256 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___256 {
	struct inode___256 * (*alloc_inode)(struct super_block___256 *);
	void (*destroy_inode)(struct inode___256 *);
	void (*free_inode)(struct inode___256 *);
	void (*dirty_inode)(struct inode___256 *, int);
	int (*write_inode)(struct inode___256 *, struct writeback_control___133 *);
	int (*drop_inode)(struct inode___256 *);
	void (*evict_inode)(struct inode___256 *);
	void (*put_super)(struct super_block___256 *);
	int (*sync_fs)(struct super_block___256 *, int);
	int (*freeze_super)(struct super_block___256 *);
	int (*freeze_fs)(struct super_block___256 *);
	int (*thaw_super)(struct super_block___256 *);
	int (*unfreeze_fs)(struct super_block___256 *);
	int (*statfs)(struct dentry___256 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___256 *, int *, char *);
	void (*umount_begin)(struct super_block___256 *);
	int (*show_options)(struct seq_file___231 *, struct dentry___256 *);
	int (*show_devname)(struct seq_file___231 *, struct dentry___256 *);
	int (*show_path)(struct seq_file___231 *, struct dentry___256 *);
	int (*show_stats)(struct seq_file___231 *, struct dentry___256 *);
	ssize_t (*quota_read)(struct super_block___256 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___256 *, int, const char *, size_t, loff_t);
	struct dquot___256 ** (*get_dquots)(struct inode___256 *);
	long int (*nr_cached_objects)(struct super_block___256 *, struct shrink_control___121 *);
	long int (*free_cached_objects)(struct super_block___256 *, struct shrink_control___121 *);
	struct file___256 * (*real_loop)(struct file___256 *);
};

struct wakeup_source___237;

struct dev_pm_info___237 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___237 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___237 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___237;

struct bus_type___237;

struct device_driver___237;

struct dev_pm_domain___237;

struct fwnode_handle___233;

struct class___237;

struct attribute_group___244;

struct device___237 {
	struct kobject___244 kobj;
	struct device___237 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___237 *type;
	struct bus_type___237 *bus;
	struct device_driver___237 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___237 power;
	struct dev_pm_domain___237 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___233 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___237 *class;
	const struct attribute_group___244 **groups;
	void (*release)(struct device___237 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___150 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___256 *bd_inode;
	struct super_block___256 *bd_super;
	void *bd_claiming;
	struct device___237 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___244 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___150 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___256 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___185)(struct file___256 *, wait_queue_head_t *, struct poll_table_struct___177 *);

struct poll_table_struct___177 {
	poll_queue_proc___185 _qproc;
	__poll_t _key;
};

struct seq_operations___231;

struct seq_file___231 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___231 *op;
	int poll_event;
	const struct file___256 *file;
	void *private;
};

typedef void bio_end_io_t___147(struct bio___147 *);

struct bio_vec___173 {
	struct page___261 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___147;

struct bio___147 {
	struct bio___147 *bi_next;
	struct block_device___150 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___147 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___135 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___147 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___173 *bi_io_vec;
	struct bio_set___147 *bi_pool;
	struct bio_vec___173 bi_inline_vecs[0];
};

struct seq_operations___231 {
	void * (*start)(struct seq_file___231 *, loff_t *);
	void (*stop)(struct seq_file___231 *, void *);
	void * (*next)(struct seq_file___231 *, void *, loff_t *);
	int (*show)(struct seq_file___231 *, void *);
};

struct kernfs_root___244;

struct kernfs_elem_dir___244 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___244 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___244;

struct kernfs_root___244 {
	struct kernfs_node___244 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___244 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___244 {
	struct kernfs_node___244 *target_kn;
};

struct kernfs_ops___244;

struct kernfs_elem_attr___244 {
	const struct kernfs_ops___244 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___244 *notify_next;
};

struct kernfs_node___244 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___244 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___244 dir;
		struct kernfs_elem_symlink___244 symlink;
		struct kernfs_elem_attr___244 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___244;

struct kernfs_ops___244 {
	int (*open)(struct kernfs_open_file___244 *);
	void (*release)(struct kernfs_open_file___244 *);
	int (*seq_show)(struct seq_file___231 *, void *);
	void * (*seq_start)(struct seq_file___231 *, loff_t *);
	void * (*seq_next)(struct seq_file___231 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___231 *, void *);
	ssize_t (*read)(struct kernfs_open_file___244 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___244 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___244 *, struct poll_table_struct___177 *);
	int (*mmap)(struct kernfs_open_file___244 *, struct vm_area_struct___261 *);
};

struct kernfs_syscall_ops___244 {
	int (*show_options)(struct seq_file___231 *, struct kernfs_root___244 *);
	int (*mkdir)(struct kernfs_node___244 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___244 *);
	int (*rename)(struct kernfs_node___244 *, struct kernfs_node___244 *, const char *);
	int (*show_path)(struct seq_file___231 *, struct kernfs_node___244 *, struct kernfs_root___244 *);
};

struct kernfs_open_file___244 {
	struct kernfs_node___244 *kn;
	struct file___256 *file;
	struct seq_file___231 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___251 *vm_ops;
};

struct fib_rules_ops___52;

struct sock___52;

struct fqdir___70;

struct fib_notifier_ops___52;

struct netns_ipv4___70 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___52 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___52 *fibnl;
	struct sock___52 **icmp_sk;
	struct sock___52 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___52 **tcp_sk;
	struct fqdir___70 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___52 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___52 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___52 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___52;

struct net_device___65;

struct sk_buff___66;

struct neighbour___52;

struct dst_ops___70 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___70 *);
	struct dst_entry___52 * (*check)(struct dst_entry___52 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___52 *);
	unsigned int (*mtu)(const struct dst_entry___52 *);
	u32 * (*cow_metrics)(struct dst_entry___52 *, long unsigned int);
	void (*destroy)(struct dst_entry___52 *);
	void (*ifdown)(struct dst_entry___52 *, struct net_device___65 *, int);
	struct dst_entry___52 * (*negative_advice)(struct dst_entry___52 *);
	void (*link_failure)(struct sk_buff___66 *);
	void (*update_pmtu)(struct dst_entry___52 *, struct sock___52 *, struct sk_buff___66 *, u32, bool);
	void (*redirect)(struct dst_entry___52 *, struct sock___52 *, struct sk_buff___66 *);
	int (*local_out)(struct net___70 *, struct sock___52 *, struct sk_buff___66 *);
	struct neighbour___52 * (*neigh_lookup)(const struct dst_entry___52 *, struct sk_buff___66 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___52 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___70 {
	struct dst_ops___70 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___70 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___52 *fib6_rules_ops;
	struct sock___52 **icmp_sk;
	struct sock___52 *ndisc_sk;
	struct sock___52 *tcp_sk;
	struct sock___52 *igmp_sk;
	struct sock___52 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___52 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___52 *notifier_ops;
	struct fib_notifier_ops___52 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___70 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___70 *fqdir;
};

struct netns_sctp___52 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___52 *ctl_sock;
	struct sock___52 *udp4_sock;
	struct sock___52 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___65 {
	struct sk_buff___66 *next;
	struct sk_buff___66 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___59;

struct netns_bpf___59 {
	struct bpf_prog_array___59 *run_array[2];
	struct bpf_prog___59 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___70 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___52 *nlsk;
	struct sock___52 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___70 xfrm4_dst_ops;
	struct dst_ops___70 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___70 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___52 *rtnl;
	struct sock___52 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___65 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___70 ipv4;
	struct netns_ipv6___70 ipv6;
	struct netns_ieee802154_lowpan___70 ieee802154_lowpan;
	struct netns_sctp___52 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___65 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___59 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___70 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___52 *crypto_nlsk;
	struct sock___52 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___183 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___183 *root_cset;
};

struct fwnode_operations___233;

struct fwnode_handle___233 {
	struct fwnode_handle___233 *secondary;
	const struct fwnode_operations___233 *ops;
	struct device___237 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___233;

struct fwnode_endpoint___233;

struct fwnode_operations___233 {
	struct fwnode_handle___233 * (*get)(struct fwnode_handle___233 *);
	void (*put)(struct fwnode_handle___233 *);
	bool (*device_is_available)(const struct fwnode_handle___233 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___233 *, const struct device___237 *);
	bool (*property_present)(const struct fwnode_handle___233 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___233 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___233 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___233 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*get_parent)(const struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*get_next_child_node)(const struct fwnode_handle___233 *, struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*get_named_child_node)(const struct fwnode_handle___233 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___233 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___233 *);
	struct fwnode_handle___233 * (*graph_get_next_endpoint)(const struct fwnode_handle___233 *, struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*graph_get_remote_endpoint)(const struct fwnode_handle___233 *);
	struct fwnode_handle___233 * (*graph_get_port_parent)(struct fwnode_handle___233 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___233 *, struct fwnode_endpoint___233 *);
	int (*add_links)(struct fwnode_handle___233 *);
};

struct fwnode_endpoint___233 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___233 *local_fwnode;
};

struct fwnode_reference_args___233 {
	struct fwnode_handle___233 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kobj_ns_type_operations___52 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___52 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___70 *net;
} possible_net_t___65;

struct proto___52;

struct sock_common___52 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___52 *skc_prot;
	possible_net_t___65 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___52 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___52 {
	struct cgroup___183 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___52;

struct socket_wq___53;

struct socket___54;

struct sock___52 {
	struct sock_common___52 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___65 sk_error_queue;
	struct sk_buff___66 *sk_rx_skb_cache;
	struct sk_buff_head___65 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___66 *head;
		struct sk_buff___66 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___52 *sk_filter;
	union {
		struct socket_wq___53 *sk_wq;
		struct socket_wq___53 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___52 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___52 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___66 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___66 *sk_tx_skb_cache;
	struct sk_buff_head___65 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___261 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___52 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___233 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___54 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___52 sk_cgrp_data;
	struct mem_cgroup___121 *sk_memcg;
	void (*sk_state_change)(struct sock___52 *);
	void (*sk_data_ready)(struct sock___52 *);
	void (*sk_write_space)(struct sock___52 *);
	void (*sk_error_report)(struct sock___52 *);
	int (*sk_backlog_rcv)(struct sock___52 *, struct sk_buff___66 *);
	struct sk_buff___66 * (*sk_validate_xmit_skb)(struct sock___52 *, struct net_device___65 *, struct sk_buff___66 *);
	void (*sk_destruct)(struct sock___52 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___244;

struct attribute_group___244 {
	const char *name;
	umode_t (*is_visible)(struct kobject___244 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___244 *, struct bin_attribute___244 *, int);
	struct attribute **attrs;
	struct bin_attribute___244 **bin_attrs;
};

struct bin_attribute___244 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___256 * (*f_mapping)();
	ssize_t (*read)(struct file___256 *, struct kobject___244 *, struct bin_attribute___244 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___256 *, struct kobject___244 *, struct bin_attribute___244 *, char *, loff_t, size_t);
	int (*mmap)(struct file___256 *, struct kobject___244 *, struct bin_attribute___244 *, struct vm_area_struct___261 *);
};

struct sysfs_ops___244 {
	ssize_t (*show)(struct kobject___244 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___244 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___244;

struct kset___244 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___244 kobj;
	const struct kset_uevent_ops___244 *uevent_ops;
};

struct kobj_type___244 {
	void (*release)(struct kobject___244 *);
	const struct sysfs_ops___244 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___244 **default_groups;
	const struct kobj_ns_type_operations___52 * (*child_ns_type)(struct kobject___244 *);
	const void * (*namespace)(struct kobject___244 *);
	void (*get_ownership)(struct kobject___244 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___244 {
	int (* const filter)(struct kset___244 *, struct kobject___244 *);
	const char * (* const name)(struct kset___244 *, struct kobject___244 *);
	int (* const uevent)(struct kset___244 *, struct kobject___244 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___240 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___240 *);
	int (*get)(char *, const struct kernel_param___240 *);
	void (*free)(void *);
};

struct kparam_array___240;

struct kernel_param___240 {
	const char *name;
	struct module___240 *mod;
	const struct kernel_param_ops___240 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___240 *arr;
	};
};

struct kparam_array___240 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___240 *ops;
	void *elem;
};

struct module_attribute___240 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___240 *, struct module_kobject___241 *, char *);
	ssize_t (*store)(struct module_attribute___240 *, struct module_kobject___241 *, const char *, size_t);
	void (*setup)(struct module___240 *, const char *);
	int (*test)(struct module___240 *);
	void (*free)(struct module___240 *);
};

struct dev_pagemap_ops___251 {
	void (*page_free)(struct page___261 *);
	void (*kill)(struct dev_pagemap___251 *);
	void (*cleanup)(struct dev_pagemap___251 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___251 *);
};

struct bpf_iter_aux_info___68;

typedef int (*bpf_iter_init_seq_priv_t___67)(void *, struct bpf_iter_aux_info___68 *);

struct bpf_map___68;

struct bpf_iter_aux_info___68 {
	struct bpf_map___68 *map;
};

struct bpf_iter_seq_info___67 {
	const struct seq_operations___231 *seq_ops;
	bpf_iter_init_seq_priv_t___67 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___68;

struct bpf_map_ops___67 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___68 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___68 *, struct file___256 *);
	void (*map_free)(struct bpf_map___68 *);
	int (*map_get_next_key)(struct bpf_map___68 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___68 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___68 *, void *);
	int (*map_lookup_batch)(struct bpf_map___68 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___68 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___68 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___68 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___68 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___68 *, void *);
	int (*map_update_elem)(struct bpf_map___68 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___68 *, void *);
	int (*map_push_elem)(struct bpf_map___68 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___68 *, void *);
	int (*map_peek_elem)(struct bpf_map___68 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___68 *, struct file___256 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___68 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___68 *, void *, struct seq_file___231 *);
	int (*map_check_btf)(const struct bpf_map___68 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___68 *, struct bpf_prog_aux___68 *);
	void (*map_poke_untrack)(struct bpf_map___68 *, struct bpf_prog_aux___68 *);
	void (*map_poke_run)(struct bpf_map___68 *, u32, struct bpf_prog___59 *, struct bpf_prog___59 *);
	int (*map_direct_value_addr)(const struct bpf_map___68 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___68 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___68 *, struct vm_area_struct___261 *);
	__poll_t (*map_poll)(struct bpf_map___68 *, struct file___256 *, struct poll_table_struct___177 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___68 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___68 *, const struct bpf_map___68 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___68 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___67 *iter_seq_info;
};

struct bpf_map___68 {
	const struct bpf_map_ops___67 *ops;
	struct bpf_map___68 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___121 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___67;

struct bpf_jit_poke_descriptor___67;

struct bpf_prog_ops___59;

struct btf_mod_pair___67;

struct bpf_prog_offload___65;

struct bpf_prog_aux___68 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___59 *dst_prog;
	struct bpf_trampoline___67 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___59 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___67 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___59 *ops;
	struct bpf_map___68 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___67 *used_btfs;
	struct bpf_prog___59 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___68 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___65 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___59 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___68 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___65;

struct bpf_map_dev_ops___65 {
	int (*map_get_next_key)(struct bpf_offloaded_map___65 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___65 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___65 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___65 *, void *);
};

struct bpf_offloaded_map___65 {
	struct bpf_map___68 map;
	struct net_device___65 *netdev;
	const struct bpf_map_dev_ops___65 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___65(struct sk_buff___66 **);

struct bpf_xdp_entity___59 {
	struct bpf_prog___59 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___65;

struct net_device_ops___65;

struct l3mdev_ops___52;

struct xfrmdev_ops___65;

struct header_ops___65;

struct netdev_rx_queue___65;

struct mini_Qdisc___59;

struct netdev_queue___65;

struct Qdisc___59;

struct rtnl_link_ops___59;

struct dcbnl_rtnl_ops___65;

struct net_device___65 {
	char name[16];
	struct netdev_name_node___65 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___65 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___52 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___65 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___65 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___244 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___65 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___59 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___65 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___59 *miniq_ingress;
	struct netdev_queue___65 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___65 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___59 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___59 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___65 = 0,
		NETREG_REGISTERED___65 = 1,
		NETREG_UNREGISTERING___65 = 2,
		NETREG_UNREGISTERED___65 = 3,
		NETREG_RELEASED___65 = 4,
		NETREG_DUMMY___65 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___65 = 0,
		RTNL_LINK_INITIALIZING___65 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___65 *);
	struct netpoll_info *npinfo;
	possible_net_t___65 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___237 dev;
	const struct attribute_group___244 *sysfs_groups[4];
	const struct attribute_group___244 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___59 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___65 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___59 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___59 {
	int (*test_run)(struct bpf_prog___59 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___65 {
	struct bpf_prog___59 *prog;
	struct net_device___65 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___67 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___59 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___240 *mod;
};

struct bpf_jit_poke_descriptor___67 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___68 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___67 {
	struct btf *btf;
	struct module___240 *module;
};

struct bpf_prog_array_item___59 {
	struct bpf_prog___59 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___59 {
	struct callback_head rcu;
	struct bpf_prog_array_item___59 items[0];
};

struct sk_buff___66 {
	union {
		struct {
			struct sk_buff___66 *next;
			struct sk_buff___66 *prev;
			union {
				struct net_device___65 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___52 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___66 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___183;

struct cgroup_subsys___183 {
	struct cgroup_subsys_state___183 * (*css_alloc)(struct cgroup_subsys_state___183 *);
	int (*css_online)(struct cgroup_subsys_state___183 *);
	void (*css_offline)(struct cgroup_subsys_state___183 *);
	void (*css_released)(struct cgroup_subsys_state___183 *);
	void (*css_free)(struct cgroup_subsys_state___183 *);
	void (*css_reset)(struct cgroup_subsys_state___183 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___183 *, int);
	int (*css_extra_stat_show)(struct seq_file___231 *, struct cgroup_subsys_state___183 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___263 *, struct css_set___183 *);
	void (*cancel_fork)(struct task_struct___263 *, struct css_set___183 *);
	void (*fork)(struct task_struct___263 *);
	void (*exit)(struct task_struct___263 *);
	void (*release)(struct task_struct___263 *);
	void (*bind)(struct cgroup_subsys_state___183 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___183 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___183 *dfl_cftypes;
	struct cftype___183 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___183 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___183 *updated_children;
	struct cgroup___183 *updated_next;
};

struct cgroup_root___183 {
	struct kernfs_root___244 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___183 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___183 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___183 *ss;
	struct list_head node;
	struct kernfs_ops___244 *kf_ops;
	int (*open)(struct kernfs_open_file___244 *);
	void (*release)(struct kernfs_open_file___244 *);
	u64 (*read_u64)(struct cgroup_subsys_state___183 *, struct cftype___183 *);
	s64 (*read_s64)(struct cgroup_subsys_state___183 *, struct cftype___183 *);
	int (*seq_show)(struct seq_file___231 *, void *);
	void * (*seq_start)(struct seq_file___231 *, loff_t *);
	void * (*seq_next)(struct seq_file___231 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___231 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___183 *, struct cftype___183 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___183 *, struct cftype___183 *, s64);
	ssize_t (*write)(struct kernfs_open_file___244 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___244 *, struct poll_table_struct___177 *);
};

struct css_task_iter___7 {
	struct cgroup_subsys___183 *ss;
	unsigned int flags;
	struct list_head *cset_pos;
	struct list_head *cset_head;
	struct list_head *tcset_pos;
	struct list_head *tcset_head;
	struct list_head *task_pos;
	struct list_head *cur_tasks_head;
	struct css_set___183 *cur_cset;
	struct css_set___183 *cur_dcset;
	struct task_struct___263 *cur_task;
	struct list_head iters_node;
};

struct msghdr___54 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___176 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___256 *msg_iocb;
};

struct inet_frags___70;

struct fqdir___70 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___70 *f;
	struct net___70 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___70;

struct inet_frags___70 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___70 *, const void *);
	void (*destructor)(struct inet_frag_queue___70 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___70 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___66 *fragments_tail;
	struct sk_buff___66 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___70 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___52;

struct fib_lookup_arg___52;

struct fib_rules_ops___52 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___52 *, struct flowi *, int, struct fib_lookup_arg___52 *);
	bool (*suppress)(struct fib_rule___52 *, int, struct fib_lookup_arg___52 *);
	int (*match)(struct fib_rule___52 *, struct flowi *, int);
	int (*configure)(struct fib_rule___52 *, struct sk_buff___66 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___52 *);
	int (*compare)(struct fib_rule___52 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___52 *, struct sk_buff___66 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___52 *);
	void (*flush_cache)(struct fib_rules_ops___52 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___240 *owner;
	struct net___70 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___52 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___70 *);
	int (*fib_dump)(struct net___70 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___240 *owner;
	struct callback_head rcu;
};

struct dst_entry___52 {
	struct net_device___65 *dev;
	struct dst_ops___70 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___66 *);
	int (*output)(struct net___70 *, struct sock___52 *, struct sk_buff___66 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___52;

struct neigh_parms___52;

struct neigh_ops___52;

struct neighbour___52 {
	struct neighbour___52 *next;
	struct neigh_table___52 *tbl;
	struct neigh_parms___52 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___65 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___52 *, struct sk_buff___66 *);
	const struct neigh_ops___52 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___65 *dev;
	u8 primary_key[0];
};

struct socket_wq___53 {
	wait_queue_head_t wait;
	struct fasync_struct___256 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___53;

struct socket___54 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___256 *file;
	struct sock___52 *sk;
	const struct proto_ops___53 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___53 wq;
};

typedef int (*sk_read_actor_t___52)(read_descriptor_t *, struct sk_buff___66 *, unsigned int, size_t);

struct proto_ops___53 {
	int family;
	struct module___240 *owner;
	int (*release)(struct socket___54 *);
	int (*bind)(struct socket___54 *, struct sockaddr *, int);
	int (*connect)(struct socket___54 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___54 *, struct socket___54 *);
	int (*accept)(struct socket___54 *, struct socket___54 *, int, bool);
	int (*getname)(struct socket___54 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___256 *, struct socket___54 *, struct poll_table_struct___177 *);
	int (*ioctl)(struct socket___54 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___54 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___54 *, void *, bool, bool);
	int (*listen)(struct socket___54 *, int);
	int (*shutdown)(struct socket___54 *, int);
	int (*setsockopt)(struct socket___54 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___54 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___231 *, struct socket___54 *);
	int (*sendmsg)(struct socket___54 *, struct msghdr___54 *, size_t);
	int (*recvmsg)(struct socket___54 *, struct msghdr___54 *, size_t, int);
	int (*mmap)(struct file___256 *, struct socket___54 *, struct vm_area_struct___261 *);
	ssize_t (*sendpage)(struct socket___54 *, struct page___261 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___54 *, loff_t *, struct pipe_inode_info___97 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___52 *, int);
	int (*peek_len)(struct socket___54 *);
	int (*read_sock)(struct sock___52 *, read_descriptor_t *, sk_read_actor_t___52);
	int (*sendpage_locked)(struct sock___52 *, struct page___261 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___52 *, struct msghdr___54 *, size_t);
	int (*set_rcvlowat)(struct sock___52 *, int);
};

struct dev_pm_ops___237 {
	int (*prepare)(struct device___237 *);
	void (*complete)(struct device___237 *);
	int (*suspend)(struct device___237 *);
	int (*resume)(struct device___237 *);
	int (*freeze)(struct device___237 *);
	int (*thaw)(struct device___237 *);
	int (*poweroff)(struct device___237 *);
	int (*restore)(struct device___237 *);
	int (*suspend_late)(struct device___237 *);
	int (*resume_early)(struct device___237 *);
	int (*freeze_late)(struct device___237 *);
	int (*thaw_early)(struct device___237 *);
	int (*poweroff_late)(struct device___237 *);
	int (*restore_early)(struct device___237 *);
	int (*suspend_noirq)(struct device___237 *);
	int (*resume_noirq)(struct device___237 *);
	int (*freeze_noirq)(struct device___237 *);
	int (*thaw_noirq)(struct device___237 *);
	int (*poweroff_noirq)(struct device___237 *);
	int (*restore_noirq)(struct device___237 *);
	int (*runtime_suspend)(struct device___237 *);
	int (*runtime_resume)(struct device___237 *);
	int (*runtime_idle)(struct device___237 *);
};

struct wakeup_source___237 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___237 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___237 {
	struct dev_pm_ops___237 ops;
	int (*start)(struct device___237 *);
	void (*detach)(struct device___237 *, bool);
	int (*activate)(struct device___237 *);
	void (*sync)(struct device___237 *);
	void (*dismiss)(struct device___237 *);
};

struct bus_type___237 {
	const char *name;
	const char *dev_name;
	struct device___237 *dev_root;
	const struct attribute_group___244 **bus_groups;
	const struct attribute_group___244 **dev_groups;
	const struct attribute_group___244 **drv_groups;
	int (*match)(struct device___237 *, struct device_driver___237 *);
	int (*uevent)(struct device___237 *, struct kobj_uevent_env *);
	int (*probe)(struct device___237 *);
	void (*sync_state)(struct device___237 *);
	void (*remove)(struct device___237 *);
	void (*shutdown)(struct device___237 *);
	int (*online)(struct device___237 *);
	int (*offline)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	int (*num_vf)(struct device___237 *);
	int (*dma_configure)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___237 {
	const char *name;
	struct bus_type___237 *bus;
	struct module___240 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___237 *);
	void (*sync_state)(struct device___237 *);
	int (*remove)(struct device___237 *);
	void (*shutdown)(struct device___237 *);
	int (*suspend)(struct device___237 *, pm_message_t);
	int (*resume)(struct device___237 *);
	const struct attribute_group___244 **groups;
	const struct attribute_group___244 **dev_groups;
	const struct dev_pm_ops___237 *pm;
	void (*coredump)(struct device___237 *);
	struct driver_private *p;
};

struct device_type___237 {
	const char *name;
	const struct attribute_group___244 **groups;
	int (*uevent)(struct device___237 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___237 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___237 *);
	const struct dev_pm_ops___237 *pm;
};

struct class___237 {
	const char *name;
	struct module___240 *owner;
	const struct attribute_group___244 **class_groups;
	const struct attribute_group___244 **dev_groups;
	struct kobject___244 *dev_kobj;
	int (*dev_uevent)(struct device___237 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___237 *, umode_t *);
	void (*class_release)(struct class___237 *);
	void (*dev_release)(struct device___237 *);
	int (*shutdown_pre)(struct device___237 *);
	const struct kobj_ns_type_operations___52 *ns_type;
	const void * (*namespace)(struct device___237 *);
	void (*get_ownership)(struct device___237 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___237 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___97;

struct pipe_buffer___97 {
	struct page___261 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___97 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___97 {
	int (*confirm)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
	void (*release)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
	bool (*try_steal)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
	bool (*get)(struct pipe_inode_info___97 *, struct pipe_buffer___97 *);
};

struct dcbnl_rtnl_ops___65 {
	int (*ieee_getets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___65 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___65 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___65 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___65 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___65 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___65 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___65 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___65 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___65 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___65 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___65 *);
	u8 (*setstate)(struct net_device___65 *, u8);
	void (*getpermhwaddr)(struct net_device___65 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___65 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___65 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___65 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___65 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___65 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___65 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___65 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___65 *, int, u8 *);
	void (*setpfccfg)(struct net_device___65 *, int, u8);
	void (*getpfccfg)(struct net_device___65 *, int, u8 *);
	u8 (*setall)(struct net_device___65 *);
	u8 (*getcap)(struct net_device___65 *, int, u8 *);
	int (*getnumtcs)(struct net_device___65 *, int, u8 *);
	int (*setnumtcs)(struct net_device___65 *, int, u8);
	u8 (*getpfcstate)(struct net_device___65 *);
	void (*setpfcstate)(struct net_device___65 *, u8);
	void (*getbcncfg)(struct net_device___65 *, int, u32 *);
	void (*setbcncfg)(struct net_device___65 *, int, u32);
	void (*getbcnrp)(struct net_device___65 *, int, u8 *);
	void (*setbcnrp)(struct net_device___65 *, int, u8);
	int (*setapp)(struct net_device___65 *, u8, u16, u8);
	int (*getapp)(struct net_device___65 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___65 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___65 *, int, u8);
	u8 (*getdcbx)(struct net_device___65 *);
	u8 (*setdcbx)(struct net_device___65 *, u8);
	int (*peer_getappinfo)(struct net_device___65 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___65 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___65 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___65 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___65 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___65 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___65 {
	struct net_device___65 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___65 {
	struct net_device___65 *dev;
};

struct xdp_buff___65 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___65 *rxq;
	struct xdp_txq_info___65 *txq;
	u32 frame_sz;
};

struct xdp_frame___65 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___65 *dev_rx;
};

struct netlink_callback___65 {
	struct sk_buff___66 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___66 *, struct netlink_callback___65 *);
	int (*done)(struct netlink_callback___65 *);
	void *data;
	struct module___240 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___65 {
	int (*create)(struct sk_buff___66 *, struct net_device___65 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___66 *, unsigned char *);
	int (*cache)(const struct neighbour___52 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___65 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___66 *);
};

struct netdev_queue___65 {
	struct net_device___65 *dev;
	struct Qdisc___59 *qdisc;
	struct Qdisc___59 *qdisc_sleeping;
	struct kobject___244 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___65 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___59 {
	struct sk_buff___66 *head;
	struct sk_buff___66 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___59;

struct Qdisc___59 {
	int (*enqueue)(struct sk_buff___66 *, struct Qdisc___59 *, struct sk_buff___66 **);
	struct sk_buff___66 * (*dequeue)(struct Qdisc___59 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___59 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___65 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___65 gso_skb;
	struct qdisc_skb_head___59 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___59 *next_sched;
	struct sk_buff_head___65 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___65 {
	struct xdp_rxq_info___65 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___244 kobj;
	struct net_device___65 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___65 {
	enum net_device_path_type type;
	const struct net_device___65 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___65 = 0,
				DEV_PATH_BR_VLAN_TAG___65 = 1,
				DEV_PATH_BR_VLAN_UNTAG___65 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___65 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___65 {
	const struct net_device___65 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___65 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___59 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___65 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___65 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___66 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___65 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___65 *dev;
	const char *name;
};

struct net_device_ops___65 {
	int (*ndo_init)(struct net_device___65 *);
	void (*ndo_uninit)(struct net_device___65 *);
	int (*ndo_open)(struct net_device___65 *);
	int (*ndo_stop)(struct net_device___65 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___66 *, struct net_device___65 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___66 *, struct net_device___65 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___65 *, struct sk_buff___66 *, struct net_device___65 *);
	void (*ndo_change_rx_flags)(struct net_device___65 *, int);
	void (*ndo_set_rx_mode)(struct net_device___65 *);
	int (*ndo_set_mac_address)(struct net_device___65 *, void *);
	int (*ndo_validate_addr)(struct net_device___65 *);
	int (*ndo_do_ioctl)(struct net_device___65 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___65 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___65 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___65 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___65 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___65 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___65 *, int);
	int (*ndo_neigh_setup)(struct net_device___65 *, struct neigh_parms___52 *);
	void (*ndo_tx_timeout)(struct net_device___65 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___65 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___65 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___65 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___65 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___65 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___65 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___65 *);
	int (*ndo_netpoll_setup)(struct net_device___65 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___65 *);
	int (*ndo_set_vf_mac)(struct net_device___65 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___65 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___65 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___65 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___65 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___65 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___65 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___65 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___65 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___65 *, int, struct sk_buff___66 *);
	int (*ndo_get_vf_guid)(struct net_device___65 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___65 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___65 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___65 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___65 *);
	int (*ndo_fcoe_disable)(struct net_device___65 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___65 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___65 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___65 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___65 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___65 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___65 *, const struct sk_buff___66 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___65 *, struct net_device___65 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___65 *, struct net_device___65 *);
	struct net_device___65 * (*ndo_get_xmit_slave)(struct net_device___65 *, struct sk_buff___66 *, bool);
	struct net_device___65 * (*ndo_sk_get_lower_dev)(struct net_device___65 *, struct sock___52 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___65 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___65 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___65 *, struct neighbour___52 *);
	void (*ndo_neigh_destroy)(struct net_device___65 *, struct neighbour___52 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___66 *, struct netlink_callback___65 *, struct net_device___65 *, struct net_device___65 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___66 *, struct nlattr **, struct net_device___65 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___65 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___66 *, u32, u32, struct net_device___65 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___65 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___65 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___65 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___65 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___65 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___65 *, struct net_device___65 *);
	void (*ndo_dfwd_del_station)(struct net_device___65 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___65 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___65 *);
	int (*ndo_change_proto_down)(struct net_device___65 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___65 *, struct sk_buff___66 *);
	void (*ndo_set_rx_headroom)(struct net_device___65 *, int);
	int (*ndo_bpf)(struct net_device___65 *, struct netdev_bpf___65 *);
	int (*ndo_xdp_xmit)(struct net_device___65 *, int, struct xdp_frame___65 **, u32);
	struct net_device___65 * (*ndo_xdp_get_xmit_slave)(struct net_device___65 *, struct xdp_buff___65 *);
	int (*ndo_xsk_wakeup)(struct net_device___65 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___65 *);
	int (*ndo_tunnel_ctl)(struct net_device___65 *, struct ip_tunnel_parm *, int);
	struct net_device___65 * (*ndo_get_peer_dev)(struct net_device___65 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___65 *, struct net_device_path___65 *);
};

struct neigh_parms___52 {
	possible_net_t___65 net;
	struct net_device___65 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___52 *);
	struct neigh_table___52 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___52 {
	u32 (*l3mdev_fib_table)(const struct net_device___65 *);
	struct sk_buff___66 * (*l3mdev_l3_rcv)(struct net_device___65 *, struct sk_buff___66 *, u16);
	struct sk_buff___66 * (*l3mdev_l3_out)(struct net_device___65 *, struct sock___52 *, struct sk_buff___66 *, u16);
	struct dst_entry___52 * (*l3mdev_link_scope_lookup)(const struct net_device___65 *, struct flowi6 *);
};

struct tcf_proto___59;

struct tcf_block___59;

struct mini_Qdisc___59 {
	struct tcf_proto___59 *filter_list;
	struct tcf_block___59 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___59 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___65 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___65 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___70 *, struct net_device___65 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___65 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___65 *, struct list_head *);
	size_t (*get_size)(const struct net_device___65 *);
	int (*fill_info)(struct sk_buff___66 *, const struct net_device___65 *);
	size_t (*get_xstats_size)(const struct net_device___65 *);
	int (*fill_xstats)(struct sk_buff___66 *, const struct net_device___65 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___65 *, struct net_device___65 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___65 *, const struct net_device___65 *);
	int (*fill_slave_info)(struct sk_buff___66 *, const struct net_device___65 *, const struct net_device___65 *);
	struct net___70 * (*get_link_net)(const struct net_device___65 *);
	size_t (*get_linkxstats_size)(const struct net_device___65 *, int);
	int (*fill_linkxstats)(struct sk_buff___66 *, const struct net_device___65 *, int *, int);
};

struct block_device_operations___147;

struct gendisk___150 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___150 *part0;
	const struct block_device_operations___147 *fops;
	struct request_queue___147 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___133 *bdi;
	struct kobject___244 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___244 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___147 {
	struct bio___147 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___173 *bip_vec;
	struct bio_vec___173 bip_inline_vecs[0];
};

struct blkcg___135;

struct blkg_policy_data___135;

struct blkcg_gq___135 {
	struct request_queue___147 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___135 *blkcg;
	struct blkcg_gq___135 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___135 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___147 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___147(struct request___147 *);

typedef void integrity_complete_fn___147(struct request___147 *, unsigned int);

struct blk_integrity_profile___147 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___147 *prepare_fn;
	integrity_complete_fn___147 *complete_fn;
	const char *name;
};

struct block_device_operations___147 {
	blk_qc_t (*submit_bio)(struct bio___147 *);
	int (*open)(struct block_device___150 *, fmode_t);
	void (*release)(struct gendisk___150 *, fmode_t);
	int (*rw_page)(struct block_device___150 *, sector_t, struct page___261 *, unsigned int);
	int (*ioctl)(struct block_device___150 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___150 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___150 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___150 *);
	int (*getgeo)(struct block_device___150 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___150 *, bool);
	void (*swap_slot_free_notify)(struct block_device___150 *, long unsigned int);
	int (*report_zones)(struct gendisk___150 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___150 *, umode_t *);
	struct module___240 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___150 *, sector_t *);
};

typedef void rq_end_io_fn___147(struct request___147 *, blk_status_t);

struct request___147 {
	struct request_queue___147 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___142 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___147 *bio;
	struct bio___147 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___173 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___147 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___147 *saved_end_io;
		} flush;
	};
	struct gendisk___150 *rq_disk;
	struct block_device___150 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___147 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___142 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___147 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___244 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___256 *debugfs_dir;
	struct dentry___256 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___147;

struct elevator_mq_ops___147 {
	int (*init_sched)(struct request_queue___147 *, struct elevator_type___147 *);
	void (*exit_sched)(struct elevator_queue___147 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___142 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___142 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___142 *);
	bool (*allow_merge)(struct request_queue___147 *, struct request___147 *, struct bio___147 *);
	bool (*bio_merge)(struct request_queue___147 *, struct bio___147 *, unsigned int);
	int (*request_merge)(struct request_queue___147 *, struct request___147 **, struct bio___147 *);
	void (*request_merged)(struct request_queue___147 *, struct request___147 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___147 *, struct request___147 *, struct request___147 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___147 *);
	void (*finish_request)(struct request___147 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___142 *, struct list_head *, bool);
	struct request___147 * (*dispatch_request)(struct blk_mq_hw_ctx___142 *);
	bool (*has_work)(struct blk_mq_hw_ctx___142 *);
	void (*completed_request)(struct request___147 *, u64);
	void (*requeue_request)(struct request___147 *);
	struct request___147 * (*former_request)(struct request_queue___147 *, struct request___147 *);
	struct request___147 * (*next_request)(struct request_queue___147 *, struct request___147 *);
	void (*init_icq)(struct io_cq___147 *);
	void (*exit_icq)(struct io_cq___147 *);
};

struct elv_fs_entry___147;

struct elevator_type___147 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___147 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___147 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___240 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___147 {
	struct elevator_type___147 *type;
	void *elevator_data;
	struct kobject___244 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___147 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___147 *, char *);
	ssize_t (*store)(struct elevator_queue___147 *, const char *, size_t);
};

struct blk_mq_queue_data___142;

struct blk_mq_ops___142 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___142 *, const struct blk_mq_queue_data___142 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___142 *);
	int (*get_budget)(struct request_queue___147 *);
	void (*put_budget)(struct request_queue___147 *, int);
	void (*set_rq_budget_token)(struct request___147 *, int);
	int (*get_rq_budget_token)(struct request___147 *);
	enum blk_eh_timer_return (*timeout)(struct request___147 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___142 *);
	void (*complete)(struct request___147 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___142 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___142 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___142 *, struct request___147 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___142 *, struct request___147 *, unsigned int);
	void (*initialize_rq_fn)(struct request___147 *);
	void (*cleanup_rq)(struct request___147 *);
	bool (*busy)(struct request_queue___147 *);
	int (*map_queues)(struct blk_mq_tag_set___142 *);
	void (*show_rq)(struct seq_file___231 *, struct request___147 *);
};

struct blk_mq_tag_set___142 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___142 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___142 {
	struct request___147 *rq;
	bool last;
};

struct blkcg_policy_data___135;

struct blkcg___135 {
	struct cgroup_subsys_state___183 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___135 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___135 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___135 {
	struct blkcg___135 *blkcg;
	int plid;
};

struct blkg_policy_data___135 {
	struct blkcg_gq___135 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___121 {
	struct mem_cgroup___121 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___121 {
	struct lruvec___129 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___121 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___121 *memcg;
};

struct obj_cgroup___121 {
	struct percpu_ref refcnt;
	struct mem_cgroup___121 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___59 {
	spinlock_t *lock;
	struct sk_buff___66 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___59;

struct Qdisc_ops___59 {
	struct Qdisc_ops___59 *next;
	const struct Qdisc_class_ops___59 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___66 *, struct Qdisc___59 *, struct sk_buff___66 **);
	struct sk_buff___66 * (*dequeue)(struct Qdisc___59 *);
	struct sk_buff___66 * (*peek)(struct Qdisc___59 *);
	int (*init)(struct Qdisc___59 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___59 *);
	void (*destroy)(struct Qdisc___59 *);
	int (*change)(struct Qdisc___59 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___59 *);
	int (*change_tx_queue_len)(struct Qdisc___59 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___59 *, unsigned int);
	int (*dump)(struct Qdisc___59 *, struct sk_buff___66 *);
	int (*dump_stats)(struct Qdisc___59 *, struct gnet_dump___59 *);
	void (*ingress_block_set)(struct Qdisc___59 *, u32);
	void (*egress_block_set)(struct Qdisc___59 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___59 *);
	u32 (*egress_block_get)(struct Qdisc___59 *);
	struct module___240 *owner;
};

struct Qdisc_class_ops___59 {
	unsigned int flags;
	struct netdev_queue___65 * (*select_queue)(struct Qdisc___59 *, struct tcmsg *);
	int (*graft)(struct Qdisc___59 *, long unsigned int, struct Qdisc___59 *, struct Qdisc___59 **, struct netlink_ext_ack *);
	struct Qdisc___59 * (*leaf)(struct Qdisc___59 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___59 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___59 *, u32);
	int (*change)(struct Qdisc___59 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___59 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___59 *, struct qdisc_walker *);
	struct tcf_block___59 * (*tcf_block)(struct Qdisc___59 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___59 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___59 *, long unsigned int);
	int (*dump)(struct Qdisc___59 *, long unsigned int, struct sk_buff___66 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___59 *, long unsigned int, struct gnet_dump___59 *);
};

struct tcf_chain___59;

struct tcf_block___59 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___70 *net;
	struct Qdisc___59 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___59 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___59;

struct tcf_proto_ops___59;

struct tcf_proto___59 {
	struct tcf_proto___59 *next;
	void *root;
	int (*classify)(struct sk_buff___66 *, const struct tcf_proto___59 *, struct tcf_result___59 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___59 *ops;
	struct tcf_chain___59 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___59 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___59 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___59 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___66 *, const struct tcf_proto___59 *, struct tcf_result___59 *);
	int (*init)(struct tcf_proto___59 *);
	void (*destroy)(struct tcf_proto___59 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___59 *, u32);
	void (*put)(struct tcf_proto___59 *, void *);
	int (*change)(struct net___70 *, struct sk_buff___66 *, struct tcf_proto___59 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___59 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___59 *);
	void (*walk)(struct tcf_proto___59 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___59 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___59 *, void *);
	void (*hw_del)(struct tcf_proto___59 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___70 *, struct tcf_chain___59 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___70 *, struct tcf_proto___59 *, void *, struct sk_buff___66 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___70 *, struct tcf_proto___59 *, void *, struct sk_buff___66 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___66 *, struct net___70 *, void *);
	struct module___240 *owner;
	int flags;
};

struct tcf_chain___59 {
	struct mutex filter_chain_lock;
	struct tcf_proto___59 *filter_chain;
	struct list_head list;
	struct tcf_block___59 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___59 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___52 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___59 *prog;
};

struct pneigh_entry___52;

struct neigh_hash_table___52;

struct neigh_table___52 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___65 *, __u32 *);
	bool (*key_eq)(const struct neighbour___52 *, const void *);
	int (*constructor)(struct neighbour___52 *);
	int (*pconstructor)(struct pneigh_entry___52 *);
	void (*pdestructor)(struct pneigh_entry___52 *);
	void (*proxy_redo)(struct sk_buff___66 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___65 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___52 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___65 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___52 *nht;
	struct pneigh_entry___52 **phash_buckets;
};

struct neigh_ops___52 {
	int family;
	void (*solicit)(struct neighbour___52 *, struct sk_buff___66 *);
	void (*error_report)(struct neighbour___52 *, struct sk_buff___66 *);
	int (*output)(struct neighbour___52 *, struct sk_buff___66 *);
	int (*connected_output)(struct neighbour___52 *, struct sk_buff___66 *);
};

struct pneigh_entry___52 {
	struct pneigh_entry___52 *next;
	possible_net_t___65 net;
	struct net_device___65 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___52 {
	struct neighbour___52 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___52 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___52 *ctarget;
	struct net___70 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___52 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___52 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___39;

struct proto___52 {
	void (*close)(struct sock___52 *, long int);
	int (*pre_connect)(struct sock___52 *, struct sockaddr *, int);
	int (*connect)(struct sock___52 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___52 *, int);
	struct sock___52 * (*accept)(struct sock___52 *, int, int *, bool);
	int (*ioctl)(struct sock___52 *, int, long unsigned int);
	int (*init)(struct sock___52 *);
	void (*destroy)(struct sock___52 *);
	void (*shutdown)(struct sock___52 *, int);
	int (*setsockopt)(struct sock___52 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___52 *, int, int, char *, int *);
	void (*keepalive)(struct sock___52 *, int);
	int (*compat_ioctl)(struct sock___52 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___52 *, struct msghdr___54 *, size_t);
	int (*recvmsg)(struct sock___52 *, struct msghdr___54 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___52 *, struct page___261 *, int, size_t, int);
	int (*bind)(struct sock___52 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___52 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___52 *, struct sk_buff___66 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___52 *);
	int (*hash)(struct sock___52 *);
	void (*unhash)(struct sock___52 *);
	void (*rehash)(struct sock___52 *);
	int (*get_port)(struct sock___52 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___52 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___52 *, int);
	bool (*sock_is_readable)(struct sock___52 *);
	void (*enter_memory_pressure)(struct sock___52 *);
	void (*leave_memory_pressure)(struct sock___52 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___39 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___240 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___52 *, int);
};

struct request_sock___40;

struct request_sock_ops___39 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___52 *, struct request_sock___40 *);
	void (*send_ack)(const struct sock___52 *, struct sk_buff___66 *, struct request_sock___40 *);
	void (*send_reset)(const struct sock___52 *, struct sk_buff___66 *);
	void (*destructor)(struct request_sock___40 *);
	void (*syn_ack_timeout)(const struct request_sock___40 *);
};

struct request_sock___40 {
	struct sock_common___52 __req_common;
	struct request_sock___40 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___39 *rsk_ops;
	struct sock___52 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct cgroup_cls_state___3 {
	struct cgroup_subsys_state___183 css;
	u32 classid;
};

struct update_classid_context {
	u32 classid;
	unsigned int batch;
};

struct rtnexthop {
	short unsigned int rtnh_len;
	unsigned char rtnh_flags;
	unsigned char rtnh_hops;
	int rtnh_ifindex;
};

struct lwtunnel_encap_ops {
	int (*build_state)(struct net___65 *, struct nlattr *, unsigned int, const void *, struct lwtunnel_state___28 **, struct netlink_ext_ack *);
	void (*destroy_state)(struct lwtunnel_state___28 *);
	int (*output)(struct net___65 *, struct sock___48 *, struct sk_buff___61 *);
	int (*input)(struct sk_buff___61 *);
	int (*fill_encap)(struct sk_buff___61 *, struct lwtunnel_state___28 *);
	int (*get_encap_size)(struct lwtunnel_state___28 *);
	int (*cmp_encap)(struct lwtunnel_state___28 *, struct lwtunnel_state___28 *);
	int (*xmit)(struct sk_buff___61 *);
	struct module___235 *owner;
};

struct dentry___257;

struct super_block___257;

struct module___241;

struct file_system_type___257 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___257 * (*mount)(struct file_system_type___257 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___257 *);
	struct module___241 *owner;
	struct file_system_type___257 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___257;

struct kiocb___257;

struct iov_iter___177;

struct poll_table_struct___178;

struct vm_area_struct___262;

struct inode___257;

struct file_lock___257;

struct page___262;

struct pipe_inode_info___98;

struct seq_file___232;

struct file_operations___258 {
	struct module___241 *owner;
	loff_t (*llseek)(struct file___257 *, loff_t, int);
	ssize_t (*read)(struct file___257 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___257 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___257 *, struct iov_iter___177 *);
	ssize_t (*write_iter)(struct kiocb___257 *, struct iov_iter___177 *);
	int (*iopoll)(struct kiocb___257 *, bool);
	int (*iterate)(struct file___257 *, struct dir_context *);
	int (*iterate_shared)(struct file___257 *, struct dir_context *);
	__poll_t (*poll)(struct file___257 *, struct poll_table_struct___178 *);
	long int (*unlocked_ioctl)(struct file___257 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___257 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___257 *, struct vm_area_struct___262 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___257 *, struct file___257 *);
	int (*flush)(struct file___257 *, fl_owner_t);
	int (*release)(struct inode___257 *, struct file___257 *);
	int (*fsync)(struct file___257 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___257 *, int);
	int (*lock)(struct file___257 *, int, struct file_lock___257 *);
	ssize_t (*sendpage)(struct file___257 *, struct page___262 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___257 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___257 *, long unsigned int);
	int (*flock)(struct file___257 *, int, struct file_lock___257 *);
	ssize_t (*splice_write)(struct pipe_inode_info___98 *, struct file___257 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___257 *, loff_t *, struct pipe_inode_info___98 *, size_t, unsigned int);
	int (*setlease)(struct file___257 *, long int, struct file_lock___257 **, void **);
	long int (*fallocate)(struct file___257 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___232 *, struct file___257 *);
	ssize_t (*copy_file_range)(struct file___257 *, loff_t, struct file___257 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___257 *, loff_t, struct file___257 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___257 *, loff_t, loff_t, int);
};

struct vmacache___262 {
	u64 seqnum;
	struct vm_area_struct___262 *vmas[4];
};

struct page_frag___262 {
	struct page___262 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___263;

struct pid___234;

struct nsproxy___243;

struct signal_struct___258;

struct bio_list___148;

struct backing_dev_info___134;

struct io_context___148;

struct css_set___184;

struct mem_cgroup___122;

struct request_queue___148;

struct vm_struct___240;

struct task_struct___264 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___264 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___263 *mm;
	struct mm_struct___263 *active_mm;
	struct vmacache___262 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___264 *real_parent;
	struct task_struct___264 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___264 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___234 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___243 *nsproxy;
	struct signal_struct___258 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___264 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___148 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___134 *backing_dev_info;
	struct io_context___148 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___184 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___98 *splice_pipe;
	struct page_frag___262 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___122 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___122 *active_memcg;
	struct request_queue___148 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___264 *oom_reaper_list;
	struct vm_struct___240 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___84 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___245;

struct kobj_type___245;

struct kernfs_node___245;

struct kobject___245 {
	const char *name;
	struct list_head entry;
	struct kobject___245 *parent;
	struct kset___245 *kset;
	struct kobj_type___245 *ktype;
	struct kernfs_node___245 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___242 {
	struct kobject___245 kobj;
	struct module___241 *mod;
	struct kobject___245 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___241 {
	struct module___241 *mod;
	struct latch_tree_node node;
};

struct module_layout___241 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___241 mtn;
};

struct module_attribute___241;

struct kernel_param___241;

struct module___241 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___242 mkobj;
	struct module_attribute___241 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___245 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___241 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___241 core_layout;
	struct module_layout___241 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___234;

struct upid___234 {
	int nr;
	struct pid_namespace___234 *ns;
};

struct pid_namespace___234 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___264 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___234 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___234 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___234 numbers[1];
};

typedef struct page___262 *pgtable_t___262;

struct address_space___257;

struct page_pool___86;

struct dev_pagemap___252;

struct page___262 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___257 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___86 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___262 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___262 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___263 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___252 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___252;

struct vm_area_struct___262 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___262 *vm_next;
	struct vm_area_struct___262 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___263 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___252 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___257 *vm_file;
	struct file___257 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___258 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___264 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___264 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___234 *pids[4];
	struct pid___234 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___263 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___262;

struct mm_struct___263 {
	struct {
		struct vm_area_struct___262 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___257 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___262 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___264 *owner;
		struct user_namespace___26 *user_ns;
		struct file___257 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___71;

struct cgroup_namespace___184;

struct nsproxy___243 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___234 *pid_ns_for_children;
	struct net___71 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___184 *cgroup_ns;
};

struct bio___148;

struct bio_list___148 {
	struct bio___148 *head;
	struct bio___148 *tail;
};

struct cgroup_subsys_state___184;

struct bdi_writeback___134 {
	struct backing_dev_info___134 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___184 *memcg_css;
	struct cgroup_subsys_state___184 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___238;

struct backing_dev_info___134 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___134 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___238 *dev;
	char dev_name[64];
	struct device___238 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___257 *debug_dir;
};

struct io_cq___148;

struct io_context___148 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___148 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___184;

struct css_set___184 {
	struct cgroup_subsys_state___184 *subsys[14];
	refcount_t refcount;
	struct css_set___184 *dom_cset;
	struct cgroup___184 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___184 *mg_src_cgrp;
	struct cgroup___184 *mg_dst_cgrp;
	struct css_set___184 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___257;

struct pipe_buffer___98;

struct pipe_inode_info___98 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___262 *tmp_page;
	struct fasync_struct___257 *fasync_readers;
	struct fasync_struct___257 *fasync_writers;
	struct pipe_buffer___98 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___184;

struct cgroup_subsys_state___184 {
	struct cgroup___184 *cgroup;
	struct cgroup_subsys___184 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___184 *parent;
};

struct cgroup_file___184 {
	struct kernfs_node___245 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___122;

struct mem_cgroup_per_node___122;

struct mem_cgroup___122 {
	struct cgroup_subsys_state___184 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___184 events_file;
	struct cgroup_file___184 events_local_file;
	struct cgroup_file___184 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___122 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___264 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___122 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___148;

struct blk_integrity___148 {
	const struct blk_integrity_profile___148 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___148 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___148 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___148;

struct elevator_queue___148;

struct blk_mq_ops___143;

struct blk_mq_hw_ctx___143;

struct gendisk___151;

struct blkcg_gq___136;

struct blk_mq_tag_set___143;

struct request_queue___148 {
	struct request___148 *last_merge;
	struct elevator_queue___148 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___143 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___143 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___151 *disk;
	struct kobject___245 kobj;
	struct kobject___245 *mq_kobj;
	struct blk_integrity___148 integrity;
	struct device___238 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___136 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___143 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___148 bio_split;
	struct dentry___257 *debugfs_dir;
	struct dentry___257 *sched_debugfs_dir;
	struct dentry___257 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___240 {
	struct vm_struct___240 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___262 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___257;

struct address_space___257 {
	struct inode___257 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___257 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___86 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___238 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___86 {
	u32 count;
	struct page___262 *cache[128];
};

struct page_pool___86 {
	struct page_pool_params___86 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___262 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___86 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___252;

struct dev_pagemap___252 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___252 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___257;

struct path___257 {
	struct vfsmount___257 *mnt;
	struct dentry___257 *dentry;
};

struct fown_struct___234 {
	rwlock_t lock;
	struct pid___234 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___257 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___257 f_path;
	struct inode___257 *f_inode;
	const struct file_operations___258 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___234 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___257 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___252;

struct vm_operations_struct___252 {
	void (*open)(struct vm_area_struct___262 *);
	void (*close)(struct vm_area_struct___262 *);
	int (*may_split)(struct vm_area_struct___262 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___262 *);
	int (*mprotect)(struct vm_area_struct___262 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___252 *);
	vm_fault_t (*huge_fault)(struct vm_fault___252 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___252 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___262 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___252 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___252 *);
	int (*access)(struct vm_area_struct___262 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___262 *);
	int (*set_policy)(struct vm_area_struct___262 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___262 *, long unsigned int);
	struct page___262 * (*find_special_page)(struct vm_area_struct___262 *, long unsigned int);
};

struct core_thread___262 {
	struct task_struct___264 *task;
	struct core_thread___262 *next;
};

struct core_state___262 {
	atomic_t nr_threads;
	struct core_thread___262 dumper;
	struct completion startup;
};

struct vm_fault___252 {
	const struct {
		struct vm_area_struct___262 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___262 *cow_page;
	struct page___262 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___262 prealloc_pte;
};

struct pglist_data___130;

struct lruvec___130 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___130 *pgdat;
};

struct zone___130 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___130 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___130 {
	struct zone___130 *zone;
	int zone_idx;
};

struct zonelist___130 {
	struct zoneref___130 _zonerefs[321];
};

struct pglist_data___130 {
	struct zone___130 node_zones[5];
	struct zonelist___130 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___264 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___264 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___130 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___257;

struct dentry___257 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___257 *d_parent;
	struct qstr d_name;
	struct inode___257 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___257 *d_op;
	struct super_block___257 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___257;

struct inode___257 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___257 *i_op;
	struct super_block___257 *i_sb;
	struct address_space___257 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___134 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___258 *i_fop;
		void (*free_inode)(struct inode___257 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___257 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___98 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___257 {
	int (*d_revalidate)(struct dentry___257 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___257 *, unsigned int);
	int (*d_hash)(const struct dentry___257 *, struct qstr *);
	int (*d_compare)(const struct dentry___257 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___257 *);
	int (*d_init)(struct dentry___257 *);
	void (*d_release)(struct dentry___257 *);
	void (*d_prune)(struct dentry___257 *);
	void (*d_iput)(struct dentry___257 *, struct inode___257 *);
	char * (*d_dname)(struct dentry___257 *, char *, int);
	struct vfsmount___257 * (*d_automount)(struct path___257 *);
	int (*d_manage)(const struct path___257 *, bool);
	struct dentry___257 * (*d_real)(struct dentry___257 *, const struct inode___257 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___257;

struct mem_dqinfo___257 {
	struct quota_format_type___257 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___257;

struct quota_info___257 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___257 *files[3];
	struct mem_dqinfo___257 info[3];
	const struct quota_format_ops___257 *ops[3];
};

struct rcuwait___258 {
	struct task_struct___264 *task;
};

struct percpu_rw_semaphore___258 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___258 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___257 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___258 rw_sem[3];
};

struct shrink_control___122;

struct shrinker___122 {
	long unsigned int (*count_objects)(struct shrinker___122 *, struct shrink_control___122 *);
	long unsigned int (*scan_objects)(struct shrinker___122 *, struct shrink_control___122 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___257;

struct dquot_operations___257;

struct quotactl_ops___257;

struct block_device___151;

struct super_block___257 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___257 *s_type;
	const struct super_operations___257 *s_op;
	const struct dquot_operations___257 *dq_op;
	const struct quotactl_ops___257 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___257 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___151 *s_bdev;
	struct backing_dev_info___134 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___257 s_dquot;
	struct sb_writers___257 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___257 *s_d_op;
	int cleancache_poolid;
	struct shrinker___122 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___257 {
	struct dentry___257 *mnt_root;
	struct super_block___257 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___122 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___122 *memcg;
};

struct psi_group___184 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___264 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___60;

struct cgroup_bpf___60 {
	struct bpf_prog_array___60 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___60 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___184;

struct cgroup_rstat_cpu___184;

struct cgroup___184 {
	struct cgroup_subsys_state___184 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___245 *kn;
	struct cgroup_file___184 procs_file;
	struct cgroup_file___184 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___184 *subsys[14];
	struct cgroup_root___184 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___184 *dom_cgrp;
	struct cgroup___184 *old_dom_cgrp;
	struct cgroup_rstat_cpu___184 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___184 psi;
	struct cgroup_bpf___60 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___148 {
	struct request_queue___148 *q;
	struct io_context___148 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___257 {
	struct file___257 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___257 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___257 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___257 *ia_file;
};

struct dquot___257 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___257 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___257 {
	int qf_fmt_id;
	const struct quota_format_ops___257 *qf_ops;
	struct module___241 *qf_owner;
	struct quota_format_type___257 *qf_next;
};

struct quota_format_ops___257 {
	int (*check_quota_file)(struct super_block___257 *, int);
	int (*read_file_info)(struct super_block___257 *, int);
	int (*write_file_info)(struct super_block___257 *, int);
	int (*free_file_info)(struct super_block___257 *, int);
	int (*read_dqblk)(struct dquot___257 *);
	int (*commit_dqblk)(struct dquot___257 *);
	int (*release_dqblk)(struct dquot___257 *);
	int (*get_next_id)(struct super_block___257 *, struct kqid *);
};

struct dquot_operations___257 {
	int (*write_dquot)(struct dquot___257 *);
	struct dquot___257 * (*alloc_dquot)(struct super_block___257 *, int);
	void (*destroy_dquot)(struct dquot___257 *);
	int (*acquire_dquot)(struct dquot___257 *);
	int (*release_dquot)(struct dquot___257 *);
	int (*mark_dirty)(struct dquot___257 *);
	int (*write_info)(struct super_block___257 *, int);
	qsize_t * (*get_reserved_space)(struct inode___257 *);
	int (*get_projid)(struct inode___257 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___257 *, qsize_t *);
	int (*get_next_id)(struct super_block___257 *, struct kqid *);
};

struct quotactl_ops___257 {
	int (*quota_on)(struct super_block___257 *, int, int, const struct path___257 *);
	int (*quota_off)(struct super_block___257 *, int);
	int (*quota_enable)(struct super_block___257 *, unsigned int);
	int (*quota_disable)(struct super_block___257 *, unsigned int);
	int (*quota_sync)(struct super_block___257 *, int);
	int (*set_info)(struct super_block___257 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___257 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___257 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___257 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___257 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___257 *, unsigned int);
};

struct writeback_control___134;

struct address_space_operations___257 {
	int (*writepage)(struct page___262 *, struct writeback_control___134 *);
	int (*readpage)(struct file___257 *, struct page___262 *);
	int (*writepages)(struct address_space___257 *, struct writeback_control___134 *);
	int (*set_page_dirty)(struct page___262 *);
	int (*readpages)(struct file___257 *, struct address_space___257 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___257 *, struct address_space___257 *, loff_t, unsigned int, unsigned int, struct page___262 **, void **);
	int (*write_end)(struct file___257 *, struct address_space___257 *, loff_t, unsigned int, unsigned int, struct page___262 *, void *);
	sector_t (*bmap)(struct address_space___257 *, sector_t);
	void (*invalidatepage)(struct page___262 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___262 *, gfp_t);
	void (*freepage)(struct page___262 *);
	ssize_t (*direct_IO)(struct kiocb___257 *, struct iov_iter___177 *);
	int (*migratepage)(struct address_space___257 *, struct page___262 *, struct page___262 *, enum migrate_mode);
	bool (*isolate_page)(struct page___262 *, isolate_mode_t);
	void (*putback_page)(struct page___262 *);
	int (*launder_page)(struct page___262 *);
	int (*is_partially_uptodate)(struct page___262 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___262 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___257 *, struct page___262 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___257 *, sector_t *);
	void (*swap_deactivate)(struct file___257 *);
};

struct writeback_control___134 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___134 *wb;
	struct inode___257 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___174;

struct iov_iter___177 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___174 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___98 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___257 {
	struct dentry___257 * (*lookup)(struct inode___257 *, struct dentry___257 *, unsigned int);
	const char * (*get_link)(struct dentry___257 *, struct inode___257 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___257 *, int);
	struct posix_acl * (*get_acl)(struct inode___257 *, int, bool);
	int (*readlink)(struct dentry___257 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___257 *, struct dentry___257 *, umode_t, bool);
	int (*link)(struct dentry___257 *, struct inode___257 *, struct dentry___257 *);
	int (*unlink)(struct inode___257 *, struct dentry___257 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___257 *, struct dentry___257 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___257 *, struct dentry___257 *, umode_t);
	int (*rmdir)(struct inode___257 *, struct dentry___257 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___257 *, struct dentry___257 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___257 *, struct dentry___257 *, struct inode___257 *, struct dentry___257 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___257 *, struct iattr___257 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___257 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___257 *, char *, size_t);
	int (*fiemap)(struct inode___257 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___257 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___257 *, struct dentry___257 *, struct file___257 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___257 *, struct dentry___257 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___257 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___257 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___257 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___257 {
	void (*fl_copy_lock)(struct file_lock___257 *, struct file_lock___257 *);
	void (*fl_release_private)(struct file_lock___257 *);
};

struct lock_manager_operations___257;

struct file_lock___257 {
	struct file_lock___257 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___257 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___257 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___257 *fl_ops;
	const struct lock_manager_operations___257 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___257 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___257 *);
	int (*lm_grant)(struct file_lock___257 *, int);
	bool (*lm_break)(struct file_lock___257 *);
	int (*lm_change)(struct file_lock___257 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___257 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___257 *);
};

struct fasync_struct___257 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___257 *fa_next;
	struct file___257 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___257 {
	struct inode___257 * (*alloc_inode)(struct super_block___257 *);
	void (*destroy_inode)(struct inode___257 *);
	void (*free_inode)(struct inode___257 *);
	void (*dirty_inode)(struct inode___257 *, int);
	int (*write_inode)(struct inode___257 *, struct writeback_control___134 *);
	int (*drop_inode)(struct inode___257 *);
	void (*evict_inode)(struct inode___257 *);
	void (*put_super)(struct super_block___257 *);
	int (*sync_fs)(struct super_block___257 *, int);
	int (*freeze_super)(struct super_block___257 *);
	int (*freeze_fs)(struct super_block___257 *);
	int (*thaw_super)(struct super_block___257 *);
	int (*unfreeze_fs)(struct super_block___257 *);
	int (*statfs)(struct dentry___257 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___257 *, int *, char *);
	void (*umount_begin)(struct super_block___257 *);
	int (*show_options)(struct seq_file___232 *, struct dentry___257 *);
	int (*show_devname)(struct seq_file___232 *, struct dentry___257 *);
	int (*show_path)(struct seq_file___232 *, struct dentry___257 *);
	int (*show_stats)(struct seq_file___232 *, struct dentry___257 *);
	ssize_t (*quota_read)(struct super_block___257 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___257 *, int, const char *, size_t, loff_t);
	struct dquot___257 ** (*get_dquots)(struct inode___257 *);
	long int (*nr_cached_objects)(struct super_block___257 *, struct shrink_control___122 *);
	long int (*free_cached_objects)(struct super_block___257 *, struct shrink_control___122 *);
	struct file___257 * (*real_loop)(struct file___257 *);
};

struct wakeup_source___238;

struct dev_pm_info___238 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___238 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___238 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___238;

struct bus_type___238;

struct device_driver___238;

struct dev_pm_domain___238;

struct fwnode_handle___234;

struct class___238;

struct attribute_group___245;

struct device___238 {
	struct kobject___245 kobj;
	struct device___238 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___238 *type;
	struct bus_type___238 *bus;
	struct device_driver___238 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___238 power;
	struct dev_pm_domain___238 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___234 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___238 *class;
	const struct attribute_group___245 **groups;
	void (*release)(struct device___238 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___151 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___257 *bd_inode;
	struct super_block___257 *bd_super;
	void *bd_claiming;
	struct device___238 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___245 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___151 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___257 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___186)(struct file___257 *, wait_queue_head_t *, struct poll_table_struct___178 *);

struct poll_table_struct___178 {
	poll_queue_proc___186 _qproc;
	__poll_t _key;
};

struct seq_operations___232;

struct seq_file___232 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___232 *op;
	int poll_event;
	const struct file___257 *file;
	void *private;
};

typedef void bio_end_io_t___148(struct bio___148 *);

struct bio_vec___174 {
	struct page___262 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___148;

struct bio___148 {
	struct bio___148 *bi_next;
	struct block_device___151 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___148 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___136 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___148 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___174 *bi_io_vec;
	struct bio_set___148 *bi_pool;
	struct bio_vec___174 bi_inline_vecs[0];
};

struct kernfs_root___245;

struct kernfs_elem_dir___245 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___245 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___245;

struct kernfs_root___245 {
	struct kernfs_node___245 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___245 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___245 {
	struct kernfs_node___245 *target_kn;
};

struct kernfs_ops___245;

struct kernfs_elem_attr___245 {
	const struct kernfs_ops___245 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___245 *notify_next;
};

struct kernfs_node___245 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___245 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___245 dir;
		struct kernfs_elem_symlink___245 symlink;
		struct kernfs_elem_attr___245 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___245;

struct kernfs_ops___245 {
	int (*open)(struct kernfs_open_file___245 *);
	void (*release)(struct kernfs_open_file___245 *);
	int (*seq_show)(struct seq_file___232 *, void *);
	void * (*seq_start)(struct seq_file___232 *, loff_t *);
	void * (*seq_next)(struct seq_file___232 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___232 *, void *);
	ssize_t (*read)(struct kernfs_open_file___245 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___245 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___245 *, struct poll_table_struct___178 *);
	int (*mmap)(struct kernfs_open_file___245 *, struct vm_area_struct___262 *);
};

struct kernfs_syscall_ops___245 {
	int (*show_options)(struct seq_file___232 *, struct kernfs_root___245 *);
	int (*mkdir)(struct kernfs_node___245 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___245 *);
	int (*rename)(struct kernfs_node___245 *, struct kernfs_node___245 *, const char *);
	int (*show_path)(struct seq_file___232 *, struct kernfs_node___245 *, struct kernfs_root___245 *);
};

struct kernfs_open_file___245 {
	struct kernfs_node___245 *kn;
	struct file___257 *file;
	struct seq_file___232 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___252 *vm_ops;
};

struct sock___53;

struct kobj_ns_type_operations___53 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___53 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___71 *net;
} possible_net_t___66;

struct proto___53;

struct sock_common___53 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___53 *skc_prot;
	possible_net_t___66 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___53 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___67;

struct sk_buff_head___66 {
	struct sk_buff___67 *next;
	struct sk_buff___67 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___53 {
	struct cgroup___184 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___53;

struct socket_wq___54;

struct dst_entry___53;

struct socket___55;

struct net_device___66;

struct sock___53 {
	struct sock_common___53 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___66 sk_error_queue;
	struct sk_buff___67 *sk_rx_skb_cache;
	struct sk_buff_head___66 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___67 *head;
		struct sk_buff___67 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___53 *sk_filter;
	union {
		struct socket_wq___54 *sk_wq;
		struct socket_wq___54 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___53 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___53 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___67 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___67 *sk_tx_skb_cache;
	struct sk_buff_head___66 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___262 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___53 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___234 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___55 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___53 sk_cgrp_data;
	struct mem_cgroup___122 *sk_memcg;
	void (*sk_state_change)(struct sock___53 *);
	void (*sk_data_ready)(struct sock___53 *);
	void (*sk_write_space)(struct sock___53 *);
	void (*sk_error_report)(struct sock___53 *);
	int (*sk_backlog_rcv)(struct sock___53 *, struct sk_buff___67 *);
	struct sk_buff___67 * (*sk_validate_xmit_skb)(struct sock___53 *, struct net_device___66 *, struct sk_buff___67 *);
	void (*sk_destruct)(struct sock___53 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___245;

struct attribute_group___245 {
	const char *name;
	umode_t (*is_visible)(struct kobject___245 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___245 *, struct bin_attribute___245 *, int);
	struct attribute **attrs;
	struct bin_attribute___245 **bin_attrs;
};

struct bin_attribute___245 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___257 * (*f_mapping)();
	ssize_t (*read)(struct file___257 *, struct kobject___245 *, struct bin_attribute___245 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___257 *, struct kobject___245 *, struct bin_attribute___245 *, char *, loff_t, size_t);
	int (*mmap)(struct file___257 *, struct kobject___245 *, struct bin_attribute___245 *, struct vm_area_struct___262 *);
};

struct sysfs_ops___245 {
	ssize_t (*show)(struct kobject___245 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___245 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___245;

struct kset___245 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___245 kobj;
	const struct kset_uevent_ops___245 *uevent_ops;
};

struct kobj_type___245 {
	void (*release)(struct kobject___245 *);
	const struct sysfs_ops___245 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___245 **default_groups;
	const struct kobj_ns_type_operations___53 * (*child_ns_type)(struct kobject___245 *);
	const void * (*namespace)(struct kobject___245 *);
	void (*get_ownership)(struct kobject___245 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___245 {
	int (* const filter)(struct kset___245 *, struct kobject___245 *);
	const char * (* const name)(struct kset___245 *, struct kobject___245 *);
	int (* const uevent)(struct kset___245 *, struct kobject___245 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___241 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___241 *);
	int (*get)(char *, const struct kernel_param___241 *);
	void (*free)(void *);
};

struct kparam_array___241;

struct kernel_param___241 {
	const char *name;
	struct module___241 *mod;
	const struct kernel_param_ops___241 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___241 *arr;
	};
};

struct kparam_array___241 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___241 *ops;
	void *elem;
};

struct module_attribute___241 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___241 *, struct module_kobject___242 *, char *);
	ssize_t (*store)(struct module_attribute___241 *, struct module_kobject___242 *, const char *, size_t);
	void (*setup)(struct module___241 *, const char *);
	int (*test)(struct module___241 *);
	void (*free)(struct module___241 *);
};

struct dev_pagemap_ops___252 {
	void (*page_free)(struct page___262 *);
	void (*kill)(struct dev_pagemap___252 *);
	void (*cleanup)(struct dev_pagemap___252 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___252 *);
};

struct fwnode_operations___234;

struct fwnode_handle___234 {
	struct fwnode_handle___234 *secondary;
	const struct fwnode_operations___234 *ops;
	struct device___238 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___234;

struct fwnode_endpoint___234;

struct fwnode_operations___234 {
	struct fwnode_handle___234 * (*get)(struct fwnode_handle___234 *);
	void (*put)(struct fwnode_handle___234 *);
	bool (*device_is_available)(const struct fwnode_handle___234 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___234 *, const struct device___238 *);
	bool (*property_present)(const struct fwnode_handle___234 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___234 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___234 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___234 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*get_parent)(const struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*get_next_child_node)(const struct fwnode_handle___234 *, struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*get_named_child_node)(const struct fwnode_handle___234 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___234 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___234 *);
	struct fwnode_handle___234 * (*graph_get_next_endpoint)(const struct fwnode_handle___234 *, struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*graph_get_remote_endpoint)(const struct fwnode_handle___234 *);
	struct fwnode_handle___234 * (*graph_get_port_parent)(struct fwnode_handle___234 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___234 *, struct fwnode_endpoint___234 *);
	int (*add_links)(struct fwnode_handle___234 *);
};

struct fwnode_endpoint___234 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___234 *local_fwnode;
};

struct fwnode_reference_args___234 {
	struct fwnode_handle___234 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___53;

struct fqdir___71;

struct fib_notifier_ops___53;

struct netns_ipv4___71 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___53 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___53 *fibnl;
	struct sock___53 **icmp_sk;
	struct sock___53 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___53 **tcp_sk;
	struct fqdir___71 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___53 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___53 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___53 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___53;

struct dst_ops___71 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___71 *);
	struct dst_entry___53 * (*check)(struct dst_entry___53 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___53 *);
	unsigned int (*mtu)(const struct dst_entry___53 *);
	u32 * (*cow_metrics)(struct dst_entry___53 *, long unsigned int);
	void (*destroy)(struct dst_entry___53 *);
	void (*ifdown)(struct dst_entry___53 *, struct net_device___66 *, int);
	struct dst_entry___53 * (*negative_advice)(struct dst_entry___53 *);
	void (*link_failure)(struct sk_buff___67 *);
	void (*update_pmtu)(struct dst_entry___53 *, struct sock___53 *, struct sk_buff___67 *, u32, bool);
	void (*redirect)(struct dst_entry___53 *, struct sock___53 *, struct sk_buff___67 *);
	int (*local_out)(struct net___71 *, struct sock___53 *, struct sk_buff___67 *);
	struct neighbour___53 * (*neigh_lookup)(const struct dst_entry___53 *, struct sk_buff___67 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___53 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___10;

struct rt6_info___10;

struct fib6_table___10;

struct netns_ipv6___71 {
	struct dst_ops___71 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___71 *fqdir;
	struct fib6_info___10 *fib6_null_entry;
	struct rt6_info___10 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___10 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___10 *ip6_prohibit_entry;
	struct rt6_info___10 *ip6_blk_hole_entry;
	struct fib6_table___10 *fib6_local_tbl;
	struct fib_rules_ops___53 *fib6_rules_ops;
	struct sock___53 **icmp_sk;
	struct sock___53 *ndisc_sk;
	struct sock___53 *tcp_sk;
	struct sock___53 *igmp_sk;
	struct sock___53 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___53 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___53 *notifier_ops;
	struct fib_notifier_ops___53 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___71 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___71 *fqdir;
};

struct netns_sctp___53 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___53 *ctl_sock;
	struct sock___53 *udp4_sock;
	struct sock___53 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___60;

struct netns_bpf___60 {
	struct bpf_prog_array___60 *run_array[2];
	struct bpf_prog___60 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___71 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___53 *nlsk;
	struct sock___53 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___71 xfrm4_dst_ops;
	struct dst_ops___71 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___71 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___53 *rtnl;
	struct sock___53 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___66 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___71 ipv4;
	struct netns_ipv6___71 ipv6;
	struct netns_ieee802154_lowpan___71 ieee802154_lowpan;
	struct netns_sctp___53 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___66 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___60 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___71 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___53 *crypto_nlsk;
	struct sock___53 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___184 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___184 *root_cset;
};

struct msghdr___55 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___177 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___257 *msg_iocb;
};

struct socket_wq___54 {
	wait_queue_head_t wait;
	struct fasync_struct___257 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___54;

struct socket___55 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___257 *file;
	struct sock___53 *sk;
	const struct proto_ops___54 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___54 wq;
};

typedef int (*sk_read_actor_t___53)(read_descriptor_t *, struct sk_buff___67 *, unsigned int, size_t);

struct proto_ops___54 {
	int family;
	struct module___241 *owner;
	int (*release)(struct socket___55 *);
	int (*bind)(struct socket___55 *, struct sockaddr *, int);
	int (*connect)(struct socket___55 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___55 *, struct socket___55 *);
	int (*accept)(struct socket___55 *, struct socket___55 *, int, bool);
	int (*getname)(struct socket___55 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___257 *, struct socket___55 *, struct poll_table_struct___178 *);
	int (*ioctl)(struct socket___55 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___55 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___55 *, void *, bool, bool);
	int (*listen)(struct socket___55 *, int);
	int (*shutdown)(struct socket___55 *, int);
	int (*setsockopt)(struct socket___55 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___55 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___232 *, struct socket___55 *);
	int (*sendmsg)(struct socket___55 *, struct msghdr___55 *, size_t);
	int (*recvmsg)(struct socket___55 *, struct msghdr___55 *, size_t, int);
	int (*mmap)(struct file___257 *, struct socket___55 *, struct vm_area_struct___262 *);
	ssize_t (*sendpage)(struct socket___55 *, struct page___262 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___55 *, loff_t *, struct pipe_inode_info___98 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___53 *, int);
	int (*peek_len)(struct socket___55 *);
	int (*read_sock)(struct sock___53 *, read_descriptor_t *, sk_read_actor_t___53);
	int (*sendpage_locked)(struct sock___53 *, struct page___262 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___53 *, struct msghdr___55 *, size_t);
	int (*set_rcvlowat)(struct sock___53 *, int);
};

struct sk_buff___67 {
	union {
		struct {
			struct sk_buff___67 *next;
			struct sk_buff___67 *prev;
			union {
				struct net_device___66 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___53 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___67 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___238 {
	int (*prepare)(struct device___238 *);
	void (*complete)(struct device___238 *);
	int (*suspend)(struct device___238 *);
	int (*resume)(struct device___238 *);
	int (*freeze)(struct device___238 *);
	int (*thaw)(struct device___238 *);
	int (*poweroff)(struct device___238 *);
	int (*restore)(struct device___238 *);
	int (*suspend_late)(struct device___238 *);
	int (*resume_early)(struct device___238 *);
	int (*freeze_late)(struct device___238 *);
	int (*thaw_early)(struct device___238 *);
	int (*poweroff_late)(struct device___238 *);
	int (*restore_early)(struct device___238 *);
	int (*suspend_noirq)(struct device___238 *);
	int (*resume_noirq)(struct device___238 *);
	int (*freeze_noirq)(struct device___238 *);
	int (*thaw_noirq)(struct device___238 *);
	int (*poweroff_noirq)(struct device___238 *);
	int (*restore_noirq)(struct device___238 *);
	int (*runtime_suspend)(struct device___238 *);
	int (*runtime_resume)(struct device___238 *);
	int (*runtime_idle)(struct device___238 *);
};

struct wakeup_source___238 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___238 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___238 {
	struct dev_pm_ops___238 ops;
	int (*start)(struct device___238 *);
	void (*detach)(struct device___238 *, bool);
	int (*activate)(struct device___238 *);
	void (*sync)(struct device___238 *);
	void (*dismiss)(struct device___238 *);
};

struct bus_type___238 {
	const char *name;
	const char *dev_name;
	struct device___238 *dev_root;
	const struct attribute_group___245 **bus_groups;
	const struct attribute_group___245 **dev_groups;
	const struct attribute_group___245 **drv_groups;
	int (*match)(struct device___238 *, struct device_driver___238 *);
	int (*uevent)(struct device___238 *, struct kobj_uevent_env *);
	int (*probe)(struct device___238 *);
	void (*sync_state)(struct device___238 *);
	void (*remove)(struct device___238 *);
	void (*shutdown)(struct device___238 *);
	int (*online)(struct device___238 *);
	int (*offline)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	int (*num_vf)(struct device___238 *);
	int (*dma_configure)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___238 {
	const char *name;
	struct bus_type___238 *bus;
	struct module___241 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___238 *);
	void (*sync_state)(struct device___238 *);
	int (*remove)(struct device___238 *);
	void (*shutdown)(struct device___238 *);
	int (*suspend)(struct device___238 *, pm_message_t);
	int (*resume)(struct device___238 *);
	const struct attribute_group___245 **groups;
	const struct attribute_group___245 **dev_groups;
	const struct dev_pm_ops___238 *pm;
	void (*coredump)(struct device___238 *);
	struct driver_private *p;
};

struct device_type___238 {
	const char *name;
	const struct attribute_group___245 **groups;
	int (*uevent)(struct device___238 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___238 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___238 *);
	const struct dev_pm_ops___238 *pm;
};

struct class___238 {
	const char *name;
	struct module___241 *owner;
	const struct attribute_group___245 **class_groups;
	const struct attribute_group___245 **dev_groups;
	struct kobject___245 *dev_kobj;
	int (*dev_uevent)(struct device___238 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___238 *, umode_t *);
	void (*class_release)(struct class___238 *);
	void (*dev_release)(struct device___238 *);
	int (*shutdown_pre)(struct device___238 *);
	const struct kobj_ns_type_operations___53 *ns_type;
	const void * (*namespace)(struct device___238 *);
	void (*get_ownership)(struct device___238 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___238 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___98;

struct pipe_buffer___98 {
	struct page___262 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___98 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___98 {
	int (*confirm)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
	void (*release)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
	bool (*try_steal)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
	bool (*get)(struct pipe_inode_info___98 *, struct pipe_buffer___98 *);
};

typedef rx_handler_result_t rx_handler_func_t___66(struct sk_buff___67 **);

struct bpf_xdp_entity___60 {
	struct bpf_prog___60 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___66;

struct net_device_ops___66;

struct l3mdev_ops___53;

struct ndisc_ops___37;

struct xfrmdev_ops___66;

struct header_ops___66;

struct inet6_dev___37;

struct netdev_rx_queue___66;

struct mini_Qdisc___60;

struct netdev_queue___66;

struct Qdisc___60;

struct rtnl_link_ops___60;

struct dcbnl_rtnl_ops___66;

struct net_device___66 {
	char name[16];
	struct netdev_name_node___66 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___66 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___53 *l3mdev_ops;
	const struct ndisc_ops___37 *ndisc_ops;
	const struct xfrmdev_ops___66 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___66 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___245 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___37 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___66 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___60 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___66 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___60 *miniq_ingress;
	struct netdev_queue___66 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___66 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___60 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___60 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___66 = 0,
		NETREG_REGISTERED___66 = 1,
		NETREG_UNREGISTERING___66 = 2,
		NETREG_UNREGISTERED___66 = 3,
		NETREG_RELEASED___66 = 4,
		NETREG_DUMMY___66 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___66 = 0,
		RTNL_LINK_INITIALIZING___66 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___66 *);
	struct netpoll_info *npinfo;
	possible_net_t___66 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___238 dev;
	const struct attribute_group___245 *sysfs_groups[4];
	const struct attribute_group___245 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___60 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___66 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___60 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___174 skb_frag_t___17;

struct skb_shared_info___17 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___67 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___17 frags[17];
};

struct bpf_iter_aux_info___69;

typedef int (*bpf_iter_init_seq_priv_t___68)(void *, struct bpf_iter_aux_info___69 *);

struct bpf_map___69;

struct bpf_iter_aux_info___69 {
	struct bpf_map___69 *map;
};

struct bpf_iter_seq_info___68 {
	const struct seq_operations___232 *seq_ops;
	bpf_iter_init_seq_priv_t___68 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___232 {
	void * (*start)(struct seq_file___232 *, loff_t *);
	void (*stop)(struct seq_file___232 *, void *);
	void * (*next)(struct seq_file___232 *, void *, loff_t *);
	int (*show)(struct seq_file___232 *, void *);
};

struct bpf_prog_aux___69;

struct bpf_map_ops___68 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___69 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___69 *, struct file___257 *);
	void (*map_free)(struct bpf_map___69 *);
	int (*map_get_next_key)(struct bpf_map___69 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___69 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___69 *, void *);
	int (*map_lookup_batch)(struct bpf_map___69 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___69 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___69 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___69 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___69 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___69 *, void *);
	int (*map_update_elem)(struct bpf_map___69 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___69 *, void *);
	int (*map_push_elem)(struct bpf_map___69 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___69 *, void *);
	int (*map_peek_elem)(struct bpf_map___69 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___69 *, struct file___257 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___69 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___69 *, void *, struct seq_file___232 *);
	int (*map_check_btf)(const struct bpf_map___69 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___69 *, struct bpf_prog_aux___69 *);
	void (*map_poke_untrack)(struct bpf_map___69 *, struct bpf_prog_aux___69 *);
	void (*map_poke_run)(struct bpf_map___69 *, u32, struct bpf_prog___60 *, struct bpf_prog___60 *);
	int (*map_direct_value_addr)(const struct bpf_map___69 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___69 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___69 *, struct vm_area_struct___262 *);
	__poll_t (*map_poll)(struct bpf_map___69 *, struct file___257 *, struct poll_table_struct___178 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___69 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___69 *, const struct bpf_map___69 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___69 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___68 *iter_seq_info;
};

struct bpf_map___69 {
	const struct bpf_map_ops___68 *ops;
	struct bpf_map___69 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___122 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___68;

struct bpf_jit_poke_descriptor___68;

struct bpf_prog_ops___60;

struct btf_mod_pair___68;

struct bpf_prog_offload___66;

struct bpf_prog_aux___69 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___60 *dst_prog;
	struct bpf_trampoline___68 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___60 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___68 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___60 *ops;
	struct bpf_map___69 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___68 *used_btfs;
	struct bpf_prog___60 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___69 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___66 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___60 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___69 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___66;

struct bpf_map_dev_ops___66 {
	int (*map_get_next_key)(struct bpf_offloaded_map___66 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___66 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___66 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___66 *, void *);
};

struct bpf_offloaded_map___66 {
	struct bpf_map___69 map;
	struct net_device___66 *netdev;
	const struct bpf_map_dev_ops___66 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___60 {
	int (*test_run)(struct bpf_prog___60 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___66 {
	struct bpf_prog___60 *prog;
	struct net_device___66 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___68 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___60 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___241 *mod;
};

struct bpf_jit_poke_descriptor___68 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___69 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___68 {
	struct btf *btf;
	struct module___241 *module;
};

struct bpf_prog_array_item___60 {
	struct bpf_prog___60 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___60 {
	struct callback_head rcu;
	struct bpf_prog_array_item___60 items[0];
};

enum {
	LWT_BPF_PROG_UNSPEC = 0,
	LWT_BPF_PROG_FD = 1,
	LWT_BPF_PROG_NAME = 2,
	__LWT_BPF_PROG_MAX = 3,
};

enum {
	LWT_BPF_UNSPEC = 0,
	LWT_BPF_IN = 1,
	LWT_BPF_OUT = 2,
	LWT_BPF_XMIT = 3,
	LWT_BPF_XMIT_HEADROOM = 4,
	__LWT_BPF_MAX = 5,
};

struct inet_frags___71;

struct fqdir___71 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___71 *f;
	struct net___71 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___71;

struct inet_frags___71 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___71 *, const void *);
	void (*destructor)(struct inet_frag_queue___71 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___71 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___67 *fragments_tail;
	struct sk_buff___67 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___71 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___53;

struct fib_lookup_arg___53;

struct fib_rules_ops___53 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___53 *, struct flowi *, int, struct fib_lookup_arg___53 *);
	bool (*suppress)(struct fib_rule___53 *, int, struct fib_lookup_arg___53 *);
	int (*match)(struct fib_rule___53 *, struct flowi *, int);
	int (*configure)(struct fib_rule___53 *, struct sk_buff___67 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___53 *);
	int (*compare)(struct fib_rule___53 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___53 *, struct sk_buff___67 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___53 *);
	void (*flush_cache)(struct fib_rules_ops___53 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___241 *owner;
	struct net___71 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___53 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___71 *);
	int (*fib_dump)(struct net___71 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___241 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___31;

struct dst_entry___53 {
	struct net_device___66 *dev;
	struct dst_ops___71 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___67 *);
	int (*output)(struct net___71 *, struct sock___53 *, struct sk_buff___67 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___31 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___53;

struct neigh_parms___53;

struct neigh_ops___53;

struct neighbour___53 {
	struct neighbour___53 *next;
	struct neigh_table___53 *tbl;
	struct neigh_parms___53 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___66 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___53 *, struct sk_buff___67 *);
	const struct neigh_ops___53 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___66 *dev;
	u8 primary_key[0];
};

struct rtable___10;

struct fnhe_hash_bucket___10;

struct fib_nh_common___10 {
	struct net_device___66 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___31 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___10 **nhc_pcpu_rth_output;
	struct rtable___10 *nhc_rth_input;
	struct fnhe_hash_bucket___10 *nhc_exceptions;
};

struct fib6_nh___10 {
	struct fib_nh_common___10 nh_common;
	long unsigned int last_probe;
	struct rt6_info___10 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___10;

struct nexthop___6;

struct fib6_info___10 {
	struct fib6_table___10 *fib6_table;
	struct fib6_info___10 *fib6_next;
	struct fib6_node___10 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___6 *nh;
	struct fib6_nh___10 fib6_nh[0];
};

struct rt6_info___10 {
	struct dst_entry___53 dst;
	struct fib6_info___10 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___37 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___10 {
	struct fib6_node___10 *parent;
	struct fib6_node___10 *left;
	struct fib6_node___10 *right;
	struct fib6_node___10 *subtree;
	struct fib6_info___10 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___10 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___10 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___10 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct dcbnl_rtnl_ops___66 {
	int (*ieee_getets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___66 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___66 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___66 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___66 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___66 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___66 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___66 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___66 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___66 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___66 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___66 *);
	u8 (*setstate)(struct net_device___66 *, u8);
	void (*getpermhwaddr)(struct net_device___66 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___66 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___66 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___66 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___66 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___66 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___66 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___66 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___66 *, int, u8 *);
	void (*setpfccfg)(struct net_device___66 *, int, u8);
	void (*getpfccfg)(struct net_device___66 *, int, u8 *);
	u8 (*setall)(struct net_device___66 *);
	u8 (*getcap)(struct net_device___66 *, int, u8 *);
	int (*getnumtcs)(struct net_device___66 *, int, u8 *);
	int (*setnumtcs)(struct net_device___66 *, int, u8);
	u8 (*getpfcstate)(struct net_device___66 *);
	void (*setpfcstate)(struct net_device___66 *, u8);
	void (*getbcncfg)(struct net_device___66 *, int, u32 *);
	void (*setbcncfg)(struct net_device___66 *, int, u32);
	void (*getbcnrp)(struct net_device___66 *, int, u8 *);
	void (*setbcnrp)(struct net_device___66 *, int, u8);
	int (*setapp)(struct net_device___66 *, u8, u16, u8);
	int (*getapp)(struct net_device___66 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___66 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___66 *, int, u8);
	u8 (*getdcbx)(struct net_device___66 *);
	u8 (*setdcbx)(struct net_device___66 *, u8);
	int (*peer_getappinfo)(struct net_device___66 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___66 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___66 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___66 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___66 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___66 *, struct dcbnl_buffer *);
};

struct cftype___184;

struct cgroup_subsys___184 {
	struct cgroup_subsys_state___184 * (*css_alloc)(struct cgroup_subsys_state___184 *);
	int (*css_online)(struct cgroup_subsys_state___184 *);
	void (*css_offline)(struct cgroup_subsys_state___184 *);
	void (*css_released)(struct cgroup_subsys_state___184 *);
	void (*css_free)(struct cgroup_subsys_state___184 *);
	void (*css_reset)(struct cgroup_subsys_state___184 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___184 *, int);
	int (*css_extra_stat_show)(struct seq_file___232 *, struct cgroup_subsys_state___184 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___264 *, struct css_set___184 *);
	void (*cancel_fork)(struct task_struct___264 *, struct css_set___184 *);
	void (*fork)(struct task_struct___264 *);
	void (*exit)(struct task_struct___264 *);
	void (*release)(struct task_struct___264 *);
	void (*bind)(struct cgroup_subsys_state___184 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___184 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___184 *dfl_cftypes;
	struct cftype___184 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___184 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___184 *updated_children;
	struct cgroup___184 *updated_next;
};

struct cgroup_root___184 {
	struct kernfs_root___245 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___184 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___184 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___184 *ss;
	struct list_head node;
	struct kernfs_ops___245 *kf_ops;
	int (*open)(struct kernfs_open_file___245 *);
	void (*release)(struct kernfs_open_file___245 *);
	u64 (*read_u64)(struct cgroup_subsys_state___184 *, struct cftype___184 *);
	s64 (*read_s64)(struct cgroup_subsys_state___184 *, struct cftype___184 *);
	int (*seq_show)(struct seq_file___232 *, void *);
	void * (*seq_start)(struct seq_file___232 *, loff_t *);
	void * (*seq_next)(struct seq_file___232 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___232 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___184 *, struct cftype___184 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___184 *, struct cftype___184 *, s64);
	ssize_t (*write)(struct kernfs_open_file___245 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___245 *, struct poll_table_struct___178 *);
};

struct xdp_rxq_info___66 {
	struct net_device___66 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___66 {
	struct net_device___66 *dev;
};

struct xdp_buff___66 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___66 *rxq;
	struct xdp_txq_info___66 *txq;
	u32 frame_sz;
};

struct xdp_frame___66 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___66 *dev_rx;
};

struct netlink_callback___66 {
	struct sk_buff___67 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___67 *, struct netlink_callback___66 *);
	int (*done)(struct netlink_callback___66 *);
	void *data;
	struct module___241 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___66 {
	int (*create)(struct sk_buff___67 *, struct net_device___66 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___67 *, unsigned char *);
	int (*cache)(const struct neighbour___53 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___66 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___67 *);
};

struct netdev_queue___66 {
	struct net_device___66 *dev;
	struct Qdisc___60 *qdisc;
	struct Qdisc___60 *qdisc_sleeping;
	struct kobject___245 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___66 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___60 {
	struct sk_buff___67 *head;
	struct sk_buff___67 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___60;

struct Qdisc___60 {
	int (*enqueue)(struct sk_buff___67 *, struct Qdisc___60 *, struct sk_buff___67 **);
	struct sk_buff___67 * (*dequeue)(struct Qdisc___60 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___60 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___66 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___66 gso_skb;
	struct qdisc_skb_head___60 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___60 *next_sched;
	struct sk_buff_head___66 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___66 {
	struct xdp_rxq_info___66 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___245 kobj;
	struct net_device___66 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___66 {
	enum net_device_path_type type;
	const struct net_device___66 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___66 = 0,
				DEV_PATH_BR_VLAN_TAG___66 = 1,
				DEV_PATH_BR_VLAN_UNTAG___66 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___66 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___66 {
	const struct net_device___66 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___66 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___60 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___66 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___66 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___67 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___66 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___66 *dev;
	const char *name;
};

struct net_device_ops___66 {
	int (*ndo_init)(struct net_device___66 *);
	void (*ndo_uninit)(struct net_device___66 *);
	int (*ndo_open)(struct net_device___66 *);
	int (*ndo_stop)(struct net_device___66 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___67 *, struct net_device___66 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___67 *, struct net_device___66 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___66 *, struct sk_buff___67 *, struct net_device___66 *);
	void (*ndo_change_rx_flags)(struct net_device___66 *, int);
	void (*ndo_set_rx_mode)(struct net_device___66 *);
	int (*ndo_set_mac_address)(struct net_device___66 *, void *);
	int (*ndo_validate_addr)(struct net_device___66 *);
	int (*ndo_do_ioctl)(struct net_device___66 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___66 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___66 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___66 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___66 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___66 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___66 *, int);
	int (*ndo_neigh_setup)(struct net_device___66 *, struct neigh_parms___53 *);
	void (*ndo_tx_timeout)(struct net_device___66 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___66 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___66 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___66 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___66 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___66 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___66 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___66 *);
	int (*ndo_netpoll_setup)(struct net_device___66 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___66 *);
	int (*ndo_set_vf_mac)(struct net_device___66 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___66 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___66 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___66 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___66 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___66 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___66 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___66 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___66 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___66 *, int, struct sk_buff___67 *);
	int (*ndo_get_vf_guid)(struct net_device___66 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___66 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___66 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___66 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___66 *);
	int (*ndo_fcoe_disable)(struct net_device___66 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___66 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___66 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___66 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___66 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___66 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___66 *, const struct sk_buff___67 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___66 *, struct net_device___66 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___66 *, struct net_device___66 *);
	struct net_device___66 * (*ndo_get_xmit_slave)(struct net_device___66 *, struct sk_buff___67 *, bool);
	struct net_device___66 * (*ndo_sk_get_lower_dev)(struct net_device___66 *, struct sock___53 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___66 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___66 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___66 *, struct neighbour___53 *);
	void (*ndo_neigh_destroy)(struct net_device___66 *, struct neighbour___53 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___67 *, struct netlink_callback___66 *, struct net_device___66 *, struct net_device___66 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___67 *, struct nlattr **, struct net_device___66 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___66 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___67 *, u32, u32, struct net_device___66 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___66 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___66 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___66 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___66 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___66 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___66 *, struct net_device___66 *);
	void (*ndo_dfwd_del_station)(struct net_device___66 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___66 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___66 *);
	int (*ndo_change_proto_down)(struct net_device___66 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___66 *, struct sk_buff___67 *);
	void (*ndo_set_rx_headroom)(struct net_device___66 *, int);
	int (*ndo_bpf)(struct net_device___66 *, struct netdev_bpf___66 *);
	int (*ndo_xdp_xmit)(struct net_device___66 *, int, struct xdp_frame___66 **, u32);
	struct net_device___66 * (*ndo_xdp_get_xmit_slave)(struct net_device___66 *, struct xdp_buff___66 *);
	int (*ndo_xsk_wakeup)(struct net_device___66 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___66 *);
	int (*ndo_tunnel_ctl)(struct net_device___66 *, struct ip_tunnel_parm *, int);
	struct net_device___66 * (*ndo_get_peer_dev)(struct net_device___66 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___66 *, struct net_device_path___66 *);
};

struct neigh_parms___53 {
	possible_net_t___66 net;
	struct net_device___66 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___53 *);
	struct neigh_table___53 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___53 {
	u32 (*l3mdev_fib_table)(const struct net_device___66 *);
	struct sk_buff___67 * (*l3mdev_l3_rcv)(struct net_device___66 *, struct sk_buff___67 *, u16);
	struct sk_buff___67 * (*l3mdev_l3_out)(struct net_device___66 *, struct sock___53 *, struct sk_buff___67 *, u16);
	struct dst_entry___53 * (*l3mdev_link_scope_lookup)(const struct net_device___66 *, struct flowi6 *);
};

struct ndisc_ops___37 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___66 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___66 *, struct neighbour___53 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___66 *, u8, struct neighbour___53 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___66 *, struct sk_buff___67 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___71 *, struct net_device___66 *, const struct prefix_info *, struct inet6_dev___37 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___37;

struct ifacaddr6___10;

struct inet6_dev___37 {
	struct net_device___66 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___37 *mc_list;
	struct ifmcaddr6___37 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___66 mc_query_queue;
	struct sk_buff_head___66 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___10 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___53 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___60;

struct tcf_block___60;

struct mini_Qdisc___60 {
	struct tcf_proto___60 *filter_list;
	struct tcf_block___60 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___60 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___66 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___66 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___71 *, struct net_device___66 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___66 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___66 *, struct list_head *);
	size_t (*get_size)(const struct net_device___66 *);
	int (*fill_info)(struct sk_buff___67 *, const struct net_device___66 *);
	size_t (*get_xstats_size)(const struct net_device___66 *);
	int (*fill_xstats)(struct sk_buff___67 *, const struct net_device___66 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___66 *, struct net_device___66 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___66 *, const struct net_device___66 *);
	int (*fill_slave_info)(struct sk_buff___67 *, const struct net_device___66 *, const struct net_device___66 *);
	struct net___71 * (*get_link_net)(const struct net_device___66 *);
	size_t (*get_linkxstats_size)(const struct net_device___66 *, int);
	int (*fill_linkxstats)(struct sk_buff___67 *, const struct net_device___66 *, int *, int);
};

struct nl_info___2 {
	struct nlmsghdr *nlh;
	struct net___71 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct pneigh_entry___53;

struct neigh_hash_table___53;

struct neigh_table___53 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___66 *, __u32 *);
	bool (*key_eq)(const struct neighbour___53 *, const void *);
	int (*constructor)(struct neighbour___53 *);
	int (*pconstructor)(struct pneigh_entry___53 *);
	void (*pdestructor)(struct pneigh_entry___53 *);
	void (*proxy_redo)(struct sk_buff___67 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___66 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___53 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___66 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___53 *nht;
	struct pneigh_entry___53 **phash_buckets;
};

struct neigh_ops___53 {
	int family;
	void (*solicit)(struct neighbour___53 *, struct sk_buff___67 *);
	void (*error_report)(struct neighbour___53 *, struct sk_buff___67 *);
	int (*output)(struct neighbour___53 *, struct sk_buff___67 *);
	int (*connected_output)(struct neighbour___53 *, struct sk_buff___67 *);
};

struct pneigh_entry___53 {
	struct pneigh_entry___53 *next;
	possible_net_t___66 net;
	struct net_device___66 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___53 {
	struct neighbour___53 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___31 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___71 *, struct sock___53 *, struct sk_buff___67 *);
	int (*orig_input)(struct sk_buff___67 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct block_device_operations___148;

struct gendisk___151 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___151 *part0;
	const struct block_device_operations___148 *fops;
	struct request_queue___148 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___134 *bdi;
	struct kobject___245 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___245 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___148 {
	struct bio___148 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___174 *bip_vec;
	struct bio_vec___174 bip_inline_vecs[0];
};

struct blkcg___136;

struct blkg_policy_data___136;

struct blkcg_gq___136 {
	struct request_queue___148 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___136 *blkcg;
	struct blkcg_gq___136 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___136 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___148 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___148(struct request___148 *);

typedef void integrity_complete_fn___148(struct request___148 *, unsigned int);

struct blk_integrity_profile___148 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___148 *prepare_fn;
	integrity_complete_fn___148 *complete_fn;
	const char *name;
};

struct block_device_operations___148 {
	blk_qc_t (*submit_bio)(struct bio___148 *);
	int (*open)(struct block_device___151 *, fmode_t);
	void (*release)(struct gendisk___151 *, fmode_t);
	int (*rw_page)(struct block_device___151 *, sector_t, struct page___262 *, unsigned int);
	int (*ioctl)(struct block_device___151 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___151 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___151 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___151 *);
	int (*getgeo)(struct block_device___151 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___151 *, bool);
	void (*swap_slot_free_notify)(struct block_device___151 *, long unsigned int);
	int (*report_zones)(struct gendisk___151 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___151 *, umode_t *);
	struct module___241 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___151 *, sector_t *);
};

typedef void rq_end_io_fn___148(struct request___148 *, blk_status_t);

struct request___148 {
	struct request_queue___148 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___143 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___148 *bio;
	struct bio___148 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___174 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___148 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___148 *saved_end_io;
		} flush;
	};
	struct gendisk___151 *rq_disk;
	struct block_device___151 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___148 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___143 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___148 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___245 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___257 *debugfs_dir;
	struct dentry___257 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___148;

struct elevator_mq_ops___148 {
	int (*init_sched)(struct request_queue___148 *, struct elevator_type___148 *);
	void (*exit_sched)(struct elevator_queue___148 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___143 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___143 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___143 *);
	bool (*allow_merge)(struct request_queue___148 *, struct request___148 *, struct bio___148 *);
	bool (*bio_merge)(struct request_queue___148 *, struct bio___148 *, unsigned int);
	int (*request_merge)(struct request_queue___148 *, struct request___148 **, struct bio___148 *);
	void (*request_merged)(struct request_queue___148 *, struct request___148 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___148 *, struct request___148 *, struct request___148 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___148 *);
	void (*finish_request)(struct request___148 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___143 *, struct list_head *, bool);
	struct request___148 * (*dispatch_request)(struct blk_mq_hw_ctx___143 *);
	bool (*has_work)(struct blk_mq_hw_ctx___143 *);
	void (*completed_request)(struct request___148 *, u64);
	void (*requeue_request)(struct request___148 *);
	struct request___148 * (*former_request)(struct request_queue___148 *, struct request___148 *);
	struct request___148 * (*next_request)(struct request_queue___148 *, struct request___148 *);
	void (*init_icq)(struct io_cq___148 *);
	void (*exit_icq)(struct io_cq___148 *);
};

struct elv_fs_entry___148;

struct elevator_type___148 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___148 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___148 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___241 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___148 {
	struct elevator_type___148 *type;
	void *elevator_data;
	struct kobject___245 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___148 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___148 *, char *);
	ssize_t (*store)(struct elevator_queue___148 *, const char *, size_t);
};

struct blk_mq_queue_data___143;

struct blk_mq_ops___143 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___143 *, const struct blk_mq_queue_data___143 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___143 *);
	int (*get_budget)(struct request_queue___148 *);
	void (*put_budget)(struct request_queue___148 *, int);
	void (*set_rq_budget_token)(struct request___148 *, int);
	int (*get_rq_budget_token)(struct request___148 *);
	enum blk_eh_timer_return (*timeout)(struct request___148 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___143 *);
	void (*complete)(struct request___148 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___143 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___143 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___143 *, struct request___148 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___143 *, struct request___148 *, unsigned int);
	void (*initialize_rq_fn)(struct request___148 *);
	void (*cleanup_rq)(struct request___148 *);
	bool (*busy)(struct request_queue___148 *);
	int (*map_queues)(struct blk_mq_tag_set___143 *);
	void (*show_rq)(struct seq_file___232 *, struct request___148 *);
};

struct blk_mq_tag_set___143 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___143 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___143 {
	struct request___148 *rq;
	bool last;
};

struct blkcg_policy_data___136;

struct blkcg___136 {
	struct cgroup_subsys_state___184 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___136 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___136 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___136 {
	struct blkcg___136 *blkcg;
	int plid;
};

struct blkg_policy_data___136 {
	struct blkcg_gq___136 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___122 {
	struct mem_cgroup___122 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___122 {
	struct lruvec___130 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___122 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___122 *memcg;
};

struct obj_cgroup___122 {
	struct percpu_ref refcnt;
	struct mem_cgroup___122 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___60 {
	spinlock_t *lock;
	struct sk_buff___67 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___60;

struct Qdisc_ops___60 {
	struct Qdisc_ops___60 *next;
	const struct Qdisc_class_ops___60 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___67 *, struct Qdisc___60 *, struct sk_buff___67 **);
	struct sk_buff___67 * (*dequeue)(struct Qdisc___60 *);
	struct sk_buff___67 * (*peek)(struct Qdisc___60 *);
	int (*init)(struct Qdisc___60 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___60 *);
	void (*destroy)(struct Qdisc___60 *);
	int (*change)(struct Qdisc___60 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___60 *);
	int (*change_tx_queue_len)(struct Qdisc___60 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___60 *, unsigned int);
	int (*dump)(struct Qdisc___60 *, struct sk_buff___67 *);
	int (*dump_stats)(struct Qdisc___60 *, struct gnet_dump___60 *);
	void (*ingress_block_set)(struct Qdisc___60 *, u32);
	void (*egress_block_set)(struct Qdisc___60 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___60 *);
	u32 (*egress_block_get)(struct Qdisc___60 *);
	struct module___241 *owner;
};

struct Qdisc_class_ops___60 {
	unsigned int flags;
	struct netdev_queue___66 * (*select_queue)(struct Qdisc___60 *, struct tcmsg *);
	int (*graft)(struct Qdisc___60 *, long unsigned int, struct Qdisc___60 *, struct Qdisc___60 **, struct netlink_ext_ack *);
	struct Qdisc___60 * (*leaf)(struct Qdisc___60 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___60 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___60 *, u32);
	int (*change)(struct Qdisc___60 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___60 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___60 *, struct qdisc_walker *);
	struct tcf_block___60 * (*tcf_block)(struct Qdisc___60 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___60 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___60 *, long unsigned int);
	int (*dump)(struct Qdisc___60 *, long unsigned int, struct sk_buff___67 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___60 *, long unsigned int, struct gnet_dump___60 *);
};

struct tcf_chain___60;

struct tcf_block___60 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___71 *net;
	struct Qdisc___60 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___60 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___60;

struct tcf_proto_ops___60;

struct tcf_proto___60 {
	struct tcf_proto___60 *next;
	void *root;
	int (*classify)(struct sk_buff___67 *, const struct tcf_proto___60 *, struct tcf_result___60 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___60 *ops;
	struct tcf_chain___60 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___60 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___60 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___60 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___67 *, const struct tcf_proto___60 *, struct tcf_result___60 *);
	int (*init)(struct tcf_proto___60 *);
	void (*destroy)(struct tcf_proto___60 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___60 *, u32);
	void (*put)(struct tcf_proto___60 *, void *);
	int (*change)(struct net___71 *, struct sk_buff___67 *, struct tcf_proto___60 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___60 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___60 *);
	void (*walk)(struct tcf_proto___60 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___60 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___60 *, void *);
	void (*hw_del)(struct tcf_proto___60 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___71 *, struct tcf_chain___60 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___71 *, struct tcf_proto___60 *, void *, struct sk_buff___67 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___71 *, struct tcf_proto___60 *, void *, struct sk_buff___67 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___67 *, struct net___71 *, void *);
	struct module___241 *owner;
	int flags;
};

struct tcf_chain___60 {
	struct mutex filter_chain_lock;
	struct tcf_proto___60 *filter_chain;
	struct list_head list;
	struct tcf_block___60 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___60 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___53 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___60 *prog;
};

struct fib_rule___53 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___53 *ctarget;
	struct net___71 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___53 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___53 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___40;

struct timewait_sock_ops___39;

struct proto___53 {
	void (*close)(struct sock___53 *, long int);
	int (*pre_connect)(struct sock___53 *, struct sockaddr *, int);
	int (*connect)(struct sock___53 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___53 *, int);
	struct sock___53 * (*accept)(struct sock___53 *, int, int *, bool);
	int (*ioctl)(struct sock___53 *, int, long unsigned int);
	int (*init)(struct sock___53 *);
	void (*destroy)(struct sock___53 *);
	void (*shutdown)(struct sock___53 *, int);
	int (*setsockopt)(struct sock___53 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___53 *, int, int, char *, int *);
	void (*keepalive)(struct sock___53 *, int);
	int (*compat_ioctl)(struct sock___53 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___53 *, struct msghdr___55 *, size_t);
	int (*recvmsg)(struct sock___53 *, struct msghdr___55 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___53 *, struct page___262 *, int, size_t, int);
	int (*bind)(struct sock___53 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___53 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___53 *, struct sk_buff___67 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___53 *);
	int (*hash)(struct sock___53 *);
	void (*unhash)(struct sock___53 *);
	void (*rehash)(struct sock___53 *);
	int (*get_port)(struct sock___53 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___53 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___53 *, int);
	bool (*sock_is_readable)(struct sock___53 *);
	void (*enter_memory_pressure)(struct sock___53 *);
	void (*leave_memory_pressure)(struct sock___53 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___40 *rsk_prot;
	struct timewait_sock_ops___39 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___241 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___53 *, int);
};

struct request_sock___41;

struct request_sock_ops___40 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___53 *, struct request_sock___41 *);
	void (*send_ack)(const struct sock___53 *, struct sk_buff___67 *, struct request_sock___41 *);
	void (*send_reset)(const struct sock___53 *, struct sk_buff___67 *);
	void (*destructor)(struct request_sock___41 *);
	void (*syn_ack_timeout)(const struct request_sock___41 *);
};

struct timewait_sock_ops___39 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___53 *, struct sock___53 *, void *);
	void (*twsk_destructor)(struct sock___53 *);
};

struct request_sock___41 {
	struct sock_common___53 __req_common;
	struct request_sock___41 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___40 *rsk_ops;
	struct sock___53 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___37 {
	struct in6_addr mca_addr;
	struct inet6_dev___37 *idev;
	struct ifmcaddr6___37 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___10 {
	struct in6_addr aca_addr;
	struct fib6_info___10 *aca_rt;
	struct ifacaddr6___10 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result___2;

struct fib6_config___2;

struct ipv6_stub___2 {
	int (*ipv6_sock_mc_join)(struct sock___53 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___53 *, int, const struct in6_addr *);
	struct dst_entry___53 * (*ipv6_dst_lookup_flow)(struct net___71 *, const struct sock___53 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___67 *);
	struct fib6_table___10 * (*fib6_get_table)(struct net___71 *, u32);
	int (*fib6_lookup)(struct net___71 *, int, struct flowi6 *, struct fib6_result___2 *, int);
	int (*fib6_table_lookup)(struct net___71 *, struct fib6_table___10 *, int, struct flowi6 *, struct fib6_result___2 *, int);
	void (*fib6_select_path)(const struct net___71 *, struct fib6_result___2 *, struct flowi6 *, int, bool, const struct sk_buff___67 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___2 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___71 *, struct fib6_nh___10 *, struct fib6_config___2 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___10 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___10 *);
	void (*fib6_update_sernum)(struct net___71 *, struct fib6_info___10 *);
	int (*ip6_del_rt)(struct net___71 *, struct fib6_info___10 *, bool);
	void (*fib6_rt_update)(struct net___71 *, struct fib6_info___10 *, struct nl_info___2 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___66 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___67 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___53 *, struct sk_buff___67 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___67 *, int, __be32, int);
	struct neigh_table___53 *nd_tbl;
	int (*ipv6_fragment)(struct net___71 *, struct sock___53 *, struct sk_buff___67 *, int (*)(struct net___71 *, struct sock___53 *, struct sk_buff___67 *));
	struct net_device___66 * (*ipv6_dev_find)(struct net___71 *, const struct in6_addr *, struct net_device___66 *);
};

struct fib6_result___2 {
	struct fib6_nh___10 *nh;
	struct fib6_info___10 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___10 *rt6;
};

struct fib6_config___2 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___2 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct fib_nh_exception___10 {
	struct fib_nh_exception___10 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___10 *fnhe_rth_input;
	struct rtable___10 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___10 {
	struct dst_entry___53 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___10 {
	struct fib_nh_exception___10 *chain;
};

struct fib_info___6;

struct fib_nh___6 {
	struct fib_nh_common___10 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___6 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___6 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___71 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___6 *nh;
	struct callback_head rcu;
	struct fib_nh___6 fib_nh[0];
};

struct nh_info___6;

struct nh_group___6;

struct nexthop___6 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___71 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___6 *nh_info;
		struct nh_group___6 *nh_grp;
	};
};

enum {
	LWTUNNEL_XMIT_DONE = 0,
	LWTUNNEL_XMIT_CONTINUE = 1,
};

struct lwtunnel_encap_ops___2 {
	int (*build_state)(struct net___71 *, struct nlattr *, unsigned int, const void *, struct lwtunnel_state___31 **, struct netlink_ext_ack *);
	void (*destroy_state)(struct lwtunnel_state___31 *);
	int (*output)(struct net___71 *, struct sock___53 *, struct sk_buff___67 *);
	int (*input)(struct sk_buff___67 *);
	int (*fill_encap)(struct sk_buff___67 *, struct lwtunnel_state___31 *);
	int (*get_encap_size)(struct lwtunnel_state___31 *);
	int (*cmp_encap)(struct lwtunnel_state___31 *, struct lwtunnel_state___31 *);
	int (*xmit)(struct sk_buff___67 *);
	struct module___241 *owner;
};

struct nh_info___6 {
	struct hlist_node dev_hash;
	struct nexthop___6 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___10 fib_nhc;
		struct fib_nh___6 fib_nh;
		struct fib6_nh___10 fib6_nh;
	};
};

struct nh_grp_entry___6;

struct nh_res_bucket___6 {
	struct nh_grp_entry___6 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___6 {
	struct nexthop___6 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___6 *nh_parent;
};

struct nh_res_table___6 {
	struct net___71 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___6 nh_buckets[0];
};

struct nh_group___6 {
	struct nh_group___6 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___6 *res_table;
	struct nh_grp_entry___6 nh_entries[0];
};

struct bpf_lwt_prog {
	struct bpf_prog___60 *prog;
	char *name;
};

struct bpf_lwt {
	struct bpf_lwt_prog in;
	struct bpf_lwt_prog out;
	struct bpf_lwt_prog xmit;
	int family;
};

struct dst_cache_pcpu {
	long unsigned int refresh_ts;
	struct dst_entry___48 *dst;
	u32 cookie;
	union {
		struct in_addr in_saddr;
		struct in6_addr in6_saddr;
	};
};

struct dentry___258;

struct super_block___258;

struct module___242;

struct file_system_type___258 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___258 * (*mount)(struct file_system_type___258 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___258 *);
	struct module___242 *owner;
	struct file_system_type___258 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___258;

struct kiocb___258;

struct iov_iter___178;

struct poll_table_struct___179;

struct vm_area_struct___263;

struct inode___258;

struct file_lock___258;

struct page___263;

struct pipe_inode_info___99;

struct seq_file___233;

struct file_operations___259 {
	struct module___242 *owner;
	loff_t (*llseek)(struct file___258 *, loff_t, int);
	ssize_t (*read)(struct file___258 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___258 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___258 *, struct iov_iter___178 *);
	ssize_t (*write_iter)(struct kiocb___258 *, struct iov_iter___178 *);
	int (*iopoll)(struct kiocb___258 *, bool);
	int (*iterate)(struct file___258 *, struct dir_context *);
	int (*iterate_shared)(struct file___258 *, struct dir_context *);
	__poll_t (*poll)(struct file___258 *, struct poll_table_struct___179 *);
	long int (*unlocked_ioctl)(struct file___258 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___258 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___258 *, struct vm_area_struct___263 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___258 *, struct file___258 *);
	int (*flush)(struct file___258 *, fl_owner_t);
	int (*release)(struct inode___258 *, struct file___258 *);
	int (*fsync)(struct file___258 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___258 *, int);
	int (*lock)(struct file___258 *, int, struct file_lock___258 *);
	ssize_t (*sendpage)(struct file___258 *, struct page___263 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___258 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___258 *, long unsigned int);
	int (*flock)(struct file___258 *, int, struct file_lock___258 *);
	ssize_t (*splice_write)(struct pipe_inode_info___99 *, struct file___258 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___258 *, loff_t *, struct pipe_inode_info___99 *, size_t, unsigned int);
	int (*setlease)(struct file___258 *, long int, struct file_lock___258 **, void **);
	long int (*fallocate)(struct file___258 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___233 *, struct file___258 *);
	ssize_t (*copy_file_range)(struct file___258 *, loff_t, struct file___258 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___258 *, loff_t, struct file___258 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___258 *, loff_t, loff_t, int);
};

struct vmacache___263 {
	u64 seqnum;
	struct vm_area_struct___263 *vmas[4];
};

struct page_frag___263 {
	struct page___263 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___85;

struct debug_info___85 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___85 *hbp_break[16];
	struct perf_event___85 *hbp_watch[16];
};

struct thread_struct___85 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___85 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___264;

struct pid___235;

struct nsproxy___244;

struct signal_struct___259;

struct bio_list___149;

struct backing_dev_info___135;

struct io_context___149;

struct css_set___185;

struct perf_event_context___85;

struct mem_cgroup___123;

struct request_queue___149;

struct vm_struct___241;

struct task_struct___265 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___265 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___264 *mm;
	struct mm_struct___264 *active_mm;
	struct vmacache___263 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___265 *real_parent;
	struct task_struct___265 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___265 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___235 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___244 *nsproxy;
	struct signal_struct___259 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___265 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___149 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___135 *backing_dev_info;
	struct io_context___149 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___185 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___85 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___99 *splice_pipe;
	struct page_frag___263 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___123 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___123 *active_memcg;
	struct request_queue___149 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___265 *oom_reaper_list;
	struct vm_struct___241 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___85 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___246;

struct kobj_type___246;

struct kernfs_node___246;

struct kobject___246 {
	const char *name;
	struct list_head entry;
	struct kobject___246 *parent;
	struct kset___246 *kset;
	struct kobj_type___246 *ktype;
	struct kernfs_node___246 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___243 {
	struct kobject___246 kobj;
	struct module___242 *mod;
	struct kobject___246 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___242 {
	struct module___242 *mod;
	struct latch_tree_node node;
};

struct module_layout___242 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___242 mtn;
};

struct module_attribute___242;

struct kernel_param___242;

struct trace_event_call___79;

struct module___242 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___243 mkobj;
	struct module_attribute___242 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___246 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___242 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___242 core_layout;
	struct module_layout___242 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___79 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___85 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___265 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___85)(struct perf_event___85 *, struct perf_sample_data *, struct pt_regs *);

struct pmu___85;

struct fasync_struct___258;

struct pid_namespace___235;

struct bpf_prog___61;

struct perf_cgroup___85;

struct perf_event___85 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___85 *group_leader;
	struct pmu___85 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___85 hw;
	struct perf_event_context___85 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___85 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___265 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___258 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___85 *aux_event;
	void (*destroy)(struct perf_event___85 *);
	struct callback_head callback_head;
	struct pid_namespace___235 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___85 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___85 orig_overflow_handler;
	struct bpf_prog___61 *prog;
	u64 bpf_cookie;
	struct trace_event_call___79 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___85 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___235 {
	int nr;
	struct pid_namespace___235 *ns;
};

struct pid_namespace___235 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___265 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___235 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___235 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___235 numbers[1];
};

typedef struct page___263 *pgtable_t___263;

struct address_space___258;

struct page_pool___87;

struct dev_pagemap___253;

struct page___263 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___258 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___87 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___263 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___263 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___264 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___253 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___253;

struct vm_area_struct___263 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___263 *vm_next;
	struct vm_area_struct___263 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___264 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___253 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___258 *vm_file;
	struct file___258 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___259 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___265 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___265 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___235 *pids[4];
	struct pid___235 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___264 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___263;

struct mm_struct___264 {
	struct {
		struct vm_area_struct___263 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___258 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___263 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___265 *owner;
		struct user_namespace___26 *user_ns;
		struct file___258 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___72;

struct cgroup_namespace___185;

struct nsproxy___244 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___235 *pid_ns_for_children;
	struct net___72 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___185 *cgroup_ns;
};

struct bio___149;

struct bio_list___149 {
	struct bio___149 *head;
	struct bio___149 *tail;
};

struct cgroup_subsys_state___185;

struct bdi_writeback___135 {
	struct backing_dev_info___135 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___185 *memcg_css;
	struct cgroup_subsys_state___185 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___239;

struct backing_dev_info___135 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___135 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___239 *dev;
	char dev_name[64];
	struct device___239 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___258 *debug_dir;
};

struct io_cq___149;

struct io_context___149 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___149 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___185;

struct css_set___185 {
	struct cgroup_subsys_state___185 *subsys[14];
	refcount_t refcount;
	struct css_set___185 *dom_cset;
	struct cgroup___185 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___185 *mg_src_cgrp;
	struct cgroup___185 *mg_dst_cgrp;
	struct css_set___185 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___85 {
	struct pmu___85 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___265 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___85 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___99;

struct pipe_inode_info___99 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___263 *tmp_page;
	struct fasync_struct___258 *fasync_readers;
	struct fasync_struct___258 *fasync_writers;
	struct pipe_buffer___99 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___185;

struct cgroup_subsys_state___185 {
	struct cgroup___185 *cgroup;
	struct cgroup_subsys___185 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___185 *parent;
};

struct cgroup_file___185 {
	struct kernfs_node___246 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___123;

struct mem_cgroup_per_node___123;

struct mem_cgroup___123 {
	struct cgroup_subsys_state___185 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___185 events_file;
	struct cgroup_file___185 events_local_file;
	struct cgroup_file___185 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___123 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___265 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___123 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___149;

struct blk_integrity___149 {
	const struct blk_integrity_profile___149 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___149 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___149 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___149;

struct elevator_queue___149;

struct blk_mq_ops___144;

struct blk_mq_hw_ctx___144;

struct gendisk___152;

struct blkcg_gq___137;

struct blk_mq_tag_set___144;

struct request_queue___149 {
	struct request___149 *last_merge;
	struct elevator_queue___149 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___144 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___144 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___152 *disk;
	struct kobject___246 kobj;
	struct kobject___246 *mq_kobj;
	struct blk_integrity___149 integrity;
	struct device___239 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___137 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___144 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___149 bio_split;
	struct dentry___258 *debugfs_dir;
	struct dentry___258 *sched_debugfs_dir;
	struct dentry___258 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___241 {
	struct vm_struct___241 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___263 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___258;

struct address_space___258 {
	struct inode___258 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___258 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___87 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___239 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___87 {
	u32 count;
	struct page___263 *cache[128];
};

struct page_pool___87 {
	struct page_pool_params___87 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___263 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___87 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___253;

struct dev_pagemap___253 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___253 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___258;

struct path___258 {
	struct vfsmount___258 *mnt;
	struct dentry___258 *dentry;
};

struct fown_struct___235 {
	rwlock_t lock;
	struct pid___235 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___258 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___258 f_path;
	struct inode___258 *f_inode;
	const struct file_operations___259 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___235 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___258 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___253;

struct vm_operations_struct___253 {
	void (*open)(struct vm_area_struct___263 *);
	void (*close)(struct vm_area_struct___263 *);
	int (*may_split)(struct vm_area_struct___263 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___263 *);
	int (*mprotect)(struct vm_area_struct___263 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___253 *);
	vm_fault_t (*huge_fault)(struct vm_fault___253 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___253 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___263 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___253 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___253 *);
	int (*access)(struct vm_area_struct___263 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___263 *);
	int (*set_policy)(struct vm_area_struct___263 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___263 *, long unsigned int);
	struct page___263 * (*find_special_page)(struct vm_area_struct___263 *, long unsigned int);
};

struct core_thread___263 {
	struct task_struct___265 *task;
	struct core_thread___263 *next;
};

struct core_state___263 {
	atomic_t nr_threads;
	struct core_thread___263 dumper;
	struct completion startup;
};

struct vm_fault___253 {
	const struct {
		struct vm_area_struct___263 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___263 *cow_page;
	struct page___263 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___263 prealloc_pte;
};

struct pglist_data___131;

struct lruvec___131 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___131 *pgdat;
};

struct zone___131 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___131 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___131 {
	struct zone___131 *zone;
	int zone_idx;
};

struct zonelist___131 {
	struct zoneref___131 _zonerefs[321];
};

struct pglist_data___131 {
	struct zone___131 node_zones[5];
	struct zonelist___131 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___265 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___265 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___131 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___258;

struct dentry___258 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___258 *d_parent;
	struct qstr d_name;
	struct inode___258 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___258 *d_op;
	struct super_block___258 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___258;

struct inode___258 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___258 *i_op;
	struct super_block___258 *i_sb;
	struct address_space___258 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___135 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___259 *i_fop;
		void (*free_inode)(struct inode___258 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___258 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___99 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___258 {
	int (*d_revalidate)(struct dentry___258 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___258 *, unsigned int);
	int (*d_hash)(const struct dentry___258 *, struct qstr *);
	int (*d_compare)(const struct dentry___258 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___258 *);
	int (*d_init)(struct dentry___258 *);
	void (*d_release)(struct dentry___258 *);
	void (*d_prune)(struct dentry___258 *);
	void (*d_iput)(struct dentry___258 *, struct inode___258 *);
	char * (*d_dname)(struct dentry___258 *, char *, int);
	struct vfsmount___258 * (*d_automount)(struct path___258 *);
	int (*d_manage)(const struct path___258 *, bool);
	struct dentry___258 * (*d_real)(struct dentry___258 *, const struct inode___258 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___258;

struct mem_dqinfo___258 {
	struct quota_format_type___258 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___258;

struct quota_info___258 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___258 *files[3];
	struct mem_dqinfo___258 info[3];
	const struct quota_format_ops___258 *ops[3];
};

struct rcuwait___259 {
	struct task_struct___265 *task;
};

struct percpu_rw_semaphore___259 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___259 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___258 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___259 rw_sem[3];
};

struct shrink_control___123;

struct shrinker___123 {
	long unsigned int (*count_objects)(struct shrinker___123 *, struct shrink_control___123 *);
	long unsigned int (*scan_objects)(struct shrinker___123 *, struct shrink_control___123 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___258;

struct dquot_operations___258;

struct quotactl_ops___258;

struct block_device___152;

struct super_block___258 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___258 *s_type;
	const struct super_operations___258 *s_op;
	const struct dquot_operations___258 *dq_op;
	const struct quotactl_ops___258 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___258 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___152 *s_bdev;
	struct backing_dev_info___135 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___258 s_dquot;
	struct sb_writers___258 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___258 *s_d_op;
	int cleancache_poolid;
	struct shrinker___123 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___258 {
	struct dentry___258 *mnt_root;
	struct super_block___258 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___123 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___123 *memcg;
};

struct psi_group___185 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___265 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___61;

struct cgroup_bpf___61 {
	struct bpf_prog_array___61 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___61 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___185;

struct cgroup_rstat_cpu___185;

struct cgroup___185 {
	struct cgroup_subsys_state___185 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___246 *kn;
	struct cgroup_file___185 procs_file;
	struct cgroup_file___185 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___185 *subsys[14];
	struct cgroup_root___185 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___185 *dom_cgrp;
	struct cgroup___185 *old_dom_cgrp;
	struct cgroup_rstat_cpu___185 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___185 psi;
	struct cgroup_bpf___61 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___149 {
	struct request_queue___149 *q;
	struct io_context___149 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___258 {
	struct file___258 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___258 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___258 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___258 *ia_file;
};

struct dquot___258 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___258 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___258 {
	int qf_fmt_id;
	const struct quota_format_ops___258 *qf_ops;
	struct module___242 *qf_owner;
	struct quota_format_type___258 *qf_next;
};

struct quota_format_ops___258 {
	int (*check_quota_file)(struct super_block___258 *, int);
	int (*read_file_info)(struct super_block___258 *, int);
	int (*write_file_info)(struct super_block___258 *, int);
	int (*free_file_info)(struct super_block___258 *, int);
	int (*read_dqblk)(struct dquot___258 *);
	int (*commit_dqblk)(struct dquot___258 *);
	int (*release_dqblk)(struct dquot___258 *);
	int (*get_next_id)(struct super_block___258 *, struct kqid *);
};

struct dquot_operations___258 {
	int (*write_dquot)(struct dquot___258 *);
	struct dquot___258 * (*alloc_dquot)(struct super_block___258 *, int);
	void (*destroy_dquot)(struct dquot___258 *);
	int (*acquire_dquot)(struct dquot___258 *);
	int (*release_dquot)(struct dquot___258 *);
	int (*mark_dirty)(struct dquot___258 *);
	int (*write_info)(struct super_block___258 *, int);
	qsize_t * (*get_reserved_space)(struct inode___258 *);
	int (*get_projid)(struct inode___258 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___258 *, qsize_t *);
	int (*get_next_id)(struct super_block___258 *, struct kqid *);
};

struct quotactl_ops___258 {
	int (*quota_on)(struct super_block___258 *, int, int, const struct path___258 *);
	int (*quota_off)(struct super_block___258 *, int);
	int (*quota_enable)(struct super_block___258 *, unsigned int);
	int (*quota_disable)(struct super_block___258 *, unsigned int);
	int (*quota_sync)(struct super_block___258 *, int);
	int (*set_info)(struct super_block___258 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___258 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___258 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___258 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___258 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___258 *, unsigned int);
};

struct writeback_control___135;

struct address_space_operations___258 {
	int (*writepage)(struct page___263 *, struct writeback_control___135 *);
	int (*readpage)(struct file___258 *, struct page___263 *);
	int (*writepages)(struct address_space___258 *, struct writeback_control___135 *);
	int (*set_page_dirty)(struct page___263 *);
	int (*readpages)(struct file___258 *, struct address_space___258 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___258 *, struct address_space___258 *, loff_t, unsigned int, unsigned int, struct page___263 **, void **);
	int (*write_end)(struct file___258 *, struct address_space___258 *, loff_t, unsigned int, unsigned int, struct page___263 *, void *);
	sector_t (*bmap)(struct address_space___258 *, sector_t);
	void (*invalidatepage)(struct page___263 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___263 *, gfp_t);
	void (*freepage)(struct page___263 *);
	ssize_t (*direct_IO)(struct kiocb___258 *, struct iov_iter___178 *);
	int (*migratepage)(struct address_space___258 *, struct page___263 *, struct page___263 *, enum migrate_mode);
	bool (*isolate_page)(struct page___263 *, isolate_mode_t);
	void (*putback_page)(struct page___263 *);
	int (*launder_page)(struct page___263 *);
	int (*is_partially_uptodate)(struct page___263 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___263 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___258 *, struct page___263 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___258 *, sector_t *);
	void (*swap_deactivate)(struct file___258 *);
};

struct writeback_control___135 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___135 *wb;
	struct inode___258 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___175;

struct iov_iter___178 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___175 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___99 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___258 {
	struct dentry___258 * (*lookup)(struct inode___258 *, struct dentry___258 *, unsigned int);
	const char * (*get_link)(struct dentry___258 *, struct inode___258 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___258 *, int);
	struct posix_acl * (*get_acl)(struct inode___258 *, int, bool);
	int (*readlink)(struct dentry___258 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___258 *, struct dentry___258 *, umode_t, bool);
	int (*link)(struct dentry___258 *, struct inode___258 *, struct dentry___258 *);
	int (*unlink)(struct inode___258 *, struct dentry___258 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___258 *, struct dentry___258 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___258 *, struct dentry___258 *, umode_t);
	int (*rmdir)(struct inode___258 *, struct dentry___258 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___258 *, struct dentry___258 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___258 *, struct dentry___258 *, struct inode___258 *, struct dentry___258 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___258 *, struct iattr___258 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___258 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___258 *, char *, size_t);
	int (*fiemap)(struct inode___258 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___258 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___258 *, struct dentry___258 *, struct file___258 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___258 *, struct dentry___258 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___258 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___258 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___258 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___258 {
	void (*fl_copy_lock)(struct file_lock___258 *, struct file_lock___258 *);
	void (*fl_release_private)(struct file_lock___258 *);
};

struct lock_manager_operations___258;

struct file_lock___258 {
	struct file_lock___258 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___258 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___258 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___258 *fl_ops;
	const struct lock_manager_operations___258 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___258 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___258 *);
	int (*lm_grant)(struct file_lock___258 *, int);
	bool (*lm_break)(struct file_lock___258 *);
	int (*lm_change)(struct file_lock___258 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___258 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___258 *);
};

struct fasync_struct___258 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___258 *fa_next;
	struct file___258 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___258 {
	struct inode___258 * (*alloc_inode)(struct super_block___258 *);
	void (*destroy_inode)(struct inode___258 *);
	void (*free_inode)(struct inode___258 *);
	void (*dirty_inode)(struct inode___258 *, int);
	int (*write_inode)(struct inode___258 *, struct writeback_control___135 *);
	int (*drop_inode)(struct inode___258 *);
	void (*evict_inode)(struct inode___258 *);
	void (*put_super)(struct super_block___258 *);
	int (*sync_fs)(struct super_block___258 *, int);
	int (*freeze_super)(struct super_block___258 *);
	int (*freeze_fs)(struct super_block___258 *);
	int (*thaw_super)(struct super_block___258 *);
	int (*unfreeze_fs)(struct super_block___258 *);
	int (*statfs)(struct dentry___258 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___258 *, int *, char *);
	void (*umount_begin)(struct super_block___258 *);
	int (*show_options)(struct seq_file___233 *, struct dentry___258 *);
	int (*show_devname)(struct seq_file___233 *, struct dentry___258 *);
	int (*show_path)(struct seq_file___233 *, struct dentry___258 *);
	int (*show_stats)(struct seq_file___233 *, struct dentry___258 *);
	ssize_t (*quota_read)(struct super_block___258 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___258 *, int, const char *, size_t, loff_t);
	struct dquot___258 ** (*get_dquots)(struct inode___258 *);
	long int (*nr_cached_objects)(struct super_block___258 *, struct shrink_control___123 *);
	long int (*free_cached_objects)(struct super_block___258 *, struct shrink_control___123 *);
	struct file___258 * (*real_loop)(struct file___258 *);
};

struct wakeup_source___239;

struct dev_pm_info___239 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___239 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___239 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___239;

struct bus_type___239;

struct device_driver___239;

struct dev_pm_domain___239;

struct fwnode_handle___235;

struct class___239;

struct attribute_group___246;

struct device___239 {
	struct kobject___246 kobj;
	struct device___239 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___239 *type;
	struct bus_type___239 *bus;
	struct device_driver___239 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___239 power;
	struct dev_pm_domain___239 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___235 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___239 *class;
	const struct attribute_group___246 **groups;
	void (*release)(struct device___239 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___152 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___258 *bd_inode;
	struct super_block___258 *bd_super;
	void *bd_claiming;
	struct device___239 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___246 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___152 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___258 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___187)(struct file___258 *, wait_queue_head_t *, struct poll_table_struct___179 *);

struct poll_table_struct___179 {
	poll_queue_proc___187 _qproc;
	__poll_t _key;
};

struct seq_operations___233;

struct seq_file___233 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___233 *op;
	int poll_event;
	const struct file___258 *file;
	void *private;
};

typedef void bio_end_io_t___149(struct bio___149 *);

struct bio_vec___175 {
	struct page___263 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___149;

struct bio___149 {
	struct bio___149 *bi_next;
	struct block_device___152 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___149 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___137 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___149 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___175 *bi_io_vec;
	struct bio_set___149 *bi_pool;
	struct bio_vec___175 bi_inline_vecs[0];
};

struct kernfs_root___246;

struct kernfs_elem_dir___246 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___246 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___246;

struct kernfs_root___246 {
	struct kernfs_node___246 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___246 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___246 {
	struct kernfs_node___246 *target_kn;
};

struct kernfs_ops___246;

struct kernfs_elem_attr___246 {
	const struct kernfs_ops___246 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___246 *notify_next;
};

struct kernfs_node___246 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___246 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___246 dir;
		struct kernfs_elem_symlink___246 symlink;
		struct kernfs_elem_attr___246 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___246;

struct kernfs_ops___246 {
	int (*open)(struct kernfs_open_file___246 *);
	void (*release)(struct kernfs_open_file___246 *);
	int (*seq_show)(struct seq_file___233 *, void *);
	void * (*seq_start)(struct seq_file___233 *, loff_t *);
	void * (*seq_next)(struct seq_file___233 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___233 *, void *);
	ssize_t (*read)(struct kernfs_open_file___246 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___246 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___246 *, struct poll_table_struct___179 *);
	int (*mmap)(struct kernfs_open_file___246 *, struct vm_area_struct___263 *);
};

struct kernfs_syscall_ops___246 {
	int (*show_options)(struct seq_file___233 *, struct kernfs_root___246 *);
	int (*mkdir)(struct kernfs_node___246 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___246 *);
	int (*rename)(struct kernfs_node___246 *, struct kernfs_node___246 *, const char *);
	int (*show_path)(struct seq_file___233 *, struct kernfs_node___246 *, struct kernfs_root___246 *);
};

struct kernfs_open_file___246 {
	struct kernfs_node___246 *kn;
	struct file___258 *file;
	struct seq_file___233 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___253 *vm_ops;
};

struct sock___54;

struct kobj_ns_type_operations___54 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___54 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___72 *net;
} possible_net_t___67;

struct proto___54;

struct sock_common___54 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___54 *skc_prot;
	possible_net_t___67 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___54 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___68;

struct sk_buff_head___67 {
	struct sk_buff___68 *next;
	struct sk_buff___68 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___54 {
	struct cgroup___185 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___54;

struct socket_wq___55;

struct dst_entry___54;

struct socket___56;

struct net_device___67;

struct sock___54 {
	struct sock_common___54 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___67 sk_error_queue;
	struct sk_buff___68 *sk_rx_skb_cache;
	struct sk_buff_head___67 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___68 *head;
		struct sk_buff___68 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___54 *sk_filter;
	union {
		struct socket_wq___55 *sk_wq;
		struct socket_wq___55 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___54 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___54 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___68 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___68 *sk_tx_skb_cache;
	struct sk_buff_head___67 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___263 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___54 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___235 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___56 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___54 sk_cgrp_data;
	struct mem_cgroup___123 *sk_memcg;
	void (*sk_state_change)(struct sock___54 *);
	void (*sk_data_ready)(struct sock___54 *);
	void (*sk_write_space)(struct sock___54 *);
	void (*sk_error_report)(struct sock___54 *);
	int (*sk_backlog_rcv)(struct sock___54 *, struct sk_buff___68 *);
	struct sk_buff___68 * (*sk_validate_xmit_skb)(struct sock___54 *, struct net_device___67 *, struct sk_buff___68 *);
	void (*sk_destruct)(struct sock___54 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___246;

struct attribute_group___246 {
	const char *name;
	umode_t (*is_visible)(struct kobject___246 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___246 *, struct bin_attribute___246 *, int);
	struct attribute **attrs;
	struct bin_attribute___246 **bin_attrs;
};

struct bin_attribute___246 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___258 * (*f_mapping)();
	ssize_t (*read)(struct file___258 *, struct kobject___246 *, struct bin_attribute___246 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___258 *, struct kobject___246 *, struct bin_attribute___246 *, char *, loff_t, size_t);
	int (*mmap)(struct file___258 *, struct kobject___246 *, struct bin_attribute___246 *, struct vm_area_struct___263 *);
};

struct sysfs_ops___246 {
	ssize_t (*show)(struct kobject___246 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___246 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___246;

struct kset___246 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___246 kobj;
	const struct kset_uevent_ops___246 *uevent_ops;
};

struct kobj_type___246 {
	void (*release)(struct kobject___246 *);
	const struct sysfs_ops___246 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___246 **default_groups;
	const struct kobj_ns_type_operations___54 * (*child_ns_type)(struct kobject___246 *);
	const void * (*namespace)(struct kobject___246 *);
	void (*get_ownership)(struct kobject___246 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___246 {
	int (* const filter)(struct kset___246 *, struct kobject___246 *);
	const char * (* const name)(struct kset___246 *, struct kobject___246 *);
	int (* const uevent)(struct kset___246 *, struct kobject___246 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___242 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___242 *);
	int (*get)(char *, const struct kernel_param___242 *);
	void (*free)(void *);
};

struct kparam_array___242;

struct kernel_param___242 {
	const char *name;
	struct module___242 *mod;
	const struct kernel_param_ops___242 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___242 *arr;
	};
};

struct kparam_array___242 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___242 *ops;
	void *elem;
};

struct module_attribute___242 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___242 *, struct module_kobject___243 *, char *);
	ssize_t (*store)(struct module_attribute___242 *, struct module_kobject___243 *, const char *, size_t);
	void (*setup)(struct module___242 *, const char *);
	int (*test)(struct module___242 *);
	void (*free)(struct module___242 *);
};

struct trace_event_class___79;

struct trace_event_call___79 {
	struct list_head list;
	struct trace_event_class___79 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___61 *prog_array;
	int (*perf_perm)(struct trace_event_call___79 *, struct perf_event___85 *);
};

struct dev_pm_ops___239 {
	int (*prepare)(struct device___239 *);
	void (*complete)(struct device___239 *);
	int (*suspend)(struct device___239 *);
	int (*resume)(struct device___239 *);
	int (*freeze)(struct device___239 *);
	int (*thaw)(struct device___239 *);
	int (*poweroff)(struct device___239 *);
	int (*restore)(struct device___239 *);
	int (*suspend_late)(struct device___239 *);
	int (*resume_early)(struct device___239 *);
	int (*freeze_late)(struct device___239 *);
	int (*thaw_early)(struct device___239 *);
	int (*poweroff_late)(struct device___239 *);
	int (*restore_early)(struct device___239 *);
	int (*suspend_noirq)(struct device___239 *);
	int (*resume_noirq)(struct device___239 *);
	int (*freeze_noirq)(struct device___239 *);
	int (*thaw_noirq)(struct device___239 *);
	int (*poweroff_noirq)(struct device___239 *);
	int (*restore_noirq)(struct device___239 *);
	int (*runtime_suspend)(struct device___239 *);
	int (*runtime_resume)(struct device___239 *);
	int (*runtime_idle)(struct device___239 *);
};

struct wakeup_source___239 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___239 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___239 {
	struct dev_pm_ops___239 ops;
	int (*start)(struct device___239 *);
	void (*detach)(struct device___239 *, bool);
	int (*activate)(struct device___239 *);
	void (*sync)(struct device___239 *);
	void (*dismiss)(struct device___239 *);
};

struct bus_type___239 {
	const char *name;
	const char *dev_name;
	struct device___239 *dev_root;
	const struct attribute_group___246 **bus_groups;
	const struct attribute_group___246 **dev_groups;
	const struct attribute_group___246 **drv_groups;
	int (*match)(struct device___239 *, struct device_driver___239 *);
	int (*uevent)(struct device___239 *, struct kobj_uevent_env *);
	int (*probe)(struct device___239 *);
	void (*sync_state)(struct device___239 *);
	void (*remove)(struct device___239 *);
	void (*shutdown)(struct device___239 *);
	int (*online)(struct device___239 *);
	int (*offline)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	int (*num_vf)(struct device___239 *);
	int (*dma_configure)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___239 {
	const char *name;
	struct bus_type___239 *bus;
	struct module___242 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___239 *);
	void (*sync_state)(struct device___239 *);
	int (*remove)(struct device___239 *);
	void (*shutdown)(struct device___239 *);
	int (*suspend)(struct device___239 *, pm_message_t);
	int (*resume)(struct device___239 *);
	const struct attribute_group___246 **groups;
	const struct attribute_group___246 **dev_groups;
	const struct dev_pm_ops___239 *pm;
	void (*coredump)(struct device___239 *);
	struct driver_private *p;
};

struct device_type___239 {
	const char *name;
	const struct attribute_group___246 **groups;
	int (*uevent)(struct device___239 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___239 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___239 *);
	const struct dev_pm_ops___239 *pm;
};

struct class___239 {
	const char *name;
	struct module___242 *owner;
	const struct attribute_group___246 **class_groups;
	const struct attribute_group___246 **dev_groups;
	struct kobject___246 *dev_kobj;
	int (*dev_uevent)(struct device___239 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___239 *, umode_t *);
	void (*class_release)(struct class___239 *);
	void (*dev_release)(struct device___239 *);
	int (*shutdown_pre)(struct device___239 *);
	const struct kobj_ns_type_operations___54 *ns_type;
	const void * (*namespace)(struct device___239 *);
	void (*get_ownership)(struct device___239 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___239 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___235;

struct fwnode_handle___235 {
	struct fwnode_handle___235 *secondary;
	const struct fwnode_operations___235 *ops;
	struct device___239 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct msghdr___56 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___178 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___258 *msg_iocb;
};

struct sk_buff___68 {
	union {
		struct {
			struct sk_buff___68 *next;
			struct sk_buff___68 *prev;
			union {
				struct net_device___67 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___54 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___68 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___72;

struct fqdir___72 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___72 *f;
	struct net___72 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___72;

struct inet_frags___72 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___72 *, const void *);
	void (*destructor)(struct inet_frag_queue___72 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___30;

struct fib_rules_ops___54;

struct fib_notifier_ops___54;

struct netns_ipv4___72 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___30 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___54 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___54 *fibnl;
	struct sock___54 **icmp_sk;
	struct sock___54 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___54 **tcp_sk;
	struct fqdir___72 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___54 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___54 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___54 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___54;

struct dst_ops___72 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___72 *);
	struct dst_entry___54 * (*check)(struct dst_entry___54 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___54 *);
	unsigned int (*mtu)(const struct dst_entry___54 *);
	u32 * (*cow_metrics)(struct dst_entry___54 *, long unsigned int);
	void (*destroy)(struct dst_entry___54 *);
	void (*ifdown)(struct dst_entry___54 *, struct net_device___67 *, int);
	struct dst_entry___54 * (*negative_advice)(struct dst_entry___54 *);
	void (*link_failure)(struct sk_buff___68 *);
	void (*update_pmtu)(struct dst_entry___54 *, struct sock___54 *, struct sk_buff___68 *, u32, bool);
	void (*redirect)(struct dst_entry___54 *, struct sock___54 *, struct sk_buff___68 *);
	int (*local_out)(struct net___72 *, struct sock___54 *, struct sk_buff___68 *);
	struct neighbour___54 * (*neigh_lookup)(const struct dst_entry___54 *, struct sk_buff___68 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___54 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___72 {
	struct dst_ops___72 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___72 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___54 *fib6_rules_ops;
	struct sock___54 **icmp_sk;
	struct sock___54 *ndisc_sk;
	struct sock___54 *tcp_sk;
	struct sock___54 *igmp_sk;
	struct sock___54 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___54 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___54 *notifier_ops;
	struct fib_notifier_ops___54 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___72 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___72 *fqdir;
};

struct netns_sctp___54 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___54 *ctl_sock;
	struct sock___54 *udp4_sock;
	struct sock___54 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___61 {
	struct bpf_prog_array___61 *run_array[2];
	struct bpf_prog___61 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___72 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___54 *nlsk;
	struct sock___54 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___72 xfrm4_dst_ops;
	struct dst_ops___72 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___72 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___54 *rtnl;
	struct sock___54 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___67 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___72 ipv4;
	struct netns_ipv6___72 ipv6;
	struct netns_ieee802154_lowpan___72 ieee802154_lowpan;
	struct netns_sctp___54 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___67 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___61 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___72 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___54 *crypto_nlsk;
	struct sock___54 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___72 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___68 *fragments_tail;
	struct sk_buff___68 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___72 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___30 {
	struct ip_ra_chain___30 *next;
	struct sock___54 *sk;
	union {
		void (*destructor)(struct sock___54 *);
		struct sock___54 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___54;

struct fib_lookup_arg___54;

struct fib_rules_ops___54 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___54 *, struct flowi *, int, struct fib_lookup_arg___54 *);
	bool (*suppress)(struct fib_rule___54 *, int, struct fib_lookup_arg___54 *);
	int (*match)(struct fib_rule___54 *, struct flowi *, int);
	int (*configure)(struct fib_rule___54 *, struct sk_buff___68 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___54 *);
	int (*compare)(struct fib_rule___54 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___54 *, struct sk_buff___68 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___54 *);
	void (*flush_cache)(struct fib_rules_ops___54 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___242 *owner;
	struct net___72 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___54 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___72 *);
	int (*fib_dump)(struct net___72 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___242 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___32;

struct dst_entry___54 {
	struct net_device___67 *dev;
	struct dst_ops___72 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___68 *);
	int (*output)(struct net___72 *, struct sock___54 *, struct sk_buff___68 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___32 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___67(struct sk_buff___68 **);

struct bpf_xdp_entity___61 {
	struct bpf_prog___61 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___67;

struct net_device_ops___67;

struct ethtool_ops___29;

struct l3mdev_ops___54;

struct ndisc_ops___38;

struct xfrmdev_ops___67;

struct header_ops___67;

struct inet6_dev___38;

struct netdev_rx_queue___67;

struct mini_Qdisc___61;

struct netdev_queue___67;

struct Qdisc___61;

struct rtnl_link_ops___61;

struct dcbnl_rtnl_ops___67;

struct net_device___67 {
	char name[16];
	struct netdev_name_node___67 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___67 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___29 *ethtool_ops;
	const struct l3mdev_ops___54 *l3mdev_ops;
	const struct ndisc_ops___38 *ndisc_ops;
	const struct xfrmdev_ops___67 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___67 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___246 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___38 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___67 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___61 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___67 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___61 *miniq_ingress;
	struct netdev_queue___67 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___67 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___61 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___61 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___67 = 0,
		NETREG_REGISTERED___67 = 1,
		NETREG_UNREGISTERING___67 = 2,
		NETREG_UNREGISTERED___67 = 3,
		NETREG_RELEASED___67 = 4,
		NETREG_DUMMY___67 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___67 = 0,
		RTNL_LINK_INITIALIZING___67 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___67 *);
	struct netpoll_info *npinfo;
	possible_net_t___67 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___239 dev;
	const struct attribute_group___246 *sysfs_groups[4];
	const struct attribute_group___246 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___61 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___67 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___61 xdp_state[3];
	long: 64;
};

struct neigh_table___54;

struct neigh_parms___54;

struct neigh_ops___54;

struct neighbour___54 {
	struct neighbour___54 *next;
	struct neigh_table___54 *tbl;
	struct neigh_parms___54 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___67 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___54 *, struct sk_buff___68 *);
	const struct neigh_ops___54 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___67 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___61 {
	struct bpf_prog___61 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___61 {
	struct callback_head rcu;
	struct bpf_prog_array_item___61 items[0];
};

struct bpf_prog_aux___70;

struct bpf_prog___61 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___70 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___253 {
	void (*page_free)(struct page___263 *);
	void (*kill)(struct dev_pagemap___253 *);
	void (*cleanup)(struct dev_pagemap___253 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___253 *);
};

struct fwnode_reference_args___235;

struct fwnode_endpoint___235;

struct fwnode_operations___235 {
	struct fwnode_handle___235 * (*get)(struct fwnode_handle___235 *);
	void (*put)(struct fwnode_handle___235 *);
	bool (*device_is_available)(const struct fwnode_handle___235 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___235 *, const struct device___239 *);
	bool (*property_present)(const struct fwnode_handle___235 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___235 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___235 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___235 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*get_parent)(const struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*get_next_child_node)(const struct fwnode_handle___235 *, struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*get_named_child_node)(const struct fwnode_handle___235 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___235 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___235 *);
	struct fwnode_handle___235 * (*graph_get_next_endpoint)(const struct fwnode_handle___235 *, struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*graph_get_remote_endpoint)(const struct fwnode_handle___235 *);
	struct fwnode_handle___235 * (*graph_get_port_parent)(struct fwnode_handle___235 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___235 *, struct fwnode_endpoint___235 *);
	int (*add_links)(struct fwnode_handle___235 *);
};

struct fwnode_endpoint___235 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___235 *local_fwnode;
};

struct fwnode_reference_args___235 {
	struct fwnode_handle___235 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___185 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___185 *root_cset;
};

struct socket_wq___55 {
	wait_queue_head_t wait;
	struct fasync_struct___258 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___55;

struct socket___56 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___258 *file;
	struct sock___54 *sk;
	const struct proto_ops___55 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___55 wq;
};

typedef int (*sk_read_actor_t___54)(read_descriptor_t *, struct sk_buff___68 *, unsigned int, size_t);

struct proto_ops___55 {
	int family;
	struct module___242 *owner;
	int (*release)(struct socket___56 *);
	int (*bind)(struct socket___56 *, struct sockaddr *, int);
	int (*connect)(struct socket___56 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___56 *, struct socket___56 *);
	int (*accept)(struct socket___56 *, struct socket___56 *, int, bool);
	int (*getname)(struct socket___56 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___258 *, struct socket___56 *, struct poll_table_struct___179 *);
	int (*ioctl)(struct socket___56 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___56 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___56 *, void *, bool, bool);
	int (*listen)(struct socket___56 *, int);
	int (*shutdown)(struct socket___56 *, int);
	int (*setsockopt)(struct socket___56 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___56 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___233 *, struct socket___56 *);
	int (*sendmsg)(struct socket___56 *, struct msghdr___56 *, size_t);
	int (*recvmsg)(struct socket___56 *, struct msghdr___56 *, size_t, int);
	int (*mmap)(struct file___258 *, struct socket___56 *, struct vm_area_struct___263 *);
	ssize_t (*sendpage)(struct socket___56 *, struct page___263 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___56 *, loff_t *, struct pipe_inode_info___99 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___54 *, int);
	int (*peek_len)(struct socket___56 *);
	int (*read_sock)(struct sock___54 *, read_descriptor_t *, sk_read_actor_t___54);
	int (*sendpage_locked)(struct sock___54 *, struct page___263 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___54 *, struct msghdr___56 *, size_t);
	int (*set_rcvlowat)(struct sock___54 *, int);
};

struct pipe_buf_operations___99;

struct pipe_buffer___99 {
	struct page___263 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___99 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___99 {
	int (*confirm)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
	void (*release)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
	bool (*try_steal)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
	bool (*get)(struct pipe_inode_info___99 *, struct pipe_buffer___99 *);
};

struct seq_operations___233 {
	void * (*start)(struct seq_file___233 *, loff_t *);
	void (*stop)(struct seq_file___233 *, void *);
	void * (*next)(struct seq_file___233 *, void *, loff_t *);
	int (*show)(struct seq_file___233 *, void *);
};

struct pernet_operations___15 {
	struct list_head list;
	int (*init)(struct net___72 *);
	void (*pre_exit)(struct net___72 *);
	void (*exit)(struct net___72 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___67 {
	int (*ieee_getets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___67 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___67 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___67 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___67 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___67 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___67 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___67 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___67 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___67 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___67 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___67 *);
	u8 (*setstate)(struct net_device___67 *, u8);
	void (*getpermhwaddr)(struct net_device___67 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___67 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___67 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___67 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___67 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___67 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___67 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___67 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___67 *, int, u8 *);
	void (*setpfccfg)(struct net_device___67 *, int, u8);
	void (*getpfccfg)(struct net_device___67 *, int, u8 *);
	u8 (*setall)(struct net_device___67 *);
	u8 (*getcap)(struct net_device___67 *, int, u8 *);
	int (*getnumtcs)(struct net_device___67 *, int, u8 *);
	int (*setnumtcs)(struct net_device___67 *, int, u8);
	u8 (*getpfcstate)(struct net_device___67 *);
	void (*setpfcstate)(struct net_device___67 *, u8);
	void (*getbcncfg)(struct net_device___67 *, int, u32 *);
	void (*setbcncfg)(struct net_device___67 *, int, u32);
	void (*getbcnrp)(struct net_device___67 *, int, u8 *);
	void (*setbcnrp)(struct net_device___67 *, int, u8);
	int (*setapp)(struct net_device___67 *, u8, u16, u8);
	int (*getapp)(struct net_device___67 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___67 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___67 *, int, u8);
	u8 (*getdcbx)(struct net_device___67 *);
	u8 (*setdcbx)(struct net_device___67 *, u8);
	int (*peer_getappinfo)(struct net_device___67 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___67 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___67 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___67 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___67 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___67 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___70;

typedef int (*bpf_iter_init_seq_priv_t___69)(void *, struct bpf_iter_aux_info___70 *);

struct bpf_map___70;

struct bpf_iter_aux_info___70 {
	struct bpf_map___70 *map;
};

struct bpf_iter_seq_info___69 {
	const struct seq_operations___233 *seq_ops;
	bpf_iter_init_seq_priv_t___69 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___69 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___70 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___70 *, struct file___258 *);
	void (*map_free)(struct bpf_map___70 *);
	int (*map_get_next_key)(struct bpf_map___70 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___70 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___70 *, void *);
	int (*map_lookup_batch)(struct bpf_map___70 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___70 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___70 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___70 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___70 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___70 *, void *);
	int (*map_update_elem)(struct bpf_map___70 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___70 *, void *);
	int (*map_push_elem)(struct bpf_map___70 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___70 *, void *);
	int (*map_peek_elem)(struct bpf_map___70 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___70 *, struct file___258 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___70 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___70 *, void *, struct seq_file___233 *);
	int (*map_check_btf)(const struct bpf_map___70 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___70 *, struct bpf_prog_aux___70 *);
	void (*map_poke_untrack)(struct bpf_map___70 *, struct bpf_prog_aux___70 *);
	void (*map_poke_run)(struct bpf_map___70 *, u32, struct bpf_prog___61 *, struct bpf_prog___61 *);
	int (*map_direct_value_addr)(const struct bpf_map___70 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___70 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___70 *, struct vm_area_struct___263 *);
	__poll_t (*map_poll)(struct bpf_map___70 *, struct file___258 *, struct poll_table_struct___179 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___70 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___70 *, const struct bpf_map___70 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___70 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___69 *iter_seq_info;
};

struct bpf_map___70 {
	const struct bpf_map_ops___69 *ops;
	struct bpf_map___70 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___123 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___69;

struct bpf_jit_poke_descriptor___69;

struct bpf_prog_ops___61;

struct btf_mod_pair___69;

struct bpf_prog_offload___67;

struct bpf_prog_aux___70 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___61 *dst_prog;
	struct bpf_trampoline___69 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___61 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___69 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___61 *ops;
	struct bpf_map___70 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___69 *used_btfs;
	struct bpf_prog___61 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___70 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___67 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___67;

struct bpf_map_dev_ops___67 {
	int (*map_get_next_key)(struct bpf_offloaded_map___67 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___67 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___67 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___67 *, void *);
};

struct bpf_offloaded_map___67 {
	struct bpf_map___70 map;
	struct net_device___67 *netdev;
	const struct bpf_map_dev_ops___67 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___61 {
	int (*test_run)(struct bpf_prog___61 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___67 {
	struct bpf_prog___61 *prog;
	struct net_device___67 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___69 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___61 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___242 *mod;
};

struct bpf_jit_poke_descriptor___69 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___70 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___69 {
	struct btf *btf;
	struct module___242 *module;
};

struct cftype___185;

struct cgroup_subsys___185 {
	struct cgroup_subsys_state___185 * (*css_alloc)(struct cgroup_subsys_state___185 *);
	int (*css_online)(struct cgroup_subsys_state___185 *);
	void (*css_offline)(struct cgroup_subsys_state___185 *);
	void (*css_released)(struct cgroup_subsys_state___185 *);
	void (*css_free)(struct cgroup_subsys_state___185 *);
	void (*css_reset)(struct cgroup_subsys_state___185 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___185 *, int);
	int (*css_extra_stat_show)(struct seq_file___233 *, struct cgroup_subsys_state___185 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___265 *, struct css_set___185 *);
	void (*cancel_fork)(struct task_struct___265 *, struct css_set___185 *);
	void (*fork)(struct task_struct___265 *);
	void (*exit)(struct task_struct___265 *);
	void (*release)(struct task_struct___265 *);
	void (*bind)(struct cgroup_subsys_state___185 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___185 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___185 *dfl_cftypes;
	struct cftype___185 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___185 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___185 *updated_children;
	struct cgroup___185 *updated_next;
};

struct cgroup_root___185 {
	struct kernfs_root___246 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___185 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___185 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___185 *ss;
	struct list_head node;
	struct kernfs_ops___246 *kf_ops;
	int (*open)(struct kernfs_open_file___246 *);
	void (*release)(struct kernfs_open_file___246 *);
	u64 (*read_u64)(struct cgroup_subsys_state___185 *, struct cftype___185 *);
	s64 (*read_s64)(struct cgroup_subsys_state___185 *, struct cftype___185 *);
	int (*seq_show)(struct seq_file___233 *, void *);
	void * (*seq_start)(struct seq_file___233 *, loff_t *);
	void * (*seq_next)(struct seq_file___233 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___233 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___185 *, struct cftype___185 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___185 *, struct cftype___185 *, s64);
	ssize_t (*write)(struct kernfs_open_file___246 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___246 *, struct poll_table_struct___179 *);
};

struct xdp_rxq_info___67 {
	struct net_device___67 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___67 {
	struct net_device___67 *dev;
};

struct xdp_buff___67 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___67 *rxq;
	struct xdp_txq_info___67 *txq;
	u32 frame_sz;
};

struct xdp_frame___67 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___67 *dev_rx;
};

struct netlink_skb_parms___9 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___54 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___67 {
	struct sk_buff___68 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___68 *, struct netlink_callback___67 *);
	int (*done)(struct netlink_callback___67 *);
	void *data;
	struct module___242 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___67 {
	int (*create)(struct sk_buff___68 *, struct net_device___67 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___68 *, unsigned char *);
	int (*cache)(const struct neighbour___54 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___67 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___68 *);
};

struct netdev_queue___67 {
	struct net_device___67 *dev;
	struct Qdisc___61 *qdisc;
	struct Qdisc___61 *qdisc_sleeping;
	struct kobject___246 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___67 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___61 {
	struct sk_buff___68 *head;
	struct sk_buff___68 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___61;

struct Qdisc___61 {
	int (*enqueue)(struct sk_buff___68 *, struct Qdisc___61 *, struct sk_buff___68 **);
	struct sk_buff___68 * (*dequeue)(struct Qdisc___61 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___61 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___67 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___67 gso_skb;
	struct qdisc_skb_head___61 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___61 *next_sched;
	struct sk_buff_head___67 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___67 {
	struct xdp_rxq_info___67 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___246 kobj;
	struct net_device___67 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___67 {
	enum net_device_path_type type;
	const struct net_device___67 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___67 = 0,
				DEV_PATH_BR_VLAN_TAG___67 = 1,
				DEV_PATH_BR_VLAN_UNTAG___67 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___67 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___67 {
	const struct net_device___67 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___67 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___61 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___67 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___67 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___68 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___67 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___67 *dev;
	const char *name;
};

struct devlink_port___6;

struct net_device_ops___67 {
	int (*ndo_init)(struct net_device___67 *);
	void (*ndo_uninit)(struct net_device___67 *);
	int (*ndo_open)(struct net_device___67 *);
	int (*ndo_stop)(struct net_device___67 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___68 *, struct net_device___67 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___68 *, struct net_device___67 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___67 *, struct sk_buff___68 *, struct net_device___67 *);
	void (*ndo_change_rx_flags)(struct net_device___67 *, int);
	void (*ndo_set_rx_mode)(struct net_device___67 *);
	int (*ndo_set_mac_address)(struct net_device___67 *, void *);
	int (*ndo_validate_addr)(struct net_device___67 *);
	int (*ndo_do_ioctl)(struct net_device___67 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___67 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___67 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___67 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___67 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___67 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___67 *, int);
	int (*ndo_neigh_setup)(struct net_device___67 *, struct neigh_parms___54 *);
	void (*ndo_tx_timeout)(struct net_device___67 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___67 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___67 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___67 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___67 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___67 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___67 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___67 *);
	int (*ndo_netpoll_setup)(struct net_device___67 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___67 *);
	int (*ndo_set_vf_mac)(struct net_device___67 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___67 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___67 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___67 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___67 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___67 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___67 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___67 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___67 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___67 *, int, struct sk_buff___68 *);
	int (*ndo_get_vf_guid)(struct net_device___67 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___67 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___67 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___67 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___67 *);
	int (*ndo_fcoe_disable)(struct net_device___67 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___67 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___67 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___67 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___67 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___67 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___67 *, const struct sk_buff___68 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___67 *, struct net_device___67 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___67 *, struct net_device___67 *);
	struct net_device___67 * (*ndo_get_xmit_slave)(struct net_device___67 *, struct sk_buff___68 *, bool);
	struct net_device___67 * (*ndo_sk_get_lower_dev)(struct net_device___67 *, struct sock___54 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___67 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___67 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___67 *, struct neighbour___54 *);
	void (*ndo_neigh_destroy)(struct net_device___67 *, struct neighbour___54 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___68 *, struct netlink_callback___67 *, struct net_device___67 *, struct net_device___67 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___68 *, struct nlattr **, struct net_device___67 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___67 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___68 *, u32, u32, struct net_device___67 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___67 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___67 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___67 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___67 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___67 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___67 *, struct net_device___67 *);
	void (*ndo_dfwd_del_station)(struct net_device___67 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___67 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___67 *);
	int (*ndo_change_proto_down)(struct net_device___67 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___67 *, struct sk_buff___68 *);
	void (*ndo_set_rx_headroom)(struct net_device___67 *, int);
	int (*ndo_bpf)(struct net_device___67 *, struct netdev_bpf___67 *);
	int (*ndo_xdp_xmit)(struct net_device___67 *, int, struct xdp_frame___67 **, u32);
	struct net_device___67 * (*ndo_xdp_get_xmit_slave)(struct net_device___67 *, struct xdp_buff___67 *);
	int (*ndo_xsk_wakeup)(struct net_device___67 *, u32, u32);
	struct devlink_port___6 * (*ndo_get_devlink_port)(struct net_device___67 *);
	int (*ndo_tunnel_ctl)(struct net_device___67 *, struct ip_tunnel_parm *, int);
	struct net_device___67 * (*ndo_get_peer_dev)(struct net_device___67 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___67 *, struct net_device_path___67 *);
};

struct neigh_parms___54 {
	possible_net_t___67 net;
	struct net_device___67 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___54 *);
	struct neigh_table___54 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct devlink___6;

struct devlink_rate___6;

struct devlink_port___6 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___6 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set;
	u8 switch_port;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___6 *devlink_rate;
};

struct ethtool_ops___29 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___67 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___67 *);
	void (*get_regs)(struct net_device___67 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___67 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___67 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___67 *);
	void (*set_msglevel)(struct net_device___67 *, u32);
	int (*nway_reset)(struct net_device___67 *);
	u32 (*get_link)(struct net_device___67 *);
	int (*get_link_ext_state)(struct net_device___67 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___67 *);
	int (*get_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___67 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___67 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___67 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___67 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___67 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___67 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___67 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___67 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___67 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___67 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___67 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___67 *);
	void (*complete)(struct net_device___67 *);
	u32 (*get_priv_flags)(struct net_device___67 *);
	int (*set_priv_flags)(struct net_device___67 *, u32);
	int (*get_sset_count)(struct net_device___67 *, int);
	int (*get_rxnfc)(struct net_device___67 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___67 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___67 *, struct ethtool_flash *);
	int (*reset)(struct net_device___67 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___67 *);
	u32 (*get_rxfh_indir_size)(struct net_device___67 *);
	int (*get_rxfh)(struct net_device___67 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___67 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___67 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___67 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___67 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___67 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___67 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___67 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___67 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___67 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___67 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___67 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___67 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___67 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___67 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___67 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___67 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___67 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___67 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___67 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___67 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___67 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___67 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___67 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___67 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___67 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___67 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___67 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___67 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___67 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___67 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___54 {
	u32 (*l3mdev_fib_table)(const struct net_device___67 *);
	struct sk_buff___68 * (*l3mdev_l3_rcv)(struct net_device___67 *, struct sk_buff___68 *, u16);
	struct sk_buff___68 * (*l3mdev_l3_out)(struct net_device___67 *, struct sock___54 *, struct sk_buff___68 *, u16);
	struct dst_entry___54 * (*l3mdev_link_scope_lookup)(const struct net_device___67 *, struct flowi6 *);
};

struct ndisc_ops___38 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___67 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___67 *, struct neighbour___54 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___67 *, u8, struct neighbour___54 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___67 *, struct sk_buff___68 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___72 *, struct net_device___67 *, const struct prefix_info *, struct inet6_dev___38 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___38;

struct inet6_dev___38 {
	struct net_device___67 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___38 *mc_list;
	struct ifmcaddr6___38 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___67 mc_query_queue;
	struct sk_buff_head___67 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___10 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___54 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___61;

struct tcf_block___61;

struct mini_Qdisc___61 {
	struct tcf_proto___61 *filter_list;
	struct tcf_block___61 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___61 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___67 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___67 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___72 *, struct net_device___67 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___67 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___67 *, struct list_head *);
	size_t (*get_size)(const struct net_device___67 *);
	int (*fill_info)(struct sk_buff___68 *, const struct net_device___67 *);
	size_t (*get_xstats_size)(const struct net_device___67 *);
	int (*fill_xstats)(struct sk_buff___68 *, const struct net_device___67 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___67 *, struct net_device___67 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___67 *, const struct net_device___67 *);
	int (*fill_slave_info)(struct sk_buff___68 *, const struct net_device___67 *, const struct net_device___67 *);
	struct net___72 * (*get_link_net)(const struct net_device___67 *);
	size_t (*get_linkxstats_size)(const struct net_device___67 *, int);
	int (*fill_linkxstats)(struct sk_buff___68 *, const struct net_device___67 *, int *, int);
};

struct block_device_operations___149;

struct gendisk___152 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___152 *part0;
	const struct block_device_operations___149 *fops;
	struct request_queue___149 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___135 *bdi;
	struct kobject___246 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___246 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___149 {
	struct bio___149 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___175 *bip_vec;
	struct bio_vec___175 bip_inline_vecs[0];
};

struct blkcg___137;

struct blkg_policy_data___137;

struct blkcg_gq___137 {
	struct request_queue___149 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___137 *blkcg;
	struct blkcg_gq___137 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___137 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___149 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___149(struct request___149 *);

typedef void integrity_complete_fn___149(struct request___149 *, unsigned int);

struct blk_integrity_profile___149 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___149 *prepare_fn;
	integrity_complete_fn___149 *complete_fn;
	const char *name;
};

struct block_device_operations___149 {
	blk_qc_t (*submit_bio)(struct bio___149 *);
	int (*open)(struct block_device___152 *, fmode_t);
	void (*release)(struct gendisk___152 *, fmode_t);
	int (*rw_page)(struct block_device___152 *, sector_t, struct page___263 *, unsigned int);
	int (*ioctl)(struct block_device___152 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___152 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___152 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___152 *);
	int (*getgeo)(struct block_device___152 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___152 *, bool);
	void (*swap_slot_free_notify)(struct block_device___152 *, long unsigned int);
	int (*report_zones)(struct gendisk___152 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___152 *, umode_t *);
	struct module___242 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___152 *, sector_t *);
};

typedef void rq_end_io_fn___149(struct request___149 *, blk_status_t);

struct request___149 {
	struct request_queue___149 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___144 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___149 *bio;
	struct bio___149 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___175 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___149 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___149 *saved_end_io;
		} flush;
	};
	struct gendisk___152 *rq_disk;
	struct block_device___152 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___149 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___144 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___149 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___246 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___258 *debugfs_dir;
	struct dentry___258 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___149;

struct elevator_mq_ops___149 {
	int (*init_sched)(struct request_queue___149 *, struct elevator_type___149 *);
	void (*exit_sched)(struct elevator_queue___149 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___144 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___144 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___144 *);
	bool (*allow_merge)(struct request_queue___149 *, struct request___149 *, struct bio___149 *);
	bool (*bio_merge)(struct request_queue___149 *, struct bio___149 *, unsigned int);
	int (*request_merge)(struct request_queue___149 *, struct request___149 **, struct bio___149 *);
	void (*request_merged)(struct request_queue___149 *, struct request___149 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___149 *, struct request___149 *, struct request___149 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___149 *);
	void (*finish_request)(struct request___149 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___144 *, struct list_head *, bool);
	struct request___149 * (*dispatch_request)(struct blk_mq_hw_ctx___144 *);
	bool (*has_work)(struct blk_mq_hw_ctx___144 *);
	void (*completed_request)(struct request___149 *, u64);
	void (*requeue_request)(struct request___149 *);
	struct request___149 * (*former_request)(struct request_queue___149 *, struct request___149 *);
	struct request___149 * (*next_request)(struct request_queue___149 *, struct request___149 *);
	void (*init_icq)(struct io_cq___149 *);
	void (*exit_icq)(struct io_cq___149 *);
};

struct elv_fs_entry___149;

struct elevator_type___149 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___149 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___149 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___242 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___149 {
	struct elevator_type___149 *type;
	void *elevator_data;
	struct kobject___246 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___149 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___149 *, char *);
	ssize_t (*store)(struct elevator_queue___149 *, const char *, size_t);
};

struct blk_mq_queue_data___144;

struct blk_mq_ops___144 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___144 *, const struct blk_mq_queue_data___144 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___144 *);
	int (*get_budget)(struct request_queue___149 *);
	void (*put_budget)(struct request_queue___149 *, int);
	void (*set_rq_budget_token)(struct request___149 *, int);
	int (*get_rq_budget_token)(struct request___149 *);
	enum blk_eh_timer_return (*timeout)(struct request___149 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___144 *);
	void (*complete)(struct request___149 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___144 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___144 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___144 *, struct request___149 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___144 *, struct request___149 *, unsigned int);
	void (*initialize_rq_fn)(struct request___149 *);
	void (*cleanup_rq)(struct request___149 *);
	bool (*busy)(struct request_queue___149 *);
	int (*map_queues)(struct blk_mq_tag_set___144 *);
	void (*show_rq)(struct seq_file___233 *, struct request___149 *);
};

struct blk_mq_tag_set___144 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___144 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___144 {
	struct request___149 *rq;
	bool last;
};

struct blkcg_policy_data___137;

struct blkcg___137 {
	struct cgroup_subsys_state___185 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___137 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___137 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___137 {
	struct blkcg___137 *blkcg;
	int plid;
};

struct blkg_policy_data___137 {
	struct blkcg_gq___137 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___123 {
	struct mem_cgroup___123 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___123 {
	struct lruvec___131 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___123 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___123 *memcg;
};

struct obj_cgroup___123 {
	struct percpu_ref refcnt;
	struct mem_cgroup___123 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___61 {
	spinlock_t *lock;
	struct sk_buff___68 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___61;

struct Qdisc_ops___61 {
	struct Qdisc_ops___61 *next;
	const struct Qdisc_class_ops___61 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___68 *, struct Qdisc___61 *, struct sk_buff___68 **);
	struct sk_buff___68 * (*dequeue)(struct Qdisc___61 *);
	struct sk_buff___68 * (*peek)(struct Qdisc___61 *);
	int (*init)(struct Qdisc___61 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___61 *);
	void (*destroy)(struct Qdisc___61 *);
	int (*change)(struct Qdisc___61 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___61 *);
	int (*change_tx_queue_len)(struct Qdisc___61 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___61 *, unsigned int);
	int (*dump)(struct Qdisc___61 *, struct sk_buff___68 *);
	int (*dump_stats)(struct Qdisc___61 *, struct gnet_dump___61 *);
	void (*ingress_block_set)(struct Qdisc___61 *, u32);
	void (*egress_block_set)(struct Qdisc___61 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___61 *);
	u32 (*egress_block_get)(struct Qdisc___61 *);
	struct module___242 *owner;
};

struct Qdisc_class_ops___61 {
	unsigned int flags;
	struct netdev_queue___67 * (*select_queue)(struct Qdisc___61 *, struct tcmsg *);
	int (*graft)(struct Qdisc___61 *, long unsigned int, struct Qdisc___61 *, struct Qdisc___61 **, struct netlink_ext_ack *);
	struct Qdisc___61 * (*leaf)(struct Qdisc___61 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___61 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___61 *, u32);
	int (*change)(struct Qdisc___61 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___61 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___61 *, struct qdisc_walker *);
	struct tcf_block___61 * (*tcf_block)(struct Qdisc___61 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___61 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___61 *, long unsigned int);
	int (*dump)(struct Qdisc___61 *, long unsigned int, struct sk_buff___68 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___61 *, long unsigned int, struct gnet_dump___61 *);
};

struct tcf_chain___61;

struct tcf_block___61 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___72 *net;
	struct Qdisc___61 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___61 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___61;

struct tcf_proto_ops___61;

struct tcf_proto___61 {
	struct tcf_proto___61 *next;
	void *root;
	int (*classify)(struct sk_buff___68 *, const struct tcf_proto___61 *, struct tcf_result___61 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___61 *ops;
	struct tcf_chain___61 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___61 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___61 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___61 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___68 *, const struct tcf_proto___61 *, struct tcf_result___61 *);
	int (*init)(struct tcf_proto___61 *);
	void (*destroy)(struct tcf_proto___61 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___61 *, u32);
	void (*put)(struct tcf_proto___61 *, void *);
	int (*change)(struct net___72 *, struct sk_buff___68 *, struct tcf_proto___61 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___61 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___61 *);
	void (*walk)(struct tcf_proto___61 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___61 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___61 *, void *);
	void (*hw_del)(struct tcf_proto___61 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___72 *, struct tcf_chain___61 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___72 *, struct tcf_proto___61 *, void *, struct sk_buff___68 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___72 *, struct tcf_proto___61 *, void *, struct sk_buff___68 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___68 *, struct net___72 *, void *);
	struct module___242 *owner;
	int flags;
};

struct tcf_chain___61 {
	struct mutex filter_chain_lock;
	struct tcf_proto___61 *filter_chain;
	struct list_head list;
	struct tcf_block___61 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___61 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___54 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___61 *prog;
};

struct pneigh_entry___54;

struct neigh_hash_table___54;

struct neigh_table___54 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___67 *, __u32 *);
	bool (*key_eq)(const struct neighbour___54 *, const void *);
	int (*constructor)(struct neighbour___54 *);
	int (*pconstructor)(struct pneigh_entry___54 *);
	void (*pdestructor)(struct pneigh_entry___54 *);
	void (*proxy_redo)(struct sk_buff___68 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___67 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___54 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___67 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___54 *nht;
	struct pneigh_entry___54 **phash_buckets;
};

struct neigh_ops___54 {
	int family;
	void (*solicit)(struct neighbour___54 *, struct sk_buff___68 *);
	void (*error_report)(struct neighbour___54 *, struct sk_buff___68 *);
	int (*output)(struct neighbour___54 *, struct sk_buff___68 *);
	int (*connected_output)(struct neighbour___54 *, struct sk_buff___68 *);
};

struct pneigh_entry___54 {
	struct pneigh_entry___54 *next;
	possible_net_t___67 net;
	struct net_device___67 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___54 {
	struct neighbour___54 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___32 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___72 *, struct sock___54 *, struct sk_buff___68 *);
	int (*orig_input)(struct sk_buff___68 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___54 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___54 *ctarget;
	struct net___72 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___54 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___54 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___41;

struct timewait_sock_ops___40;

struct proto___54 {
	void (*close)(struct sock___54 *, long int);
	int (*pre_connect)(struct sock___54 *, struct sockaddr *, int);
	int (*connect)(struct sock___54 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___54 *, int);
	struct sock___54 * (*accept)(struct sock___54 *, int, int *, bool);
	int (*ioctl)(struct sock___54 *, int, long unsigned int);
	int (*init)(struct sock___54 *);
	void (*destroy)(struct sock___54 *);
	void (*shutdown)(struct sock___54 *, int);
	int (*setsockopt)(struct sock___54 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___54 *, int, int, char *, int *);
	void (*keepalive)(struct sock___54 *, int);
	int (*compat_ioctl)(struct sock___54 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___54 *, struct msghdr___56 *, size_t);
	int (*recvmsg)(struct sock___54 *, struct msghdr___56 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___54 *, struct page___263 *, int, size_t, int);
	int (*bind)(struct sock___54 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___54 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___54 *, struct sk_buff___68 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___54 *);
	int (*hash)(struct sock___54 *);
	void (*unhash)(struct sock___54 *);
	void (*rehash)(struct sock___54 *);
	int (*get_port)(struct sock___54 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___54 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___54 *, int);
	bool (*sock_is_readable)(struct sock___54 *);
	void (*enter_memory_pressure)(struct sock___54 *);
	void (*leave_memory_pressure)(struct sock___54 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___41 *rsk_prot;
	struct timewait_sock_ops___40 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___242 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___54 *, int);
};

struct request_sock___42;

struct request_sock_ops___41 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___54 *, struct request_sock___42 *);
	void (*send_ack)(const struct sock___54 *, struct sk_buff___68 *, struct request_sock___42 *);
	void (*send_reset)(const struct sock___54 *, struct sk_buff___68 *);
	void (*destructor)(struct request_sock___42 *);
	void (*syn_ack_timeout)(const struct request_sock___42 *);
};

struct timewait_sock_ops___40 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___54 *, struct sock___54 *, void *);
	void (*twsk_destructor)(struct sock___54 *);
};

struct request_sock___42 {
	struct sock_common___54 __req_common;
	struct request_sock___42 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___41 *rsk_ops;
	struct sock___54 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___38 {
	struct in6_addr mca_addr;
	struct inet6_dev___38 *idev;
	struct ifmcaddr6___38 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct rdma_cgroup___4 {
	struct cgroup_subsys_state___185 css;
	struct list_head rpools;
};

struct rdma_restrack_entry___3 {
	bool valid;
	u8 no_track: 1;
	struct kref kref;
	struct completion comp;
	struct task_struct___265 *task;
	const char *kern_name;
	enum rdma_restrack_type type;
	bool user;
	u32 id;
};

struct rdma_link_ops___3 {
	struct list_head list;
	const char *type;
	int (*newlink)(const char *, struct net_device___67 *);
};

struct ib_device___3;

struct rdma_counter___3 {
	struct rdma_restrack_entry___3 res;
	struct ib_device___3 *device;
	uint32_t id;
	struct kref kref;
	struct rdma_counter_mode mode;
	struct mutex lock;
	struct rdma_hw_stats *stats;
	u32 port;
};

struct ib_qp___3;

struct ib_send_wr___3;

struct ib_recv_wr___3;

struct ib_cq___3;

struct ib_wc___3;

struct ib_srq___3;

struct rdma_netdev_alloc_params___3;

struct ib_gid_attr___3;

struct ib_ucontext___3;

struct rdma_user_mmap_entry___3;

struct ib_pd___3;

struct ib_ah___3;

struct rdma_ah_init_attr___3;

struct rdma_ah_attr___3;

struct ib_srq_init_attr___3;

struct ib_qp_init_attr___3;

struct ib_qp_attr___3;

struct ib_mr___3;

struct ib_mw___3;

struct ib_xrcd___3;

struct ib_flow___3;

struct ib_flow_attr___3;

struct ib_flow_action___3;

struct ib_flow_action_attrs_esp___3;

struct ib_wq___3;

struct ib_wq_init_attr___3;

struct ib_rwq_ind_table___3;

struct ib_rwq_ind_table_init_attr___3;

struct ib_dm___3;

struct ib_counters___3;

struct ib_device_ops___3 {
	struct module___242 *owner;
	enum rdma_driver_id driver_id;
	u32 uverbs_abi_ver;
	unsigned int uverbs_no_driver_id_binding: 1;
	long: 63;
	long: 64;
	long: 64;
	const struct attribute_group___246 *device_group;
	const struct attribute_group___246 **port_groups;
	int (*post_send)(struct ib_qp___3 *, const struct ib_send_wr___3 *, const struct ib_send_wr___3 **);
	int (*post_recv)(struct ib_qp___3 *, const struct ib_recv_wr___3 *, const struct ib_recv_wr___3 **);
	void (*drain_rq)(struct ib_qp___3 *);
	void (*drain_sq)(struct ib_qp___3 *);
	int (*poll_cq)(struct ib_cq___3 *, int, struct ib_wc___3 *);
	int (*peek_cq)(struct ib_cq___3 *, int);
	int (*req_notify_cq)(struct ib_cq___3 *, enum ib_cq_notify_flags);
	int (*post_srq_recv)(struct ib_srq___3 *, const struct ib_recv_wr___3 *, const struct ib_recv_wr___3 **);
	int (*process_mad)(struct ib_device___3 *, int, u32, const struct ib_wc___3 *, const struct ib_grh *, const struct ib_mad *, struct ib_mad *, size_t *, u16 *);
	int (*query_device)(struct ib_device___3 *, struct ib_device_attr *, struct ib_udata *);
	int (*modify_device)(struct ib_device___3 *, int, struct ib_device_modify *);
	void (*get_dev_fw_str)(struct ib_device___3 *, char *);
	const struct cpumask * (*get_vector_affinity)(struct ib_device___3 *, int);
	int (*query_port)(struct ib_device___3 *, u32, struct ib_port_attr *);
	int (*modify_port)(struct ib_device___3 *, u32, int, struct ib_port_modify *);
	int (*get_port_immutable)(struct ib_device___3 *, u32, struct ib_port_immutable *);
	enum rdma_link_layer (*get_link_layer)(struct ib_device___3 *, u32);
	struct net_device___67 * (*get_netdev)(struct ib_device___3 *, u32);
	struct net_device___67 * (*alloc_rdma_netdev)(struct ib_device___3 *, u32, enum rdma_netdev_t, const char *, unsigned char, void (*)(struct net_device___67 *));
	int (*rdma_netdev_get_params)(struct ib_device___3 *, u32, enum rdma_netdev_t, struct rdma_netdev_alloc_params___3 *);
	int (*query_gid)(struct ib_device___3 *, u32, int, union ib_gid *);
	int (*add_gid)(const struct ib_gid_attr___3 *, void **);
	int (*del_gid)(const struct ib_gid_attr___3 *, void **);
	int (*query_pkey)(struct ib_device___3 *, u32, u16, u16 *);
	int (*alloc_ucontext)(struct ib_ucontext___3 *, struct ib_udata *);
	void (*dealloc_ucontext)(struct ib_ucontext___3 *);
	int (*mmap)(struct ib_ucontext___3 *, struct vm_area_struct___263 *);
	void (*mmap_free)(struct rdma_user_mmap_entry___3 *);
	void (*disassociate_ucontext)(struct ib_ucontext___3 *);
	int (*alloc_pd)(struct ib_pd___3 *, struct ib_udata *);
	int (*dealloc_pd)(struct ib_pd___3 *, struct ib_udata *);
	int (*create_ah)(struct ib_ah___3 *, struct rdma_ah_init_attr___3 *, struct ib_udata *);
	int (*create_user_ah)(struct ib_ah___3 *, struct rdma_ah_init_attr___3 *, struct ib_udata *);
	int (*modify_ah)(struct ib_ah___3 *, struct rdma_ah_attr___3 *);
	int (*query_ah)(struct ib_ah___3 *, struct rdma_ah_attr___3 *);
	int (*destroy_ah)(struct ib_ah___3 *, u32);
	int (*create_srq)(struct ib_srq___3 *, struct ib_srq_init_attr___3 *, struct ib_udata *);
	int (*modify_srq)(struct ib_srq___3 *, struct ib_srq_attr *, enum ib_srq_attr_mask, struct ib_udata *);
	int (*query_srq)(struct ib_srq___3 *, struct ib_srq_attr *);
	int (*destroy_srq)(struct ib_srq___3 *, struct ib_udata *);
	int (*create_qp)(struct ib_qp___3 *, struct ib_qp_init_attr___3 *, struct ib_udata *);
	int (*modify_qp)(struct ib_qp___3 *, struct ib_qp_attr___3 *, int, struct ib_udata *);
	int (*query_qp)(struct ib_qp___3 *, struct ib_qp_attr___3 *, int, struct ib_qp_init_attr___3 *);
	int (*destroy_qp)(struct ib_qp___3 *, struct ib_udata *);
	int (*create_cq)(struct ib_cq___3 *, const struct ib_cq_init_attr *, struct ib_udata *);
	int (*modify_cq)(struct ib_cq___3 *, u16, u16);
	int (*destroy_cq)(struct ib_cq___3 *, struct ib_udata *);
	int (*resize_cq)(struct ib_cq___3 *, int, struct ib_udata *);
	struct ib_mr___3 * (*get_dma_mr)(struct ib_pd___3 *, int);
	struct ib_mr___3 * (*reg_user_mr)(struct ib_pd___3 *, u64, u64, u64, int, struct ib_udata *);
	struct ib_mr___3 * (*reg_user_mr_dmabuf)(struct ib_pd___3 *, u64, u64, u64, int, int, struct ib_udata *);
	struct ib_mr___3 * (*rereg_user_mr)(struct ib_mr___3 *, int, u64, u64, u64, int, struct ib_pd___3 *, struct ib_udata *);
	int (*dereg_mr)(struct ib_mr___3 *, struct ib_udata *);
	struct ib_mr___3 * (*alloc_mr)(struct ib_pd___3 *, enum ib_mr_type, u32);
	struct ib_mr___3 * (*alloc_mr_integrity)(struct ib_pd___3 *, u32, u32);
	int (*advise_mr)(struct ib_pd___3 *, enum ib_uverbs_advise_mr_advice, u32, struct ib_sge *, u32, struct uverbs_attr_bundle *);
	int (*map_mr_sg)(struct ib_mr___3 *, struct scatterlist *, int, unsigned int *);
	int (*check_mr_status)(struct ib_mr___3 *, u32, struct ib_mr_status *);
	int (*alloc_mw)(struct ib_mw___3 *, struct ib_udata *);
	int (*dealloc_mw)(struct ib_mw___3 *);
	int (*attach_mcast)(struct ib_qp___3 *, union ib_gid *, u16);
	int (*detach_mcast)(struct ib_qp___3 *, union ib_gid *, u16);
	int (*alloc_xrcd)(struct ib_xrcd___3 *, struct ib_udata *);
	int (*dealloc_xrcd)(struct ib_xrcd___3 *, struct ib_udata *);
	struct ib_flow___3 * (*create_flow)(struct ib_qp___3 *, struct ib_flow_attr___3 *, struct ib_udata *);
	int (*destroy_flow)(struct ib_flow___3 *);
	struct ib_flow_action___3 * (*create_flow_action_esp)(struct ib_device___3 *, const struct ib_flow_action_attrs_esp___3 *, struct uverbs_attr_bundle *);
	int (*destroy_flow_action)(struct ib_flow_action___3 *);
	int (*modify_flow_action_esp)(struct ib_flow_action___3 *, const struct ib_flow_action_attrs_esp___3 *, struct uverbs_attr_bundle *);
	int (*set_vf_link_state)(struct ib_device___3 *, int, u32, int);
	int (*get_vf_config)(struct ib_device___3 *, int, u32, struct ifla_vf_info *);
	int (*get_vf_stats)(struct ib_device___3 *, int, u32, struct ifla_vf_stats *);
	int (*get_vf_guid)(struct ib_device___3 *, int, u32, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*set_vf_guid)(struct ib_device___3 *, int, u32, u64, int);
	struct ib_wq___3 * (*create_wq)(struct ib_pd___3 *, struct ib_wq_init_attr___3 *, struct ib_udata *);
	int (*destroy_wq)(struct ib_wq___3 *, struct ib_udata *);
	int (*modify_wq)(struct ib_wq___3 *, struct ib_wq_attr *, u32, struct ib_udata *);
	int (*create_rwq_ind_table)(struct ib_rwq_ind_table___3 *, struct ib_rwq_ind_table_init_attr___3 *, struct ib_udata *);
	int (*destroy_rwq_ind_table)(struct ib_rwq_ind_table___3 *);
	struct ib_dm___3 * (*alloc_dm)(struct ib_device___3 *, struct ib_ucontext___3 *, struct ib_dm_alloc_attr *, struct uverbs_attr_bundle *);
	int (*dealloc_dm)(struct ib_dm___3 *, struct uverbs_attr_bundle *);
	struct ib_mr___3 * (*reg_dm_mr)(struct ib_pd___3 *, struct ib_dm___3 *, struct ib_dm_mr_attr *, struct uverbs_attr_bundle *);
	int (*create_counters)(struct ib_counters___3 *, struct uverbs_attr_bundle *);
	int (*destroy_counters)(struct ib_counters___3 *);
	int (*read_counters)(struct ib_counters___3 *, struct ib_counters_read_attr *, struct uverbs_attr_bundle *);
	int (*map_mr_sg_pi)(struct ib_mr___3 *, struct scatterlist *, int, unsigned int *, struct scatterlist *, int, unsigned int *);
	struct rdma_hw_stats * (*alloc_hw_device_stats)(struct ib_device___3 *);
	struct rdma_hw_stats * (*alloc_hw_port_stats)(struct ib_device___3 *, u32);
	int (*get_hw_stats)(struct ib_device___3 *, struct rdma_hw_stats *, u32, int);
	int (*fill_res_mr_entry)(struct sk_buff___68 *, struct ib_mr___3 *);
	int (*fill_res_mr_entry_raw)(struct sk_buff___68 *, struct ib_mr___3 *);
	int (*fill_res_cq_entry)(struct sk_buff___68 *, struct ib_cq___3 *);
	int (*fill_res_cq_entry_raw)(struct sk_buff___68 *, struct ib_cq___3 *);
	int (*fill_res_qp_entry)(struct sk_buff___68 *, struct ib_qp___3 *);
	int (*fill_res_qp_entry_raw)(struct sk_buff___68 *, struct ib_qp___3 *);
	int (*fill_res_cm_id_entry)(struct sk_buff___68 *, struct rdma_cm_id *);
	int (*enable_driver)(struct ib_device___3 *);
	void (*dealloc_driver)(struct ib_device___3 *);
	void (*iw_add_ref)(struct ib_qp___3 *);
	void (*iw_rem_ref)(struct ib_qp___3 *);
	struct ib_qp___3 * (*iw_get_qp)(struct ib_device___3 *, int);
	int (*iw_connect)(struct iw_cm_id *, struct iw_cm_conn_param *);
	int (*iw_accept)(struct iw_cm_id *, struct iw_cm_conn_param *);
	int (*iw_reject)(struct iw_cm_id *, const void *, u8);
	int (*iw_create_listen)(struct iw_cm_id *, int);
	int (*iw_destroy_listen)(struct iw_cm_id *);
	int (*counter_bind_qp)(struct rdma_counter___3 *, struct ib_qp___3 *);
	int (*counter_unbind_qp)(struct ib_qp___3 *);
	int (*counter_dealloc)(struct rdma_counter___3 *);
	struct rdma_hw_stats * (*counter_alloc_stats)(struct rdma_counter___3 *);
	int (*counter_update_stats)(struct rdma_counter___3 *);
	int (*fill_stat_mr_entry)(struct sk_buff___68 *, struct ib_mr___3 *);
	int (*query_ucontext)(struct ib_ucontext___3 *, struct uverbs_attr_bundle *);
	int (*get_numa_node)(struct ib_device___3 *);
	size_t size_ib_ah;
	size_t size_ib_counters;
	size_t size_ib_cq;
	size_t size_ib_mw;
	size_t size_ib_pd;
	size_t size_ib_qp;
	size_t size_ib_rwq_ind_table;
	size_t size_ib_srq;
	size_t size_ib_ucontext;
	size_t size_ib_xrcd;
};

struct ib_core_device___3 {
	struct device___239 dev;
	possible_net_t___67 rdma_net;
	struct kobject___246 *ports_kobj;
	struct list_head port_list;
	struct ib_device___3 *owner;
};

struct ib_port_data___3;

struct ib_device___3 {
	struct device___239 *dma_device;
	struct ib_device_ops___3 ops;
	char name[64];
	struct callback_head callback_head;
	struct list_head event_handler_list;
	struct rw_semaphore event_handler_rwsem;
	spinlock_t qp_open_list_lock;
	struct rw_semaphore client_data_rwsem;
	struct xarray client_data;
	struct mutex unregistration_lock;
	rwlock_t cache_lock;
	struct ib_port_data___3 *port_data;
	int num_comp_vectors;
	union {
		struct device___239 dev;
		struct ib_core_device___3 coredev;
	};
	const struct attribute_group___246 *groups[4];
	u64 uverbs_cmd_mask;
	char node_desc[64];
	__be64 node_guid;
	u32 local_dma_lkey;
	u16 is_switch: 1;
	u16 kverbs_provider: 1;
	u16 use_cq_dim: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 node_type;
	u32 phys_port_cnt;
	struct ib_device_attr attrs;
	struct hw_stats_device_data *hw_stats_data;
	struct rdmacg_device cg_device;
	u32 index;
	spinlock_t cq_pools_lock;
	struct list_head cq_pools[3];
	struct rdma_restrack_root *res;
	const struct uapi_definition *driver_def;
	refcount_t refcount;
	struct completion unreg_completion;
	struct work_struct unregistration_work;
	const struct rdma_link_ops___3 *link_ops;
	struct mutex compat_devs_mutex;
	struct xarray compat_devs;
	char iw_ifname[16];
	u32 iw_driver_flags;
	u32 lag_flags;
};

struct ib_gid_attr___3 {
	struct net_device___67 *ndev;
	struct ib_device___3 *device;
	union ib_gid gid;
	enum ib_gid_type gid_type;
	u16 index;
	u32 port_num;
};

typedef void (*ib_comp_handler___3)(struct ib_cq___3 *, void *);

struct ib_event___3;

struct ib_cq___3 {
	struct ib_device___3 *device;
	struct ib_ucq_object *uobject;
	ib_comp_handler___3 comp_handler;
	void (*event_handler)(struct ib_event___3 *, void *);
	void *cq_context;
	int cqe;
	unsigned int cqe_used;
	atomic_t usecnt;
	enum ib_poll_context poll_ctx;
	struct ib_wc___3 *wc;
	struct list_head pool_entry;
	union {
		struct irq_poll iop;
		struct work_struct work;
	};
	struct workqueue_struct *comp_wq;
	struct dim *dim;
	ktime_t timestamp;
	u8 interrupt: 1;
	u8 shared: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int comp_vector;
	struct rdma_restrack_entry___3 res;
};

struct ib_qp_security___3;

struct ib_qp___3 {
	struct ib_device___3 *device;
	struct ib_pd___3 *pd;
	struct ib_cq___3 *send_cq;
	struct ib_cq___3 *recv_cq;
	spinlock_t mr_lock;
	int mrs_used;
	struct list_head rdma_mrs;
	struct list_head sig_mrs;
	struct ib_srq___3 *srq;
	struct ib_xrcd___3 *xrcd;
	struct list_head xrcd_list;
	atomic_t usecnt;
	struct list_head open_list;
	struct ib_qp___3 *real_qp;
	struct ib_uqp_object *uobject;
	void (*event_handler)(struct ib_event___3 *, void *);
	void *qp_context;
	const struct ib_gid_attr___3 *av_sgid_attr;
	const struct ib_gid_attr___3 *alt_path_sgid_attr;
	u32 qp_num;
	u32 max_write_sge;
	u32 max_read_sge;
	enum ib_qp_type qp_type;
	struct ib_rwq_ind_table___3 *rwq_ind_tbl;
	struct ib_qp_security___3 *qp_sec;
	u32 port;
	bool integrity_en;
	struct rdma_restrack_entry___3 res;
	struct rdma_counter___3 *counter;
};

struct ib_srq___3 {
	struct ib_device___3 *device;
	struct ib_pd___3 *pd;
	struct ib_usrq_object *uobject;
	void (*event_handler)(struct ib_event___3 *, void *);
	void *srq_context;
	enum ib_srq_type srq_type;
	atomic_t usecnt;
	struct {
		struct ib_cq___3 *cq;
		union {
			struct {
				struct ib_xrcd___3 *xrcd;
				u32 srq_num;
			} xrc;
		};
	} ext;
	struct rdma_restrack_entry___3 res;
};

struct ib_wq___3 {
	struct ib_device___3 *device;
	struct ib_uwq_object *uobject;
	void *wq_context;
	void (*event_handler)(struct ib_event___3 *, void *);
	struct ib_pd___3 *pd;
	struct ib_cq___3 *cq;
	u32 wq_num;
	enum ib_wq_state state;
	enum ib_wq_type wq_type;
	atomic_t usecnt;
};

struct ib_event___3 {
	struct ib_device___3 *device;
	union {
		struct ib_cq___3 *cq;
		struct ib_qp___3 *qp;
		struct ib_srq___3 *srq;
		struct ib_wq___3 *wq;
		u32 port_num;
	} element;
	enum ib_event_type event;
};

struct ib_global_route___3 {
	const struct ib_gid_attr___3 *sgid_attr;
	union ib_gid dgid;
	u32 flow_label;
	u8 sgid_index;
	u8 hop_limit;
	u8 traffic_class;
};

struct rdma_ah_init_attr___3 {
	struct rdma_ah_attr___3 *ah_attr;
	u32 flags;
	struct net_device___67 *xmit_slave;
};

struct rdma_ah_attr___3 {
	struct ib_global_route___3 grh;
	u8 sl;
	u8 static_rate;
	u32 port_num;
	u8 ah_flags;
	enum rdma_ah_attr_type type;
	union {
		struct ib_ah_attr ib;
		struct roce_ah_attr roce;
		struct opa_ah_attr opa;
	};
};

struct ib_cqe___3 {
	void (*done)(struct ib_cq___3 *, struct ib_wc___3 *);
};

struct ib_wc___3 {
	union {
		u64 wr_id;
		struct ib_cqe___3 *wr_cqe;
	};
	enum ib_wc_status status;
	enum ib_wc_opcode opcode;
	u32 vendor_err;
	u32 byte_len;
	struct ib_qp___3 *qp;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
	u32 src_qp;
	u32 slid;
	int wc_flags;
	u16 pkey_index;
	u8 sl;
	u8 dlid_path_bits;
	u32 port_num;
	u8 smac[6];
	u16 vlan_id;
	u8 network_hdr_type;
};

struct ib_xrcd___3 {
	struct ib_device___3 *device;
	atomic_t usecnt;
	struct inode___258 *inode;
	struct rw_semaphore tgt_qps_rwsem;
	struct xarray tgt_qps;
};

struct ib_srq_init_attr___3 {
	void (*event_handler)(struct ib_event___3 *, void *);
	void *srq_context;
	struct ib_srq_attr attr;
	enum ib_srq_type srq_type;
	struct {
		struct ib_cq___3 *cq;
		union {
			struct {
				struct ib_xrcd___3 *xrcd;
			} xrc;
			struct {
				u32 max_num_tags;
			} tag_matching;
		};
	} ext;
};

struct ib_qp_init_attr___3 {
	void (*event_handler)(struct ib_event___3 *, void *);
	void *qp_context;
	struct ib_cq___3 *send_cq;
	struct ib_cq___3 *recv_cq;
	struct ib_srq___3 *srq;
	struct ib_xrcd___3 *xrcd;
	struct ib_qp_cap cap;
	enum ib_sig_type sq_sig_type;
	enum ib_qp_type qp_type;
	u32 create_flags;
	u32 port_num;
	struct ib_rwq_ind_table___3 *rwq_ind_tbl;
	u32 source_qpn;
};

struct ib_uobject___3;

struct ib_rwq_ind_table___3 {
	struct ib_device___3 *device;
	struct ib_uobject___3 *uobject;
	atomic_t usecnt;
	u32 ind_tbl_num;
	u32 log_ind_tbl_size;
	struct ib_wq___3 **ind_tbl;
};

struct ib_qp_attr___3 {
	enum ib_qp_state qp_state;
	enum ib_qp_state cur_qp_state;
	enum ib_mtu path_mtu;
	enum ib_mig_state path_mig_state;
	u32 qkey;
	u32 rq_psn;
	u32 sq_psn;
	u32 dest_qp_num;
	int qp_access_flags;
	struct ib_qp_cap cap;
	struct rdma_ah_attr___3 ah_attr;
	struct rdma_ah_attr___3 alt_ah_attr;
	u16 pkey_index;
	u16 alt_pkey_index;
	u8 en_sqd_async_notify;
	u8 sq_draining;
	u8 max_rd_atomic;
	u8 max_dest_rd_atomic;
	u8 min_rnr_timer;
	u32 port_num;
	u8 timeout;
	u8 retry_cnt;
	u8 rnr_retry;
	u32 alt_port_num;
	u8 alt_timeout;
	u32 rate_limit;
	struct net_device___67 *xmit_slave;
};

struct ib_send_wr___3 {
	struct ib_send_wr___3 *next;
	union {
		u64 wr_id;
		struct ib_cqe___3 *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
	enum ib_wr_opcode opcode;
	int send_flags;
	union {
		__be32 imm_data;
		u32 invalidate_rkey;
	} ex;
};

struct ib_ah___3 {
	struct ib_device___3 *device;
	struct ib_pd___3 *pd;
	struct ib_uobject___3 *uobject;
	const struct ib_gid_attr___3 *sgid_attr;
	enum rdma_ah_attr_type type;
};

struct ib_mr___3 {
	struct ib_device___3 *device;
	struct ib_pd___3 *pd;
	u32 lkey;
	u32 rkey;
	u64 iova;
	u64 length;
	unsigned int page_size;
	enum ib_mr_type type;
	bool need_inval;
	union {
		struct ib_uobject___3 *uobject;
		struct list_head qp_entry;
	};
	struct ib_dm___3 *dm;
	struct ib_sig_attrs *sig_attrs;
	struct rdma_restrack_entry___3 res;
};

struct ib_recv_wr___3 {
	struct ib_recv_wr___3 *next;
	union {
		u64 wr_id;
		struct ib_cqe___3 *wr_cqe;
	};
	struct ib_sge *sg_list;
	int num_sge;
};

struct ib_rdmacg_object___3 {
	struct rdma_cgroup___4 *cg;
};

struct ib_ucontext___3 {
	struct ib_device___3 *device;
	struct ib_uverbs_file *ufile;
	struct ib_rdmacg_object___3 cg_obj;
	struct rdma_restrack_entry___3 res;
	struct xarray mmap_xa;
};

struct ib_uobject___3 {
	u64 user_handle;
	struct ib_uverbs_file *ufile;
	struct ib_ucontext___3 *context;
	void *object;
	struct list_head list;
	struct ib_rdmacg_object___3 cg_obj;
	int id;
	struct kref ref;
	atomic_t usecnt;
	struct callback_head rcu;
	const struct uverbs_api_object *uapi_object;
};

struct ib_pd___3 {
	u32 local_dma_lkey;
	u32 flags;
	struct ib_device___3 *device;
	struct ib_uobject___3 *uobject;
	atomic_t usecnt;
	u32 unsafe_global_rkey;
	struct ib_mr___3 *__internal_mr;
	struct rdma_restrack_entry___3 res;
};

struct ib_wq_init_attr___3 {
	void *wq_context;
	enum ib_wq_type wq_type;
	u32 max_wr;
	u32 max_sge;
	struct ib_cq___3 *cq;
	void (*event_handler)(struct ib_event___3 *, void *);
	u32 create_flags;
};

struct ib_rwq_ind_table_init_attr___3 {
	u32 log_ind_tbl_size;
	struct ib_wq___3 **ind_tbl;
};

struct ib_port_pkey___3 {
	enum port_pkey_state state;
	u16 pkey_index;
	u32 port_num;
	struct list_head qp_list;
	struct list_head to_error_list;
	struct ib_qp_security___3 *sec;
};

struct ib_ports_pkeys___3;

struct ib_qp_security___3 {
	struct ib_qp___3 *qp;
	struct ib_device___3 *dev;
	struct mutex mutex;
	struct ib_ports_pkeys___3 *ports_pkeys;
	struct list_head shared_qp_list;
	void *security;
	bool destroying;
	atomic_t error_list_count;
	struct completion error_complete;
	int error_comps_pending;
};

struct ib_ports_pkeys___3 {
	struct ib_port_pkey___3 main;
	struct ib_port_pkey___3 alt;
};

struct ib_dm___3 {
	struct ib_device___3 *device;
	u32 length;
	u32 flags;
	struct ib_uobject___3 *uobject;
	atomic_t usecnt;
};

struct ib_mw___3 {
	struct ib_device___3 *device;
	struct ib_pd___3 *pd;
	struct ib_uobject___3 *uobject;
	u32 rkey;
	enum ib_mw_type type;
};

struct ib_flow_spec_action_handle___3 {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_flow_action___3 *act;
};

struct ib_flow_action___3 {
	struct ib_device___3 *device;
	struct ib_uobject___3 *uobject;
	enum ib_flow_action_type type;
	atomic_t usecnt;
};

struct ib_flow_spec_action_count___3 {
	enum ib_flow_spec_type type;
	u16 size;
	struct ib_counters___3 *counters;
};

struct ib_counters___3 {
	struct ib_device___3 *device;
	struct ib_uobject___3 *uobject;
	atomic_t usecnt;
};

union ib_flow_spec___3 {
	struct {
		u32 type;
		u16 size;
	};
	struct ib_flow_spec_eth eth;
	struct ib_flow_spec_ib ib;
	struct ib_flow_spec_ipv4 ipv4;
	struct ib_flow_spec_tcp_udp tcp_udp;
	struct ib_flow_spec_ipv6 ipv6;
	struct ib_flow_spec_tunnel tunnel;
	struct ib_flow_spec_esp esp;
	struct ib_flow_spec_gre gre;
	struct ib_flow_spec_mpls mpls;
	struct ib_flow_spec_action_tag flow_tag;
	struct ib_flow_spec_action_drop drop;
	struct ib_flow_spec_action_handle___3 action;
	struct ib_flow_spec_action_count___3 flow_count;
};

struct ib_flow_attr___3 {
	enum ib_flow_attr_type type;
	u16 size;
	u16 priority;
	u32 flags;
	u8 num_of_specs;
	u32 port;
	union ib_flow_spec___3 flows[0];
};

struct ib_flow___3 {
	struct ib_qp___3 *qp;
	struct ib_device___3 *device;
	struct ib_uobject___3 *uobject;
};

struct ib_flow_spec_list___3 {
	struct ib_flow_spec_list___3 *next;
	union ib_flow_spec___3 spec;
};

struct ib_flow_action_attrs_esp___3 {
	struct ib_flow_action_attrs_esp_keymats *keymat;
	struct ib_flow_action_attrs_esp_replays *replay;
	struct ib_flow_spec_list___3 *encap;
	u32 esn;
	u32 spi;
	u32 seq;
	u32 tfc_pad;
	u64 flags;
	u64 hard_limit_pkts;
};

struct ib_port_data___3 {
	struct ib_device___3 *ib_dev;
	struct ib_port_immutable immutable;
	spinlock_t pkey_list_lock;
	spinlock_t netdev_lock;
	struct list_head pkey_list;
	struct ib_port_cache cache;
	struct net_device___67 *netdev;
	struct hlist_node ndev_hash_link;
	struct rdma_port_counter port_counter;
	struct ib_port *sysfs;
};

struct rdma_netdev_alloc_params___3 {
	size_t sizeof_priv;
	unsigned int txqs;
	unsigned int rxqs;
	void *param;
	int (*initialize_rdma_netdev)(struct ib_device___3 *, u32, struct net_device___67 *, void *);
};

struct rdma_user_mmap_entry___3 {
	struct kref ref;
	struct ib_ucontext___3 *ucontext;
	long unsigned int start_pgoff;
	size_t npages;
	bool driver_removed;
};

struct genl_ops___4;

struct genl_info___3;

struct genl_small_ops___4;

struct genl_family___4 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___4 *, struct sk_buff___68 *, struct genl_info___3 *);
	void (*post_doit)(const struct genl_ops___4 *, struct sk_buff___68 *, struct genl_info___3 *);
	const struct genl_ops___4 *ops;
	const struct genl_small_ops___4 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___242 *module;
};

struct genl_ops___4 {
	int (*doit)(struct sk_buff___68 *, struct genl_info___3 *);
	int (*start)(struct netlink_callback___67 *);
	int (*dumpit)(struct sk_buff___68 *, struct netlink_callback___67 *);
	int (*done)(struct netlink_callback___67 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___3 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___67 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___4 {
	int (*doit)(struct sk_buff___68 *, struct genl_info___3 *);
	int (*dumpit)(struct sk_buff___68 *, struct netlink_callback___67 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_dumpit_info___2 {
	const struct genl_family___4 *family;
	struct genl_ops___4 op;
	struct nlattr **attrs;
};

enum devlink_command {
	DEVLINK_CMD_UNSPEC = 0,
	DEVLINK_CMD_GET = 1,
	DEVLINK_CMD_SET = 2,
	DEVLINK_CMD_NEW = 3,
	DEVLINK_CMD_DEL = 4,
	DEVLINK_CMD_PORT_GET = 5,
	DEVLINK_CMD_PORT_SET = 6,
	DEVLINK_CMD_PORT_NEW = 7,
	DEVLINK_CMD_PORT_DEL = 8,
	DEVLINK_CMD_PORT_SPLIT = 9,
	DEVLINK_CMD_PORT_UNSPLIT = 10,
	DEVLINK_CMD_SB_GET = 11,
	DEVLINK_CMD_SB_SET = 12,
	DEVLINK_CMD_SB_NEW = 13,
	DEVLINK_CMD_SB_DEL = 14,
	DEVLINK_CMD_SB_POOL_GET = 15,
	DEVLINK_CMD_SB_POOL_SET = 16,
	DEVLINK_CMD_SB_POOL_NEW = 17,
	DEVLINK_CMD_SB_POOL_DEL = 18,
	DEVLINK_CMD_SB_PORT_POOL_GET = 19,
	DEVLINK_CMD_SB_PORT_POOL_SET = 20,
	DEVLINK_CMD_SB_PORT_POOL_NEW = 21,
	DEVLINK_CMD_SB_PORT_POOL_DEL = 22,
	DEVLINK_CMD_SB_TC_POOL_BIND_GET = 23,
	DEVLINK_CMD_SB_TC_POOL_BIND_SET = 24,
	DEVLINK_CMD_SB_TC_POOL_BIND_NEW = 25,
	DEVLINK_CMD_SB_TC_POOL_BIND_DEL = 26,
	DEVLINK_CMD_SB_OCC_SNAPSHOT = 27,
	DEVLINK_CMD_SB_OCC_MAX_CLEAR = 28,
	DEVLINK_CMD_ESWITCH_GET = 29,
	DEVLINK_CMD_ESWITCH_SET = 30,
	DEVLINK_CMD_DPIPE_TABLE_GET = 31,
	DEVLINK_CMD_DPIPE_ENTRIES_GET = 32,
	DEVLINK_CMD_DPIPE_HEADERS_GET = 33,
	DEVLINK_CMD_DPIPE_TABLE_COUNTERS_SET = 34,
	DEVLINK_CMD_RESOURCE_SET = 35,
	DEVLINK_CMD_RESOURCE_DUMP = 36,
	DEVLINK_CMD_RELOAD = 37,
	DEVLINK_CMD_PARAM_GET = 38,
	DEVLINK_CMD_PARAM_SET = 39,
	DEVLINK_CMD_PARAM_NEW = 40,
	DEVLINK_CMD_PARAM_DEL = 41,
	DEVLINK_CMD_REGION_GET = 42,
	DEVLINK_CMD_REGION_SET = 43,
	DEVLINK_CMD_REGION_NEW = 44,
	DEVLINK_CMD_REGION_DEL = 45,
	DEVLINK_CMD_REGION_READ = 46,
	DEVLINK_CMD_PORT_PARAM_GET = 47,
	DEVLINK_CMD_PORT_PARAM_SET = 48,
	DEVLINK_CMD_PORT_PARAM_NEW = 49,
	DEVLINK_CMD_PORT_PARAM_DEL = 50,
	DEVLINK_CMD_INFO_GET = 51,
	DEVLINK_CMD_HEALTH_REPORTER_GET = 52,
	DEVLINK_CMD_HEALTH_REPORTER_SET = 53,
	DEVLINK_CMD_HEALTH_REPORTER_RECOVER = 54,
	DEVLINK_CMD_HEALTH_REPORTER_DIAGNOSE = 55,
	DEVLINK_CMD_HEALTH_REPORTER_DUMP_GET = 56,
	DEVLINK_CMD_HEALTH_REPORTER_DUMP_CLEAR = 57,
	DEVLINK_CMD_FLASH_UPDATE = 58,
	DEVLINK_CMD_FLASH_UPDATE_END = 59,
	DEVLINK_CMD_FLASH_UPDATE_STATUS = 60,
	DEVLINK_CMD_TRAP_GET = 61,
	DEVLINK_CMD_TRAP_SET = 62,
	DEVLINK_CMD_TRAP_NEW = 63,
	DEVLINK_CMD_TRAP_DEL = 64,
	DEVLINK_CMD_TRAP_GROUP_GET = 65,
	DEVLINK_CMD_TRAP_GROUP_SET = 66,
	DEVLINK_CMD_TRAP_GROUP_NEW = 67,
	DEVLINK_CMD_TRAP_GROUP_DEL = 68,
	DEVLINK_CMD_TRAP_POLICER_GET = 69,
	DEVLINK_CMD_TRAP_POLICER_SET = 70,
	DEVLINK_CMD_TRAP_POLICER_NEW = 71,
	DEVLINK_CMD_TRAP_POLICER_DEL = 72,
	DEVLINK_CMD_HEALTH_REPORTER_TEST = 73,
	DEVLINK_CMD_RATE_GET = 74,
	DEVLINK_CMD_RATE_SET = 75,
	DEVLINK_CMD_RATE_NEW = 76,
	DEVLINK_CMD_RATE_DEL = 77,
	__DEVLINK_CMD_MAX = 78,
	DEVLINK_CMD_MAX = 77,
};

enum devlink_eswitch_mode {
	DEVLINK_ESWITCH_MODE_LEGACY = 0,
	DEVLINK_ESWITCH_MODE_SWITCHDEV = 1,
};

enum {
	DEVLINK_ATTR_STATS_RX_PACKETS = 0,
	DEVLINK_ATTR_STATS_RX_BYTES = 1,
	DEVLINK_ATTR_STATS_RX_DROPPED = 2,
	__DEVLINK_ATTR_STATS_MAX = 3,
	DEVLINK_ATTR_STATS_MAX = 2,
};

enum {
	DEVLINK_FLASH_OVERWRITE_SETTINGS_BIT = 0,
	DEVLINK_FLASH_OVERWRITE_IDENTIFIERS_BIT = 1,
	__DEVLINK_FLASH_OVERWRITE_MAX_BIT = 2,
	DEVLINK_FLASH_OVERWRITE_MAX_BIT = 1,
};

enum {
	DEVLINK_ATTR_TRAP_METADATA_TYPE_IN_PORT = 0,
	DEVLINK_ATTR_TRAP_METADATA_TYPE_FA_COOKIE = 1,
};

enum devlink_attr {
	DEVLINK_ATTR_UNSPEC = 0,
	DEVLINK_ATTR_BUS_NAME = 1,
	DEVLINK_ATTR_DEV_NAME = 2,
	DEVLINK_ATTR_PORT_INDEX = 3,
	DEVLINK_ATTR_PORT_TYPE = 4,
	DEVLINK_ATTR_PORT_DESIRED_TYPE = 5,
	DEVLINK_ATTR_PORT_NETDEV_IFINDEX = 6,
	DEVLINK_ATTR_PORT_NETDEV_NAME = 7,
	DEVLINK_ATTR_PORT_IBDEV_NAME = 8,
	DEVLINK_ATTR_PORT_SPLIT_COUNT = 9,
	DEVLINK_ATTR_PORT_SPLIT_GROUP = 10,
	DEVLINK_ATTR_SB_INDEX = 11,
	DEVLINK_ATTR_SB_SIZE = 12,
	DEVLINK_ATTR_SB_INGRESS_POOL_COUNT = 13,
	DEVLINK_ATTR_SB_EGRESS_POOL_COUNT = 14,
	DEVLINK_ATTR_SB_INGRESS_TC_COUNT = 15,
	DEVLINK_ATTR_SB_EGRESS_TC_COUNT = 16,
	DEVLINK_ATTR_SB_POOL_INDEX = 17,
	DEVLINK_ATTR_SB_POOL_TYPE = 18,
	DEVLINK_ATTR_SB_POOL_SIZE = 19,
	DEVLINK_ATTR_SB_POOL_THRESHOLD_TYPE = 20,
	DEVLINK_ATTR_SB_THRESHOLD = 21,
	DEVLINK_ATTR_SB_TC_INDEX = 22,
	DEVLINK_ATTR_SB_OCC_CUR = 23,
	DEVLINK_ATTR_SB_OCC_MAX = 24,
	DEVLINK_ATTR_ESWITCH_MODE = 25,
	DEVLINK_ATTR_ESWITCH_INLINE_MODE = 26,
	DEVLINK_ATTR_DPIPE_TABLES = 27,
	DEVLINK_ATTR_DPIPE_TABLE = 28,
	DEVLINK_ATTR_DPIPE_TABLE_NAME = 29,
	DEVLINK_ATTR_DPIPE_TABLE_SIZE = 30,
	DEVLINK_ATTR_DPIPE_TABLE_MATCHES = 31,
	DEVLINK_ATTR_DPIPE_TABLE_ACTIONS = 32,
	DEVLINK_ATTR_DPIPE_TABLE_COUNTERS_ENABLED = 33,
	DEVLINK_ATTR_DPIPE_ENTRIES = 34,
	DEVLINK_ATTR_DPIPE_ENTRY = 35,
	DEVLINK_ATTR_DPIPE_ENTRY_INDEX = 36,
	DEVLINK_ATTR_DPIPE_ENTRY_MATCH_VALUES = 37,
	DEVLINK_ATTR_DPIPE_ENTRY_ACTION_VALUES = 38,
	DEVLINK_ATTR_DPIPE_ENTRY_COUNTER = 39,
	DEVLINK_ATTR_DPIPE_MATCH = 40,
	DEVLINK_ATTR_DPIPE_MATCH_VALUE = 41,
	DEVLINK_ATTR_DPIPE_MATCH_TYPE = 42,
	DEVLINK_ATTR_DPIPE_ACTION = 43,
	DEVLINK_ATTR_DPIPE_ACTION_VALUE = 44,
	DEVLINK_ATTR_DPIPE_ACTION_TYPE = 45,
	DEVLINK_ATTR_DPIPE_VALUE = 46,
	DEVLINK_ATTR_DPIPE_VALUE_MASK = 47,
	DEVLINK_ATTR_DPIPE_VALUE_MAPPING = 48,
	DEVLINK_ATTR_DPIPE_HEADERS = 49,
	DEVLINK_ATTR_DPIPE_HEADER = 50,
	DEVLINK_ATTR_DPIPE_HEADER_NAME = 51,
	DEVLINK_ATTR_DPIPE_HEADER_ID = 52,
	DEVLINK_ATTR_DPIPE_HEADER_FIELDS = 53,
	DEVLINK_ATTR_DPIPE_HEADER_GLOBAL = 54,
	DEVLINK_ATTR_DPIPE_HEADER_INDEX = 55,
	DEVLINK_ATTR_DPIPE_FIELD = 56,
	DEVLINK_ATTR_DPIPE_FIELD_NAME = 57,
	DEVLINK_ATTR_DPIPE_FIELD_ID = 58,
	DEVLINK_ATTR_DPIPE_FIELD_BITWIDTH = 59,
	DEVLINK_ATTR_DPIPE_FIELD_MAPPING_TYPE = 60,
	DEVLINK_ATTR_PAD = 61,
	DEVLINK_ATTR_ESWITCH_ENCAP_MODE = 62,
	DEVLINK_ATTR_RESOURCE_LIST = 63,
	DEVLINK_ATTR_RESOURCE = 64,
	DEVLINK_ATTR_RESOURCE_NAME = 65,
	DEVLINK_ATTR_RESOURCE_ID = 66,
	DEVLINK_ATTR_RESOURCE_SIZE = 67,
	DEVLINK_ATTR_RESOURCE_SIZE_NEW = 68,
	DEVLINK_ATTR_RESOURCE_SIZE_VALID = 69,
	DEVLINK_ATTR_RESOURCE_SIZE_MIN = 70,
	DEVLINK_ATTR_RESOURCE_SIZE_MAX = 71,
	DEVLINK_ATTR_RESOURCE_SIZE_GRAN = 72,
	DEVLINK_ATTR_RESOURCE_UNIT = 73,
	DEVLINK_ATTR_RESOURCE_OCC = 74,
	DEVLINK_ATTR_DPIPE_TABLE_RESOURCE_ID = 75,
	DEVLINK_ATTR_DPIPE_TABLE_RESOURCE_UNITS = 76,
	DEVLINK_ATTR_PORT_FLAVOUR = 77,
	DEVLINK_ATTR_PORT_NUMBER = 78,
	DEVLINK_ATTR_PORT_SPLIT_SUBPORT_NUMBER = 79,
	DEVLINK_ATTR_PARAM = 80,
	DEVLINK_ATTR_PARAM_NAME = 81,
	DEVLINK_ATTR_PARAM_GENERIC = 82,
	DEVLINK_ATTR_PARAM_TYPE = 83,
	DEVLINK_ATTR_PARAM_VALUES_LIST = 84,
	DEVLINK_ATTR_PARAM_VALUE = 85,
	DEVLINK_ATTR_PARAM_VALUE_DATA = 86,
	DEVLINK_ATTR_PARAM_VALUE_CMODE = 87,
	DEVLINK_ATTR_REGION_NAME = 88,
	DEVLINK_ATTR_REGION_SIZE = 89,
	DEVLINK_ATTR_REGION_SNAPSHOTS = 90,
	DEVLINK_ATTR_REGION_SNAPSHOT = 91,
	DEVLINK_ATTR_REGION_SNAPSHOT_ID = 92,
	DEVLINK_ATTR_REGION_CHUNKS = 93,
	DEVLINK_ATTR_REGION_CHUNK = 94,
	DEVLINK_ATTR_REGION_CHUNK_DATA = 95,
	DEVLINK_ATTR_REGION_CHUNK_ADDR = 96,
	DEVLINK_ATTR_REGION_CHUNK_LEN = 97,
	DEVLINK_ATTR_INFO_DRIVER_NAME = 98,
	DEVLINK_ATTR_INFO_SERIAL_NUMBER = 99,
	DEVLINK_ATTR_INFO_VERSION_FIXED = 100,
	DEVLINK_ATTR_INFO_VERSION_RUNNING = 101,
	DEVLINK_ATTR_INFO_VERSION_STORED = 102,
	DEVLINK_ATTR_INFO_VERSION_NAME = 103,
	DEVLINK_ATTR_INFO_VERSION_VALUE = 104,
	DEVLINK_ATTR_SB_POOL_CELL_SIZE = 105,
	DEVLINK_ATTR_FMSG = 106,
	DEVLINK_ATTR_FMSG_OBJ_NEST_START = 107,
	DEVLINK_ATTR_FMSG_PAIR_NEST_START = 108,
	DEVLINK_ATTR_FMSG_ARR_NEST_START = 109,
	DEVLINK_ATTR_FMSG_NEST_END = 110,
	DEVLINK_ATTR_FMSG_OBJ_NAME = 111,
	DEVLINK_ATTR_FMSG_OBJ_VALUE_TYPE = 112,
	DEVLINK_ATTR_FMSG_OBJ_VALUE_DATA = 113,
	DEVLINK_ATTR_HEALTH_REPORTER = 114,
	DEVLINK_ATTR_HEALTH_REPORTER_NAME = 115,
	DEVLINK_ATTR_HEALTH_REPORTER_STATE = 116,
	DEVLINK_ATTR_HEALTH_REPORTER_ERR_COUNT = 117,
	DEVLINK_ATTR_HEALTH_REPORTER_RECOVER_COUNT = 118,
	DEVLINK_ATTR_HEALTH_REPORTER_DUMP_TS = 119,
	DEVLINK_ATTR_HEALTH_REPORTER_GRACEFUL_PERIOD = 120,
	DEVLINK_ATTR_HEALTH_REPORTER_AUTO_RECOVER = 121,
	DEVLINK_ATTR_FLASH_UPDATE_FILE_NAME = 122,
	DEVLINK_ATTR_FLASH_UPDATE_COMPONENT = 123,
	DEVLINK_ATTR_FLASH_UPDATE_STATUS_MSG = 124,
	DEVLINK_ATTR_FLASH_UPDATE_STATUS_DONE = 125,
	DEVLINK_ATTR_FLASH_UPDATE_STATUS_TOTAL = 126,
	DEVLINK_ATTR_PORT_PCI_PF_NUMBER = 127,
	DEVLINK_ATTR_PORT_PCI_VF_NUMBER = 128,
	DEVLINK_ATTR_STATS = 129,
	DEVLINK_ATTR_TRAP_NAME = 130,
	DEVLINK_ATTR_TRAP_ACTION = 131,
	DEVLINK_ATTR_TRAP_TYPE = 132,
	DEVLINK_ATTR_TRAP_GENERIC = 133,
	DEVLINK_ATTR_TRAP_METADATA = 134,
	DEVLINK_ATTR_TRAP_GROUP_NAME = 135,
	DEVLINK_ATTR_RELOAD_FAILED = 136,
	DEVLINK_ATTR_HEALTH_REPORTER_DUMP_TS_NS = 137,
	DEVLINK_ATTR_NETNS_FD = 138,
	DEVLINK_ATTR_NETNS_PID = 139,
	DEVLINK_ATTR_NETNS_ID = 140,
	DEVLINK_ATTR_HEALTH_REPORTER_AUTO_DUMP = 141,
	DEVLINK_ATTR_TRAP_POLICER_ID = 142,
	DEVLINK_ATTR_TRAP_POLICER_RATE = 143,
	DEVLINK_ATTR_TRAP_POLICER_BURST = 144,
	DEVLINK_ATTR_PORT_FUNCTION = 145,
	DEVLINK_ATTR_INFO_BOARD_SERIAL_NUMBER = 146,
	DEVLINK_ATTR_PORT_LANES = 147,
	DEVLINK_ATTR_PORT_SPLITTABLE = 148,
	DEVLINK_ATTR_PORT_EXTERNAL = 149,
	DEVLINK_ATTR_PORT_CONTROLLER_NUMBER = 150,
	DEVLINK_ATTR_FLASH_UPDATE_STATUS_TIMEOUT = 151,
	DEVLINK_ATTR_FLASH_UPDATE_OVERWRITE_MASK = 152,
	DEVLINK_ATTR_RELOAD_ACTION = 153,
	DEVLINK_ATTR_RELOAD_ACTIONS_PERFORMED = 154,
	DEVLINK_ATTR_RELOAD_LIMITS = 155,
	DEVLINK_ATTR_DEV_STATS = 156,
	DEVLINK_ATTR_RELOAD_STATS = 157,
	DEVLINK_ATTR_RELOAD_STATS_ENTRY = 158,
	DEVLINK_ATTR_RELOAD_STATS_LIMIT = 159,
	DEVLINK_ATTR_RELOAD_STATS_VALUE = 160,
	DEVLINK_ATTR_REMOTE_RELOAD_STATS = 161,
	DEVLINK_ATTR_RELOAD_ACTION_INFO = 162,
	DEVLINK_ATTR_RELOAD_ACTION_STATS = 163,
	DEVLINK_ATTR_PORT_PCI_SF_NUMBER = 164,
	DEVLINK_ATTR_RATE_TYPE = 165,
	DEVLINK_ATTR_RATE_TX_SHARE = 166,
	DEVLINK_ATTR_RATE_TX_MAX = 167,
	DEVLINK_ATTR_RATE_NODE_NAME = 168,
	DEVLINK_ATTR_RATE_PARENT_NODE_NAME = 169,
	__DEVLINK_ATTR_MAX = 170,
	DEVLINK_ATTR_MAX = 169,
};

enum devlink_dpipe_match_type {
	DEVLINK_DPIPE_MATCH_TYPE_FIELD_EXACT = 0,
};

enum devlink_dpipe_action_type {
	DEVLINK_DPIPE_ACTION_TYPE_FIELD_MODIFY = 0,
};

enum devlink_dpipe_field_ethernet_id {
	DEVLINK_DPIPE_FIELD_ETHERNET_DST_MAC = 0,
};

enum devlink_dpipe_field_ipv4_id {
	DEVLINK_DPIPE_FIELD_IPV4_DST_IP = 0,
};

enum devlink_dpipe_field_ipv6_id {
	DEVLINK_DPIPE_FIELD_IPV6_DST_IP = 0,
};

enum devlink_dpipe_header_id {
	DEVLINK_DPIPE_HEADER_ETHERNET = 0,
	DEVLINK_DPIPE_HEADER_IPV4 = 1,
	DEVLINK_DPIPE_HEADER_IPV6 = 2,
};

enum devlink_resource_unit {
	DEVLINK_RESOURCE_UNIT_ENTRY = 0,
};

enum devlink_port_function_attr {
	DEVLINK_PORT_FUNCTION_ATTR_UNSPEC = 0,
	DEVLINK_PORT_FUNCTION_ATTR_HW_ADDR = 1,
	DEVLINK_PORT_FN_ATTR_STATE = 2,
	DEVLINK_PORT_FN_ATTR_OPSTATE = 3,
	__DEVLINK_PORT_FUNCTION_ATTR_MAX = 4,
	DEVLINK_PORT_FUNCTION_ATTR_MAX = 3,
};

struct devlink_ops___6;

struct devlink___6 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___6 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___239 *dev;
	possible_net_t___67 _net;
	struct mutex lock;
	u8 reload_failed;
	u8 reload_enabled;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_info_req___2;

struct devlink_ops___6 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___6 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___6 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___6 *, enum devlink_port_type);
	int (*port_split)(struct devlink___6 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___6 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___6 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___6 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___6 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___6 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___6 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___6 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___6 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___6 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___6 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___6 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___6 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___6 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___6 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___6 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___6 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___6 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___6 *, struct devlink_info_req___2 *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___6 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___6 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___6 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___6 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___6 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___6 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___6 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___6 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___6 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___6 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___6 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___6 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___6 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___6 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___6 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___6 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___6 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___6 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___6 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___6 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___6 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___6 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___6 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___6 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___6 *, struct devlink_rate___6 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___6 *, struct devlink_rate___6 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___6 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___6 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___6 *parent;
	union {
		struct devlink_port___6 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct devlink_dpipe_match {
	enum devlink_dpipe_match_type type;
	unsigned int header_index;
	struct devlink_dpipe_header *header;
	unsigned int field_id;
};

struct devlink_dpipe_action {
	enum devlink_dpipe_action_type type;
	unsigned int header_index;
	struct devlink_dpipe_header *header;
	unsigned int field_id;
};

struct devlink_dpipe_value {
	union {
		struct devlink_dpipe_action *action;
		struct devlink_dpipe_match *match;
	};
	unsigned int mapping_value;
	bool mapping_valid;
	unsigned int value_size;
	void *value;
	void *mask;
};

struct devlink_dpipe_entry {
	u64 index;
	struct devlink_dpipe_value *match_values;
	unsigned int match_values_count;
	struct devlink_dpipe_value *action_values;
	unsigned int action_values_count;
	u64 counter;
	bool counter_valid;
};

struct devlink_dpipe_dump_ctx {
	struct genl_info___3 *info;
	enum devlink_command cmd;
	struct sk_buff___68 *skb;
	struct nlattr *nest;
	void *hdr;
};

struct devlink_dpipe_table_ops;

struct devlink_dpipe_table {
	void *priv;
	struct list_head list;
	const char *name;
	bool counters_enabled;
	bool counter_control_extern;
	bool resource_valid;
	u64 resource_id;
	u64 resource_units;
	struct devlink_dpipe_table_ops *table_ops;
	struct callback_head rcu;
};

struct devlink_dpipe_table_ops {
	int (*actions_dump)(void *, struct sk_buff___68 *);
	int (*matches_dump)(void *, struct sk_buff___68 *);
	int (*entries_dump)(void *, bool, struct devlink_dpipe_dump_ctx *);
	int (*counters_set_update)(void *, bool);
	u64 (*size_get)(void *);
};

struct devlink_resource_size_params {
	u64 size_min;
	u64 size_max;
	u64 size_granularity;
	enum devlink_resource_unit unit;
};

typedef u64 devlink_resource_occ_get_t(void *);

struct devlink_resource {
	const char *name;
	u64 id;
	u64 size;
	u64 size_new;
	bool size_valid;
	struct devlink_resource *parent;
	struct devlink_resource_size_params size_params;
	struct list_head list;
	struct list_head resource_list;
	devlink_resource_occ_get_t *occ_get;
	void *occ_get_priv;
};

enum devlink_param_type {
	DEVLINK_PARAM_TYPE_U8 = 0,
	DEVLINK_PARAM_TYPE_U16 = 1,
	DEVLINK_PARAM_TYPE_U32 = 2,
	DEVLINK_PARAM_TYPE_STRING = 3,
	DEVLINK_PARAM_TYPE_BOOL = 4,
};

struct devlink_flash_notify {
	const char *status_msg;
	const char *component;
	long unsigned int done;
	long unsigned int total;
	long unsigned int timeout;
};

struct devlink_param {
	u32 id;
	const char *name;
	bool generic;
	enum devlink_param_type type;
	long unsigned int supported_cmodes;
	int (*get)(struct devlink___6 *, u32, struct devlink_param_gset_ctx *);
	int (*set)(struct devlink___6 *, u32, struct devlink_param_gset_ctx *);
	int (*validate)(struct devlink___6 *, u32, union devlink_param_value, struct netlink_ext_ack *);
};

struct devlink_param_item {
	struct list_head list;
	const struct devlink_param *param;
	union devlink_param_value driverinit_value;
	bool driverinit_value_valid;
	bool published;
};

enum devlink_param_generic_id {
	DEVLINK_PARAM_GENERIC_ID_INT_ERR_RESET = 0,
	DEVLINK_PARAM_GENERIC_ID_MAX_MACS = 1,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_SRIOV = 2,
	DEVLINK_PARAM_GENERIC_ID_REGION_SNAPSHOT = 3,
	DEVLINK_PARAM_GENERIC_ID_IGNORE_ARI = 4,
	DEVLINK_PARAM_GENERIC_ID_MSIX_VEC_PER_PF_MAX = 5,
	DEVLINK_PARAM_GENERIC_ID_MSIX_VEC_PER_PF_MIN = 6,
	DEVLINK_PARAM_GENERIC_ID_FW_LOAD_POLICY = 7,
	DEVLINK_PARAM_GENERIC_ID_RESET_DEV_ON_DRV_PROBE = 8,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_ROCE = 9,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_REMOTE_DEV_RESET = 10,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_ETH = 11,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_RDMA = 12,
	DEVLINK_PARAM_GENERIC_ID_ENABLE_VNET = 13,
	__DEVLINK_PARAM_GENERIC_ID_MAX = 14,
	DEVLINK_PARAM_GENERIC_ID_MAX = 13,
};

struct devlink_region_ops {
	const char *name;
	void (*destructor)(const void *);
	int (*snapshot)(struct devlink___6 *, const struct devlink_region_ops *, struct netlink_ext_ack *, u8 **);
	void *priv;
};

struct devlink_port_region_ops {
	const char *name;
	void (*destructor)(const void *);
	int (*snapshot)(struct devlink_port___6 *, const struct devlink_port_region_ops *, struct netlink_ext_ack *, u8 **);
	void *priv;
};

enum devlink_health_reporter_state {
	DEVLINK_HEALTH_REPORTER_STATE_HEALTHY = 0,
	DEVLINK_HEALTH_REPORTER_STATE_ERROR = 1,
};

struct devlink_health_reporter;

struct devlink_fmsg;

struct devlink_health_reporter_ops {
	char *name;
	int (*recover)(struct devlink_health_reporter *, void *, struct netlink_ext_ack *);
	int (*dump)(struct devlink_health_reporter *, struct devlink_fmsg *, void *, struct netlink_ext_ack *);
	int (*diagnose)(struct devlink_health_reporter *, struct devlink_fmsg *, struct netlink_ext_ack *);
	int (*test)(struct devlink_health_reporter *, struct netlink_ext_ack *);
};

struct devlink_health_reporter {
	struct list_head list;
	void *priv;
	const struct devlink_health_reporter_ops *ops;
	struct devlink___6 *devlink;
	struct devlink_port___6 *devlink_port;
	struct devlink_fmsg *dump_fmsg;
	struct mutex dump_lock;
	u64 graceful_period;
	bool auto_recover;
	bool auto_dump;
	u8 health_state;
	u64 dump_ts;
	u64 dump_real_ts;
	u64 error_count;
	u64 recovery_count;
	u64 last_recovery_ts;
	refcount_t refcount;
};

struct devlink_fmsg {
	struct list_head item_list;
	bool putting_binary;
};

struct devlink_trap_metadata___2 {
	const char *trap_name;
	const char *trap_group_name;
	struct net_device___67 *input_dev;
	const struct flow_action_cookie *fa_cookie;
	enum devlink_trap_type trap_type;
};

enum devlink_trap_generic_id {
	DEVLINK_TRAP_GENERIC_ID_SMAC_MC = 0,
	DEVLINK_TRAP_GENERIC_ID_VLAN_TAG_MISMATCH = 1,
	DEVLINK_TRAP_GENERIC_ID_INGRESS_VLAN_FILTER = 2,
	DEVLINK_TRAP_GENERIC_ID_INGRESS_STP_FILTER = 3,
	DEVLINK_TRAP_GENERIC_ID_EMPTY_TX_LIST = 4,
	DEVLINK_TRAP_GENERIC_ID_PORT_LOOPBACK_FILTER = 5,
	DEVLINK_TRAP_GENERIC_ID_BLACKHOLE_ROUTE = 6,
	DEVLINK_TRAP_GENERIC_ID_TTL_ERROR = 7,
	DEVLINK_TRAP_GENERIC_ID_TAIL_DROP = 8,
	DEVLINK_TRAP_GENERIC_ID_NON_IP_PACKET = 9,
	DEVLINK_TRAP_GENERIC_ID_UC_DIP_MC_DMAC = 10,
	DEVLINK_TRAP_GENERIC_ID_DIP_LB = 11,
	DEVLINK_TRAP_GENERIC_ID_SIP_MC = 12,
	DEVLINK_TRAP_GENERIC_ID_SIP_LB = 13,
	DEVLINK_TRAP_GENERIC_ID_CORRUPTED_IP_HDR = 14,
	DEVLINK_TRAP_GENERIC_ID_IPV4_SIP_BC = 15,
	DEVLINK_TRAP_GENERIC_ID_IPV6_MC_DIP_RESERVED_SCOPE = 16,
	DEVLINK_TRAP_GENERIC_ID_IPV6_MC_DIP_INTERFACE_LOCAL_SCOPE = 17,
	DEVLINK_TRAP_GENERIC_ID_MTU_ERROR = 18,
	DEVLINK_TRAP_GENERIC_ID_UNRESOLVED_NEIGH = 19,
	DEVLINK_TRAP_GENERIC_ID_RPF = 20,
	DEVLINK_TRAP_GENERIC_ID_REJECT_ROUTE = 21,
	DEVLINK_TRAP_GENERIC_ID_IPV4_LPM_UNICAST_MISS = 22,
	DEVLINK_TRAP_GENERIC_ID_IPV6_LPM_UNICAST_MISS = 23,
	DEVLINK_TRAP_GENERIC_ID_NON_ROUTABLE = 24,
	DEVLINK_TRAP_GENERIC_ID_DECAP_ERROR = 25,
	DEVLINK_TRAP_GENERIC_ID_OVERLAY_SMAC_MC = 26,
	DEVLINK_TRAP_GENERIC_ID_INGRESS_FLOW_ACTION_DROP = 27,
	DEVLINK_TRAP_GENERIC_ID_EGRESS_FLOW_ACTION_DROP = 28,
	DEVLINK_TRAP_GENERIC_ID_STP = 29,
	DEVLINK_TRAP_GENERIC_ID_LACP = 30,
	DEVLINK_TRAP_GENERIC_ID_LLDP = 31,
	DEVLINK_TRAP_GENERIC_ID_IGMP_QUERY = 32,
	DEVLINK_TRAP_GENERIC_ID_IGMP_V1_REPORT = 33,
	DEVLINK_TRAP_GENERIC_ID_IGMP_V2_REPORT = 34,
	DEVLINK_TRAP_GENERIC_ID_IGMP_V3_REPORT = 35,
	DEVLINK_TRAP_GENERIC_ID_IGMP_V2_LEAVE = 36,
	DEVLINK_TRAP_GENERIC_ID_MLD_QUERY = 37,
	DEVLINK_TRAP_GENERIC_ID_MLD_V1_REPORT = 38,
	DEVLINK_TRAP_GENERIC_ID_MLD_V2_REPORT = 39,
	DEVLINK_TRAP_GENERIC_ID_MLD_V1_DONE = 40,
	DEVLINK_TRAP_GENERIC_ID_IPV4_DHCP = 41,
	DEVLINK_TRAP_GENERIC_ID_IPV6_DHCP = 42,
	DEVLINK_TRAP_GENERIC_ID_ARP_REQUEST = 43,
	DEVLINK_TRAP_GENERIC_ID_ARP_RESPONSE = 44,
	DEVLINK_TRAP_GENERIC_ID_ARP_OVERLAY = 45,
	DEVLINK_TRAP_GENERIC_ID_IPV6_NEIGH_SOLICIT = 46,
	DEVLINK_TRAP_GENERIC_ID_IPV6_NEIGH_ADVERT = 47,
	DEVLINK_TRAP_GENERIC_ID_IPV4_BFD = 48,
	DEVLINK_TRAP_GENERIC_ID_IPV6_BFD = 49,
	DEVLINK_TRAP_GENERIC_ID_IPV4_OSPF = 50,
	DEVLINK_TRAP_GENERIC_ID_IPV6_OSPF = 51,
	DEVLINK_TRAP_GENERIC_ID_IPV4_BGP = 52,
	DEVLINK_TRAP_GENERIC_ID_IPV6_BGP = 53,
	DEVLINK_TRAP_GENERIC_ID_IPV4_VRRP = 54,
	DEVLINK_TRAP_GENERIC_ID_IPV6_VRRP = 55,
	DEVLINK_TRAP_GENERIC_ID_IPV4_PIM = 56,
	DEVLINK_TRAP_GENERIC_ID_IPV6_PIM = 57,
	DEVLINK_TRAP_GENERIC_ID_UC_LB = 58,
	DEVLINK_TRAP_GENERIC_ID_LOCAL_ROUTE = 59,
	DEVLINK_TRAP_GENERIC_ID_EXTERNAL_ROUTE = 60,
	DEVLINK_TRAP_GENERIC_ID_IPV6_UC_DIP_LINK_LOCAL_SCOPE = 61,
	DEVLINK_TRAP_GENERIC_ID_IPV6_DIP_ALL_NODES = 62,
	DEVLINK_TRAP_GENERIC_ID_IPV6_DIP_ALL_ROUTERS = 63,
	DEVLINK_TRAP_GENERIC_ID_IPV6_ROUTER_SOLICIT = 64,
	DEVLINK_TRAP_GENERIC_ID_IPV6_ROUTER_ADVERT = 65,
	DEVLINK_TRAP_GENERIC_ID_IPV6_REDIRECT = 66,
	DEVLINK_TRAP_GENERIC_ID_IPV4_ROUTER_ALERT = 67,
	DEVLINK_TRAP_GENERIC_ID_IPV6_ROUTER_ALERT = 68,
	DEVLINK_TRAP_GENERIC_ID_PTP_EVENT = 69,
	DEVLINK_TRAP_GENERIC_ID_PTP_GENERAL = 70,
	DEVLINK_TRAP_GENERIC_ID_FLOW_ACTION_SAMPLE = 71,
	DEVLINK_TRAP_GENERIC_ID_FLOW_ACTION_TRAP = 72,
	DEVLINK_TRAP_GENERIC_ID_EARLY_DROP = 73,
	DEVLINK_TRAP_GENERIC_ID_VXLAN_PARSING = 74,
	DEVLINK_TRAP_GENERIC_ID_LLC_SNAP_PARSING = 75,
	DEVLINK_TRAP_GENERIC_ID_VLAN_PARSING = 76,
	DEVLINK_TRAP_GENERIC_ID_PPPOE_PPP_PARSING = 77,
	DEVLINK_TRAP_GENERIC_ID_MPLS_PARSING = 78,
	DEVLINK_TRAP_GENERIC_ID_ARP_PARSING = 79,
	DEVLINK_TRAP_GENERIC_ID_IP_1_PARSING = 80,
	DEVLINK_TRAP_GENERIC_ID_IP_N_PARSING = 81,
	DEVLINK_TRAP_GENERIC_ID_GRE_PARSING = 82,
	DEVLINK_TRAP_GENERIC_ID_UDP_PARSING = 83,
	DEVLINK_TRAP_GENERIC_ID_TCP_PARSING = 84,
	DEVLINK_TRAP_GENERIC_ID_IPSEC_PARSING = 85,
	DEVLINK_TRAP_GENERIC_ID_SCTP_PARSING = 86,
	DEVLINK_TRAP_GENERIC_ID_DCCP_PARSING = 87,
	DEVLINK_TRAP_GENERIC_ID_GTP_PARSING = 88,
	DEVLINK_TRAP_GENERIC_ID_ESP_PARSING = 89,
	DEVLINK_TRAP_GENERIC_ID_BLACKHOLE_NEXTHOP = 90,
	DEVLINK_TRAP_GENERIC_ID_DMAC_FILTER = 91,
	__DEVLINK_TRAP_GENERIC_ID_MAX = 92,
	DEVLINK_TRAP_GENERIC_ID_MAX = 91,
};

enum devlink_trap_group_generic_id {
	DEVLINK_TRAP_GROUP_GENERIC_ID_L2_DROPS = 0,
	DEVLINK_TRAP_GROUP_GENERIC_ID_L3_DROPS = 1,
	DEVLINK_TRAP_GROUP_GENERIC_ID_L3_EXCEPTIONS = 2,
	DEVLINK_TRAP_GROUP_GENERIC_ID_BUFFER_DROPS = 3,
	DEVLINK_TRAP_GROUP_GENERIC_ID_TUNNEL_DROPS = 4,
	DEVLINK_TRAP_GROUP_GENERIC_ID_ACL_DROPS = 5,
	DEVLINK_TRAP_GROUP_GENERIC_ID_STP = 6,
	DEVLINK_TRAP_GROUP_GENERIC_ID_LACP = 7,
	DEVLINK_TRAP_GROUP_GENERIC_ID_LLDP = 8,
	DEVLINK_TRAP_GROUP_GENERIC_ID_MC_SNOOPING = 9,
	DEVLINK_TRAP_GROUP_GENERIC_ID_DHCP = 10,
	DEVLINK_TRAP_GROUP_GENERIC_ID_NEIGH_DISCOVERY = 11,
	DEVLINK_TRAP_GROUP_GENERIC_ID_BFD = 12,
	DEVLINK_TRAP_GROUP_GENERIC_ID_OSPF = 13,
	DEVLINK_TRAP_GROUP_GENERIC_ID_BGP = 14,
	DEVLINK_TRAP_GROUP_GENERIC_ID_VRRP = 15,
	DEVLINK_TRAP_GROUP_GENERIC_ID_PIM = 16,
	DEVLINK_TRAP_GROUP_GENERIC_ID_UC_LB = 17,
	DEVLINK_TRAP_GROUP_GENERIC_ID_LOCAL_DELIVERY = 18,
	DEVLINK_TRAP_GROUP_GENERIC_ID_EXTERNAL_DELIVERY = 19,
	DEVLINK_TRAP_GROUP_GENERIC_ID_IPV6 = 20,
	DEVLINK_TRAP_GROUP_GENERIC_ID_PTP_EVENT = 21,
	DEVLINK_TRAP_GROUP_GENERIC_ID_PTP_GENERAL = 22,
	DEVLINK_TRAP_GROUP_GENERIC_ID_ACL_SAMPLE = 23,
	DEVLINK_TRAP_GROUP_GENERIC_ID_ACL_TRAP = 24,
	DEVLINK_TRAP_GROUP_GENERIC_ID_PARSER_ERROR_DROPS = 25,
	__DEVLINK_TRAP_GROUP_GENERIC_ID_MAX = 26,
	DEVLINK_TRAP_GROUP_GENERIC_ID_MAX = 25,
};

struct devlink_info_req___2 {
	struct sk_buff___68 *msg;
};

struct perf_cpu_context___85;

struct perf_output_handle___85;

struct pmu___85 {
	struct list_head entry;
	struct module___242 *module;
	struct device___239 *dev;
	const struct attribute_group___246 **attr_groups;
	const struct attribute_group___246 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___85 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___85 *);
	void (*pmu_disable)(struct pmu___85 *);
	int (*event_init)(struct perf_event___85 *);
	void (*event_mapped)(struct perf_event___85 *, struct mm_struct___264 *);
	void (*event_unmapped)(struct perf_event___85 *, struct mm_struct___264 *);
	int (*add)(struct perf_event___85 *, int);
	void (*del)(struct perf_event___85 *, int);
	void (*start)(struct perf_event___85 *, int);
	void (*stop)(struct perf_event___85 *, int);
	void (*read)(struct perf_event___85 *);
	void (*start_txn)(struct pmu___85 *, unsigned int);
	int (*commit_txn)(struct pmu___85 *);
	void (*cancel_txn)(struct pmu___85 *);
	int (*event_idx)(struct perf_event___85 *);
	void (*sched_task)(struct perf_event_context___85 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___85 *, struct perf_event_context___85 *);
	void * (*setup_aux)(struct perf_event___85 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___85 *, struct perf_output_handle___85 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___85 *);
	int (*aux_output_match)(struct perf_event___85 *);
	int (*filter_match)(struct perf_event___85 *);
	int (*check_period)(struct perf_event___85 *, u64);
};

struct perf_cpu_context___85 {
	struct perf_event_context___85 ctx;
	struct perf_event_context___85 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___85 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___85 **heap;
	struct perf_event___85 *heap_default[2];
};

struct perf_output_handle___85 {
	struct perf_event___85 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___85 {
	struct cgroup_subsys_state___185 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___79 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___79 *);
	};
};

struct trace_event_class___79 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___79 *, enum trace_reg, void *);
	struct trace_event_fields___79 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___79 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___79 *);
};

struct trace_event_file___40;

struct trace_event_buffer___39 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___40 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___40 {
	struct list_head list;
	struct trace_event_call___79 *event_call;
	struct event_filter *filter;
	struct dentry___258 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_devlink_hwmsg {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	bool incoming;
	long unsigned int type;
	u32 __data_loc_buf;
	size_t len;
	char __data[0];
};

struct trace_event_raw_devlink_hwerr {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	int err;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_raw_devlink_health_report {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	u32 __data_loc_reporter_name;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_raw_devlink_health_recover_aborted {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	u32 __data_loc_reporter_name;
	bool health_state;
	u64 time_since_last_recover;
	char __data[0];
};

struct trace_event_raw_devlink_health_reporter_state_update {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	u32 __data_loc_reporter_name;
	u8 new_state;
	char __data[0];
};

struct trace_event_raw_devlink_trap_report {
	struct trace_entry ent;
	u32 __data_loc_bus_name;
	u32 __data_loc_dev_name;
	u32 __data_loc_driver_name;
	u32 __data_loc_trap_name;
	u32 __data_loc_trap_group_name;
	u32 __data_loc_input_dev_name;
	char __data[0];
};

struct trace_event_data_offsets_devlink_hwmsg {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 buf;
};

struct trace_event_data_offsets_devlink_hwerr {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 msg;
};

struct trace_event_data_offsets_devlink_health_report {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 reporter_name;
	u32 msg;
};

struct trace_event_data_offsets_devlink_health_recover_aborted {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 reporter_name;
};

struct trace_event_data_offsets_devlink_health_reporter_state_update {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 reporter_name;
};

struct trace_event_data_offsets_devlink_trap_report {
	u32 bus_name;
	u32 dev_name;
	u32 driver_name;
	u32 trap_name;
	u32 trap_group_name;
	u32 input_dev_name;
};

typedef void (*btf_trace_devlink_hwmsg)(void *, const struct devlink___6 *, bool, long unsigned int, const u8 *, size_t);

typedef void (*btf_trace_devlink_hwerr)(void *, const struct devlink___6 *, int, const char *);

typedef void (*btf_trace_devlink_health_report)(void *, const struct devlink___6 *, const char *, const char *);

typedef void (*btf_trace_devlink_health_recover_aborted)(void *, const struct devlink___6 *, const char *, bool, u64);

typedef void (*btf_trace_devlink_health_reporter_state_update)(void *, const struct devlink___6 *, const char *, bool);

typedef void (*btf_trace_devlink_trap_report)(void *, const struct devlink___6 *, struct sk_buff___68 *, const struct devlink_trap_metadata___2 *);

struct devlink_sb {
	struct list_head list;
	unsigned int index;
	u32 size;
	u16 ingress_pools_count;
	u16 egress_pools_count;
	u16 ingress_tc_count;
	u16 egress_tc_count;
};

struct devlink_region {
	struct devlink___6 *devlink;
	struct devlink_port___6 *port;
	struct list_head list;
	union {
		const struct devlink_region_ops *ops;
		const struct devlink_port_region_ops *port_ops;
	};
	struct list_head snapshot_list;
	u32 max_snapshots;
	u32 cur_snapshots;
	u64 size;
};

struct devlink_snapshot {
	struct list_head list;
	struct devlink_region *region;
	u8 *data;
	u32 id;
};

enum devlink_multicast_groups {
	DEVLINK_MCGRP_CONFIG = 0,
};

struct devlink_reload_combination {
	enum devlink_reload_action action;
	enum devlink_reload_limit limit;
};

struct devlink_fmsg_item {
	struct list_head list;
	int attrtype;
	u8 nla_type;
	u16 len;
	int value[0];
};

struct devlink_stats {
	u64 rx_bytes;
	u64 rx_packets;
	struct u64_stats_sync syncp;
};

struct devlink_trap_policer_item {
	const struct devlink_trap_policer *policer;
	u64 rate;
	u64 burst;
	struct list_head list;
};

struct devlink_trap_group_item {
	const struct devlink_trap_group *group;
	struct devlink_trap_policer_item *policer_item;
	struct list_head list;
	struct devlink_stats *stats;
};

struct devlink_trap_item {
	const struct devlink_trap *trap;
	struct devlink_trap_group_item *group_item;
	struct list_head list;
	enum devlink_trap_action action;
	struct devlink_stats *stats;
	void *priv;
};

typedef struct bio_vec___175 skb_frag_t___18;

struct gro_cell;

struct gro_cells {
	struct gro_cell *cells;
};

struct gro_cell {
	struct sk_buff_head___67 napi_skbs;
	struct napi_struct___14 napi;
};

enum __sk_action {
	__SK_DROP = 0,
	__SK_PASS = 1,
	__SK_REDIRECT = 2,
	__SK_NONE = 3,
};

enum sk_psock_state_bits {
	SK_PSOCK_TX_ENABLED = 0,
};

struct sk_psock_link {
	struct list_head list;
	struct bpf_map___58 *map;
	void *link_raw;
};

typedef int (*bpf_iter_attach_target_t___2)(struct bpf_prog___56 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___65 *);

typedef void (*bpf_iter_detach_target_t___2)(struct bpf_iter_aux_info___65 *);

typedef void (*bpf_iter_show_fdinfo_t___2)(const struct bpf_iter_aux_info___65 *, struct seq_file___228 *);

typedef int (*bpf_iter_fill_link_info_t___2)(const struct bpf_iter_aux_info___65 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___8 * (*bpf_iter_get_func_proto_t___3)(enum bpf_func_id, const struct bpf_prog___56 *);

struct bpf_iter_reg___2 {
	const char *target;
	bpf_iter_attach_target_t___2 attach_target;
	bpf_iter_detach_target_t___2 detach_target;
	bpf_iter_show_fdinfo_t___2 show_fdinfo;
	bpf_iter_fill_link_info_t___2 fill_link_info;
	bpf_iter_get_func_proto_t___3 get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___64 *seq_info;
};

struct bpf_iter_meta___3 {
	union {
		struct seq_file___228 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct sk_psock_link___2 {
	struct list_head list;
	struct bpf_map___65 *map;
	void *link_raw;
};

struct bpf_stab {
	struct bpf_map___65 map;
	struct sock___49 **sks;
	struct sk_psock_progs progs;
	raw_spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
};

typedef u64 (*btf_bpf_sock_map_update)(struct bpf_sock_ops_kern *, struct bpf_map___65 *, void *, u64);

typedef u64 (*btf_bpf_sk_redirect_map)(struct sk_buff___63 *, struct bpf_map___65 *, u32, u64);

typedef u64 (*btf_bpf_msg_redirect_map)(struct sk_msg *, struct bpf_map___65 *, u32, u64);

struct sock_map_seq_info {
	struct bpf_map___65 *map;
	struct sock___49 *sk;
	u32 index;
};

struct bpf_iter__sockmap {
	union {
		struct bpf_iter_meta___3 *meta;
	};
	union {
		struct bpf_map___65 *map;
	};
	union {
		void *key;
	};
	union {
		struct sock___49 *sk;
	};
};

struct bpf_shtab_elem {
	struct callback_head rcu;
	u32 hash;
	struct sock___49 *sk;
	struct hlist_node node;
	u8 key[0];
};

struct bpf_shtab_bucket {
	struct hlist_head head;
	raw_spinlock_t lock;
};

struct bpf_shtab {
	struct bpf_map___65 map;
	struct bpf_shtab_bucket *buckets;
	u32 buckets_num;
	u32 elem_size;
	struct sk_psock_progs progs;
	atomic_t count;
	long: 32;
	long: 64;
};

typedef u64 (*btf_bpf_sock_hash_update)(struct bpf_sock_ops_kern *, struct bpf_map___65 *, void *, u64);

typedef u64 (*btf_bpf_sk_redirect_hash)(struct sk_buff___63 *, struct bpf_map___65 *, void *, u64);

typedef u64 (*btf_bpf_msg_redirect_hash)(struct sk_msg *, struct bpf_map___65 *, void *, u64);

struct sock_hash_seq_info {
	struct bpf_map___65 *map;
	struct bpf_shtab *htab;
	u32 bucket_id;
};

typedef int (*bpf_iter_attach_target_t___3)(struct bpf_prog___17 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___18 *);

typedef void (*bpf_iter_detach_target_t___3)(struct bpf_iter_aux_info___18 *);

typedef void (*bpf_iter_show_fdinfo_t___3)(const struct bpf_iter_aux_info___18 *, struct seq_file___67 *);

typedef int (*bpf_iter_fill_link_info_t___3)(const struct bpf_iter_aux_info___18 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___11 * (*bpf_iter_get_func_proto_t___4)(enum bpf_func_id, const struct bpf_prog___17 *);

struct bpf_iter_reg___3 {
	const char *target;
	bpf_iter_attach_target_t___3 attach_target;
	bpf_iter_detach_target_t___3 detach_target;
	bpf_iter_show_fdinfo_t___3 show_fdinfo;
	bpf_iter_fill_link_info_t___3 fill_link_info;
	bpf_iter_get_func_proto_t___4 get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___18 *seq_info;
};

struct bpf_iter_meta___4 {
	union {
		struct seq_file___67 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

enum {
	SK_DIAG_BPF_STORAGE_REQ_NONE = 0,
	SK_DIAG_BPF_STORAGE_REQ_MAP_FD = 1,
	__SK_DIAG_BPF_STORAGE_REQ_MAX = 2,
};

enum {
	SK_DIAG_BPF_STORAGE_REP_NONE = 0,
	SK_DIAG_BPF_STORAGE = 1,
	__SK_DIAG_BPF_STORAGE_REP_MAX = 2,
};

enum {
	SK_DIAG_BPF_STORAGE_NONE = 0,
	SK_DIAG_BPF_STORAGE_PAD = 1,
	SK_DIAG_BPF_STORAGE_MAP_ID = 2,
	SK_DIAG_BPF_STORAGE_MAP_VALUE = 3,
	__SK_DIAG_BPF_STORAGE_MAX = 4,
};

typedef u64 (*btf_bpf_sk_storage_get)(struct bpf_map___18 *, struct sock___12 *, void *, u64);

typedef u64 (*btf_bpf_sk_storage_delete)(struct bpf_map___18 *, struct sock___12 *);

typedef u64 (*btf_bpf_sk_storage_get_tracing)(struct bpf_map___18 *, struct sock___12 *, void *, u64);

typedef u64 (*btf_bpf_sk_storage_delete_tracing)(struct bpf_map___18 *, struct sock___12 *);

struct bpf_sk_storage_diag {
	u32 nr_maps;
	struct bpf_map___18 *maps[0];
};

struct bpf_iter_seq_sk_storage_map_info {
	struct bpf_map___18 *map;
	unsigned int bucket_id;
	unsigned int skip_elems;
};

struct bpf_iter__bpf_sk_storage_map {
	union {
		struct bpf_iter_meta___4 *meta;
	};
	union {
		struct bpf_map___18 *map;
	};
	union {
		struct sock___12 *sk;
	};
	union {
		void *value;
	};
};

struct nvmem_cell___2;

struct dentry___259;

struct super_block___259;

struct module___243;

struct file_system_type___259 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___259 * (*mount)(struct file_system_type___259 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___259 *);
	struct module___243 *owner;
	struct file_system_type___259 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___259;

struct kiocb___259;

struct iov_iter___179;

struct poll_table_struct___180;

struct vm_area_struct___264;

struct inode___259;

struct file_lock___259;

struct page___264;

struct pipe_inode_info___100;

struct seq_file___234;

struct file_operations___260 {
	struct module___243 *owner;
	loff_t (*llseek)(struct file___259 *, loff_t, int);
	ssize_t (*read)(struct file___259 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___259 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___259 *, struct iov_iter___179 *);
	ssize_t (*write_iter)(struct kiocb___259 *, struct iov_iter___179 *);
	int (*iopoll)(struct kiocb___259 *, bool);
	int (*iterate)(struct file___259 *, struct dir_context *);
	int (*iterate_shared)(struct file___259 *, struct dir_context *);
	__poll_t (*poll)(struct file___259 *, struct poll_table_struct___180 *);
	long int (*unlocked_ioctl)(struct file___259 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___259 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___259 *, struct vm_area_struct___264 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___259 *, struct file___259 *);
	int (*flush)(struct file___259 *, fl_owner_t);
	int (*release)(struct inode___259 *, struct file___259 *);
	int (*fsync)(struct file___259 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___259 *, int);
	int (*lock)(struct file___259 *, int, struct file_lock___259 *);
	ssize_t (*sendpage)(struct file___259 *, struct page___264 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___259 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___259 *, long unsigned int);
	int (*flock)(struct file___259 *, int, struct file_lock___259 *);
	ssize_t (*splice_write)(struct pipe_inode_info___100 *, struct file___259 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___259 *, loff_t *, struct pipe_inode_info___100 *, size_t, unsigned int);
	int (*setlease)(struct file___259 *, long int, struct file_lock___259 **, void **);
	long int (*fallocate)(struct file___259 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___234 *, struct file___259 *);
	ssize_t (*copy_file_range)(struct file___259 *, loff_t, struct file___259 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___259 *, loff_t, struct file___259 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___259 *, loff_t, loff_t, int);
};

struct vmacache___264 {
	u64 seqnum;
	struct vm_area_struct___264 *vmas[4];
};

struct page_frag___264 {
	struct page___264 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___86;

struct debug_info___86 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___86 *hbp_break[16];
	struct perf_event___86 *hbp_watch[16];
};

struct thread_struct___86 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___86 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___265;

struct pid___236;

struct nsproxy___245;

struct signal_struct___260;

struct bio_list___150;

struct backing_dev_info___136;

struct io_context___150;

struct css_set___186;

struct perf_event_context___86;

struct mem_cgroup___124;

struct request_queue___150;

struct vm_struct___242;

struct task_struct___266 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___266 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___265 *mm;
	struct mm_struct___265 *active_mm;
	struct vmacache___264 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___266 *real_parent;
	struct task_struct___266 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___266 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___236 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___245 *nsproxy;
	struct signal_struct___260 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___266 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___150 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___136 *backing_dev_info;
	struct io_context___150 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___186 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___86 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___100 *splice_pipe;
	struct page_frag___264 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___124 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___124 *active_memcg;
	struct request_queue___150 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___266 *oom_reaper_list;
	struct vm_struct___242 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___247;

struct kobj_type___247;

struct kernfs_node___247;

struct kobject___247 {
	const char *name;
	struct list_head entry;
	struct kobject___247 *parent;
	struct kset___247 *kset;
	struct kobj_type___247 *ktype;
	struct kernfs_node___247 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___244 {
	struct kobject___247 kobj;
	struct module___243 *mod;
	struct kobject___247 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___243 {
	struct module___243 *mod;
	struct latch_tree_node node;
};

struct module_layout___243 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___243 mtn;
};

struct module_attribute___243;

struct kernel_param___243;

struct trace_event_call___80;

struct module___243 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___244 mkobj;
	struct module_attribute___243 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___247 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___243 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___243 core_layout;
	struct module_layout___243 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___80 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___86 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___266 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___86)(struct perf_event___86 *, struct perf_sample_data___3 *, struct pt_regs *);

struct pmu___86;

struct fasync_struct___259;

struct pid_namespace___236;

struct bpf_prog___62;

struct perf_cgroup___86;

struct perf_event___86 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___86 *group_leader;
	struct pmu___86 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___86 hw;
	struct perf_event_context___86 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___86 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___266 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___259 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___86 *aux_event;
	void (*destroy)(struct perf_event___86 *);
	struct callback_head callback_head;
	struct pid_namespace___236 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___86 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___86 orig_overflow_handler;
	struct bpf_prog___62 *prog;
	u64 bpf_cookie;
	struct trace_event_call___80 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___86 *cgrp;
	void *security;
	struct list_head sb_list;
};

typedef struct page___264 *pgtable_t___264;

struct address_space___259;

struct page_pool___88;

struct dev_pagemap___254;

struct page___264 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___259 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___88 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___264 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___264 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___265 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___254 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___254;

struct vm_area_struct___264 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___264 *vm_next;
	struct vm_area_struct___264 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___265 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___254 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___259 *vm_file;
	struct file___259 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___264;

struct mm_struct___265 {
	struct {
		struct vm_area_struct___264 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___259 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___264 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___266 *owner;
		struct user_namespace___26 *user_ns;
		struct file___259 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___259;

struct address_space___259 {
	struct inode___259 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___259 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___240;

struct page_pool_params___88 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___240 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___88 {
	u32 count;
	struct page___264 *cache[128];
};

struct page_pool___88 {
	struct page_pool_params___88 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___264 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___88 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___254;

struct dev_pagemap___254 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___254 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___259;

struct path___259 {
	struct vfsmount___259 *mnt;
	struct dentry___259 *dentry;
};

struct fown_struct___236 {
	rwlock_t lock;
	struct pid___236 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___259 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___259 f_path;
	struct inode___259 *f_inode;
	const struct file_operations___260 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___236 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___259 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___254;

struct vm_operations_struct___254 {
	void (*open)(struct vm_area_struct___264 *);
	void (*close)(struct vm_area_struct___264 *);
	int (*may_split)(struct vm_area_struct___264 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___264 *);
	int (*mprotect)(struct vm_area_struct___264 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___254 *);
	vm_fault_t (*huge_fault)(struct vm_fault___254 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___254 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___264 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___254 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___254 *);
	int (*access)(struct vm_area_struct___264 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___264 *);
	int (*set_policy)(struct vm_area_struct___264 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___264 *, long unsigned int);
	struct page___264 * (*find_special_page)(struct vm_area_struct___264 *, long unsigned int);
};

struct core_thread___264 {
	struct task_struct___266 *task;
	struct core_thread___264 *next;
};

struct core_state___264 {
	atomic_t nr_threads;
	struct core_thread___264 dumper;
	struct completion startup;
};

struct vm_fault___254 {
	const struct {
		struct vm_area_struct___264 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___264 *cow_page;
	struct page___264 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___264 prealloc_pte;
};

struct pglist_data___132;

struct lruvec___132 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___132 *pgdat;
};

struct zone___132 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___132 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___132 {
	struct zone___132 *zone;
	int zone_idx;
};

struct zonelist___132 {
	struct zoneref___132 _zonerefs[321];
};

struct pglist_data___132 {
	struct zone___132 node_zones[5];
	struct zonelist___132 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___266 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___266 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___132 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___259;

struct dentry___259 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___259 *d_parent;
	struct qstr d_name;
	struct inode___259 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___259 *d_op;
	struct super_block___259 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___259;

struct bdi_writeback___136;

struct inode___259 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___259 *i_op;
	struct super_block___259 *i_sb;
	struct address_space___259 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___136 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___260 *i_fop;
		void (*free_inode)(struct inode___259 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___259 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___100 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___259 {
	int (*d_revalidate)(struct dentry___259 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___259 *, unsigned int);
	int (*d_hash)(const struct dentry___259 *, struct qstr *);
	int (*d_compare)(const struct dentry___259 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___259 *);
	int (*d_init)(struct dentry___259 *);
	void (*d_release)(struct dentry___259 *);
	void (*d_prune)(struct dentry___259 *);
	void (*d_iput)(struct dentry___259 *, struct inode___259 *);
	char * (*d_dname)(struct dentry___259 *, char *, int);
	struct vfsmount___259 * (*d_automount)(struct path___259 *);
	int (*d_manage)(const struct path___259 *, bool);
	struct dentry___259 * (*d_real)(struct dentry___259 *, const struct inode___259 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___259;

struct mem_dqinfo___259 {
	struct quota_format_type___259 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___259;

struct quota_info___259 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___259 *files[3];
	struct mem_dqinfo___259 info[3];
	const struct quota_format_ops___259 *ops[3];
};

struct rcuwait___260 {
	struct task_struct___266 *task;
};

struct percpu_rw_semaphore___260 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___260 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___259 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___260 rw_sem[3];
};

struct shrink_control___124;

struct shrinker___124 {
	long unsigned int (*count_objects)(struct shrinker___124 *, struct shrink_control___124 *);
	long unsigned int (*scan_objects)(struct shrinker___124 *, struct shrink_control___124 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___259;

struct dquot_operations___259;

struct quotactl_ops___259;

struct block_device___153;

struct super_block___259 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___259 *s_type;
	const struct super_operations___259 *s_op;
	const struct dquot_operations___259 *dq_op;
	const struct quotactl_ops___259 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___259 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___153 *s_bdev;
	struct backing_dev_info___136 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___259 s_dquot;
	struct sb_writers___259 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___259 *s_d_op;
	int cleancache_poolid;
	struct shrinker___124 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___259 {
	struct dentry___259 *mnt_root;
	struct super_block___259 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct upid___236 {
	int nr;
	struct pid_namespace___236 *ns;
};

struct pid_namespace___236 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___266 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___236 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___236 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___236 numbers[1];
};

struct signal_struct___260 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___266 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___266 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___236 *pids[4];
	struct pid___236 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___265 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___73;

struct cgroup_namespace___186;

struct nsproxy___245 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___236 *pid_ns_for_children;
	struct net___73 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___186 *cgroup_ns;
};

struct bio___150;

struct bio_list___150 {
	struct bio___150 *head;
	struct bio___150 *tail;
};

struct cgroup_subsys_state___186;

struct bdi_writeback___136 {
	struct backing_dev_info___136 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___186 *memcg_css;
	struct cgroup_subsys_state___186 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___136 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___136 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___240 *dev;
	char dev_name[64];
	struct device___240 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___259 *debug_dir;
};

struct io_cq___150;

struct io_context___150 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___150 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___186;

struct css_set___186 {
	struct cgroup_subsys_state___186 *subsys[14];
	refcount_t refcount;
	struct css_set___186 *dom_cset;
	struct cgroup___186 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___186 *mg_src_cgrp;
	struct cgroup___186 *mg_dst_cgrp;
	struct css_set___186 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___86 {
	struct pmu___86 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___266 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___86 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___100;

struct pipe_inode_info___100 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___264 *tmp_page;
	struct fasync_struct___259 *fasync_readers;
	struct fasync_struct___259 *fasync_writers;
	struct pipe_buffer___100 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___186;

struct cgroup_subsys_state___186 {
	struct cgroup___186 *cgroup;
	struct cgroup_subsys___186 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___186 *parent;
};

struct cgroup_file___186 {
	struct kernfs_node___247 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___124;

struct mem_cgroup_per_node___124;

struct mem_cgroup___124 {
	struct cgroup_subsys_state___186 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___186 events_file;
	struct cgroup_file___186 events_local_file;
	struct cgroup_file___186 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___124 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___266 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___124 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___150;

struct blk_integrity___150 {
	const struct blk_integrity_profile___150 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___150 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___150 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___150;

struct elevator_queue___150;

struct blk_mq_ops___145;

struct blk_mq_hw_ctx___145;

struct gendisk___153;

struct blkcg_gq___138;

struct blk_mq_tag_set___145;

struct request_queue___150 {
	struct request___150 *last_merge;
	struct elevator_queue___150 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___145 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___145 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___153 *disk;
	struct kobject___247 kobj;
	struct kobject___247 *mq_kobj;
	struct blk_integrity___150 integrity;
	struct device___240 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___138 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___145 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___150 bio_split;
	struct dentry___259 *debugfs_dir;
	struct dentry___259 *sched_debugfs_dir;
	struct dentry___259 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___242 {
	struct vm_struct___242 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___264 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___124 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___124 *memcg;
};

struct psi_group___186 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___266 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___62;

struct cgroup_bpf___62 {
	struct bpf_prog_array___62 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___62 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___186;

struct cgroup_rstat_cpu___186;

struct cgroup___186 {
	struct cgroup_subsys_state___186 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___247 *kn;
	struct cgroup_file___186 procs_file;
	struct cgroup_file___186 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___186 *subsys[14];
	struct cgroup_root___186 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___186 *dom_cgrp;
	struct cgroup___186 *old_dom_cgrp;
	struct cgroup_rstat_cpu___186 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___186 psi;
	struct cgroup_bpf___62 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___150 {
	struct request_queue___150 *q;
	struct io_context___150 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___259 {
	struct file___259 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___259 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___259 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___259 *ia_file;
};

struct dquot___259 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___259 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___259 {
	int qf_fmt_id;
	const struct quota_format_ops___259 *qf_ops;
	struct module___243 *qf_owner;
	struct quota_format_type___259 *qf_next;
};

struct quota_format_ops___259 {
	int (*check_quota_file)(struct super_block___259 *, int);
	int (*read_file_info)(struct super_block___259 *, int);
	int (*write_file_info)(struct super_block___259 *, int);
	int (*free_file_info)(struct super_block___259 *, int);
	int (*read_dqblk)(struct dquot___259 *);
	int (*commit_dqblk)(struct dquot___259 *);
	int (*release_dqblk)(struct dquot___259 *);
	int (*get_next_id)(struct super_block___259 *, struct kqid *);
};

struct dquot_operations___259 {
	int (*write_dquot)(struct dquot___259 *);
	struct dquot___259 * (*alloc_dquot)(struct super_block___259 *, int);
	void (*destroy_dquot)(struct dquot___259 *);
	int (*acquire_dquot)(struct dquot___259 *);
	int (*release_dquot)(struct dquot___259 *);
	int (*mark_dirty)(struct dquot___259 *);
	int (*write_info)(struct super_block___259 *, int);
	qsize_t * (*get_reserved_space)(struct inode___259 *);
	int (*get_projid)(struct inode___259 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___259 *, qsize_t *);
	int (*get_next_id)(struct super_block___259 *, struct kqid *);
};

struct quotactl_ops___259 {
	int (*quota_on)(struct super_block___259 *, int, int, const struct path___259 *);
	int (*quota_off)(struct super_block___259 *, int);
	int (*quota_enable)(struct super_block___259 *, unsigned int);
	int (*quota_disable)(struct super_block___259 *, unsigned int);
	int (*quota_sync)(struct super_block___259 *, int);
	int (*set_info)(struct super_block___259 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___259 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___259 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___259 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___259 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___259 *, unsigned int);
};

struct writeback_control___136;

struct address_space_operations___259 {
	int (*writepage)(struct page___264 *, struct writeback_control___136 *);
	int (*readpage)(struct file___259 *, struct page___264 *);
	int (*writepages)(struct address_space___259 *, struct writeback_control___136 *);
	int (*set_page_dirty)(struct page___264 *);
	int (*readpages)(struct file___259 *, struct address_space___259 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___259 *, struct address_space___259 *, loff_t, unsigned int, unsigned int, struct page___264 **, void **);
	int (*write_end)(struct file___259 *, struct address_space___259 *, loff_t, unsigned int, unsigned int, struct page___264 *, void *);
	sector_t (*bmap)(struct address_space___259 *, sector_t);
	void (*invalidatepage)(struct page___264 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___264 *, gfp_t);
	void (*freepage)(struct page___264 *);
	ssize_t (*direct_IO)(struct kiocb___259 *, struct iov_iter___179 *);
	int (*migratepage)(struct address_space___259 *, struct page___264 *, struct page___264 *, enum migrate_mode);
	bool (*isolate_page)(struct page___264 *, isolate_mode_t);
	void (*putback_page)(struct page___264 *);
	int (*launder_page)(struct page___264 *);
	int (*is_partially_uptodate)(struct page___264 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___264 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___259 *, struct page___264 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___259 *, sector_t *);
	void (*swap_deactivate)(struct file___259 *);
};

struct writeback_control___136 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___136 *wb;
	struct inode___259 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___176;

struct iov_iter___179 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___176 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___100 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___259 {
	struct dentry___259 * (*lookup)(struct inode___259 *, struct dentry___259 *, unsigned int);
	const char * (*get_link)(struct dentry___259 *, struct inode___259 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___259 *, int);
	struct posix_acl * (*get_acl)(struct inode___259 *, int, bool);
	int (*readlink)(struct dentry___259 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___259 *, struct dentry___259 *, umode_t, bool);
	int (*link)(struct dentry___259 *, struct inode___259 *, struct dentry___259 *);
	int (*unlink)(struct inode___259 *, struct dentry___259 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___259 *, struct dentry___259 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___259 *, struct dentry___259 *, umode_t);
	int (*rmdir)(struct inode___259 *, struct dentry___259 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___259 *, struct dentry___259 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___259 *, struct dentry___259 *, struct inode___259 *, struct dentry___259 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___259 *, struct iattr___259 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___259 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___259 *, char *, size_t);
	int (*fiemap)(struct inode___259 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___259 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___259 *, struct dentry___259 *, struct file___259 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___259 *, struct dentry___259 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___259 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___259 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___259 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___259 {
	void (*fl_copy_lock)(struct file_lock___259 *, struct file_lock___259 *);
	void (*fl_release_private)(struct file_lock___259 *);
};

struct lock_manager_operations___259;

struct file_lock___259 {
	struct file_lock___259 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___259 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___259 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___259 *fl_ops;
	const struct lock_manager_operations___259 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___259 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___259 *);
	int (*lm_grant)(struct file_lock___259 *, int);
	bool (*lm_break)(struct file_lock___259 *);
	int (*lm_change)(struct file_lock___259 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___259 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___259 *);
};

struct fasync_struct___259 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___259 *fa_next;
	struct file___259 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___259 {
	struct inode___259 * (*alloc_inode)(struct super_block___259 *);
	void (*destroy_inode)(struct inode___259 *);
	void (*free_inode)(struct inode___259 *);
	void (*dirty_inode)(struct inode___259 *, int);
	int (*write_inode)(struct inode___259 *, struct writeback_control___136 *);
	int (*drop_inode)(struct inode___259 *);
	void (*evict_inode)(struct inode___259 *);
	void (*put_super)(struct super_block___259 *);
	int (*sync_fs)(struct super_block___259 *, int);
	int (*freeze_super)(struct super_block___259 *);
	int (*freeze_fs)(struct super_block___259 *);
	int (*thaw_super)(struct super_block___259 *);
	int (*unfreeze_fs)(struct super_block___259 *);
	int (*statfs)(struct dentry___259 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___259 *, int *, char *);
	void (*umount_begin)(struct super_block___259 *);
	int (*show_options)(struct seq_file___234 *, struct dentry___259 *);
	int (*show_devname)(struct seq_file___234 *, struct dentry___259 *);
	int (*show_path)(struct seq_file___234 *, struct dentry___259 *);
	int (*show_stats)(struct seq_file___234 *, struct dentry___259 *);
	ssize_t (*quota_read)(struct super_block___259 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___259 *, int, const char *, size_t, loff_t);
	struct dquot___259 ** (*get_dquots)(struct inode___259 *);
	long int (*nr_cached_objects)(struct super_block___259 *, struct shrink_control___124 *);
	long int (*free_cached_objects)(struct super_block___259 *, struct shrink_control___124 *);
	struct file___259 * (*real_loop)(struct file___259 *);
};

struct wakeup_source___240;

struct dev_pm_info___240 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___240 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___240 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___240;

struct bus_type___240;

struct device_driver___240;

struct dev_pm_domain___240;

struct fwnode_handle___236;

struct class___240;

struct attribute_group___247;

struct device___240 {
	struct kobject___247 kobj;
	struct device___240 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___240 *type;
	struct bus_type___240 *bus;
	struct device_driver___240 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___240 power;
	struct dev_pm_domain___240 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___236 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___240 *class;
	const struct attribute_group___247 **groups;
	void (*release)(struct device___240 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___153 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___259 *bd_inode;
	struct super_block___259 *bd_super;
	void *bd_claiming;
	struct device___240 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___247 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___153 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___259 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___188)(struct file___259 *, wait_queue_head_t *, struct poll_table_struct___180 *);

struct poll_table_struct___180 {
	poll_queue_proc___188 _qproc;
	__poll_t _key;
};

struct seq_operations___234;

struct seq_file___234 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___234 *op;
	int poll_event;
	const struct file___259 *file;
	void *private;
};

typedef void bio_end_io_t___150(struct bio___150 *);

struct bio_vec___176 {
	struct page___264 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___150;

struct bio___150 {
	struct bio___150 *bi_next;
	struct block_device___153 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___150 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___138 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___150 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___176 *bi_io_vec;
	struct bio_set___150 *bi_pool;
	struct bio_vec___176 bi_inline_vecs[0];
};

struct dev_pagemap_ops___254 {
	void (*page_free)(struct page___264 *);
	void (*kill)(struct dev_pagemap___254 *);
	void (*cleanup)(struct dev_pagemap___254 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___254 *);
};

struct fwnode_operations___236;

struct fwnode_handle___236 {
	struct fwnode_handle___236 *secondary;
	const struct fwnode_operations___236 *ops;
	struct device___240 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___236;

struct fwnode_endpoint___236;

struct fwnode_operations___236 {
	struct fwnode_handle___236 * (*get)(struct fwnode_handle___236 *);
	void (*put)(struct fwnode_handle___236 *);
	bool (*device_is_available)(const struct fwnode_handle___236 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___236 *, const struct device___240 *);
	bool (*property_present)(const struct fwnode_handle___236 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___236 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___236 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___236 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*get_parent)(const struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*get_next_child_node)(const struct fwnode_handle___236 *, struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*get_named_child_node)(const struct fwnode_handle___236 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___236 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___236 *);
	struct fwnode_handle___236 * (*graph_get_next_endpoint)(const struct fwnode_handle___236 *, struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*graph_get_remote_endpoint)(const struct fwnode_handle___236 *);
	struct fwnode_handle___236 * (*graph_get_port_parent)(struct fwnode_handle___236 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___236 *, struct fwnode_endpoint___236 *);
	int (*add_links)(struct fwnode_handle___236 *);
};

struct fwnode_endpoint___236 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___236 *local_fwnode;
};

struct fwnode_reference_args___236 {
	struct fwnode_handle___236 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___247;

struct kernfs_elem_dir___247 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___247 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___247;

struct kernfs_root___247 {
	struct kernfs_node___247 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___247 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___247 {
	struct kernfs_node___247 *target_kn;
};

struct kernfs_ops___247;

struct kernfs_elem_attr___247 {
	const struct kernfs_ops___247 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___247 *notify_next;
};

struct kernfs_node___247 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___247 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___247 dir;
		struct kernfs_elem_symlink___247 symlink;
		struct kernfs_elem_attr___247 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___247;

struct kernfs_ops___247 {
	int (*open)(struct kernfs_open_file___247 *);
	void (*release)(struct kernfs_open_file___247 *);
	int (*seq_show)(struct seq_file___234 *, void *);
	void * (*seq_start)(struct seq_file___234 *, loff_t *);
	void * (*seq_next)(struct seq_file___234 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___234 *, void *);
	ssize_t (*read)(struct kernfs_open_file___247 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___247 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___247 *, struct poll_table_struct___180 *);
	int (*mmap)(struct kernfs_open_file___247 *, struct vm_area_struct___264 *);
};

struct kernfs_syscall_ops___247 {
	int (*show_options)(struct seq_file___234 *, struct kernfs_root___247 *);
	int (*mkdir)(struct kernfs_node___247 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___247 *);
	int (*rename)(struct kernfs_node___247 *, struct kernfs_node___247 *, const char *);
	int (*show_path)(struct seq_file___234 *, struct kernfs_node___247 *, struct kernfs_root___247 *);
};

struct kernfs_open_file___247 {
	struct kernfs_node___247 *kn;
	struct file___259 *file;
	struct seq_file___234 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___254 *vm_ops;
};

struct sock___55;

struct kobj_ns_type_operations___55 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___55 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___73 *net;
} possible_net_t___68;

struct proto___55;

struct sock_common___55 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___55 *skc_prot;
	possible_net_t___68 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___55 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___69;

struct sk_buff_head___68 {
	struct sk_buff___69 *next;
	struct sk_buff___69 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___55 {
	struct cgroup___186 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___55;

struct socket_wq___56;

struct dst_entry___55;

struct socket___57;

struct net_device___68;

struct sock___55 {
	struct sock_common___55 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___68 sk_error_queue;
	struct sk_buff___69 *sk_rx_skb_cache;
	struct sk_buff_head___68 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___69 *head;
		struct sk_buff___69 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___55 *sk_filter;
	union {
		struct socket_wq___56 *sk_wq;
		struct socket_wq___56 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___55 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___55 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___69 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___69 *sk_tx_skb_cache;
	struct sk_buff_head___68 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___264 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___55 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___236 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___57 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___55 sk_cgrp_data;
	struct mem_cgroup___124 *sk_memcg;
	void (*sk_state_change)(struct sock___55 *);
	void (*sk_data_ready)(struct sock___55 *);
	void (*sk_write_space)(struct sock___55 *);
	void (*sk_error_report)(struct sock___55 *);
	int (*sk_backlog_rcv)(struct sock___55 *, struct sk_buff___69 *);
	struct sk_buff___69 * (*sk_validate_xmit_skb)(struct sock___55 *, struct net_device___68 *, struct sk_buff___69 *);
	void (*sk_destruct)(struct sock___55 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___247;

struct attribute_group___247 {
	const char *name;
	umode_t (*is_visible)(struct kobject___247 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___247 *, struct bin_attribute___247 *, int);
	struct attribute **attrs;
	struct bin_attribute___247 **bin_attrs;
};

struct bin_attribute___247 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___259 * (*f_mapping)();
	ssize_t (*read)(struct file___259 *, struct kobject___247 *, struct bin_attribute___247 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___259 *, struct kobject___247 *, struct bin_attribute___247 *, char *, loff_t, size_t);
	int (*mmap)(struct file___259 *, struct kobject___247 *, struct bin_attribute___247 *, struct vm_area_struct___264 *);
};

struct sysfs_ops___247 {
	ssize_t (*show)(struct kobject___247 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___247 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___247;

struct kset___247 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___247 kobj;
	const struct kset_uevent_ops___247 *uevent_ops;
};

struct kobj_type___247 {
	void (*release)(struct kobject___247 *);
	const struct sysfs_ops___247 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___247 **default_groups;
	const struct kobj_ns_type_operations___55 * (*child_ns_type)(struct kobject___247 *);
	const void * (*namespace)(struct kobject___247 *);
	void (*get_ownership)(struct kobject___247 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___247 {
	int (* const filter)(struct kset___247 *, struct kobject___247 *);
	const char * (* const name)(struct kset___247 *, struct kobject___247 *);
	int (* const uevent)(struct kset___247 *, struct kobject___247 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___243 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___243 *);
	int (*get)(char *, const struct kernel_param___243 *);
	void (*free)(void *);
};

struct kparam_array___243;

struct kernel_param___243 {
	const char *name;
	struct module___243 *mod;
	const struct kernel_param_ops___243 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___243 *arr;
	};
};

struct kparam_array___243 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___243 *ops;
	void *elem;
};

struct module_attribute___243 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___243 *, struct module_kobject___244 *, char *);
	ssize_t (*store)(struct module_attribute___243 *, struct module_kobject___244 *, const char *, size_t);
	void (*setup)(struct module___243 *, const char *);
	int (*test)(struct module___243 *);
	void (*free)(struct module___243 *);
};

struct trace_event_class___80;

struct trace_event_call___80 {
	struct list_head list;
	struct trace_event_class___80 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___62 *prog_array;
	int (*perf_perm)(struct trace_event_call___80 *, struct perf_event___86 *);
};

struct ip_ra_chain___31;

struct fib_rules_ops___55;

struct fqdir___73;

struct fib_notifier_ops___55;

struct netns_ipv4___73 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___31 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___55 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___55 *fibnl;
	struct sock___55 **icmp_sk;
	struct sock___55 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___55 **tcp_sk;
	struct fqdir___73 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___55 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___55 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___55 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___55;

struct dst_ops___73 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___73 *);
	struct dst_entry___55 * (*check)(struct dst_entry___55 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___55 *);
	unsigned int (*mtu)(const struct dst_entry___55 *);
	u32 * (*cow_metrics)(struct dst_entry___55 *, long unsigned int);
	void (*destroy)(struct dst_entry___55 *);
	void (*ifdown)(struct dst_entry___55 *, struct net_device___68 *, int);
	struct dst_entry___55 * (*negative_advice)(struct dst_entry___55 *);
	void (*link_failure)(struct sk_buff___69 *);
	void (*update_pmtu)(struct dst_entry___55 *, struct sock___55 *, struct sk_buff___69 *, u32, bool);
	void (*redirect)(struct dst_entry___55 *, struct sock___55 *, struct sk_buff___69 *);
	int (*local_out)(struct net___73 *, struct sock___55 *, struct sk_buff___69 *);
	struct neighbour___55 * (*neigh_lookup)(const struct dst_entry___55 *, struct sk_buff___69 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___55 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___73 {
	struct dst_ops___73 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___73 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___55 *fib6_rules_ops;
	struct sock___55 **icmp_sk;
	struct sock___55 *ndisc_sk;
	struct sock___55 *tcp_sk;
	struct sock___55 *igmp_sk;
	struct sock___55 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___55 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___55 *notifier_ops;
	struct fib_notifier_ops___55 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___73 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___73 *fqdir;
};

struct netns_sctp___55 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___55 *ctl_sock;
	struct sock___55 *udp4_sock;
	struct sock___55 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___62 {
	struct bpf_prog_array___62 *run_array[2];
	struct bpf_prog___62 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___73 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___55 *nlsk;
	struct sock___55 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___73 xfrm4_dst_ops;
	struct dst_ops___73 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___73 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___55 *rtnl;
	struct sock___55 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___68 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___73 ipv4;
	struct netns_ipv6___73 ipv6;
	struct netns_ieee802154_lowpan___73 ieee802154_lowpan;
	struct netns_sctp___55 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___68 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___62 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___73 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___55 *crypto_nlsk;
	struct sock___55 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___186 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___186 *root_cset;
};

struct msghdr___57 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___179 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___259 *msg_iocb;
};

struct socket_wq___56 {
	wait_queue_head_t wait;
	struct fasync_struct___259 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___56;

struct socket___57 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___259 *file;
	struct sock___55 *sk;
	const struct proto_ops___56 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___56 wq;
};

typedef int (*sk_read_actor_t___55)(read_descriptor_t *, struct sk_buff___69 *, unsigned int, size_t);

struct proto_ops___56 {
	int family;
	struct module___243 *owner;
	int (*release)(struct socket___57 *);
	int (*bind)(struct socket___57 *, struct sockaddr *, int);
	int (*connect)(struct socket___57 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___57 *, struct socket___57 *);
	int (*accept)(struct socket___57 *, struct socket___57 *, int, bool);
	int (*getname)(struct socket___57 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___259 *, struct socket___57 *, struct poll_table_struct___180 *);
	int (*ioctl)(struct socket___57 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___57 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___57 *, void *, bool, bool);
	int (*listen)(struct socket___57 *, int);
	int (*shutdown)(struct socket___57 *, int);
	int (*setsockopt)(struct socket___57 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___57 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___234 *, struct socket___57 *);
	int (*sendmsg)(struct socket___57 *, struct msghdr___57 *, size_t);
	int (*recvmsg)(struct socket___57 *, struct msghdr___57 *, size_t, int);
	int (*mmap)(struct file___259 *, struct socket___57 *, struct vm_area_struct___264 *);
	ssize_t (*sendpage)(struct socket___57 *, struct page___264 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___57 *, loff_t *, struct pipe_inode_info___100 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___55 *, int);
	int (*peek_len)(struct socket___57 *);
	int (*read_sock)(struct sock___55 *, read_descriptor_t *, sk_read_actor_t___55);
	int (*sendpage_locked)(struct sock___55 *, struct page___264 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___55 *, struct msghdr___57 *, size_t);
	int (*set_rcvlowat)(struct sock___55 *, int);
};

struct sk_buff___69 {
	union {
		struct {
			struct sk_buff___69 *next;
			struct sk_buff___69 *prev;
			union {
				struct net_device___68 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___55 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___69 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___240 {
	int (*prepare)(struct device___240 *);
	void (*complete)(struct device___240 *);
	int (*suspend)(struct device___240 *);
	int (*resume)(struct device___240 *);
	int (*freeze)(struct device___240 *);
	int (*thaw)(struct device___240 *);
	int (*poweroff)(struct device___240 *);
	int (*restore)(struct device___240 *);
	int (*suspend_late)(struct device___240 *);
	int (*resume_early)(struct device___240 *);
	int (*freeze_late)(struct device___240 *);
	int (*thaw_early)(struct device___240 *);
	int (*poweroff_late)(struct device___240 *);
	int (*restore_early)(struct device___240 *);
	int (*suspend_noirq)(struct device___240 *);
	int (*resume_noirq)(struct device___240 *);
	int (*freeze_noirq)(struct device___240 *);
	int (*thaw_noirq)(struct device___240 *);
	int (*poweroff_noirq)(struct device___240 *);
	int (*restore_noirq)(struct device___240 *);
	int (*runtime_suspend)(struct device___240 *);
	int (*runtime_resume)(struct device___240 *);
	int (*runtime_idle)(struct device___240 *);
};

struct wakeup_source___240 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___240 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___240 {
	struct dev_pm_ops___240 ops;
	int (*start)(struct device___240 *);
	void (*detach)(struct device___240 *, bool);
	int (*activate)(struct device___240 *);
	void (*sync)(struct device___240 *);
	void (*dismiss)(struct device___240 *);
};

struct bus_type___240 {
	const char *name;
	const char *dev_name;
	struct device___240 *dev_root;
	const struct attribute_group___247 **bus_groups;
	const struct attribute_group___247 **dev_groups;
	const struct attribute_group___247 **drv_groups;
	int (*match)(struct device___240 *, struct device_driver___240 *);
	int (*uevent)(struct device___240 *, struct kobj_uevent_env *);
	int (*probe)(struct device___240 *);
	void (*sync_state)(struct device___240 *);
	void (*remove)(struct device___240 *);
	void (*shutdown)(struct device___240 *);
	int (*online)(struct device___240 *);
	int (*offline)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	int (*num_vf)(struct device___240 *);
	int (*dma_configure)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___240 {
	const char *name;
	struct bus_type___240 *bus;
	struct module___243 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___240 *);
	void (*sync_state)(struct device___240 *);
	int (*remove)(struct device___240 *);
	void (*shutdown)(struct device___240 *);
	int (*suspend)(struct device___240 *, pm_message_t);
	int (*resume)(struct device___240 *);
	const struct attribute_group___247 **groups;
	const struct attribute_group___247 **dev_groups;
	const struct dev_pm_ops___240 *pm;
	void (*coredump)(struct device___240 *);
	struct driver_private *p;
};

struct device_type___240 {
	const char *name;
	const struct attribute_group___247 **groups;
	int (*uevent)(struct device___240 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___240 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___240 *);
	const struct dev_pm_ops___240 *pm;
};

struct class___240 {
	const char *name;
	struct module___243 *owner;
	const struct attribute_group___247 **class_groups;
	const struct attribute_group___247 **dev_groups;
	struct kobject___247 *dev_kobj;
	int (*dev_uevent)(struct device___240 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___240 *, umode_t *);
	void (*class_release)(struct class___240 *);
	void (*dev_release)(struct device___240 *);
	int (*shutdown_pre)(struct device___240 *);
	const struct kobj_ns_type_operations___55 *ns_type;
	const void * (*namespace)(struct device___240 *);
	void (*get_ownership)(struct device___240 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___240 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___100;

struct pipe_buffer___100 {
	struct page___264 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___100 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___100 {
	int (*confirm)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
	void (*release)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
	bool (*try_steal)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
	bool (*get)(struct pipe_inode_info___100 *, struct pipe_buffer___100 *);
};

typedef rx_handler_result_t rx_handler_func_t___68(struct sk_buff___69 **);

struct bpf_xdp_entity___62 {
	struct bpf_prog___62 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___68;

struct net_device_ops___68;

struct l3mdev_ops___55;

struct ndisc_ops___39;

struct xfrmdev_ops___68;

struct header_ops___68;

struct inet6_dev___39;

struct netdev_rx_queue___68;

struct mini_Qdisc___62;

struct netdev_queue___68;

struct Qdisc___62;

struct rtnl_link_ops___62;

struct dcbnl_rtnl_ops___68;

struct net_device___68 {
	char name[16];
	struct netdev_name_node___68 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___68 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___55 *l3mdev_ops;
	const struct ndisc_ops___39 *ndisc_ops;
	const struct xfrmdev_ops___68 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___68 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___247 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___39 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___68 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___62 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___68 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___62 *miniq_ingress;
	struct netdev_queue___68 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___68 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___62 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___62 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___68 = 0,
		NETREG_REGISTERED___68 = 1,
		NETREG_UNREGISTERING___68 = 2,
		NETREG_UNREGISTERED___68 = 3,
		NETREG_RELEASED___68 = 4,
		NETREG_DUMMY___68 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___68 = 0,
		RTNL_LINK_INITIALIZING___68 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___68 *);
	struct netpoll_info *npinfo;
	possible_net_t___68 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___240 dev;
	const struct attribute_group___247 *sysfs_groups[4];
	const struct attribute_group___247 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___62 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___68 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___62 xdp_state[3];
	long: 64;
};

struct inet_frags___73;

struct fqdir___73 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___73 *f;
	struct net___73 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___73;

struct inet_frags___73 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___73 *, const void *);
	void (*destructor)(struct inet_frag_queue___73 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___73 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___69 *fragments_tail;
	struct sk_buff___69 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___73 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___31 {
	struct ip_ra_chain___31 *next;
	struct sock___55 *sk;
	union {
		void (*destructor)(struct sock___55 *);
		struct sock___55 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___55;

struct fib_lookup_arg___55;

struct fib_rules_ops___55 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___55 *, struct flowi *, int, struct fib_lookup_arg___55 *);
	bool (*suppress)(struct fib_rule___55 *, int, struct fib_lookup_arg___55 *);
	int (*match)(struct fib_rule___55 *, struct flowi *, int);
	int (*configure)(struct fib_rule___55 *, struct sk_buff___69 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___55 *);
	int (*compare)(struct fib_rule___55 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___55 *, struct sk_buff___69 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___55 *);
	void (*flush_cache)(struct fib_rules_ops___55 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___243 *owner;
	struct net___73 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___55 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___73 *);
	int (*fib_dump)(struct net___73 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___243 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___33;

struct dst_entry___55 {
	struct net_device___68 *dev;
	struct dst_ops___73 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___69 *);
	int (*output)(struct net___73 *, struct sock___55 *, struct sk_buff___69 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___33 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___55;

struct neigh_parms___55;

struct neigh_ops___55;

struct neighbour___55 {
	struct neighbour___55 *next;
	struct neigh_table___55 *tbl;
	struct neigh_parms___55 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___68 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___55 *, struct sk_buff___69 *);
	const struct neigh_ops___55 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___68 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___62 {
	struct bpf_prog___62 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___62 {
	struct callback_head rcu;
	struct bpf_prog_array_item___62 items[0];
};

struct bpf_prog_aux___71;

struct bpf_prog___62 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___71 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___234 {
	void * (*start)(struct seq_file___234 *, loff_t *);
	void (*stop)(struct seq_file___234 *, void *);
	void * (*next)(struct seq_file___234 *, void *, loff_t *);
	int (*show)(struct seq_file___234 *, void *);
};

struct dcbnl_rtnl_ops___68 {
	int (*ieee_getets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___68 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___68 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___68 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___68 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___68 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___68 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___68 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___68 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___68 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___68 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___68 *);
	u8 (*setstate)(struct net_device___68 *, u8);
	void (*getpermhwaddr)(struct net_device___68 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___68 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___68 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___68 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___68 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___68 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___68 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___68 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___68 *, int, u8 *);
	void (*setpfccfg)(struct net_device___68 *, int, u8);
	void (*getpfccfg)(struct net_device___68 *, int, u8 *);
	u8 (*setall)(struct net_device___68 *);
	u8 (*getcap)(struct net_device___68 *, int, u8 *);
	int (*getnumtcs)(struct net_device___68 *, int, u8 *);
	int (*setnumtcs)(struct net_device___68 *, int, u8);
	u8 (*getpfcstate)(struct net_device___68 *);
	void (*setpfcstate)(struct net_device___68 *, u8);
	void (*getbcncfg)(struct net_device___68 *, int, u32 *);
	void (*setbcncfg)(struct net_device___68 *, int, u32);
	void (*getbcnrp)(struct net_device___68 *, int, u8 *);
	void (*setbcnrp)(struct net_device___68 *, int, u8);
	int (*setapp)(struct net_device___68 *, u8, u16, u8);
	int (*getapp)(struct net_device___68 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___68 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___68 *, int, u8);
	u8 (*getdcbx)(struct net_device___68 *);
	u8 (*setdcbx)(struct net_device___68 *, u8);
	int (*peer_getappinfo)(struct net_device___68 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___68 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___68 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___68 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___68 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___68 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___71;

typedef int (*bpf_iter_init_seq_priv_t___70)(void *, struct bpf_iter_aux_info___71 *);

struct bpf_map___71;

struct bpf_iter_aux_info___71 {
	struct bpf_map___71 *map;
};

struct bpf_iter_seq_info___70 {
	const struct seq_operations___234 *seq_ops;
	bpf_iter_init_seq_priv_t___70 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___70 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___71 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___71 *, struct file___259 *);
	void (*map_free)(struct bpf_map___71 *);
	int (*map_get_next_key)(struct bpf_map___71 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___71 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___71 *, void *);
	int (*map_lookup_batch)(struct bpf_map___71 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___71 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___71 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___71 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___71 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___71 *, void *);
	int (*map_update_elem)(struct bpf_map___71 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___71 *, void *);
	int (*map_push_elem)(struct bpf_map___71 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___71 *, void *);
	int (*map_peek_elem)(struct bpf_map___71 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___71 *, struct file___259 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___71 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___71 *, void *, struct seq_file___234 *);
	int (*map_check_btf)(const struct bpf_map___71 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___71 *, struct bpf_prog_aux___71 *);
	void (*map_poke_untrack)(struct bpf_map___71 *, struct bpf_prog_aux___71 *);
	void (*map_poke_run)(struct bpf_map___71 *, u32, struct bpf_prog___62 *, struct bpf_prog___62 *);
	int (*map_direct_value_addr)(const struct bpf_map___71 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___71 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___71 *, struct vm_area_struct___264 *);
	__poll_t (*map_poll)(struct bpf_map___71 *, struct file___259 *, struct poll_table_struct___180 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___71 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___71 *, const struct bpf_map___71 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___71 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___70 *iter_seq_info;
};

struct bpf_map___71 {
	const struct bpf_map_ops___70 *ops;
	struct bpf_map___71 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___124 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___70;

struct bpf_jit_poke_descriptor___70;

struct bpf_prog_ops___62;

struct btf_mod_pair___70;

struct bpf_prog_offload___68;

struct bpf_prog_aux___71 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___62 *dst_prog;
	struct bpf_trampoline___70 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___62 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___70 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___62 *ops;
	struct bpf_map___71 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___70 *used_btfs;
	struct bpf_prog___62 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___71 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___68 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___68;

struct bpf_map_dev_ops___68 {
	int (*map_get_next_key)(struct bpf_offloaded_map___68 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___68 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___68 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___68 *, void *);
};

struct bpf_offloaded_map___68 {
	struct bpf_map___71 map;
	struct net_device___68 *netdev;
	const struct bpf_map_dev_ops___68 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___62 {
	int (*test_run)(struct bpf_prog___62 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___68 {
	struct bpf_prog___62 *prog;
	struct net_device___68 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___70 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___62 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___243 *mod;
};

struct bpf_jit_poke_descriptor___70 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___71 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___70 {
	struct btf *btf;
	struct module___243 *module;
};

struct cftype___186;

struct cgroup_subsys___186 {
	struct cgroup_subsys_state___186 * (*css_alloc)(struct cgroup_subsys_state___186 *);
	int (*css_online)(struct cgroup_subsys_state___186 *);
	void (*css_offline)(struct cgroup_subsys_state___186 *);
	void (*css_released)(struct cgroup_subsys_state___186 *);
	void (*css_free)(struct cgroup_subsys_state___186 *);
	void (*css_reset)(struct cgroup_subsys_state___186 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___186 *, int);
	int (*css_extra_stat_show)(struct seq_file___234 *, struct cgroup_subsys_state___186 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___266 *, struct css_set___186 *);
	void (*cancel_fork)(struct task_struct___266 *, struct css_set___186 *);
	void (*fork)(struct task_struct___266 *);
	void (*exit)(struct task_struct___266 *);
	void (*release)(struct task_struct___266 *);
	void (*bind)(struct cgroup_subsys_state___186 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___186 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___186 *dfl_cftypes;
	struct cftype___186 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___186 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___186 *updated_children;
	struct cgroup___186 *updated_next;
};

struct cgroup_root___186 {
	struct kernfs_root___247 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___186 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___186 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___186 *ss;
	struct list_head node;
	struct kernfs_ops___247 *kf_ops;
	int (*open)(struct kernfs_open_file___247 *);
	void (*release)(struct kernfs_open_file___247 *);
	u64 (*read_u64)(struct cgroup_subsys_state___186 *, struct cftype___186 *);
	s64 (*read_s64)(struct cgroup_subsys_state___186 *, struct cftype___186 *);
	int (*seq_show)(struct seq_file___234 *, void *);
	void * (*seq_start)(struct seq_file___234 *, loff_t *);
	void * (*seq_next)(struct seq_file___234 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___234 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___186 *, struct cftype___186 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___186 *, struct cftype___186 *, s64);
	ssize_t (*write)(struct kernfs_open_file___247 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___247 *, struct poll_table_struct___180 *);
};

struct xdp_rxq_info___68 {
	struct net_device___68 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___68 {
	struct net_device___68 *dev;
};

struct xdp_buff___68 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___68 *rxq;
	struct xdp_txq_info___68 *txq;
	u32 frame_sz;
};

struct xdp_frame___68 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___68 *dev_rx;
};

struct scm_fp_list___3 {
	short int count;
	short int max;
	struct user_struct *user;
	struct file___259 *fp[253];
};

struct scm_cookie___2 {
	struct pid___236 *pid;
	struct scm_fp_list___3 *fp;
	struct scm_creds creds;
	struct lsmblob lsmblob;
};

struct netlink_callback___68 {
	struct sk_buff___69 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___69 *, struct netlink_callback___68 *);
	int (*done)(struct netlink_callback___68 *);
	void *data;
	struct module___243 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___68 {
	int (*create)(struct sk_buff___69 *, struct net_device___68 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___69 *, unsigned char *);
	int (*cache)(const struct neighbour___55 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___68 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___69 *);
};

struct netdev_queue___68 {
	struct net_device___68 *dev;
	struct Qdisc___62 *qdisc;
	struct Qdisc___62 *qdisc_sleeping;
	struct kobject___247 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___68 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___62 {
	struct sk_buff___69 *head;
	struct sk_buff___69 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___62;

struct Qdisc___62 {
	int (*enqueue)(struct sk_buff___69 *, struct Qdisc___62 *, struct sk_buff___69 **);
	struct sk_buff___69 * (*dequeue)(struct Qdisc___62 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___62 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___68 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___68 gso_skb;
	struct qdisc_skb_head___62 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___62 *next_sched;
	struct sk_buff_head___68 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___68 {
	struct xdp_rxq_info___68 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___247 kobj;
	struct net_device___68 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___68 {
	enum net_device_path_type type;
	const struct net_device___68 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___68 = 0,
				DEV_PATH_BR_VLAN_TAG___68 = 1,
				DEV_PATH_BR_VLAN_UNTAG___68 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___68 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___68 {
	const struct net_device___68 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___68 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___62 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___68 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___68 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___69 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___68 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___68 *dev;
	const char *name;
};

struct net_device_ops___68 {
	int (*ndo_init)(struct net_device___68 *);
	void (*ndo_uninit)(struct net_device___68 *);
	int (*ndo_open)(struct net_device___68 *);
	int (*ndo_stop)(struct net_device___68 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___69 *, struct net_device___68 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___69 *, struct net_device___68 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___68 *, struct sk_buff___69 *, struct net_device___68 *);
	void (*ndo_change_rx_flags)(struct net_device___68 *, int);
	void (*ndo_set_rx_mode)(struct net_device___68 *);
	int (*ndo_set_mac_address)(struct net_device___68 *, void *);
	int (*ndo_validate_addr)(struct net_device___68 *);
	int (*ndo_do_ioctl)(struct net_device___68 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___68 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___68 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___68 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___68 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___68 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___68 *, int);
	int (*ndo_neigh_setup)(struct net_device___68 *, struct neigh_parms___55 *);
	void (*ndo_tx_timeout)(struct net_device___68 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___68 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___68 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___68 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___68 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___68 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___68 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___68 *);
	int (*ndo_netpoll_setup)(struct net_device___68 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___68 *);
	int (*ndo_set_vf_mac)(struct net_device___68 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___68 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___68 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___68 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___68 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___68 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___68 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___68 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___68 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___68 *, int, struct sk_buff___69 *);
	int (*ndo_get_vf_guid)(struct net_device___68 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___68 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___68 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___68 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___68 *);
	int (*ndo_fcoe_disable)(struct net_device___68 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___68 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___68 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___68 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___68 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___68 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___68 *, const struct sk_buff___69 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___68 *, struct net_device___68 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___68 *, struct net_device___68 *);
	struct net_device___68 * (*ndo_get_xmit_slave)(struct net_device___68 *, struct sk_buff___69 *, bool);
	struct net_device___68 * (*ndo_sk_get_lower_dev)(struct net_device___68 *, struct sock___55 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___68 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___68 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___68 *, struct neighbour___55 *);
	void (*ndo_neigh_destroy)(struct net_device___68 *, struct neighbour___55 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___69 *, struct netlink_callback___68 *, struct net_device___68 *, struct net_device___68 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___69 *, struct nlattr **, struct net_device___68 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___68 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___69 *, u32, u32, struct net_device___68 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___68 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___68 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___68 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___68 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___68 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___68 *, struct net_device___68 *);
	void (*ndo_dfwd_del_station)(struct net_device___68 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___68 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___68 *);
	int (*ndo_change_proto_down)(struct net_device___68 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___68 *, struct sk_buff___69 *);
	void (*ndo_set_rx_headroom)(struct net_device___68 *, int);
	int (*ndo_bpf)(struct net_device___68 *, struct netdev_bpf___68 *);
	int (*ndo_xdp_xmit)(struct net_device___68 *, int, struct xdp_frame___68 **, u32);
	struct net_device___68 * (*ndo_xdp_get_xmit_slave)(struct net_device___68 *, struct xdp_buff___68 *);
	int (*ndo_xsk_wakeup)(struct net_device___68 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___68 *);
	int (*ndo_tunnel_ctl)(struct net_device___68 *, struct ip_tunnel_parm *, int);
	struct net_device___68 * (*ndo_get_peer_dev)(struct net_device___68 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___68 *, struct net_device_path___68 *);
};

struct neigh_parms___55 {
	possible_net_t___68 net;
	struct net_device___68 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___55 *);
	struct neigh_table___55 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___55 {
	u32 (*l3mdev_fib_table)(const struct net_device___68 *);
	struct sk_buff___69 * (*l3mdev_l3_rcv)(struct net_device___68 *, struct sk_buff___69 *, u16);
	struct sk_buff___69 * (*l3mdev_l3_out)(struct net_device___68 *, struct sock___55 *, struct sk_buff___69 *, u16);
	struct dst_entry___55 * (*l3mdev_link_scope_lookup)(const struct net_device___68 *, struct flowi6 *);
};

struct ndisc_ops___39 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___68 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___68 *, struct neighbour___55 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___68 *, u8, struct neighbour___55 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___68 *, struct sk_buff___69 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___73 *, struct net_device___68 *, const struct prefix_info *, struct inet6_dev___39 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___39;

struct inet6_dev___39 {
	struct net_device___68 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___39 *mc_list;
	struct ifmcaddr6___39 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___68 mc_query_queue;
	struct sk_buff_head___68 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___10 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___55 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___62;

struct tcf_block___62;

struct mini_Qdisc___62 {
	struct tcf_proto___62 *filter_list;
	struct tcf_block___62 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___62 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___68 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___68 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___73 *, struct net_device___68 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___68 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___68 *, struct list_head *);
	size_t (*get_size)(const struct net_device___68 *);
	int (*fill_info)(struct sk_buff___69 *, const struct net_device___68 *);
	size_t (*get_xstats_size)(const struct net_device___68 *);
	int (*fill_xstats)(struct sk_buff___69 *, const struct net_device___68 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___68 *, struct net_device___68 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___68 *, const struct net_device___68 *);
	int (*fill_slave_info)(struct sk_buff___69 *, const struct net_device___68 *, const struct net_device___68 *);
	struct net___73 * (*get_link_net)(const struct net_device___68 *);
	size_t (*get_linkxstats_size)(const struct net_device___68 *, int);
	int (*fill_linkxstats)(struct sk_buff___69 *, const struct net_device___68 *, int *, int);
};

struct block_device_operations___150;

struct gendisk___153 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___153 *part0;
	const struct block_device_operations___150 *fops;
	struct request_queue___150 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___136 *bdi;
	struct kobject___247 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___247 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___150 {
	struct bio___150 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___176 *bip_vec;
	struct bio_vec___176 bip_inline_vecs[0];
};

struct blkcg___138;

struct blkg_policy_data___138;

struct blkcg_gq___138 {
	struct request_queue___150 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___138 *blkcg;
	struct blkcg_gq___138 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___138 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___150 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___150(struct request___150 *);

typedef void integrity_complete_fn___150(struct request___150 *, unsigned int);

struct blk_integrity_profile___150 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___150 *prepare_fn;
	integrity_complete_fn___150 *complete_fn;
	const char *name;
};

struct block_device_operations___150 {
	blk_qc_t (*submit_bio)(struct bio___150 *);
	int (*open)(struct block_device___153 *, fmode_t);
	void (*release)(struct gendisk___153 *, fmode_t);
	int (*rw_page)(struct block_device___153 *, sector_t, struct page___264 *, unsigned int);
	int (*ioctl)(struct block_device___153 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___153 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___153 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___153 *);
	int (*getgeo)(struct block_device___153 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___153 *, bool);
	void (*swap_slot_free_notify)(struct block_device___153 *, long unsigned int);
	int (*report_zones)(struct gendisk___153 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___153 *, umode_t *);
	struct module___243 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___153 *, sector_t *);
};

typedef void rq_end_io_fn___150(struct request___150 *, blk_status_t);

struct request___150 {
	struct request_queue___150 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___145 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___150 *bio;
	struct bio___150 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___176 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___150 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___150 *saved_end_io;
		} flush;
	};
	struct gendisk___153 *rq_disk;
	struct block_device___153 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___150 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___145 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___150 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___247 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___259 *debugfs_dir;
	struct dentry___259 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___150;

struct elevator_mq_ops___150 {
	int (*init_sched)(struct request_queue___150 *, struct elevator_type___150 *);
	void (*exit_sched)(struct elevator_queue___150 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___145 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___145 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___145 *);
	bool (*allow_merge)(struct request_queue___150 *, struct request___150 *, struct bio___150 *);
	bool (*bio_merge)(struct request_queue___150 *, struct bio___150 *, unsigned int);
	int (*request_merge)(struct request_queue___150 *, struct request___150 **, struct bio___150 *);
	void (*request_merged)(struct request_queue___150 *, struct request___150 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___150 *, struct request___150 *, struct request___150 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___150 *);
	void (*finish_request)(struct request___150 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___145 *, struct list_head *, bool);
	struct request___150 * (*dispatch_request)(struct blk_mq_hw_ctx___145 *);
	bool (*has_work)(struct blk_mq_hw_ctx___145 *);
	void (*completed_request)(struct request___150 *, u64);
	void (*requeue_request)(struct request___150 *);
	struct request___150 * (*former_request)(struct request_queue___150 *, struct request___150 *);
	struct request___150 * (*next_request)(struct request_queue___150 *, struct request___150 *);
	void (*init_icq)(struct io_cq___150 *);
	void (*exit_icq)(struct io_cq___150 *);
};

struct elv_fs_entry___150;

struct elevator_type___150 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___150 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___150 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___243 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___150 {
	struct elevator_type___150 *type;
	void *elevator_data;
	struct kobject___247 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___150 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___150 *, char *);
	ssize_t (*store)(struct elevator_queue___150 *, const char *, size_t);
};

struct blk_mq_queue_data___145;

struct blk_mq_ops___145 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___145 *, const struct blk_mq_queue_data___145 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___145 *);
	int (*get_budget)(struct request_queue___150 *);
	void (*put_budget)(struct request_queue___150 *, int);
	void (*set_rq_budget_token)(struct request___150 *, int);
	int (*get_rq_budget_token)(struct request___150 *);
	enum blk_eh_timer_return (*timeout)(struct request___150 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___145 *);
	void (*complete)(struct request___150 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___145 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___145 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___145 *, struct request___150 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___145 *, struct request___150 *, unsigned int);
	void (*initialize_rq_fn)(struct request___150 *);
	void (*cleanup_rq)(struct request___150 *);
	bool (*busy)(struct request_queue___150 *);
	int (*map_queues)(struct blk_mq_tag_set___145 *);
	void (*show_rq)(struct seq_file___234 *, struct request___150 *);
};

struct blk_mq_tag_set___145 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___145 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___145 {
	struct request___150 *rq;
	bool last;
};

struct blkcg_policy_data___138;

struct blkcg___138 {
	struct cgroup_subsys_state___186 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___138 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___138 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___138 {
	struct blkcg___138 *blkcg;
	int plid;
};

struct blkg_policy_data___138 {
	struct blkcg_gq___138 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___124 {
	struct mem_cgroup___124 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___124 {
	struct lruvec___132 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___124 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___124 *memcg;
};

struct obj_cgroup___124 {
	struct percpu_ref refcnt;
	struct mem_cgroup___124 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___62 {
	spinlock_t *lock;
	struct sk_buff___69 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___62;

struct Qdisc_ops___62 {
	struct Qdisc_ops___62 *next;
	const struct Qdisc_class_ops___62 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___69 *, struct Qdisc___62 *, struct sk_buff___69 **);
	struct sk_buff___69 * (*dequeue)(struct Qdisc___62 *);
	struct sk_buff___69 * (*peek)(struct Qdisc___62 *);
	int (*init)(struct Qdisc___62 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___62 *);
	void (*destroy)(struct Qdisc___62 *);
	int (*change)(struct Qdisc___62 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___62 *);
	int (*change_tx_queue_len)(struct Qdisc___62 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___62 *, unsigned int);
	int (*dump)(struct Qdisc___62 *, struct sk_buff___69 *);
	int (*dump_stats)(struct Qdisc___62 *, struct gnet_dump___62 *);
	void (*ingress_block_set)(struct Qdisc___62 *, u32);
	void (*egress_block_set)(struct Qdisc___62 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___62 *);
	u32 (*egress_block_get)(struct Qdisc___62 *);
	struct module___243 *owner;
};

struct Qdisc_class_ops___62 {
	unsigned int flags;
	struct netdev_queue___68 * (*select_queue)(struct Qdisc___62 *, struct tcmsg *);
	int (*graft)(struct Qdisc___62 *, long unsigned int, struct Qdisc___62 *, struct Qdisc___62 **, struct netlink_ext_ack *);
	struct Qdisc___62 * (*leaf)(struct Qdisc___62 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___62 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___62 *, u32);
	int (*change)(struct Qdisc___62 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___62 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___62 *, struct qdisc_walker *);
	struct tcf_block___62 * (*tcf_block)(struct Qdisc___62 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___62 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___62 *, long unsigned int);
	int (*dump)(struct Qdisc___62 *, long unsigned int, struct sk_buff___69 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___62 *, long unsigned int, struct gnet_dump___62 *);
};

struct tcf_chain___62;

struct tcf_block___62 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___73 *net;
	struct Qdisc___62 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___62 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___62;

struct tcf_proto_ops___62;

struct tcf_proto___62 {
	struct tcf_proto___62 *next;
	void *root;
	int (*classify)(struct sk_buff___69 *, const struct tcf_proto___62 *, struct tcf_result___62 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___62 *ops;
	struct tcf_chain___62 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___62 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___62 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___62 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___69 *, const struct tcf_proto___62 *, struct tcf_result___62 *);
	int (*init)(struct tcf_proto___62 *);
	void (*destroy)(struct tcf_proto___62 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___62 *, u32);
	void (*put)(struct tcf_proto___62 *, void *);
	int (*change)(struct net___73 *, struct sk_buff___69 *, struct tcf_proto___62 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___62 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___62 *);
	void (*walk)(struct tcf_proto___62 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___62 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___62 *, void *);
	void (*hw_del)(struct tcf_proto___62 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___73 *, struct tcf_chain___62 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___73 *, struct tcf_proto___62 *, void *, struct sk_buff___69 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___73 *, struct tcf_proto___62 *, void *, struct sk_buff___69 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___69 *, struct net___73 *, void *);
	struct module___243 *owner;
	int flags;
};

struct tcf_chain___62 {
	struct mutex filter_chain_lock;
	struct tcf_proto___62 *filter_chain;
	struct list_head list;
	struct tcf_block___62 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___62 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___55 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___62 *prog;
};

struct pneigh_entry___55;

struct neigh_hash_table___55;

struct neigh_table___55 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___68 *, __u32 *);
	bool (*key_eq)(const struct neighbour___55 *, const void *);
	int (*constructor)(struct neighbour___55 *);
	int (*pconstructor)(struct pneigh_entry___55 *);
	void (*pdestructor)(struct pneigh_entry___55 *);
	void (*proxy_redo)(struct sk_buff___69 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___68 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___55 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___68 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___55 *nht;
	struct pneigh_entry___55 **phash_buckets;
};

struct neigh_ops___55 {
	int family;
	void (*solicit)(struct neighbour___55 *, struct sk_buff___69 *);
	void (*error_report)(struct neighbour___55 *, struct sk_buff___69 *);
	int (*output)(struct neighbour___55 *, struct sk_buff___69 *);
	int (*connected_output)(struct neighbour___55 *, struct sk_buff___69 *);
};

struct pneigh_entry___55 {
	struct pneigh_entry___55 *next;
	possible_net_t___68 net;
	struct net_device___68 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___55 {
	struct neighbour___55 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___33 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___73 *, struct sock___55 *, struct sk_buff___69 *);
	int (*orig_input)(struct sk_buff___69 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___55 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___55 *ctarget;
	struct net___73 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___55 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___55 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___42;

struct timewait_sock_ops___41;

struct proto___55 {
	void (*close)(struct sock___55 *, long int);
	int (*pre_connect)(struct sock___55 *, struct sockaddr *, int);
	int (*connect)(struct sock___55 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___55 *, int);
	struct sock___55 * (*accept)(struct sock___55 *, int, int *, bool);
	int (*ioctl)(struct sock___55 *, int, long unsigned int);
	int (*init)(struct sock___55 *);
	void (*destroy)(struct sock___55 *);
	void (*shutdown)(struct sock___55 *, int);
	int (*setsockopt)(struct sock___55 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___55 *, int, int, char *, int *);
	void (*keepalive)(struct sock___55 *, int);
	int (*compat_ioctl)(struct sock___55 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___55 *, struct msghdr___57 *, size_t);
	int (*recvmsg)(struct sock___55 *, struct msghdr___57 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___55 *, struct page___264 *, int, size_t, int);
	int (*bind)(struct sock___55 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___55 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___55 *, struct sk_buff___69 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___55 *);
	int (*hash)(struct sock___55 *);
	void (*unhash)(struct sock___55 *);
	void (*rehash)(struct sock___55 *);
	int (*get_port)(struct sock___55 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___55 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___55 *, int);
	bool (*sock_is_readable)(struct sock___55 *);
	void (*enter_memory_pressure)(struct sock___55 *);
	void (*leave_memory_pressure)(struct sock___55 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___42 *rsk_prot;
	struct timewait_sock_ops___41 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___243 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___55 *, int);
};

struct request_sock___43;

struct request_sock_ops___42 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___55 *, struct request_sock___43 *);
	void (*send_ack)(const struct sock___55 *, struct sk_buff___69 *, struct request_sock___43 *);
	void (*send_reset)(const struct sock___55 *, struct sk_buff___69 *);
	void (*destructor)(struct request_sock___43 *);
	void (*syn_ack_timeout)(const struct request_sock___43 *);
};

struct timewait_sock_ops___41 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___55 *, struct sock___55 *, void *);
	void (*twsk_destructor)(struct sock___55 *);
};

struct request_sock___43 {
	struct sock_common___55 __req_common;
	struct request_sock___43 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___42 *rsk_ops;
	struct sock___55 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct perf_cpu_context___86;

struct perf_output_handle___86;

struct pmu___86 {
	struct list_head entry;
	struct module___243 *module;
	struct device___240 *dev;
	const struct attribute_group___247 **attr_groups;
	const struct attribute_group___247 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___86 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___86 *);
	void (*pmu_disable)(struct pmu___86 *);
	int (*event_init)(struct perf_event___86 *);
	void (*event_mapped)(struct perf_event___86 *, struct mm_struct___265 *);
	void (*event_unmapped)(struct perf_event___86 *, struct mm_struct___265 *);
	int (*add)(struct perf_event___86 *, int);
	void (*del)(struct perf_event___86 *, int);
	void (*start)(struct perf_event___86 *, int);
	void (*stop)(struct perf_event___86 *, int);
	void (*read)(struct perf_event___86 *);
	void (*start_txn)(struct pmu___86 *, unsigned int);
	int (*commit_txn)(struct pmu___86 *);
	void (*cancel_txn)(struct pmu___86 *);
	int (*event_idx)(struct perf_event___86 *);
	void (*sched_task)(struct perf_event_context___86 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___86 *, struct perf_event_context___86 *);
	void * (*setup_aux)(struct perf_event___86 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___86 *, struct perf_output_handle___86 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___86 *);
	int (*aux_output_match)(struct perf_event___86 *);
	int (*filter_match)(struct perf_event___86 *);
	int (*check_period)(struct perf_event___86 *, u64);
};

struct perf_cpu_context___86 {
	struct perf_event_context___86 ctx;
	struct perf_event_context___86 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___86 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___86 **heap;
	struct perf_event___86 *heap_default[2];
};

struct perf_output_handle___86 {
	struct perf_event___86 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___86 {
	struct cgroup_subsys_state___186 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___80 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___80 *);
	};
};

struct trace_event_class___80 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___80 *, enum trace_reg, void *);
	struct trace_event_fields___80 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___80 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___80 *);
};

struct ifmcaddr6___39 {
	struct in6_addr mca_addr;
	struct inet6_dev___39 *idev;
	struct ifmcaddr6___39 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct compat_cmsghdr {
	compat_size_t cmsg_len;
	compat_int_t cmsg_level;
	compat_int_t cmsg_type;
};

struct dentry___260;

struct super_block___260;

struct module___244;

struct file_system_type___260 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___260 * (*mount)(struct file_system_type___260 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___260 *);
	struct module___244 *owner;
	struct file_system_type___260 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___260;

struct kiocb___260;

struct iov_iter___180;

struct poll_table_struct___181;

struct vm_area_struct___265;

struct inode___260;

struct file_lock___260;

struct page___265;

struct pipe_inode_info___101;

struct seq_file___235;

struct file_operations___261 {
	struct module___244 *owner;
	loff_t (*llseek)(struct file___260 *, loff_t, int);
	ssize_t (*read)(struct file___260 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___260 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___260 *, struct iov_iter___180 *);
	ssize_t (*write_iter)(struct kiocb___260 *, struct iov_iter___180 *);
	int (*iopoll)(struct kiocb___260 *, bool);
	int (*iterate)(struct file___260 *, struct dir_context *);
	int (*iterate_shared)(struct file___260 *, struct dir_context *);
	__poll_t (*poll)(struct file___260 *, struct poll_table_struct___181 *);
	long int (*unlocked_ioctl)(struct file___260 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___260 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___260 *, struct vm_area_struct___265 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___260 *, struct file___260 *);
	int (*flush)(struct file___260 *, fl_owner_t);
	int (*release)(struct inode___260 *, struct file___260 *);
	int (*fsync)(struct file___260 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___260 *, int);
	int (*lock)(struct file___260 *, int, struct file_lock___260 *);
	ssize_t (*sendpage)(struct file___260 *, struct page___265 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___260 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___260 *, long unsigned int);
	int (*flock)(struct file___260 *, int, struct file_lock___260 *);
	ssize_t (*splice_write)(struct pipe_inode_info___101 *, struct file___260 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___260 *, loff_t *, struct pipe_inode_info___101 *, size_t, unsigned int);
	int (*setlease)(struct file___260 *, long int, struct file_lock___260 **, void **);
	long int (*fallocate)(struct file___260 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___235 *, struct file___260 *);
	ssize_t (*copy_file_range)(struct file___260 *, loff_t, struct file___260 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___260 *, loff_t, struct file___260 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___260 *, loff_t, loff_t, int);
};

struct vmacache___265 {
	u64 seqnum;
	struct vm_area_struct___265 *vmas[4];
};

struct page_frag___265 {
	struct page___265 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___266;

struct pid___237;

struct nsproxy___246;

struct signal_struct___261;

struct bio_list___151;

struct backing_dev_info___137;

struct io_context___151;

struct css_set___187;

struct mem_cgroup___125;

struct request_queue___151;

struct vm_struct___243;

struct task_struct___267 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___267 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___266 *mm;
	struct mm_struct___266 *active_mm;
	struct vmacache___265 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___267 *real_parent;
	struct task_struct___267 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___267 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___237 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___246 *nsproxy;
	struct signal_struct___261 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___267 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___151 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___137 *backing_dev_info;
	struct io_context___151 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___187 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___101 *splice_pipe;
	struct page_frag___265 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___125 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___125 *active_memcg;
	struct request_queue___151 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___267 *oom_reaper_list;
	struct vm_struct___243 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___248;

struct kobj_type___248;

struct kernfs_node___248;

struct kobject___248 {
	const char *name;
	struct list_head entry;
	struct kobject___248 *parent;
	struct kset___248 *kset;
	struct kobj_type___248 *ktype;
	struct kernfs_node___248 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___245 {
	struct kobject___248 kobj;
	struct module___244 *mod;
	struct kobject___248 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___244 {
	struct module___244 *mod;
	struct latch_tree_node node;
};

struct module_layout___244 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___244 mtn;
};

struct module_attribute___244;

struct kernel_param___244;

struct module___244 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___245 mkobj;
	struct module_attribute___244 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___248 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___244 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___244 core_layout;
	struct module_layout___244 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___237;

struct upid___237 {
	int nr;
	struct pid_namespace___237 *ns;
};

struct pid_namespace___237 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___267 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___237 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___237 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___237 numbers[1];
};

typedef struct page___265 *pgtable_t___265;

struct address_space___260;

struct page_pool___89;

struct dev_pagemap___255;

struct page___265 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___260 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___89 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___265 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___265 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___266 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___255 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___255;

struct vm_area_struct___265 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___265 *vm_next;
	struct vm_area_struct___265 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___266 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___255 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___260 *vm_file;
	struct file___260 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___261 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___267 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___267 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___237 *pids[4];
	struct pid___237 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___266 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___265;

struct mm_struct___266 {
	struct {
		struct vm_area_struct___265 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___260 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___265 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___267 *owner;
		struct user_namespace___26 *user_ns;
		struct file___260 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___74;

struct cgroup_namespace___187;

struct nsproxy___246 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___237 *pid_ns_for_children;
	struct net___74 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___187 *cgroup_ns;
};

struct bio___151;

struct bio_list___151 {
	struct bio___151 *head;
	struct bio___151 *tail;
};

struct cgroup_subsys_state___187;

struct bdi_writeback___137 {
	struct backing_dev_info___137 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___187 *memcg_css;
	struct cgroup_subsys_state___187 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___241;

struct backing_dev_info___137 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___137 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___241 *dev;
	char dev_name[64];
	struct device___241 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___260 *debug_dir;
};

struct io_cq___151;

struct io_context___151 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___151 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___187;

struct css_set___187 {
	struct cgroup_subsys_state___187 *subsys[14];
	refcount_t refcount;
	struct css_set___187 *dom_cset;
	struct cgroup___187 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___187 *mg_src_cgrp;
	struct cgroup___187 *mg_dst_cgrp;
	struct css_set___187 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___260;

struct pipe_buffer___101;

struct pipe_inode_info___101 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___265 *tmp_page;
	struct fasync_struct___260 *fasync_readers;
	struct fasync_struct___260 *fasync_writers;
	struct pipe_buffer___101 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___187;

struct cgroup_subsys_state___187 {
	struct cgroup___187 *cgroup;
	struct cgroup_subsys___187 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___187 *parent;
};

struct cgroup_file___187 {
	struct kernfs_node___248 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___125;

struct mem_cgroup_per_node___125;

struct mem_cgroup___125 {
	struct cgroup_subsys_state___187 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___187 events_file;
	struct cgroup_file___187 events_local_file;
	struct cgroup_file___187 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___125 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___267 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___125 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___151;

struct blk_integrity___151 {
	const struct blk_integrity_profile___151 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___151 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___151 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___151;

struct elevator_queue___151;

struct blk_mq_ops___146;

struct blk_mq_hw_ctx___146;

struct gendisk___154;

struct blkcg_gq___139;

struct blk_mq_tag_set___146;

struct request_queue___151 {
	struct request___151 *last_merge;
	struct elevator_queue___151 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___146 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___146 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___154 *disk;
	struct kobject___248 kobj;
	struct kobject___248 *mq_kobj;
	struct blk_integrity___151 integrity;
	struct device___241 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___139 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___146 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___151 bio_split;
	struct dentry___260 *debugfs_dir;
	struct dentry___260 *sched_debugfs_dir;
	struct dentry___260 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___243 {
	struct vm_struct___243 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___265 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___260;

struct address_space___260 {
	struct inode___260 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___260 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___89 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___241 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___89 {
	u32 count;
	struct page___265 *cache[128];
};

struct page_pool___89 {
	struct page_pool_params___89 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___265 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___89 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___255;

struct dev_pagemap___255 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___255 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___260;

struct path___260 {
	struct vfsmount___260 *mnt;
	struct dentry___260 *dentry;
};

struct fown_struct___237 {
	rwlock_t lock;
	struct pid___237 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___260 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___260 f_path;
	struct inode___260 *f_inode;
	const struct file_operations___261 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___237 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___260 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___255;

struct vm_operations_struct___255 {
	void (*open)(struct vm_area_struct___265 *);
	void (*close)(struct vm_area_struct___265 *);
	int (*may_split)(struct vm_area_struct___265 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___265 *);
	int (*mprotect)(struct vm_area_struct___265 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___255 *);
	vm_fault_t (*huge_fault)(struct vm_fault___255 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___255 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___265 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___255 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___255 *);
	int (*access)(struct vm_area_struct___265 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___265 *);
	int (*set_policy)(struct vm_area_struct___265 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___265 *, long unsigned int);
	struct page___265 * (*find_special_page)(struct vm_area_struct___265 *, long unsigned int);
};

struct core_thread___265 {
	struct task_struct___267 *task;
	struct core_thread___265 *next;
};

struct core_state___265 {
	atomic_t nr_threads;
	struct core_thread___265 dumper;
	struct completion startup;
};

struct vm_fault___255 {
	const struct {
		struct vm_area_struct___265 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___265 *cow_page;
	struct page___265 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___265 prealloc_pte;
};

struct pglist_data___133;

struct lruvec___133 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___133 *pgdat;
};

struct zone___133 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___133 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___133 {
	struct zone___133 *zone;
	int zone_idx;
};

struct zonelist___133 {
	struct zoneref___133 _zonerefs[321];
};

struct pglist_data___133 {
	struct zone___133 node_zones[5];
	struct zonelist___133 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___267 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___267 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___133 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___260;

struct dentry___260 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___260 *d_parent;
	struct qstr d_name;
	struct inode___260 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___260 *d_op;
	struct super_block___260 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___260;

struct inode___260 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___260 *i_op;
	struct super_block___260 *i_sb;
	struct address_space___260 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___137 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___261 *i_fop;
		void (*free_inode)(struct inode___260 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___260 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___101 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___260 {
	int (*d_revalidate)(struct dentry___260 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___260 *, unsigned int);
	int (*d_hash)(const struct dentry___260 *, struct qstr *);
	int (*d_compare)(const struct dentry___260 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___260 *);
	int (*d_init)(struct dentry___260 *);
	void (*d_release)(struct dentry___260 *);
	void (*d_prune)(struct dentry___260 *);
	void (*d_iput)(struct dentry___260 *, struct inode___260 *);
	char * (*d_dname)(struct dentry___260 *, char *, int);
	struct vfsmount___260 * (*d_automount)(struct path___260 *);
	int (*d_manage)(const struct path___260 *, bool);
	struct dentry___260 * (*d_real)(struct dentry___260 *, const struct inode___260 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___260;

struct mem_dqinfo___260 {
	struct quota_format_type___260 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___260;

struct quota_info___260 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___260 *files[3];
	struct mem_dqinfo___260 info[3];
	const struct quota_format_ops___260 *ops[3];
};

struct rcuwait___261 {
	struct task_struct___267 *task;
};

struct percpu_rw_semaphore___261 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___261 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___260 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___261 rw_sem[3];
};

struct shrink_control___125;

struct shrinker___125 {
	long unsigned int (*count_objects)(struct shrinker___125 *, struct shrink_control___125 *);
	long unsigned int (*scan_objects)(struct shrinker___125 *, struct shrink_control___125 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___260;

struct dquot_operations___260;

struct quotactl_ops___260;

struct block_device___154;

struct super_block___260 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___260 *s_type;
	const struct super_operations___260 *s_op;
	const struct dquot_operations___260 *dq_op;
	const struct quotactl_ops___260 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___260 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___154 *s_bdev;
	struct backing_dev_info___137 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___260 s_dquot;
	struct sb_writers___260 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___260 *s_d_op;
	int cleancache_poolid;
	struct shrinker___125 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___260 {
	struct dentry___260 *mnt_root;
	struct super_block___260 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___125 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___125 *memcg;
};

struct psi_group___187 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___267 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___63;

struct cgroup_bpf___63 {
	struct bpf_prog_array___63 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___63 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___187;

struct cgroup_rstat_cpu___187;

struct cgroup___187 {
	struct cgroup_subsys_state___187 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___248 *kn;
	struct cgroup_file___187 procs_file;
	struct cgroup_file___187 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___187 *subsys[14];
	struct cgroup_root___187 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___187 *dom_cgrp;
	struct cgroup___187 *old_dom_cgrp;
	struct cgroup_rstat_cpu___187 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___187 psi;
	struct cgroup_bpf___63 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___151 {
	struct request_queue___151 *q;
	struct io_context___151 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___260 {
	struct file___260 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___260 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___260 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___260 *ia_file;
};

struct dquot___260 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___260 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___260 {
	int qf_fmt_id;
	const struct quota_format_ops___260 *qf_ops;
	struct module___244 *qf_owner;
	struct quota_format_type___260 *qf_next;
};

struct quota_format_ops___260 {
	int (*check_quota_file)(struct super_block___260 *, int);
	int (*read_file_info)(struct super_block___260 *, int);
	int (*write_file_info)(struct super_block___260 *, int);
	int (*free_file_info)(struct super_block___260 *, int);
	int (*read_dqblk)(struct dquot___260 *);
	int (*commit_dqblk)(struct dquot___260 *);
	int (*release_dqblk)(struct dquot___260 *);
	int (*get_next_id)(struct super_block___260 *, struct kqid *);
};

struct dquot_operations___260 {
	int (*write_dquot)(struct dquot___260 *);
	struct dquot___260 * (*alloc_dquot)(struct super_block___260 *, int);
	void (*destroy_dquot)(struct dquot___260 *);
	int (*acquire_dquot)(struct dquot___260 *);
	int (*release_dquot)(struct dquot___260 *);
	int (*mark_dirty)(struct dquot___260 *);
	int (*write_info)(struct super_block___260 *, int);
	qsize_t * (*get_reserved_space)(struct inode___260 *);
	int (*get_projid)(struct inode___260 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___260 *, qsize_t *);
	int (*get_next_id)(struct super_block___260 *, struct kqid *);
};

struct quotactl_ops___260 {
	int (*quota_on)(struct super_block___260 *, int, int, const struct path___260 *);
	int (*quota_off)(struct super_block___260 *, int);
	int (*quota_enable)(struct super_block___260 *, unsigned int);
	int (*quota_disable)(struct super_block___260 *, unsigned int);
	int (*quota_sync)(struct super_block___260 *, int);
	int (*set_info)(struct super_block___260 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___260 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___260 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___260 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___260 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___260 *, unsigned int);
};

struct writeback_control___137;

struct address_space_operations___260 {
	int (*writepage)(struct page___265 *, struct writeback_control___137 *);
	int (*readpage)(struct file___260 *, struct page___265 *);
	int (*writepages)(struct address_space___260 *, struct writeback_control___137 *);
	int (*set_page_dirty)(struct page___265 *);
	int (*readpages)(struct file___260 *, struct address_space___260 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___260 *, struct address_space___260 *, loff_t, unsigned int, unsigned int, struct page___265 **, void **);
	int (*write_end)(struct file___260 *, struct address_space___260 *, loff_t, unsigned int, unsigned int, struct page___265 *, void *);
	sector_t (*bmap)(struct address_space___260 *, sector_t);
	void (*invalidatepage)(struct page___265 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___265 *, gfp_t);
	void (*freepage)(struct page___265 *);
	ssize_t (*direct_IO)(struct kiocb___260 *, struct iov_iter___180 *);
	int (*migratepage)(struct address_space___260 *, struct page___265 *, struct page___265 *, enum migrate_mode);
	bool (*isolate_page)(struct page___265 *, isolate_mode_t);
	void (*putback_page)(struct page___265 *);
	int (*launder_page)(struct page___265 *);
	int (*is_partially_uptodate)(struct page___265 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___265 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___260 *, struct page___265 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___260 *, sector_t *);
	void (*swap_deactivate)(struct file___260 *);
};

struct writeback_control___137 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___137 *wb;
	struct inode___260 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___177;

struct iov_iter___180 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___177 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___101 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___260 {
	struct dentry___260 * (*lookup)(struct inode___260 *, struct dentry___260 *, unsigned int);
	const char * (*get_link)(struct dentry___260 *, struct inode___260 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___260 *, int);
	struct posix_acl * (*get_acl)(struct inode___260 *, int, bool);
	int (*readlink)(struct dentry___260 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___260 *, struct dentry___260 *, umode_t, bool);
	int (*link)(struct dentry___260 *, struct inode___260 *, struct dentry___260 *);
	int (*unlink)(struct inode___260 *, struct dentry___260 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___260 *, struct dentry___260 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___260 *, struct dentry___260 *, umode_t);
	int (*rmdir)(struct inode___260 *, struct dentry___260 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___260 *, struct dentry___260 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___260 *, struct dentry___260 *, struct inode___260 *, struct dentry___260 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___260 *, struct iattr___260 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___260 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___260 *, char *, size_t);
	int (*fiemap)(struct inode___260 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___260 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___260 *, struct dentry___260 *, struct file___260 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___260 *, struct dentry___260 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___260 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___260 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___260 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___260 {
	void (*fl_copy_lock)(struct file_lock___260 *, struct file_lock___260 *);
	void (*fl_release_private)(struct file_lock___260 *);
};

struct lock_manager_operations___260;

struct file_lock___260 {
	struct file_lock___260 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___260 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___260 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___260 *fl_ops;
	const struct lock_manager_operations___260 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___260 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___260 *);
	int (*lm_grant)(struct file_lock___260 *, int);
	bool (*lm_break)(struct file_lock___260 *);
	int (*lm_change)(struct file_lock___260 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___260 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___260 *);
};

struct fasync_struct___260 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___260 *fa_next;
	struct file___260 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___260 {
	struct inode___260 * (*alloc_inode)(struct super_block___260 *);
	void (*destroy_inode)(struct inode___260 *);
	void (*free_inode)(struct inode___260 *);
	void (*dirty_inode)(struct inode___260 *, int);
	int (*write_inode)(struct inode___260 *, struct writeback_control___137 *);
	int (*drop_inode)(struct inode___260 *);
	void (*evict_inode)(struct inode___260 *);
	void (*put_super)(struct super_block___260 *);
	int (*sync_fs)(struct super_block___260 *, int);
	int (*freeze_super)(struct super_block___260 *);
	int (*freeze_fs)(struct super_block___260 *);
	int (*thaw_super)(struct super_block___260 *);
	int (*unfreeze_fs)(struct super_block___260 *);
	int (*statfs)(struct dentry___260 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___260 *, int *, char *);
	void (*umount_begin)(struct super_block___260 *);
	int (*show_options)(struct seq_file___235 *, struct dentry___260 *);
	int (*show_devname)(struct seq_file___235 *, struct dentry___260 *);
	int (*show_path)(struct seq_file___235 *, struct dentry___260 *);
	int (*show_stats)(struct seq_file___235 *, struct dentry___260 *);
	ssize_t (*quota_read)(struct super_block___260 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___260 *, int, const char *, size_t, loff_t);
	struct dquot___260 ** (*get_dquots)(struct inode___260 *);
	long int (*nr_cached_objects)(struct super_block___260 *, struct shrink_control___125 *);
	long int (*free_cached_objects)(struct super_block___260 *, struct shrink_control___125 *);
	struct file___260 * (*real_loop)(struct file___260 *);
};

struct wakeup_source___241;

struct dev_pm_info___241 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___241 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___241 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___241;

struct bus_type___241;

struct device_driver___241;

struct dev_pm_domain___241;

struct device_node___104;

struct fwnode_handle___237;

struct class___241;

struct attribute_group___248;

struct device___241 {
	struct kobject___248 kobj;
	struct device___241 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___241 *type;
	struct bus_type___241 *bus;
	struct device_driver___241 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___241 power;
	struct dev_pm_domain___241 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___104 *of_node;
	struct fwnode_handle___237 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___241 *class;
	const struct attribute_group___248 **groups;
	void (*release)(struct device___241 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___154 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___260 *bd_inode;
	struct super_block___260 *bd_super;
	void *bd_claiming;
	struct device___241 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___248 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___154 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___260 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___189)(struct file___260 *, wait_queue_head_t *, struct poll_table_struct___181 *);

struct poll_table_struct___181 {
	poll_queue_proc___189 _qproc;
	__poll_t _key;
};

struct seq_operations___235;

struct seq_file___235 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___235 *op;
	int poll_event;
	const struct file___260 *file;
	void *private;
};

typedef void bio_end_io_t___151(struct bio___151 *);

struct bio_vec___177 {
	struct page___265 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___151;

struct bio___151 {
	struct bio___151 *bi_next;
	struct block_device___154 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___151 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___139 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___151 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___177 *bi_io_vec;
	struct bio_set___151 *bi_pool;
	struct bio_vec___177 bi_inline_vecs[0];
};

struct kernfs_root___248;

struct kernfs_elem_dir___248 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___248 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___248;

struct kernfs_root___248 {
	struct kernfs_node___248 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___248 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___248 {
	struct kernfs_node___248 *target_kn;
};

struct kernfs_ops___248;

struct kernfs_elem_attr___248 {
	const struct kernfs_ops___248 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___248 *notify_next;
};

struct kernfs_node___248 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___248 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___248 dir;
		struct kernfs_elem_symlink___248 symlink;
		struct kernfs_elem_attr___248 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___248;

struct kernfs_ops___248 {
	int (*open)(struct kernfs_open_file___248 *);
	void (*release)(struct kernfs_open_file___248 *);
	int (*seq_show)(struct seq_file___235 *, void *);
	void * (*seq_start)(struct seq_file___235 *, loff_t *);
	void * (*seq_next)(struct seq_file___235 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___235 *, void *);
	ssize_t (*read)(struct kernfs_open_file___248 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___248 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___248 *, struct poll_table_struct___181 *);
	int (*mmap)(struct kernfs_open_file___248 *, struct vm_area_struct___265 *);
};

struct kernfs_syscall_ops___248 {
	int (*show_options)(struct seq_file___235 *, struct kernfs_root___248 *);
	int (*mkdir)(struct kernfs_node___248 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___248 *);
	int (*rename)(struct kernfs_node___248 *, struct kernfs_node___248 *, const char *);
	int (*show_path)(struct seq_file___235 *, struct kernfs_node___248 *, struct kernfs_root___248 *);
};

struct kernfs_open_file___248 {
	struct kernfs_node___248 *kn;
	struct file___260 *file;
	struct seq_file___235 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___255 *vm_ops;
};

struct sock___56;

struct kobj_ns_type_operations___56 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___56 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___74 *net;
} possible_net_t___69;

struct proto___56;

struct sock_common___56 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___56 *skc_prot;
	possible_net_t___69 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___56 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___70;

struct sk_buff_head___69 {
	struct sk_buff___70 *next;
	struct sk_buff___70 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___56 {
	struct cgroup___187 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___56;

struct socket_wq___57;

struct dst_entry___56;

struct socket___58;

struct net_device___69;

struct sock___56 {
	struct sock_common___56 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___69 sk_error_queue;
	struct sk_buff___70 *sk_rx_skb_cache;
	struct sk_buff_head___69 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___70 *head;
		struct sk_buff___70 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___56 *sk_filter;
	union {
		struct socket_wq___57 *sk_wq;
		struct socket_wq___57 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___56 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___56 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___70 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___70 *sk_tx_skb_cache;
	struct sk_buff_head___69 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___265 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___56 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___237 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___58 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___56 sk_cgrp_data;
	struct mem_cgroup___125 *sk_memcg;
	void (*sk_state_change)(struct sock___56 *);
	void (*sk_data_ready)(struct sock___56 *);
	void (*sk_write_space)(struct sock___56 *);
	void (*sk_error_report)(struct sock___56 *);
	int (*sk_backlog_rcv)(struct sock___56 *, struct sk_buff___70 *);
	struct sk_buff___70 * (*sk_validate_xmit_skb)(struct sock___56 *, struct net_device___69 *, struct sk_buff___70 *);
	void (*sk_destruct)(struct sock___56 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___248;

struct attribute_group___248 {
	const char *name;
	umode_t (*is_visible)(struct kobject___248 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___248 *, struct bin_attribute___248 *, int);
	struct attribute **attrs;
	struct bin_attribute___248 **bin_attrs;
};

struct bin_attribute___248 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___260 * (*f_mapping)();
	ssize_t (*read)(struct file___260 *, struct kobject___248 *, struct bin_attribute___248 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___260 *, struct kobject___248 *, struct bin_attribute___248 *, char *, loff_t, size_t);
	int (*mmap)(struct file___260 *, struct kobject___248 *, struct bin_attribute___248 *, struct vm_area_struct___265 *);
};

struct sysfs_ops___248 {
	ssize_t (*show)(struct kobject___248 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___248 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___248;

struct kset___248 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___248 kobj;
	const struct kset_uevent_ops___248 *uevent_ops;
};

struct kobj_type___248 {
	void (*release)(struct kobject___248 *);
	const struct sysfs_ops___248 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___248 **default_groups;
	const struct kobj_ns_type_operations___56 * (*child_ns_type)(struct kobject___248 *);
	const void * (*namespace)(struct kobject___248 *);
	void (*get_ownership)(struct kobject___248 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___248 {
	int (* const filter)(struct kset___248 *, struct kobject___248 *);
	const char * (* const name)(struct kset___248 *, struct kobject___248 *);
	int (* const uevent)(struct kset___248 *, struct kobject___248 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___244 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___244 *);
	int (*get)(char *, const struct kernel_param___244 *);
	void (*free)(void *);
};

struct kparam_array___244;

struct kernel_param___244 {
	const char *name;
	struct module___244 *mod;
	const struct kernel_param_ops___244 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___244 *arr;
	};
};

struct kparam_array___244 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___244 *ops;
	void *elem;
};

struct module_attribute___244 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___244 *, struct module_kobject___245 *, char *);
	ssize_t (*store)(struct module_attribute___244 *, struct module_kobject___245 *, const char *, size_t);
	void (*setup)(struct module___244 *, const char *);
	int (*test)(struct module___244 *);
	void (*free)(struct module___244 *);
};

struct dev_pagemap_ops___255 {
	void (*page_free)(struct page___265 *);
	void (*kill)(struct dev_pagemap___255 *);
	void (*cleanup)(struct dev_pagemap___255 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___255 *);
};

struct msghdr___58 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___180 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___260 *msg_iocb;
};

struct sk_buff___70 {
	union {
		struct {
			struct sk_buff___70 *next;
			struct sk_buff___70 *prev;
			union {
				struct net_device___69 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___56 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___70 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___74;

struct fqdir___74 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___74 *f;
	struct net___74 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___74;

struct inet_frags___74 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___74 *, const void *);
	void (*destructor)(struct inet_frag_queue___74 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___32;

struct fib_rules_ops___56;

struct fib_notifier_ops___56;

struct netns_ipv4___74 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___32 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___56 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___56 *fibnl;
	struct sock___56 **icmp_sk;
	struct sock___56 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___56 **tcp_sk;
	struct fqdir___74 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___56 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___56 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___56 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___56;

struct dst_ops___74 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___74 *);
	struct dst_entry___56 * (*check)(struct dst_entry___56 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___56 *);
	unsigned int (*mtu)(const struct dst_entry___56 *);
	u32 * (*cow_metrics)(struct dst_entry___56 *, long unsigned int);
	void (*destroy)(struct dst_entry___56 *);
	void (*ifdown)(struct dst_entry___56 *, struct net_device___69 *, int);
	struct dst_entry___56 * (*negative_advice)(struct dst_entry___56 *);
	void (*link_failure)(struct sk_buff___70 *);
	void (*update_pmtu)(struct dst_entry___56 *, struct sock___56 *, struct sk_buff___70 *, u32, bool);
	void (*redirect)(struct dst_entry___56 *, struct sock___56 *, struct sk_buff___70 *);
	int (*local_out)(struct net___74 *, struct sock___56 *, struct sk_buff___70 *);
	struct neighbour___56 * (*neigh_lookup)(const struct dst_entry___56 *, struct sk_buff___70 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___56 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___74 {
	struct dst_ops___74 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___74 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___56 *fib6_rules_ops;
	struct sock___56 **icmp_sk;
	struct sock___56 *ndisc_sk;
	struct sock___56 *tcp_sk;
	struct sock___56 *igmp_sk;
	struct sock___56 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___56 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___56 *notifier_ops;
	struct fib_notifier_ops___56 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___74 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___74 *fqdir;
};

struct netns_sctp___56 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___56 *ctl_sock;
	struct sock___56 *udp4_sock;
	struct sock___56 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___63;

struct netns_bpf___63 {
	struct bpf_prog_array___63 *run_array[2];
	struct bpf_prog___63 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___74 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___56 *nlsk;
	struct sock___56 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___74 xfrm4_dst_ops;
	struct dst_ops___74 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___74 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___56 *rtnl;
	struct sock___56 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___69 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___74 ipv4;
	struct netns_ipv6___74 ipv6;
	struct netns_ieee802154_lowpan___74 ieee802154_lowpan;
	struct netns_sctp___56 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___69 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___63 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___74 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___56 *crypto_nlsk;
	struct sock___56 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___74 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___70 *fragments_tail;
	struct sk_buff___70 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___74 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___32 {
	struct ip_ra_chain___32 *next;
	struct sock___56 *sk;
	union {
		void (*destructor)(struct sock___56 *);
		struct sock___56 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___56;

struct fib_lookup_arg___56;

struct fib_rules_ops___56 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___56 *, struct flowi *, int, struct fib_lookup_arg___56 *);
	bool (*suppress)(struct fib_rule___56 *, int, struct fib_lookup_arg___56 *);
	int (*match)(struct fib_rule___56 *, struct flowi *, int);
	int (*configure)(struct fib_rule___56 *, struct sk_buff___70 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___56 *);
	int (*compare)(struct fib_rule___56 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___56 *, struct sk_buff___70 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___56 *);
	void (*flush_cache)(struct fib_rules_ops___56 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___244 *owner;
	struct net___74 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___56 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___74 *);
	int (*fib_dump)(struct net___74 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___244 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___34;

struct dst_entry___56 {
	struct net_device___69 *dev;
	struct dst_ops___74 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___70 *);
	int (*output)(struct net___74 *, struct sock___56 *, struct sk_buff___70 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___34 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___69(struct sk_buff___70 **);

struct bpf_xdp_entity___63 {
	struct bpf_prog___63 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___69;

struct net_device_ops___69;

struct ethtool_ops___30;

struct l3mdev_ops___56;

struct ndisc_ops___40;

struct xfrmdev_ops___69;

struct header_ops___69;

struct dsa_port___5;

struct inet6_dev___40;

struct netdev_rx_queue___69;

struct mini_Qdisc___63;

struct netdev_queue___69;

struct Qdisc___63;

struct rtnl_link_ops___63;

struct dcbnl_rtnl_ops___69;

struct phy_device___13;

struct net_device___69 {
	char name[16];
	struct netdev_name_node___69 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___69 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___30 *ethtool_ops;
	const struct l3mdev_ops___56 *l3mdev_ops;
	const struct ndisc_ops___40 *ndisc_ops;
	const struct xfrmdev_ops___69 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___69 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___248 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port___5 *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___40 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___69 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___63 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___69 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___63 *miniq_ingress;
	struct netdev_queue___69 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___69 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___63 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___63 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___69 = 0,
		NETREG_REGISTERED___69 = 1,
		NETREG_UNREGISTERING___69 = 2,
		NETREG_UNREGISTERED___69 = 3,
		NETREG_RELEASED___69 = 4,
		NETREG_DUMMY___69 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___69 = 0,
		RTNL_LINK_INITIALIZING___69 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___69 *);
	struct netpoll_info *npinfo;
	possible_net_t___69 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___241 dev;
	const struct attribute_group___248 *sysfs_groups[4];
	const struct attribute_group___248 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___63 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___69 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___13 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___63 xdp_state[3];
	long: 64;
};

struct neigh_table___56;

struct neigh_parms___56;

struct neigh_ops___56;

struct neighbour___56 {
	struct neighbour___56 *next;
	struct neigh_table___56 *tbl;
	struct neigh_parms___56 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___69 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___56 *, struct sk_buff___70 *);
	const struct neigh_ops___56 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___69 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___63 {
	struct bpf_prog___63 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___63 {
	struct callback_head rcu;
	struct bpf_prog_array_item___63 items[0];
};

struct bpf_prog_aux___72;

struct bpf_prog___63 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___72 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___237;

struct fwnode_handle___237 {
	struct fwnode_handle___237 *secondary;
	const struct fwnode_operations___237 *ops;
	struct device___241 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___237;

struct fwnode_endpoint___237;

struct fwnode_operations___237 {
	struct fwnode_handle___237 * (*get)(struct fwnode_handle___237 *);
	void (*put)(struct fwnode_handle___237 *);
	bool (*device_is_available)(const struct fwnode_handle___237 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___237 *, const struct device___241 *);
	bool (*property_present)(const struct fwnode_handle___237 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___237 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___237 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___237 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*get_parent)(const struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*get_next_child_node)(const struct fwnode_handle___237 *, struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*get_named_child_node)(const struct fwnode_handle___237 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___237 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___237 *);
	struct fwnode_handle___237 * (*graph_get_next_endpoint)(const struct fwnode_handle___237 *, struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*graph_get_remote_endpoint)(const struct fwnode_handle___237 *);
	struct fwnode_handle___237 * (*graph_get_port_parent)(struct fwnode_handle___237 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___237 *, struct fwnode_endpoint___237 *);
	int (*add_links)(struct fwnode_handle___237 *);
};

struct fwnode_endpoint___237 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___237 *local_fwnode;
};

struct fwnode_reference_args___237 {
	struct fwnode_handle___237 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___187 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___187 *root_cset;
};

struct socket_wq___57 {
	wait_queue_head_t wait;
	struct fasync_struct___260 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___57;

struct socket___58 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___260 *file;
	struct sock___56 *sk;
	const struct proto_ops___57 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___57 wq;
};

typedef int (*sk_read_actor_t___56)(read_descriptor_t *, struct sk_buff___70 *, unsigned int, size_t);

struct proto_ops___57 {
	int family;
	struct module___244 *owner;
	int (*release)(struct socket___58 *);
	int (*bind)(struct socket___58 *, struct sockaddr *, int);
	int (*connect)(struct socket___58 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___58 *, struct socket___58 *);
	int (*accept)(struct socket___58 *, struct socket___58 *, int, bool);
	int (*getname)(struct socket___58 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___260 *, struct socket___58 *, struct poll_table_struct___181 *);
	int (*ioctl)(struct socket___58 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___58 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___58 *, void *, bool, bool);
	int (*listen)(struct socket___58 *, int);
	int (*shutdown)(struct socket___58 *, int);
	int (*setsockopt)(struct socket___58 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___58 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___235 *, struct socket___58 *);
	int (*sendmsg)(struct socket___58 *, struct msghdr___58 *, size_t);
	int (*recvmsg)(struct socket___58 *, struct msghdr___58 *, size_t, int);
	int (*mmap)(struct file___260 *, struct socket___58 *, struct vm_area_struct___265 *);
	ssize_t (*sendpage)(struct socket___58 *, struct page___265 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___58 *, loff_t *, struct pipe_inode_info___101 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___56 *, int);
	int (*peek_len)(struct socket___58 *);
	int (*read_sock)(struct sock___56 *, read_descriptor_t *, sk_read_actor_t___56);
	int (*sendpage_locked)(struct sock___56 *, struct page___265 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___56 *, struct msghdr___58 *, size_t);
	int (*set_rcvlowat)(struct sock___56 *, int);
};

struct dev_pm_ops___241 {
	int (*prepare)(struct device___241 *);
	void (*complete)(struct device___241 *);
	int (*suspend)(struct device___241 *);
	int (*resume)(struct device___241 *);
	int (*freeze)(struct device___241 *);
	int (*thaw)(struct device___241 *);
	int (*poweroff)(struct device___241 *);
	int (*restore)(struct device___241 *);
	int (*suspend_late)(struct device___241 *);
	int (*resume_early)(struct device___241 *);
	int (*freeze_late)(struct device___241 *);
	int (*thaw_early)(struct device___241 *);
	int (*poweroff_late)(struct device___241 *);
	int (*restore_early)(struct device___241 *);
	int (*suspend_noirq)(struct device___241 *);
	int (*resume_noirq)(struct device___241 *);
	int (*freeze_noirq)(struct device___241 *);
	int (*thaw_noirq)(struct device___241 *);
	int (*poweroff_noirq)(struct device___241 *);
	int (*restore_noirq)(struct device___241 *);
	int (*runtime_suspend)(struct device___241 *);
	int (*runtime_resume)(struct device___241 *);
	int (*runtime_idle)(struct device___241 *);
};

struct wakeup_source___241 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___241 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___241 {
	struct dev_pm_ops___241 ops;
	int (*start)(struct device___241 *);
	void (*detach)(struct device___241 *, bool);
	int (*activate)(struct device___241 *);
	void (*sync)(struct device___241 *);
	void (*dismiss)(struct device___241 *);
};

struct bus_type___241 {
	const char *name;
	const char *dev_name;
	struct device___241 *dev_root;
	const struct attribute_group___248 **bus_groups;
	const struct attribute_group___248 **dev_groups;
	const struct attribute_group___248 **drv_groups;
	int (*match)(struct device___241 *, struct device_driver___241 *);
	int (*uevent)(struct device___241 *, struct kobj_uevent_env *);
	int (*probe)(struct device___241 *);
	void (*sync_state)(struct device___241 *);
	void (*remove)(struct device___241 *);
	void (*shutdown)(struct device___241 *);
	int (*online)(struct device___241 *);
	int (*offline)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	int (*num_vf)(struct device___241 *);
	int (*dma_configure)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___241 {
	const char *name;
	struct bus_type___241 *bus;
	struct module___244 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___241 *);
	void (*sync_state)(struct device___241 *);
	int (*remove)(struct device___241 *);
	void (*shutdown)(struct device___241 *);
	int (*suspend)(struct device___241 *, pm_message_t);
	int (*resume)(struct device___241 *);
	const struct attribute_group___248 **groups;
	const struct attribute_group___248 **dev_groups;
	const struct dev_pm_ops___241 *pm;
	void (*coredump)(struct device___241 *);
	struct driver_private *p;
};

struct device_type___241 {
	const char *name;
	const struct attribute_group___248 **groups;
	int (*uevent)(struct device___241 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___241 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___241 *);
	const struct dev_pm_ops___241 *pm;
};

struct class___241 {
	const char *name;
	struct module___244 *owner;
	const struct attribute_group___248 **class_groups;
	const struct attribute_group___248 **dev_groups;
	struct kobject___248 *dev_kobj;
	int (*dev_uevent)(struct device___241 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___241 *, umode_t *);
	void (*class_release)(struct class___241 *);
	void (*dev_release)(struct device___241 *);
	int (*shutdown_pre)(struct device___241 *);
	const struct kobj_ns_type_operations___56 *ns_type;
	const void * (*namespace)(struct device___241 *);
	void (*get_ownership)(struct device___241 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___241 *pm;
	struct subsys_private *p;
};

struct property___78;

struct device_node___104 {
	const char *name;
	phandle phandle;
	const char *full_name;
	struct fwnode_handle___237 fwnode;
	struct property___78 *properties;
	struct property___78 *deadprops;
	struct device_node___104 *parent;
	struct device_node___104 *child;
	struct device_node___104 *sibling;
	struct kobject___248 kobj;
	long unsigned int _flags;
	void *data;
};

struct pipe_buf_operations___101;

struct pipe_buffer___101 {
	struct page___265 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___101 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___101 {
	int (*confirm)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
	void (*release)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
	bool (*try_steal)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
	bool (*get)(struct pipe_inode_info___101 *, struct pipe_buffer___101 *);
};

struct seq_operations___235 {
	void * (*start)(struct seq_file___235 *, loff_t *);
	void (*stop)(struct seq_file___235 *, void *);
	void * (*next)(struct seq_file___235 *, void *, loff_t *);
	int (*show)(struct seq_file___235 *, void *);
};

struct dcbnl_rtnl_ops___69 {
	int (*ieee_getets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___69 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___69 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___69 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___69 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___69 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___69 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___69 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___69 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___69 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___69 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___69 *);
	u8 (*setstate)(struct net_device___69 *, u8);
	void (*getpermhwaddr)(struct net_device___69 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___69 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___69 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___69 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___69 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___69 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___69 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___69 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___69 *, int, u8 *);
	void (*setpfccfg)(struct net_device___69 *, int, u8);
	void (*getpfccfg)(struct net_device___69 *, int, u8 *);
	u8 (*setall)(struct net_device___69 *);
	u8 (*getcap)(struct net_device___69 *, int, u8 *);
	int (*getnumtcs)(struct net_device___69 *, int, u8 *);
	int (*setnumtcs)(struct net_device___69 *, int, u8);
	u8 (*getpfcstate)(struct net_device___69 *);
	void (*setpfcstate)(struct net_device___69 *, u8);
	void (*getbcncfg)(struct net_device___69 *, int, u32 *);
	void (*setbcncfg)(struct net_device___69 *, int, u32);
	void (*getbcnrp)(struct net_device___69 *, int, u8 *);
	void (*setbcnrp)(struct net_device___69 *, int, u8);
	int (*setapp)(struct net_device___69 *, u8, u16, u8);
	int (*getapp)(struct net_device___69 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___69 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___69 *, int, u8);
	u8 (*getdcbx)(struct net_device___69 *);
	u8 (*setdcbx)(struct net_device___69 *, u8);
	int (*peer_getappinfo)(struct net_device___69 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___69 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___69 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___69 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___69 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___69 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___72;

typedef int (*bpf_iter_init_seq_priv_t___71)(void *, struct bpf_iter_aux_info___72 *);

struct bpf_map___72;

struct bpf_iter_aux_info___72 {
	struct bpf_map___72 *map;
};

struct bpf_iter_seq_info___71 {
	const struct seq_operations___235 *seq_ops;
	bpf_iter_init_seq_priv_t___71 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___71 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___72 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___72 *, struct file___260 *);
	void (*map_free)(struct bpf_map___72 *);
	int (*map_get_next_key)(struct bpf_map___72 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___72 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___72 *, void *);
	int (*map_lookup_batch)(struct bpf_map___72 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___72 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___72 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___72 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___72 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___72 *, void *);
	int (*map_update_elem)(struct bpf_map___72 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___72 *, void *);
	int (*map_push_elem)(struct bpf_map___72 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___72 *, void *);
	int (*map_peek_elem)(struct bpf_map___72 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___72 *, struct file___260 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___72 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___72 *, void *, struct seq_file___235 *);
	int (*map_check_btf)(const struct bpf_map___72 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___72 *, struct bpf_prog_aux___72 *);
	void (*map_poke_untrack)(struct bpf_map___72 *, struct bpf_prog_aux___72 *);
	void (*map_poke_run)(struct bpf_map___72 *, u32, struct bpf_prog___63 *, struct bpf_prog___63 *);
	int (*map_direct_value_addr)(const struct bpf_map___72 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___72 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___72 *, struct vm_area_struct___265 *);
	__poll_t (*map_poll)(struct bpf_map___72 *, struct file___260 *, struct poll_table_struct___181 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___72 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___72 *, const struct bpf_map___72 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___72 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___71 *iter_seq_info;
};

struct bpf_map___72 {
	const struct bpf_map_ops___71 *ops;
	struct bpf_map___72 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___125 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___71;

struct bpf_jit_poke_descriptor___71;

struct bpf_prog_ops___63;

struct btf_mod_pair___71;

struct bpf_prog_offload___69;

struct bpf_prog_aux___72 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___63 *dst_prog;
	struct bpf_trampoline___71 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___63 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___71 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___63 *ops;
	struct bpf_map___72 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___71 *used_btfs;
	struct bpf_prog___63 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___72 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___69 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___69;

struct bpf_map_dev_ops___69 {
	int (*map_get_next_key)(struct bpf_offloaded_map___69 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___69 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___69 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___69 *, void *);
};

struct bpf_offloaded_map___69 {
	struct bpf_map___72 map;
	struct net_device___69 *netdev;
	const struct bpf_map_dev_ops___69 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___63 {
	int (*test_run)(struct bpf_prog___63 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___69 {
	struct bpf_prog___63 *prog;
	struct net_device___69 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___71 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___63 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___244 *mod;
};

struct bpf_jit_poke_descriptor___71 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___72 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___71 {
	struct btf *btf;
	struct module___244 *module;
};

struct cftype___187;

struct cgroup_subsys___187 {
	struct cgroup_subsys_state___187 * (*css_alloc)(struct cgroup_subsys_state___187 *);
	int (*css_online)(struct cgroup_subsys_state___187 *);
	void (*css_offline)(struct cgroup_subsys_state___187 *);
	void (*css_released)(struct cgroup_subsys_state___187 *);
	void (*css_free)(struct cgroup_subsys_state___187 *);
	void (*css_reset)(struct cgroup_subsys_state___187 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___187 *, int);
	int (*css_extra_stat_show)(struct seq_file___235 *, struct cgroup_subsys_state___187 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___267 *, struct css_set___187 *);
	void (*cancel_fork)(struct task_struct___267 *, struct css_set___187 *);
	void (*fork)(struct task_struct___267 *);
	void (*exit)(struct task_struct___267 *);
	void (*release)(struct task_struct___267 *);
	void (*bind)(struct cgroup_subsys_state___187 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___187 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___187 *dfl_cftypes;
	struct cftype___187 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___187 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___187 *updated_children;
	struct cgroup___187 *updated_next;
};

struct cgroup_root___187 {
	struct kernfs_root___248 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___187 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___187 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___187 *ss;
	struct list_head node;
	struct kernfs_ops___248 *kf_ops;
	int (*open)(struct kernfs_open_file___248 *);
	void (*release)(struct kernfs_open_file___248 *);
	u64 (*read_u64)(struct cgroup_subsys_state___187 *, struct cftype___187 *);
	s64 (*read_s64)(struct cgroup_subsys_state___187 *, struct cftype___187 *);
	int (*seq_show)(struct seq_file___235 *, void *);
	void * (*seq_start)(struct seq_file___235 *, loff_t *);
	void * (*seq_next)(struct seq_file___235 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___235 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___187 *, struct cftype___187 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___187 *, struct cftype___187 *, s64);
	ssize_t (*write)(struct kernfs_open_file___248 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___248 *, struct poll_table_struct___181 *);
};

struct xdp_rxq_info___69 {
	struct net_device___69 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___69 {
	struct net_device___69 *dev;
};

struct xdp_buff___69 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___69 *rxq;
	struct xdp_txq_info___69 *txq;
	u32 frame_sz;
};

struct xdp_frame___69 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___69 *dev_rx;
};

struct netlink_callback___69 {
	struct sk_buff___70 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___70 *, struct netlink_callback___69 *);
	int (*done)(struct netlink_callback___69 *);
	void *data;
	struct module___244 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___69 {
	int (*create)(struct sk_buff___70 *, struct net_device___69 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___70 *, unsigned char *);
	int (*cache)(const struct neighbour___56 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___69 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___70 *);
};

struct netdev_queue___69 {
	struct net_device___69 *dev;
	struct Qdisc___63 *qdisc;
	struct Qdisc___63 *qdisc_sleeping;
	struct kobject___248 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___69 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___63 {
	struct sk_buff___70 *head;
	struct sk_buff___70 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___63;

struct Qdisc___63 {
	int (*enqueue)(struct sk_buff___70 *, struct Qdisc___63 *, struct sk_buff___70 **);
	struct sk_buff___70 * (*dequeue)(struct Qdisc___63 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___63 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___69 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___69 gso_skb;
	struct qdisc_skb_head___63 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___63 *next_sched;
	struct sk_buff_head___69 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___69 {
	struct xdp_rxq_info___69 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___248 kobj;
	struct net_device___69 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___69 {
	enum net_device_path_type type;
	const struct net_device___69 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___69 = 0,
				DEV_PATH_BR_VLAN_TAG___69 = 1,
				DEV_PATH_BR_VLAN_UNTAG___69 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___69 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___69 {
	const struct net_device___69 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___69 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___63 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___69 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___69 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___70 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___69 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___69 *dev;
	const char *name;
};

struct devlink_port___7;

struct net_device_ops___69 {
	int (*ndo_init)(struct net_device___69 *);
	void (*ndo_uninit)(struct net_device___69 *);
	int (*ndo_open)(struct net_device___69 *);
	int (*ndo_stop)(struct net_device___69 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___70 *, struct net_device___69 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___70 *, struct net_device___69 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___69 *, struct sk_buff___70 *, struct net_device___69 *);
	void (*ndo_change_rx_flags)(struct net_device___69 *, int);
	void (*ndo_set_rx_mode)(struct net_device___69 *);
	int (*ndo_set_mac_address)(struct net_device___69 *, void *);
	int (*ndo_validate_addr)(struct net_device___69 *);
	int (*ndo_do_ioctl)(struct net_device___69 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___69 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___69 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___69 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___69 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___69 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___69 *, int);
	int (*ndo_neigh_setup)(struct net_device___69 *, struct neigh_parms___56 *);
	void (*ndo_tx_timeout)(struct net_device___69 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___69 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___69 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___69 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___69 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___69 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___69 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___69 *);
	int (*ndo_netpoll_setup)(struct net_device___69 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___69 *);
	int (*ndo_set_vf_mac)(struct net_device___69 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___69 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___69 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___69 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___69 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___69 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___69 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___69 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___69 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___69 *, int, struct sk_buff___70 *);
	int (*ndo_get_vf_guid)(struct net_device___69 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___69 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___69 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___69 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___69 *);
	int (*ndo_fcoe_disable)(struct net_device___69 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___69 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___69 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___69 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___69 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___69 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___69 *, const struct sk_buff___70 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___69 *, struct net_device___69 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___69 *, struct net_device___69 *);
	struct net_device___69 * (*ndo_get_xmit_slave)(struct net_device___69 *, struct sk_buff___70 *, bool);
	struct net_device___69 * (*ndo_sk_get_lower_dev)(struct net_device___69 *, struct sock___56 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___69 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___69 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___69 *, struct neighbour___56 *);
	void (*ndo_neigh_destroy)(struct net_device___69 *, struct neighbour___56 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___70 *, struct netlink_callback___69 *, struct net_device___69 *, struct net_device___69 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___70 *, struct nlattr **, struct net_device___69 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___69 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___70 *, u32, u32, struct net_device___69 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___69 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___69 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___69 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___69 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___69 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___69 *, struct net_device___69 *);
	void (*ndo_dfwd_del_station)(struct net_device___69 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___69 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___69 *);
	int (*ndo_change_proto_down)(struct net_device___69 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___69 *, struct sk_buff___70 *);
	void (*ndo_set_rx_headroom)(struct net_device___69 *, int);
	int (*ndo_bpf)(struct net_device___69 *, struct netdev_bpf___69 *);
	int (*ndo_xdp_xmit)(struct net_device___69 *, int, struct xdp_frame___69 **, u32);
	struct net_device___69 * (*ndo_xdp_get_xmit_slave)(struct net_device___69 *, struct xdp_buff___69 *);
	int (*ndo_xsk_wakeup)(struct net_device___69 *, u32, u32);
	struct devlink_port___7 * (*ndo_get_devlink_port)(struct net_device___69 *);
	int (*ndo_tunnel_ctl)(struct net_device___69 *, struct ip_tunnel_parm *, int);
	struct net_device___69 * (*ndo_get_peer_dev)(struct net_device___69 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___69 *, struct net_device_path___69 *);
};

struct neigh_parms___56 {
	possible_net_t___69 net;
	struct net_device___69 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___56 *);
	struct neigh_table___56 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct devlink___7;

struct devlink_rate___7;

struct devlink_port___7 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___7 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set;
	u8 switch_port;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___7 *devlink_rate;
};

struct ethtool_ops___30 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___69 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___69 *);
	void (*get_regs)(struct net_device___69 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___69 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___69 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___69 *);
	void (*set_msglevel)(struct net_device___69 *, u32);
	int (*nway_reset)(struct net_device___69 *);
	u32 (*get_link)(struct net_device___69 *);
	int (*get_link_ext_state)(struct net_device___69 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___69 *);
	int (*get_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___69 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___69 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___69 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___69 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___69 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___69 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___69 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___69 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___69 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___69 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___69 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___69 *);
	void (*complete)(struct net_device___69 *);
	u32 (*get_priv_flags)(struct net_device___69 *);
	int (*set_priv_flags)(struct net_device___69 *, u32);
	int (*get_sset_count)(struct net_device___69 *, int);
	int (*get_rxnfc)(struct net_device___69 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___69 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___69 *, struct ethtool_flash *);
	int (*reset)(struct net_device___69 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___69 *);
	u32 (*get_rxfh_indir_size)(struct net_device___69 *);
	int (*get_rxfh)(struct net_device___69 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___69 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___69 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___69 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___69 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___69 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___69 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___69 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___69 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___69 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___69 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___69 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___69 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___69 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___69 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___69 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___69 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___69 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___69 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___69 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___69 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___69 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___69 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___69 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___69 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___69 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___69 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___69 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___69 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___69 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___69 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct l3mdev_ops___56 {
	u32 (*l3mdev_fib_table)(const struct net_device___69 *);
	struct sk_buff___70 * (*l3mdev_l3_rcv)(struct net_device___69 *, struct sk_buff___70 *, u16);
	struct sk_buff___70 * (*l3mdev_l3_out)(struct net_device___69 *, struct sock___56 *, struct sk_buff___70 *, u16);
	struct dst_entry___56 * (*l3mdev_link_scope_lookup)(const struct net_device___69 *, struct flowi6 *);
};

struct ndisc_ops___40 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___69 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___69 *, struct neighbour___56 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___69 *, u8, struct neighbour___56 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___69 *, struct sk_buff___70 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___74 *, struct net_device___69 *, const struct prefix_info *, struct inet6_dev___40 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct phylink_config___5 {
	struct device___241 *dev;
	enum phylink_op_type type;
	bool pcs_poll;
	bool poll_fixed_state;
	bool ovr_an_inband;
	void (*get_fixed_state)(struct phylink_config___5 *, struct phylink_link_state *);
};

struct dsa_device_ops___5;

struct dsa_switch_tree___5;

struct dsa_switch___5;

struct dsa_netdevice_ops___5;

struct dsa_port___5 {
	union {
		struct net_device___69 *master;
		struct net_device___69 *slave;
	};
	const struct dsa_device_ops___5 *tag_ops;
	struct dsa_switch_tree___5 *dst;
	struct sk_buff___70 * (*rcv)(struct sk_buff___70 *, struct net_device___69 *);
	enum {
		DSA_PORT_TYPE_UNUSED___5 = 0,
		DSA_PORT_TYPE_CPU___5 = 1,
		DSA_PORT_TYPE_DSA___5 = 2,
		DSA_PORT_TYPE_USER___5 = 3,
	} type;
	struct dsa_switch___5 *ds;
	unsigned int index;
	const char *name;
	struct dsa_port___5 *cpu_dp;
	u8 mac[6];
	struct device_node___104 *dn;
	unsigned int ageing_time;
	bool vlan_filtering;
	bool learning;
	u8 stp_state;
	struct net_device___69 *bridge_dev;
	int bridge_num;
	struct devlink_port___7 devlink_port;
	bool devlink_port_setup;
	struct phylink *pl;
	struct phylink_config___5 pl_config;
	struct net_device___69 *lag_dev;
	bool lag_tx_enabled;
	struct net_device___69 *hsr_dev;
	struct list_head list;
	void *priv;
	const struct ethtool_ops___30 *orig_ethtool_ops;
	const struct dsa_netdevice_ops___5 *netdev_ops;
	struct list_head fdbs;
	struct list_head mdbs;
	bool setup;
};

struct ifmcaddr6___40;

struct inet6_dev___40 {
	struct net_device___69 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___40 *mc_list;
	struct ifmcaddr6___40 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___69 mc_query_queue;
	struct sk_buff_head___69 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___10 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___56 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___63;

struct tcf_block___63;

struct mini_Qdisc___63 {
	struct tcf_proto___63 *filter_list;
	struct tcf_block___63 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___63 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___69 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___69 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___74 *, struct net_device___69 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___69 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___69 *, struct list_head *);
	size_t (*get_size)(const struct net_device___69 *);
	int (*fill_info)(struct sk_buff___70 *, const struct net_device___69 *);
	size_t (*get_xstats_size)(const struct net_device___69 *);
	int (*fill_xstats)(struct sk_buff___70 *, const struct net_device___69 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___69 *, struct net_device___69 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___69 *, const struct net_device___69 *);
	int (*fill_slave_info)(struct sk_buff___70 *, const struct net_device___69 *, const struct net_device___69 *);
	struct net___74 * (*get_link_net)(const struct net_device___69 *);
	size_t (*get_linkxstats_size)(const struct net_device___69 *, int);
	int (*fill_linkxstats)(struct sk_buff___70 *, const struct net_device___69 *, int *, int);
};

struct mii_bus___16;

struct mdio_device___16 {
	struct device___241 dev;
	struct mii_bus___16 *bus;
	char modalias[32];
	int (*bus_match)(struct device___241 *, struct device_driver___241 *);
	void (*device_free)(struct mdio_device___16 *);
	void (*device_remove)(struct mdio_device___16 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___13;

struct mii_timestamper___13;

struct phy_device___13 {
	struct mdio_device___16 mdio;
	struct phy_driver___13 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___70 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___69 *attached_dev;
	struct mii_timestamper___13 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___13 *, bool);
	void (*adjust_link)(struct net_device___69 *);
	const struct macsec_ops *macsec_ops;
};

struct napi_gro_cb___3 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___70 *last;
};

struct offload_callbacks___2 {
	struct sk_buff___70 * (*gso_segment)(struct sk_buff___70 *, netdev_features_t);
	struct sk_buff___70 * (*gro_receive)(struct list_head *, struct sk_buff___70 *);
	int (*gro_complete)(struct sk_buff___70 *, int);
};

struct packet_offload___2 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___2 callbacks;
	struct list_head list;
};

struct netdev_notifier_info___12 {
	struct net_device___69 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_changeupper_info___5 {
	struct netdev_notifier_info___12 info;
	struct net_device___69 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct flow_action_entry___5 {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___69 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action___5 {
	unsigned int num_entries;
	struct flow_action_entry___5 entries[0];
};

struct flow_rule___5 {
	struct flow_match match;
	struct flow_action___5 action;
};

struct mii_bus___16 {
	struct module___244 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___16 *, int, int);
	int (*write)(struct mii_bus___16 *, int, int, u16);
	int (*reset)(struct mii_bus___16 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___241 *parent;
	enum {
		MDIOBUS_ALLOCATED___16 = 1,
		MDIOBUS_REGISTERED___16 = 2,
		MDIOBUS_UNREGISTERED___16 = 3,
		MDIOBUS_RELEASED___16 = 4,
	} state;
	struct device___241 dev;
	struct mdio_device___16 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___16 = 0,
		MDIOBUS_C22___16 = 1,
		MDIOBUS_C45___16 = 2,
		MDIOBUS_C22_C45___16 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___15 {
	struct device_driver___241 driver;
	int flags;
};

struct mii_timestamper___13 {
	bool (*rxtstamp)(struct mii_timestamper___13 *, struct sk_buff___70 *, int);
	void (*txtstamp)(struct mii_timestamper___13 *, struct sk_buff___70 *, int);
	int (*hwtstamp)(struct mii_timestamper___13 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___13 *, struct phy_device___13 *);
	int (*ts_info)(struct mii_timestamper___13 *, struct ethtool_ts_info *);
	struct device___241 *device;
};

struct phy_driver___13 {
	struct mdio_driver_common___15 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___13 *);
	int (*config_init)(struct phy_device___13 *);
	int (*probe)(struct phy_device___13 *);
	int (*get_features)(struct phy_device___13 *);
	int (*suspend)(struct phy_device___13 *);
	int (*resume)(struct phy_device___13 *);
	int (*config_aneg)(struct phy_device___13 *);
	int (*aneg_done)(struct phy_device___13 *);
	int (*read_status)(struct phy_device___13 *);
	int (*config_intr)(struct phy_device___13 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___13 *);
	void (*remove)(struct phy_device___13 *);
	int (*match_phy_device)(struct phy_device___13 *);
	int (*set_wol)(struct phy_device___13 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___13 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___13 *);
	int (*read_mmd)(struct phy_device___13 *, int, u16);
	int (*write_mmd)(struct phy_device___13 *, int, u16, u16);
	int (*read_page)(struct phy_device___13 *);
	int (*write_page)(struct phy_device___13 *, int);
	int (*module_info)(struct phy_device___13 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___13 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___13 *);
	int (*cable_test_tdr_start)(struct phy_device___13 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___13 *, bool *);
	int (*get_sset_count)(struct phy_device___13 *);
	void (*get_strings)(struct phy_device___13 *, u8 *);
	void (*get_stats)(struct phy_device___13 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___13 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___13 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___13 *, bool);
	int (*get_sqi)(struct phy_device___13 *);
	int (*get_sqi_max)(struct phy_device___13 *);
};

struct property___78 {
	char *name;
	int length;
	void *value;
	struct property___78 *next;
	long unsigned int _flags;
	struct bin_attribute___248 attr;
};

struct pneigh_entry___56;

struct neigh_hash_table___56;

struct neigh_table___56 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___69 *, __u32 *);
	bool (*key_eq)(const struct neighbour___56 *, const void *);
	int (*constructor)(struct neighbour___56 *);
	int (*pconstructor)(struct pneigh_entry___56 *);
	void (*pdestructor)(struct pneigh_entry___56 *);
	void (*proxy_redo)(struct sk_buff___70 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___69 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___56 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___69 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___56 *nht;
	struct pneigh_entry___56 **phash_buckets;
};

struct neigh_ops___56 {
	int family;
	void (*solicit)(struct neighbour___56 *, struct sk_buff___70 *);
	void (*error_report)(struct neighbour___56 *, struct sk_buff___70 *);
	int (*output)(struct neighbour___56 *, struct sk_buff___70 *);
	int (*connected_output)(struct neighbour___56 *, struct sk_buff___70 *);
};

struct pneigh_entry___56 {
	struct pneigh_entry___56 *next;
	possible_net_t___69 net;
	struct net_device___69 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___56 {
	struct neighbour___56 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___34 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___74 *, struct sock___56 *, struct sk_buff___70 *);
	int (*orig_input)(struct sk_buff___70 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct block_device_operations___151;

struct gendisk___154 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___154 *part0;
	const struct block_device_operations___151 *fops;
	struct request_queue___151 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___137 *bdi;
	struct kobject___248 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___248 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___151 {
	struct bio___151 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___177 *bip_vec;
	struct bio_vec___177 bip_inline_vecs[0];
};

struct blkcg___139;

struct blkg_policy_data___139;

struct blkcg_gq___139 {
	struct request_queue___151 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___139 *blkcg;
	struct blkcg_gq___139 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___139 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___151 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___151(struct request___151 *);

typedef void integrity_complete_fn___151(struct request___151 *, unsigned int);

struct blk_integrity_profile___151 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___151 *prepare_fn;
	integrity_complete_fn___151 *complete_fn;
	const char *name;
};

struct block_device_operations___151 {
	blk_qc_t (*submit_bio)(struct bio___151 *);
	int (*open)(struct block_device___154 *, fmode_t);
	void (*release)(struct gendisk___154 *, fmode_t);
	int (*rw_page)(struct block_device___154 *, sector_t, struct page___265 *, unsigned int);
	int (*ioctl)(struct block_device___154 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___154 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___154 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___154 *);
	int (*getgeo)(struct block_device___154 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___154 *, bool);
	void (*swap_slot_free_notify)(struct block_device___154 *, long unsigned int);
	int (*report_zones)(struct gendisk___154 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___154 *, umode_t *);
	struct module___244 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___154 *, sector_t *);
};

typedef void rq_end_io_fn___151(struct request___151 *, blk_status_t);

struct request___151 {
	struct request_queue___151 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___146 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___151 *bio;
	struct bio___151 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___177 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___151 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___151 *saved_end_io;
		} flush;
	};
	struct gendisk___154 *rq_disk;
	struct block_device___154 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___151 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___146 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___151 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___248 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___260 *debugfs_dir;
	struct dentry___260 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___151;

struct elevator_mq_ops___151 {
	int (*init_sched)(struct request_queue___151 *, struct elevator_type___151 *);
	void (*exit_sched)(struct elevator_queue___151 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___146 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___146 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___146 *);
	bool (*allow_merge)(struct request_queue___151 *, struct request___151 *, struct bio___151 *);
	bool (*bio_merge)(struct request_queue___151 *, struct bio___151 *, unsigned int);
	int (*request_merge)(struct request_queue___151 *, struct request___151 **, struct bio___151 *);
	void (*request_merged)(struct request_queue___151 *, struct request___151 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___151 *, struct request___151 *, struct request___151 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___151 *);
	void (*finish_request)(struct request___151 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___146 *, struct list_head *, bool);
	struct request___151 * (*dispatch_request)(struct blk_mq_hw_ctx___146 *);
	bool (*has_work)(struct blk_mq_hw_ctx___146 *);
	void (*completed_request)(struct request___151 *, u64);
	void (*requeue_request)(struct request___151 *);
	struct request___151 * (*former_request)(struct request_queue___151 *, struct request___151 *);
	struct request___151 * (*next_request)(struct request_queue___151 *, struct request___151 *);
	void (*init_icq)(struct io_cq___151 *);
	void (*exit_icq)(struct io_cq___151 *);
};

struct elv_fs_entry___151;

struct elevator_type___151 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___151 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___151 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___244 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___151 {
	struct elevator_type___151 *type;
	void *elevator_data;
	struct kobject___248 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___151 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___151 *, char *);
	ssize_t (*store)(struct elevator_queue___151 *, const char *, size_t);
};

struct blk_mq_queue_data___146;

struct blk_mq_ops___146 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___146 *, const struct blk_mq_queue_data___146 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___146 *);
	int (*get_budget)(struct request_queue___151 *);
	void (*put_budget)(struct request_queue___151 *, int);
	void (*set_rq_budget_token)(struct request___151 *, int);
	int (*get_rq_budget_token)(struct request___151 *);
	enum blk_eh_timer_return (*timeout)(struct request___151 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___146 *);
	void (*complete)(struct request___151 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___146 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___146 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___146 *, struct request___151 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___146 *, struct request___151 *, unsigned int);
	void (*initialize_rq_fn)(struct request___151 *);
	void (*cleanup_rq)(struct request___151 *);
	bool (*busy)(struct request_queue___151 *);
	int (*map_queues)(struct blk_mq_tag_set___146 *);
	void (*show_rq)(struct seq_file___235 *, struct request___151 *);
};

struct blk_mq_tag_set___146 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___146 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___146 {
	struct request___151 *rq;
	bool last;
};

struct blkcg_policy_data___139;

struct blkcg___139 {
	struct cgroup_subsys_state___187 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___139 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___139 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___139 {
	struct blkcg___139 *blkcg;
	int plid;
};

struct blkg_policy_data___139 {
	struct blkcg_gq___139 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___125 {
	struct mem_cgroup___125 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___125 {
	struct lruvec___133 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___125 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___125 *memcg;
};

struct obj_cgroup___125 {
	struct percpu_ref refcnt;
	struct mem_cgroup___125 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___63 {
	spinlock_t *lock;
	struct sk_buff___70 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct flow_cls_offload___5 {
	struct flow_cls_common_offload common;
	enum flow_cls_command command;
	long unsigned int cookie;
	struct flow_rule___5 *rule;
	struct flow_stats stats;
	u32 classid;
};

struct Qdisc_class_ops___63;

struct Qdisc_ops___63 {
	struct Qdisc_ops___63 *next;
	const struct Qdisc_class_ops___63 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___70 *, struct Qdisc___63 *, struct sk_buff___70 **);
	struct sk_buff___70 * (*dequeue)(struct Qdisc___63 *);
	struct sk_buff___70 * (*peek)(struct Qdisc___63 *);
	int (*init)(struct Qdisc___63 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___63 *);
	void (*destroy)(struct Qdisc___63 *);
	int (*change)(struct Qdisc___63 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___63 *);
	int (*change_tx_queue_len)(struct Qdisc___63 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___63 *, unsigned int);
	int (*dump)(struct Qdisc___63 *, struct sk_buff___70 *);
	int (*dump_stats)(struct Qdisc___63 *, struct gnet_dump___63 *);
	void (*ingress_block_set)(struct Qdisc___63 *, u32);
	void (*egress_block_set)(struct Qdisc___63 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___63 *);
	u32 (*egress_block_get)(struct Qdisc___63 *);
	struct module___244 *owner;
};

struct qdisc_walker___6;

struct Qdisc_class_ops___63 {
	unsigned int flags;
	struct netdev_queue___69 * (*select_queue)(struct Qdisc___63 *, struct tcmsg *);
	int (*graft)(struct Qdisc___63 *, long unsigned int, struct Qdisc___63 *, struct Qdisc___63 **, struct netlink_ext_ack *);
	struct Qdisc___63 * (*leaf)(struct Qdisc___63 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___63 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___63 *, u32);
	int (*change)(struct Qdisc___63 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___63 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___63 *, struct qdisc_walker___6 *);
	struct tcf_block___63 * (*tcf_block)(struct Qdisc___63 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___63 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___63 *, long unsigned int);
	int (*dump)(struct Qdisc___63 *, long unsigned int, struct sk_buff___70 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___63 *, long unsigned int, struct gnet_dump___63 *);
};

struct qdisc_walker___6 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___63 *, long unsigned int, struct qdisc_walker___6 *);
};

struct tcf_chain___63;

struct tcf_block___63 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___74 *net;
	struct Qdisc___63 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___63 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___63;

struct tcf_proto_ops___63;

struct tcf_proto___63 {
	struct tcf_proto___63 *next;
	void *root;
	int (*classify)(struct sk_buff___70 *, const struct tcf_proto___63 *, struct tcf_result___63 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___63 *ops;
	struct tcf_chain___63 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___63 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___63 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___63 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___70 *, const struct tcf_proto___63 *, struct tcf_result___63 *);
	int (*init)(struct tcf_proto___63 *);
	void (*destroy)(struct tcf_proto___63 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___63 *, u32);
	void (*put)(struct tcf_proto___63 *, void *);
	int (*change)(struct net___74 *, struct sk_buff___70 *, struct tcf_proto___63 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___63 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___63 *);
	void (*walk)(struct tcf_proto___63 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___63 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___63 *, void *);
	void (*hw_del)(struct tcf_proto___63 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___74 *, struct tcf_chain___63 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___74 *, struct tcf_proto___63 *, void *, struct sk_buff___70 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___74 *, struct tcf_proto___63 *, void *, struct sk_buff___70 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___70 *, struct net___74 *, void *);
	struct module___244 *owner;
	int flags;
};

struct tcf_chain___63 {
	struct mutex filter_chain_lock;
	struct tcf_proto___63 *filter_chain;
	struct list_head list;
	struct tcf_block___63 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___63 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___56 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___63 *prog;
};

struct fib_rule___56 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___56 *ctarget;
	struct net___74 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___56 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___56 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___43;

struct timewait_sock_ops___42;

struct proto___56 {
	void (*close)(struct sock___56 *, long int);
	int (*pre_connect)(struct sock___56 *, struct sockaddr *, int);
	int (*connect)(struct sock___56 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___56 *, int);
	struct sock___56 * (*accept)(struct sock___56 *, int, int *, bool);
	int (*ioctl)(struct sock___56 *, int, long unsigned int);
	int (*init)(struct sock___56 *);
	void (*destroy)(struct sock___56 *);
	void (*shutdown)(struct sock___56 *, int);
	int (*setsockopt)(struct sock___56 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___56 *, int, int, char *, int *);
	void (*keepalive)(struct sock___56 *, int);
	int (*compat_ioctl)(struct sock___56 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___56 *, struct msghdr___58 *, size_t);
	int (*recvmsg)(struct sock___56 *, struct msghdr___58 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___56 *, struct page___265 *, int, size_t, int);
	int (*bind)(struct sock___56 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___56 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___56 *, struct sk_buff___70 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___56 *);
	int (*hash)(struct sock___56 *);
	void (*unhash)(struct sock___56 *);
	void (*rehash)(struct sock___56 *);
	int (*get_port)(struct sock___56 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___56 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___56 *, int);
	bool (*sock_is_readable)(struct sock___56 *);
	void (*enter_memory_pressure)(struct sock___56 *);
	void (*leave_memory_pressure)(struct sock___56 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___43 *rsk_prot;
	struct timewait_sock_ops___42 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___244 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___56 *, int);
};

struct request_sock___44;

struct request_sock_ops___43 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___56 *, struct request_sock___44 *);
	void (*send_ack)(const struct sock___56 *, struct sk_buff___70 *, struct request_sock___44 *);
	void (*send_reset)(const struct sock___56 *, struct sk_buff___70 *);
	void (*destructor)(struct request_sock___44 *);
	void (*syn_ack_timeout)(const struct request_sock___44 *);
};

struct timewait_sock_ops___42 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___56 *, struct sock___56 *, void *);
	void (*twsk_destructor)(struct sock___56 *);
};

struct request_sock___44 {
	struct sock_common___56 __req_common;
	struct request_sock___44 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___43 *rsk_ops;
	struct sock___56 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___40 {
	struct in6_addr mca_addr;
	struct inet6_dev___40 *idev;
	struct ifmcaddr6___40 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct dsa_chip_data___5 {
	struct device___241 *host_dev;
	int sw_addr;
	struct device___241 *netdev[12];
	int eeprom_len;
	struct device_node___104 *of_node;
	char *port_names[12];
	struct device_node___104 *port_dn[12];
	s8 rtable[4];
};

struct dsa_platform_data___5 {
	struct device___241 *netdev;
	struct net_device___69 *of_netdev;
	int nr_chips;
	struct dsa_chip_data___5 *chip;
};

struct devlink_ops___7;

struct devlink___7 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___7 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___241 *dev;
	possible_net_t___69 _net;
	struct mutex lock;
	u8 reload_failed;
	u8 reload_enabled;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_ops___7 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___7 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___7 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___7 *, enum devlink_port_type);
	int (*port_split)(struct devlink___7 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___7 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___7 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___7 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___7 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___7 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___7 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___7 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___7 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___7 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___7 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___7 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___7 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___7 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___7 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___7 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___7 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___7 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___7 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___7 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___7 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___7 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___7 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___7 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___7 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___7 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___7 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___7 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___7 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___7 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___7 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___7 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___7 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___7 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___7 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___7 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___7 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___7 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___7 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___7 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___7 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___7 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___7 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___7 *, struct devlink_rate___7 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___7 *, struct devlink_rate___7 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___7 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___7 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___7 *parent;
	union {
		struct devlink_port___7 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct switchdev_obj___5 {
	struct list_head list;
	struct net_device___69 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___69 *, int, void *);
};

struct switchdev_obj_port_vlan___5 {
	struct switchdev_obj___5 obj;
	u16 flags;
	u16 vid;
};

struct switchdev_obj_port_mdb___5 {
	struct switchdev_obj___5 obj;
	unsigned char addr[6];
	u16 vid;
};

struct switchdev_obj_mrp___5 {
	struct switchdev_obj___5 obj;
	struct net_device___69 *p_port;
	struct net_device___69 *s_port;
	u32 ring_id;
	u16 prio;
};

struct switchdev_obj_ring_role_mrp___5 {
	struct switchdev_obj___5 obj;
	u8 ring_role;
	u32 ring_id;
	u8 sw_backup;
};

struct dsa_device_ops___5 {
	struct sk_buff___70 * (*xmit)(struct sk_buff___70 *, struct net_device___69 *);
	struct sk_buff___70 * (*rcv)(struct sk_buff___70 *, struct net_device___69 *);
	void (*flow_dissect)(const struct sk_buff___70 *, __be16 *, int *);
	unsigned int needed_headroom;
	unsigned int needed_tailroom;
	const char *name;
	enum dsa_tag_protocol proto;
	bool promisc_on_master;
};

struct dsa_netdevice_ops___5 {
	int (*ndo_eth_ioctl)(struct net_device___69 *, struct ifreq *, int);
};

struct dsa_switch_tree___5 {
	struct list_head list;
	struct raw_notifier_head nh;
	unsigned int index;
	struct kref refcount;
	bool setup;
	const struct dsa_device_ops___5 *tag_ops;
	enum dsa_tag_protocol default_proto;
	struct dsa_platform_data___5 *pd;
	struct list_head ports;
	struct list_head rtable;
	struct net_device___69 **lags;
	unsigned int lags_len;
	unsigned int last_switch;
};

struct dsa_switch_ops___5;

struct dsa_switch___5 {
	bool setup;
	struct device___241 *dev;
	struct dsa_switch_tree___5 *dst;
	unsigned int index;
	struct notifier_block nb;
	void *priv;
	struct dsa_chip_data___5 *cd;
	const struct dsa_switch_ops___5 *ops;
	u32 phys_mii_mask;
	struct mii_bus___16 *slave_mii_bus;
	unsigned int ageing_time_min;
	unsigned int ageing_time_max;
	struct dsa_8021q_context *tag_8021q_ctx;
	struct devlink___7 *devlink;
	unsigned int num_tx_queues;
	bool vlan_filtering_is_global;
	bool needs_standalone_vlan_filtering;
	bool configure_vlan_while_not_filtering;
	bool untag_bridge_pvid;
	bool assisted_learning_on_cpu_port;
	bool vlan_filtering;
	bool pcs_poll;
	bool mtu_enforcement_ingress;
	unsigned int num_lag_ids;
	unsigned int num_fwd_offloading_bridges;
	size_t num_ports;
};

struct dsa_switch_ops___5 {
	enum dsa_tag_protocol (*get_tag_protocol)(struct dsa_switch___5 *, int, enum dsa_tag_protocol);
	int (*change_tag_protocol)(struct dsa_switch___5 *, int, enum dsa_tag_protocol);
	int (*setup)(struct dsa_switch___5 *);
	void (*teardown)(struct dsa_switch___5 *);
	int (*port_setup)(struct dsa_switch___5 *, int);
	void (*port_teardown)(struct dsa_switch___5 *, int);
	u32 (*get_phy_flags)(struct dsa_switch___5 *, int);
	int (*phy_read)(struct dsa_switch___5 *, int, int);
	int (*phy_write)(struct dsa_switch___5 *, int, int, u16);
	void (*adjust_link)(struct dsa_switch___5 *, int, struct phy_device___13 *);
	void (*fixed_link_update)(struct dsa_switch___5 *, int, struct fixed_phy_status___2 *);
	void (*phylink_validate)(struct dsa_switch___5 *, int, long unsigned int *, struct phylink_link_state *);
	int (*phylink_mac_link_state)(struct dsa_switch___5 *, int, struct phylink_link_state *);
	void (*phylink_mac_config)(struct dsa_switch___5 *, int, unsigned int, const struct phylink_link_state *);
	void (*phylink_mac_an_restart)(struct dsa_switch___5 *, int);
	void (*phylink_mac_link_down)(struct dsa_switch___5 *, int, unsigned int, phy_interface_t);
	void (*phylink_mac_link_up)(struct dsa_switch___5 *, int, unsigned int, phy_interface_t, struct phy_device___13 *, int, int, bool, bool);
	void (*phylink_fixed_state)(struct dsa_switch___5 *, int, struct phylink_link_state *);
	void (*get_strings)(struct dsa_switch___5 *, int, u32, uint8_t *);
	void (*get_ethtool_stats)(struct dsa_switch___5 *, int, uint64_t *);
	int (*get_sset_count)(struct dsa_switch___5 *, int, int);
	void (*get_ethtool_phy_stats)(struct dsa_switch___5 *, int, uint64_t *);
	void (*get_stats64)(struct dsa_switch___5 *, int, struct rtnl_link_stats64 *);
	void (*self_test)(struct dsa_switch___5 *, int, struct ethtool_test *, u64 *);
	void (*get_wol)(struct dsa_switch___5 *, int, struct ethtool_wolinfo *);
	int (*set_wol)(struct dsa_switch___5 *, int, struct ethtool_wolinfo *);
	int (*get_ts_info)(struct dsa_switch___5 *, int, struct ethtool_ts_info *);
	int (*suspend)(struct dsa_switch___5 *);
	int (*resume)(struct dsa_switch___5 *);
	int (*port_enable)(struct dsa_switch___5 *, int, struct phy_device___13 *);
	void (*port_disable)(struct dsa_switch___5 *, int);
	int (*set_mac_eee)(struct dsa_switch___5 *, int, struct ethtool_eee *);
	int (*get_mac_eee)(struct dsa_switch___5 *, int, struct ethtool_eee *);
	int (*get_eeprom_len)(struct dsa_switch___5 *);
	int (*get_eeprom)(struct dsa_switch___5 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct dsa_switch___5 *, struct ethtool_eeprom *, u8 *);
	int (*get_regs_len)(struct dsa_switch___5 *, int);
	void (*get_regs)(struct dsa_switch___5 *, int, struct ethtool_regs *, void *);
	int (*port_prechangeupper)(struct dsa_switch___5 *, int, struct netdev_notifier_changeupper_info___5 *);
	int (*set_ageing_time)(struct dsa_switch___5 *, unsigned int);
	int (*port_bridge_join)(struct dsa_switch___5 *, int, struct net_device___69 *);
	void (*port_bridge_leave)(struct dsa_switch___5 *, int, struct net_device___69 *);
	int (*port_bridge_tx_fwd_offload)(struct dsa_switch___5 *, int, struct net_device___69 *, int);
	void (*port_bridge_tx_fwd_unoffload)(struct dsa_switch___5 *, int, struct net_device___69 *, int);
	void (*port_stp_state_set)(struct dsa_switch___5 *, int, u8);
	void (*port_fast_age)(struct dsa_switch___5 *, int);
	int (*port_pre_bridge_flags)(struct dsa_switch___5 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_bridge_flags)(struct dsa_switch___5 *, int, struct switchdev_brport_flags, struct netlink_ext_ack *);
	int (*port_vlan_filtering)(struct dsa_switch___5 *, int, bool, struct netlink_ext_ack *);
	int (*port_vlan_add)(struct dsa_switch___5 *, int, const struct switchdev_obj_port_vlan___5 *, struct netlink_ext_ack *);
	int (*port_vlan_del)(struct dsa_switch___5 *, int, const struct switchdev_obj_port_vlan___5 *);
	int (*port_fdb_add)(struct dsa_switch___5 *, int, const unsigned char *, u16);
	int (*port_fdb_del)(struct dsa_switch___5 *, int, const unsigned char *, u16);
	int (*port_fdb_dump)(struct dsa_switch___5 *, int, dsa_fdb_dump_cb_t *, void *);
	int (*port_mdb_add)(struct dsa_switch___5 *, int, const struct switchdev_obj_port_mdb___5 *);
	int (*port_mdb_del)(struct dsa_switch___5 *, int, const struct switchdev_obj_port_mdb___5 *);
	int (*get_rxnfc)(struct dsa_switch___5 *, int, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct dsa_switch___5 *, int, struct ethtool_rxnfc *);
	int (*cls_flower_add)(struct dsa_switch___5 *, int, struct flow_cls_offload___5 *, bool);
	int (*cls_flower_del)(struct dsa_switch___5 *, int, struct flow_cls_offload___5 *, bool);
	int (*cls_flower_stats)(struct dsa_switch___5 *, int, struct flow_cls_offload___5 *, bool);
	int (*port_mirror_add)(struct dsa_switch___5 *, int, struct dsa_mall_mirror_tc_entry *, bool);
	void (*port_mirror_del)(struct dsa_switch___5 *, int, struct dsa_mall_mirror_tc_entry *);
	int (*port_policer_add)(struct dsa_switch___5 *, int, struct dsa_mall_policer_tc_entry *);
	void (*port_policer_del)(struct dsa_switch___5 *, int);
	int (*port_setup_tc)(struct dsa_switch___5 *, int, enum tc_setup_type, void *);
	int (*crosschip_bridge_join)(struct dsa_switch___5 *, int, int, int, struct net_device___69 *);
	void (*crosschip_bridge_leave)(struct dsa_switch___5 *, int, int, int, struct net_device___69 *);
	int (*crosschip_lag_change)(struct dsa_switch___5 *, int, int);
	int (*crosschip_lag_join)(struct dsa_switch___5 *, int, int, struct net_device___69 *, struct netdev_lag_upper_info *);
	int (*crosschip_lag_leave)(struct dsa_switch___5 *, int, int, struct net_device___69 *);
	int (*port_hwtstamp_get)(struct dsa_switch___5 *, int, struct ifreq *);
	int (*port_hwtstamp_set)(struct dsa_switch___5 *, int, struct ifreq *);
	void (*port_txtstamp)(struct dsa_switch___5 *, int, struct sk_buff___70 *);
	bool (*port_rxtstamp)(struct dsa_switch___5 *, int, struct sk_buff___70 *, unsigned int);
	int (*devlink_param_get)(struct dsa_switch___5 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_param_set)(struct dsa_switch___5 *, u32, struct devlink_param_gset_ctx *);
	int (*devlink_info_get)(struct dsa_switch___5 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*devlink_sb_pool_get)(struct dsa_switch___5 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*devlink_sb_pool_set)(struct dsa_switch___5 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*devlink_sb_port_pool_get)(struct dsa_switch___5 *, int, unsigned int, u16, u32 *);
	int (*devlink_sb_port_pool_set)(struct dsa_switch___5 *, int, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_tc_pool_bind_get)(struct dsa_switch___5 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*devlink_sb_tc_pool_bind_set)(struct dsa_switch___5 *, int, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*devlink_sb_occ_snapshot)(struct dsa_switch___5 *, unsigned int);
	int (*devlink_sb_occ_max_clear)(struct dsa_switch___5 *, unsigned int);
	int (*devlink_sb_occ_port_pool_get)(struct dsa_switch___5 *, int, unsigned int, u16, u32 *, u32 *);
	int (*devlink_sb_occ_tc_port_bind_get)(struct dsa_switch___5 *, int, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*port_change_mtu)(struct dsa_switch___5 *, int, int);
	int (*port_max_mtu)(struct dsa_switch___5 *, int);
	int (*port_lag_change)(struct dsa_switch___5 *, int);
	int (*port_lag_join)(struct dsa_switch___5 *, int, struct net_device___69 *, struct netdev_lag_upper_info *);
	int (*port_lag_leave)(struct dsa_switch___5 *, int, struct net_device___69 *);
	int (*port_hsr_join)(struct dsa_switch___5 *, int, struct net_device___69 *);
	int (*port_hsr_leave)(struct dsa_switch___5 *, int, struct net_device___69 *);
	int (*port_mrp_add)(struct dsa_switch___5 *, int, const struct switchdev_obj_mrp___5 *);
	int (*port_mrp_del)(struct dsa_switch___5 *, int, const struct switchdev_obj_mrp___5 *);
	int (*port_mrp_add_ring_role)(struct dsa_switch___5 *, int, const struct switchdev_obj_ring_role_mrp___5 *);
	int (*port_mrp_del_ring_role)(struct dsa_switch___5 *, int, const struct switchdev_obj_ring_role_mrp___5 *);
	int (*tag_8021q_vlan_add)(struct dsa_switch___5 *, int, u16, u16);
	int (*tag_8021q_vlan_del)(struct dsa_switch___5 *, int, u16);
};

struct fch_hdr {
	__u8 daddr[6];
	__u8 saddr[6];
};

struct fcllc {
	__u8 dsap;
	__u8 ssap;
	__u8 llc;
	__u8 protid[3];
	__be16 ethertype;
};

struct fddi_8022_1_hdr {
	__u8 dsap;
	__u8 ssap;
	__u8 ctrl;
};

struct fddi_8022_2_hdr {
	__u8 dsap;
	__u8 ssap;
	__u8 ctrl_1;
	__u8 ctrl_2;
};

struct fddi_snap_hdr {
	__u8 dsap;
	__u8 ssap;
	__u8 ctrl;
	__u8 oui[3];
	__be16 ethertype;
};

struct fddihdr {
	__u8 fc;
	__u8 daddr[6];
	__u8 saddr[6];
	union {
		struct fddi_8022_1_hdr llc_8022_1;
		struct fddi_8022_2_hdr llc_8022_2;
		struct fddi_snap_hdr llc_snap;
	} hdr;
} __attribute__((packed));

struct dentry___261;

struct super_block___261;

struct module___245;

struct file_system_type___261 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___261 * (*mount)(struct file_system_type___261 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___261 *);
	struct module___245 *owner;
	struct file_system_type___261 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___261;

struct kiocb___261;

struct iov_iter___181;

struct poll_table_struct___182;

struct vm_area_struct___266;

struct inode___261;

struct file_lock___261;

struct page___266;

struct pipe_inode_info___102;

struct seq_file___236;

struct file_operations___262 {
	struct module___245 *owner;
	loff_t (*llseek)(struct file___261 *, loff_t, int);
	ssize_t (*read)(struct file___261 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___261 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___261 *, struct iov_iter___181 *);
	ssize_t (*write_iter)(struct kiocb___261 *, struct iov_iter___181 *);
	int (*iopoll)(struct kiocb___261 *, bool);
	int (*iterate)(struct file___261 *, struct dir_context *);
	int (*iterate_shared)(struct file___261 *, struct dir_context *);
	__poll_t (*poll)(struct file___261 *, struct poll_table_struct___182 *);
	long int (*unlocked_ioctl)(struct file___261 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___261 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___261 *, struct vm_area_struct___266 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___261 *, struct file___261 *);
	int (*flush)(struct file___261 *, fl_owner_t);
	int (*release)(struct inode___261 *, struct file___261 *);
	int (*fsync)(struct file___261 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___261 *, int);
	int (*lock)(struct file___261 *, int, struct file_lock___261 *);
	ssize_t (*sendpage)(struct file___261 *, struct page___266 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___261 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___261 *, long unsigned int);
	int (*flock)(struct file___261 *, int, struct file_lock___261 *);
	ssize_t (*splice_write)(struct pipe_inode_info___102 *, struct file___261 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___261 *, loff_t *, struct pipe_inode_info___102 *, size_t, unsigned int);
	int (*setlease)(struct file___261 *, long int, struct file_lock___261 **, void **);
	long int (*fallocate)(struct file___261 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___236 *, struct file___261 *);
	ssize_t (*copy_file_range)(struct file___261 *, loff_t, struct file___261 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___261 *, loff_t, struct file___261 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___261 *, loff_t, loff_t, int);
};

struct vmacache___266 {
	u64 seqnum;
	struct vm_area_struct___266 *vmas[4];
};

struct page_frag___266 {
	struct page___266 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___267;

struct pid___238;

struct nsproxy___247;

struct signal_struct___262;

struct bio_list___152;

struct backing_dev_info___138;

struct io_context___152;

struct css_set___188;

struct mem_cgroup___126;

struct request_queue___152;

struct vm_struct___244;

struct task_struct___268 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___268 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___267 *mm;
	struct mm_struct___267 *active_mm;
	struct vmacache___266 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___268 *real_parent;
	struct task_struct___268 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___268 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___238 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___247 *nsproxy;
	struct signal_struct___262 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___268 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___152 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___138 *backing_dev_info;
	struct io_context___152 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___188 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___102 *splice_pipe;
	struct page_frag___266 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___126 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___126 *active_memcg;
	struct request_queue___152 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___268 *oom_reaper_list;
	struct vm_struct___244 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___249;

struct kobj_type___249;

struct kernfs_node___249;

struct kobject___249 {
	const char *name;
	struct list_head entry;
	struct kobject___249 *parent;
	struct kset___249 *kset;
	struct kobj_type___249 *ktype;
	struct kernfs_node___249 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___246 {
	struct kobject___249 kobj;
	struct module___245 *mod;
	struct kobject___249 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___245 {
	struct module___245 *mod;
	struct latch_tree_node node;
};

struct module_layout___245 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___245 mtn;
};

struct module_attribute___245;

struct kernel_param___245;

struct module___245 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___246 mkobj;
	struct module_attribute___245 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___249 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___245 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___245 core_layout;
	struct module_layout___245 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___238;

struct upid___238 {
	int nr;
	struct pid_namespace___238 *ns;
};

struct pid_namespace___238 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___268 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___238 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___238 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___238 numbers[1];
};

typedef struct page___266 *pgtable_t___266;

struct address_space___261;

struct page_pool___90;

struct dev_pagemap___256;

struct page___266 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___261 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___90 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___266 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___266 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___267 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___256 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___256;

struct vm_area_struct___266 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___266 *vm_next;
	struct vm_area_struct___266 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___267 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___256 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___261 *vm_file;
	struct file___261 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___262 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___268 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___268 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___238 *pids[4];
	struct pid___238 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___267 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___266;

struct mm_struct___267 {
	struct {
		struct vm_area_struct___266 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___261 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___266 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___268 *owner;
		struct user_namespace___26 *user_ns;
		struct file___261 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___75;

struct cgroup_namespace___188;

struct nsproxy___247 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___238 *pid_ns_for_children;
	struct net___75 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___188 *cgroup_ns;
};

struct bio___152;

struct bio_list___152 {
	struct bio___152 *head;
	struct bio___152 *tail;
};

struct cgroup_subsys_state___188;

struct bdi_writeback___138 {
	struct backing_dev_info___138 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___188 *memcg_css;
	struct cgroup_subsys_state___188 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___242;

struct backing_dev_info___138 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___138 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___242 *dev;
	char dev_name[64];
	struct device___242 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___261 *debug_dir;
};

struct io_cq___152;

struct io_context___152 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___152 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___188;

struct css_set___188 {
	struct cgroup_subsys_state___188 *subsys[14];
	refcount_t refcount;
	struct css_set___188 *dom_cset;
	struct cgroup___188 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___188 *mg_src_cgrp;
	struct cgroup___188 *mg_dst_cgrp;
	struct css_set___188 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___261;

struct pipe_buffer___102;

struct pipe_inode_info___102 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___266 *tmp_page;
	struct fasync_struct___261 *fasync_readers;
	struct fasync_struct___261 *fasync_writers;
	struct pipe_buffer___102 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___188;

struct cgroup_subsys_state___188 {
	struct cgroup___188 *cgroup;
	struct cgroup_subsys___188 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___188 *parent;
};

struct cgroup_file___188 {
	struct kernfs_node___249 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___126;

struct mem_cgroup_per_node___126;

struct mem_cgroup___126 {
	struct cgroup_subsys_state___188 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___188 events_file;
	struct cgroup_file___188 events_local_file;
	struct cgroup_file___188 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___126 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___268 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___126 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___152;

struct blk_integrity___152 {
	const struct blk_integrity_profile___152 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___152 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___152 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___152;

struct elevator_queue___152;

struct blk_mq_ops___147;

struct blk_mq_hw_ctx___147;

struct gendisk___155;

struct blkcg_gq___140;

struct blk_mq_tag_set___147;

struct request_queue___152 {
	struct request___152 *last_merge;
	struct elevator_queue___152 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___147 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___147 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___155 *disk;
	struct kobject___249 kobj;
	struct kobject___249 *mq_kobj;
	struct blk_integrity___152 integrity;
	struct device___242 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___140 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___147 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___152 bio_split;
	struct dentry___261 *debugfs_dir;
	struct dentry___261 *sched_debugfs_dir;
	struct dentry___261 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___244 {
	struct vm_struct___244 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___266 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___261;

struct address_space___261 {
	struct inode___261 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___261 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___90 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___242 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___90 {
	u32 count;
	struct page___266 *cache[128];
};

struct page_pool___90 {
	struct page_pool_params___90 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___266 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___90 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___256;

struct dev_pagemap___256 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___256 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___261;

struct path___261 {
	struct vfsmount___261 *mnt;
	struct dentry___261 *dentry;
};

struct fown_struct___238 {
	rwlock_t lock;
	struct pid___238 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___261 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___261 f_path;
	struct inode___261 *f_inode;
	const struct file_operations___262 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___238 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___261 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___256;

struct vm_operations_struct___256 {
	void (*open)(struct vm_area_struct___266 *);
	void (*close)(struct vm_area_struct___266 *);
	int (*may_split)(struct vm_area_struct___266 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___266 *);
	int (*mprotect)(struct vm_area_struct___266 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___256 *);
	vm_fault_t (*huge_fault)(struct vm_fault___256 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___256 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___266 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___256 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___256 *);
	int (*access)(struct vm_area_struct___266 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___266 *);
	int (*set_policy)(struct vm_area_struct___266 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___266 *, long unsigned int);
	struct page___266 * (*find_special_page)(struct vm_area_struct___266 *, long unsigned int);
};

struct core_thread___266 {
	struct task_struct___268 *task;
	struct core_thread___266 *next;
};

struct core_state___266 {
	atomic_t nr_threads;
	struct core_thread___266 dumper;
	struct completion startup;
};

struct vm_fault___256 {
	const struct {
		struct vm_area_struct___266 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___266 *cow_page;
	struct page___266 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___266 prealloc_pte;
};

struct pglist_data___134;

struct lruvec___134 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___134 *pgdat;
};

struct zone___134 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___134 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___134 {
	struct zone___134 *zone;
	int zone_idx;
};

struct zonelist___134 {
	struct zoneref___134 _zonerefs[321];
};

struct pglist_data___134 {
	struct zone___134 node_zones[5];
	struct zonelist___134 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___268 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___268 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___134 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___261;

struct dentry___261 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___261 *d_parent;
	struct qstr d_name;
	struct inode___261 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___261 *d_op;
	struct super_block___261 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___261;

struct inode___261 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___261 *i_op;
	struct super_block___261 *i_sb;
	struct address_space___261 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___138 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___262 *i_fop;
		void (*free_inode)(struct inode___261 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___261 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___102 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___261 {
	int (*d_revalidate)(struct dentry___261 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___261 *, unsigned int);
	int (*d_hash)(const struct dentry___261 *, struct qstr *);
	int (*d_compare)(const struct dentry___261 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___261 *);
	int (*d_init)(struct dentry___261 *);
	void (*d_release)(struct dentry___261 *);
	void (*d_prune)(struct dentry___261 *);
	void (*d_iput)(struct dentry___261 *, struct inode___261 *);
	char * (*d_dname)(struct dentry___261 *, char *, int);
	struct vfsmount___261 * (*d_automount)(struct path___261 *);
	int (*d_manage)(const struct path___261 *, bool);
	struct dentry___261 * (*d_real)(struct dentry___261 *, const struct inode___261 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___261;

struct mem_dqinfo___261 {
	struct quota_format_type___261 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___261;

struct quota_info___261 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___261 *files[3];
	struct mem_dqinfo___261 info[3];
	const struct quota_format_ops___261 *ops[3];
};

struct rcuwait___262 {
	struct task_struct___268 *task;
};

struct percpu_rw_semaphore___262 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___262 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___261 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___262 rw_sem[3];
};

struct shrink_control___126;

struct shrinker___126 {
	long unsigned int (*count_objects)(struct shrinker___126 *, struct shrink_control___126 *);
	long unsigned int (*scan_objects)(struct shrinker___126 *, struct shrink_control___126 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___261;

struct dquot_operations___261;

struct quotactl_ops___261;

struct block_device___155;

struct super_block___261 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___261 *s_type;
	const struct super_operations___261 *s_op;
	const struct dquot_operations___261 *dq_op;
	const struct quotactl_ops___261 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___261 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___155 *s_bdev;
	struct backing_dev_info___138 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___261 s_dquot;
	struct sb_writers___261 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___261 *s_d_op;
	int cleancache_poolid;
	struct shrinker___126 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___261 {
	struct dentry___261 *mnt_root;
	struct super_block___261 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___126 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___126 *memcg;
};

struct psi_group___188 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___268 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___64;

struct cgroup_bpf___64 {
	struct bpf_prog_array___64 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___64 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___188;

struct cgroup_rstat_cpu___188;

struct cgroup___188 {
	struct cgroup_subsys_state___188 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___249 *kn;
	struct cgroup_file___188 procs_file;
	struct cgroup_file___188 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___188 *subsys[14];
	struct cgroup_root___188 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___188 *dom_cgrp;
	struct cgroup___188 *old_dom_cgrp;
	struct cgroup_rstat_cpu___188 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___188 psi;
	struct cgroup_bpf___64 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___152 {
	struct request_queue___152 *q;
	struct io_context___152 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___261 {
	struct file___261 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___261 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___261 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___261 *ia_file;
};

struct dquot___261 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___261 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___261 {
	int qf_fmt_id;
	const struct quota_format_ops___261 *qf_ops;
	struct module___245 *qf_owner;
	struct quota_format_type___261 *qf_next;
};

struct quota_format_ops___261 {
	int (*check_quota_file)(struct super_block___261 *, int);
	int (*read_file_info)(struct super_block___261 *, int);
	int (*write_file_info)(struct super_block___261 *, int);
	int (*free_file_info)(struct super_block___261 *, int);
	int (*read_dqblk)(struct dquot___261 *);
	int (*commit_dqblk)(struct dquot___261 *);
	int (*release_dqblk)(struct dquot___261 *);
	int (*get_next_id)(struct super_block___261 *, struct kqid *);
};

struct dquot_operations___261 {
	int (*write_dquot)(struct dquot___261 *);
	struct dquot___261 * (*alloc_dquot)(struct super_block___261 *, int);
	void (*destroy_dquot)(struct dquot___261 *);
	int (*acquire_dquot)(struct dquot___261 *);
	int (*release_dquot)(struct dquot___261 *);
	int (*mark_dirty)(struct dquot___261 *);
	int (*write_info)(struct super_block___261 *, int);
	qsize_t * (*get_reserved_space)(struct inode___261 *);
	int (*get_projid)(struct inode___261 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___261 *, qsize_t *);
	int (*get_next_id)(struct super_block___261 *, struct kqid *);
};

struct quotactl_ops___261 {
	int (*quota_on)(struct super_block___261 *, int, int, const struct path___261 *);
	int (*quota_off)(struct super_block___261 *, int);
	int (*quota_enable)(struct super_block___261 *, unsigned int);
	int (*quota_disable)(struct super_block___261 *, unsigned int);
	int (*quota_sync)(struct super_block___261 *, int);
	int (*set_info)(struct super_block___261 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___261 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___261 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___261 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___261 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___261 *, unsigned int);
};

struct writeback_control___138;

struct address_space_operations___261 {
	int (*writepage)(struct page___266 *, struct writeback_control___138 *);
	int (*readpage)(struct file___261 *, struct page___266 *);
	int (*writepages)(struct address_space___261 *, struct writeback_control___138 *);
	int (*set_page_dirty)(struct page___266 *);
	int (*readpages)(struct file___261 *, struct address_space___261 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___261 *, struct address_space___261 *, loff_t, unsigned int, unsigned int, struct page___266 **, void **);
	int (*write_end)(struct file___261 *, struct address_space___261 *, loff_t, unsigned int, unsigned int, struct page___266 *, void *);
	sector_t (*bmap)(struct address_space___261 *, sector_t);
	void (*invalidatepage)(struct page___266 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___266 *, gfp_t);
	void (*freepage)(struct page___266 *);
	ssize_t (*direct_IO)(struct kiocb___261 *, struct iov_iter___181 *);
	int (*migratepage)(struct address_space___261 *, struct page___266 *, struct page___266 *, enum migrate_mode);
	bool (*isolate_page)(struct page___266 *, isolate_mode_t);
	void (*putback_page)(struct page___266 *);
	int (*launder_page)(struct page___266 *);
	int (*is_partially_uptodate)(struct page___266 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___266 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___261 *, struct page___266 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___261 *, sector_t *);
	void (*swap_deactivate)(struct file___261 *);
};

struct writeback_control___138 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___138 *wb;
	struct inode___261 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___178;

struct iov_iter___181 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___178 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___102 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___261 {
	struct dentry___261 * (*lookup)(struct inode___261 *, struct dentry___261 *, unsigned int);
	const char * (*get_link)(struct dentry___261 *, struct inode___261 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___261 *, int);
	struct posix_acl * (*get_acl)(struct inode___261 *, int, bool);
	int (*readlink)(struct dentry___261 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___261 *, struct dentry___261 *, umode_t, bool);
	int (*link)(struct dentry___261 *, struct inode___261 *, struct dentry___261 *);
	int (*unlink)(struct inode___261 *, struct dentry___261 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___261 *, struct dentry___261 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___261 *, struct dentry___261 *, umode_t);
	int (*rmdir)(struct inode___261 *, struct dentry___261 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___261 *, struct dentry___261 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___261 *, struct dentry___261 *, struct inode___261 *, struct dentry___261 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___261 *, struct iattr___261 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___261 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___261 *, char *, size_t);
	int (*fiemap)(struct inode___261 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___261 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___261 *, struct dentry___261 *, struct file___261 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___261 *, struct dentry___261 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___261 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___261 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___261 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___261 {
	void (*fl_copy_lock)(struct file_lock___261 *, struct file_lock___261 *);
	void (*fl_release_private)(struct file_lock___261 *);
};

struct lock_manager_operations___261;

struct file_lock___261 {
	struct file_lock___261 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___261 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___261 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___261 *fl_ops;
	const struct lock_manager_operations___261 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___261 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___261 *);
	int (*lm_grant)(struct file_lock___261 *, int);
	bool (*lm_break)(struct file_lock___261 *);
	int (*lm_change)(struct file_lock___261 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___261 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___261 *);
};

struct fasync_struct___261 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___261 *fa_next;
	struct file___261 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___261 {
	struct inode___261 * (*alloc_inode)(struct super_block___261 *);
	void (*destroy_inode)(struct inode___261 *);
	void (*free_inode)(struct inode___261 *);
	void (*dirty_inode)(struct inode___261 *, int);
	int (*write_inode)(struct inode___261 *, struct writeback_control___138 *);
	int (*drop_inode)(struct inode___261 *);
	void (*evict_inode)(struct inode___261 *);
	void (*put_super)(struct super_block___261 *);
	int (*sync_fs)(struct super_block___261 *, int);
	int (*freeze_super)(struct super_block___261 *);
	int (*freeze_fs)(struct super_block___261 *);
	int (*thaw_super)(struct super_block___261 *);
	int (*unfreeze_fs)(struct super_block___261 *);
	int (*statfs)(struct dentry___261 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___261 *, int *, char *);
	void (*umount_begin)(struct super_block___261 *);
	int (*show_options)(struct seq_file___236 *, struct dentry___261 *);
	int (*show_devname)(struct seq_file___236 *, struct dentry___261 *);
	int (*show_path)(struct seq_file___236 *, struct dentry___261 *);
	int (*show_stats)(struct seq_file___236 *, struct dentry___261 *);
	ssize_t (*quota_read)(struct super_block___261 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___261 *, int, const char *, size_t, loff_t);
	struct dquot___261 ** (*get_dquots)(struct inode___261 *);
	long int (*nr_cached_objects)(struct super_block___261 *, struct shrink_control___126 *);
	long int (*free_cached_objects)(struct super_block___261 *, struct shrink_control___126 *);
	struct file___261 * (*real_loop)(struct file___261 *);
};

struct wakeup_source___242;

struct dev_pm_info___242 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___242 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___242 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___242;

struct bus_type___242;

struct device_driver___242;

struct dev_pm_domain___242;

struct fwnode_handle___238;

struct class___242;

struct attribute_group___249;

struct device___242 {
	struct kobject___249 kobj;
	struct device___242 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___242 *type;
	struct bus_type___242 *bus;
	struct device_driver___242 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___242 power;
	struct dev_pm_domain___242 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___238 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___242 *class;
	const struct attribute_group___249 **groups;
	void (*release)(struct device___242 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___155 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___261 *bd_inode;
	struct super_block___261 *bd_super;
	void *bd_claiming;
	struct device___242 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___249 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___155 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___261 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___190)(struct file___261 *, wait_queue_head_t *, struct poll_table_struct___182 *);

struct poll_table_struct___182 {
	poll_queue_proc___190 _qproc;
	__poll_t _key;
};

struct seq_operations___236;

struct seq_file___236 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___236 *op;
	int poll_event;
	const struct file___261 *file;
	void *private;
};

typedef void bio_end_io_t___152(struct bio___152 *);

struct bio_vec___178 {
	struct page___266 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___152;

struct bio___152 {
	struct bio___152 *bi_next;
	struct block_device___155 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___152 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___140 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___152 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___178 *bi_io_vec;
	struct bio_set___152 *bi_pool;
	struct bio_vec___178 bi_inline_vecs[0];
};

struct kernfs_root___249;

struct kernfs_elem_dir___249 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___249 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___249;

struct kernfs_root___249 {
	struct kernfs_node___249 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___249 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___249 {
	struct kernfs_node___249 *target_kn;
};

struct kernfs_ops___249;

struct kernfs_elem_attr___249 {
	const struct kernfs_ops___249 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___249 *notify_next;
};

struct kernfs_node___249 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___249 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___249 dir;
		struct kernfs_elem_symlink___249 symlink;
		struct kernfs_elem_attr___249 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___249;

struct kernfs_ops___249 {
	int (*open)(struct kernfs_open_file___249 *);
	void (*release)(struct kernfs_open_file___249 *);
	int (*seq_show)(struct seq_file___236 *, void *);
	void * (*seq_start)(struct seq_file___236 *, loff_t *);
	void * (*seq_next)(struct seq_file___236 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___236 *, void *);
	ssize_t (*read)(struct kernfs_open_file___249 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___249 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___249 *, struct poll_table_struct___182 *);
	int (*mmap)(struct kernfs_open_file___249 *, struct vm_area_struct___266 *);
};

struct kernfs_syscall_ops___249 {
	int (*show_options)(struct seq_file___236 *, struct kernfs_root___249 *);
	int (*mkdir)(struct kernfs_node___249 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___249 *);
	int (*rename)(struct kernfs_node___249 *, struct kernfs_node___249 *, const char *);
	int (*show_path)(struct seq_file___236 *, struct kernfs_node___249 *, struct kernfs_root___249 *);
};

struct kernfs_open_file___249 {
	struct kernfs_node___249 *kn;
	struct file___261 *file;
	struct seq_file___236 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___256 *vm_ops;
};

struct sock___57;

struct kobj_ns_type_operations___57 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___57 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___75 *net;
} possible_net_t___70;

struct proto___57;

struct sock_common___57 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___57 *skc_prot;
	possible_net_t___70 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___57 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___71;

struct sk_buff_head___70 {
	struct sk_buff___71 *next;
	struct sk_buff___71 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___57 {
	struct cgroup___188 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___57;

struct socket_wq___58;

struct xfrm_policy___7;

struct dst_entry___57;

struct socket___59;

struct net_device___70;

struct sock___57 {
	struct sock_common___57 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___70 sk_error_queue;
	struct sk_buff___71 *sk_rx_skb_cache;
	struct sk_buff_head___70 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___71 *head;
		struct sk_buff___71 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___57 *sk_filter;
	union {
		struct socket_wq___58 *sk_wq;
		struct socket_wq___58 *sk_wq_raw;
	};
	struct xfrm_policy___7 *sk_policy[2];
	struct dst_entry___57 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___57 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___71 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___71 *sk_tx_skb_cache;
	struct sk_buff_head___70 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___266 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___57 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___238 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___59 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___57 sk_cgrp_data;
	struct mem_cgroup___126 *sk_memcg;
	void (*sk_state_change)(struct sock___57 *);
	void (*sk_data_ready)(struct sock___57 *);
	void (*sk_write_space)(struct sock___57 *);
	void (*sk_error_report)(struct sock___57 *);
	int (*sk_backlog_rcv)(struct sock___57 *, struct sk_buff___71 *);
	struct sk_buff___71 * (*sk_validate_xmit_skb)(struct sock___57 *, struct net_device___70 *, struct sk_buff___71 *);
	void (*sk_destruct)(struct sock___57 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___249;

struct attribute_group___249 {
	const char *name;
	umode_t (*is_visible)(struct kobject___249 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___249 *, struct bin_attribute___249 *, int);
	struct attribute **attrs;
	struct bin_attribute___249 **bin_attrs;
};

struct bin_attribute___249 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___261 * (*f_mapping)();
	ssize_t (*read)(struct file___261 *, struct kobject___249 *, struct bin_attribute___249 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___261 *, struct kobject___249 *, struct bin_attribute___249 *, char *, loff_t, size_t);
	int (*mmap)(struct file___261 *, struct kobject___249 *, struct bin_attribute___249 *, struct vm_area_struct___266 *);
};

struct sysfs_ops___249 {
	ssize_t (*show)(struct kobject___249 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___249 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___249;

struct kset___249 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___249 kobj;
	const struct kset_uevent_ops___249 *uevent_ops;
};

struct kobj_type___249 {
	void (*release)(struct kobject___249 *);
	const struct sysfs_ops___249 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___249 **default_groups;
	const struct kobj_ns_type_operations___57 * (*child_ns_type)(struct kobject___249 *);
	const void * (*namespace)(struct kobject___249 *);
	void (*get_ownership)(struct kobject___249 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___249 {
	int (* const filter)(struct kset___249 *, struct kobject___249 *);
	const char * (* const name)(struct kset___249 *, struct kobject___249 *);
	int (* const uevent)(struct kset___249 *, struct kobject___249 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___245 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___245 *);
	int (*get)(char *, const struct kernel_param___245 *);
	void (*free)(void *);
};

struct kparam_array___245;

struct kernel_param___245 {
	const char *name;
	struct module___245 *mod;
	const struct kernel_param_ops___245 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___245 *arr;
	};
};

struct kparam_array___245 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___245 *ops;
	void *elem;
};

struct module_attribute___245 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___245 *, struct module_kobject___246 *, char *);
	ssize_t (*store)(struct module_attribute___245 *, struct module_kobject___246 *, const char *, size_t);
	void (*setup)(struct module___245 *, const char *);
	int (*test)(struct module___245 *);
	void (*free)(struct module___245 *);
};

struct msghdr___59 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___181 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___261 *msg_iocb;
};

struct sk_buff___71 {
	union {
		struct {
			struct sk_buff___71 *next;
			struct sk_buff___71 *prev;
			union {
				struct net_device___70 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___57 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___71 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___75;

struct fqdir___75 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___75 *f;
	struct net___75 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___75;

struct inet_frags___75 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___75 *, const void *);
	void (*destructor)(struct inet_frag_queue___75 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___33;

struct fib_rules_ops___57;

struct fib_notifier_ops___57;

struct netns_ipv4___75 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___33 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___57 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___57 *fibnl;
	struct sock___57 **icmp_sk;
	struct sock___57 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___57 **tcp_sk;
	struct fqdir___75 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___57 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___57 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___57 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___57;

struct dst_ops___75 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___75 *);
	struct dst_entry___57 * (*check)(struct dst_entry___57 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___57 *);
	unsigned int (*mtu)(const struct dst_entry___57 *);
	u32 * (*cow_metrics)(struct dst_entry___57 *, long unsigned int);
	void (*destroy)(struct dst_entry___57 *);
	void (*ifdown)(struct dst_entry___57 *, struct net_device___70 *, int);
	struct dst_entry___57 * (*negative_advice)(struct dst_entry___57 *);
	void (*link_failure)(struct sk_buff___71 *);
	void (*update_pmtu)(struct dst_entry___57 *, struct sock___57 *, struct sk_buff___71 *, u32, bool);
	void (*redirect)(struct dst_entry___57 *, struct sock___57 *, struct sk_buff___71 *);
	int (*local_out)(struct net___75 *, struct sock___57 *, struct sk_buff___71 *);
	struct neighbour___57 * (*neigh_lookup)(const struct dst_entry___57 *, struct sk_buff___71 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___57 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___11;

struct rt6_info___11;

struct fib6_table___11;

struct netns_ipv6___75 {
	struct dst_ops___75 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___75 *fqdir;
	struct fib6_info___11 *fib6_null_entry;
	struct rt6_info___11 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___11 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___11 *ip6_prohibit_entry;
	struct rt6_info___11 *ip6_blk_hole_entry;
	struct fib6_table___11 *fib6_local_tbl;
	struct fib_rules_ops___57 *fib6_rules_ops;
	struct sock___57 **icmp_sk;
	struct sock___57 *ndisc_sk;
	struct sock___57 *tcp_sk;
	struct sock___57 *igmp_sk;
	struct sock___57 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___57 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___57 *notifier_ops;
	struct fib_notifier_ops___57 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___75 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___75 *fqdir;
};

struct netns_sctp___57 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___57 *ctl_sock;
	struct sock___57 *udp4_sock;
	struct sock___57 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___64;

struct netns_bpf___64 {
	struct bpf_prog_array___64 *run_array[2];
	struct bpf_prog___64 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___75 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___57 *nlsk;
	struct sock___57 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___75 xfrm4_dst_ops;
	struct dst_ops___75 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___75 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___57 *rtnl;
	struct sock___57 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___70 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___75 ipv4;
	struct netns_ipv6___75 ipv6;
	struct netns_ieee802154_lowpan___75 ieee802154_lowpan;
	struct netns_sctp___57 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___70 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___64 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___75 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___57 *crypto_nlsk;
	struct sock___57 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___75 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___71 *fragments_tail;
	struct sk_buff___71 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___75 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___33 {
	struct ip_ra_chain___33 *next;
	struct sock___57 *sk;
	union {
		void (*destructor)(struct sock___57 *);
		struct sock___57 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___57;

struct fib_lookup_arg___57;

struct fib_rules_ops___57 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___57 *, struct flowi *, int, struct fib_lookup_arg___57 *);
	bool (*suppress)(struct fib_rule___57 *, int, struct fib_lookup_arg___57 *);
	int (*match)(struct fib_rule___57 *, struct flowi *, int);
	int (*configure)(struct fib_rule___57 *, struct sk_buff___71 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___57 *);
	int (*compare)(struct fib_rule___57 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___57 *, struct sk_buff___71 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___57 *);
	void (*flush_cache)(struct fib_rules_ops___57 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___245 *owner;
	struct net___75 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___57 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___75 *);
	int (*fib_dump)(struct net___75 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___245 *owner;
	struct callback_head rcu;
};

struct xfrm_state___7;

struct lwtunnel_state___35;

struct dst_entry___57 {
	struct net_device___70 *dev;
	struct dst_ops___75 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___7 *xfrm;
	int (*input)(struct sk_buff___71 *);
	int (*output)(struct net___75 *, struct sock___57 *, struct sk_buff___71 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___35 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___70(struct sk_buff___71 **);

struct bpf_xdp_entity___64 {
	struct bpf_prog___64 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___70;

struct net_device_ops___70;

struct l3mdev_ops___57;

struct ndisc_ops___41;

struct xfrmdev_ops___70;

struct header_ops___70;

struct inet6_dev___41;

struct netdev_rx_queue___70;

struct mini_Qdisc___64;

struct netdev_queue___70;

struct Qdisc___64;

struct rtnl_link_ops___64;

struct dcbnl_rtnl_ops___70;

struct net_device___70 {
	char name[16];
	struct netdev_name_node___70 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___70 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___57 *l3mdev_ops;
	const struct ndisc_ops___41 *ndisc_ops;
	const struct xfrmdev_ops___70 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___70 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___249 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___41 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___70 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___64 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___70 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___64 *miniq_ingress;
	struct netdev_queue___70 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___70 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___64 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___64 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___70 = 0,
		NETREG_REGISTERED___70 = 1,
		NETREG_UNREGISTERING___70 = 2,
		NETREG_UNREGISTERED___70 = 3,
		NETREG_RELEASED___70 = 4,
		NETREG_DUMMY___70 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___70 = 0,
		RTNL_LINK_INITIALIZING___70 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___70 *);
	struct netpoll_info *npinfo;
	possible_net_t___70 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___242 dev;
	const struct attribute_group___249 *sysfs_groups[4];
	const struct attribute_group___249 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___64 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___70 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___64 xdp_state[3];
	long: 64;
};

struct neigh_table___57;

struct neigh_parms___57;

struct neigh_ops___57;

struct neighbour___57 {
	struct neighbour___57 *next;
	struct neigh_table___57 *tbl;
	struct neigh_parms___57 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___70 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___57 *, struct sk_buff___71 *);
	const struct neigh_ops___57 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___70 *dev;
	u8 primary_key[0];
};

struct rtable___11;

struct fnhe_hash_bucket___11;

struct fib_nh_common___11 {
	struct net_device___70 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___35 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___11 **nhc_pcpu_rth_output;
	struct rtable___11 *nhc_rth_input;
	struct fnhe_hash_bucket___11 *nhc_exceptions;
};

struct fib6_nh___11 {
	struct fib_nh_common___11 nh_common;
	long unsigned int last_probe;
	struct rt6_info___11 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___11;

struct fib6_info___11 {
	struct fib6_table___11 *fib6_table;
	struct fib6_info___11 *fib6_next;
	struct fib6_node___11 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___11 fib6_nh[0];
};

struct rt6_info___11 {
	struct dst_entry___57 dst;
	struct fib6_info___11 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___41 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___11 {
	struct fib6_node___11 *parent;
	struct fib6_node___11 *left;
	struct fib6_node___11 *right;
	struct fib6_node___11 *subtree;
	struct fib6_info___11 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___11 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___11 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___11 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___64 {
	struct bpf_prog___64 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___64 {
	struct callback_head rcu;
	struct bpf_prog_array_item___64 items[0];
};

struct bpf_prog_aux___73;

struct bpf_prog___64 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___73 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___256 {
	void (*page_free)(struct page___266 *);
	void (*kill)(struct dev_pagemap___256 *);
	void (*cleanup)(struct dev_pagemap___256 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___256 *);
};

struct fwnode_operations___238;

struct fwnode_handle___238 {
	struct fwnode_handle___238 *secondary;
	const struct fwnode_operations___238 *ops;
	struct device___242 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___238;

struct fwnode_endpoint___238;

struct fwnode_operations___238 {
	struct fwnode_handle___238 * (*get)(struct fwnode_handle___238 *);
	void (*put)(struct fwnode_handle___238 *);
	bool (*device_is_available)(const struct fwnode_handle___238 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___238 *, const struct device___242 *);
	bool (*property_present)(const struct fwnode_handle___238 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___238 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___238 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___238 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*get_parent)(const struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*get_next_child_node)(const struct fwnode_handle___238 *, struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*get_named_child_node)(const struct fwnode_handle___238 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___238 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___238 *);
	struct fwnode_handle___238 * (*graph_get_next_endpoint)(const struct fwnode_handle___238 *, struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*graph_get_remote_endpoint)(const struct fwnode_handle___238 *);
	struct fwnode_handle___238 * (*graph_get_port_parent)(struct fwnode_handle___238 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___238 *, struct fwnode_endpoint___238 *);
	int (*add_links)(struct fwnode_handle___238 *);
};

struct fwnode_endpoint___238 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___238 *local_fwnode;
};

struct fwnode_reference_args___238 {
	struct fwnode_handle___238 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___188 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___188 *root_cset;
};

struct socket_wq___58 {
	wait_queue_head_t wait;
	struct fasync_struct___261 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___58;

struct socket___59 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___261 *file;
	struct sock___57 *sk;
	const struct proto_ops___58 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___58 wq;
};

typedef int (*sk_read_actor_t___57)(read_descriptor_t *, struct sk_buff___71 *, unsigned int, size_t);

struct proto_ops___58 {
	int family;
	struct module___245 *owner;
	int (*release)(struct socket___59 *);
	int (*bind)(struct socket___59 *, struct sockaddr *, int);
	int (*connect)(struct socket___59 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___59 *, struct socket___59 *);
	int (*accept)(struct socket___59 *, struct socket___59 *, int, bool);
	int (*getname)(struct socket___59 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___261 *, struct socket___59 *, struct poll_table_struct___182 *);
	int (*ioctl)(struct socket___59 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___59 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___59 *, void *, bool, bool);
	int (*listen)(struct socket___59 *, int);
	int (*shutdown)(struct socket___59 *, int);
	int (*setsockopt)(struct socket___59 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___59 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___236 *, struct socket___59 *);
	int (*sendmsg)(struct socket___59 *, struct msghdr___59 *, size_t);
	int (*recvmsg)(struct socket___59 *, struct msghdr___59 *, size_t, int);
	int (*mmap)(struct file___261 *, struct socket___59 *, struct vm_area_struct___266 *);
	ssize_t (*sendpage)(struct socket___59 *, struct page___266 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___59 *, loff_t *, struct pipe_inode_info___102 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___57 *, int);
	int (*peek_len)(struct socket___59 *);
	int (*read_sock)(struct sock___57 *, read_descriptor_t *, sk_read_actor_t___57);
	int (*sendpage_locked)(struct sock___57 *, struct page___266 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___57 *, struct msghdr___59 *, size_t);
	int (*set_rcvlowat)(struct sock___57 *, int);
};

struct dev_pm_ops___242 {
	int (*prepare)(struct device___242 *);
	void (*complete)(struct device___242 *);
	int (*suspend)(struct device___242 *);
	int (*resume)(struct device___242 *);
	int (*freeze)(struct device___242 *);
	int (*thaw)(struct device___242 *);
	int (*poweroff)(struct device___242 *);
	int (*restore)(struct device___242 *);
	int (*suspend_late)(struct device___242 *);
	int (*resume_early)(struct device___242 *);
	int (*freeze_late)(struct device___242 *);
	int (*thaw_early)(struct device___242 *);
	int (*poweroff_late)(struct device___242 *);
	int (*restore_early)(struct device___242 *);
	int (*suspend_noirq)(struct device___242 *);
	int (*resume_noirq)(struct device___242 *);
	int (*freeze_noirq)(struct device___242 *);
	int (*thaw_noirq)(struct device___242 *);
	int (*poweroff_noirq)(struct device___242 *);
	int (*restore_noirq)(struct device___242 *);
	int (*runtime_suspend)(struct device___242 *);
	int (*runtime_resume)(struct device___242 *);
	int (*runtime_idle)(struct device___242 *);
};

struct wakeup_source___242 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___242 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___242 {
	struct dev_pm_ops___242 ops;
	int (*start)(struct device___242 *);
	void (*detach)(struct device___242 *, bool);
	int (*activate)(struct device___242 *);
	void (*sync)(struct device___242 *);
	void (*dismiss)(struct device___242 *);
};

struct bus_type___242 {
	const char *name;
	const char *dev_name;
	struct device___242 *dev_root;
	const struct attribute_group___249 **bus_groups;
	const struct attribute_group___249 **dev_groups;
	const struct attribute_group___249 **drv_groups;
	int (*match)(struct device___242 *, struct device_driver___242 *);
	int (*uevent)(struct device___242 *, struct kobj_uevent_env *);
	int (*probe)(struct device___242 *);
	void (*sync_state)(struct device___242 *);
	void (*remove)(struct device___242 *);
	void (*shutdown)(struct device___242 *);
	int (*online)(struct device___242 *);
	int (*offline)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	int (*num_vf)(struct device___242 *);
	int (*dma_configure)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___242 {
	const char *name;
	struct bus_type___242 *bus;
	struct module___245 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___242 *);
	void (*sync_state)(struct device___242 *);
	int (*remove)(struct device___242 *);
	void (*shutdown)(struct device___242 *);
	int (*suspend)(struct device___242 *, pm_message_t);
	int (*resume)(struct device___242 *);
	const struct attribute_group___249 **groups;
	const struct attribute_group___249 **dev_groups;
	const struct dev_pm_ops___242 *pm;
	void (*coredump)(struct device___242 *);
	struct driver_private *p;
};

struct device_type___242 {
	const char *name;
	const struct attribute_group___249 **groups;
	int (*uevent)(struct device___242 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___242 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___242 *);
	const struct dev_pm_ops___242 *pm;
};

struct class___242 {
	const char *name;
	struct module___245 *owner;
	const struct attribute_group___249 **class_groups;
	const struct attribute_group___249 **dev_groups;
	struct kobject___249 *dev_kobj;
	int (*dev_uevent)(struct device___242 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___242 *, umode_t *);
	void (*class_release)(struct class___242 *);
	void (*dev_release)(struct device___242 *);
	int (*shutdown_pre)(struct device___242 *);
	const struct kobj_ns_type_operations___57 *ns_type;
	const void * (*namespace)(struct device___242 *);
	void (*get_ownership)(struct device___242 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___242 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___102;

struct pipe_buffer___102 {
	struct page___266 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___102 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___102 {
	int (*confirm)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
	void (*release)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
	bool (*try_steal)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
	bool (*get)(struct pipe_inode_info___102 *, struct pipe_buffer___102 *);
};

typedef struct bio_vec___178 skb_frag_t___19;

struct skb_shared_info___18 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___71 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___19 frags[17];
};

struct seq_operations___236 {
	void * (*start)(struct seq_file___236 *, loff_t *);
	void (*stop)(struct seq_file___236 *, void *);
	void * (*next)(struct seq_file___236 *, void *, loff_t *);
	int (*show)(struct seq_file___236 *, void *);
};

struct dcbnl_rtnl_ops___70 {
	int (*ieee_getets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___70 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___70 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___70 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___70 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___70 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___70 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___70 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___70 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___70 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___70 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___70 *);
	u8 (*setstate)(struct net_device___70 *, u8);
	void (*getpermhwaddr)(struct net_device___70 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___70 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___70 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___70 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___70 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___70 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___70 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___70 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___70 *, int, u8 *);
	void (*setpfccfg)(struct net_device___70 *, int, u8);
	void (*getpfccfg)(struct net_device___70 *, int, u8 *);
	u8 (*setall)(struct net_device___70 *);
	u8 (*getcap)(struct net_device___70 *, int, u8 *);
	int (*getnumtcs)(struct net_device___70 *, int, u8 *);
	int (*setnumtcs)(struct net_device___70 *, int, u8);
	u8 (*getpfcstate)(struct net_device___70 *);
	void (*setpfcstate)(struct net_device___70 *, u8);
	void (*getbcncfg)(struct net_device___70 *, int, u32 *);
	void (*setbcncfg)(struct net_device___70 *, int, u32);
	void (*getbcnrp)(struct net_device___70 *, int, u8 *);
	void (*setbcnrp)(struct net_device___70 *, int, u8);
	int (*setapp)(struct net_device___70 *, u8, u16, u8);
	int (*getapp)(struct net_device___70 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___70 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___70 *, int, u8);
	u8 (*getdcbx)(struct net_device___70 *);
	u8 (*setdcbx)(struct net_device___70 *, u8);
	int (*peer_getappinfo)(struct net_device___70 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___70 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___70 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___70 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___70 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___70 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___73;

typedef int (*bpf_iter_init_seq_priv_t___72)(void *, struct bpf_iter_aux_info___73 *);

struct bpf_map___73;

struct bpf_iter_aux_info___73 {
	struct bpf_map___73 *map;
};

struct bpf_iter_seq_info___72 {
	const struct seq_operations___236 *seq_ops;
	bpf_iter_init_seq_priv_t___72 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___72 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___73 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___73 *, struct file___261 *);
	void (*map_free)(struct bpf_map___73 *);
	int (*map_get_next_key)(struct bpf_map___73 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___73 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___73 *, void *);
	int (*map_lookup_batch)(struct bpf_map___73 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___73 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___73 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___73 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___73 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___73 *, void *);
	int (*map_update_elem)(struct bpf_map___73 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___73 *, void *);
	int (*map_push_elem)(struct bpf_map___73 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___73 *, void *);
	int (*map_peek_elem)(struct bpf_map___73 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___73 *, struct file___261 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___73 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___73 *, void *, struct seq_file___236 *);
	int (*map_check_btf)(const struct bpf_map___73 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___73 *, struct bpf_prog_aux___73 *);
	void (*map_poke_untrack)(struct bpf_map___73 *, struct bpf_prog_aux___73 *);
	void (*map_poke_run)(struct bpf_map___73 *, u32, struct bpf_prog___64 *, struct bpf_prog___64 *);
	int (*map_direct_value_addr)(const struct bpf_map___73 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___73 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___73 *, struct vm_area_struct___266 *);
	__poll_t (*map_poll)(struct bpf_map___73 *, struct file___261 *, struct poll_table_struct___182 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___73 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___73 *, const struct bpf_map___73 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___73 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___72 *iter_seq_info;
};

struct bpf_map___73 {
	const struct bpf_map_ops___72 *ops;
	struct bpf_map___73 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___126 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___72;

struct bpf_jit_poke_descriptor___72;

struct bpf_prog_ops___64;

struct btf_mod_pair___72;

struct bpf_prog_offload___70;

struct bpf_prog_aux___73 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___64 *dst_prog;
	struct bpf_trampoline___72 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___64 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___72 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___64 *ops;
	struct bpf_map___73 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___72 *used_btfs;
	struct bpf_prog___64 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___73 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___70 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___70;

struct bpf_map_dev_ops___70 {
	int (*map_get_next_key)(struct bpf_offloaded_map___70 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___70 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___70 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___70 *, void *);
};

struct bpf_offloaded_map___70 {
	struct bpf_map___73 map;
	struct net_device___70 *netdev;
	const struct bpf_map_dev_ops___70 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___64 {
	int (*test_run)(struct bpf_prog___64 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___70 {
	struct bpf_prog___64 *prog;
	struct net_device___70 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___72 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___64 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___245 *mod;
};

struct bpf_jit_poke_descriptor___72 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___73 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___72 {
	struct btf *btf;
	struct module___245 *module;
};

struct cftype___188;

struct cgroup_subsys___188 {
	struct cgroup_subsys_state___188 * (*css_alloc)(struct cgroup_subsys_state___188 *);
	int (*css_online)(struct cgroup_subsys_state___188 *);
	void (*css_offline)(struct cgroup_subsys_state___188 *);
	void (*css_released)(struct cgroup_subsys_state___188 *);
	void (*css_free)(struct cgroup_subsys_state___188 *);
	void (*css_reset)(struct cgroup_subsys_state___188 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___188 *, int);
	int (*css_extra_stat_show)(struct seq_file___236 *, struct cgroup_subsys_state___188 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___268 *, struct css_set___188 *);
	void (*cancel_fork)(struct task_struct___268 *, struct css_set___188 *);
	void (*fork)(struct task_struct___268 *);
	void (*exit)(struct task_struct___268 *);
	void (*release)(struct task_struct___268 *);
	void (*bind)(struct cgroup_subsys_state___188 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___188 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___188 *dfl_cftypes;
	struct cftype___188 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___188 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___188 *updated_children;
	struct cgroup___188 *updated_next;
};

struct cgroup_root___188 {
	struct kernfs_root___249 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___188 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___188 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___188 *ss;
	struct list_head node;
	struct kernfs_ops___249 *kf_ops;
	int (*open)(struct kernfs_open_file___249 *);
	void (*release)(struct kernfs_open_file___249 *);
	u64 (*read_u64)(struct cgroup_subsys_state___188 *, struct cftype___188 *);
	s64 (*read_s64)(struct cgroup_subsys_state___188 *, struct cftype___188 *);
	int (*seq_show)(struct seq_file___236 *, void *);
	void * (*seq_start)(struct seq_file___236 *, loff_t *);
	void * (*seq_next)(struct seq_file___236 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___236 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___188 *, struct cftype___188 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___188 *, struct cftype___188 *, s64);
	ssize_t (*write)(struct kernfs_open_file___249 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___249 *, struct poll_table_struct___182 *);
};

struct xdp_rxq_info___70 {
	struct net_device___70 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___70 {
	struct net_device___70 *dev;
};

struct xdp_buff___70 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___70 *rxq;
	struct xdp_txq_info___70 *txq;
	u32 frame_sz;
};

struct xdp_frame___70 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___70 *dev_rx;
};

struct netlink_callback___70 {
	struct sk_buff___71 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___71 *, struct netlink_callback___70 *);
	int (*done)(struct netlink_callback___70 *);
	void *data;
	struct module___245 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum macvlan_mode {
	MACVLAN_MODE_PRIVATE = 1,
	MACVLAN_MODE_VEPA = 2,
	MACVLAN_MODE_BRIDGE = 4,
	MACVLAN_MODE_PASSTHRU = 8,
	MACVLAN_MODE_SOURCE = 16,
};

struct tc_ratespec {
	unsigned char cell_log;
	__u8 linklayer;
	short unsigned int overhead;
	short int cell_align;
	short unsigned int mpu;
	__u32 rate;
};

struct tc_prio_qopt {
	int bands;
	__u8 priomap[16];
};

struct header_ops___70 {
	int (*create)(struct sk_buff___71 *, struct net_device___70 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___71 *, unsigned char *);
	int (*cache)(const struct neighbour___57 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___70 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___71 *);
};

struct netdev_queue___70 {
	struct net_device___70 *dev;
	struct Qdisc___64 *qdisc;
	struct Qdisc___64 *qdisc_sleeping;
	struct kobject___249 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___70 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___64 {
	struct sk_buff___71 *head;
	struct sk_buff___71 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___64;

struct Qdisc___64 {
	int (*enqueue)(struct sk_buff___71 *, struct Qdisc___64 *, struct sk_buff___71 **);
	struct sk_buff___71 * (*dequeue)(struct Qdisc___64 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___64 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___70 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___70 gso_skb;
	struct qdisc_skb_head___64 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___64 *next_sched;
	struct sk_buff_head___70 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___70 {
	struct xdp_rxq_info___70 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___249 kobj;
	struct net_device___70 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___70 {
	enum net_device_path_type type;
	const struct net_device___70 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___70 = 0,
				DEV_PATH_BR_VLAN_TAG___70 = 1,
				DEV_PATH_BR_VLAN_UNTAG___70 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___70 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___70 {
	const struct net_device___70 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___70 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___64 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___70 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___70 {
	int (*xdo_dev_state_add)(struct xfrm_state___7 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___7 *);
	void (*xdo_dev_state_free)(struct xfrm_state___7 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___71 *, struct xfrm_state___7 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___7 *);
};

struct xfrm_state_offload___7 {
	struct net_device___70 *dev;
	struct net_device___70 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___7;

struct xfrm_type_offload___7;

struct xfrm_state___7 {
	possible_net_t___70 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___57 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___7 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___7 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___266 xfrag;
	const struct xfrm_type___7 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___7 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___70 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___70 *dev;
	const char *name;
};

struct net_device_ops___70 {
	int (*ndo_init)(struct net_device___70 *);
	void (*ndo_uninit)(struct net_device___70 *);
	int (*ndo_open)(struct net_device___70 *);
	int (*ndo_stop)(struct net_device___70 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___71 *, struct net_device___70 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___71 *, struct net_device___70 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___70 *, struct sk_buff___71 *, struct net_device___70 *);
	void (*ndo_change_rx_flags)(struct net_device___70 *, int);
	void (*ndo_set_rx_mode)(struct net_device___70 *);
	int (*ndo_set_mac_address)(struct net_device___70 *, void *);
	int (*ndo_validate_addr)(struct net_device___70 *);
	int (*ndo_do_ioctl)(struct net_device___70 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___70 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___70 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___70 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___70 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___70 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___70 *, int);
	int (*ndo_neigh_setup)(struct net_device___70 *, struct neigh_parms___57 *);
	void (*ndo_tx_timeout)(struct net_device___70 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___70 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___70 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___70 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___70 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___70 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___70 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___70 *);
	int (*ndo_netpoll_setup)(struct net_device___70 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___70 *);
	int (*ndo_set_vf_mac)(struct net_device___70 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___70 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___70 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___70 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___70 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___70 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___70 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___70 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___70 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___70 *, int, struct sk_buff___71 *);
	int (*ndo_get_vf_guid)(struct net_device___70 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___70 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___70 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___70 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___70 *);
	int (*ndo_fcoe_disable)(struct net_device___70 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___70 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___70 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___70 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___70 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___70 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___70 *, const struct sk_buff___71 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___70 *, struct net_device___70 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___70 *, struct net_device___70 *);
	struct net_device___70 * (*ndo_get_xmit_slave)(struct net_device___70 *, struct sk_buff___71 *, bool);
	struct net_device___70 * (*ndo_sk_get_lower_dev)(struct net_device___70 *, struct sock___57 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___70 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___70 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___70 *, struct neighbour___57 *);
	void (*ndo_neigh_destroy)(struct net_device___70 *, struct neighbour___57 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___71 *, struct netlink_callback___70 *, struct net_device___70 *, struct net_device___70 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___71 *, struct nlattr **, struct net_device___70 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___70 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___71 *, u32, u32, struct net_device___70 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___70 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___70 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___70 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___70 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___70 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___70 *, struct net_device___70 *);
	void (*ndo_dfwd_del_station)(struct net_device___70 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___70 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___70 *);
	int (*ndo_change_proto_down)(struct net_device___70 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___70 *, struct sk_buff___71 *);
	void (*ndo_set_rx_headroom)(struct net_device___70 *, int);
	int (*ndo_bpf)(struct net_device___70 *, struct netdev_bpf___70 *);
	int (*ndo_xdp_xmit)(struct net_device___70 *, int, struct xdp_frame___70 **, u32);
	struct net_device___70 * (*ndo_xdp_get_xmit_slave)(struct net_device___70 *, struct xdp_buff___70 *);
	int (*ndo_xsk_wakeup)(struct net_device___70 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___70 *);
	int (*ndo_tunnel_ctl)(struct net_device___70 *, struct ip_tunnel_parm *, int);
	struct net_device___70 * (*ndo_get_peer_dev)(struct net_device___70 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___70 *, struct net_device_path___70 *);
};

struct neigh_parms___57 {
	possible_net_t___70 net;
	struct net_device___70 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___57 *);
	struct neigh_table___57 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___57 {
	u32 (*l3mdev_fib_table)(const struct net_device___70 *);
	struct sk_buff___71 * (*l3mdev_l3_rcv)(struct net_device___70 *, struct sk_buff___71 *, u16);
	struct sk_buff___71 * (*l3mdev_l3_out)(struct net_device___70 *, struct sock___57 *, struct sk_buff___71 *, u16);
	struct dst_entry___57 * (*l3mdev_link_scope_lookup)(const struct net_device___70 *, struct flowi6 *);
};

struct ndisc_ops___41 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___70 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___70 *, struct neighbour___57 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___70 *, u8, struct neighbour___57 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___70 *, struct sk_buff___71 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___75 *, struct net_device___70 *, const struct prefix_info *, struct inet6_dev___41 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___41;

struct ifacaddr6___11;

struct inet6_dev___41 {
	struct net_device___70 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___41 *mc_list;
	struct ifmcaddr6___41 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___70 mc_query_queue;
	struct sk_buff_head___70 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___11 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___57 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___64;

struct tcf_block___64;

struct mini_Qdisc___64 {
	struct tcf_proto___64 *filter_list;
	struct tcf_block___64 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___64 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___70 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___70 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___75 *, struct net_device___70 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___70 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___70 *, struct list_head *);
	size_t (*get_size)(const struct net_device___70 *);
	int (*fill_info)(struct sk_buff___71 *, const struct net_device___70 *);
	size_t (*get_xstats_size)(const struct net_device___70 *);
	int (*fill_xstats)(struct sk_buff___71 *, const struct net_device___70 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___70 *, struct net_device___70 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___70 *, const struct net_device___70 *);
	int (*fill_slave_info)(struct sk_buff___71 *, const struct net_device___70 *, const struct net_device___70 *);
	struct net___75 * (*get_link_net)(const struct net_device___70 *);
	size_t (*get_linkxstats_size)(const struct net_device___70 *, int);
	int (*fill_linkxstats)(struct sk_buff___71 *, const struct net_device___70 *, int *, int);
};

enum {
	TCA_UNSPEC = 0,
	TCA_KIND = 1,
	TCA_OPTIONS = 2,
	TCA_STATS = 3,
	TCA_XSTATS = 4,
	TCA_RATE = 5,
	TCA_FCNT = 6,
	TCA_STATS2 = 7,
	TCA_STAB = 8,
	TCA_PAD = 9,
	TCA_DUMP_INVISIBLE = 10,
	TCA_CHAIN = 11,
	TCA_HW_OFFLOAD = 12,
	TCA_INGRESS_BLOCK = 13,
	TCA_EGRESS_BLOCK = 14,
	TCA_DUMP_FLAGS = 15,
	__TCA_MAX = 16,
};

struct vlan_pcpu_stats {
	u64 rx_packets;
	u64 rx_bytes;
	u64 rx_multicast;
	u64 tx_packets;
	u64 tx_bytes;
	struct u64_stats_sync syncp;
	u32 rx_errors;
	u32 tx_dropped;
};

struct netpoll___5;

struct skb_array {
	struct ptr_ring ring;
};

struct macvlan_port;

struct macvlan_dev {
	struct net_device___70 *dev;
	struct list_head list;
	struct hlist_node hlist;
	struct macvlan_port *port;
	struct net_device___70 *lowerdev;
	void *accel_priv;
	struct vlan_pcpu_stats *pcpu_stats;
	long unsigned int mc_filter[4];
	netdev_features_t set_features;
	enum macvlan_mode mode;
	u16 flags;
	unsigned int macaddr_count;
	u32 bc_queue_len_req;
	struct netpoll___5 *netpoll;
};

struct gnet_dump___64 {
	spinlock_t *lock;
	struct sk_buff___71 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___64;

struct Qdisc_ops___64 {
	struct Qdisc_ops___64 *next;
	const struct Qdisc_class_ops___64 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___71 *, struct Qdisc___64 *, struct sk_buff___71 **);
	struct sk_buff___71 * (*dequeue)(struct Qdisc___64 *);
	struct sk_buff___71 * (*peek)(struct Qdisc___64 *);
	int (*init)(struct Qdisc___64 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___64 *);
	void (*destroy)(struct Qdisc___64 *);
	int (*change)(struct Qdisc___64 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___64 *);
	int (*change_tx_queue_len)(struct Qdisc___64 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___64 *, unsigned int);
	int (*dump)(struct Qdisc___64 *, struct sk_buff___71 *);
	int (*dump_stats)(struct Qdisc___64 *, struct gnet_dump___64 *);
	void (*ingress_block_set)(struct Qdisc___64 *, u32);
	void (*egress_block_set)(struct Qdisc___64 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___64 *);
	u32 (*egress_block_get)(struct Qdisc___64 *);
	struct module___245 *owner;
};

struct qdisc_walker___7;

struct Qdisc_class_ops___64 {
	unsigned int flags;
	struct netdev_queue___70 * (*select_queue)(struct Qdisc___64 *, struct tcmsg *);
	int (*graft)(struct Qdisc___64 *, long unsigned int, struct Qdisc___64 *, struct Qdisc___64 **, struct netlink_ext_ack *);
	struct Qdisc___64 * (*leaf)(struct Qdisc___64 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___64 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___64 *, u32);
	int (*change)(struct Qdisc___64 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___64 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___64 *, struct qdisc_walker___7 *);
	struct tcf_block___64 * (*tcf_block)(struct Qdisc___64 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___64 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___64 *, long unsigned int);
	int (*dump)(struct Qdisc___64 *, long unsigned int, struct sk_buff___71 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___64 *, long unsigned int, struct gnet_dump___64 *);
};

struct qdisc_walker___7 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___64 *, long unsigned int, struct qdisc_walker___7 *);
};

struct tcf_chain___64;

struct tcf_block___64 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___75 *net;
	struct Qdisc___64 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___64 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___64;

struct tcf_proto_ops___64;

struct tcf_proto___64 {
	struct tcf_proto___64 *next;
	void *root;
	int (*classify)(struct sk_buff___71 *, const struct tcf_proto___64 *, struct tcf_result___64 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___64 *ops;
	struct tcf_chain___64 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___64 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___64 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___64 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___71 *, const struct tcf_proto___64 *, struct tcf_result___64 *);
	int (*init)(struct tcf_proto___64 *);
	void (*destroy)(struct tcf_proto___64 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___64 *, u32);
	void (*put)(struct tcf_proto___64 *, void *);
	int (*change)(struct net___75 *, struct sk_buff___71 *, struct tcf_proto___64 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___64 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___64 *);
	void (*walk)(struct tcf_proto___64 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___64 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___64 *, void *);
	void (*hw_del)(struct tcf_proto___64 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___75 *, struct tcf_chain___64 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___75 *, struct tcf_proto___64 *, void *, struct sk_buff___71 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___75 *, struct tcf_proto___64 *, void *, struct sk_buff___71 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___71 *, struct net___75 *, void *);
	struct module___245 *owner;
	int flags;
};

struct tcf_chain___64 {
	struct mutex filter_chain_lock;
	struct tcf_proto___64 *filter_chain;
	struct list_head list;
	struct tcf_block___64 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___64 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct psched_ratecfg {
	u64 rate_bytes_ps;
	u32 mult;
	u16 overhead;
	u16 mpu;
	u8 linklayer;
	u8 shift;
};

struct psched_pktrate {
	u64 rate_pkts_ps;
	u32 mult;
	u8 shift;
};

struct mini_Qdisc_pair {
	struct mini_Qdisc___64 miniq1;
	struct mini_Qdisc___64 miniq2;
	struct mini_Qdisc___64 **p_miniq;
};

struct pneigh_entry___57;

struct neigh_hash_table___57;

struct neigh_table___57 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___70 *, __u32 *);
	bool (*key_eq)(const struct neighbour___57 *, const void *);
	int (*constructor)(struct neighbour___57 *);
	int (*pconstructor)(struct pneigh_entry___57 *);
	void (*pdestructor)(struct pneigh_entry___57 *);
	void (*proxy_redo)(struct sk_buff___71 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___70 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___57 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___70 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___57 *nht;
	struct pneigh_entry___57 **phash_buckets;
};

struct neigh_ops___57 {
	int family;
	void (*solicit)(struct neighbour___57 *, struct sk_buff___71 *);
	void (*error_report)(struct neighbour___57 *, struct sk_buff___71 *);
	int (*output)(struct neighbour___57 *, struct sk_buff___71 *);
	int (*connected_output)(struct neighbour___57 *, struct sk_buff___71 *);
};

struct pneigh_entry___57 {
	struct pneigh_entry___57 *next;
	possible_net_t___70 net;
	struct net_device___70 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___57 {
	struct neighbour___57 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___35 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___75 *, struct sock___57 *, struct sk_buff___71 *);
	int (*orig_input)(struct sk_buff___71 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct block_device_operations___152;

struct gendisk___155 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___155 *part0;
	const struct block_device_operations___152 *fops;
	struct request_queue___152 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___138 *bdi;
	struct kobject___249 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___249 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___152 {
	struct bio___152 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___178 *bip_vec;
	struct bio_vec___178 bip_inline_vecs[0];
};

struct blkcg___140;

struct blkg_policy_data___140;

struct blkcg_gq___140 {
	struct request_queue___152 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___140 *blkcg;
	struct blkcg_gq___140 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___140 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___152 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___152(struct request___152 *);

typedef void integrity_complete_fn___152(struct request___152 *, unsigned int);

struct blk_integrity_profile___152 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___152 *prepare_fn;
	integrity_complete_fn___152 *complete_fn;
	const char *name;
};

struct block_device_operations___152 {
	blk_qc_t (*submit_bio)(struct bio___152 *);
	int (*open)(struct block_device___155 *, fmode_t);
	void (*release)(struct gendisk___155 *, fmode_t);
	int (*rw_page)(struct block_device___155 *, sector_t, struct page___266 *, unsigned int);
	int (*ioctl)(struct block_device___155 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___155 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___155 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___155 *);
	int (*getgeo)(struct block_device___155 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___155 *, bool);
	void (*swap_slot_free_notify)(struct block_device___155 *, long unsigned int);
	int (*report_zones)(struct gendisk___155 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___155 *, umode_t *);
	struct module___245 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___155 *, sector_t *);
};

typedef void rq_end_io_fn___152(struct request___152 *, blk_status_t);

struct request___152 {
	struct request_queue___152 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___147 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___152 *bio;
	struct bio___152 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___178 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___152 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___152 *saved_end_io;
		} flush;
	};
	struct gendisk___155 *rq_disk;
	struct block_device___155 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___152 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___147 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___152 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___249 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___261 *debugfs_dir;
	struct dentry___261 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___152;

struct elevator_mq_ops___152 {
	int (*init_sched)(struct request_queue___152 *, struct elevator_type___152 *);
	void (*exit_sched)(struct elevator_queue___152 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___147 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___147 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___147 *);
	bool (*allow_merge)(struct request_queue___152 *, struct request___152 *, struct bio___152 *);
	bool (*bio_merge)(struct request_queue___152 *, struct bio___152 *, unsigned int);
	int (*request_merge)(struct request_queue___152 *, struct request___152 **, struct bio___152 *);
	void (*request_merged)(struct request_queue___152 *, struct request___152 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___152 *, struct request___152 *, struct request___152 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___152 *);
	void (*finish_request)(struct request___152 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___147 *, struct list_head *, bool);
	struct request___152 * (*dispatch_request)(struct blk_mq_hw_ctx___147 *);
	bool (*has_work)(struct blk_mq_hw_ctx___147 *);
	void (*completed_request)(struct request___152 *, u64);
	void (*requeue_request)(struct request___152 *);
	struct request___152 * (*former_request)(struct request_queue___152 *, struct request___152 *);
	struct request___152 * (*next_request)(struct request_queue___152 *, struct request___152 *);
	void (*init_icq)(struct io_cq___152 *);
	void (*exit_icq)(struct io_cq___152 *);
};

struct elv_fs_entry___152;

struct elevator_type___152 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___152 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___152 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___245 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___152 {
	struct elevator_type___152 *type;
	void *elevator_data;
	struct kobject___249 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___152 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___152 *, char *);
	ssize_t (*store)(struct elevator_queue___152 *, const char *, size_t);
};

struct blk_mq_queue_data___147;

struct blk_mq_ops___147 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___147 *, const struct blk_mq_queue_data___147 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___147 *);
	int (*get_budget)(struct request_queue___152 *);
	void (*put_budget)(struct request_queue___152 *, int);
	void (*set_rq_budget_token)(struct request___152 *, int);
	int (*get_rq_budget_token)(struct request___152 *);
	enum blk_eh_timer_return (*timeout)(struct request___152 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___147 *);
	void (*complete)(struct request___152 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___147 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___147 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___147 *, struct request___152 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___147 *, struct request___152 *, unsigned int);
	void (*initialize_rq_fn)(struct request___152 *);
	void (*cleanup_rq)(struct request___152 *);
	bool (*busy)(struct request_queue___152 *);
	int (*map_queues)(struct blk_mq_tag_set___147 *);
	void (*show_rq)(struct seq_file___236 *, struct request___152 *);
};

struct blk_mq_tag_set___147 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___147 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___147 {
	struct request___152 *rq;
	bool last;
};

struct blkcg_policy_data___140;

struct blkcg___140 {
	struct cgroup_subsys_state___188 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___140 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___140 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___140 {
	struct blkcg___140 *blkcg;
	int plid;
};

struct blkg_policy_data___140 {
	struct blkcg_gq___140 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___126 {
	struct mem_cgroup___126 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___126 {
	struct lruvec___134 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___126 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___126 *memcg;
};

struct obj_cgroup___126 {
	struct percpu_ref refcnt;
	struct mem_cgroup___126 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct sk_filter___57 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___64 *prog;
};

struct fib_rule___57 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___57 *ctarget;
	struct net___75 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___57 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___57 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___44;

struct timewait_sock_ops___43;

struct proto___57 {
	void (*close)(struct sock___57 *, long int);
	int (*pre_connect)(struct sock___57 *, struct sockaddr *, int);
	int (*connect)(struct sock___57 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___57 *, int);
	struct sock___57 * (*accept)(struct sock___57 *, int, int *, bool);
	int (*ioctl)(struct sock___57 *, int, long unsigned int);
	int (*init)(struct sock___57 *);
	void (*destroy)(struct sock___57 *);
	void (*shutdown)(struct sock___57 *, int);
	int (*setsockopt)(struct sock___57 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___57 *, int, int, char *, int *);
	void (*keepalive)(struct sock___57 *, int);
	int (*compat_ioctl)(struct sock___57 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___57 *, struct msghdr___59 *, size_t);
	int (*recvmsg)(struct sock___57 *, struct msghdr___59 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___57 *, struct page___266 *, int, size_t, int);
	int (*bind)(struct sock___57 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___57 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___57 *, struct sk_buff___71 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___57 *);
	int (*hash)(struct sock___57 *);
	void (*unhash)(struct sock___57 *);
	void (*rehash)(struct sock___57 *);
	int (*get_port)(struct sock___57 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___57 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___57 *, int);
	bool (*sock_is_readable)(struct sock___57 *);
	void (*enter_memory_pressure)(struct sock___57 *);
	void (*leave_memory_pressure)(struct sock___57 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___44 *rsk_prot;
	struct timewait_sock_ops___43 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___245 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___57 *, int);
};

struct xfrm_policy_queue___7 {
	struct sk_buff_head___70 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___7 {
	possible_net_t___70 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___7 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct request_sock___45;

struct request_sock_ops___44 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___57 *, struct request_sock___45 *);
	void (*send_ack)(const struct sock___57 *, struct sk_buff___71 *, struct request_sock___45 *);
	void (*send_reset)(const struct sock___57 *, struct sk_buff___71 *);
	void (*destructor)(struct request_sock___45 *);
	void (*syn_ack_timeout)(const struct request_sock___45 *);
};

struct timewait_sock_ops___43 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___57 *, struct sock___57 *, void *);
	void (*twsk_destructor)(struct sock___57 *);
};

struct request_sock___45 {
	struct sock_common___57 __req_common;
	struct request_sock___45 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___44 *rsk_ops;
	struct sock___57 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___41 {
	struct in6_addr mca_addr;
	struct inet6_dev___41 *idev;
	struct ifmcaddr6___41 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___11 {
	struct in6_addr aca_addr;
	struct fib6_info___11 *aca_rt;
	struct ifacaddr6___11 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___11 {
	struct fib_nh_exception___11 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___11 *fnhe_rth_input;
	struct rtable___11 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___11 {
	struct dst_entry___57 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___11 {
	struct fib_nh_exception___11 *chain;
};

struct xfrm_type___7 {
	struct module___245 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___7 *);
	void (*destructor)(struct xfrm_state___7 *);
	int (*input)(struct xfrm_state___7 *, struct sk_buff___71 *);
	int (*output)(struct xfrm_state___7 *, struct sk_buff___71 *);
	int (*reject)(struct xfrm_state___7 *, struct sk_buff___71 *, const struct flowi *);
};

struct xfrm_type_offload___7 {
	struct module___245 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___7 *, struct sk_buff___71 *);
	int (*input_tail)(struct xfrm_state___7 *, struct sk_buff___71 *);
	int (*xmit)(struct xfrm_state___7 *, struct sk_buff___71 *, netdev_features_t);
};

struct sec_path___4 {
	int len;
	int olen;
	struct xfrm_state___7 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct pfifo_fast_priv {
	struct skb_array q[3];
};

struct tc_qopt_offload_stats {
	struct gnet_stats_basic_packed *bstats;
	struct gnet_stats_queue *qstats;
};

enum tc_mq_command {
	TC_MQ_CREATE = 0,
	TC_MQ_DESTROY = 1,
	TC_MQ_STATS = 2,
	TC_MQ_GRAFT = 3,
};

struct tc_mq_opt_offload_graft_params {
	long unsigned int queue;
	u32 child_handle;
};

struct tc_mq_qopt_offload {
	enum tc_mq_command command;
	u32 handle;
	union {
		struct tc_qopt_offload_stats stats;
		struct tc_mq_opt_offload_graft_params graft_params;
	};
};

struct mq_sched {
	struct Qdisc___58 **qdiscs;
};

struct nl_info___3 {
	struct nlmsghdr *nlh;
	struct net___57 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct ip_options___2 {
	__be32 faddr;
	__be32 nexthop;
	unsigned char optlen;
	unsigned char srr;
	unsigned char rr;
	unsigned char ts;
	unsigned char is_strictroute;
	unsigned char srr_is_hit;
	unsigned char is_changed;
	unsigned char rr_needaddr;
	unsigned char ts_needtime;
	unsigned char ts_needaddr;
	long: 32;
	long: 64;
	unsigned char router_alert;
	unsigned char cipso;
	unsigned char __pad2;
	unsigned char __data[0];
};

struct fib6_result___3;

struct fib6_config___3;

struct ipv6_stub___3 {
	int (*ipv6_sock_mc_join)(struct sock___42 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___42 *, int, const struct in6_addr *);
	struct dst_entry___41 * (*ipv6_dst_lookup_flow)(struct net___57 *, const struct sock___42 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___53 *);
	struct fib6_table___6 * (*fib6_get_table)(struct net___57 *, u32);
	int (*fib6_lookup)(struct net___57 *, int, struct flowi6 *, struct fib6_result___3 *, int);
	int (*fib6_table_lookup)(struct net___57 *, struct fib6_table___6 *, int, struct flowi6 *, struct fib6_result___3 *, int);
	void (*fib6_select_path)(const struct net___57 *, struct fib6_result___3 *, struct flowi6 *, int, bool, const struct sk_buff___53 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___3 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___57 *, struct fib6_nh___6 *, struct fib6_config___3 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___6 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___6 *);
	void (*fib6_update_sernum)(struct net___57 *, struct fib6_info___6 *);
	int (*ip6_del_rt)(struct net___57 *, struct fib6_info___6 *, bool);
	void (*fib6_rt_update)(struct net___57 *, struct fib6_info___6 *, struct nl_info___3 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___6 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___53 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___42 *, struct sk_buff___53 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___53 *, int, __be32, int);
	struct neigh_table___41 *nd_tbl;
	int (*ipv6_fragment)(struct net___57 *, struct sock___42 *, struct sk_buff___53 *, int (*)(struct net___57 *, struct sock___42 *, struct sk_buff___53 *));
	struct net_device___6 * (*ipv6_dev_find)(struct net___57 *, const struct in6_addr *, struct net_device___6 *);
};

struct fib6_result___3 {
	struct fib6_nh___6 *nh;
	struct fib6_info___6 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___6 *rt6;
};

struct fib6_config___3 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___3 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct inet_skb_parm___2 {
	int iif;
	struct ip_options___2 opt;
	u16 flags;
	u16 frag_max_size;
};

struct sch_frag_data {
	long unsigned int dst;
	struct qdisc_skb_cb cb;
	__be16 inner_protocol;
	u16 vlan_tci;
	__be16 vlan_proto;
	unsigned int l2_len;
	u8 l2_data[18];
	int (*xmit)(struct sk_buff___53 *);
};

struct dentry___262;

struct super_block___262;

struct module___246;

struct file_system_type___262 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___262 * (*mount)(struct file_system_type___262 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___262 *);
	struct module___246 *owner;
	struct file_system_type___262 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___262;

struct kiocb___262;

struct iov_iter___182;

struct poll_table_struct___183;

struct vm_area_struct___267;

struct inode___262;

struct file_lock___262;

struct page___267;

struct pipe_inode_info___103;

struct seq_file___237;

struct file_operations___263 {
	struct module___246 *owner;
	loff_t (*llseek)(struct file___262 *, loff_t, int);
	ssize_t (*read)(struct file___262 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___262 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___262 *, struct iov_iter___182 *);
	ssize_t (*write_iter)(struct kiocb___262 *, struct iov_iter___182 *);
	int (*iopoll)(struct kiocb___262 *, bool);
	int (*iterate)(struct file___262 *, struct dir_context *);
	int (*iterate_shared)(struct file___262 *, struct dir_context *);
	__poll_t (*poll)(struct file___262 *, struct poll_table_struct___183 *);
	long int (*unlocked_ioctl)(struct file___262 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___262 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___262 *, struct vm_area_struct___267 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___262 *, struct file___262 *);
	int (*flush)(struct file___262 *, fl_owner_t);
	int (*release)(struct inode___262 *, struct file___262 *);
	int (*fsync)(struct file___262 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___262 *, int);
	int (*lock)(struct file___262 *, int, struct file_lock___262 *);
	ssize_t (*sendpage)(struct file___262 *, struct page___267 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___262 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___262 *, long unsigned int);
	int (*flock)(struct file___262 *, int, struct file_lock___262 *);
	ssize_t (*splice_write)(struct pipe_inode_info___103 *, struct file___262 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___262 *, loff_t *, struct pipe_inode_info___103 *, size_t, unsigned int);
	int (*setlease)(struct file___262 *, long int, struct file_lock___262 **, void **);
	long int (*fallocate)(struct file___262 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___237 *, struct file___262 *);
	ssize_t (*copy_file_range)(struct file___262 *, loff_t, struct file___262 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___262 *, loff_t, struct file___262 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___262 *, loff_t, loff_t, int);
};

struct vmacache___267 {
	u64 seqnum;
	struct vm_area_struct___267 *vmas[4];
};

struct page_frag___267 {
	struct page___267 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___268;

struct pid___239;

struct nsproxy___248;

struct signal_struct___263;

struct bio_list___153;

struct backing_dev_info___139;

struct io_context___153;

struct css_set___189;

struct mem_cgroup___127;

struct request_queue___153;

struct vm_struct___245;

struct task_struct___269 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___269 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___268 *mm;
	struct mm_struct___268 *active_mm;
	struct vmacache___267 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___269 *real_parent;
	struct task_struct___269 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___269 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___239 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___248 *nsproxy;
	struct signal_struct___263 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___269 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___153 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___139 *backing_dev_info;
	struct io_context___153 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___189 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___103 *splice_pipe;
	struct page_frag___267 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___127 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___127 *active_memcg;
	struct request_queue___153 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___269 *oom_reaper_list;
	struct vm_struct___245 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___250;

struct kobj_type___250;

struct kernfs_node___250;

struct kobject___250 {
	const char *name;
	struct list_head entry;
	struct kobject___250 *parent;
	struct kset___250 *kset;
	struct kobj_type___250 *ktype;
	struct kernfs_node___250 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___247 {
	struct kobject___250 kobj;
	struct module___246 *mod;
	struct kobject___250 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___246 {
	struct module___246 *mod;
	struct latch_tree_node node;
};

struct module_layout___246 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___246 mtn;
};

struct module_attribute___246;

struct kernel_param___246;

struct module___246 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___247 mkobj;
	struct module_attribute___246 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___250 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___246 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___246 core_layout;
	struct module_layout___246 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___239;

struct upid___239 {
	int nr;
	struct pid_namespace___239 *ns;
};

struct pid_namespace___239 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___269 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___239 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___239 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___239 numbers[1];
};

typedef struct page___267 *pgtable_t___267;

struct address_space___262;

struct page_pool___91;

struct dev_pagemap___257;

struct page___267 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___262 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___91 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___267 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___267 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___268 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___257 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___257;

struct vm_area_struct___267 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___267 *vm_next;
	struct vm_area_struct___267 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___268 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___257 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___262 *vm_file;
	struct file___262 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___263 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___269 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___269 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___239 *pids[4];
	struct pid___239 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___268 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___267;

struct mm_struct___268 {
	struct {
		struct vm_area_struct___267 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___262 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___267 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___269 *owner;
		struct user_namespace___26 *user_ns;
		struct file___262 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___76;

struct cgroup_namespace___189;

struct nsproxy___248 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___239 *pid_ns_for_children;
	struct net___76 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___189 *cgroup_ns;
};

struct bio___153;

struct bio_list___153 {
	struct bio___153 *head;
	struct bio___153 *tail;
};

struct cgroup_subsys_state___189;

struct bdi_writeback___139 {
	struct backing_dev_info___139 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___189 *memcg_css;
	struct cgroup_subsys_state___189 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___243;

struct backing_dev_info___139 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___139 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___243 *dev;
	char dev_name[64];
	struct device___243 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___262 *debug_dir;
};

struct io_cq___153;

struct io_context___153 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___153 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___189;

struct css_set___189 {
	struct cgroup_subsys_state___189 *subsys[14];
	refcount_t refcount;
	struct css_set___189 *dom_cset;
	struct cgroup___189 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___189 *mg_src_cgrp;
	struct cgroup___189 *mg_dst_cgrp;
	struct css_set___189 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___262;

struct pipe_buffer___103;

struct pipe_inode_info___103 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___267 *tmp_page;
	struct fasync_struct___262 *fasync_readers;
	struct fasync_struct___262 *fasync_writers;
	struct pipe_buffer___103 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___189;

struct cgroup_subsys_state___189 {
	struct cgroup___189 *cgroup;
	struct cgroup_subsys___189 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___189 *parent;
};

struct cgroup_file___189 {
	struct kernfs_node___250 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___127;

struct mem_cgroup_per_node___127;

struct mem_cgroup___127 {
	struct cgroup_subsys_state___189 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___189 events_file;
	struct cgroup_file___189 events_local_file;
	struct cgroup_file___189 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___127 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___269 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___127 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___153;

struct blk_integrity___153 {
	const struct blk_integrity_profile___153 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___153 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___153 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___153;

struct elevator_queue___153;

struct blk_mq_ops___148;

struct blk_mq_hw_ctx___148;

struct gendisk___156;

struct blkcg_gq___141;

struct blk_mq_tag_set___148;

struct request_queue___153 {
	struct request___153 *last_merge;
	struct elevator_queue___153 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___148 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___148 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___156 *disk;
	struct kobject___250 kobj;
	struct kobject___250 *mq_kobj;
	struct blk_integrity___153 integrity;
	struct device___243 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___141 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___148 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___153 bio_split;
	struct dentry___262 *debugfs_dir;
	struct dentry___262 *sched_debugfs_dir;
	struct dentry___262 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___245 {
	struct vm_struct___245 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___267 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___262;

struct address_space___262 {
	struct inode___262 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___262 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___91 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___243 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___91 {
	u32 count;
	struct page___267 *cache[128];
};

struct page_pool___91 {
	struct page_pool_params___91 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___267 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___91 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___257;

struct dev_pagemap___257 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___257 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___262;

struct path___262 {
	struct vfsmount___262 *mnt;
	struct dentry___262 *dentry;
};

struct fown_struct___239 {
	rwlock_t lock;
	struct pid___239 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___262 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___262 f_path;
	struct inode___262 *f_inode;
	const struct file_operations___263 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___239 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___262 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___257;

struct vm_operations_struct___257 {
	void (*open)(struct vm_area_struct___267 *);
	void (*close)(struct vm_area_struct___267 *);
	int (*may_split)(struct vm_area_struct___267 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___267 *);
	int (*mprotect)(struct vm_area_struct___267 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___257 *);
	vm_fault_t (*huge_fault)(struct vm_fault___257 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___257 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___267 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___257 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___257 *);
	int (*access)(struct vm_area_struct___267 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___267 *);
	int (*set_policy)(struct vm_area_struct___267 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___267 *, long unsigned int);
	struct page___267 * (*find_special_page)(struct vm_area_struct___267 *, long unsigned int);
};

struct core_thread___267 {
	struct task_struct___269 *task;
	struct core_thread___267 *next;
};

struct core_state___267 {
	atomic_t nr_threads;
	struct core_thread___267 dumper;
	struct completion startup;
};

struct vm_fault___257 {
	const struct {
		struct vm_area_struct___267 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___267 *cow_page;
	struct page___267 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___267 prealloc_pte;
};

struct pglist_data___135;

struct lruvec___135 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___135 *pgdat;
};

struct zone___135 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___135 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___135 {
	struct zone___135 *zone;
	int zone_idx;
};

struct zonelist___135 {
	struct zoneref___135 _zonerefs[321];
};

struct pglist_data___135 {
	struct zone___135 node_zones[5];
	struct zonelist___135 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___269 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___269 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___135 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___262;

struct dentry___262 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___262 *d_parent;
	struct qstr d_name;
	struct inode___262 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___262 *d_op;
	struct super_block___262 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___262;

struct inode___262 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___262 *i_op;
	struct super_block___262 *i_sb;
	struct address_space___262 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___139 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___263 *i_fop;
		void (*free_inode)(struct inode___262 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___262 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___103 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___262 {
	int (*d_revalidate)(struct dentry___262 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___262 *, unsigned int);
	int (*d_hash)(const struct dentry___262 *, struct qstr *);
	int (*d_compare)(const struct dentry___262 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___262 *);
	int (*d_init)(struct dentry___262 *);
	void (*d_release)(struct dentry___262 *);
	void (*d_prune)(struct dentry___262 *);
	void (*d_iput)(struct dentry___262 *, struct inode___262 *);
	char * (*d_dname)(struct dentry___262 *, char *, int);
	struct vfsmount___262 * (*d_automount)(struct path___262 *);
	int (*d_manage)(const struct path___262 *, bool);
	struct dentry___262 * (*d_real)(struct dentry___262 *, const struct inode___262 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___262;

struct mem_dqinfo___262 {
	struct quota_format_type___262 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___262;

struct quota_info___262 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___262 *files[3];
	struct mem_dqinfo___262 info[3];
	const struct quota_format_ops___262 *ops[3];
};

struct rcuwait___263 {
	struct task_struct___269 *task;
};

struct percpu_rw_semaphore___263 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___263 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___262 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___263 rw_sem[3];
};

struct shrink_control___127;

struct shrinker___127 {
	long unsigned int (*count_objects)(struct shrinker___127 *, struct shrink_control___127 *);
	long unsigned int (*scan_objects)(struct shrinker___127 *, struct shrink_control___127 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___262;

struct dquot_operations___262;

struct quotactl_ops___262;

struct block_device___156;

struct super_block___262 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___262 *s_type;
	const struct super_operations___262 *s_op;
	const struct dquot_operations___262 *dq_op;
	const struct quotactl_ops___262 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___262 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___156 *s_bdev;
	struct backing_dev_info___139 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___262 s_dquot;
	struct sb_writers___262 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___262 *s_d_op;
	int cleancache_poolid;
	struct shrinker___127 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___262 {
	struct dentry___262 *mnt_root;
	struct super_block___262 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___127 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___127 *memcg;
};

struct psi_group___189 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___269 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___65;

struct cgroup_bpf___65 {
	struct bpf_prog_array___65 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___65 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___189;

struct cgroup_rstat_cpu___189;

struct cgroup___189 {
	struct cgroup_subsys_state___189 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___250 *kn;
	struct cgroup_file___189 procs_file;
	struct cgroup_file___189 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___189 *subsys[14];
	struct cgroup_root___189 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___189 *dom_cgrp;
	struct cgroup___189 *old_dom_cgrp;
	struct cgroup_rstat_cpu___189 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___189 psi;
	struct cgroup_bpf___65 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___153 {
	struct request_queue___153 *q;
	struct io_context___153 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___262 {
	struct file___262 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___262 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___262 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___262 *ia_file;
};

struct dquot___262 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___262 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___262 {
	int qf_fmt_id;
	const struct quota_format_ops___262 *qf_ops;
	struct module___246 *qf_owner;
	struct quota_format_type___262 *qf_next;
};

struct quota_format_ops___262 {
	int (*check_quota_file)(struct super_block___262 *, int);
	int (*read_file_info)(struct super_block___262 *, int);
	int (*write_file_info)(struct super_block___262 *, int);
	int (*free_file_info)(struct super_block___262 *, int);
	int (*read_dqblk)(struct dquot___262 *);
	int (*commit_dqblk)(struct dquot___262 *);
	int (*release_dqblk)(struct dquot___262 *);
	int (*get_next_id)(struct super_block___262 *, struct kqid *);
};

struct dquot_operations___262 {
	int (*write_dquot)(struct dquot___262 *);
	struct dquot___262 * (*alloc_dquot)(struct super_block___262 *, int);
	void (*destroy_dquot)(struct dquot___262 *);
	int (*acquire_dquot)(struct dquot___262 *);
	int (*release_dquot)(struct dquot___262 *);
	int (*mark_dirty)(struct dquot___262 *);
	int (*write_info)(struct super_block___262 *, int);
	qsize_t * (*get_reserved_space)(struct inode___262 *);
	int (*get_projid)(struct inode___262 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___262 *, qsize_t *);
	int (*get_next_id)(struct super_block___262 *, struct kqid *);
};

struct quotactl_ops___262 {
	int (*quota_on)(struct super_block___262 *, int, int, const struct path___262 *);
	int (*quota_off)(struct super_block___262 *, int);
	int (*quota_enable)(struct super_block___262 *, unsigned int);
	int (*quota_disable)(struct super_block___262 *, unsigned int);
	int (*quota_sync)(struct super_block___262 *, int);
	int (*set_info)(struct super_block___262 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___262 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___262 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___262 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___262 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___262 *, unsigned int);
};

struct writeback_control___139;

struct address_space_operations___262 {
	int (*writepage)(struct page___267 *, struct writeback_control___139 *);
	int (*readpage)(struct file___262 *, struct page___267 *);
	int (*writepages)(struct address_space___262 *, struct writeback_control___139 *);
	int (*set_page_dirty)(struct page___267 *);
	int (*readpages)(struct file___262 *, struct address_space___262 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___262 *, struct address_space___262 *, loff_t, unsigned int, unsigned int, struct page___267 **, void **);
	int (*write_end)(struct file___262 *, struct address_space___262 *, loff_t, unsigned int, unsigned int, struct page___267 *, void *);
	sector_t (*bmap)(struct address_space___262 *, sector_t);
	void (*invalidatepage)(struct page___267 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___267 *, gfp_t);
	void (*freepage)(struct page___267 *);
	ssize_t (*direct_IO)(struct kiocb___262 *, struct iov_iter___182 *);
	int (*migratepage)(struct address_space___262 *, struct page___267 *, struct page___267 *, enum migrate_mode);
	bool (*isolate_page)(struct page___267 *, isolate_mode_t);
	void (*putback_page)(struct page___267 *);
	int (*launder_page)(struct page___267 *);
	int (*is_partially_uptodate)(struct page___267 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___267 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___262 *, struct page___267 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___262 *, sector_t *);
	void (*swap_deactivate)(struct file___262 *);
};

struct writeback_control___139 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___139 *wb;
	struct inode___262 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___179;

struct iov_iter___182 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___179 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___103 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___262 {
	struct dentry___262 * (*lookup)(struct inode___262 *, struct dentry___262 *, unsigned int);
	const char * (*get_link)(struct dentry___262 *, struct inode___262 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___262 *, int);
	struct posix_acl * (*get_acl)(struct inode___262 *, int, bool);
	int (*readlink)(struct dentry___262 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___262 *, struct dentry___262 *, umode_t, bool);
	int (*link)(struct dentry___262 *, struct inode___262 *, struct dentry___262 *);
	int (*unlink)(struct inode___262 *, struct dentry___262 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___262 *, struct dentry___262 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___262 *, struct dentry___262 *, umode_t);
	int (*rmdir)(struct inode___262 *, struct dentry___262 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___262 *, struct dentry___262 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___262 *, struct dentry___262 *, struct inode___262 *, struct dentry___262 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___262 *, struct iattr___262 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___262 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___262 *, char *, size_t);
	int (*fiemap)(struct inode___262 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___262 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___262 *, struct dentry___262 *, struct file___262 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___262 *, struct dentry___262 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___262 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___262 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___262 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___262 {
	void (*fl_copy_lock)(struct file_lock___262 *, struct file_lock___262 *);
	void (*fl_release_private)(struct file_lock___262 *);
};

struct lock_manager_operations___262;

struct file_lock___262 {
	struct file_lock___262 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___262 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___262 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___262 *fl_ops;
	const struct lock_manager_operations___262 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___262 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___262 *);
	int (*lm_grant)(struct file_lock___262 *, int);
	bool (*lm_break)(struct file_lock___262 *);
	int (*lm_change)(struct file_lock___262 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___262 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___262 *);
};

struct fasync_struct___262 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___262 *fa_next;
	struct file___262 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___262 {
	struct inode___262 * (*alloc_inode)(struct super_block___262 *);
	void (*destroy_inode)(struct inode___262 *);
	void (*free_inode)(struct inode___262 *);
	void (*dirty_inode)(struct inode___262 *, int);
	int (*write_inode)(struct inode___262 *, struct writeback_control___139 *);
	int (*drop_inode)(struct inode___262 *);
	void (*evict_inode)(struct inode___262 *);
	void (*put_super)(struct super_block___262 *);
	int (*sync_fs)(struct super_block___262 *, int);
	int (*freeze_super)(struct super_block___262 *);
	int (*freeze_fs)(struct super_block___262 *);
	int (*thaw_super)(struct super_block___262 *);
	int (*unfreeze_fs)(struct super_block___262 *);
	int (*statfs)(struct dentry___262 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___262 *, int *, char *);
	void (*umount_begin)(struct super_block___262 *);
	int (*show_options)(struct seq_file___237 *, struct dentry___262 *);
	int (*show_devname)(struct seq_file___237 *, struct dentry___262 *);
	int (*show_path)(struct seq_file___237 *, struct dentry___262 *);
	int (*show_stats)(struct seq_file___237 *, struct dentry___262 *);
	ssize_t (*quota_read)(struct super_block___262 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___262 *, int, const char *, size_t, loff_t);
	struct dquot___262 ** (*get_dquots)(struct inode___262 *);
	long int (*nr_cached_objects)(struct super_block___262 *, struct shrink_control___127 *);
	long int (*free_cached_objects)(struct super_block___262 *, struct shrink_control___127 *);
	struct file___262 * (*real_loop)(struct file___262 *);
};

struct wakeup_source___243;

struct dev_pm_info___243 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___243 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___243 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___243;

struct bus_type___243;

struct device_driver___243;

struct dev_pm_domain___243;

struct fwnode_handle___239;

struct class___243;

struct attribute_group___250;

struct device___243 {
	struct kobject___250 kobj;
	struct device___243 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___243 *type;
	struct bus_type___243 *bus;
	struct device_driver___243 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___243 power;
	struct dev_pm_domain___243 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___239 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___243 *class;
	const struct attribute_group___250 **groups;
	void (*release)(struct device___243 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___156 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___262 *bd_inode;
	struct super_block___262 *bd_super;
	void *bd_claiming;
	struct device___243 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___250 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___156 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___262 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___191)(struct file___262 *, wait_queue_head_t *, struct poll_table_struct___183 *);

struct poll_table_struct___183 {
	poll_queue_proc___191 _qproc;
	__poll_t _key;
};

struct seq_operations___237;

struct seq_file___237 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___237 *op;
	int poll_event;
	const struct file___262 *file;
	void *private;
};

typedef void bio_end_io_t___153(struct bio___153 *);

struct bio_vec___179 {
	struct page___267 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___153;

struct bio___153 {
	struct bio___153 *bi_next;
	struct block_device___156 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___153 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___141 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___153 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___179 *bi_io_vec;
	struct bio_set___153 *bi_pool;
	struct bio_vec___179 bi_inline_vecs[0];
};

struct kernfs_root___250;

struct kernfs_elem_dir___250 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___250 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___250;

struct kernfs_root___250 {
	struct kernfs_node___250 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___250 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___250 {
	struct kernfs_node___250 *target_kn;
};

struct kernfs_ops___250;

struct kernfs_elem_attr___250 {
	const struct kernfs_ops___250 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___250 *notify_next;
};

struct kernfs_node___250 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___250 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___250 dir;
		struct kernfs_elem_symlink___250 symlink;
		struct kernfs_elem_attr___250 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___250;

struct kernfs_ops___250 {
	int (*open)(struct kernfs_open_file___250 *);
	void (*release)(struct kernfs_open_file___250 *);
	int (*seq_show)(struct seq_file___237 *, void *);
	void * (*seq_start)(struct seq_file___237 *, loff_t *);
	void * (*seq_next)(struct seq_file___237 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___237 *, void *);
	ssize_t (*read)(struct kernfs_open_file___250 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___250 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___250 *, struct poll_table_struct___183 *);
	int (*mmap)(struct kernfs_open_file___250 *, struct vm_area_struct___267 *);
};

struct kernfs_syscall_ops___250 {
	int (*show_options)(struct seq_file___237 *, struct kernfs_root___250 *);
	int (*mkdir)(struct kernfs_node___250 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___250 *);
	int (*rename)(struct kernfs_node___250 *, struct kernfs_node___250 *, const char *);
	int (*show_path)(struct seq_file___237 *, struct kernfs_node___250 *, struct kernfs_root___250 *);
};

struct kernfs_open_file___250 {
	struct kernfs_node___250 *kn;
	struct file___262 *file;
	struct seq_file___237 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___257 *vm_ops;
};

struct sock___58;

struct kobj_ns_type_operations___58 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___58 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___76 *net;
} possible_net_t___71;

struct proto___58;

struct sock_common___58 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___58 *skc_prot;
	possible_net_t___71 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___58 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___72;

struct sk_buff_head___71 {
	struct sk_buff___72 *next;
	struct sk_buff___72 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___58 {
	struct cgroup___189 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___58;

struct socket_wq___59;

struct dst_entry___58;

struct socket___60;

struct net_device___71;

struct sock___58 {
	struct sock_common___58 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___71 sk_error_queue;
	struct sk_buff___72 *sk_rx_skb_cache;
	struct sk_buff_head___71 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___72 *head;
		struct sk_buff___72 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___58 *sk_filter;
	union {
		struct socket_wq___59 *sk_wq;
		struct socket_wq___59 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___58 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___58 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___72 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___72 *sk_tx_skb_cache;
	struct sk_buff_head___71 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___267 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___58 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___239 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___60 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___58 sk_cgrp_data;
	struct mem_cgroup___127 *sk_memcg;
	void (*sk_state_change)(struct sock___58 *);
	void (*sk_data_ready)(struct sock___58 *);
	void (*sk_write_space)(struct sock___58 *);
	void (*sk_error_report)(struct sock___58 *);
	int (*sk_backlog_rcv)(struct sock___58 *, struct sk_buff___72 *);
	struct sk_buff___72 * (*sk_validate_xmit_skb)(struct sock___58 *, struct net_device___71 *, struct sk_buff___72 *);
	void (*sk_destruct)(struct sock___58 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___250;

struct attribute_group___250 {
	const char *name;
	umode_t (*is_visible)(struct kobject___250 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___250 *, struct bin_attribute___250 *, int);
	struct attribute **attrs;
	struct bin_attribute___250 **bin_attrs;
};

struct bin_attribute___250 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___262 * (*f_mapping)();
	ssize_t (*read)(struct file___262 *, struct kobject___250 *, struct bin_attribute___250 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___262 *, struct kobject___250 *, struct bin_attribute___250 *, char *, loff_t, size_t);
	int (*mmap)(struct file___262 *, struct kobject___250 *, struct bin_attribute___250 *, struct vm_area_struct___267 *);
};

struct sysfs_ops___250 {
	ssize_t (*show)(struct kobject___250 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___250 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___250;

struct kset___250 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___250 kobj;
	const struct kset_uevent_ops___250 *uevent_ops;
};

struct kobj_type___250 {
	void (*release)(struct kobject___250 *);
	const struct sysfs_ops___250 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___250 **default_groups;
	const struct kobj_ns_type_operations___58 * (*child_ns_type)(struct kobject___250 *);
	const void * (*namespace)(struct kobject___250 *);
	void (*get_ownership)(struct kobject___250 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___250 {
	int (* const filter)(struct kset___250 *, struct kobject___250 *);
	const char * (* const name)(struct kset___250 *, struct kobject___250 *);
	int (* const uevent)(struct kset___250 *, struct kobject___250 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___246 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___246 *);
	int (*get)(char *, const struct kernel_param___246 *);
	void (*free)(void *);
};

struct kparam_array___246;

struct kernel_param___246 {
	const char *name;
	struct module___246 *mod;
	const struct kernel_param_ops___246 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___246 *arr;
	};
};

struct kparam_array___246 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___246 *ops;
	void *elem;
};

struct module_attribute___246 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___246 *, struct module_kobject___247 *, char *);
	ssize_t (*store)(struct module_attribute___246 *, struct module_kobject___247 *, const char *, size_t);
	void (*setup)(struct module___246 *, const char *);
	int (*test)(struct module___246 *);
	void (*free)(struct module___246 *);
};

struct dev_pagemap_ops___257 {
	void (*page_free)(struct page___267 *);
	void (*kill)(struct dev_pagemap___257 *);
	void (*cleanup)(struct dev_pagemap___257 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___257 *);
};

struct fwnode_operations___239;

struct fwnode_handle___239 {
	struct fwnode_handle___239 *secondary;
	const struct fwnode_operations___239 *ops;
	struct device___243 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___239;

struct fwnode_endpoint___239;

struct fwnode_operations___239 {
	struct fwnode_handle___239 * (*get)(struct fwnode_handle___239 *);
	void (*put)(struct fwnode_handle___239 *);
	bool (*device_is_available)(const struct fwnode_handle___239 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___239 *, const struct device___243 *);
	bool (*property_present)(const struct fwnode_handle___239 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___239 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___239 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___239 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*get_parent)(const struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*get_next_child_node)(const struct fwnode_handle___239 *, struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*get_named_child_node)(const struct fwnode_handle___239 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___239 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___239 *);
	struct fwnode_handle___239 * (*graph_get_next_endpoint)(const struct fwnode_handle___239 *, struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*graph_get_remote_endpoint)(const struct fwnode_handle___239 *);
	struct fwnode_handle___239 * (*graph_get_port_parent)(struct fwnode_handle___239 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___239 *, struct fwnode_endpoint___239 *);
	int (*add_links)(struct fwnode_handle___239 *);
};

struct fwnode_endpoint___239 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___239 *local_fwnode;
};

struct fwnode_reference_args___239 {
	struct fwnode_handle___239 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___58;

struct fqdir___76;

struct fib_notifier_ops___58;

struct netns_ipv4___76 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___58 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___58 *fibnl;
	struct sock___58 **icmp_sk;
	struct sock___58 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___58 **tcp_sk;
	struct fqdir___76 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___58 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___58 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___58 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___58;

struct dst_ops___76 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___76 *);
	struct dst_entry___58 * (*check)(struct dst_entry___58 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___58 *);
	unsigned int (*mtu)(const struct dst_entry___58 *);
	u32 * (*cow_metrics)(struct dst_entry___58 *, long unsigned int);
	void (*destroy)(struct dst_entry___58 *);
	void (*ifdown)(struct dst_entry___58 *, struct net_device___71 *, int);
	struct dst_entry___58 * (*negative_advice)(struct dst_entry___58 *);
	void (*link_failure)(struct sk_buff___72 *);
	void (*update_pmtu)(struct dst_entry___58 *, struct sock___58 *, struct sk_buff___72 *, u32, bool);
	void (*redirect)(struct dst_entry___58 *, struct sock___58 *, struct sk_buff___72 *);
	int (*local_out)(struct net___76 *, struct sock___58 *, struct sk_buff___72 *);
	struct neighbour___58 * (*neigh_lookup)(const struct dst_entry___58 *, struct sk_buff___72 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___58 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___76 {
	struct dst_ops___76 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___76 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___58 *fib6_rules_ops;
	struct sock___58 **icmp_sk;
	struct sock___58 *ndisc_sk;
	struct sock___58 *tcp_sk;
	struct sock___58 *igmp_sk;
	struct sock___58 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___58 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___58 *notifier_ops;
	struct fib_notifier_ops___58 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___76 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___76 *fqdir;
};

struct netns_sctp___58 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___58 *ctl_sock;
	struct sock___58 *udp4_sock;
	struct sock___58 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___65;

struct netns_bpf___65 {
	struct bpf_prog_array___65 *run_array[2];
	struct bpf_prog___65 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___76 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___58 *nlsk;
	struct sock___58 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___76 xfrm4_dst_ops;
	struct dst_ops___76 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___76 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___58 *rtnl;
	struct sock___58 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___71 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___76 ipv4;
	struct netns_ipv6___76 ipv6;
	struct netns_ieee802154_lowpan___76 ieee802154_lowpan;
	struct netns_sctp___58 sctp;
	struct netns_nf___5 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___71 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___65 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___76 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___58 *crypto_nlsk;
	struct sock___58 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___189 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___189 *root_cset;
};

struct msghdr___60 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___182 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___262 *msg_iocb;
};

struct socket_wq___59 {
	wait_queue_head_t wait;
	struct fasync_struct___262 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___59;

struct socket___60 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___262 *file;
	struct sock___58 *sk;
	const struct proto_ops___59 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___59 wq;
};

typedef int (*sk_read_actor_t___58)(read_descriptor_t *, struct sk_buff___72 *, unsigned int, size_t);

struct proto_ops___59 {
	int family;
	struct module___246 *owner;
	int (*release)(struct socket___60 *);
	int (*bind)(struct socket___60 *, struct sockaddr *, int);
	int (*connect)(struct socket___60 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___60 *, struct socket___60 *);
	int (*accept)(struct socket___60 *, struct socket___60 *, int, bool);
	int (*getname)(struct socket___60 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___262 *, struct socket___60 *, struct poll_table_struct___183 *);
	int (*ioctl)(struct socket___60 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___60 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___60 *, void *, bool, bool);
	int (*listen)(struct socket___60 *, int);
	int (*shutdown)(struct socket___60 *, int);
	int (*setsockopt)(struct socket___60 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___60 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___237 *, struct socket___60 *);
	int (*sendmsg)(struct socket___60 *, struct msghdr___60 *, size_t);
	int (*recvmsg)(struct socket___60 *, struct msghdr___60 *, size_t, int);
	int (*mmap)(struct file___262 *, struct socket___60 *, struct vm_area_struct___267 *);
	ssize_t (*sendpage)(struct socket___60 *, struct page___267 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___60 *, loff_t *, struct pipe_inode_info___103 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___58 *, int);
	int (*peek_len)(struct socket___60 *);
	int (*read_sock)(struct sock___58 *, read_descriptor_t *, sk_read_actor_t___58);
	int (*sendpage_locked)(struct sock___58 *, struct page___267 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___58 *, struct msghdr___60 *, size_t);
	int (*set_rcvlowat)(struct sock___58 *, int);
};

struct sk_buff___72 {
	union {
		struct {
			struct sk_buff___72 *next;
			struct sk_buff___72 *prev;
			union {
				struct net_device___71 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___58 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___72 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___243 {
	int (*prepare)(struct device___243 *);
	void (*complete)(struct device___243 *);
	int (*suspend)(struct device___243 *);
	int (*resume)(struct device___243 *);
	int (*freeze)(struct device___243 *);
	int (*thaw)(struct device___243 *);
	int (*poweroff)(struct device___243 *);
	int (*restore)(struct device___243 *);
	int (*suspend_late)(struct device___243 *);
	int (*resume_early)(struct device___243 *);
	int (*freeze_late)(struct device___243 *);
	int (*thaw_early)(struct device___243 *);
	int (*poweroff_late)(struct device___243 *);
	int (*restore_early)(struct device___243 *);
	int (*suspend_noirq)(struct device___243 *);
	int (*resume_noirq)(struct device___243 *);
	int (*freeze_noirq)(struct device___243 *);
	int (*thaw_noirq)(struct device___243 *);
	int (*poweroff_noirq)(struct device___243 *);
	int (*restore_noirq)(struct device___243 *);
	int (*runtime_suspend)(struct device___243 *);
	int (*runtime_resume)(struct device___243 *);
	int (*runtime_idle)(struct device___243 *);
};

struct wakeup_source___243 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___243 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___243 {
	struct dev_pm_ops___243 ops;
	int (*start)(struct device___243 *);
	void (*detach)(struct device___243 *, bool);
	int (*activate)(struct device___243 *);
	void (*sync)(struct device___243 *);
	void (*dismiss)(struct device___243 *);
};

struct bus_type___243 {
	const char *name;
	const char *dev_name;
	struct device___243 *dev_root;
	const struct attribute_group___250 **bus_groups;
	const struct attribute_group___250 **dev_groups;
	const struct attribute_group___250 **drv_groups;
	int (*match)(struct device___243 *, struct device_driver___243 *);
	int (*uevent)(struct device___243 *, struct kobj_uevent_env *);
	int (*probe)(struct device___243 *);
	void (*sync_state)(struct device___243 *);
	void (*remove)(struct device___243 *);
	void (*shutdown)(struct device___243 *);
	int (*online)(struct device___243 *);
	int (*offline)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	int (*num_vf)(struct device___243 *);
	int (*dma_configure)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___243 {
	const char *name;
	struct bus_type___243 *bus;
	struct module___246 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___243 *);
	void (*sync_state)(struct device___243 *);
	int (*remove)(struct device___243 *);
	void (*shutdown)(struct device___243 *);
	int (*suspend)(struct device___243 *, pm_message_t);
	int (*resume)(struct device___243 *);
	const struct attribute_group___250 **groups;
	const struct attribute_group___250 **dev_groups;
	const struct dev_pm_ops___243 *pm;
	void (*coredump)(struct device___243 *);
	struct driver_private *p;
};

struct device_type___243 {
	const char *name;
	const struct attribute_group___250 **groups;
	int (*uevent)(struct device___243 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___243 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___243 *);
	const struct dev_pm_ops___243 *pm;
};

struct class___243 {
	const char *name;
	struct module___246 *owner;
	const struct attribute_group___250 **class_groups;
	const struct attribute_group___250 **dev_groups;
	struct kobject___250 *dev_kobj;
	int (*dev_uevent)(struct device___243 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___243 *, umode_t *);
	void (*class_release)(struct class___243 *);
	void (*dev_release)(struct device___243 *);
	int (*shutdown_pre)(struct device___243 *);
	const struct kobj_ns_type_operations___58 *ns_type;
	const void * (*namespace)(struct device___243 *);
	void (*get_ownership)(struct device___243 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___243 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___103;

struct pipe_buffer___103 {
	struct page___267 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___103 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___103 {
	int (*confirm)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
	void (*release)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
	bool (*try_steal)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
	bool (*get)(struct pipe_inode_info___103 *, struct pipe_buffer___103 *);
};

typedef rx_handler_result_t rx_handler_func_t___71(struct sk_buff___72 **);

struct bpf_xdp_entity___65 {
	struct bpf_prog___65 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___71;

struct net_device_ops___71;

struct l3mdev_ops___58;

struct xfrmdev_ops___71;

struct header_ops___71;

struct netdev_rx_queue___71;

struct mini_Qdisc___65;

struct netdev_queue___71;

struct Qdisc___65;

struct rtnl_link_ops___65;

struct dcbnl_rtnl_ops___71;

struct net_device___71 {
	char name[16];
	struct netdev_name_node___71 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___71 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___58 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___71 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___71 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___250 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___71 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___65 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___71 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___65 *miniq_ingress;
	struct netdev_queue___71 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___71 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___65 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___65 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___71 = 0,
		NETREG_REGISTERED___71 = 1,
		NETREG_UNREGISTERING___71 = 2,
		NETREG_UNREGISTERED___71 = 3,
		NETREG_RELEASED___71 = 4,
		NETREG_DUMMY___71 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___71 = 0,
		RTNL_LINK_INITIALIZING___71 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___71 *);
	struct netpoll_info *npinfo;
	possible_net_t___71 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___243 dev;
	const struct attribute_group___250 *sysfs_groups[4];
	const struct attribute_group___250 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___65 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___71 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___65 xdp_state[3];
	long: 64;
};

struct seq_operations___237 {
	void * (*start)(struct seq_file___237 *, loff_t *);
	void (*stop)(struct seq_file___237 *, void *);
	void * (*next)(struct seq_file___237 *, void *, loff_t *);
	int (*show)(struct seq_file___237 *, void *);
};

struct inet_frags___76;

struct fqdir___76 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___76 *f;
	struct net___76 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___76;

struct inet_frags___76 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___76 *, const void *);
	void (*destructor)(struct inet_frag_queue___76 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___76 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___72 *fragments_tail;
	struct sk_buff___72 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___76 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___58;

struct fib_lookup_arg___58;

struct fib_rules_ops___58 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___58 *, struct flowi *, int, struct fib_lookup_arg___58 *);
	bool (*suppress)(struct fib_rule___58 *, int, struct fib_lookup_arg___58 *);
	int (*match)(struct fib_rule___58 *, struct flowi *, int);
	int (*configure)(struct fib_rule___58 *, struct sk_buff___72 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___58 *);
	int (*compare)(struct fib_rule___58 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___58 *, struct sk_buff___72 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___58 *);
	void (*flush_cache)(struct fib_rules_ops___58 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___246 *owner;
	struct net___76 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___58 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___76 *);
	int (*fib_dump)(struct net___76 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___246 *owner;
	struct callback_head rcu;
};

struct dst_entry___58 {
	struct net_device___71 *dev;
	struct dst_ops___76 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___72 *);
	int (*output)(struct net___76 *, struct sock___58 *, struct sk_buff___72 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___58;

struct neigh_parms___58;

struct neigh_ops___58;

struct neighbour___58 {
	struct neighbour___58 *next;
	struct neigh_table___58 *tbl;
	struct neigh_parms___58 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___71 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___58 *, struct sk_buff___72 *);
	const struct neigh_ops___58 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___71 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___65 {
	struct bpf_prog___65 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___65 {
	struct callback_head rcu;
	struct bpf_prog_array_item___65 items[0];
};

struct bpf_prog_aux___74;

struct bpf_prog___65 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___74 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct pernet_operations___16 {
	struct list_head list;
	int (*init)(struct net___76 *);
	void (*pre_exit)(struct net___76 *);
	void (*exit)(struct net___76 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___71 {
	int (*ieee_getets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___71 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___71 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___71 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___71 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___71 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___71 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___71 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___71 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___71 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___71 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___71 *);
	u8 (*setstate)(struct net_device___71 *, u8);
	void (*getpermhwaddr)(struct net_device___71 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___71 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___71 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___71 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___71 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___71 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___71 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___71 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___71 *, int, u8 *);
	void (*setpfccfg)(struct net_device___71 *, int, u8);
	void (*getpfccfg)(struct net_device___71 *, int, u8 *);
	u8 (*setall)(struct net_device___71 *);
	u8 (*getcap)(struct net_device___71 *, int, u8 *);
	int (*getnumtcs)(struct net_device___71 *, int, u8 *);
	int (*setnumtcs)(struct net_device___71 *, int, u8);
	u8 (*getpfcstate)(struct net_device___71 *);
	void (*setpfcstate)(struct net_device___71 *, u8);
	void (*getbcncfg)(struct net_device___71 *, int, u32 *);
	void (*setbcncfg)(struct net_device___71 *, int, u32);
	void (*getbcnrp)(struct net_device___71 *, int, u8 *);
	void (*setbcnrp)(struct net_device___71 *, int, u8);
	int (*setapp)(struct net_device___71 *, u8, u16, u8);
	int (*getapp)(struct net_device___71 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___71 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___71 *, int, u8);
	u8 (*getdcbx)(struct net_device___71 *);
	u8 (*setdcbx)(struct net_device___71 *, u8);
	int (*peer_getappinfo)(struct net_device___71 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___71 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___71 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___71 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___71 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___71 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___74;

typedef int (*bpf_iter_init_seq_priv_t___73)(void *, struct bpf_iter_aux_info___74 *);

struct bpf_map___74;

struct bpf_iter_aux_info___74 {
	struct bpf_map___74 *map;
};

struct bpf_iter_seq_info___73 {
	const struct seq_operations___237 *seq_ops;
	bpf_iter_init_seq_priv_t___73 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___73 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___74 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___74 *, struct file___262 *);
	void (*map_free)(struct bpf_map___74 *);
	int (*map_get_next_key)(struct bpf_map___74 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___74 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___74 *, void *);
	int (*map_lookup_batch)(struct bpf_map___74 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___74 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___74 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___74 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___74 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___74 *, void *);
	int (*map_update_elem)(struct bpf_map___74 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___74 *, void *);
	int (*map_push_elem)(struct bpf_map___74 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___74 *, void *);
	int (*map_peek_elem)(struct bpf_map___74 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___74 *, struct file___262 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___74 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___74 *, void *, struct seq_file___237 *);
	int (*map_check_btf)(const struct bpf_map___74 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___74 *, struct bpf_prog_aux___74 *);
	void (*map_poke_untrack)(struct bpf_map___74 *, struct bpf_prog_aux___74 *);
	void (*map_poke_run)(struct bpf_map___74 *, u32, struct bpf_prog___65 *, struct bpf_prog___65 *);
	int (*map_direct_value_addr)(const struct bpf_map___74 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___74 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___74 *, struct vm_area_struct___267 *);
	__poll_t (*map_poll)(struct bpf_map___74 *, struct file___262 *, struct poll_table_struct___183 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___74 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___74 *, const struct bpf_map___74 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___74 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___73 *iter_seq_info;
};

struct bpf_map___74 {
	const struct bpf_map_ops___73 *ops;
	struct bpf_map___74 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___127 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___73;

struct bpf_jit_poke_descriptor___73;

struct bpf_prog_ops___65;

struct btf_mod_pair___73;

struct bpf_prog_offload___71;

struct bpf_prog_aux___74 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___65 *dst_prog;
	struct bpf_trampoline___73 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___65 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___73 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___65 *ops;
	struct bpf_map___74 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___73 *used_btfs;
	struct bpf_prog___65 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___74 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___71 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___71;

struct bpf_map_dev_ops___71 {
	int (*map_get_next_key)(struct bpf_offloaded_map___71 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___71 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___71 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___71 *, void *);
};

struct bpf_offloaded_map___71 {
	struct bpf_map___74 map;
	struct net_device___71 *netdev;
	const struct bpf_map_dev_ops___71 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___65 {
	int (*test_run)(struct bpf_prog___65 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___71 {
	struct bpf_prog___65 *prog;
	struct net_device___71 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___73 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___65 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___246 *mod;
};

struct bpf_jit_poke_descriptor___73 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___74 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___73 {
	struct btf *btf;
	struct module___246 *module;
};

struct cftype___189;

struct cgroup_subsys___189 {
	struct cgroup_subsys_state___189 * (*css_alloc)(struct cgroup_subsys_state___189 *);
	int (*css_online)(struct cgroup_subsys_state___189 *);
	void (*css_offline)(struct cgroup_subsys_state___189 *);
	void (*css_released)(struct cgroup_subsys_state___189 *);
	void (*css_free)(struct cgroup_subsys_state___189 *);
	void (*css_reset)(struct cgroup_subsys_state___189 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___189 *, int);
	int (*css_extra_stat_show)(struct seq_file___237 *, struct cgroup_subsys_state___189 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___269 *, struct css_set___189 *);
	void (*cancel_fork)(struct task_struct___269 *, struct css_set___189 *);
	void (*fork)(struct task_struct___269 *);
	void (*exit)(struct task_struct___269 *);
	void (*release)(struct task_struct___269 *);
	void (*bind)(struct cgroup_subsys_state___189 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___189 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___189 *dfl_cftypes;
	struct cftype___189 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___189 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___189 *updated_children;
	struct cgroup___189 *updated_next;
};

struct cgroup_root___189 {
	struct kernfs_root___250 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___189 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___189 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___189 *ss;
	struct list_head node;
	struct kernfs_ops___250 *kf_ops;
	int (*open)(struct kernfs_open_file___250 *);
	void (*release)(struct kernfs_open_file___250 *);
	u64 (*read_u64)(struct cgroup_subsys_state___189 *, struct cftype___189 *);
	s64 (*read_s64)(struct cgroup_subsys_state___189 *, struct cftype___189 *);
	int (*seq_show)(struct seq_file___237 *, void *);
	void * (*seq_start)(struct seq_file___237 *, loff_t *);
	void * (*seq_next)(struct seq_file___237 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___237 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___189 *, struct cftype___189 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___189 *, struct cftype___189 *, s64);
	ssize_t (*write)(struct kernfs_open_file___250 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___250 *, struct poll_table_struct___183 *);
};

struct xdp_rxq_info___71 {
	struct net_device___71 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___71 {
	struct net_device___71 *dev;
};

struct xdp_buff___71 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___71 *rxq;
	struct xdp_txq_info___71 *txq;
	u32 frame_sz;
};

struct xdp_frame___71 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___71 *dev_rx;
};

struct netlink_skb_parms___10 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___58 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___71 {
	struct sk_buff___72 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___72 *, struct netlink_callback___71 *);
	int (*done)(struct netlink_callback___71 *);
	void *data;
	struct module___246 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum tc_link_layer {
	TC_LINKLAYER_UNAWARE = 0,
	TC_LINKLAYER_ETHERNET = 1,
	TC_LINKLAYER_ATM = 2,
};

enum {
	TCA_STAB_UNSPEC = 0,
	TCA_STAB_BASE = 1,
	TCA_STAB_DATA = 2,
	__TCA_STAB_MAX = 3,
};

struct header_ops___71 {
	int (*create)(struct sk_buff___72 *, struct net_device___71 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___72 *, unsigned char *);
	int (*cache)(const struct neighbour___58 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___71 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___72 *);
};

struct netdev_queue___71 {
	struct net_device___71 *dev;
	struct Qdisc___65 *qdisc;
	struct Qdisc___65 *qdisc_sleeping;
	struct kobject___250 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___71 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___65 {
	struct sk_buff___72 *head;
	struct sk_buff___72 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___65;

struct Qdisc___65 {
	int (*enqueue)(struct sk_buff___72 *, struct Qdisc___65 *, struct sk_buff___72 **);
	struct sk_buff___72 * (*dequeue)(struct Qdisc___65 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___65 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___71 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___71 gso_skb;
	struct qdisc_skb_head___65 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___65 *next_sched;
	struct sk_buff_head___71 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___71 {
	struct xdp_rxq_info___71 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___250 kobj;
	struct net_device___71 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___71 {
	enum net_device_path_type type;
	const struct net_device___71 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___71 = 0,
				DEV_PATH_BR_VLAN_TAG___71 = 1,
				DEV_PATH_BR_VLAN_UNTAG___71 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___71 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___71 {
	const struct net_device___71 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___71 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___65 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___71 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___71 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___72 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___71 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___71 *dev;
	const char *name;
};

struct net_device_ops___71 {
	int (*ndo_init)(struct net_device___71 *);
	void (*ndo_uninit)(struct net_device___71 *);
	int (*ndo_open)(struct net_device___71 *);
	int (*ndo_stop)(struct net_device___71 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___72 *, struct net_device___71 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___72 *, struct net_device___71 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___71 *, struct sk_buff___72 *, struct net_device___71 *);
	void (*ndo_change_rx_flags)(struct net_device___71 *, int);
	void (*ndo_set_rx_mode)(struct net_device___71 *);
	int (*ndo_set_mac_address)(struct net_device___71 *, void *);
	int (*ndo_validate_addr)(struct net_device___71 *);
	int (*ndo_do_ioctl)(struct net_device___71 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___71 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___71 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___71 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___71 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___71 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___71 *, int);
	int (*ndo_neigh_setup)(struct net_device___71 *, struct neigh_parms___58 *);
	void (*ndo_tx_timeout)(struct net_device___71 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___71 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___71 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___71 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___71 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___71 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___71 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___71 *);
	int (*ndo_netpoll_setup)(struct net_device___71 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___71 *);
	int (*ndo_set_vf_mac)(struct net_device___71 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___71 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___71 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___71 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___71 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___71 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___71 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___71 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___71 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___71 *, int, struct sk_buff___72 *);
	int (*ndo_get_vf_guid)(struct net_device___71 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___71 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___71 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___71 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___71 *);
	int (*ndo_fcoe_disable)(struct net_device___71 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___71 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___71 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___71 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___71 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___71 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___71 *, const struct sk_buff___72 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___71 *, struct net_device___71 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___71 *, struct net_device___71 *);
	struct net_device___71 * (*ndo_get_xmit_slave)(struct net_device___71 *, struct sk_buff___72 *, bool);
	struct net_device___71 * (*ndo_sk_get_lower_dev)(struct net_device___71 *, struct sock___58 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___71 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___71 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___71 *, struct neighbour___58 *);
	void (*ndo_neigh_destroy)(struct net_device___71 *, struct neighbour___58 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___72 *, struct netlink_callback___71 *, struct net_device___71 *, struct net_device___71 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___72 *, struct nlattr **, struct net_device___71 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___71 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___72 *, u32, u32, struct net_device___71 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___71 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___71 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___71 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___71 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___71 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___71 *, struct net_device___71 *);
	void (*ndo_dfwd_del_station)(struct net_device___71 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___71 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___71 *);
	int (*ndo_change_proto_down)(struct net_device___71 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___71 *, struct sk_buff___72 *);
	void (*ndo_set_rx_headroom)(struct net_device___71 *, int);
	int (*ndo_bpf)(struct net_device___71 *, struct netdev_bpf___71 *);
	int (*ndo_xdp_xmit)(struct net_device___71 *, int, struct xdp_frame___71 **, u32);
	struct net_device___71 * (*ndo_xdp_get_xmit_slave)(struct net_device___71 *, struct xdp_buff___71 *);
	int (*ndo_xsk_wakeup)(struct net_device___71 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___71 *);
	int (*ndo_tunnel_ctl)(struct net_device___71 *, struct ip_tunnel_parm *, int);
	struct net_device___71 * (*ndo_get_peer_dev)(struct net_device___71 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___71 *, struct net_device_path___71 *);
};

struct neigh_parms___58 {
	possible_net_t___71 net;
	struct net_device___71 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___58 *);
	struct neigh_table___58 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___58 {
	u32 (*l3mdev_fib_table)(const struct net_device___71 *);
	struct sk_buff___72 * (*l3mdev_l3_rcv)(struct net_device___71 *, struct sk_buff___72 *, u16);
	struct sk_buff___72 * (*l3mdev_l3_out)(struct net_device___71 *, struct sock___58 *, struct sk_buff___72 *, u16);
	struct dst_entry___58 * (*l3mdev_link_scope_lookup)(const struct net_device___71 *, struct flowi6 *);
};

struct tcf_proto___65;

struct tcf_block___65;

struct mini_Qdisc___65 {
	struct tcf_proto___65 *filter_list;
	struct tcf_block___65 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___65 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___71 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___71 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___76 *, struct net_device___71 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___71 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___71 *, struct list_head *);
	size_t (*get_size)(const struct net_device___71 *);
	int (*fill_info)(struct sk_buff___72 *, const struct net_device___71 *);
	size_t (*get_xstats_size)(const struct net_device___71 *);
	int (*fill_xstats)(struct sk_buff___72 *, const struct net_device___71 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___71 *, struct net_device___71 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___71 *, const struct net_device___71 *);
	int (*fill_slave_info)(struct sk_buff___72 *, const struct net_device___71 *, const struct net_device___71 *);
	struct net___76 * (*get_link_net)(const struct net_device___71 *);
	size_t (*get_linkxstats_size)(const struct net_device___71 *, int);
	int (*fill_linkxstats)(struct sk_buff___72 *, const struct net_device___71 *, int *, int);
};

struct block_device_operations___153;

struct gendisk___156 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___156 *part0;
	const struct block_device_operations___153 *fops;
	struct request_queue___153 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___139 *bdi;
	struct kobject___250 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___250 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___153 {
	struct bio___153 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___179 *bip_vec;
	struct bio_vec___179 bip_inline_vecs[0];
};

struct blkcg___141;

struct blkg_policy_data___141;

struct blkcg_gq___141 {
	struct request_queue___153 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___141 *blkcg;
	struct blkcg_gq___141 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___141 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___153 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___153(struct request___153 *);

typedef void integrity_complete_fn___153(struct request___153 *, unsigned int);

struct blk_integrity_profile___153 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___153 *prepare_fn;
	integrity_complete_fn___153 *complete_fn;
	const char *name;
};

struct block_device_operations___153 {
	blk_qc_t (*submit_bio)(struct bio___153 *);
	int (*open)(struct block_device___156 *, fmode_t);
	void (*release)(struct gendisk___156 *, fmode_t);
	int (*rw_page)(struct block_device___156 *, sector_t, struct page___267 *, unsigned int);
	int (*ioctl)(struct block_device___156 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___156 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___156 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___156 *);
	int (*getgeo)(struct block_device___156 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___156 *, bool);
	void (*swap_slot_free_notify)(struct block_device___156 *, long unsigned int);
	int (*report_zones)(struct gendisk___156 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___156 *, umode_t *);
	struct module___246 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___156 *, sector_t *);
};

typedef void rq_end_io_fn___153(struct request___153 *, blk_status_t);

struct request___153 {
	struct request_queue___153 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___148 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___153 *bio;
	struct bio___153 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___179 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___153 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___153 *saved_end_io;
		} flush;
	};
	struct gendisk___156 *rq_disk;
	struct block_device___156 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___153 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___148 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___153 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___250 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___262 *debugfs_dir;
	struct dentry___262 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___153;

struct elevator_mq_ops___153 {
	int (*init_sched)(struct request_queue___153 *, struct elevator_type___153 *);
	void (*exit_sched)(struct elevator_queue___153 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___148 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___148 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___148 *);
	bool (*allow_merge)(struct request_queue___153 *, struct request___153 *, struct bio___153 *);
	bool (*bio_merge)(struct request_queue___153 *, struct bio___153 *, unsigned int);
	int (*request_merge)(struct request_queue___153 *, struct request___153 **, struct bio___153 *);
	void (*request_merged)(struct request_queue___153 *, struct request___153 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___153 *, struct request___153 *, struct request___153 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___153 *);
	void (*finish_request)(struct request___153 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___148 *, struct list_head *, bool);
	struct request___153 * (*dispatch_request)(struct blk_mq_hw_ctx___148 *);
	bool (*has_work)(struct blk_mq_hw_ctx___148 *);
	void (*completed_request)(struct request___153 *, u64);
	void (*requeue_request)(struct request___153 *);
	struct request___153 * (*former_request)(struct request_queue___153 *, struct request___153 *);
	struct request___153 * (*next_request)(struct request_queue___153 *, struct request___153 *);
	void (*init_icq)(struct io_cq___153 *);
	void (*exit_icq)(struct io_cq___153 *);
};

struct elv_fs_entry___153;

struct elevator_type___153 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___153 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___153 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___246 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___153 {
	struct elevator_type___153 *type;
	void *elevator_data;
	struct kobject___250 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___153 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___153 *, char *);
	ssize_t (*store)(struct elevator_queue___153 *, const char *, size_t);
};

struct blk_mq_queue_data___148;

struct blk_mq_ops___148 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___148 *, const struct blk_mq_queue_data___148 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___148 *);
	int (*get_budget)(struct request_queue___153 *);
	void (*put_budget)(struct request_queue___153 *, int);
	void (*set_rq_budget_token)(struct request___153 *, int);
	int (*get_rq_budget_token)(struct request___153 *);
	enum blk_eh_timer_return (*timeout)(struct request___153 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___148 *);
	void (*complete)(struct request___153 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___148 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___148 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___148 *, struct request___153 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___148 *, struct request___153 *, unsigned int);
	void (*initialize_rq_fn)(struct request___153 *);
	void (*cleanup_rq)(struct request___153 *);
	bool (*busy)(struct request_queue___153 *);
	int (*map_queues)(struct blk_mq_tag_set___148 *);
	void (*show_rq)(struct seq_file___237 *, struct request___153 *);
};

struct blk_mq_tag_set___148 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___148 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___148 {
	struct request___153 *rq;
	bool last;
};

struct blkcg_policy_data___141;

struct blkcg___141 {
	struct cgroup_subsys_state___189 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___141 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___141 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___141 {
	struct blkcg___141 *blkcg;
	int plid;
};

struct blkg_policy_data___141 {
	struct blkcg_gq___141 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___127 {
	struct mem_cgroup___127 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___127 {
	struct lruvec___135 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___127 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___127 *memcg;
};

struct obj_cgroup___127 {
	struct percpu_ref refcnt;
	struct mem_cgroup___127 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___65 {
	spinlock_t *lock;
	struct sk_buff___72 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

typedef int (*rtnl_doit_func___5)(struct sk_buff___72 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___5)(struct sk_buff___72 *, struct netlink_callback___71 *);

struct qdisc_rate_table {
	struct tc_ratespec rate;
	u32 data[256];
	struct qdisc_rate_table *next;
	int refcnt;
};

struct Qdisc_class_ops___65;

struct Qdisc_ops___65 {
	struct Qdisc_ops___65 *next;
	const struct Qdisc_class_ops___65 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___72 *, struct Qdisc___65 *, struct sk_buff___72 **);
	struct sk_buff___72 * (*dequeue)(struct Qdisc___65 *);
	struct sk_buff___72 * (*peek)(struct Qdisc___65 *);
	int (*init)(struct Qdisc___65 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___65 *);
	void (*destroy)(struct Qdisc___65 *);
	int (*change)(struct Qdisc___65 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___65 *);
	int (*change_tx_queue_len)(struct Qdisc___65 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___65 *, unsigned int);
	int (*dump)(struct Qdisc___65 *, struct sk_buff___72 *);
	int (*dump_stats)(struct Qdisc___65 *, struct gnet_dump___65 *);
	void (*ingress_block_set)(struct Qdisc___65 *, u32);
	void (*egress_block_set)(struct Qdisc___65 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___65 *);
	u32 (*egress_block_get)(struct Qdisc___65 *);
	struct module___246 *owner;
};

struct qdisc_walker___8;

struct Qdisc_class_ops___65 {
	unsigned int flags;
	struct netdev_queue___71 * (*select_queue)(struct Qdisc___65 *, struct tcmsg *);
	int (*graft)(struct Qdisc___65 *, long unsigned int, struct Qdisc___65 *, struct Qdisc___65 **, struct netlink_ext_ack *);
	struct Qdisc___65 * (*leaf)(struct Qdisc___65 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___65 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___65 *, u32);
	int (*change)(struct Qdisc___65 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___65 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___65 *, struct qdisc_walker___8 *);
	struct tcf_block___65 * (*tcf_block)(struct Qdisc___65 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___65 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___65 *, long unsigned int);
	int (*dump)(struct Qdisc___65 *, long unsigned int, struct sk_buff___72 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___65 *, long unsigned int, struct gnet_dump___65 *);
};

struct qdisc_walker___8 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___65 *, long unsigned int, struct qdisc_walker___8 *);
};

struct tcf_chain___65;

struct tcf_block___65 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___76 *net;
	struct Qdisc___65 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___65 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___65;

struct tcf_proto_ops___65;

struct tcf_proto___65 {
	struct tcf_proto___65 *next;
	void *root;
	int (*classify)(struct sk_buff___72 *, const struct tcf_proto___65 *, struct tcf_result___65 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___65 *ops;
	struct tcf_chain___65 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___65 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___65 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___3;

struct tcf_proto_ops___65 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___72 *, const struct tcf_proto___65 *, struct tcf_result___65 *);
	int (*init)(struct tcf_proto___65 *);
	void (*destroy)(struct tcf_proto___65 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___65 *, u32);
	void (*put)(struct tcf_proto___65 *, void *);
	int (*change)(struct net___76 *, struct sk_buff___72 *, struct tcf_proto___65 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___65 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___65 *);
	void (*walk)(struct tcf_proto___65 *, struct tcf_walker___3 *, bool);
	int (*reoffload)(struct tcf_proto___65 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___65 *, void *);
	void (*hw_del)(struct tcf_proto___65 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___76 *, struct tcf_chain___65 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___76 *, struct tcf_proto___65 *, void *, struct sk_buff___72 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___76 *, struct tcf_proto___65 *, void *, struct sk_buff___72 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___72 *, struct net___76 *, void *);
	struct module___246 *owner;
	int flags;
};

struct tcf_walker___3 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___65 *, void *, struct tcf_walker___3 *);
};

struct tcf_chain___65 {
	struct mutex filter_chain_lock;
	struct tcf_proto___65 *filter_chain;
	struct list_head list;
	struct tcf_block___65 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___65 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct Qdisc_class_common {
	u32 classid;
	struct hlist_node hnode;
};

struct Qdisc_class_hash {
	struct hlist_head *hash;
	unsigned int hashsize;
	unsigned int hashmask;
	unsigned int hashelems;
};

struct sk_filter___58 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___65 *prog;
};

struct pneigh_entry___58;

struct neigh_hash_table___58;

struct neigh_table___58 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___71 *, __u32 *);
	bool (*key_eq)(const struct neighbour___58 *, const void *);
	int (*constructor)(struct neighbour___58 *);
	int (*pconstructor)(struct pneigh_entry___58 *);
	void (*pdestructor)(struct pneigh_entry___58 *);
	void (*proxy_redo)(struct sk_buff___72 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___71 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___58 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___71 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___58 *nht;
	struct pneigh_entry___58 **phash_buckets;
};

struct neigh_ops___58 {
	int family;
	void (*solicit)(struct neighbour___58 *, struct sk_buff___72 *);
	void (*error_report)(struct neighbour___58 *, struct sk_buff___72 *);
	int (*output)(struct neighbour___58 *, struct sk_buff___72 *);
	int (*connected_output)(struct neighbour___58 *, struct sk_buff___72 *);
};

struct pneigh_entry___58 {
	struct pneigh_entry___58 *next;
	possible_net_t___71 net;
	struct net_device___71 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___58 {
	struct neighbour___58 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___58 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___58 *ctarget;
	struct net___76 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___58 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___58 *rule;
	u32 table;
	int flags;
};

struct proto___58 {
	void (*close)(struct sock___58 *, long int);
	int (*pre_connect)(struct sock___58 *, struct sockaddr *, int);
	int (*connect)(struct sock___58 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___58 *, int);
	struct sock___58 * (*accept)(struct sock___58 *, int, int *, bool);
	int (*ioctl)(struct sock___58 *, int, long unsigned int);
	int (*init)(struct sock___58 *);
	void (*destroy)(struct sock___58 *);
	void (*shutdown)(struct sock___58 *, int);
	int (*setsockopt)(struct sock___58 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___58 *, int, int, char *, int *);
	void (*keepalive)(struct sock___58 *, int);
	int (*compat_ioctl)(struct sock___58 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___58 *, struct msghdr___60 *, size_t);
	int (*recvmsg)(struct sock___58 *, struct msghdr___60 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___58 *, struct page___267 *, int, size_t, int);
	int (*bind)(struct sock___58 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___58 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___58 *, struct sk_buff___72 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___58 *);
	int (*hash)(struct sock___58 *);
	void (*unhash)(struct sock___58 *);
	void (*rehash)(struct sock___58 *);
	int (*get_port)(struct sock___58 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___58 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___58 *, int);
	bool (*sock_is_readable)(struct sock___58 *);
	void (*enter_memory_pressure)(struct sock___58 *);
	void (*leave_memory_pressure)(struct sock___58 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___246 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___58 *, int);
};

struct qdisc_watchdog {
	u64 last_expires;
	struct hrtimer timer;
	struct Qdisc___65 *qdisc;
};

enum tc_root_command {
	TC_ROOT_GRAFT = 0,
};

struct tc_root_qopt_offload {
	enum tc_root_command command;
	u32 handle;
	bool ingress;
};

struct check_loop_arg {
	struct qdisc_walker___8 w;
	struct Qdisc___65 *p;
	int depth;
};

struct tcf_bind_args {
	struct tcf_walker___3 w;
	long unsigned int base;
	long unsigned int cl;
	u32 classid;
};

struct tc_bind_class_args {
	struct qdisc_walker___8 w;
	long unsigned int new_cl;
	u32 portid;
	u32 clid;
};

struct qdisc_dump_args {
	struct qdisc_walker___8 w;
	struct sk_buff___72 *skb;
	struct netlink_callback___71 *cb;
};

enum net_xmit_qdisc_t {
	__NET_XMIT_STOLEN = 65536,
	__NET_XMIT_BYPASS = 131072,
};

struct dentry___263;

struct super_block___263;

struct module___247;

struct file_system_type___263 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___263 * (*mount)(struct file_system_type___263 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___263 *);
	struct module___247 *owner;
	struct file_system_type___263 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___263;

struct kiocb___263;

struct iov_iter___183;

struct poll_table_struct___184;

struct vm_area_struct___268;

struct inode___263;

struct file_lock___263;

struct page___268;

struct pipe_inode_info___104;

struct seq_file___238;

struct file_operations___264 {
	struct module___247 *owner;
	loff_t (*llseek)(struct file___263 *, loff_t, int);
	ssize_t (*read)(struct file___263 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___263 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___263 *, struct iov_iter___183 *);
	ssize_t (*write_iter)(struct kiocb___263 *, struct iov_iter___183 *);
	int (*iopoll)(struct kiocb___263 *, bool);
	int (*iterate)(struct file___263 *, struct dir_context *);
	int (*iterate_shared)(struct file___263 *, struct dir_context *);
	__poll_t (*poll)(struct file___263 *, struct poll_table_struct___184 *);
	long int (*unlocked_ioctl)(struct file___263 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___263 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___263 *, struct vm_area_struct___268 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___263 *, struct file___263 *);
	int (*flush)(struct file___263 *, fl_owner_t);
	int (*release)(struct inode___263 *, struct file___263 *);
	int (*fsync)(struct file___263 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___263 *, int);
	int (*lock)(struct file___263 *, int, struct file_lock___263 *);
	ssize_t (*sendpage)(struct file___263 *, struct page___268 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___263 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___263 *, long unsigned int);
	int (*flock)(struct file___263 *, int, struct file_lock___263 *);
	ssize_t (*splice_write)(struct pipe_inode_info___104 *, struct file___263 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___263 *, loff_t *, struct pipe_inode_info___104 *, size_t, unsigned int);
	int (*setlease)(struct file___263 *, long int, struct file_lock___263 **, void **);
	long int (*fallocate)(struct file___263 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___238 *, struct file___263 *);
	ssize_t (*copy_file_range)(struct file___263 *, loff_t, struct file___263 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___263 *, loff_t, struct file___263 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___263 *, loff_t, loff_t, int);
};

struct vmacache___268 {
	u64 seqnum;
	struct vm_area_struct___268 *vmas[4];
};

struct page_frag___268 {
	struct page___268 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___269;

struct pid___240;

struct nsproxy___249;

struct signal_struct___264;

struct bio_list___154;

struct backing_dev_info___140;

struct io_context___154;

struct css_set___190;

struct mem_cgroup___128;

struct request_queue___154;

struct vm_struct___246;

struct task_struct___270 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___270 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___269 *mm;
	struct mm_struct___269 *active_mm;
	struct vmacache___268 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___270 *real_parent;
	struct task_struct___270 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___270 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___240 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___249 *nsproxy;
	struct signal_struct___264 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___270 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___154 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___140 *backing_dev_info;
	struct io_context___154 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___190 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___104 *splice_pipe;
	struct page_frag___268 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___128 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___128 *active_memcg;
	struct request_queue___154 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___270 *oom_reaper_list;
	struct vm_struct___246 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___86 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___251;

struct kobj_type___251;

struct kernfs_node___251;

struct kobject___251 {
	const char *name;
	struct list_head entry;
	struct kobject___251 *parent;
	struct kset___251 *kset;
	struct kobj_type___251 *ktype;
	struct kernfs_node___251 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___248 {
	struct kobject___251 kobj;
	struct module___247 *mod;
	struct kobject___251 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___247 {
	struct module___247 *mod;
	struct latch_tree_node node;
};

struct module_layout___247 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___247 mtn;
};

struct module_attribute___247;

struct kernel_param___247;

struct module___247 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___248 mkobj;
	struct module_attribute___247 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___251 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___247 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___247 core_layout;
	struct module_layout___247 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___240;

struct upid___240 {
	int nr;
	struct pid_namespace___240 *ns;
};

struct pid_namespace___240 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___270 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___240 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___240 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___240 numbers[1];
};

typedef struct page___268 *pgtable_t___268;

struct address_space___263;

struct page_pool___92;

struct dev_pagemap___258;

struct page___268 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___263 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___92 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___268 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___268 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___269 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___258 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___258;

struct vm_area_struct___268 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___268 *vm_next;
	struct vm_area_struct___268 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___269 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___258 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___263 *vm_file;
	struct file___263 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___264 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___270 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___270 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___240 *pids[4];
	struct pid___240 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___269 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___268;

struct mm_struct___269 {
	struct {
		struct vm_area_struct___268 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___263 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___268 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___270 *owner;
		struct user_namespace___26 *user_ns;
		struct file___263 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___77;

struct cgroup_namespace___190;

struct nsproxy___249 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___240 *pid_ns_for_children;
	struct net___77 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___190 *cgroup_ns;
};

struct bio___154;

struct bio_list___154 {
	struct bio___154 *head;
	struct bio___154 *tail;
};

struct cgroup_subsys_state___190;

struct bdi_writeback___140 {
	struct backing_dev_info___140 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___190 *memcg_css;
	struct cgroup_subsys_state___190 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___244;

struct backing_dev_info___140 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___140 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___244 *dev;
	char dev_name[64];
	struct device___244 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___263 *debug_dir;
};

struct io_cq___154;

struct io_context___154 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___154 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___190;

struct css_set___190 {
	struct cgroup_subsys_state___190 *subsys[14];
	refcount_t refcount;
	struct css_set___190 *dom_cset;
	struct cgroup___190 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___190 *mg_src_cgrp;
	struct cgroup___190 *mg_dst_cgrp;
	struct css_set___190 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___263;

struct pipe_buffer___104;

struct pipe_inode_info___104 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___268 *tmp_page;
	struct fasync_struct___263 *fasync_readers;
	struct fasync_struct___263 *fasync_writers;
	struct pipe_buffer___104 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___190;

struct cgroup_subsys_state___190 {
	struct cgroup___190 *cgroup;
	struct cgroup_subsys___190 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___190 *parent;
};

struct cgroup_file___190 {
	struct kernfs_node___251 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___128;

struct mem_cgroup_per_node___128;

struct mem_cgroup___128 {
	struct cgroup_subsys_state___190 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___190 events_file;
	struct cgroup_file___190 events_local_file;
	struct cgroup_file___190 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___128 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___270 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___128 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___154;

struct blk_integrity___154 {
	const struct blk_integrity_profile___154 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___154 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___154 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___154;

struct elevator_queue___154;

struct blk_mq_ops___149;

struct blk_mq_hw_ctx___149;

struct gendisk___157;

struct blkcg_gq___142;

struct blk_mq_tag_set___149;

struct request_queue___154 {
	struct request___154 *last_merge;
	struct elevator_queue___154 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___149 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___149 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___157 *disk;
	struct kobject___251 kobj;
	struct kobject___251 *mq_kobj;
	struct blk_integrity___154 integrity;
	struct device___244 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___142 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___149 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___154 bio_split;
	struct dentry___263 *debugfs_dir;
	struct dentry___263 *sched_debugfs_dir;
	struct dentry___263 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___246 {
	struct vm_struct___246 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___268 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___263;

struct address_space___263 {
	struct inode___263 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___263 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___92 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___244 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___92 {
	u32 count;
	struct page___268 *cache[128];
};

struct page_pool___92 {
	struct page_pool_params___92 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___268 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___92 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___258;

struct dev_pagemap___258 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___258 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___263;

struct path___263 {
	struct vfsmount___263 *mnt;
	struct dentry___263 *dentry;
};

struct fown_struct___240 {
	rwlock_t lock;
	struct pid___240 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___263 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___263 f_path;
	struct inode___263 *f_inode;
	const struct file_operations___264 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___240 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___263 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___258;

struct vm_operations_struct___258 {
	void (*open)(struct vm_area_struct___268 *);
	void (*close)(struct vm_area_struct___268 *);
	int (*may_split)(struct vm_area_struct___268 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___268 *);
	int (*mprotect)(struct vm_area_struct___268 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___258 *);
	vm_fault_t (*huge_fault)(struct vm_fault___258 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___258 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___268 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___258 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___258 *);
	int (*access)(struct vm_area_struct___268 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___268 *);
	int (*set_policy)(struct vm_area_struct___268 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___268 *, long unsigned int);
	struct page___268 * (*find_special_page)(struct vm_area_struct___268 *, long unsigned int);
};

struct core_thread___268 {
	struct task_struct___270 *task;
	struct core_thread___268 *next;
};

struct core_state___268 {
	atomic_t nr_threads;
	struct core_thread___268 dumper;
	struct completion startup;
};

struct vm_fault___258 {
	const struct {
		struct vm_area_struct___268 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___268 *cow_page;
	struct page___268 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___268 prealloc_pte;
};

struct pglist_data___136;

struct lruvec___136 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___136 *pgdat;
};

struct zone___136 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___136 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___136 {
	struct zone___136 *zone;
	int zone_idx;
};

struct zonelist___136 {
	struct zoneref___136 _zonerefs[321];
};

struct pglist_data___136 {
	struct zone___136 node_zones[5];
	struct zonelist___136 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___270 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___270 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___136 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___263;

struct dentry___263 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___263 *d_parent;
	struct qstr d_name;
	struct inode___263 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___263 *d_op;
	struct super_block___263 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___263;

struct inode___263 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___263 *i_op;
	struct super_block___263 *i_sb;
	struct address_space___263 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___140 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___264 *i_fop;
		void (*free_inode)(struct inode___263 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___263 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___104 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___263 {
	int (*d_revalidate)(struct dentry___263 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___263 *, unsigned int);
	int (*d_hash)(const struct dentry___263 *, struct qstr *);
	int (*d_compare)(const struct dentry___263 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___263 *);
	int (*d_init)(struct dentry___263 *);
	void (*d_release)(struct dentry___263 *);
	void (*d_prune)(struct dentry___263 *);
	void (*d_iput)(struct dentry___263 *, struct inode___263 *);
	char * (*d_dname)(struct dentry___263 *, char *, int);
	struct vfsmount___263 * (*d_automount)(struct path___263 *);
	int (*d_manage)(const struct path___263 *, bool);
	struct dentry___263 * (*d_real)(struct dentry___263 *, const struct inode___263 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___263;

struct mem_dqinfo___263 {
	struct quota_format_type___263 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___263;

struct quota_info___263 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___263 *files[3];
	struct mem_dqinfo___263 info[3];
	const struct quota_format_ops___263 *ops[3];
};

struct rcuwait___264 {
	struct task_struct___270 *task;
};

struct percpu_rw_semaphore___264 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___264 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___263 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___264 rw_sem[3];
};

struct shrink_control___128;

struct shrinker___128 {
	long unsigned int (*count_objects)(struct shrinker___128 *, struct shrink_control___128 *);
	long unsigned int (*scan_objects)(struct shrinker___128 *, struct shrink_control___128 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___263;

struct dquot_operations___263;

struct quotactl_ops___263;

struct block_device___157;

struct super_block___263 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___263 *s_type;
	const struct super_operations___263 *s_op;
	const struct dquot_operations___263 *dq_op;
	const struct quotactl_ops___263 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___263 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___157 *s_bdev;
	struct backing_dev_info___140 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___263 s_dquot;
	struct sb_writers___263 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___263 *s_d_op;
	int cleancache_poolid;
	struct shrinker___128 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___263 {
	struct dentry___263 *mnt_root;
	struct super_block___263 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___128 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___128 *memcg;
};

struct psi_group___190 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___270 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___66;

struct cgroup_bpf___66 {
	struct bpf_prog_array___66 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___66 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___190;

struct cgroup_rstat_cpu___190;

struct cgroup___190 {
	struct cgroup_subsys_state___190 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___251 *kn;
	struct cgroup_file___190 procs_file;
	struct cgroup_file___190 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___190 *subsys[14];
	struct cgroup_root___190 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___190 *dom_cgrp;
	struct cgroup___190 *old_dom_cgrp;
	struct cgroup_rstat_cpu___190 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___190 psi;
	struct cgroup_bpf___66 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___154 {
	struct request_queue___154 *q;
	struct io_context___154 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___263 {
	struct file___263 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___263 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___263 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___263 *ia_file;
};

struct dquot___263 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___263 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___263 {
	int qf_fmt_id;
	const struct quota_format_ops___263 *qf_ops;
	struct module___247 *qf_owner;
	struct quota_format_type___263 *qf_next;
};

struct quota_format_ops___263 {
	int (*check_quota_file)(struct super_block___263 *, int);
	int (*read_file_info)(struct super_block___263 *, int);
	int (*write_file_info)(struct super_block___263 *, int);
	int (*free_file_info)(struct super_block___263 *, int);
	int (*read_dqblk)(struct dquot___263 *);
	int (*commit_dqblk)(struct dquot___263 *);
	int (*release_dqblk)(struct dquot___263 *);
	int (*get_next_id)(struct super_block___263 *, struct kqid *);
};

struct dquot_operations___263 {
	int (*write_dquot)(struct dquot___263 *);
	struct dquot___263 * (*alloc_dquot)(struct super_block___263 *, int);
	void (*destroy_dquot)(struct dquot___263 *);
	int (*acquire_dquot)(struct dquot___263 *);
	int (*release_dquot)(struct dquot___263 *);
	int (*mark_dirty)(struct dquot___263 *);
	int (*write_info)(struct super_block___263 *, int);
	qsize_t * (*get_reserved_space)(struct inode___263 *);
	int (*get_projid)(struct inode___263 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___263 *, qsize_t *);
	int (*get_next_id)(struct super_block___263 *, struct kqid *);
};

struct quotactl_ops___263 {
	int (*quota_on)(struct super_block___263 *, int, int, const struct path___263 *);
	int (*quota_off)(struct super_block___263 *, int);
	int (*quota_enable)(struct super_block___263 *, unsigned int);
	int (*quota_disable)(struct super_block___263 *, unsigned int);
	int (*quota_sync)(struct super_block___263 *, int);
	int (*set_info)(struct super_block___263 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___263 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___263 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___263 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___263 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___263 *, unsigned int);
};

struct writeback_control___140;

struct address_space_operations___263 {
	int (*writepage)(struct page___268 *, struct writeback_control___140 *);
	int (*readpage)(struct file___263 *, struct page___268 *);
	int (*writepages)(struct address_space___263 *, struct writeback_control___140 *);
	int (*set_page_dirty)(struct page___268 *);
	int (*readpages)(struct file___263 *, struct address_space___263 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___263 *, struct address_space___263 *, loff_t, unsigned int, unsigned int, struct page___268 **, void **);
	int (*write_end)(struct file___263 *, struct address_space___263 *, loff_t, unsigned int, unsigned int, struct page___268 *, void *);
	sector_t (*bmap)(struct address_space___263 *, sector_t);
	void (*invalidatepage)(struct page___268 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___268 *, gfp_t);
	void (*freepage)(struct page___268 *);
	ssize_t (*direct_IO)(struct kiocb___263 *, struct iov_iter___183 *);
	int (*migratepage)(struct address_space___263 *, struct page___268 *, struct page___268 *, enum migrate_mode);
	bool (*isolate_page)(struct page___268 *, isolate_mode_t);
	void (*putback_page)(struct page___268 *);
	int (*launder_page)(struct page___268 *);
	int (*is_partially_uptodate)(struct page___268 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___268 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___263 *, struct page___268 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___263 *, sector_t *);
	void (*swap_deactivate)(struct file___263 *);
};

struct writeback_control___140 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___140 *wb;
	struct inode___263 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___180;

struct iov_iter___183 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___180 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___104 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___263 {
	struct dentry___263 * (*lookup)(struct inode___263 *, struct dentry___263 *, unsigned int);
	const char * (*get_link)(struct dentry___263 *, struct inode___263 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___263 *, int);
	struct posix_acl * (*get_acl)(struct inode___263 *, int, bool);
	int (*readlink)(struct dentry___263 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___263 *, struct dentry___263 *, umode_t, bool);
	int (*link)(struct dentry___263 *, struct inode___263 *, struct dentry___263 *);
	int (*unlink)(struct inode___263 *, struct dentry___263 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___263 *, struct dentry___263 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___263 *, struct dentry___263 *, umode_t);
	int (*rmdir)(struct inode___263 *, struct dentry___263 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___263 *, struct dentry___263 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___263 *, struct dentry___263 *, struct inode___263 *, struct dentry___263 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___263 *, struct iattr___263 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___263 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___263 *, char *, size_t);
	int (*fiemap)(struct inode___263 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___263 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___263 *, struct dentry___263 *, struct file___263 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___263 *, struct dentry___263 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___263 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___263 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___263 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___263 {
	void (*fl_copy_lock)(struct file_lock___263 *, struct file_lock___263 *);
	void (*fl_release_private)(struct file_lock___263 *);
};

struct lock_manager_operations___263;

struct file_lock___263 {
	struct file_lock___263 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___263 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___263 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___263 *fl_ops;
	const struct lock_manager_operations___263 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___263 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___263 *);
	int (*lm_grant)(struct file_lock___263 *, int);
	bool (*lm_break)(struct file_lock___263 *);
	int (*lm_change)(struct file_lock___263 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___263 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___263 *);
};

struct fasync_struct___263 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___263 *fa_next;
	struct file___263 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___263 {
	struct inode___263 * (*alloc_inode)(struct super_block___263 *);
	void (*destroy_inode)(struct inode___263 *);
	void (*free_inode)(struct inode___263 *);
	void (*dirty_inode)(struct inode___263 *, int);
	int (*write_inode)(struct inode___263 *, struct writeback_control___140 *);
	int (*drop_inode)(struct inode___263 *);
	void (*evict_inode)(struct inode___263 *);
	void (*put_super)(struct super_block___263 *);
	int (*sync_fs)(struct super_block___263 *, int);
	int (*freeze_super)(struct super_block___263 *);
	int (*freeze_fs)(struct super_block___263 *);
	int (*thaw_super)(struct super_block___263 *);
	int (*unfreeze_fs)(struct super_block___263 *);
	int (*statfs)(struct dentry___263 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___263 *, int *, char *);
	void (*umount_begin)(struct super_block___263 *);
	int (*show_options)(struct seq_file___238 *, struct dentry___263 *);
	int (*show_devname)(struct seq_file___238 *, struct dentry___263 *);
	int (*show_path)(struct seq_file___238 *, struct dentry___263 *);
	int (*show_stats)(struct seq_file___238 *, struct dentry___263 *);
	ssize_t (*quota_read)(struct super_block___263 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___263 *, int, const char *, size_t, loff_t);
	struct dquot___263 ** (*get_dquots)(struct inode___263 *);
	long int (*nr_cached_objects)(struct super_block___263 *, struct shrink_control___128 *);
	long int (*free_cached_objects)(struct super_block___263 *, struct shrink_control___128 *);
	struct file___263 * (*real_loop)(struct file___263 *);
};

struct wakeup_source___244;

struct dev_pm_info___244 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___244 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___244 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___244;

struct bus_type___244;

struct device_driver___244;

struct dev_pm_domain___244;

struct fwnode_handle___240;

struct class___244;

struct attribute_group___251;

struct device___244 {
	struct kobject___251 kobj;
	struct device___244 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___244 *type;
	struct bus_type___244 *bus;
	struct device_driver___244 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___244 power;
	struct dev_pm_domain___244 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___240 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___244 *class;
	const struct attribute_group___251 **groups;
	void (*release)(struct device___244 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___157 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___263 *bd_inode;
	struct super_block___263 *bd_super;
	void *bd_claiming;
	struct device___244 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___251 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___157 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___263 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___192)(struct file___263 *, wait_queue_head_t *, struct poll_table_struct___184 *);

struct poll_table_struct___184 {
	poll_queue_proc___192 _qproc;
	__poll_t _key;
};

struct seq_operations___238;

struct seq_file___238 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___238 *op;
	int poll_event;
	const struct file___263 *file;
	void *private;
};

typedef void bio_end_io_t___154(struct bio___154 *);

struct bio_vec___180 {
	struct page___268 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___154;

struct bio___154 {
	struct bio___154 *bi_next;
	struct block_device___157 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___154 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___142 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___154 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___180 *bi_io_vec;
	struct bio_set___154 *bi_pool;
	struct bio_vec___180 bi_inline_vecs[0];
};

struct kernfs_root___251;

struct kernfs_elem_dir___251 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___251 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___251;

struct kernfs_root___251 {
	struct kernfs_node___251 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___251 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___251 {
	struct kernfs_node___251 *target_kn;
};

struct kernfs_ops___251;

struct kernfs_elem_attr___251 {
	const struct kernfs_ops___251 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___251 *notify_next;
};

struct kernfs_node___251 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___251 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___251 dir;
		struct kernfs_elem_symlink___251 symlink;
		struct kernfs_elem_attr___251 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___251;

struct kernfs_ops___251 {
	int (*open)(struct kernfs_open_file___251 *);
	void (*release)(struct kernfs_open_file___251 *);
	int (*seq_show)(struct seq_file___238 *, void *);
	void * (*seq_start)(struct seq_file___238 *, loff_t *);
	void * (*seq_next)(struct seq_file___238 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___238 *, void *);
	ssize_t (*read)(struct kernfs_open_file___251 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___251 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___251 *, struct poll_table_struct___184 *);
	int (*mmap)(struct kernfs_open_file___251 *, struct vm_area_struct___268 *);
};

struct kernfs_syscall_ops___251 {
	int (*show_options)(struct seq_file___238 *, struct kernfs_root___251 *);
	int (*mkdir)(struct kernfs_node___251 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___251 *);
	int (*rename)(struct kernfs_node___251 *, struct kernfs_node___251 *, const char *);
	int (*show_path)(struct seq_file___238 *, struct kernfs_node___251 *, struct kernfs_root___251 *);
};

struct kernfs_open_file___251 {
	struct kernfs_node___251 *kn;
	struct file___263 *file;
	struct seq_file___238 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___258 *vm_ops;
};

struct sock___59;

struct kobj_ns_type_operations___59 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___59 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___77 *net;
} possible_net_t___72;

struct proto___59;

struct sock_common___59 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___59 *skc_prot;
	possible_net_t___72 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___59 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___73;

struct sk_buff_head___72 {
	struct sk_buff___73 *next;
	struct sk_buff___73 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___59 {
	struct cgroup___190 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___59;

struct socket_wq___60;

struct dst_entry___59;

struct socket___61;

struct net_device___72;

struct sock___59 {
	struct sock_common___59 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___72 sk_error_queue;
	struct sk_buff___73 *sk_rx_skb_cache;
	struct sk_buff_head___72 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___73 *head;
		struct sk_buff___73 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___59 *sk_filter;
	union {
		struct socket_wq___60 *sk_wq;
		struct socket_wq___60 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___59 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___59 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___73 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___73 *sk_tx_skb_cache;
	struct sk_buff_head___72 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___268 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___59 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___240 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___61 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___59 sk_cgrp_data;
	struct mem_cgroup___128 *sk_memcg;
	void (*sk_state_change)(struct sock___59 *);
	void (*sk_data_ready)(struct sock___59 *);
	void (*sk_write_space)(struct sock___59 *);
	void (*sk_error_report)(struct sock___59 *);
	int (*sk_backlog_rcv)(struct sock___59 *, struct sk_buff___73 *);
	struct sk_buff___73 * (*sk_validate_xmit_skb)(struct sock___59 *, struct net_device___72 *, struct sk_buff___73 *);
	void (*sk_destruct)(struct sock___59 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___251;

struct attribute_group___251 {
	const char *name;
	umode_t (*is_visible)(struct kobject___251 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___251 *, struct bin_attribute___251 *, int);
	struct attribute **attrs;
	struct bin_attribute___251 **bin_attrs;
};

struct bin_attribute___251 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___263 * (*f_mapping)();
	ssize_t (*read)(struct file___263 *, struct kobject___251 *, struct bin_attribute___251 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___263 *, struct kobject___251 *, struct bin_attribute___251 *, char *, loff_t, size_t);
	int (*mmap)(struct file___263 *, struct kobject___251 *, struct bin_attribute___251 *, struct vm_area_struct___268 *);
};

struct sysfs_ops___251 {
	ssize_t (*show)(struct kobject___251 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___251 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___251;

struct kset___251 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___251 kobj;
	const struct kset_uevent_ops___251 *uevent_ops;
};

struct kobj_type___251 {
	void (*release)(struct kobject___251 *);
	const struct sysfs_ops___251 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___251 **default_groups;
	const struct kobj_ns_type_operations___59 * (*child_ns_type)(struct kobject___251 *);
	const void * (*namespace)(struct kobject___251 *);
	void (*get_ownership)(struct kobject___251 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___251 {
	int (* const filter)(struct kset___251 *, struct kobject___251 *);
	const char * (* const name)(struct kset___251 *, struct kobject___251 *);
	int (* const uevent)(struct kset___251 *, struct kobject___251 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___247 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___247 *);
	int (*get)(char *, const struct kernel_param___247 *);
	void (*free)(void *);
};

struct kparam_array___247;

struct kernel_param___247 {
	const char *name;
	struct module___247 *mod;
	const struct kernel_param_ops___247 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___247 *arr;
	};
};

struct kparam_array___247 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___247 *ops;
	void *elem;
};

struct module_attribute___247 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___247 *, struct module_kobject___248 *, char *);
	ssize_t (*store)(struct module_attribute___247 *, struct module_kobject___248 *, const char *, size_t);
	void (*setup)(struct module___247 *, const char *);
	int (*test)(struct module___247 *);
	void (*free)(struct module___247 *);
};

struct dev_pagemap_ops___258 {
	void (*page_free)(struct page___268 *);
	void (*kill)(struct dev_pagemap___258 *);
	void (*cleanup)(struct dev_pagemap___258 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___258 *);
};

struct fwnode_operations___240;

struct fwnode_handle___240 {
	struct fwnode_handle___240 *secondary;
	const struct fwnode_operations___240 *ops;
	struct device___244 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___240;

struct fwnode_endpoint___240;

struct fwnode_operations___240 {
	struct fwnode_handle___240 * (*get)(struct fwnode_handle___240 *);
	void (*put)(struct fwnode_handle___240 *);
	bool (*device_is_available)(const struct fwnode_handle___240 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___240 *, const struct device___244 *);
	bool (*property_present)(const struct fwnode_handle___240 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___240 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___240 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___240 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*get_parent)(const struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*get_next_child_node)(const struct fwnode_handle___240 *, struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*get_named_child_node)(const struct fwnode_handle___240 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___240 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___240 *);
	struct fwnode_handle___240 * (*graph_get_next_endpoint)(const struct fwnode_handle___240 *, struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*graph_get_remote_endpoint)(const struct fwnode_handle___240 *);
	struct fwnode_handle___240 * (*graph_get_port_parent)(struct fwnode_handle___240 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___240 *, struct fwnode_endpoint___240 *);
	int (*add_links)(struct fwnode_handle___240 *);
};

struct fwnode_endpoint___240 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___240 *local_fwnode;
};

struct fwnode_reference_args___240 {
	struct fwnode_handle___240 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___59;

struct fqdir___77;

struct fib_notifier_ops___59;

struct netns_ipv4___77 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___59 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___59 *fibnl;
	struct sock___59 **icmp_sk;
	struct sock___59 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___59 **tcp_sk;
	struct fqdir___77 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___59 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___59 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___59 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___59;

struct dst_ops___77 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___77 *);
	struct dst_entry___59 * (*check)(struct dst_entry___59 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___59 *);
	unsigned int (*mtu)(const struct dst_entry___59 *);
	u32 * (*cow_metrics)(struct dst_entry___59 *, long unsigned int);
	void (*destroy)(struct dst_entry___59 *);
	void (*ifdown)(struct dst_entry___59 *, struct net_device___72 *, int);
	struct dst_entry___59 * (*negative_advice)(struct dst_entry___59 *);
	void (*link_failure)(struct sk_buff___73 *);
	void (*update_pmtu)(struct dst_entry___59 *, struct sock___59 *, struct sk_buff___73 *, u32, bool);
	void (*redirect)(struct dst_entry___59 *, struct sock___59 *, struct sk_buff___73 *);
	int (*local_out)(struct net___77 *, struct sock___59 *, struct sk_buff___73 *);
	struct neighbour___59 * (*neigh_lookup)(const struct dst_entry___59 *, struct sk_buff___73 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___59 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___12;

struct rt6_info___12;

struct fib6_table___12;

struct netns_ipv6___77 {
	struct dst_ops___77 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___77 *fqdir;
	struct fib6_info___12 *fib6_null_entry;
	struct rt6_info___12 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___12 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___12 *ip6_prohibit_entry;
	struct rt6_info___12 *ip6_blk_hole_entry;
	struct fib6_table___12 *fib6_local_tbl;
	struct fib_rules_ops___59 *fib6_rules_ops;
	struct sock___59 **icmp_sk;
	struct sock___59 *ndisc_sk;
	struct sock___59 *tcp_sk;
	struct sock___59 *igmp_sk;
	struct sock___59 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___59 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___59 *notifier_ops;
	struct fib_notifier_ops___59 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___77 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___77 *fqdir;
};

struct netns_sctp___59 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___59 *ctl_sock;
	struct sock___59 *udp4_sock;
	struct sock___59 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___6;

struct netns_nf___6 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___6 *hooks_ipv4[5];
	struct nf_hook_entries___6 *hooks_ipv6[5];
	struct nf_hook_entries___6 *hooks_arp[3];
	struct nf_hook_entries___6 *hooks_bridge[5];
	struct nf_hook_entries___6 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___66;

struct netns_bpf___66 {
	struct bpf_prog_array___66 *run_array[2];
	struct bpf_prog___66 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___77 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___59 *nlsk;
	struct sock___59 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___77 xfrm4_dst_ops;
	struct dst_ops___77 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___77 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___59 *rtnl;
	struct sock___59 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___72 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___77 ipv4;
	struct netns_ipv6___77 ipv6;
	struct netns_ieee802154_lowpan___77 ieee802154_lowpan;
	struct netns_sctp___59 sctp;
	struct netns_nf___6 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___72 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___66 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___77 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___59 *crypto_nlsk;
	struct sock___59 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___190 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___190 *root_cset;
};

struct msghdr___61 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___183 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___263 *msg_iocb;
};

struct socket_wq___60 {
	wait_queue_head_t wait;
	struct fasync_struct___263 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___60;

struct socket___61 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___263 *file;
	struct sock___59 *sk;
	const struct proto_ops___60 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___60 wq;
};

typedef int (*sk_read_actor_t___59)(read_descriptor_t *, struct sk_buff___73 *, unsigned int, size_t);

struct proto_ops___60 {
	int family;
	struct module___247 *owner;
	int (*release)(struct socket___61 *);
	int (*bind)(struct socket___61 *, struct sockaddr *, int);
	int (*connect)(struct socket___61 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___61 *, struct socket___61 *);
	int (*accept)(struct socket___61 *, struct socket___61 *, int, bool);
	int (*getname)(struct socket___61 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___263 *, struct socket___61 *, struct poll_table_struct___184 *);
	int (*ioctl)(struct socket___61 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___61 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___61 *, void *, bool, bool);
	int (*listen)(struct socket___61 *, int);
	int (*shutdown)(struct socket___61 *, int);
	int (*setsockopt)(struct socket___61 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___61 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___238 *, struct socket___61 *);
	int (*sendmsg)(struct socket___61 *, struct msghdr___61 *, size_t);
	int (*recvmsg)(struct socket___61 *, struct msghdr___61 *, size_t, int);
	int (*mmap)(struct file___263 *, struct socket___61 *, struct vm_area_struct___268 *);
	ssize_t (*sendpage)(struct socket___61 *, struct page___268 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___61 *, loff_t *, struct pipe_inode_info___104 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___59 *, int);
	int (*peek_len)(struct socket___61 *);
	int (*read_sock)(struct sock___59 *, read_descriptor_t *, sk_read_actor_t___59);
	int (*sendpage_locked)(struct sock___59 *, struct page___268 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___59 *, struct msghdr___61 *, size_t);
	int (*set_rcvlowat)(struct sock___59 *, int);
};

struct sk_buff___73 {
	union {
		struct {
			struct sk_buff___73 *next;
			struct sk_buff___73 *prev;
			union {
				struct net_device___72 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___59 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___73 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___244 {
	int (*prepare)(struct device___244 *);
	void (*complete)(struct device___244 *);
	int (*suspend)(struct device___244 *);
	int (*resume)(struct device___244 *);
	int (*freeze)(struct device___244 *);
	int (*thaw)(struct device___244 *);
	int (*poweroff)(struct device___244 *);
	int (*restore)(struct device___244 *);
	int (*suspend_late)(struct device___244 *);
	int (*resume_early)(struct device___244 *);
	int (*freeze_late)(struct device___244 *);
	int (*thaw_early)(struct device___244 *);
	int (*poweroff_late)(struct device___244 *);
	int (*restore_early)(struct device___244 *);
	int (*suspend_noirq)(struct device___244 *);
	int (*resume_noirq)(struct device___244 *);
	int (*freeze_noirq)(struct device___244 *);
	int (*thaw_noirq)(struct device___244 *);
	int (*poweroff_noirq)(struct device___244 *);
	int (*restore_noirq)(struct device___244 *);
	int (*runtime_suspend)(struct device___244 *);
	int (*runtime_resume)(struct device___244 *);
	int (*runtime_idle)(struct device___244 *);
};

struct wakeup_source___244 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___244 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___244 {
	struct dev_pm_ops___244 ops;
	int (*start)(struct device___244 *);
	void (*detach)(struct device___244 *, bool);
	int (*activate)(struct device___244 *);
	void (*sync)(struct device___244 *);
	void (*dismiss)(struct device___244 *);
};

struct bus_type___244 {
	const char *name;
	const char *dev_name;
	struct device___244 *dev_root;
	const struct attribute_group___251 **bus_groups;
	const struct attribute_group___251 **dev_groups;
	const struct attribute_group___251 **drv_groups;
	int (*match)(struct device___244 *, struct device_driver___244 *);
	int (*uevent)(struct device___244 *, struct kobj_uevent_env *);
	int (*probe)(struct device___244 *);
	void (*sync_state)(struct device___244 *);
	void (*remove)(struct device___244 *);
	void (*shutdown)(struct device___244 *);
	int (*online)(struct device___244 *);
	int (*offline)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	int (*num_vf)(struct device___244 *);
	int (*dma_configure)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___244 {
	const char *name;
	struct bus_type___244 *bus;
	struct module___247 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___244 *);
	void (*sync_state)(struct device___244 *);
	int (*remove)(struct device___244 *);
	void (*shutdown)(struct device___244 *);
	int (*suspend)(struct device___244 *, pm_message_t);
	int (*resume)(struct device___244 *);
	const struct attribute_group___251 **groups;
	const struct attribute_group___251 **dev_groups;
	const struct dev_pm_ops___244 *pm;
	void (*coredump)(struct device___244 *);
	struct driver_private *p;
};

struct device_type___244 {
	const char *name;
	const struct attribute_group___251 **groups;
	int (*uevent)(struct device___244 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___244 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___244 *);
	const struct dev_pm_ops___244 *pm;
};

struct class___244 {
	const char *name;
	struct module___247 *owner;
	const struct attribute_group___251 **class_groups;
	const struct attribute_group___251 **dev_groups;
	struct kobject___251 *dev_kobj;
	int (*dev_uevent)(struct device___244 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___244 *, umode_t *);
	void (*class_release)(struct class___244 *);
	void (*dev_release)(struct device___244 *);
	int (*shutdown_pre)(struct device___244 *);
	const struct kobj_ns_type_operations___59 *ns_type;
	const void * (*namespace)(struct device___244 *);
	void (*get_ownership)(struct device___244 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___244 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___104;

struct pipe_buffer___104 {
	struct page___268 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___104 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___104 {
	int (*confirm)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
	void (*release)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
	bool (*try_steal)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
	bool (*get)(struct pipe_inode_info___104 *, struct pipe_buffer___104 *);
};

typedef rx_handler_result_t rx_handler_func_t___72(struct sk_buff___73 **);

struct bpf_xdp_entity___66 {
	struct bpf_prog___66 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___72;

struct net_device_ops___72;

struct l3mdev_ops___59;

struct ndisc_ops___42;

struct xfrmdev_ops___72;

struct header_ops___72;

struct inet6_dev___42;

struct netdev_rx_queue___72;

struct mini_Qdisc___66;

struct netdev_queue___72;

struct Qdisc___66;

struct rtnl_link_ops___66;

struct dcbnl_rtnl_ops___72;

struct net_device___72 {
	char name[16];
	struct netdev_name_node___72 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___72 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___59 *l3mdev_ops;
	const struct ndisc_ops___42 *ndisc_ops;
	const struct xfrmdev_ops___72 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___72 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___251 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___42 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___72 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___66 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___72 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___66 *miniq_ingress;
	struct netdev_queue___72 *ingress_queue;
	struct nf_hook_entries___6 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___72 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___66 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___66 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___72 = 0,
		NETREG_REGISTERED___72 = 1,
		NETREG_UNREGISTERING___72 = 2,
		NETREG_UNREGISTERED___72 = 3,
		NETREG_RELEASED___72 = 4,
		NETREG_DUMMY___72 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___72 = 0,
		RTNL_LINK_INITIALIZING___72 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___72 *);
	struct netpoll_info *npinfo;
	possible_net_t___72 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___244 dev;
	const struct attribute_group___251 *sysfs_groups[4];
	const struct attribute_group___251 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___66 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___72 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___66 xdp_state[3];
	long: 64;
};

struct inet_frags___77;

struct fqdir___77 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___77 *f;
	struct net___77 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___77;

struct inet_frags___77 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___77 *, const void *);
	void (*destructor)(struct inet_frag_queue___77 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___77 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___73 *fragments_tail;
	struct sk_buff___73 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___77 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___59;

struct fib_lookup_arg___59;

struct fib_rules_ops___59 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___59 *, struct flowi *, int, struct fib_lookup_arg___59 *);
	bool (*suppress)(struct fib_rule___59 *, int, struct fib_lookup_arg___59 *);
	int (*match)(struct fib_rule___59 *, struct flowi *, int);
	int (*configure)(struct fib_rule___59 *, struct sk_buff___73 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___59 *);
	int (*compare)(struct fib_rule___59 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___59 *, struct sk_buff___73 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___59 *);
	void (*flush_cache)(struct fib_rules_ops___59 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___247 *owner;
	struct net___77 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___59 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___77 *);
	int (*fib_dump)(struct net___77 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___247 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___36;

struct dst_entry___59 {
	struct net_device___72 *dev;
	struct dst_ops___77 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___73 *);
	int (*output)(struct net___77 *, struct sock___59 *, struct sk_buff___73 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___36 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___59;

struct neigh_parms___59;

struct neigh_ops___59;

struct neighbour___59 {
	struct neighbour___59 *next;
	struct neigh_table___59 *tbl;
	struct neigh_parms___59 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___72 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___59 *, struct sk_buff___73 *);
	const struct neigh_ops___59 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___72 *dev;
	u8 primary_key[0];
};

struct rtable___12;

struct fnhe_hash_bucket___12;

struct fib_nh_common___12 {
	struct net_device___72 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___36 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___12 **nhc_pcpu_rth_output;
	struct rtable___12 *nhc_rth_input;
	struct fnhe_hash_bucket___12 *nhc_exceptions;
};

struct fib6_nh___12 {
	struct fib_nh_common___12 nh_common;
	long unsigned int last_probe;
	struct rt6_info___12 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___12;

struct nexthop___7;

struct fib6_info___12 {
	struct fib6_table___12 *fib6_table;
	struct fib6_info___12 *fib6_next;
	struct fib6_node___12 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___7 *nh;
	struct fib6_nh___12 fib6_nh[0];
};

struct rt6_info___12 {
	struct dst_entry___59 dst;
	struct fib6_info___12 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___42 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___12 {
	struct fib6_node___12 *parent;
	struct fib6_node___12 *left;
	struct fib6_node___12 *right;
	struct fib6_node___12 *subtree;
	struct fib6_info___12 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___12 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___12 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___12 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___6;

typedef unsigned int nf_hookfn___6(void *, struct sk_buff___73 *, const struct nf_hook_state___6 *);

struct nf_hook_entry___6 {
	nf_hookfn___6 *hook;
	void *priv;
};

struct nf_hook_entries___6 {
	u16 num_hook_entries;
	struct nf_hook_entry___6 hooks[0];
};

union bpf_attr___3 {
	struct {
		__u32 map_type;
		__u32 key_size;
		__u32 value_size;
		__u32 max_entries;
		__u32 map_flags;
		__u32 inner_map_fd;
		__u32 numa_node;
		char map_name[16];
		__u32 map_ifindex;
		__u32 btf_fd;
		__u32 btf_key_type_id;
		__u32 btf_value_type_id;
		__u32 btf_vmlinux_value_type_id;
	};
	struct {
		__u32 map_fd;
		__u64 key;
		union {
			__u64 value;
			__u64 next_key;
		};
		__u64 flags;
	};
	struct {
		__u64 in_batch;
		__u64 out_batch;
		__u64 keys;
		__u64 values;
		__u32 count;
		__u32 map_fd;
		__u64 elem_flags;
		__u64 flags;
	} batch;
	struct {
		__u32 prog_type;
		__u32 insn_cnt;
		__u64 insns;
		__u64 license;
		__u32 log_level;
		__u32 log_size;
		__u64 log_buf;
		__u32 kern_version;
		__u32 prog_flags;
		char prog_name[16];
		__u32 prog_ifindex;
		__u32 expected_attach_type;
		__u32 prog_btf_fd;
		__u32 func_info_rec_size;
		__u64 func_info;
		__u32 func_info_cnt;
		__u32 line_info_rec_size;
		__u64 line_info;
		__u32 line_info_cnt;
		__u32 attach_btf_id;
		union {
			__u32 attach_prog_fd;
			__u32 attach_btf_obj_fd;
		};
		long: 64;
		__u64 fd_array;
	};
	struct {
		__u64 pathname;
		__u32 bpf_fd;
		__u32 file_flags;
	};
	struct {
		__u32 target_fd;
		__u32 attach_bpf_fd;
		__u32 attach_type;
		__u32 attach_flags;
		__u32 replace_bpf_fd;
	};
	struct {
		__u32 prog_fd;
		__u32 retval;
		__u32 data_size_in;
		__u32 data_size_out;
		__u64 data_in;
		__u64 data_out;
		__u32 repeat;
		__u32 duration;
		__u32 ctx_size_in;
		__u32 ctx_size_out;
		__u64 ctx_in;
		__u64 ctx_out;
		__u32 flags;
		__u32 cpu;
	} test;
	struct {
		union {
			__u32 start_id;
			__u32 prog_id;
			__u32 map_id;
			__u32 btf_id;
			__u32 link_id;
		};
		int: 32;
		__u32 next_id;
		__u32 open_flags;
	};
	struct {
		__u32 bpf_fd;
		__u32 info_len;
		__u64 info;
	} info;
	struct {
		__u32 target_fd;
		__u32 attach_type;
		__u32 query_flags;
		__u32 attach_flags;
		__u64 prog_ids;
		__u32 prog_cnt;
	} query;
	struct {
		__u64 name;
		__u32 prog_fd;
	} raw_tracepoint;
	struct {
		__u64 btf;
		__u64 btf_log_buf;
		__u32 btf_size;
		__u32 btf_log_size;
		__u32 btf_log_level;
	};
	struct {
		__u32 pid;
		__u32 fd;
		__u32 flags;
		__u32 buf_len;
		__u64 buf;
		__u32 prog_id;
		__u32 fd_type;
		__u64 probe_offset;
		__u64 probe_addr;
	} task_fd_query;
	struct {
		__u32 prog_fd;
		union {
			__u32 target_fd;
			__u32 target_ifindex;
		};
		int: 32;
		__u32 attach_type;
		__u32 flags;
		union {
			__u32 target_btf_id;
			struct {
				__u64 iter_info;
				__u32 iter_info_len;
			};
			struct {
				__u64 bpf_cookie;
			} perf_event;
		};
	} link_create;
	struct {
		__u32 link_fd;
		__u32 new_prog_fd;
		__u32 flags;
		__u32 old_prog_fd;
	} link_update;
	struct {
		__u32 link_fd;
	} link_detach;
	struct {
		__u32 type;
	} enable_stats;
	struct {
		__u32 link_fd;
		__u32 flags;
	} iter_create;
	struct {
		__u32 prog_fd;
		__u32 map_fd;
		__u32 flags;
	} prog_bind_map;
};

struct bpf_prog_array_item___66 {
	struct bpf_prog___66 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___66 {
	struct callback_head rcu;
	struct bpf_prog_array_item___66 items[0];
};

struct bpf_prog_stats___2;

struct bpf_prog_aux___75;

struct bpf_prog___66 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats___2 *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___75 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___238 {
	void * (*start)(struct seq_file___238 *, loff_t *);
	void (*stop)(struct seq_file___238 *, void *);
	void * (*next)(struct seq_file___238 *, void *, loff_t *);
	int (*show)(struct seq_file___238 *, void *);
};

struct pernet_operations___17 {
	struct list_head list;
	int (*init)(struct net___77 *);
	void (*pre_exit)(struct net___77 *);
	void (*exit)(struct net___77 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___72 {
	int (*ieee_getets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___72 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___72 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___72 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___72 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___72 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___72 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___72 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___72 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___72 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___72 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___72 *);
	u8 (*setstate)(struct net_device___72 *, u8);
	void (*getpermhwaddr)(struct net_device___72 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___72 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___72 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___72 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___72 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___72 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___72 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___72 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___72 *, int, u8 *);
	void (*setpfccfg)(struct net_device___72 *, int, u8);
	void (*getpfccfg)(struct net_device___72 *, int, u8 *);
	u8 (*setall)(struct net_device___72 *);
	u8 (*getcap)(struct net_device___72 *, int, u8 *);
	int (*getnumtcs)(struct net_device___72 *, int, u8 *);
	int (*setnumtcs)(struct net_device___72 *, int, u8);
	u8 (*getpfcstate)(struct net_device___72 *);
	void (*setpfcstate)(struct net_device___72 *, u8);
	void (*getbcncfg)(struct net_device___72 *, int, u32 *);
	void (*setbcncfg)(struct net_device___72 *, int, u32);
	void (*getbcnrp)(struct net_device___72 *, int, u8 *);
	void (*setbcnrp)(struct net_device___72 *, int, u8);
	int (*setapp)(struct net_device___72 *, u8, u16, u8);
	int (*getapp)(struct net_device___72 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___72 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___72 *, int, u8);
	u8 (*getdcbx)(struct net_device___72 *);
	u8 (*setdcbx)(struct net_device___72 *, u8);
	int (*peer_getappinfo)(struct net_device___72 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___72 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___72 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___72 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___72 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___72 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___75;

typedef int (*bpf_iter_init_seq_priv_t___74)(void *, struct bpf_iter_aux_info___75 *);

struct bpf_map___75;

struct bpf_iter_aux_info___75 {
	struct bpf_map___75 *map;
};

struct bpf_iter_seq_info___74 {
	const struct seq_operations___238 *seq_ops;
	bpf_iter_init_seq_priv_t___74 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___74 {
	int (*map_alloc_check)(union bpf_attr___3 *);
	struct bpf_map___75 * (*map_alloc)(union bpf_attr___3 *);
	void (*map_release)(struct bpf_map___75 *, struct file___263 *);
	void (*map_free)(struct bpf_map___75 *);
	int (*map_get_next_key)(struct bpf_map___75 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___75 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___75 *, void *);
	int (*map_lookup_batch)(struct bpf_map___75 *, const union bpf_attr___3 *, union bpf_attr___3 *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___75 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___75 *, const union bpf_attr___3 *, union bpf_attr___3 *);
	int (*map_update_batch)(struct bpf_map___75 *, const union bpf_attr___3 *, union bpf_attr___3 *);
	int (*map_delete_batch)(struct bpf_map___75 *, const union bpf_attr___3 *, union bpf_attr___3 *);
	void * (*map_lookup_elem)(struct bpf_map___75 *, void *);
	int (*map_update_elem)(struct bpf_map___75 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___75 *, void *);
	int (*map_push_elem)(struct bpf_map___75 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___75 *, void *);
	int (*map_peek_elem)(struct bpf_map___75 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___75 *, struct file___263 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___75 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___75 *, void *, struct seq_file___238 *);
	int (*map_check_btf)(const struct bpf_map___75 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___75 *, struct bpf_prog_aux___75 *);
	void (*map_poke_untrack)(struct bpf_map___75 *, struct bpf_prog_aux___75 *);
	void (*map_poke_run)(struct bpf_map___75 *, u32, struct bpf_prog___66 *, struct bpf_prog___66 *);
	int (*map_direct_value_addr)(const struct bpf_map___75 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___75 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___75 *, struct vm_area_struct___268 *);
	__poll_t (*map_poll)(struct bpf_map___75 *, struct file___263 *, struct poll_table_struct___184 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___75 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___75 *, const struct bpf_map___75 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___75 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___74 *iter_seq_info;
};

struct bpf_map___75 {
	const struct bpf_map_ops___74 *ops;
	struct bpf_map___75 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___128 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___74;

struct bpf_jit_poke_descriptor___74;

struct bpf_prog_ops___66;

struct btf_mod_pair___74;

struct bpf_prog_offload___72;

struct bpf_prog_aux___75 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___66 *dst_prog;
	struct bpf_trampoline___74 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___66 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___74 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___66 *ops;
	struct bpf_map___75 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___74 *used_btfs;
	struct bpf_prog___66 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___75 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___72 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___72;

struct bpf_map_dev_ops___72 {
	int (*map_get_next_key)(struct bpf_offloaded_map___72 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___72 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___72 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___72 *, void *);
};

struct bpf_offloaded_map___72 {
	struct bpf_map___75 map;
	struct net_device___72 *netdev;
	const struct bpf_map_dev_ops___72 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___66 {
	int (*test_run)(struct bpf_prog___66 *, const union bpf_attr___3 *, union bpf_attr___3 *);
};

struct bpf_prog_offload___72 {
	struct bpf_prog___66 *prog;
	struct net_device___72 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___74 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___66 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___247 *mod;
};

struct bpf_jit_poke_descriptor___74 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___75 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___74 {
	struct btf *btf;
	struct module___247 *module;
};

struct cftype___190;

struct cgroup_subsys___190 {
	struct cgroup_subsys_state___190 * (*css_alloc)(struct cgroup_subsys_state___190 *);
	int (*css_online)(struct cgroup_subsys_state___190 *);
	void (*css_offline)(struct cgroup_subsys_state___190 *);
	void (*css_released)(struct cgroup_subsys_state___190 *);
	void (*css_free)(struct cgroup_subsys_state___190 *);
	void (*css_reset)(struct cgroup_subsys_state___190 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___190 *, int);
	int (*css_extra_stat_show)(struct seq_file___238 *, struct cgroup_subsys_state___190 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___270 *, struct css_set___190 *);
	void (*cancel_fork)(struct task_struct___270 *, struct css_set___190 *);
	void (*fork)(struct task_struct___270 *);
	void (*exit)(struct task_struct___270 *);
	void (*release)(struct task_struct___270 *);
	void (*bind)(struct cgroup_subsys_state___190 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___190 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___190 *dfl_cftypes;
	struct cftype___190 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___190 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___190 *updated_children;
	struct cgroup___190 *updated_next;
};

struct cgroup_root___190 {
	struct kernfs_root___251 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___190 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___190 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___190 *ss;
	struct list_head node;
	struct kernfs_ops___251 *kf_ops;
	int (*open)(struct kernfs_open_file___251 *);
	void (*release)(struct kernfs_open_file___251 *);
	u64 (*read_u64)(struct cgroup_subsys_state___190 *, struct cftype___190 *);
	s64 (*read_s64)(struct cgroup_subsys_state___190 *, struct cftype___190 *);
	int (*seq_show)(struct seq_file___238 *, void *);
	void * (*seq_start)(struct seq_file___238 *, loff_t *);
	void * (*seq_next)(struct seq_file___238 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___238 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___190 *, struct cftype___190 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___190 *, struct cftype___190 *, s64);
	ssize_t (*write)(struct kernfs_open_file___251 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___251 *, struct poll_table_struct___184 *);
};

struct xdp_rxq_info___72 {
	struct net_device___72 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___72 {
	struct net_device___72 *dev;
};

struct xdp_buff___72 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___72 *rxq;
	struct xdp_txq_info___72 *txq;
	u32 frame_sz;
};

struct xdp_frame___72 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___72 *dev_rx;
};

struct netlink_skb_parms___11 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___59 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___72 {
	struct sk_buff___73 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___73 *, struct netlink_callback___72 *);
	int (*done)(struct netlink_callback___72 *);
	void *data;
	struct module___247 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum {
	TCA_ACT_UNSPEC = 0,
	TCA_ACT_KIND = 1,
	TCA_ACT_OPTIONS = 2,
	TCA_ACT_INDEX = 3,
	TCA_ACT_STATS = 4,
	TCA_ACT_PAD = 5,
	TCA_ACT_COOKIE = 6,
	TCA_ACT_FLAGS = 7,
	TCA_ACT_HW_STATS = 8,
	TCA_ACT_USED_HW_STATS = 9,
	__TCA_ACT_MAX = 10,
};

enum tca_id {
	TCA_ID_UNSPEC = 0,
	TCA_ID_POLICE = 1,
	TCA_ID_GACT = 5,
	TCA_ID_IPT = 6,
	TCA_ID_PEDIT = 7,
	TCA_ID_MIRRED = 8,
	TCA_ID_NAT = 9,
	TCA_ID_XT = 10,
	TCA_ID_SKBEDIT = 11,
	TCA_ID_VLAN = 12,
	TCA_ID_BPF = 13,
	TCA_ID_CONNMARK = 14,
	TCA_ID_SKBMOD = 15,
	TCA_ID_CSUM = 16,
	TCA_ID_TUNNEL_KEY = 17,
	TCA_ID_SIMP = 22,
	TCA_ID_IFE = 25,
	TCA_ID_SAMPLE = 26,
	TCA_ID_CTINFO = 27,
	TCA_ID_MPLS = 28,
	TCA_ID_CT = 29,
	TCA_ID_GATE = 30,
	__TCA_ID_MAX = 255,
};

struct tcf_t {
	__u64 install;
	__u64 lastuse;
	__u64 expires;
	__u64 firstuse;
};

struct header_ops___72 {
	int (*create)(struct sk_buff___73 *, struct net_device___72 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___73 *, unsigned char *);
	int (*cache)(const struct neighbour___59 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___72 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___73 *);
};

struct netdev_queue___72 {
	struct net_device___72 *dev;
	struct Qdisc___66 *qdisc;
	struct Qdisc___66 *qdisc_sleeping;
	struct kobject___251 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___72 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___66 {
	struct sk_buff___73 *head;
	struct sk_buff___73 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___66;

struct Qdisc___66 {
	int (*enqueue)(struct sk_buff___73 *, struct Qdisc___66 *, struct sk_buff___73 **);
	struct sk_buff___73 * (*dequeue)(struct Qdisc___66 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___66 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___72 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___72 gso_skb;
	struct qdisc_skb_head___66 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___66 *next_sched;
	struct sk_buff_head___72 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___72 {
	struct xdp_rxq_info___72 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___251 kobj;
	struct net_device___72 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___72 {
	enum net_device_path_type type;
	const struct net_device___72 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___72 = 0,
				DEV_PATH_BR_VLAN_TAG___72 = 1,
				DEV_PATH_BR_VLAN_UNTAG___72 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___72 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___72 {
	const struct net_device___72 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___72 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___66 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___72 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___72 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___73 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___72 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___72 *dev;
	const char *name;
};

struct net_device_ops___72 {
	int (*ndo_init)(struct net_device___72 *);
	void (*ndo_uninit)(struct net_device___72 *);
	int (*ndo_open)(struct net_device___72 *);
	int (*ndo_stop)(struct net_device___72 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___73 *, struct net_device___72 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___73 *, struct net_device___72 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___72 *, struct sk_buff___73 *, struct net_device___72 *);
	void (*ndo_change_rx_flags)(struct net_device___72 *, int);
	void (*ndo_set_rx_mode)(struct net_device___72 *);
	int (*ndo_set_mac_address)(struct net_device___72 *, void *);
	int (*ndo_validate_addr)(struct net_device___72 *);
	int (*ndo_do_ioctl)(struct net_device___72 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___72 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___72 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___72 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___72 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___72 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___72 *, int);
	int (*ndo_neigh_setup)(struct net_device___72 *, struct neigh_parms___59 *);
	void (*ndo_tx_timeout)(struct net_device___72 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___72 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___72 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___72 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___72 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___72 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___72 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___72 *);
	int (*ndo_netpoll_setup)(struct net_device___72 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___72 *);
	int (*ndo_set_vf_mac)(struct net_device___72 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___72 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___72 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___72 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___72 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___72 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___72 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___72 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___72 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___72 *, int, struct sk_buff___73 *);
	int (*ndo_get_vf_guid)(struct net_device___72 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___72 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___72 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___72 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___72 *);
	int (*ndo_fcoe_disable)(struct net_device___72 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___72 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___72 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___72 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___72 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___72 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___72 *, const struct sk_buff___73 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___72 *, struct net_device___72 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___72 *, struct net_device___72 *);
	struct net_device___72 * (*ndo_get_xmit_slave)(struct net_device___72 *, struct sk_buff___73 *, bool);
	struct net_device___72 * (*ndo_sk_get_lower_dev)(struct net_device___72 *, struct sock___59 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___72 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___72 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___72 *, struct neighbour___59 *);
	void (*ndo_neigh_destroy)(struct net_device___72 *, struct neighbour___59 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___73 *, struct netlink_callback___72 *, struct net_device___72 *, struct net_device___72 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___73 *, struct nlattr **, struct net_device___72 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___72 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___73 *, u32, u32, struct net_device___72 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___72 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___72 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___72 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___72 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___72 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___72 *, struct net_device___72 *);
	void (*ndo_dfwd_del_station)(struct net_device___72 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___72 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___72 *);
	int (*ndo_change_proto_down)(struct net_device___72 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___72 *, struct sk_buff___73 *);
	void (*ndo_set_rx_headroom)(struct net_device___72 *, int);
	int (*ndo_bpf)(struct net_device___72 *, struct netdev_bpf___72 *);
	int (*ndo_xdp_xmit)(struct net_device___72 *, int, struct xdp_frame___72 **, u32);
	struct net_device___72 * (*ndo_xdp_get_xmit_slave)(struct net_device___72 *, struct xdp_buff___72 *);
	int (*ndo_xsk_wakeup)(struct net_device___72 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___72 *);
	int (*ndo_tunnel_ctl)(struct net_device___72 *, struct ip_tunnel_parm *, int);
	struct net_device___72 * (*ndo_get_peer_dev)(struct net_device___72 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___72 *, struct net_device_path___72 *);
};

struct neigh_parms___59 {
	possible_net_t___72 net;
	struct net_device___72 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___59 *);
	struct neigh_table___59 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___59 {
	u32 (*l3mdev_fib_table)(const struct net_device___72 *);
	struct sk_buff___73 * (*l3mdev_l3_rcv)(struct net_device___72 *, struct sk_buff___73 *, u16);
	struct sk_buff___73 * (*l3mdev_l3_out)(struct net_device___72 *, struct sock___59 *, struct sk_buff___73 *, u16);
	struct dst_entry___59 * (*l3mdev_link_scope_lookup)(const struct net_device___72 *, struct flowi6 *);
};

struct ndisc_ops___42 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___72 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___72 *, struct neighbour___59 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___72 *, u8, struct neighbour___59 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___72 *, struct sk_buff___73 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___77 *, struct net_device___72 *, const struct prefix_info *, struct inet6_dev___42 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___42;

struct ifacaddr6___12;

struct inet6_dev___42 {
	struct net_device___72 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___42 *mc_list;
	struct ifmcaddr6___42 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___72 mc_query_queue;
	struct sk_buff_head___72 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___12 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___59 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___66;

struct tcf_block___66;

struct mini_Qdisc___66 {
	struct tcf_proto___66 *filter_list;
	struct tcf_block___66 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___66 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___72 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___72 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___77 *, struct net_device___72 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___72 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___72 *, struct list_head *);
	size_t (*get_size)(const struct net_device___72 *);
	int (*fill_info)(struct sk_buff___73 *, const struct net_device___72 *);
	size_t (*get_xstats_size)(const struct net_device___72 *);
	int (*fill_xstats)(struct sk_buff___73 *, const struct net_device___72 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___72 *, struct net_device___72 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___72 *, const struct net_device___72 *);
	int (*fill_slave_info)(struct sk_buff___73 *, const struct net_device___72 *, const struct net_device___72 *);
	struct net___77 * (*get_link_net)(const struct net_device___72 *);
	size_t (*get_linkxstats_size)(const struct net_device___72 *, int);
	int (*fill_linkxstats)(struct sk_buff___73 *, const struct net_device___72 *, int *, int);
};

struct block_device_operations___154;

struct gendisk___157 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___157 *part0;
	const struct block_device_operations___154 *fops;
	struct request_queue___154 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___140 *bdi;
	struct kobject___251 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___251 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___154 {
	struct bio___154 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___180 *bip_vec;
	struct bio_vec___180 bip_inline_vecs[0];
};

struct blkcg___142;

struct blkg_policy_data___142;

struct blkcg_gq___142 {
	struct request_queue___154 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___142 *blkcg;
	struct blkcg_gq___142 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___142 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___154 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___154(struct request___154 *);

typedef void integrity_complete_fn___154(struct request___154 *, unsigned int);

struct blk_integrity_profile___154 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___154 *prepare_fn;
	integrity_complete_fn___154 *complete_fn;
	const char *name;
};

struct block_device_operations___154 {
	blk_qc_t (*submit_bio)(struct bio___154 *);
	int (*open)(struct block_device___157 *, fmode_t);
	void (*release)(struct gendisk___157 *, fmode_t);
	int (*rw_page)(struct block_device___157 *, sector_t, struct page___268 *, unsigned int);
	int (*ioctl)(struct block_device___157 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___157 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___157 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___157 *);
	int (*getgeo)(struct block_device___157 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___157 *, bool);
	void (*swap_slot_free_notify)(struct block_device___157 *, long unsigned int);
	int (*report_zones)(struct gendisk___157 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___157 *, umode_t *);
	struct module___247 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___157 *, sector_t *);
};

typedef void rq_end_io_fn___154(struct request___154 *, blk_status_t);

struct request___154 {
	struct request_queue___154 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___149 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___154 *bio;
	struct bio___154 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___180 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___154 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___154 *saved_end_io;
		} flush;
	};
	struct gendisk___157 *rq_disk;
	struct block_device___157 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___154 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___149 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___154 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___251 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___263 *debugfs_dir;
	struct dentry___263 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___154;

struct elevator_mq_ops___154 {
	int (*init_sched)(struct request_queue___154 *, struct elevator_type___154 *);
	void (*exit_sched)(struct elevator_queue___154 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___149 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___149 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___149 *);
	bool (*allow_merge)(struct request_queue___154 *, struct request___154 *, struct bio___154 *);
	bool (*bio_merge)(struct request_queue___154 *, struct bio___154 *, unsigned int);
	int (*request_merge)(struct request_queue___154 *, struct request___154 **, struct bio___154 *);
	void (*request_merged)(struct request_queue___154 *, struct request___154 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___154 *, struct request___154 *, struct request___154 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___154 *);
	void (*finish_request)(struct request___154 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___149 *, struct list_head *, bool);
	struct request___154 * (*dispatch_request)(struct blk_mq_hw_ctx___149 *);
	bool (*has_work)(struct blk_mq_hw_ctx___149 *);
	void (*completed_request)(struct request___154 *, u64);
	void (*requeue_request)(struct request___154 *);
	struct request___154 * (*former_request)(struct request_queue___154 *, struct request___154 *);
	struct request___154 * (*next_request)(struct request_queue___154 *, struct request___154 *);
	void (*init_icq)(struct io_cq___154 *);
	void (*exit_icq)(struct io_cq___154 *);
};

struct elv_fs_entry___154;

struct elevator_type___154 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___154 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___154 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___247 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___154 {
	struct elevator_type___154 *type;
	void *elevator_data;
	struct kobject___251 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___154 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___154 *, char *);
	ssize_t (*store)(struct elevator_queue___154 *, const char *, size_t);
};

struct blk_mq_queue_data___149;

struct blk_mq_ops___149 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___149 *, const struct blk_mq_queue_data___149 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___149 *);
	int (*get_budget)(struct request_queue___154 *);
	void (*put_budget)(struct request_queue___154 *, int);
	void (*set_rq_budget_token)(struct request___154 *, int);
	int (*get_rq_budget_token)(struct request___154 *);
	enum blk_eh_timer_return (*timeout)(struct request___154 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___149 *);
	void (*complete)(struct request___154 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___149 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___149 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___149 *, struct request___154 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___149 *, struct request___154 *, unsigned int);
	void (*initialize_rq_fn)(struct request___154 *);
	void (*cleanup_rq)(struct request___154 *);
	bool (*busy)(struct request_queue___154 *);
	int (*map_queues)(struct blk_mq_tag_set___149 *);
	void (*show_rq)(struct seq_file___238 *, struct request___154 *);
};

struct blk_mq_tag_set___149 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___149 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___149 {
	struct request___154 *rq;
	bool last;
};

struct blkcg_policy_data___142;

struct blkcg___142 {
	struct cgroup_subsys_state___190 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___142 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___142 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___142 {
	struct blkcg___142 *blkcg;
	int plid;
};

struct blkg_policy_data___142 {
	struct blkcg_gq___142 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___128 {
	struct mem_cgroup___128 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___128 {
	struct lruvec___136 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___128 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___128 *memcg;
};

struct obj_cgroup___128 {
	struct percpu_ref refcnt;
	struct mem_cgroup___128 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___66 {
	spinlock_t *lock;
	struct sk_buff___73 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

typedef int (*rtnl_doit_func___6)(struct sk_buff___73 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___6)(struct sk_buff___73 *, struct netlink_callback___72 *);

struct psample_group {
	struct list_head list;
	struct net___77 *net;
	u32 group_num;
	u32 refcount;
	u32 seq;
	struct callback_head rcu;
};

struct action_gate_entry {
	u8 gate_state;
	u32 interval;
	s32 ipv;
	s32 maxoctets;
};

struct flow_action_entry___6 {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___72 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info___2 *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action___6 {
	unsigned int num_entries;
	struct flow_action_entry___6 entries[0];
};

struct flow_block_offload___2 {
	enum flow_block_command command;
	enum flow_block_binder_type binder_type;
	bool block_shared;
	bool unlocked_driver_cb;
	struct net___77 *net;
	struct flow_block *block;
	struct list_head cb_list;
	struct list_head *driver_block_list;
	struct netlink_ext_ack *extack;
	struct Qdisc___66 *sch;
	struct list_head *cb_list_head;
};

struct flow_block_cb___2;

struct flow_block_indr___2 {
	struct list_head list;
	struct net_device___72 *dev;
	struct Qdisc___66 *sch;
	enum flow_block_binder_type binder_type;
	void *data;
	void *cb_priv;
	void (*cleanup)(struct flow_block_cb___2 *);
};

struct flow_block_cb___2 {
	struct list_head driver_list;
	struct list_head list;
	flow_setup_cb_t *cb;
	void *cb_ident;
	void *cb_priv;
	void (*release)(void *);
	struct flow_block_indr___2 indr;
	unsigned int refcnt;
};

struct Qdisc_class_ops___66;

struct Qdisc_ops___66 {
	struct Qdisc_ops___66 *next;
	const struct Qdisc_class_ops___66 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___73 *, struct Qdisc___66 *, struct sk_buff___73 **);
	struct sk_buff___73 * (*dequeue)(struct Qdisc___66 *);
	struct sk_buff___73 * (*peek)(struct Qdisc___66 *);
	int (*init)(struct Qdisc___66 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___66 *);
	void (*destroy)(struct Qdisc___66 *);
	int (*change)(struct Qdisc___66 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___66 *);
	int (*change_tx_queue_len)(struct Qdisc___66 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___66 *, unsigned int);
	int (*dump)(struct Qdisc___66 *, struct sk_buff___73 *);
	int (*dump_stats)(struct Qdisc___66 *, struct gnet_dump___66 *);
	void (*ingress_block_set)(struct Qdisc___66 *, u32);
	void (*egress_block_set)(struct Qdisc___66 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___66 *);
	u32 (*egress_block_get)(struct Qdisc___66 *);
	struct module___247 *owner;
};

struct qdisc_walker___9;

struct Qdisc_class_ops___66 {
	unsigned int flags;
	struct netdev_queue___72 * (*select_queue)(struct Qdisc___66 *, struct tcmsg *);
	int (*graft)(struct Qdisc___66 *, long unsigned int, struct Qdisc___66 *, struct Qdisc___66 **, struct netlink_ext_ack *);
	struct Qdisc___66 * (*leaf)(struct Qdisc___66 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___66 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___66 *, u32);
	int (*change)(struct Qdisc___66 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___66 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___66 *, struct qdisc_walker___9 *);
	struct tcf_block___66 * (*tcf_block)(struct Qdisc___66 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___66 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___66 *, long unsigned int);
	int (*dump)(struct Qdisc___66 *, long unsigned int, struct sk_buff___73 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___66 *, long unsigned int, struct gnet_dump___66 *);
};

struct qdisc_walker___9 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___66 *, long unsigned int, struct qdisc_walker___9 *);
};

struct tcf_chain___66;

struct tcf_block___66 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___77 *net;
	struct Qdisc___66 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___66 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

enum qdisc_class_ops_flags {
	QDISC_CLASS_OPS_DOIT_UNLOCKED = 1,
};

struct tcf_result___66;

struct tcf_proto_ops___66;

struct tcf_proto___66 {
	struct tcf_proto___66 *next;
	void *root;
	int (*classify)(struct sk_buff___73 *, const struct tcf_proto___66 *, struct tcf_result___66 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___66 *ops;
	struct tcf_chain___66 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___66 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___66 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_walker___4;

struct tcf_proto_ops___66 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___73 *, const struct tcf_proto___66 *, struct tcf_result___66 *);
	int (*init)(struct tcf_proto___66 *);
	void (*destroy)(struct tcf_proto___66 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___66 *, u32);
	void (*put)(struct tcf_proto___66 *, void *);
	int (*change)(struct net___77 *, struct sk_buff___73 *, struct tcf_proto___66 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___66 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___66 *);
	void (*walk)(struct tcf_proto___66 *, struct tcf_walker___4 *, bool);
	int (*reoffload)(struct tcf_proto___66 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___66 *, void *);
	void (*hw_del)(struct tcf_proto___66 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___77 *, struct tcf_chain___66 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___77 *, struct tcf_proto___66 *, void *, struct sk_buff___73 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___77 *, struct tcf_proto___66 *, void *, struct sk_buff___73 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___73 *, struct net___77 *, void *);
	struct module___247 *owner;
	int flags;
};

struct tcf_walker___4 {
	int stop;
	int skip;
	int count;
	bool nonempty;
	long unsigned int cookie;
	int (*fn)(struct tcf_proto___66 *, void *, struct tcf_walker___4 *);
};

struct tcf_chain___66 {
	struct mutex filter_chain_lock;
	struct tcf_proto___66 *filter_chain;
	struct list_head list;
	struct tcf_block___66 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___66 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

enum tcf_proto_ops_flags {
	TCF_PROTO_OPS_DOIT_UNLOCKED = 1,
};

typedef void tcf_chain_head_change_t(struct tcf_proto___66 *, void *);

struct bpf_prog_stats___2 {
	u64_stats_t cnt;
	u64_stats_t nsecs;
	u64_stats_t misses;
	struct u64_stats_sync syncp;
};

struct sk_filter___59 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___66 *prog;
};

struct pneigh_entry___59;

struct neigh_hash_table___59;

struct neigh_table___59 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___72 *, __u32 *);
	bool (*key_eq)(const struct neighbour___59 *, const void *);
	int (*constructor)(struct neighbour___59 *);
	int (*pconstructor)(struct pneigh_entry___59 *);
	void (*pdestructor)(struct pneigh_entry___59 *);
	void (*proxy_redo)(struct sk_buff___73 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___72 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___59 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___72 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___59 *nht;
	struct pneigh_entry___59 **phash_buckets;
};

struct neigh_ops___59 {
	int family;
	void (*solicit)(struct neighbour___59 *, struct sk_buff___73 *);
	void (*error_report)(struct neighbour___59 *, struct sk_buff___73 *);
	int (*output)(struct neighbour___59 *, struct sk_buff___73 *);
	int (*connected_output)(struct neighbour___59 *, struct sk_buff___73 *);
};

struct pneigh_entry___59 {
	struct pneigh_entry___59 *next;
	possible_net_t___72 net;
	struct net_device___72 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___59 {
	struct neighbour___59 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___36 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___77 *, struct sock___59 *, struct sk_buff___73 *);
	int (*orig_input)(struct sk_buff___73 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___59 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___59 *ctarget;
	struct net___77 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___59 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___59 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___45;

struct timewait_sock_ops___44;

struct proto___59 {
	void (*close)(struct sock___59 *, long int);
	int (*pre_connect)(struct sock___59 *, struct sockaddr *, int);
	int (*connect)(struct sock___59 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___59 *, int);
	struct sock___59 * (*accept)(struct sock___59 *, int, int *, bool);
	int (*ioctl)(struct sock___59 *, int, long unsigned int);
	int (*init)(struct sock___59 *);
	void (*destroy)(struct sock___59 *);
	void (*shutdown)(struct sock___59 *, int);
	int (*setsockopt)(struct sock___59 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___59 *, int, int, char *, int *);
	void (*keepalive)(struct sock___59 *, int);
	int (*compat_ioctl)(struct sock___59 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___59 *, struct msghdr___61 *, size_t);
	int (*recvmsg)(struct sock___59 *, struct msghdr___61 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___59 *, struct page___268 *, int, size_t, int);
	int (*bind)(struct sock___59 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___59 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___59 *, struct sk_buff___73 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___59 *);
	int (*hash)(struct sock___59 *);
	void (*unhash)(struct sock___59 *);
	void (*rehash)(struct sock___59 *);
	int (*get_port)(struct sock___59 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___59 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___59 *, int);
	bool (*sock_is_readable)(struct sock___59 *);
	void (*enter_memory_pressure)(struct sock___59 *);
	void (*leave_memory_pressure)(struct sock___59 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___45 *rsk_prot;
	struct timewait_sock_ops___44 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___247 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___59 *, int);
};

struct request_sock___46;

struct request_sock_ops___45 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___59 *, struct request_sock___46 *);
	void (*send_ack)(const struct sock___59 *, struct sk_buff___73 *, struct request_sock___46 *);
	void (*send_reset)(const struct sock___59 *, struct sk_buff___73 *);
	void (*destructor)(struct request_sock___46 *);
	void (*syn_ack_timeout)(const struct request_sock___46 *);
};

struct timewait_sock_ops___44 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___59 *, struct sock___59 *, void *);
	void (*twsk_destructor)(struct sock___59 *);
};

struct tcf_idrinfo {
	struct mutex lock;
	struct idr action_idr;
	struct net___77 *net;
};

struct tc_action_ops;

struct tc_cookie;

struct tc_action {
	const struct tc_action_ops *ops;
	__u32 type;
	struct tcf_idrinfo *idrinfo;
	u32 tcfa_index;
	refcount_t tcfa_refcnt;
	atomic_t tcfa_bindcnt;
	int tcfa_action;
	struct tcf_t tcfa_tm;
	struct gnet_stats_basic_packed tcfa_bstats;
	struct gnet_stats_basic_packed tcfa_bstats_hw;
	struct gnet_stats_queue tcfa_qstats;
	struct net_rate_estimator *tcfa_rate_est;
	spinlock_t tcfa_lock;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_basic_cpu *cpu_bstats_hw;
	struct gnet_stats_queue *cpu_qstats;
	struct tc_cookie *act_cookie;
	struct tcf_chain___66 *goto_chain;
	u32 tcfa_flags;
	u8 hw_stats;
	u8 used_hw_stats;
	bool used_hw_stats_valid;
};

typedef void (*tc_action_priv_destructor)(void *);

struct tc_action_ops {
	struct list_head head;
	char kind[16];
	enum tca_id id;
	size_t size;
	struct module___247 *owner;
	int (*act)(struct sk_buff___73 *, const struct tc_action *, struct tcf_result___66 *);
	int (*dump)(struct sk_buff___73 *, struct tc_action *, int, int);
	void (*cleanup)(struct tc_action *);
	int (*lookup)(struct net___77 *, struct tc_action **, u32);
	int (*init)(struct net___77 *, struct nlattr *, struct nlattr *, struct tc_action **, struct tcf_proto___66 *, u32, struct netlink_ext_ack *);
	int (*walk)(struct net___77 *, struct sk_buff___73 *, struct netlink_callback___72 *, int, const struct tc_action_ops *, struct netlink_ext_ack *);
	void (*stats_update)(struct tc_action *, u64, u64, u64, u64, bool);
	size_t (*get_fill_size)(const struct tc_action *);
	struct net_device___72 * (*get_dev)(const struct tc_action *, tc_action_priv_destructor *);
	struct psample_group * (*get_psample_group)(const struct tc_action *, tc_action_priv_destructor *);
};

struct tc_cookie {
	u8 *data;
	u32 len;
	struct callback_head rcu;
};

struct tcf_block_ext_info {
	enum flow_block_binder_type binder_type;
	tcf_chain_head_change_t *chain_head_change;
	void *chain_head_change_priv;
	u32 block_index;
};

struct tcf_qevent {
	struct tcf_block___66 *block;
	struct tcf_block_ext_info info;
	struct tcf_proto___66 *filter_chain;
};

struct tcf_exts {
	__u32 type;
	int nr_actions;
	struct tc_action **actions;
	struct net___77 *net;
	int action;
	int police;
};

enum pedit_header_type {
	TCA_PEDIT_KEY_EX_HDR_TYPE_NETWORK = 0,
	TCA_PEDIT_KEY_EX_HDR_TYPE_ETH = 1,
	TCA_PEDIT_KEY_EX_HDR_TYPE_IP4 = 2,
	TCA_PEDIT_KEY_EX_HDR_TYPE_IP6 = 3,
	TCA_PEDIT_KEY_EX_HDR_TYPE_TCP = 4,
	TCA_PEDIT_KEY_EX_HDR_TYPE_UDP = 5,
	__PEDIT_HDR_TYPE_MAX = 6,
};

enum pedit_cmd {
	TCA_PEDIT_KEY_EX_CMD_SET = 0,
	TCA_PEDIT_KEY_EX_CMD_ADD = 1,
	__PEDIT_CMD_MAX = 2,
};

struct tc_pedit_key {
	__u32 mask;
	__u32 val;
	__u32 off;
	__u32 at;
	__u32 offmask;
	__u32 shift;
};

struct tcf_pedit_key_ex {
	enum pedit_header_type htype;
	enum pedit_cmd cmd;
};

struct tcf_pedit {
	struct tc_action common;
	unsigned char tcfp_nkeys;
	unsigned char tcfp_flags;
	struct tc_pedit_key *tcfp_keys;
	struct tcf_pedit_key_ex *tcfp_keys_ex;
};

struct tcf_mirred {
	struct tc_action common;
	int tcfm_eaction;
	bool tcfm_mac_header_xmit;
	struct net_device___72 *tcfm_dev;
	struct list_head tcfm_list;
};

struct tcf_vlan_params {
	int tcfv_action;
	unsigned char tcfv_push_dst[6];
	unsigned char tcfv_push_src[6];
	u16 tcfv_push_vid;
	__be16 tcfv_push_proto;
	u8 tcfv_push_prio;
	bool tcfv_push_prio_exists;
	struct callback_head rcu;
};

struct tcf_vlan {
	struct tc_action common;
	struct tcf_vlan_params *vlan_p;
};

struct request_sock___46 {
	struct sock_common___59 __req_common;
	struct request_sock___46 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___45 *rsk_ops;
	struct sock___59 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___42 {
	struct in6_addr mca_addr;
	struct inet6_dev___42 *idev;
	struct ifmcaddr6___42 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___12 {
	struct in6_addr aca_addr;
	struct fib6_info___12 *aca_rt;
	struct ifacaddr6___12 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___12 {
	struct fib_nh_exception___12 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___12 *fnhe_rth_input;
	struct rtable___12 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___12 {
	struct dst_entry___59 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___12 {
	struct fib_nh_exception___12 *chain;
};

struct fib_info___7;

struct fib_nh___7 {
	struct fib_nh_common___12 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___7 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___7 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___77 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___7 *nh;
	struct callback_head rcu;
	struct fib_nh___7 fib_nh[0];
};

struct nh_info___7;

struct nh_group___7;

struct nexthop___7 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___77 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___7 *nh_info;
		struct nh_group___7 *nh_grp;
	};
};

struct nh_info___7 {
	struct hlist_node dev_hash;
	struct nexthop___7 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___12 fib_nhc;
		struct fib_nh___7 fib_nh;
		struct fib6_nh___12 fib6_nh;
	};
};

struct nh_grp_entry___7;

struct nh_res_bucket___7 {
	struct nh_grp_entry___7 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___7 {
	struct nexthop___7 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___7 *nh_parent;
};

struct nh_res_table___7 {
	struct net___77 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___7 nh_buckets[0];
};

struct nh_group___7 {
	struct nh_group___7 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___7 *res_table;
	struct nh_grp_entry___7 nh_entries[0];
};

struct hw_port_info___5 {
	struct net_device___72 *lower_dev;
	u32 port_id;
};

struct metadata_dst___6 {
	struct dst_entry___59 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___5 port_info;
	} u;
};

struct tcf_tunnel_key_params {
	struct callback_head rcu;
	int tcft_action;
	struct metadata_dst___6 *tcft_enc_metadata;
};

struct tcf_tunnel_key {
	struct tc_action common;
	struct tcf_tunnel_key_params *params;
};

struct tcf_csum_params {
	u32 update_flags;
	struct callback_head rcu;
};

struct tcf_csum {
	struct tc_action common;
	struct tcf_csum_params *params;
};

struct tcf_gact {
	struct tc_action common;
	u16 tcfg_ptype;
	u16 tcfg_pval;
	int tcfg_paction;
	atomic_t packets;
};

struct tcf_police_params {
	int tcfp_result;
	u32 tcfp_ewma_rate;
	s64 tcfp_burst;
	u32 tcfp_mtu;
	s64 tcfp_mtu_ptoks;
	s64 tcfp_pkt_burst;
	struct psched_ratecfg rate;
	bool rate_present;
	struct psched_ratecfg peak;
	bool peak_present;
	struct psched_pktrate ppsrate;
	bool pps_present;
	struct callback_head rcu;
};

struct tcf_police {
	struct tc_action common;
	struct tcf_police_params *params;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	spinlock_t tcfp_lock;
	s64 tcfp_toks;
	s64 tcfp_ptoks;
	s64 tcfp_pkttoks;
	s64 tcfp_t_c;
	long: 64;
	long: 64;
	long: 64;
};

struct tcf_sample {
	struct tc_action common;
	u32 rate;
	bool truncate;
	u32 trunc_size;
	struct psample_group *psample_group;
	u32 psample_group_num;
	struct list_head tcfm_list;
};

struct tcf_skbedit_params {
	u32 flags;
	u32 priority;
	u32 mark;
	u32 mask;
	u16 queue_mapping;
	u16 ptype;
	struct callback_head rcu;
};

struct tcf_skbedit {
	struct tc_action common;
	struct tcf_skbedit_params *params;
};

struct nf_hook_state___6 {
	u8 hook;
	u8 pf;
	struct net_device___72 *in;
	struct net_device___72 *out;
	struct sock___59 *sk;
	struct net___77 *net;
	int (*okfn)(struct net___77 *, struct sock___59 *, struct sk_buff___73 *);
};

struct nf_conn___2 {
	struct nf_conntrack ct_general;
	spinlock_t lock;
	u32 timeout;
	struct nf_conntrack_zone zone;
	struct nf_conntrack_tuple_hash tuplehash[2];
	long unsigned int status;
	u16 cpu;
	possible_net_t___72 ct_net;
	struct hlist_node nat_bysource;
	struct {	} __nfct_init_offset;
	struct nf_conn___2 *master;
	u_int32_t mark;
	u_int32_t secmark;
	struct nf_ct_ext *ext;
	union nf_conntrack_proto proto;
};

struct nf_nat_range2 {
	unsigned int flags;
	union nf_inet_addr min_addr;
	union nf_inet_addr max_addr;
	union nf_conntrack_man_proto min_proto;
	union nf_conntrack_man_proto max_proto;
	union nf_conntrack_man_proto base_proto;
};

struct tcf_ct_flow_table;

struct tcf_ct_params {
	struct nf_conn___2 *tmpl;
	u16 zone;
	u32 mark;
	u32 mark_mask;
	u32 labels[4];
	u32 labels_mask[4];
	struct nf_nat_range2 range;
	bool ipv4_range;
	u16 ct_action;
	struct callback_head rcu;
	struct tcf_ct_flow_table *ct_ft;
	struct nf_flowtable *nf_ft;
};

struct tcf_ct {
	struct tc_action common;
	struct tcf_ct_params *params;
};

struct tcf_mpls_params {
	int tcfm_action;
	u32 tcfm_label;
	u8 tcfm_tc;
	u8 tcfm_ttl;
	u8 tcfm_bos;
	__be16 tcfm_proto;
	struct callback_head rcu;
};

struct tcf_mpls {
	struct tc_action common;
	struct tcf_mpls_params *mpls_p;
};

struct tcfg_gate_entry {
	int index;
	u8 gate_state;
	u32 interval;
	s32 ipv;
	s32 maxoctets;
	struct list_head list;
};

struct tcf_gate_params {
	s32 tcfg_priority;
	u64 tcfg_basetime;
	u64 tcfg_cycletime;
	u64 tcfg_cycletime_ext;
	u32 tcfg_flags;
	s32 tcfg_clockid;
	size_t num_entries;
	struct list_head entries;
};

struct tcf_gate {
	struct tc_action common;
	struct tcf_gate_params param;
	u8 current_gate_status;
	ktime_t current_close_time;
	u32 current_entry_octets;
	s32 current_max_octets;
	struct tcfg_gate_entry *next_entry;
	struct hrtimer hitimer;
	enum tk_offsets tk_offset;
};

struct tcf_filter_chain_list_item {
	struct list_head list;
	tcf_chain_head_change_t *chain_head_change;
	void *chain_head_change_priv;
};

struct tcf_net {
	spinlock_t idr_lock;
	struct idr idr;
};

struct tcf_block_owner_item {
	struct list_head list;
	struct Qdisc___66 *q;
	enum flow_block_binder_type binder_type;
};

struct tcf_chain_info {
	struct tcf_proto___66 **pprev;
	struct tcf_proto___66 *next;
};

struct tcf_dump_args {
	struct tcf_walker___4 w;
	struct sk_buff___73 *skb;
	struct netlink_callback___72 *cb;
	struct tcf_block___66 *block;
	struct Qdisc___66 *q;
	u32 parent;
	bool terse_dump;
};

struct pernet_operations___18 {
	struct list_head list;
	int (*init)(struct net___69 *);
	void (*pre_exit)(struct net___69 *);
	void (*exit)(struct net___69 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct netlink_skb_parms___12 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___51 *sk;
	bool nsid_is_set;
	int nsid;
};

struct tcamsg {
	unsigned char tca_family;
	unsigned char tca__pad1;
	short unsigned int tca__pad2;
};

enum {
	TCA_ROOT_UNSPEC = 0,
	TCA_ROOT_TAB = 1,
	TCA_ROOT_FLAGS = 2,
	TCA_ROOT_COUNT = 3,
	TCA_ROOT_TIME_DELTA = 4,
	__TCA_ROOT_MAX = 5,
};

typedef int (*rtnl_doit_func___7)(struct sk_buff___65 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___7)(struct sk_buff___65 *, struct netlink_callback___64 *);

struct tcf_idrinfo___2 {
	struct mutex lock;
	struct idr action_idr;
	struct net___69 *net;
};

struct tc_action_ops___2;

struct tc_action___2 {
	const struct tc_action_ops___2 *ops;
	__u32 type;
	struct tcf_idrinfo___2 *idrinfo;
	u32 tcfa_index;
	refcount_t tcfa_refcnt;
	atomic_t tcfa_bindcnt;
	int tcfa_action;
	struct tcf_t tcfa_tm;
	struct gnet_stats_basic_packed tcfa_bstats;
	struct gnet_stats_basic_packed tcfa_bstats_hw;
	struct gnet_stats_queue tcfa_qstats;
	struct net_rate_estimator *tcfa_rate_est;
	spinlock_t tcfa_lock;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_basic_cpu *cpu_bstats_hw;
	struct gnet_stats_queue *cpu_qstats;
	struct tc_cookie *act_cookie;
	struct tcf_chain___58 *goto_chain;
	u32 tcfa_flags;
	u8 hw_stats;
	u8 used_hw_stats;
	bool used_hw_stats_valid;
};

struct tc_action_ops___2 {
	struct list_head head;
	char kind[16];
	enum tca_id id;
	size_t size;
	struct module___239 *owner;
	int (*act)(struct sk_buff___65 *, const struct tc_action___2 *, struct tcf_result___58 *);
	int (*dump)(struct sk_buff___65 *, struct tc_action___2 *, int, int);
	void (*cleanup)(struct tc_action___2 *);
	int (*lookup)(struct net___69 *, struct tc_action___2 **, u32);
	int (*init)(struct net___69 *, struct nlattr *, struct nlattr *, struct tc_action___2 **, struct tcf_proto___58 *, u32, struct netlink_ext_ack *);
	int (*walk)(struct net___69 *, struct sk_buff___65 *, struct netlink_callback___64 *, int, const struct tc_action_ops___2 *, struct netlink_ext_ack *);
	void (*stats_update)(struct tc_action___2 *, u64, u64, u64, u64, bool);
	size_t (*get_fill_size)(const struct tc_action___2 *);
	struct net_device___64 * (*get_dev)(const struct tc_action___2 *, tc_action_priv_destructor *);
	struct psample_group * (*get_psample_group)(const struct tc_action___2 *, tc_action_priv_destructor *);
};

struct tc_action_net {
	struct tcf_idrinfo___2 *idrinfo;
	const struct tc_action_ops___2 *ops;
};

typedef struct bio_vec___172 skb_frag_t___20;

struct skb_shared_info___19 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___65 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___20 frags[17];
};

struct tc_fifo_qopt {
	__u32 limit;
};

enum tc_fifo_command {
	TC_FIFO_REPLACE = 0,
	TC_FIFO_DESTROY = 1,
	TC_FIFO_STATS = 2,
};

struct tc_fifo_qopt_offload {
	enum tc_fifo_command command;
	u32 handle;
	u32 parent;
	union {
		struct tc_qopt_offload_stats stats;
	};
};

struct tcf_ematch_tree_hdr {
	__u16 nmatches;
	__u16 progid;
};

enum {
	TCA_EMATCH_TREE_UNSPEC = 0,
	TCA_EMATCH_TREE_HDR = 1,
	TCA_EMATCH_TREE_LIST = 2,
	__TCA_EMATCH_TREE_MAX = 3,
};

struct tcf_ematch_hdr {
	__u16 matchid;
	__u16 kind;
	__u16 flags;
	__u16 pad;
};

struct tcf_pkt_info {
	unsigned char *ptr;
	int nexthdr;
};

struct tcf_ematch_ops;

struct tcf_ematch {
	struct tcf_ematch_ops *ops;
	long unsigned int data;
	unsigned int datalen;
	u16 matchid;
	u16 flags;
	struct net___69 *net;
};

struct tcf_ematch_ops {
	int kind;
	int datalen;
	int (*change)(struct net___69 *, void *, int, struct tcf_ematch *);
	int (*match)(struct sk_buff___65 *, struct tcf_ematch *, struct tcf_pkt_info *);
	void (*destroy)(struct tcf_ematch *);
	int (*dump)(struct sk_buff___65 *, struct tcf_ematch *);
	struct module___239 *owner;
	struct list_head link;
};

struct tcf_ematch_tree {
	struct tcf_ematch_tree_hdr hdr;
	struct tcf_ematch *matches;
};

struct net_proto_family___2 {
	int family;
	int (*create)(struct net___10 *, struct socket___6 *, int, int);
	struct module___57 *owner;
};

typedef struct bio_vec___30 skb_frag_t___21;

struct skb_shared_info___20 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___9 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___21 frags[17];
};

struct seq_net_private___4 {
	struct net___10 *net;
};

struct pernet_operations___19 {
	struct list_head list;
	int (*init)(struct net___10 *);
	void (*pre_exit)(struct net___10 *);
	void (*exit)(struct net___10 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

typedef int (*bpf_iter_attach_target_t___4)(struct bpf_prog___7 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___7 *);

typedef void (*bpf_iter_detach_target_t___4)(struct bpf_iter_aux_info___7 *);

typedef void (*bpf_iter_show_fdinfo_t___4)(const struct bpf_iter_aux_info___7 *, struct seq_file___56 *);

typedef int (*bpf_iter_fill_link_info_t___4)(const struct bpf_iter_aux_info___7 *, struct bpf_link_info *);

typedef const struct bpf_func_proto * (*bpf_iter_get_func_proto_t___5)(enum bpf_func_id, const struct bpf_prog___7 *);

struct bpf_iter_reg___4 {
	const char *target;
	bpf_iter_attach_target_t___4 attach_target;
	bpf_iter_detach_target_t___4 detach_target;
	bpf_iter_show_fdinfo_t___4 show_fdinfo;
	bpf_iter_fill_link_info_t___4 fill_link_info;
	bpf_iter_get_func_proto_t___5 get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___7 *seq_info;
};

struct bpf_iter_meta___5 {
	union {
		struct seq_file___56 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct scm_fp_list___4 {
	short int count;
	short int max;
	struct user_struct *user;
	struct file___59 *fp[253];
};

struct scm_cookie___3 {
	struct pid___52 *pid;
	struct scm_fp_list___4 *fp;
	struct scm_creds creds;
	struct lsmblob lsmblob;
};

struct sockaddr_nl {
	__kernel_sa_family_t nl_family;
	short unsigned int nl_pad;
	__u32 nl_pid;
	__u32 nl_groups;
};

struct nlmsgerr {
	int error;
	struct nlmsghdr msg;
};

enum nlmsgerr_attrs {
	NLMSGERR_ATTR_UNUSED = 0,
	NLMSGERR_ATTR_MSG = 1,
	NLMSGERR_ATTR_OFFS = 2,
	NLMSGERR_ATTR_COOKIE = 3,
	NLMSGERR_ATTR_POLICY = 4,
	__NLMSGERR_ATTR_MAX = 5,
	NLMSGERR_ATTR_MAX = 4,
};

struct nl_pktinfo {
	__u32 group;
};

enum {
	NETLINK_UNCONNECTED = 0,
	NETLINK_CONNECTED = 1,
};

enum netlink_skb_flags {
	NETLINK_SKB_DST = 8,
};

struct netlink_skb_parms___13 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___8 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___5 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___9 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___10 *, int);
	void (*unbind)(struct net___10 *, int);
	bool (*compare)(struct net___10 *, struct sock___8 *);
};

struct netlink_notify {
	struct net___10 *net;
	u32 portid;
	int protocol;
};

struct netlink_dump_control___2 {
	int (*start)(struct netlink_callback___7 *);
	int (*dump)(struct sk_buff___9 *, struct netlink_callback___7 *);
	int (*done)(struct netlink_callback___7 *);
	void *data;
	struct module___57 *module;
	u32 min_dump_alloc;
};

struct netlink_tap {
	struct net_device___12 *dev;
	struct module___57 *module;
	struct list_head list;
};

struct socket_alloc___4 {
	struct socket___6 socket;
	struct inode___59 vfs_inode;
	long: 64;
};

struct trace_event_raw_netlink_extack {
	struct trace_entry ent;
	u32 __data_loc_msg;
	char __data[0];
};

struct trace_event_data_offsets_netlink_extack {
	u32 msg;
};

typedef void (*btf_trace_netlink_extack)(void *, const char *);

struct netlink_sock {
	struct sock___8 sk;
	u32 portid;
	u32 dst_portid;
	u32 dst_group;
	u32 flags;
	u32 subscriptions;
	u32 ngroups;
	long unsigned int *groups;
	long unsigned int state;
	size_t max_recvmsg_len;
	wait_queue_head_t wait;
	bool bound;
	bool cb_running;
	int dump_done_errno;
	struct netlink_callback___7 cb;
	struct mutex *cb_mutex;
	struct mutex cb_def_mutex;
	void (*netlink_rcv)(struct sk_buff___9 *);
	int (*netlink_bind)(struct net___10 *, int);
	void (*netlink_unbind)(struct net___10 *, int);
	struct module___57 *module;
	struct rhash_head node;
	struct callback_head rcu;
	struct work_struct work;
};

struct listeners;

struct netlink_table {
	struct rhashtable hash;
	struct hlist_head mc_list;
	struct listeners *listeners;
	unsigned int flags;
	unsigned int groups;
	struct mutex *cb_mutex;
	struct module___57 *module;
	int (*bind)(struct net___10 *, int);
	void (*unbind)(struct net___10 *, int);
	bool (*compare)(struct net___10 *, struct sock___8 *);
	int registered;
};

struct listeners {
	struct callback_head rcu;
	long unsigned int masks[0];
};

struct netlink_tap_net {
	struct list_head netlink_tap_all;
	struct mutex netlink_tap_lock;
};

struct netlink_compare_arg {
	possible_net_t___7 pnet;
	u32 portid;
};

struct netlink_broadcast_data {
	struct sock___8 *exclude_sk;
	struct net___10 *net;
	u32 portid;
	u32 group;
	int failure;
	int delivery_failure;
	int congested;
	int delivered;
	gfp_t allocation;
	struct sk_buff___9 *skb;
	struct sk_buff___9 *skb2;
	int (*tx_filter)(struct sock___8 *, struct sk_buff___9 *, void *);
	void *tx_data;
};

struct netlink_set_err_data {
	struct sock___8 *exclude_sk;
	u32 portid;
	u32 group;
	int code;
};

struct nl_seq_iter {
	struct seq_net_private___4 p;
	struct rhashtable_iter hti;
	int link;
};

struct bpf_iter__netlink {
	union {
		struct bpf_iter_meta___5 *meta;
	};
	union {
		struct netlink_sock *sk;
	};
};

struct netlink_dump_control___3 {
	int (*start)(struct netlink_callback___65 *);
	int (*dump)(struct sk_buff___66 *, struct netlink_callback___65 *);
	int (*done)(struct netlink_callback___65 *);
	void *data;
	struct module___240 *module;
	u32 min_dump_alloc;
};

enum {
	CTRL_CMD_UNSPEC = 0,
	CTRL_CMD_NEWFAMILY = 1,
	CTRL_CMD_DELFAMILY = 2,
	CTRL_CMD_GETFAMILY = 3,
	CTRL_CMD_NEWOPS = 4,
	CTRL_CMD_DELOPS = 5,
	CTRL_CMD_GETOPS = 6,
	CTRL_CMD_NEWMCAST_GRP = 7,
	CTRL_CMD_DELMCAST_GRP = 8,
	CTRL_CMD_GETMCAST_GRP = 9,
	CTRL_CMD_GETPOLICY = 10,
	__CTRL_CMD_MAX = 11,
};

enum {
	CTRL_ATTR_UNSPEC = 0,
	CTRL_ATTR_FAMILY_ID = 1,
	CTRL_ATTR_FAMILY_NAME = 2,
	CTRL_ATTR_VERSION = 3,
	CTRL_ATTR_HDRSIZE = 4,
	CTRL_ATTR_MAXATTR = 5,
	CTRL_ATTR_OPS = 6,
	CTRL_ATTR_MCAST_GROUPS = 7,
	CTRL_ATTR_POLICY = 8,
	CTRL_ATTR_OP_POLICY = 9,
	CTRL_ATTR_OP = 10,
	__CTRL_ATTR_MAX = 11,
};

enum {
	CTRL_ATTR_OP_UNSPEC = 0,
	CTRL_ATTR_OP_ID = 1,
	CTRL_ATTR_OP_FLAGS = 2,
	__CTRL_ATTR_OP_MAX = 3,
};

enum {
	CTRL_ATTR_MCAST_GRP_UNSPEC = 0,
	CTRL_ATTR_MCAST_GRP_NAME = 1,
	CTRL_ATTR_MCAST_GRP_ID = 2,
	__CTRL_ATTR_MCAST_GRP_MAX = 3,
};

enum {
	CTRL_ATTR_POLICY_UNSPEC = 0,
	CTRL_ATTR_POLICY_DO = 1,
	CTRL_ATTR_POLICY_DUMP = 2,
	__CTRL_ATTR_POLICY_DUMP_MAX = 3,
	CTRL_ATTR_POLICY_DUMP_MAX = 2,
};

struct genl_ops___5;

struct genl_info___4;

struct genl_small_ops___5;

struct genl_family___5 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___5 *, struct sk_buff___66 *, struct genl_info___4 *);
	void (*post_doit)(const struct genl_ops___5 *, struct sk_buff___66 *, struct genl_info___4 *);
	const struct genl_ops___5 *ops;
	const struct genl_small_ops___5 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___240 *module;
};

struct genl_ops___5 {
	int (*doit)(struct sk_buff___66 *, struct genl_info___4 *);
	int (*start)(struct netlink_callback___65 *);
	int (*dumpit)(struct sk_buff___66 *, struct netlink_callback___65 *);
	int (*done)(struct netlink_callback___65 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___4 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___65 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___5 {
	int (*doit)(struct sk_buff___66 *, struct genl_info___4 *);
	int (*dumpit)(struct sk_buff___66 *, struct netlink_callback___65 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_dumpit_info___3 {
	const struct genl_family___5 *family;
	struct genl_ops___5 op;
	struct nlattr **attrs;
};

struct genl_start_context {
	const struct genl_family___5 *family;
	struct nlmsghdr *nlh;
	struct netlink_ext_ack *extack;
	const struct genl_ops___5 *ops;
	int hdrlen;
};

struct netlink_policy_dump_state;

struct ctrl_dump_policy_ctx {
	struct netlink_policy_dump_state *state;
	const struct genl_family___5 *rt;
	unsigned int opidx;
	u32 op;
	u16 fam_id;
	u8 policies: 1;
	u8 single_op: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
};

enum netlink_attribute_type {
	NL_ATTR_TYPE_INVALID = 0,
	NL_ATTR_TYPE_FLAG = 1,
	NL_ATTR_TYPE_U8 = 2,
	NL_ATTR_TYPE_U16 = 3,
	NL_ATTR_TYPE_U32 = 4,
	NL_ATTR_TYPE_U64 = 5,
	NL_ATTR_TYPE_S8 = 6,
	NL_ATTR_TYPE_S16 = 7,
	NL_ATTR_TYPE_S32 = 8,
	NL_ATTR_TYPE_S64 = 9,
	NL_ATTR_TYPE_BINARY = 10,
	NL_ATTR_TYPE_STRING = 11,
	NL_ATTR_TYPE_NUL_STRING = 12,
	NL_ATTR_TYPE_NESTED = 13,
	NL_ATTR_TYPE_NESTED_ARRAY = 14,
	NL_ATTR_TYPE_BITFIELD32 = 15,
};

enum netlink_policy_type_attr {
	NL_POLICY_TYPE_ATTR_UNSPEC = 0,
	NL_POLICY_TYPE_ATTR_TYPE = 1,
	NL_POLICY_TYPE_ATTR_MIN_VALUE_S = 2,
	NL_POLICY_TYPE_ATTR_MAX_VALUE_S = 3,
	NL_POLICY_TYPE_ATTR_MIN_VALUE_U = 4,
	NL_POLICY_TYPE_ATTR_MAX_VALUE_U = 5,
	NL_POLICY_TYPE_ATTR_MIN_LENGTH = 6,
	NL_POLICY_TYPE_ATTR_MAX_LENGTH = 7,
	NL_POLICY_TYPE_ATTR_POLICY_IDX = 8,
	NL_POLICY_TYPE_ATTR_POLICY_MAXTYPE = 9,
	NL_POLICY_TYPE_ATTR_BITFIELD32_MASK = 10,
	NL_POLICY_TYPE_ATTR_PAD = 11,
	NL_POLICY_TYPE_ATTR_MASK = 12,
	__NL_POLICY_TYPE_ATTR_MAX = 13,
	NL_POLICY_TYPE_ATTR_MAX = 12,
};

struct netlink_policy_dump_state___2 {
	unsigned int policy_idx;
	unsigned int attr_idx;
	unsigned int n_alloc;
	struct {
		const struct nla_policy *policy;
		unsigned int maxtype;
	} policies[0];
};

struct dentry___264;

struct super_block___264;

struct module___248;

struct file_system_type___264 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___264 * (*mount)(struct file_system_type___264 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___264 *);
	struct module___248 *owner;
	struct file_system_type___264 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___264;

struct kiocb___264;

struct iov_iter___184;

struct poll_table_struct___185;

struct vm_area_struct___269;

struct inode___264;

struct file_lock___264;

struct page___269;

struct pipe_inode_info___105;

struct seq_file___239;

struct file_operations___265 {
	struct module___248 *owner;
	loff_t (*llseek)(struct file___264 *, loff_t, int);
	ssize_t (*read)(struct file___264 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___264 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___264 *, struct iov_iter___184 *);
	ssize_t (*write_iter)(struct kiocb___264 *, struct iov_iter___184 *);
	int (*iopoll)(struct kiocb___264 *, bool);
	int (*iterate)(struct file___264 *, struct dir_context *);
	int (*iterate_shared)(struct file___264 *, struct dir_context *);
	__poll_t (*poll)(struct file___264 *, struct poll_table_struct___185 *);
	long int (*unlocked_ioctl)(struct file___264 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___264 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___264 *, struct vm_area_struct___269 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___264 *, struct file___264 *);
	int (*flush)(struct file___264 *, fl_owner_t);
	int (*release)(struct inode___264 *, struct file___264 *);
	int (*fsync)(struct file___264 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___264 *, int);
	int (*lock)(struct file___264 *, int, struct file_lock___264 *);
	ssize_t (*sendpage)(struct file___264 *, struct page___269 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___264 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___264 *, long unsigned int);
	int (*flock)(struct file___264 *, int, struct file_lock___264 *);
	ssize_t (*splice_write)(struct pipe_inode_info___105 *, struct file___264 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___264 *, loff_t *, struct pipe_inode_info___105 *, size_t, unsigned int);
	int (*setlease)(struct file___264 *, long int, struct file_lock___264 **, void **);
	long int (*fallocate)(struct file___264 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___239 *, struct file___264 *);
	ssize_t (*copy_file_range)(struct file___264 *, loff_t, struct file___264 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___264 *, loff_t, struct file___264 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___264 *, loff_t, loff_t, int);
};

struct vmacache___269 {
	u64 seqnum;
	struct vm_area_struct___269 *vmas[4];
};

struct page_frag___269 {
	struct page___269 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___87;

struct debug_info___87 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___87 *hbp_break[16];
	struct perf_event___87 *hbp_watch[16];
};

struct thread_struct___87 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___87 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___270;

struct pid___241;

struct nsproxy___250;

struct signal_struct___265;

struct bio_list___155;

struct backing_dev_info___141;

struct io_context___155;

struct css_set___191;

struct perf_event_context___87;

struct mem_cgroup___129;

struct request_queue___155;

struct vm_struct___247;

struct bpf_local_storage___9;

struct task_struct___271 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___271 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___270 *mm;
	struct mm_struct___270 *active_mm;
	struct vmacache___269 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___271 *real_parent;
	struct task_struct___271 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___271 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___241 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___250 *nsproxy;
	struct signal_struct___265 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___271 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___155 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___141 *backing_dev_info;
	struct io_context___155 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___191 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___87 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___105 *splice_pipe;
	struct page_frag___269 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___129 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___129 *active_memcg;
	struct request_queue___155 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___271 *oom_reaper_list;
	struct vm_struct___247 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___9 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___252;

struct kobj_type___252;

struct kernfs_node___252;

struct kobject___252 {
	const char *name;
	struct list_head entry;
	struct kobject___252 *parent;
	struct kset___252 *kset;
	struct kobj_type___252 *ktype;
	struct kernfs_node___252 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___249 {
	struct kobject___252 kobj;
	struct module___248 *mod;
	struct kobject___252 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___248 {
	struct module___248 *mod;
	struct latch_tree_node node;
};

struct module_layout___248 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___248 mtn;
};

struct module_attribute___248;

struct kernel_param___248;

struct trace_event_call___81;

struct module___248 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___249 mkobj;
	struct module_attribute___248 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___252 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___248 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___248 core_layout;
	struct module_layout___248 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___81 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___87 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___271 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___87)(struct perf_event___87 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___87;

struct fasync_struct___264;

struct pid_namespace___241;

struct bpf_prog___67;

struct perf_cgroup___87;

struct perf_event___87 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___87 *group_leader;
	struct pmu___87 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___87 hw;
	struct perf_event_context___87 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___87 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___271 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___264 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___87 *aux_event;
	void (*destroy)(struct perf_event___87 *);
	struct callback_head callback_head;
	struct pid_namespace___241 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___87 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___87 orig_overflow_handler;
	struct bpf_prog___67 *prog;
	u64 bpf_cookie;
	struct trace_event_call___81 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___87 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct vfsmount___264;

struct path___264 {
	struct vfsmount___264 *mnt;
	struct dentry___264 *dentry;
};

struct fown_struct___241 {
	rwlock_t lock;
	struct pid___241 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___264;

struct file___264 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___264 f_path;
	struct inode___264 *f_inode;
	const struct file_operations___265 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___241 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___264 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___269 *pgtable_t___269;

struct page_pool___93;

struct dev_pagemap___259;

struct page___269 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___264 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___93 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___269 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___269 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___270 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___259 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___259;

struct vm_area_struct___269 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___269 *vm_next;
	struct vm_area_struct___269 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___270 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___259 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___264 *vm_file;
	struct file___264 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___269;

struct mm_struct___270 {
	struct {
		struct vm_area_struct___269 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___264 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___269 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___271 *owner;
		struct user_namespace___26 *user_ns;
		struct file___264 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___264;

struct address_space___264 {
	struct inode___264 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___264 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___245;

struct page_pool_params___93 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___245 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___93 {
	u32 count;
	struct page___269 *cache[128];
};

struct page_pool___93 {
	struct page_pool_params___93 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___269 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___93 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___259;

struct dev_pagemap___259 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___259 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___259;

struct vm_operations_struct___259 {
	void (*open)(struct vm_area_struct___269 *);
	void (*close)(struct vm_area_struct___269 *);
	int (*may_split)(struct vm_area_struct___269 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___269 *);
	int (*mprotect)(struct vm_area_struct___269 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___259 *);
	vm_fault_t (*huge_fault)(struct vm_fault___259 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___259 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___269 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___259 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___259 *);
	int (*access)(struct vm_area_struct___269 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___269 *);
	int (*set_policy)(struct vm_area_struct___269 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___269 *, long unsigned int);
	struct page___269 * (*find_special_page)(struct vm_area_struct___269 *, long unsigned int);
};

struct core_thread___269 {
	struct task_struct___271 *task;
	struct core_thread___269 *next;
};

struct core_state___269 {
	atomic_t nr_threads;
	struct core_thread___269 dumper;
	struct completion startup;
};

struct vm_fault___259 {
	const struct {
		struct vm_area_struct___269 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___269 *cow_page;
	struct page___269 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___269 prealloc_pte;
};

struct upid___241 {
	int nr;
	struct pid_namespace___241 *ns;
};

struct pid_namespace___241 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___271 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___241 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___241 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___241 numbers[1];
};

struct signal_struct___265 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___271 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___271 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___241 *pids[4];
	struct pid___241 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___270 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___78;

struct cgroup_namespace___191;

struct nsproxy___250 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___241 *pid_ns_for_children;
	struct net___78 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___191 *cgroup_ns;
};

struct bio___155;

struct bio_list___155 {
	struct bio___155 *head;
	struct bio___155 *tail;
};

struct cgroup_subsys_state___191;

struct bdi_writeback___141 {
	struct backing_dev_info___141 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___191 *memcg_css;
	struct cgroup_subsys_state___191 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___141 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___141 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___245 *dev;
	char dev_name[64];
	struct device___245 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___264 *debug_dir;
};

struct io_cq___155;

struct io_context___155 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___155 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___191;

struct css_set___191 {
	struct cgroup_subsys_state___191 *subsys[14];
	refcount_t refcount;
	struct css_set___191 *dom_cset;
	struct cgroup___191 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___191 *mg_src_cgrp;
	struct cgroup___191 *mg_dst_cgrp;
	struct css_set___191 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___87 {
	struct pmu___87 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___271 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___87 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct pipe_buffer___105;

struct pipe_inode_info___105 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___269 *tmp_page;
	struct fasync_struct___264 *fasync_readers;
	struct fasync_struct___264 *fasync_writers;
	struct pipe_buffer___105 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___191;

struct cgroup_subsys_state___191 {
	struct cgroup___191 *cgroup;
	struct cgroup_subsys___191 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___191 *parent;
};

struct cgroup_file___191 {
	struct kernfs_node___252 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___129;

struct mem_cgroup_per_node___129;

struct mem_cgroup___129 {
	struct cgroup_subsys_state___191 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___191 events_file;
	struct cgroup_file___191 events_local_file;
	struct cgroup_file___191 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___129 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___271 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___129 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___155;

struct blk_integrity___155 {
	const struct blk_integrity_profile___155 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___155 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___155 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___155;

struct elevator_queue___155;

struct blk_mq_ops___150;

struct blk_mq_hw_ctx___150;

struct gendisk___158;

struct blkcg_gq___143;

struct blk_mq_tag_set___150;

struct request_queue___155 {
	struct request___155 *last_merge;
	struct elevator_queue___155 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___150 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___150 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___158 *disk;
	struct kobject___252 kobj;
	struct kobject___252 *mq_kobj;
	struct blk_integrity___155 integrity;
	struct device___245 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___143 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___150 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___155 bio_split;
	struct dentry___264 *debugfs_dir;
	struct dentry___264 *sched_debugfs_dir;
	struct dentry___264 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___247 {
	struct vm_struct___247 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___269 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___9;

struct bpf_local_storage___9 {
	struct bpf_local_storage_data___9 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct pglist_data___137;

struct lruvec___137 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___137 *pgdat;
};

struct zone___137 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___137 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___137 {
	struct zone___137 *zone;
	int zone_idx;
};

struct zonelist___137 {
	struct zoneref___137 _zonerefs[321];
};

struct pglist_data___137 {
	struct zone___137 node_zones[5];
	struct zonelist___137 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___271 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___271 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___137 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___264;

struct dentry___264 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___264 *d_parent;
	struct qstr d_name;
	struct inode___264 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___264 *d_op;
	struct super_block___264 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___264;

struct inode___264 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___264 *i_op;
	struct super_block___264 *i_sb;
	struct address_space___264 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___141 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___265 *i_fop;
		void (*free_inode)(struct inode___264 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___264 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___105 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___264 {
	int (*d_revalidate)(struct dentry___264 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___264 *, unsigned int);
	int (*d_hash)(const struct dentry___264 *, struct qstr *);
	int (*d_compare)(const struct dentry___264 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___264 *);
	int (*d_init)(struct dentry___264 *);
	void (*d_release)(struct dentry___264 *);
	void (*d_prune)(struct dentry___264 *);
	void (*d_iput)(struct dentry___264 *, struct inode___264 *);
	char * (*d_dname)(struct dentry___264 *, char *, int);
	struct vfsmount___264 * (*d_automount)(struct path___264 *);
	int (*d_manage)(const struct path___264 *, bool);
	struct dentry___264 * (*d_real)(struct dentry___264 *, const struct inode___264 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___264;

struct mem_dqinfo___264 {
	struct quota_format_type___264 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___264;

struct quota_info___264 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___264 *files[3];
	struct mem_dqinfo___264 info[3];
	const struct quota_format_ops___264 *ops[3];
};

struct rcuwait___265 {
	struct task_struct___271 *task;
};

struct percpu_rw_semaphore___265 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___265 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___264 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___265 rw_sem[3];
};

struct shrink_control___129;

struct shrinker___129 {
	long unsigned int (*count_objects)(struct shrinker___129 *, struct shrink_control___129 *);
	long unsigned int (*scan_objects)(struct shrinker___129 *, struct shrink_control___129 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___264;

struct dquot_operations___264;

struct quotactl_ops___264;

struct block_device___158;

struct super_block___264 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___264 *s_type;
	const struct super_operations___264 *s_op;
	const struct dquot_operations___264 *dq_op;
	const struct quotactl_ops___264 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___264 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___158 *s_bdev;
	struct backing_dev_info___141 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___264 s_dquot;
	struct sb_writers___264 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___264 *s_d_op;
	int cleancache_poolid;
	struct shrinker___129 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___264 {
	struct dentry___264 *mnt_root;
	struct super_block___264 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___129 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___129 *memcg;
};

struct psi_group___191 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___271 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___67;

struct cgroup_bpf___67 {
	struct bpf_prog_array___67 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___67 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___191;

struct cgroup_rstat_cpu___191;

struct cgroup___191 {
	struct cgroup_subsys_state___191 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___252 *kn;
	struct cgroup_file___191 procs_file;
	struct cgroup_file___191 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___191 *subsys[14];
	struct cgroup_root___191 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___191 *dom_cgrp;
	struct cgroup___191 *old_dom_cgrp;
	struct cgroup_rstat_cpu___191 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___191 psi;
	struct cgroup_bpf___67 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___155 {
	struct request_queue___155 *q;
	struct io_context___155 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___264 {
	struct file___264 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___264 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___264 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___264 *ia_file;
};

struct dquot___264 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___264 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___264 {
	int qf_fmt_id;
	const struct quota_format_ops___264 *qf_ops;
	struct module___248 *qf_owner;
	struct quota_format_type___264 *qf_next;
};

struct quota_format_ops___264 {
	int (*check_quota_file)(struct super_block___264 *, int);
	int (*read_file_info)(struct super_block___264 *, int);
	int (*write_file_info)(struct super_block___264 *, int);
	int (*free_file_info)(struct super_block___264 *, int);
	int (*read_dqblk)(struct dquot___264 *);
	int (*commit_dqblk)(struct dquot___264 *);
	int (*release_dqblk)(struct dquot___264 *);
	int (*get_next_id)(struct super_block___264 *, struct kqid *);
};

struct dquot_operations___264 {
	int (*write_dquot)(struct dquot___264 *);
	struct dquot___264 * (*alloc_dquot)(struct super_block___264 *, int);
	void (*destroy_dquot)(struct dquot___264 *);
	int (*acquire_dquot)(struct dquot___264 *);
	int (*release_dquot)(struct dquot___264 *);
	int (*mark_dirty)(struct dquot___264 *);
	int (*write_info)(struct super_block___264 *, int);
	qsize_t * (*get_reserved_space)(struct inode___264 *);
	int (*get_projid)(struct inode___264 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___264 *, qsize_t *);
	int (*get_next_id)(struct super_block___264 *, struct kqid *);
};

struct quotactl_ops___264 {
	int (*quota_on)(struct super_block___264 *, int, int, const struct path___264 *);
	int (*quota_off)(struct super_block___264 *, int);
	int (*quota_enable)(struct super_block___264 *, unsigned int);
	int (*quota_disable)(struct super_block___264 *, unsigned int);
	int (*quota_sync)(struct super_block___264 *, int);
	int (*set_info)(struct super_block___264 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___264 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___264 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___264 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___264 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___264 *, unsigned int);
};

struct writeback_control___141;

struct address_space_operations___264 {
	int (*writepage)(struct page___269 *, struct writeback_control___141 *);
	int (*readpage)(struct file___264 *, struct page___269 *);
	int (*writepages)(struct address_space___264 *, struct writeback_control___141 *);
	int (*set_page_dirty)(struct page___269 *);
	int (*readpages)(struct file___264 *, struct address_space___264 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___264 *, struct address_space___264 *, loff_t, unsigned int, unsigned int, struct page___269 **, void **);
	int (*write_end)(struct file___264 *, struct address_space___264 *, loff_t, unsigned int, unsigned int, struct page___269 *, void *);
	sector_t (*bmap)(struct address_space___264 *, sector_t);
	void (*invalidatepage)(struct page___269 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___269 *, gfp_t);
	void (*freepage)(struct page___269 *);
	ssize_t (*direct_IO)(struct kiocb___264 *, struct iov_iter___184 *);
	int (*migratepage)(struct address_space___264 *, struct page___269 *, struct page___269 *, enum migrate_mode);
	bool (*isolate_page)(struct page___269 *, isolate_mode_t);
	void (*putback_page)(struct page___269 *);
	int (*launder_page)(struct page___269 *);
	int (*is_partially_uptodate)(struct page___269 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___269 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___264 *, struct page___269 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___264 *, sector_t *);
	void (*swap_deactivate)(struct file___264 *);
};

struct writeback_control___141 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___141 *wb;
	struct inode___264 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___181;

struct iov_iter___184 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___181 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___105 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___264 {
	struct dentry___264 * (*lookup)(struct inode___264 *, struct dentry___264 *, unsigned int);
	const char * (*get_link)(struct dentry___264 *, struct inode___264 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___264 *, int);
	struct posix_acl * (*get_acl)(struct inode___264 *, int, bool);
	int (*readlink)(struct dentry___264 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___264 *, struct dentry___264 *, umode_t, bool);
	int (*link)(struct dentry___264 *, struct inode___264 *, struct dentry___264 *);
	int (*unlink)(struct inode___264 *, struct dentry___264 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___264 *, struct dentry___264 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___264 *, struct dentry___264 *, umode_t);
	int (*rmdir)(struct inode___264 *, struct dentry___264 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___264 *, struct dentry___264 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___264 *, struct dentry___264 *, struct inode___264 *, struct dentry___264 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___264 *, struct iattr___264 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___264 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___264 *, char *, size_t);
	int (*fiemap)(struct inode___264 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___264 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___264 *, struct dentry___264 *, struct file___264 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___264 *, struct dentry___264 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___264 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___264 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___264 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___264 {
	void (*fl_copy_lock)(struct file_lock___264 *, struct file_lock___264 *);
	void (*fl_release_private)(struct file_lock___264 *);
};

struct lock_manager_operations___264;

struct file_lock___264 {
	struct file_lock___264 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___264 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___264 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___264 *fl_ops;
	const struct lock_manager_operations___264 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___264 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___264 *);
	int (*lm_grant)(struct file_lock___264 *, int);
	bool (*lm_break)(struct file_lock___264 *);
	int (*lm_change)(struct file_lock___264 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___264 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___264 *);
};

struct fasync_struct___264 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___264 *fa_next;
	struct file___264 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___264 {
	struct inode___264 * (*alloc_inode)(struct super_block___264 *);
	void (*destroy_inode)(struct inode___264 *);
	void (*free_inode)(struct inode___264 *);
	void (*dirty_inode)(struct inode___264 *, int);
	int (*write_inode)(struct inode___264 *, struct writeback_control___141 *);
	int (*drop_inode)(struct inode___264 *);
	void (*evict_inode)(struct inode___264 *);
	void (*put_super)(struct super_block___264 *);
	int (*sync_fs)(struct super_block___264 *, int);
	int (*freeze_super)(struct super_block___264 *);
	int (*freeze_fs)(struct super_block___264 *);
	int (*thaw_super)(struct super_block___264 *);
	int (*unfreeze_fs)(struct super_block___264 *);
	int (*statfs)(struct dentry___264 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___264 *, int *, char *);
	void (*umount_begin)(struct super_block___264 *);
	int (*show_options)(struct seq_file___239 *, struct dentry___264 *);
	int (*show_devname)(struct seq_file___239 *, struct dentry___264 *);
	int (*show_path)(struct seq_file___239 *, struct dentry___264 *);
	int (*show_stats)(struct seq_file___239 *, struct dentry___264 *);
	ssize_t (*quota_read)(struct super_block___264 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___264 *, int, const char *, size_t, loff_t);
	struct dquot___264 ** (*get_dquots)(struct inode___264 *);
	long int (*nr_cached_objects)(struct super_block___264 *, struct shrink_control___129 *);
	long int (*free_cached_objects)(struct super_block___264 *, struct shrink_control___129 *);
	struct file___264 * (*real_loop)(struct file___264 *);
};

struct wakeup_source___245;

struct dev_pm_info___245 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___245 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___245 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___245;

struct bus_type___245;

struct device_driver___245;

struct dev_pm_domain___245;

struct fwnode_handle___241;

struct class___245;

struct attribute_group___252;

struct device___245 {
	struct kobject___252 kobj;
	struct device___245 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___245 *type;
	struct bus_type___245 *bus;
	struct device_driver___245 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___245 power;
	struct dev_pm_domain___245 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___241 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___245 *class;
	const struct attribute_group___252 **groups;
	void (*release)(struct device___245 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___158 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___264 *bd_inode;
	struct super_block___264 *bd_super;
	void *bd_claiming;
	struct device___245 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___252 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___158 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___264 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___193)(struct file___264 *, wait_queue_head_t *, struct poll_table_struct___185 *);

struct poll_table_struct___185 {
	poll_queue_proc___193 _qproc;
	__poll_t _key;
};

struct seq_operations___239;

struct seq_file___239 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___239 *op;
	int poll_event;
	const struct file___264 *file;
	void *private;
};

typedef void bio_end_io_t___155(struct bio___155 *);

struct bio_vec___181 {
	struct page___269 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___155;

struct bio___155 {
	struct bio___155 *bi_next;
	struct block_device___158 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___155 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___143 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___155 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___181 *bi_io_vec;
	struct bio_set___155 *bi_pool;
	struct bio_vec___181 bi_inline_vecs[0];
};

struct kernfs_root___252;

struct kernfs_elem_dir___252 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___252 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___252;

struct kernfs_root___252 {
	struct kernfs_node___252 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___252 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___252 {
	struct kernfs_node___252 *target_kn;
};

struct kernfs_ops___252;

struct kernfs_elem_attr___252 {
	const struct kernfs_ops___252 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___252 *notify_next;
};

struct kernfs_node___252 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___252 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___252 dir;
		struct kernfs_elem_symlink___252 symlink;
		struct kernfs_elem_attr___252 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___252;

struct kernfs_ops___252 {
	int (*open)(struct kernfs_open_file___252 *);
	void (*release)(struct kernfs_open_file___252 *);
	int (*seq_show)(struct seq_file___239 *, void *);
	void * (*seq_start)(struct seq_file___239 *, loff_t *);
	void * (*seq_next)(struct seq_file___239 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___239 *, void *);
	ssize_t (*read)(struct kernfs_open_file___252 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___252 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___252 *, struct poll_table_struct___185 *);
	int (*mmap)(struct kernfs_open_file___252 *, struct vm_area_struct___269 *);
};

struct kernfs_syscall_ops___252 {
	int (*show_options)(struct seq_file___239 *, struct kernfs_root___252 *);
	int (*mkdir)(struct kernfs_node___252 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___252 *);
	int (*rename)(struct kernfs_node___252 *, struct kernfs_node___252 *, const char *);
	int (*show_path)(struct seq_file___239 *, struct kernfs_node___252 *, struct kernfs_root___252 *);
};

struct kernfs_open_file___252 {
	struct kernfs_node___252 *kn;
	struct file___264 *file;
	struct seq_file___239 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___259 *vm_ops;
};

struct sock___60;

struct kobj_ns_type_operations___60 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___60 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___78 *net;
} possible_net_t___73;

struct proto___60;

struct sock_common___60 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___60 *skc_prot;
	possible_net_t___73 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___60 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___74;

struct sk_buff_head___73 {
	struct sk_buff___74 *next;
	struct sk_buff___74 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___60 {
	struct cgroup___191 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___60;

struct socket_wq___61;

struct dst_entry___60;

struct socket___62;

struct net_device___73;

struct sock_reuseport___14;

struct sock___60 {
	struct sock_common___60 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___73 sk_error_queue;
	struct sk_buff___74 *sk_rx_skb_cache;
	struct sk_buff_head___73 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___74 *head;
		struct sk_buff___74 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___60 *sk_filter;
	union {
		struct socket_wq___61 *sk_wq;
		struct socket_wq___61 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___60 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___60 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___74 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___74 *sk_tx_skb_cache;
	struct sk_buff_head___73 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___269 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___60 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___241 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___62 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___60 sk_cgrp_data;
	struct mem_cgroup___129 *sk_memcg;
	void (*sk_state_change)(struct sock___60 *);
	void (*sk_data_ready)(struct sock___60 *);
	void (*sk_write_space)(struct sock___60 *);
	void (*sk_error_report)(struct sock___60 *);
	int (*sk_backlog_rcv)(struct sock___60 *, struct sk_buff___74 *);
	struct sk_buff___74 * (*sk_validate_xmit_skb)(struct sock___60 *, struct net_device___73 *, struct sk_buff___74 *);
	void (*sk_destruct)(struct sock___60 *);
	struct sock_reuseport___14 *sk_reuseport_cb;
	struct bpf_local_storage___9 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___252;

struct attribute_group___252 {
	const char *name;
	umode_t (*is_visible)(struct kobject___252 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___252 *, struct bin_attribute___252 *, int);
	struct attribute **attrs;
	struct bin_attribute___252 **bin_attrs;
};

struct bin_attribute___252 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___264 * (*f_mapping)();
	ssize_t (*read)(struct file___264 *, struct kobject___252 *, struct bin_attribute___252 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___264 *, struct kobject___252 *, struct bin_attribute___252 *, char *, loff_t, size_t);
	int (*mmap)(struct file___264 *, struct kobject___252 *, struct bin_attribute___252 *, struct vm_area_struct___269 *);
};

struct sysfs_ops___252 {
	ssize_t (*show)(struct kobject___252 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___252 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___252;

struct kset___252 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___252 kobj;
	const struct kset_uevent_ops___252 *uevent_ops;
};

struct kobj_type___252 {
	void (*release)(struct kobject___252 *);
	const struct sysfs_ops___252 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___252 **default_groups;
	const struct kobj_ns_type_operations___60 * (*child_ns_type)(struct kobject___252 *);
	const void * (*namespace)(struct kobject___252 *);
	void (*get_ownership)(struct kobject___252 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___252 {
	int (* const filter)(struct kset___252 *, struct kobject___252 *);
	const char * (* const name)(struct kset___252 *, struct kobject___252 *);
	int (* const uevent)(struct kset___252 *, struct kobject___252 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___248 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___248 *);
	int (*get)(char *, const struct kernel_param___248 *);
	void (*free)(void *);
};

struct kparam_array___248;

struct kernel_param___248 {
	const char *name;
	struct module___248 *mod;
	const struct kernel_param_ops___248 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___248 *arr;
	};
};

struct kparam_array___248 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___248 *ops;
	void *elem;
};

struct module_attribute___248 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___248 *, struct module_kobject___249 *, char *);
	ssize_t (*store)(struct module_attribute___248 *, struct module_kobject___249 *, const char *, size_t);
	void (*setup)(struct module___248 *, const char *);
	int (*test)(struct module___248 *);
	void (*free)(struct module___248 *);
};

struct trace_event_class___81;

struct trace_event_call___81 {
	struct list_head list;
	struct trace_event_class___81 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___67 *prog_array;
	int (*perf_perm)(struct trace_event_call___81 *, struct perf_event___87 *);
};

struct dev_pagemap_ops___259 {
	void (*page_free)(struct page___269 *);
	void (*kill)(struct dev_pagemap___259 *);
	void (*cleanup)(struct dev_pagemap___259 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___259 *);
};

struct bpf_iter_aux_info___76;

typedef int (*bpf_iter_init_seq_priv_t___75)(void *, struct bpf_iter_aux_info___76 *);

struct bpf_map___76;

struct bpf_iter_aux_info___76 {
	struct bpf_map___76 *map;
};

struct bpf_iter_seq_info___75 {
	const struct seq_operations___239 *seq_ops;
	bpf_iter_init_seq_priv_t___75 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___239 {
	void * (*start)(struct seq_file___239 *, loff_t *);
	void (*stop)(struct seq_file___239 *, void *);
	void * (*next)(struct seq_file___239 *, void *, loff_t *);
	int (*show)(struct seq_file___239 *, void *);
};

struct bpf_prog_aux___76;

struct bpf_local_storage_map___9;

struct bpf_map_ops___75 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___76 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___76 *, struct file___264 *);
	void (*map_free)(struct bpf_map___76 *);
	int (*map_get_next_key)(struct bpf_map___76 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___76 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___76 *, void *);
	int (*map_lookup_batch)(struct bpf_map___76 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___76 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___76 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___76 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___76 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___76 *, void *);
	int (*map_update_elem)(struct bpf_map___76 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___76 *, void *);
	int (*map_push_elem)(struct bpf_map___76 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___76 *, void *);
	int (*map_peek_elem)(struct bpf_map___76 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___76 *, struct file___264 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___76 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___76 *, void *, struct seq_file___239 *);
	int (*map_check_btf)(const struct bpf_map___76 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___76 *, struct bpf_prog_aux___76 *);
	void (*map_poke_untrack)(struct bpf_map___76 *, struct bpf_prog_aux___76 *);
	void (*map_poke_run)(struct bpf_map___76 *, u32, struct bpf_prog___67 *, struct bpf_prog___67 *);
	int (*map_direct_value_addr)(const struct bpf_map___76 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___76 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___76 *, struct vm_area_struct___269 *);
	__poll_t (*map_poll)(struct bpf_map___76 *, struct file___264 *, struct poll_table_struct___185 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___9 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___9 *, void *, u32);
	struct bpf_local_storage___9 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___76 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___76 *, const struct bpf_map___76 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___76 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___75 *iter_seq_info;
};

struct bpf_map___76 {
	const struct bpf_map_ops___75 *ops;
	struct bpf_map___76 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___129 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___75;

struct bpf_jit_poke_descriptor___75;

struct bpf_prog_ops___67;

struct btf_mod_pair___75;

struct bpf_prog_offload___73;

struct bpf_prog_aux___76 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___67 *dst_prog;
	struct bpf_trampoline___75 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___67 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___75 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___67 *ops;
	struct bpf_map___76 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___75 *used_btfs;
	struct bpf_prog___67 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___76 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___73 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___67 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___76 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_local_storage_map___9 {
	struct bpf_map___76 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_offloaded_map___73;

struct bpf_map_dev_ops___73 {
	int (*map_get_next_key)(struct bpf_offloaded_map___73 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___73 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___73 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___73 *, void *);
};

struct bpf_offloaded_map___73 {
	struct bpf_map___76 map;
	struct net_device___73 *netdev;
	const struct bpf_map_dev_ops___73 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___73(struct sk_buff___74 **);

struct bpf_xdp_entity___67 {
	struct bpf_prog___67 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___73;

struct net_device_ops___73;

struct l3mdev_ops___60;

struct ndisc_ops___43;

struct xfrmdev_ops___73;

struct header_ops___73;

struct inet6_dev___43;

struct netdev_rx_queue___73;

struct mini_Qdisc___67;

struct netdev_queue___73;

struct Qdisc___67;

struct rtnl_link_ops___67;

struct dcbnl_rtnl_ops___73;

struct net_device___73 {
	char name[16];
	struct netdev_name_node___73 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___73 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___60 *l3mdev_ops;
	const struct ndisc_ops___43 *ndisc_ops;
	const struct xfrmdev_ops___73 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___73 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___252 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___43 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___73 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___67 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___73 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___67 *miniq_ingress;
	struct netdev_queue___73 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___73 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___67 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___67 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___73 = 0,
		NETREG_REGISTERED___73 = 1,
		NETREG_UNREGISTERING___73 = 2,
		NETREG_UNREGISTERED___73 = 3,
		NETREG_RELEASED___73 = 4,
		NETREG_DUMMY___73 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___73 = 0,
		RTNL_LINK_INITIALIZING___73 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___73 *);
	struct netpoll_info *npinfo;
	possible_net_t___73 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___245 dev;
	const struct attribute_group___252 *sysfs_groups[4];
	const struct attribute_group___252 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___67 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___73 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___67 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___67 {
	int (*test_run)(struct bpf_prog___67 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___73 {
	struct bpf_prog___67 *prog;
	struct net_device___73 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___75 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___67 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___248 *mod;
};

struct bpf_jit_poke_descriptor___75 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___76 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___75 {
	struct btf *btf;
	struct module___248 *module;
};

struct bpf_prog_array_item___67 {
	struct bpf_prog___67 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___67 {
	struct callback_head rcu;
	struct bpf_prog_array_item___67 items[0];
};

struct bpf_cg_run_ctx___3 {
	struct bpf_run_ctx run_ctx;
	const struct bpf_prog_array_item___67 *prog_item;
};

struct sk_buff___74 {
	union {
		struct {
			struct sk_buff___74 *next;
			struct sk_buff___74 *prev;
			union {
				struct net_device___73 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___60 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___74 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct fwnode_operations___241;

struct fwnode_handle___241 {
	struct fwnode_handle___241 *secondary;
	const struct fwnode_operations___241 *ops;
	struct device___245 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___241;

struct fwnode_endpoint___241;

struct fwnode_operations___241 {
	struct fwnode_handle___241 * (*get)(struct fwnode_handle___241 *);
	void (*put)(struct fwnode_handle___241 *);
	bool (*device_is_available)(const struct fwnode_handle___241 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___241 *, const struct device___245 *);
	bool (*property_present)(const struct fwnode_handle___241 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___241 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___241 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___241 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*get_parent)(const struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*get_next_child_node)(const struct fwnode_handle___241 *, struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*get_named_child_node)(const struct fwnode_handle___241 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___241 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___241 *);
	struct fwnode_handle___241 * (*graph_get_next_endpoint)(const struct fwnode_handle___241 *, struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*graph_get_remote_endpoint)(const struct fwnode_handle___241 *);
	struct fwnode_handle___241 * (*graph_get_port_parent)(struct fwnode_handle___241 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___241 *, struct fwnode_endpoint___241 *);
	int (*add_links)(struct fwnode_handle___241 *);
};

struct fwnode_endpoint___241 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___241 *local_fwnode;
};

struct fwnode_reference_args___241 {
	struct fwnode_handle___241 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___34;

struct fib_rules_ops___60;

struct fqdir___78;

struct tcp_congestion_ops___13;

struct fib_notifier_ops___60;

struct netns_ipv4___78 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___34 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___60 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___60 *fibnl;
	struct sock___60 **icmp_sk;
	struct sock___60 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___60 **tcp_sk;
	struct fqdir___78 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___13 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___60 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___60 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___60 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___60;

struct dst_ops___78 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___78 *);
	struct dst_entry___60 * (*check)(struct dst_entry___60 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___60 *);
	unsigned int (*mtu)(const struct dst_entry___60 *);
	u32 * (*cow_metrics)(struct dst_entry___60 *, long unsigned int);
	void (*destroy)(struct dst_entry___60 *);
	void (*ifdown)(struct dst_entry___60 *, struct net_device___73 *, int);
	struct dst_entry___60 * (*negative_advice)(struct dst_entry___60 *);
	void (*link_failure)(struct sk_buff___74 *);
	void (*update_pmtu)(struct dst_entry___60 *, struct sock___60 *, struct sk_buff___74 *, u32, bool);
	void (*redirect)(struct dst_entry___60 *, struct sock___60 *, struct sk_buff___74 *);
	int (*local_out)(struct net___78 *, struct sock___60 *, struct sk_buff___74 *);
	struct neighbour___60 * (*neigh_lookup)(const struct dst_entry___60 *, struct sk_buff___74 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___60 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___78 {
	struct dst_ops___78 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___78 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___60 *fib6_rules_ops;
	struct sock___60 **icmp_sk;
	struct sock___60 *ndisc_sk;
	struct sock___60 *tcp_sk;
	struct sock___60 *igmp_sk;
	struct sock___60 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___60 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___60 *notifier_ops;
	struct fib_notifier_ops___60 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___78 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___78 *fqdir;
};

struct netns_sctp___60 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___60 *ctl_sock;
	struct sock___60 *udp4_sock;
	struct sock___60 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___67 {
	struct bpf_prog_array___67 *run_array[2];
	struct bpf_prog___67 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___78 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___60 *nlsk;
	struct sock___60 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___78 xfrm4_dst_ops;
	struct dst_ops___78 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___78 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___60 *rtnl;
	struct sock___60 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___73 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___78 ipv4;
	struct netns_ipv6___78 ipv6;
	struct netns_ieee802154_lowpan___78 ieee802154_lowpan;
	struct netns_sctp___60 sctp;
	struct netns_nf___6 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___73 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___67 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___78 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___60 *crypto_nlsk;
	struct sock___60 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___191 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___191 *root_cset;
};

struct msghdr___62 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___184 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___264 *msg_iocb;
};

struct socket_wq___61 {
	wait_queue_head_t wait;
	struct fasync_struct___264 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___61;

struct socket___62 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___264 *file;
	struct sock___60 *sk;
	const struct proto_ops___61 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___61 wq;
};

typedef int (*sk_read_actor_t___60)(read_descriptor_t *, struct sk_buff___74 *, unsigned int, size_t);

struct proto_ops___61 {
	int family;
	struct module___248 *owner;
	int (*release)(struct socket___62 *);
	int (*bind)(struct socket___62 *, struct sockaddr *, int);
	int (*connect)(struct socket___62 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___62 *, struct socket___62 *);
	int (*accept)(struct socket___62 *, struct socket___62 *, int, bool);
	int (*getname)(struct socket___62 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___264 *, struct socket___62 *, struct poll_table_struct___185 *);
	int (*ioctl)(struct socket___62 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___62 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___62 *, void *, bool, bool);
	int (*listen)(struct socket___62 *, int);
	int (*shutdown)(struct socket___62 *, int);
	int (*setsockopt)(struct socket___62 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___62 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___239 *, struct socket___62 *);
	int (*sendmsg)(struct socket___62 *, struct msghdr___62 *, size_t);
	int (*recvmsg)(struct socket___62 *, struct msghdr___62 *, size_t, int);
	int (*mmap)(struct file___264 *, struct socket___62 *, struct vm_area_struct___269 *);
	ssize_t (*sendpage)(struct socket___62 *, struct page___269 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___62 *, loff_t *, struct pipe_inode_info___105 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___60 *, int);
	int (*peek_len)(struct socket___62 *);
	int (*read_sock)(struct sock___60 *, read_descriptor_t *, sk_read_actor_t___60);
	int (*sendpage_locked)(struct sock___60 *, struct page___269 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___60 *, struct msghdr___62 *, size_t);
	int (*set_rcvlowat)(struct sock___60 *, int);
};

struct dev_pm_ops___245 {
	int (*prepare)(struct device___245 *);
	void (*complete)(struct device___245 *);
	int (*suspend)(struct device___245 *);
	int (*resume)(struct device___245 *);
	int (*freeze)(struct device___245 *);
	int (*thaw)(struct device___245 *);
	int (*poweroff)(struct device___245 *);
	int (*restore)(struct device___245 *);
	int (*suspend_late)(struct device___245 *);
	int (*resume_early)(struct device___245 *);
	int (*freeze_late)(struct device___245 *);
	int (*thaw_early)(struct device___245 *);
	int (*poweroff_late)(struct device___245 *);
	int (*restore_early)(struct device___245 *);
	int (*suspend_noirq)(struct device___245 *);
	int (*resume_noirq)(struct device___245 *);
	int (*freeze_noirq)(struct device___245 *);
	int (*thaw_noirq)(struct device___245 *);
	int (*poweroff_noirq)(struct device___245 *);
	int (*restore_noirq)(struct device___245 *);
	int (*runtime_suspend)(struct device___245 *);
	int (*runtime_resume)(struct device___245 *);
	int (*runtime_idle)(struct device___245 *);
};

struct wakeup_source___245 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___245 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___245 {
	struct dev_pm_ops___245 ops;
	int (*start)(struct device___245 *);
	void (*detach)(struct device___245 *, bool);
	int (*activate)(struct device___245 *);
	void (*sync)(struct device___245 *);
	void (*dismiss)(struct device___245 *);
};

struct bus_type___245 {
	const char *name;
	const char *dev_name;
	struct device___245 *dev_root;
	const struct attribute_group___252 **bus_groups;
	const struct attribute_group___252 **dev_groups;
	const struct attribute_group___252 **drv_groups;
	int (*match)(struct device___245 *, struct device_driver___245 *);
	int (*uevent)(struct device___245 *, struct kobj_uevent_env *);
	int (*probe)(struct device___245 *);
	void (*sync_state)(struct device___245 *);
	void (*remove)(struct device___245 *);
	void (*shutdown)(struct device___245 *);
	int (*online)(struct device___245 *);
	int (*offline)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	int (*num_vf)(struct device___245 *);
	int (*dma_configure)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___245 {
	const char *name;
	struct bus_type___245 *bus;
	struct module___248 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___245 *);
	void (*sync_state)(struct device___245 *);
	int (*remove)(struct device___245 *);
	void (*shutdown)(struct device___245 *);
	int (*suspend)(struct device___245 *, pm_message_t);
	int (*resume)(struct device___245 *);
	const struct attribute_group___252 **groups;
	const struct attribute_group___252 **dev_groups;
	const struct dev_pm_ops___245 *pm;
	void (*coredump)(struct device___245 *);
	struct driver_private *p;
};

struct device_type___245 {
	const char *name;
	const struct attribute_group___252 **groups;
	int (*uevent)(struct device___245 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___245 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___245 *);
	const struct dev_pm_ops___245 *pm;
};

struct class___245 {
	const char *name;
	struct module___248 *owner;
	const struct attribute_group___252 **class_groups;
	const struct attribute_group___252 **dev_groups;
	struct kobject___252 *dev_kobj;
	int (*dev_uevent)(struct device___245 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___245 *, umode_t *);
	void (*class_release)(struct class___245 *);
	void (*dev_release)(struct device___245 *);
	int (*shutdown_pre)(struct device___245 *);
	const struct kobj_ns_type_operations___60 *ns_type;
	const void * (*namespace)(struct device___245 *);
	void (*get_ownership)(struct device___245 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___245 *pm;
	struct subsys_private *p;
};

struct bpf_flow_dissector___4 {
	struct bpf_flow_keys *flow_keys;
	const struct sk_buff___74 *skb;
	const void *data;
	const void *data_end;
};

struct pipe_buf_operations___105;

struct pipe_buffer___105 {
	struct page___269 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___105 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___105 {
	int (*confirm)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
	void (*release)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
	bool (*try_steal)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
	bool (*get)(struct pipe_inode_info___105 *, struct pipe_buffer___105 *);
};

typedef struct bio_vec___181 skb_frag_t___22;

struct skb_shared_info___21 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___74 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___22 frags[17];
};

struct inet_frags___78;

struct fqdir___78 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___78 *f;
	struct net___78 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___78;

struct inet_frags___78 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___78 *, const void *);
	void (*destructor)(struct inet_frag_queue___78 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___78 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___74 *fragments_tail;
	struct sk_buff___74 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___78 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___34 {
	struct ip_ra_chain___34 *next;
	struct sock___60 *sk;
	union {
		void (*destructor)(struct sock___60 *);
		struct sock___60 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___60;

struct fib_lookup_arg___60;

struct fib_rules_ops___60 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___60 *, struct flowi *, int, struct fib_lookup_arg___60 *);
	bool (*suppress)(struct fib_rule___60 *, int, struct fib_lookup_arg___60 *);
	int (*match)(struct fib_rule___60 *, struct flowi *, int);
	int (*configure)(struct fib_rule___60 *, struct sk_buff___74 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___60 *);
	int (*compare)(struct fib_rule___60 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___60 *, struct sk_buff___74 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___60 *);
	void (*flush_cache)(struct fib_rules_ops___60 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___248 *owner;
	struct net___78 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___13 {
	u32 (*ssthresh)(struct sock___60 *);
	void (*cong_avoid)(struct sock___60 *, u32, u32);
	void (*set_state)(struct sock___60 *, u8);
	void (*cwnd_event)(struct sock___60 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___60 *, u32);
	void (*pkts_acked)(struct sock___60 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___60 *);
	void (*cong_control)(struct sock___60 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___60 *);
	u32 (*sndbuf_expand)(struct sock___60 *);
	size_t (*get_info)(struct sock___60 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___248 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___60 *);
	void (*release)(struct sock___60 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___60 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___78 *);
	int (*fib_dump)(struct net___78 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___248 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___37;

struct dst_entry___60 {
	struct net_device___73 *dev;
	struct dst_ops___78 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___74 *);
	int (*output)(struct net___78 *, struct sock___60 *, struct sk_buff___74 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___37 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___60;

struct neigh_parms___60;

struct neigh_ops___60;

struct neighbour___60 {
	struct neighbour___60 *next;
	struct neigh_table___60 *tbl;
	struct neigh_parms___60 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___73 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___60 *, struct sk_buff___74 *);
	const struct neigh_ops___60 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___73 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___73 {
	int (*ieee_getets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___73 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___73 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___73 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___73 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___73 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___73 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___73 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___73 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___73 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___73 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___73 *);
	u8 (*setstate)(struct net_device___73 *, u8);
	void (*getpermhwaddr)(struct net_device___73 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___73 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___73 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___73 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___73 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___73 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___73 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___73 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___73 *, int, u8 *);
	void (*setpfccfg)(struct net_device___73 *, int, u8);
	void (*getpfccfg)(struct net_device___73 *, int, u8 *);
	u8 (*setall)(struct net_device___73 *);
	u8 (*getcap)(struct net_device___73 *, int, u8 *);
	int (*getnumtcs)(struct net_device___73 *, int, u8 *);
	int (*setnumtcs)(struct net_device___73 *, int, u8);
	u8 (*getpfcstate)(struct net_device___73 *);
	void (*setpfcstate)(struct net_device___73 *, u8);
	void (*getbcncfg)(struct net_device___73 *, int, u32 *);
	void (*setbcncfg)(struct net_device___73 *, int, u32);
	void (*getbcnrp)(struct net_device___73 *, int, u8 *);
	void (*setbcnrp)(struct net_device___73 *, int, u8);
	int (*setapp)(struct net_device___73 *, u8, u16, u8);
	int (*getapp)(struct net_device___73 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___73 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___73 *, int, u8);
	u8 (*getdcbx)(struct net_device___73 *);
	u8 (*setdcbx)(struct net_device___73 *, u8);
	int (*peer_getappinfo)(struct net_device___73 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___73 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___73 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___73 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___73 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___73 *, struct dcbnl_buffer *);
};

struct cftype___191;

struct cgroup_subsys___191 {
	struct cgroup_subsys_state___191 * (*css_alloc)(struct cgroup_subsys_state___191 *);
	int (*css_online)(struct cgroup_subsys_state___191 *);
	void (*css_offline)(struct cgroup_subsys_state___191 *);
	void (*css_released)(struct cgroup_subsys_state___191 *);
	void (*css_free)(struct cgroup_subsys_state___191 *);
	void (*css_reset)(struct cgroup_subsys_state___191 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___191 *, int);
	int (*css_extra_stat_show)(struct seq_file___239 *, struct cgroup_subsys_state___191 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___271 *, struct css_set___191 *);
	void (*cancel_fork)(struct task_struct___271 *, struct css_set___191 *);
	void (*fork)(struct task_struct___271 *);
	void (*exit)(struct task_struct___271 *);
	void (*release)(struct task_struct___271 *);
	void (*bind)(struct cgroup_subsys_state___191 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___191 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___191 *dfl_cftypes;
	struct cftype___191 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___191 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___191 *updated_children;
	struct cgroup___191 *updated_next;
};

struct cgroup_root___191 {
	struct kernfs_root___252 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___191 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___191 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___191 *ss;
	struct list_head node;
	struct kernfs_ops___252 *kf_ops;
	int (*open)(struct kernfs_open_file___252 *);
	void (*release)(struct kernfs_open_file___252 *);
	u64 (*read_u64)(struct cgroup_subsys_state___191 *, struct cftype___191 *);
	s64 (*read_s64)(struct cgroup_subsys_state___191 *, struct cftype___191 *);
	int (*seq_show)(struct seq_file___239 *, void *);
	void * (*seq_start)(struct seq_file___239 *, loff_t *);
	void * (*seq_next)(struct seq_file___239 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___239 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___191 *, struct cftype___191 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___191 *, struct cftype___191 *, s64);
	ssize_t (*write)(struct kernfs_open_file___252 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___252 *, struct poll_table_struct___185 *);
};

struct xdp_rxq_info___73 {
	struct net_device___73 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___73 {
	struct net_device___73 *dev;
};

struct xdp_buff___73 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___73 *rxq;
	struct xdp_txq_info___73 *txq;
	u32 frame_sz;
};

struct xdp_frame___73 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___73 *dev_rx;
};

struct netlink_callback___73 {
	struct sk_buff___74 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___74 *, struct netlink_callback___73 *);
	int (*done)(struct netlink_callback___73 *);
	void *data;
	struct module___248 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___73 {
	int (*create)(struct sk_buff___74 *, struct net_device___73 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___74 *, unsigned char *);
	int (*cache)(const struct neighbour___60 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___73 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___74 *);
};

struct netdev_queue___73 {
	struct net_device___73 *dev;
	struct Qdisc___67 *qdisc;
	struct Qdisc___67 *qdisc_sleeping;
	struct kobject___252 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___73 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___67 {
	struct sk_buff___74 *head;
	struct sk_buff___74 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___67;

struct Qdisc___67 {
	int (*enqueue)(struct sk_buff___74 *, struct Qdisc___67 *, struct sk_buff___74 **);
	struct sk_buff___74 * (*dequeue)(struct Qdisc___67 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___67 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___73 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___73 gso_skb;
	struct qdisc_skb_head___67 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___67 *next_sched;
	struct sk_buff_head___73 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___73 {
	struct xdp_rxq_info___73 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___252 kobj;
	struct net_device___73 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___73 {
	enum net_device_path_type type;
	const struct net_device___73 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___73 = 0,
				DEV_PATH_BR_VLAN_TAG___73 = 1,
				DEV_PATH_BR_VLAN_UNTAG___73 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___73 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___73 {
	const struct net_device___73 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___73 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___67 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___73 *offmap;
		};
		struct {
			struct xsk_buff_pool *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___73 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___74 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___73 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___73 *dev;
	const char *name;
};

struct net_device_ops___73 {
	int (*ndo_init)(struct net_device___73 *);
	void (*ndo_uninit)(struct net_device___73 *);
	int (*ndo_open)(struct net_device___73 *);
	int (*ndo_stop)(struct net_device___73 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___74 *, struct net_device___73 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___74 *, struct net_device___73 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___73 *, struct sk_buff___74 *, struct net_device___73 *);
	void (*ndo_change_rx_flags)(struct net_device___73 *, int);
	void (*ndo_set_rx_mode)(struct net_device___73 *);
	int (*ndo_set_mac_address)(struct net_device___73 *, void *);
	int (*ndo_validate_addr)(struct net_device___73 *);
	int (*ndo_do_ioctl)(struct net_device___73 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___73 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___73 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___73 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___73 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___73 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___73 *, int);
	int (*ndo_neigh_setup)(struct net_device___73 *, struct neigh_parms___60 *);
	void (*ndo_tx_timeout)(struct net_device___73 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___73 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___73 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___73 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___73 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___73 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___73 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___73 *);
	int (*ndo_netpoll_setup)(struct net_device___73 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___73 *);
	int (*ndo_set_vf_mac)(struct net_device___73 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___73 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___73 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___73 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___73 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___73 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___73 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___73 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___73 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___73 *, int, struct sk_buff___74 *);
	int (*ndo_get_vf_guid)(struct net_device___73 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___73 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___73 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___73 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___73 *);
	int (*ndo_fcoe_disable)(struct net_device___73 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___73 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___73 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___73 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___73 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___73 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___73 *, const struct sk_buff___74 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___73 *, struct net_device___73 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___73 *, struct net_device___73 *);
	struct net_device___73 * (*ndo_get_xmit_slave)(struct net_device___73 *, struct sk_buff___74 *, bool);
	struct net_device___73 * (*ndo_sk_get_lower_dev)(struct net_device___73 *, struct sock___60 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___73 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___73 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___73 *, struct neighbour___60 *);
	void (*ndo_neigh_destroy)(struct net_device___73 *, struct neighbour___60 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___74 *, struct netlink_callback___73 *, struct net_device___73 *, struct net_device___73 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___74 *, struct nlattr **, struct net_device___73 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___73 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___74 *, u32, u32, struct net_device___73 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___73 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___73 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___73 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___73 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___73 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___73 *, struct net_device___73 *);
	void (*ndo_dfwd_del_station)(struct net_device___73 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___73 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___73 *);
	int (*ndo_change_proto_down)(struct net_device___73 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___73 *, struct sk_buff___74 *);
	void (*ndo_set_rx_headroom)(struct net_device___73 *, int);
	int (*ndo_bpf)(struct net_device___73 *, struct netdev_bpf___73 *);
	int (*ndo_xdp_xmit)(struct net_device___73 *, int, struct xdp_frame___73 **, u32);
	struct net_device___73 * (*ndo_xdp_get_xmit_slave)(struct net_device___73 *, struct xdp_buff___73 *);
	int (*ndo_xsk_wakeup)(struct net_device___73 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___73 *);
	int (*ndo_tunnel_ctl)(struct net_device___73 *, struct ip_tunnel_parm *, int);
	struct net_device___73 * (*ndo_get_peer_dev)(struct net_device___73 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___73 *, struct net_device_path___73 *);
};

struct neigh_parms___60 {
	possible_net_t___73 net;
	struct net_device___73 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___60 *);
	struct neigh_table___60 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___60 {
	u32 (*l3mdev_fib_table)(const struct net_device___73 *);
	struct sk_buff___74 * (*l3mdev_l3_rcv)(struct net_device___73 *, struct sk_buff___74 *, u16);
	struct sk_buff___74 * (*l3mdev_l3_out)(struct net_device___73 *, struct sock___60 *, struct sk_buff___74 *, u16);
	struct dst_entry___60 * (*l3mdev_link_scope_lookup)(const struct net_device___73 *, struct flowi6 *);
};

struct ndisc_ops___43 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___73 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___73 *, struct neighbour___60 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___73 *, u8, struct neighbour___60 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___73 *, struct sk_buff___74 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___78 *, struct net_device___73 *, const struct prefix_info *, struct inet6_dev___43 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___43;

struct inet6_dev___43 {
	struct net_device___73 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___43 *mc_list;
	struct ifmcaddr6___43 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___73 mc_query_queue;
	struct sk_buff_head___73 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___12 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___60 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___67;

struct tcf_block___67;

struct mini_Qdisc___67 {
	struct tcf_proto___67 *filter_list;
	struct tcf_block___67 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___67 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___73 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___73 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___78 *, struct net_device___73 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___73 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___73 *, struct list_head *);
	size_t (*get_size)(const struct net_device___73 *);
	int (*fill_info)(struct sk_buff___74 *, const struct net_device___73 *);
	size_t (*get_xstats_size)(const struct net_device___73 *);
	int (*fill_xstats)(struct sk_buff___74 *, const struct net_device___73 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___73 *, struct net_device___73 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___73 *, const struct net_device___73 *);
	int (*fill_slave_info)(struct sk_buff___74 *, const struct net_device___73 *, const struct net_device___73 *);
	struct net___78 * (*get_link_net)(const struct net_device___73 *);
	size_t (*get_linkxstats_size)(const struct net_device___73 *, int);
	int (*fill_linkxstats)(struct sk_buff___74 *, const struct net_device___73 *, int *, int);
};

struct gnet_dump___67 {
	spinlock_t *lock;
	struct sk_buff___74 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___67;

struct Qdisc_ops___67 {
	struct Qdisc_ops___67 *next;
	const struct Qdisc_class_ops___67 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___74 *, struct Qdisc___67 *, struct sk_buff___74 **);
	struct sk_buff___74 * (*dequeue)(struct Qdisc___67 *);
	struct sk_buff___74 * (*peek)(struct Qdisc___67 *);
	int (*init)(struct Qdisc___67 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___67 *);
	void (*destroy)(struct Qdisc___67 *);
	int (*change)(struct Qdisc___67 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___67 *);
	int (*change_tx_queue_len)(struct Qdisc___67 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___67 *, unsigned int);
	int (*dump)(struct Qdisc___67 *, struct sk_buff___74 *);
	int (*dump_stats)(struct Qdisc___67 *, struct gnet_dump___67 *);
	void (*ingress_block_set)(struct Qdisc___67 *, u32);
	void (*egress_block_set)(struct Qdisc___67 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___67 *);
	u32 (*egress_block_get)(struct Qdisc___67 *);
	struct module___248 *owner;
};

struct Qdisc_class_ops___67 {
	unsigned int flags;
	struct netdev_queue___73 * (*select_queue)(struct Qdisc___67 *, struct tcmsg *);
	int (*graft)(struct Qdisc___67 *, long unsigned int, struct Qdisc___67 *, struct Qdisc___67 **, struct netlink_ext_ack *);
	struct Qdisc___67 * (*leaf)(struct Qdisc___67 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___67 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___67 *, u32);
	int (*change)(struct Qdisc___67 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___67 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___67 *, struct qdisc_walker *);
	struct tcf_block___67 * (*tcf_block)(struct Qdisc___67 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___67 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___67 *, long unsigned int);
	int (*dump)(struct Qdisc___67 *, long unsigned int, struct sk_buff___74 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___67 *, long unsigned int, struct gnet_dump___67 *);
};

struct tcf_chain___67;

struct tcf_block___67 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___78 *net;
	struct Qdisc___67 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___67 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___67;

struct tcf_proto_ops___67;

struct tcf_proto___67 {
	struct tcf_proto___67 *next;
	void *root;
	int (*classify)(struct sk_buff___74 *, const struct tcf_proto___67 *, struct tcf_result___67 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___67 *ops;
	struct tcf_chain___67 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___67 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___67 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___67 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___74 *, const struct tcf_proto___67 *, struct tcf_result___67 *);
	int (*init)(struct tcf_proto___67 *);
	void (*destroy)(struct tcf_proto___67 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___67 *, u32);
	void (*put)(struct tcf_proto___67 *, void *);
	int (*change)(struct net___78 *, struct sk_buff___74 *, struct tcf_proto___67 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___67 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___67 *);
	void (*walk)(struct tcf_proto___67 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___67 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___67 *, void *);
	void (*hw_del)(struct tcf_proto___67 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___78 *, struct tcf_chain___67 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___78 *, struct tcf_proto___67 *, void *, struct sk_buff___74 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___78 *, struct tcf_proto___67 *, void *, struct sk_buff___74 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___74 *, struct net___78 *, void *);
	struct module___248 *owner;
	int flags;
};

struct tcf_chain___67 {
	struct mutex filter_chain_lock;
	struct tcf_proto___67 *filter_chain;
	struct list_head list;
	struct tcf_block___67 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___67 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___60 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___67 *prog;
};

struct bpf_sk_lookup_kern___3 {
	u16 family;
	u16 protocol;
	__be16 sport;
	u16 dport;
	struct {
		__be32 saddr;
		__be32 daddr;
	} v4;
	struct {
		const struct in6_addr *saddr;
		const struct in6_addr *daddr;
	} v6;
	struct sock___60 *selected_sk;
	bool no_reuseport;
};

struct block_device_operations___155;

struct gendisk___158 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___158 *part0;
	const struct block_device_operations___155 *fops;
	struct request_queue___155 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___141 *bdi;
	struct kobject___252 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___252 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___155 {
	struct bio___155 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___181 *bip_vec;
	struct bio_vec___181 bip_inline_vecs[0];
};

struct blkcg___143;

struct blkg_policy_data___143;

struct blkcg_gq___143 {
	struct request_queue___155 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___143 *blkcg;
	struct blkcg_gq___143 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___143 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___155 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___155(struct request___155 *);

typedef void integrity_complete_fn___155(struct request___155 *, unsigned int);

struct blk_integrity_profile___155 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___155 *prepare_fn;
	integrity_complete_fn___155 *complete_fn;
	const char *name;
};

struct block_device_operations___155 {
	blk_qc_t (*submit_bio)(struct bio___155 *);
	int (*open)(struct block_device___158 *, fmode_t);
	void (*release)(struct gendisk___158 *, fmode_t);
	int (*rw_page)(struct block_device___158 *, sector_t, struct page___269 *, unsigned int);
	int (*ioctl)(struct block_device___158 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___158 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___158 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___158 *);
	int (*getgeo)(struct block_device___158 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___158 *, bool);
	void (*swap_slot_free_notify)(struct block_device___158 *, long unsigned int);
	int (*report_zones)(struct gendisk___158 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___158 *, umode_t *);
	struct module___248 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___158 *, sector_t *);
};

typedef void rq_end_io_fn___155(struct request___155 *, blk_status_t);

struct request___155 {
	struct request_queue___155 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___150 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___155 *bio;
	struct bio___155 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___181 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___155 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___155 *saved_end_io;
		} flush;
	};
	struct gendisk___158 *rq_disk;
	struct block_device___158 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___155 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___150 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___155 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___252 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___264 *debugfs_dir;
	struct dentry___264 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___155;

struct elevator_mq_ops___155 {
	int (*init_sched)(struct request_queue___155 *, struct elevator_type___155 *);
	void (*exit_sched)(struct elevator_queue___155 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___150 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___150 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___150 *);
	bool (*allow_merge)(struct request_queue___155 *, struct request___155 *, struct bio___155 *);
	bool (*bio_merge)(struct request_queue___155 *, struct bio___155 *, unsigned int);
	int (*request_merge)(struct request_queue___155 *, struct request___155 **, struct bio___155 *);
	void (*request_merged)(struct request_queue___155 *, struct request___155 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___155 *, struct request___155 *, struct request___155 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___155 *);
	void (*finish_request)(struct request___155 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___150 *, struct list_head *, bool);
	struct request___155 * (*dispatch_request)(struct blk_mq_hw_ctx___150 *);
	bool (*has_work)(struct blk_mq_hw_ctx___150 *);
	void (*completed_request)(struct request___155 *, u64);
	void (*requeue_request)(struct request___155 *);
	struct request___155 * (*former_request)(struct request_queue___155 *, struct request___155 *);
	struct request___155 * (*next_request)(struct request_queue___155 *, struct request___155 *);
	void (*init_icq)(struct io_cq___155 *);
	void (*exit_icq)(struct io_cq___155 *);
};

struct elv_fs_entry___155;

struct elevator_type___155 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___155 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___155 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___248 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___155 {
	struct elevator_type___155 *type;
	void *elevator_data;
	struct kobject___252 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___155 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___155 *, char *);
	ssize_t (*store)(struct elevator_queue___155 *, const char *, size_t);
};

struct blk_mq_queue_data___150;

struct blk_mq_ops___150 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___150 *, const struct blk_mq_queue_data___150 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___150 *);
	int (*get_budget)(struct request_queue___155 *);
	void (*put_budget)(struct request_queue___155 *, int);
	void (*set_rq_budget_token)(struct request___155 *, int);
	int (*get_rq_budget_token)(struct request___155 *);
	enum blk_eh_timer_return (*timeout)(struct request___155 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___150 *);
	void (*complete)(struct request___155 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___150 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___150 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___150 *, struct request___155 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___150 *, struct request___155 *, unsigned int);
	void (*initialize_rq_fn)(struct request___155 *);
	void (*cleanup_rq)(struct request___155 *);
	bool (*busy)(struct request_queue___155 *);
	int (*map_queues)(struct blk_mq_tag_set___150 *);
	void (*show_rq)(struct seq_file___239 *, struct request___155 *);
};

struct blk_mq_tag_set___150 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___150 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___150 {
	struct request___155 *rq;
	bool last;
};

struct blkcg_policy_data___143;

struct blkcg___143 {
	struct cgroup_subsys_state___191 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___143 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___143 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___143 {
	struct blkcg___143 *blkcg;
	int plid;
};

struct blkg_policy_data___143 {
	struct blkcg_gq___143 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___129 {
	struct mem_cgroup___129 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___129 {
	struct lruvec___137 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___129 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___129 *memcg;
};

struct obj_cgroup___129 {
	struct percpu_ref refcnt;
	struct mem_cgroup___129 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___60;

struct neigh_hash_table___60;

struct neigh_table___60 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___73 *, __u32 *);
	bool (*key_eq)(const struct neighbour___60 *, const void *);
	int (*constructor)(struct neighbour___60 *);
	int (*pconstructor)(struct pneigh_entry___60 *);
	void (*pdestructor)(struct pneigh_entry___60 *);
	void (*proxy_redo)(struct sk_buff___74 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___73 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___60 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___73 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___60 *nht;
	struct pneigh_entry___60 **phash_buckets;
};

struct neigh_ops___60 {
	int family;
	void (*solicit)(struct neighbour___60 *, struct sk_buff___74 *);
	void (*error_report)(struct neighbour___60 *, struct sk_buff___74 *);
	int (*output)(struct neighbour___60 *, struct sk_buff___74 *);
	int (*connected_output)(struct neighbour___60 *, struct sk_buff___74 *);
};

struct pneigh_entry___60 {
	struct pneigh_entry___60 *next;
	possible_net_t___73 net;
	struct net_device___73 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___60 {
	struct neighbour___60 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___37 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___78 *, struct sock___60 *, struct sk_buff___74 *);
	int (*orig_input)(struct sk_buff___74 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___60 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___60 *ctarget;
	struct net___78 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___60 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___60 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___46;

struct timewait_sock_ops___45;

struct proto___60 {
	void (*close)(struct sock___60 *, long int);
	int (*pre_connect)(struct sock___60 *, struct sockaddr *, int);
	int (*connect)(struct sock___60 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___60 *, int);
	struct sock___60 * (*accept)(struct sock___60 *, int, int *, bool);
	int (*ioctl)(struct sock___60 *, int, long unsigned int);
	int (*init)(struct sock___60 *);
	void (*destroy)(struct sock___60 *);
	void (*shutdown)(struct sock___60 *, int);
	int (*setsockopt)(struct sock___60 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___60 *, int, int, char *, int *);
	void (*keepalive)(struct sock___60 *, int);
	int (*compat_ioctl)(struct sock___60 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___60 *, struct msghdr___62 *, size_t);
	int (*recvmsg)(struct sock___60 *, struct msghdr___62 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___60 *, struct page___269 *, int, size_t, int);
	int (*bind)(struct sock___60 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___60 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___60 *, struct sk_buff___74 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___60 *);
	int (*hash)(struct sock___60 *);
	void (*unhash)(struct sock___60 *);
	void (*rehash)(struct sock___60 *);
	int (*get_port)(struct sock___60 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___60 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___60 *, int);
	bool (*sock_is_readable)(struct sock___60 *);
	void (*enter_memory_pressure)(struct sock___60 *);
	void (*leave_memory_pressure)(struct sock___60 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___46 *rsk_prot;
	struct timewait_sock_ops___45 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___248 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___60 *, int);
};

struct sock_reuseport___14 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___67 *prog;
	struct sock___60 *socks[0];
};

struct request_sock___47;

struct request_sock_ops___46 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___60 *, struct request_sock___47 *);
	void (*send_ack)(const struct sock___60 *, struct sk_buff___74 *, struct request_sock___47 *);
	void (*send_reset)(const struct sock___60 *, struct sk_buff___74 *);
	void (*destructor)(struct request_sock___47 *);
	void (*syn_ack_timeout)(const struct request_sock___47 *);
};

struct timewait_sock_ops___45 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___60 *, struct sock___60 *, void *);
	void (*twsk_destructor)(struct sock___60 *);
};

struct bpf_local_storage_data___9 {
	struct bpf_local_storage_map___9 *smap;
	u8 data[0];
};

struct request_sock___47 {
	struct sock_common___60 __req_common;
	struct request_sock___47 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___46 *rsk_ops;
	struct sock___60 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___43 {
	struct in6_addr mca_addr;
	struct inet6_dev___43 *idev;
	struct ifmcaddr6___43 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct perf_cpu_context___87;

struct perf_output_handle___87;

struct pmu___87 {
	struct list_head entry;
	struct module___248 *module;
	struct device___245 *dev;
	const struct attribute_group___252 **attr_groups;
	const struct attribute_group___252 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___87 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___87 *);
	void (*pmu_disable)(struct pmu___87 *);
	int (*event_init)(struct perf_event___87 *);
	void (*event_mapped)(struct perf_event___87 *, struct mm_struct___270 *);
	void (*event_unmapped)(struct perf_event___87 *, struct mm_struct___270 *);
	int (*add)(struct perf_event___87 *, int);
	void (*del)(struct perf_event___87 *, int);
	void (*start)(struct perf_event___87 *, int);
	void (*stop)(struct perf_event___87 *, int);
	void (*read)(struct perf_event___87 *);
	void (*start_txn)(struct pmu___87 *, unsigned int);
	int (*commit_txn)(struct pmu___87 *);
	void (*cancel_txn)(struct pmu___87 *);
	int (*event_idx)(struct perf_event___87 *);
	void (*sched_task)(struct perf_event_context___87 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___87 *, struct perf_event_context___87 *);
	void * (*setup_aux)(struct perf_event___87 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___87 *, struct perf_output_handle___87 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___87 *);
	int (*aux_output_match)(struct perf_event___87 *);
	int (*filter_match)(struct perf_event___87 *);
	int (*check_period)(struct perf_event___87 *, u64);
};

struct perf_cpu_context___87 {
	struct perf_event_context___87 ctx;
	struct perf_event_context___87 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___87 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___87 **heap;
	struct perf_event___87 *heap_default[2];
};

struct perf_output_handle___87 {
	struct perf_event___87 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___87 {
	struct cgroup_subsys_state___191 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___81 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___81 *);
	};
};

struct trace_event_class___81 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___81 *, enum trace_reg, void *);
	struct trace_event_fields___81 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___81 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___81 *);
};

struct trace_event_file___41;

struct trace_event_buffer___40 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___41 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___41 {
	struct list_head list;
	struct trace_event_call___81 *event_call;
	struct event_filter *filter;
	struct dentry___264 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_bpf_test_finish {
	struct trace_entry ent;
	int err;
	char __data[0];
};

struct trace_event_data_offsets_bpf_test_finish {};

typedef void (*btf_trace_bpf_test_finish)(void *, int *);

struct bpf_test_timer {
	enum {
		NO_PREEMPT = 0,
		NO_MIGRATE = 1,
	} mode;
	u32 i;
	u64 time_start;
	u64 time_spent;
};

struct bpf_fentry_test_t {
	struct bpf_fentry_test_t *a;
};

struct bpf_raw_tp_test_run_info {
	struct bpf_prog___67 *prog;
	void *ctx;
	u32 retval;
};

struct dentry___265;

struct super_block___265;

struct module___249;

struct file_system_type___265 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___265 * (*mount)(struct file_system_type___265 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___265 *);
	struct module___249 *owner;
	struct file_system_type___265 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___265;

struct kiocb___265;

struct iov_iter___185;

struct poll_table_struct___186;

struct vm_area_struct___270;

struct inode___265;

struct file_lock___265;

struct page___270;

struct pipe_inode_info___106;

struct seq_file___240;

struct file_operations___266 {
	struct module___249 *owner;
	loff_t (*llseek)(struct file___265 *, loff_t, int);
	ssize_t (*read)(struct file___265 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___265 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___265 *, struct iov_iter___185 *);
	ssize_t (*write_iter)(struct kiocb___265 *, struct iov_iter___185 *);
	int (*iopoll)(struct kiocb___265 *, bool);
	int (*iterate)(struct file___265 *, struct dir_context *);
	int (*iterate_shared)(struct file___265 *, struct dir_context *);
	__poll_t (*poll)(struct file___265 *, struct poll_table_struct___186 *);
	long int (*unlocked_ioctl)(struct file___265 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___265 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___265 *, struct vm_area_struct___270 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___265 *, struct file___265 *);
	int (*flush)(struct file___265 *, fl_owner_t);
	int (*release)(struct inode___265 *, struct file___265 *);
	int (*fsync)(struct file___265 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___265 *, int);
	int (*lock)(struct file___265 *, int, struct file_lock___265 *);
	ssize_t (*sendpage)(struct file___265 *, struct page___270 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___265 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___265 *, long unsigned int);
	int (*flock)(struct file___265 *, int, struct file_lock___265 *);
	ssize_t (*splice_write)(struct pipe_inode_info___106 *, struct file___265 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___265 *, loff_t *, struct pipe_inode_info___106 *, size_t, unsigned int);
	int (*setlease)(struct file___265 *, long int, struct file_lock___265 **, void **);
	long int (*fallocate)(struct file___265 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___240 *, struct file___265 *);
	ssize_t (*copy_file_range)(struct file___265 *, loff_t, struct file___265 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___265 *, loff_t, struct file___265 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___265 *, loff_t, loff_t, int);
};

struct vmacache___270 {
	u64 seqnum;
	struct vm_area_struct___270 *vmas[4];
};

struct page_frag___270 {
	struct page___270 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___271;

struct pid___242;

struct nsproxy___251;

struct signal_struct___266;

struct bio_list___156;

struct backing_dev_info___142;

struct io_context___156;

struct css_set___192;

struct mem_cgroup___130;

struct request_queue___156;

struct vm_struct___248;

struct task_struct___272 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___272 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___271 *mm;
	struct mm_struct___271 *active_mm;
	struct vmacache___270 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___272 *real_parent;
	struct task_struct___272 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___272 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___242 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___251 *nsproxy;
	struct signal_struct___266 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___272 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___156 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___142 *backing_dev_info;
	struct io_context___156 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___192 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___106 *splice_pipe;
	struct page_frag___270 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___130 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___130 *active_memcg;
	struct request_queue___156 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___272 *oom_reaper_list;
	struct vm_struct___248 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___253;

struct kobj_type___253;

struct kernfs_node___253;

struct kobject___253 {
	const char *name;
	struct list_head entry;
	struct kobject___253 *parent;
	struct kset___253 *kset;
	struct kobj_type___253 *ktype;
	struct kernfs_node___253 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___250 {
	struct kobject___253 kobj;
	struct module___249 *mod;
	struct kobject___253 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___249 {
	struct module___249 *mod;
	struct latch_tree_node node;
};

struct module_layout___249 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___249 mtn;
};

struct module_attribute___249;

struct kernel_param___249;

struct module___249 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___250 mkobj;
	struct module_attribute___249 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___253 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___249 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___249 core_layout;
	struct module_layout___249 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___242;

struct upid___242 {
	int nr;
	struct pid_namespace___242 *ns;
};

struct pid_namespace___242 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___272 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___242 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___242 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___242 numbers[1];
};

typedef struct page___270 *pgtable_t___270;

struct address_space___265;

struct page_pool___94;

struct dev_pagemap___260;

struct page___270 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___265 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___94 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___270 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___270 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___271 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___260 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___260;

struct vm_area_struct___270 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___270 *vm_next;
	struct vm_area_struct___270 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___271 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___260 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___265 *vm_file;
	struct file___265 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___266 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___272 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___272 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___242 *pids[4];
	struct pid___242 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___271 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___270;

struct mm_struct___271 {
	struct {
		struct vm_area_struct___270 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___265 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___270 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___272 *owner;
		struct user_namespace___26 *user_ns;
		struct file___265 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___79;

struct cgroup_namespace___192;

struct nsproxy___251 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___242 *pid_ns_for_children;
	struct net___79 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___192 *cgroup_ns;
};

struct bio___156;

struct bio_list___156 {
	struct bio___156 *head;
	struct bio___156 *tail;
};

struct cgroup_subsys_state___192;

struct bdi_writeback___142 {
	struct backing_dev_info___142 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___192 *memcg_css;
	struct cgroup_subsys_state___192 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___246;

struct backing_dev_info___142 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___142 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___246 *dev;
	char dev_name[64];
	struct device___246 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___265 *debug_dir;
};

struct io_cq___156;

struct io_context___156 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___156 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___192;

struct css_set___192 {
	struct cgroup_subsys_state___192 *subsys[14];
	refcount_t refcount;
	struct css_set___192 *dom_cset;
	struct cgroup___192 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___192 *mg_src_cgrp;
	struct cgroup___192 *mg_dst_cgrp;
	struct css_set___192 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___265;

struct pipe_buffer___106;

struct pipe_inode_info___106 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___270 *tmp_page;
	struct fasync_struct___265 *fasync_readers;
	struct fasync_struct___265 *fasync_writers;
	struct pipe_buffer___106 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___192;

struct cgroup_subsys_state___192 {
	struct cgroup___192 *cgroup;
	struct cgroup_subsys___192 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___192 *parent;
};

struct cgroup_file___192 {
	struct kernfs_node___253 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___130;

struct mem_cgroup_per_node___130;

struct mem_cgroup___130 {
	struct cgroup_subsys_state___192 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___192 events_file;
	struct cgroup_file___192 events_local_file;
	struct cgroup_file___192 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___130 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___272 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___130 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___156;

struct blk_integrity___156 {
	const struct blk_integrity_profile___156 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___156 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___156 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___156;

struct elevator_queue___156;

struct blk_mq_ops___151;

struct blk_mq_hw_ctx___151;

struct gendisk___159;

struct blkcg_gq___144;

struct blk_mq_tag_set___151;

struct request_queue___156 {
	struct request___156 *last_merge;
	struct elevator_queue___156 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___151 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___151 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___159 *disk;
	struct kobject___253 kobj;
	struct kobject___253 *mq_kobj;
	struct blk_integrity___156 integrity;
	struct device___246 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___144 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___151 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___156 bio_split;
	struct dentry___265 *debugfs_dir;
	struct dentry___265 *sched_debugfs_dir;
	struct dentry___265 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___248 {
	struct vm_struct___248 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___270 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___182 {
	struct page___270 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___185 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___182 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___106 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___63 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___185 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___265 *msg_iocb;
};

struct kiocb___265 {
	struct file___265 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___265 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct dentry_operations___265;

struct dentry___265 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___265 *d_parent;
	struct qstr d_name;
	struct inode___265 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___265 *d_op;
	struct super_block___265 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___265;

struct address_space___265 {
	struct inode___265 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___265 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___265;

struct inode___265 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___265 *i_op;
	struct super_block___265 *i_sb;
	struct address_space___265 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___142 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___266 *i_fop;
		void (*free_inode)(struct inode___265 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___265 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___106 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___265;

struct path___265;

struct dentry_operations___265 {
	int (*d_revalidate)(struct dentry___265 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___265 *, unsigned int);
	int (*d_hash)(const struct dentry___265 *, struct qstr *);
	int (*d_compare)(const struct dentry___265 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___265 *);
	int (*d_init)(struct dentry___265 *);
	void (*d_release)(struct dentry___265 *);
	void (*d_prune)(struct dentry___265 *);
	void (*d_iput)(struct dentry___265 *, struct inode___265 *);
	char * (*d_dname)(struct dentry___265 *, char *, int);
	struct vfsmount___265 * (*d_automount)(struct path___265 *);
	int (*d_manage)(const struct path___265 *, bool);
	struct dentry___265 * (*d_real)(struct dentry___265 *, const struct inode___265 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___265;

struct mem_dqinfo___265 {
	struct quota_format_type___265 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___265;

struct quota_info___265 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___265 *files[3];
	struct mem_dqinfo___265 info[3];
	const struct quota_format_ops___265 *ops[3];
};

struct rcuwait___266 {
	struct task_struct___272 *task;
};

struct percpu_rw_semaphore___266 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___266 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___265 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___266 rw_sem[3];
};

struct shrink_control___130;

struct shrinker___130 {
	long unsigned int (*count_objects)(struct shrinker___130 *, struct shrink_control___130 *);
	long unsigned int (*scan_objects)(struct shrinker___130 *, struct shrink_control___130 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___265;

struct dquot_operations___265;

struct quotactl_ops___265;

struct block_device___159;

struct super_block___265 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___265 *s_type;
	const struct super_operations___265 *s_op;
	const struct dquot_operations___265 *dq_op;
	const struct quotactl_ops___265 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___265 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___159 *s_bdev;
	struct backing_dev_info___142 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___265 s_dquot;
	struct sb_writers___265 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___265 *s_d_op;
	int cleancache_poolid;
	struct shrinker___130 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___265 {
	struct dentry___265 *mnt_root;
	struct super_block___265 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___265 {
	struct vfsmount___265 *mnt;
	struct dentry___265 *dentry;
};

struct shrink_control___130 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___130 *memcg;
};

struct page_pool_params___94 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___246 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___94 {
	u32 count;
	struct page___270 *cache[128];
};

struct page_pool___94 {
	struct page_pool_params___94 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___270 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___94 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___260;

struct dev_pagemap___260 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___260 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___242 {
	rwlock_t lock;
	struct pid___242 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___265 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___265 f_path;
	struct inode___265 *f_inode;
	const struct file_operations___266 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___242 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___265 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___260;

struct vm_operations_struct___260 {
	void (*open)(struct vm_area_struct___270 *);
	void (*close)(struct vm_area_struct___270 *);
	int (*may_split)(struct vm_area_struct___270 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___270 *);
	int (*mprotect)(struct vm_area_struct___270 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___260 *);
	vm_fault_t (*huge_fault)(struct vm_fault___260 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___260 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___270 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___260 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___260 *);
	int (*access)(struct vm_area_struct___270 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___270 *);
	int (*set_policy)(struct vm_area_struct___270 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___270 *, long unsigned int);
	struct page___270 * (*find_special_page)(struct vm_area_struct___270 *, long unsigned int);
};

struct core_thread___270 {
	struct task_struct___272 *task;
	struct core_thread___270 *next;
};

struct core_state___270 {
	atomic_t nr_threads;
	struct core_thread___270 dumper;
	struct completion startup;
};

struct vm_fault___260 {
	const struct {
		struct vm_area_struct___270 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___270 *cow_page;
	struct page___270 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___270 prealloc_pte;
};

struct pglist_data___138;

struct lruvec___138 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___138 *pgdat;
};

struct zone___138 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___138 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___138 {
	struct zone___138 *zone;
	int zone_idx;
};

struct zonelist___138 {
	struct zoneref___138 _zonerefs[321];
};

struct pglist_data___138 {
	struct zone___138 node_zones[5];
	struct zonelist___138 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___272 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___272 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___138 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___192 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___272 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___68;

struct cgroup_bpf___68 {
	struct bpf_prog_array___68 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___68 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___192;

struct cgroup_rstat_cpu___192;

struct cgroup___192 {
	struct cgroup_subsys_state___192 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___253 *kn;
	struct cgroup_file___192 procs_file;
	struct cgroup_file___192 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___192 *subsys[14];
	struct cgroup_root___192 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___192 *dom_cgrp;
	struct cgroup___192 *old_dom_cgrp;
	struct cgroup_rstat_cpu___192 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___192 psi;
	struct cgroup_bpf___68 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___156 {
	struct request_queue___156 *q;
	struct io_context___156 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___265 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___265 *ia_file;
};

struct dquot___265 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___265 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___265 {
	int qf_fmt_id;
	const struct quota_format_ops___265 *qf_ops;
	struct module___249 *qf_owner;
	struct quota_format_type___265 *qf_next;
};

struct quota_format_ops___265 {
	int (*check_quota_file)(struct super_block___265 *, int);
	int (*read_file_info)(struct super_block___265 *, int);
	int (*write_file_info)(struct super_block___265 *, int);
	int (*free_file_info)(struct super_block___265 *, int);
	int (*read_dqblk)(struct dquot___265 *);
	int (*commit_dqblk)(struct dquot___265 *);
	int (*release_dqblk)(struct dquot___265 *);
	int (*get_next_id)(struct super_block___265 *, struct kqid *);
};

struct dquot_operations___265 {
	int (*write_dquot)(struct dquot___265 *);
	struct dquot___265 * (*alloc_dquot)(struct super_block___265 *, int);
	void (*destroy_dquot)(struct dquot___265 *);
	int (*acquire_dquot)(struct dquot___265 *);
	int (*release_dquot)(struct dquot___265 *);
	int (*mark_dirty)(struct dquot___265 *);
	int (*write_info)(struct super_block___265 *, int);
	qsize_t * (*get_reserved_space)(struct inode___265 *);
	int (*get_projid)(struct inode___265 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___265 *, qsize_t *);
	int (*get_next_id)(struct super_block___265 *, struct kqid *);
};

struct quotactl_ops___265 {
	int (*quota_on)(struct super_block___265 *, int, int, const struct path___265 *);
	int (*quota_off)(struct super_block___265 *, int);
	int (*quota_enable)(struct super_block___265 *, unsigned int);
	int (*quota_disable)(struct super_block___265 *, unsigned int);
	int (*quota_sync)(struct super_block___265 *, int);
	int (*set_info)(struct super_block___265 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___265 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___265 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___265 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___265 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___265 *, unsigned int);
};

struct writeback_control___142;

struct address_space_operations___265 {
	int (*writepage)(struct page___270 *, struct writeback_control___142 *);
	int (*readpage)(struct file___265 *, struct page___270 *);
	int (*writepages)(struct address_space___265 *, struct writeback_control___142 *);
	int (*set_page_dirty)(struct page___270 *);
	int (*readpages)(struct file___265 *, struct address_space___265 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___265 *, struct address_space___265 *, loff_t, unsigned int, unsigned int, struct page___270 **, void **);
	int (*write_end)(struct file___265 *, struct address_space___265 *, loff_t, unsigned int, unsigned int, struct page___270 *, void *);
	sector_t (*bmap)(struct address_space___265 *, sector_t);
	void (*invalidatepage)(struct page___270 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___270 *, gfp_t);
	void (*freepage)(struct page___270 *);
	ssize_t (*direct_IO)(struct kiocb___265 *, struct iov_iter___185 *);
	int (*migratepage)(struct address_space___265 *, struct page___270 *, struct page___270 *, enum migrate_mode);
	bool (*isolate_page)(struct page___270 *, isolate_mode_t);
	void (*putback_page)(struct page___270 *);
	int (*launder_page)(struct page___270 *);
	int (*is_partially_uptodate)(struct page___270 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___270 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___265 *, struct page___270 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___265 *, sector_t *);
	void (*swap_deactivate)(struct file___265 *);
};

struct writeback_control___142 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___142 *wb;
	struct inode___265 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___265 {
	struct dentry___265 * (*lookup)(struct inode___265 *, struct dentry___265 *, unsigned int);
	const char * (*get_link)(struct dentry___265 *, struct inode___265 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___265 *, int);
	struct posix_acl * (*get_acl)(struct inode___265 *, int, bool);
	int (*readlink)(struct dentry___265 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___265 *, struct dentry___265 *, umode_t, bool);
	int (*link)(struct dentry___265 *, struct inode___265 *, struct dentry___265 *);
	int (*unlink)(struct inode___265 *, struct dentry___265 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___265 *, struct dentry___265 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___265 *, struct dentry___265 *, umode_t);
	int (*rmdir)(struct inode___265 *, struct dentry___265 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___265 *, struct dentry___265 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___265 *, struct dentry___265 *, struct inode___265 *, struct dentry___265 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___265 *, struct iattr___265 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___265 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___265 *, char *, size_t);
	int (*fiemap)(struct inode___265 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___265 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___265 *, struct dentry___265 *, struct file___265 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___265 *, struct dentry___265 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___265 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___265 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___265 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___265 {
	void (*fl_copy_lock)(struct file_lock___265 *, struct file_lock___265 *);
	void (*fl_release_private)(struct file_lock___265 *);
};

struct lock_manager_operations___265;

struct file_lock___265 {
	struct file_lock___265 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___265 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___265 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___265 *fl_ops;
	const struct lock_manager_operations___265 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___265 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___265 *);
	int (*lm_grant)(struct file_lock___265 *, int);
	bool (*lm_break)(struct file_lock___265 *);
	int (*lm_change)(struct file_lock___265 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___265 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___265 *);
};

struct fasync_struct___265 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___265 *fa_next;
	struct file___265 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___265 {
	struct inode___265 * (*alloc_inode)(struct super_block___265 *);
	void (*destroy_inode)(struct inode___265 *);
	void (*free_inode)(struct inode___265 *);
	void (*dirty_inode)(struct inode___265 *, int);
	int (*write_inode)(struct inode___265 *, struct writeback_control___142 *);
	int (*drop_inode)(struct inode___265 *);
	void (*evict_inode)(struct inode___265 *);
	void (*put_super)(struct super_block___265 *);
	int (*sync_fs)(struct super_block___265 *, int);
	int (*freeze_super)(struct super_block___265 *);
	int (*freeze_fs)(struct super_block___265 *);
	int (*thaw_super)(struct super_block___265 *);
	int (*unfreeze_fs)(struct super_block___265 *);
	int (*statfs)(struct dentry___265 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___265 *, int *, char *);
	void (*umount_begin)(struct super_block___265 *);
	int (*show_options)(struct seq_file___240 *, struct dentry___265 *);
	int (*show_devname)(struct seq_file___240 *, struct dentry___265 *);
	int (*show_path)(struct seq_file___240 *, struct dentry___265 *);
	int (*show_stats)(struct seq_file___240 *, struct dentry___265 *);
	ssize_t (*quota_read)(struct super_block___265 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___265 *, int, const char *, size_t, loff_t);
	struct dquot___265 ** (*get_dquots)(struct inode___265 *);
	long int (*nr_cached_objects)(struct super_block___265 *, struct shrink_control___130 *);
	long int (*free_cached_objects)(struct super_block___265 *, struct shrink_control___130 *);
	struct file___265 * (*real_loop)(struct file___265 *);
};

struct wakeup_source___246;

struct dev_pm_info___246 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___246 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___246 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___246;

struct bus_type___246;

struct device_driver___246;

struct dev_pm_domain___246;

struct fwnode_handle___242;

struct class___246;

struct attribute_group___253;

struct device___246 {
	struct kobject___253 kobj;
	struct device___246 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___246 *type;
	struct bus_type___246 *bus;
	struct device_driver___246 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___246 power;
	struct dev_pm_domain___246 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___242 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___246 *class;
	const struct attribute_group___253 **groups;
	void (*release)(struct device___246 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___159 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___265 *bd_inode;
	struct super_block___265 *bd_super;
	void *bd_claiming;
	struct device___246 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___253 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___159 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___265 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___194)(struct file___265 *, wait_queue_head_t *, struct poll_table_struct___186 *);

struct poll_table_struct___186 {
	poll_queue_proc___194 _qproc;
	__poll_t _key;
};

struct seq_operations___240;

struct seq_file___240 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___240 *op;
	int poll_event;
	const struct file___265 *file;
	void *private;
};

typedef void bio_end_io_t___156(struct bio___156 *);

struct bio_integrity_payload___156;

struct bio___156 {
	struct bio___156 *bi_next;
	struct block_device___159 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___156 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___144 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___156 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___182 *bi_io_vec;
	struct bio_set___156 *bi_pool;
	struct bio_vec___182 bi_inline_vecs[0];
};

struct kernfs_root___253;

struct kernfs_elem_dir___253 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___253 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___253;

struct kernfs_root___253 {
	struct kernfs_node___253 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___253 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___253 {
	struct kernfs_node___253 *target_kn;
};

struct kernfs_ops___253;

struct kernfs_elem_attr___253 {
	const struct kernfs_ops___253 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___253 *notify_next;
};

struct kernfs_node___253 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___253 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___253 dir;
		struct kernfs_elem_symlink___253 symlink;
		struct kernfs_elem_attr___253 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___253;

struct kernfs_ops___253 {
	int (*open)(struct kernfs_open_file___253 *);
	void (*release)(struct kernfs_open_file___253 *);
	int (*seq_show)(struct seq_file___240 *, void *);
	void * (*seq_start)(struct seq_file___240 *, loff_t *);
	void * (*seq_next)(struct seq_file___240 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___240 *, void *);
	ssize_t (*read)(struct kernfs_open_file___253 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___253 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___253 *, struct poll_table_struct___186 *);
	int (*mmap)(struct kernfs_open_file___253 *, struct vm_area_struct___270 *);
};

struct kernfs_syscall_ops___253 {
	int (*show_options)(struct seq_file___240 *, struct kernfs_root___253 *);
	int (*mkdir)(struct kernfs_node___253 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___253 *);
	int (*rename)(struct kernfs_node___253 *, struct kernfs_node___253 *, const char *);
	int (*show_path)(struct seq_file___240 *, struct kernfs_node___253 *, struct kernfs_root___253 *);
};

struct kernfs_open_file___253 {
	struct kernfs_node___253 *kn;
	struct file___265 *file;
	struct seq_file___240 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___260 *vm_ops;
};

struct sock___61;

struct kobj_ns_type_operations___61 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___61 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___79 *net;
} possible_net_t___74;

struct proto___61;

struct sock_common___61 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___61 *skc_prot;
	possible_net_t___74 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___61 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___75;

struct sk_buff_head___74 {
	struct sk_buff___75 *next;
	struct sk_buff___75 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___61 {
	struct cgroup___192 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___61;

struct socket_wq___62;

struct dst_entry___61;

struct socket___63;

struct net_device___74;

struct sock___61 {
	struct sock_common___61 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___74 sk_error_queue;
	struct sk_buff___75 *sk_rx_skb_cache;
	struct sk_buff_head___74 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___75 *head;
		struct sk_buff___75 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___61 *sk_filter;
	union {
		struct socket_wq___62 *sk_wq;
		struct socket_wq___62 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___61 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___61 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___75 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___75 *sk_tx_skb_cache;
	struct sk_buff_head___74 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___270 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___61 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___242 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___63 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___61 sk_cgrp_data;
	struct mem_cgroup___130 *sk_memcg;
	void (*sk_state_change)(struct sock___61 *);
	void (*sk_data_ready)(struct sock___61 *);
	void (*sk_write_space)(struct sock___61 *);
	void (*sk_error_report)(struct sock___61 *);
	int (*sk_backlog_rcv)(struct sock___61 *, struct sk_buff___75 *);
	struct sk_buff___75 * (*sk_validate_xmit_skb)(struct sock___61 *, struct net_device___74 *, struct sk_buff___75 *);
	void (*sk_destruct)(struct sock___61 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___253;

struct attribute_group___253 {
	const char *name;
	umode_t (*is_visible)(struct kobject___253 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___253 *, struct bin_attribute___253 *, int);
	struct attribute **attrs;
	struct bin_attribute___253 **bin_attrs;
};

struct bin_attribute___253 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___265 * (*f_mapping)();
	ssize_t (*read)(struct file___265 *, struct kobject___253 *, struct bin_attribute___253 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___265 *, struct kobject___253 *, struct bin_attribute___253 *, char *, loff_t, size_t);
	int (*mmap)(struct file___265 *, struct kobject___253 *, struct bin_attribute___253 *, struct vm_area_struct___270 *);
};

struct sysfs_ops___253 {
	ssize_t (*show)(struct kobject___253 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___253 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___253;

struct kset___253 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___253 kobj;
	const struct kset_uevent_ops___253 *uevent_ops;
};

struct kobj_type___253 {
	void (*release)(struct kobject___253 *);
	const struct sysfs_ops___253 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___253 **default_groups;
	const struct kobj_ns_type_operations___61 * (*child_ns_type)(struct kobject___253 *);
	const void * (*namespace)(struct kobject___253 *);
	void (*get_ownership)(struct kobject___253 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___253 {
	int (* const filter)(struct kset___253 *, struct kobject___253 *);
	const char * (* const name)(struct kset___253 *, struct kobject___253 *);
	int (* const uevent)(struct kset___253 *, struct kobject___253 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___249 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___249 *);
	int (*get)(char *, const struct kernel_param___249 *);
	void (*free)(void *);
};

struct kparam_array___249;

struct kernel_param___249 {
	const char *name;
	struct module___249 *mod;
	const struct kernel_param_ops___249 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___249 *arr;
	};
};

struct kparam_array___249 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___249 *ops;
	void *elem;
};

struct module_attribute___249 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___249 *, struct module_kobject___250 *, char *);
	ssize_t (*store)(struct module_attribute___249 *, struct module_kobject___250 *, const char *, size_t);
	void (*setup)(struct module___249 *, const char *);
	int (*test)(struct module___249 *);
	void (*free)(struct module___249 *);
};

struct dev_pagemap_ops___260 {
	void (*page_free)(struct page___270 *);
	void (*kill)(struct dev_pagemap___260 *);
	void (*cleanup)(struct dev_pagemap___260 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___260 *);
};

struct fwnode_operations___242;

struct fwnode_handle___242 {
	struct fwnode_handle___242 *secondary;
	const struct fwnode_operations___242 *ops;
	struct device___246 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___242;

struct fwnode_endpoint___242;

struct fwnode_operations___242 {
	struct fwnode_handle___242 * (*get)(struct fwnode_handle___242 *);
	void (*put)(struct fwnode_handle___242 *);
	bool (*device_is_available)(const struct fwnode_handle___242 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___242 *, const struct device___246 *);
	bool (*property_present)(const struct fwnode_handle___242 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___242 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___242 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___242 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*get_parent)(const struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*get_next_child_node)(const struct fwnode_handle___242 *, struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*get_named_child_node)(const struct fwnode_handle___242 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___242 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___242 *);
	struct fwnode_handle___242 * (*graph_get_next_endpoint)(const struct fwnode_handle___242 *, struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*graph_get_remote_endpoint)(const struct fwnode_handle___242 *);
	struct fwnode_handle___242 * (*graph_get_port_parent)(struct fwnode_handle___242 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___242 *, struct fwnode_endpoint___242 *);
	int (*add_links)(struct fwnode_handle___242 *);
};

struct fwnode_endpoint___242 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___242 *local_fwnode;
};

struct fwnode_reference_args___242 {
	struct fwnode_handle___242 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct fib_rules_ops___61;

struct fqdir___79;

struct fib_notifier_ops___61;

struct netns_ipv4___79 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___61 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___61 *fibnl;
	struct sock___61 **icmp_sk;
	struct sock___61 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___61 **tcp_sk;
	struct fqdir___79 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___61 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___61 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___61 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___61;

struct dst_ops___79 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___79 *);
	struct dst_entry___61 * (*check)(struct dst_entry___61 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___61 *);
	unsigned int (*mtu)(const struct dst_entry___61 *);
	u32 * (*cow_metrics)(struct dst_entry___61 *, long unsigned int);
	void (*destroy)(struct dst_entry___61 *);
	void (*ifdown)(struct dst_entry___61 *, struct net_device___74 *, int);
	struct dst_entry___61 * (*negative_advice)(struct dst_entry___61 *);
	void (*link_failure)(struct sk_buff___75 *);
	void (*update_pmtu)(struct dst_entry___61 *, struct sock___61 *, struct sk_buff___75 *, u32, bool);
	void (*redirect)(struct dst_entry___61 *, struct sock___61 *, struct sk_buff___75 *);
	int (*local_out)(struct net___79 *, struct sock___61 *, struct sk_buff___75 *);
	struct neighbour___61 * (*neigh_lookup)(const struct dst_entry___61 *, struct sk_buff___75 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___61 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___79 {
	struct dst_ops___79 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___79 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___61 *fib6_rules_ops;
	struct sock___61 **icmp_sk;
	struct sock___61 *ndisc_sk;
	struct sock___61 *tcp_sk;
	struct sock___61 *igmp_sk;
	struct sock___61 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___61 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___61 *notifier_ops;
	struct fib_notifier_ops___61 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___79 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___79 *fqdir;
};

struct netns_sctp___61 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___61 *ctl_sock;
	struct sock___61 *udp4_sock;
	struct sock___61 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___68;

struct netns_bpf___68 {
	struct bpf_prog_array___68 *run_array[2];
	struct bpf_prog___68 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___79 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___61 *nlsk;
	struct sock___61 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___79 xfrm4_dst_ops;
	struct dst_ops___79 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___79 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___61 *rtnl;
	struct sock___61 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___74 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___79 ipv4;
	struct netns_ipv6___79 ipv6;
	struct netns_ieee802154_lowpan___79 ieee802154_lowpan;
	struct netns_sctp___61 sctp;
	struct netns_nf___6 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___74 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___68 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___79 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___61 *crypto_nlsk;
	struct sock___61 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___192 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___192 *root_cset;
};

struct socket_wq___62 {
	wait_queue_head_t wait;
	struct fasync_struct___265 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___62;

struct socket___63 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___265 *file;
	struct sock___61 *sk;
	const struct proto_ops___62 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___62 wq;
};

typedef int (*sk_read_actor_t___61)(read_descriptor_t *, struct sk_buff___75 *, unsigned int, size_t);

struct proto_ops___62 {
	int family;
	struct module___249 *owner;
	int (*release)(struct socket___63 *);
	int (*bind)(struct socket___63 *, struct sockaddr *, int);
	int (*connect)(struct socket___63 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___63 *, struct socket___63 *);
	int (*accept)(struct socket___63 *, struct socket___63 *, int, bool);
	int (*getname)(struct socket___63 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___265 *, struct socket___63 *, struct poll_table_struct___186 *);
	int (*ioctl)(struct socket___63 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___63 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___63 *, void *, bool, bool);
	int (*listen)(struct socket___63 *, int);
	int (*shutdown)(struct socket___63 *, int);
	int (*setsockopt)(struct socket___63 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___63 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___240 *, struct socket___63 *);
	int (*sendmsg)(struct socket___63 *, struct msghdr___63 *, size_t);
	int (*recvmsg)(struct socket___63 *, struct msghdr___63 *, size_t, int);
	int (*mmap)(struct file___265 *, struct socket___63 *, struct vm_area_struct___270 *);
	ssize_t (*sendpage)(struct socket___63 *, struct page___270 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___63 *, loff_t *, struct pipe_inode_info___106 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___61 *, int);
	int (*peek_len)(struct socket___63 *);
	int (*read_sock)(struct sock___61 *, read_descriptor_t *, sk_read_actor_t___61);
	int (*sendpage_locked)(struct sock___61 *, struct page___270 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___61 *, struct msghdr___63 *, size_t);
	int (*set_rcvlowat)(struct sock___61 *, int);
};

struct sk_buff___75 {
	union {
		struct {
			struct sk_buff___75 *next;
			struct sk_buff___75 *prev;
			union {
				struct net_device___74 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___61 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___75 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___246 {
	int (*prepare)(struct device___246 *);
	void (*complete)(struct device___246 *);
	int (*suspend)(struct device___246 *);
	int (*resume)(struct device___246 *);
	int (*freeze)(struct device___246 *);
	int (*thaw)(struct device___246 *);
	int (*poweroff)(struct device___246 *);
	int (*restore)(struct device___246 *);
	int (*suspend_late)(struct device___246 *);
	int (*resume_early)(struct device___246 *);
	int (*freeze_late)(struct device___246 *);
	int (*thaw_early)(struct device___246 *);
	int (*poweroff_late)(struct device___246 *);
	int (*restore_early)(struct device___246 *);
	int (*suspend_noirq)(struct device___246 *);
	int (*resume_noirq)(struct device___246 *);
	int (*freeze_noirq)(struct device___246 *);
	int (*thaw_noirq)(struct device___246 *);
	int (*poweroff_noirq)(struct device___246 *);
	int (*restore_noirq)(struct device___246 *);
	int (*runtime_suspend)(struct device___246 *);
	int (*runtime_resume)(struct device___246 *);
	int (*runtime_idle)(struct device___246 *);
};

struct wakeup_source___246 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___246 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___246 {
	struct dev_pm_ops___246 ops;
	int (*start)(struct device___246 *);
	void (*detach)(struct device___246 *, bool);
	int (*activate)(struct device___246 *);
	void (*sync)(struct device___246 *);
	void (*dismiss)(struct device___246 *);
};

struct bus_type___246 {
	const char *name;
	const char *dev_name;
	struct device___246 *dev_root;
	const struct attribute_group___253 **bus_groups;
	const struct attribute_group___253 **dev_groups;
	const struct attribute_group___253 **drv_groups;
	int (*match)(struct device___246 *, struct device_driver___246 *);
	int (*uevent)(struct device___246 *, struct kobj_uevent_env *);
	int (*probe)(struct device___246 *);
	void (*sync_state)(struct device___246 *);
	void (*remove)(struct device___246 *);
	void (*shutdown)(struct device___246 *);
	int (*online)(struct device___246 *);
	int (*offline)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	int (*num_vf)(struct device___246 *);
	int (*dma_configure)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___246 {
	const char *name;
	struct bus_type___246 *bus;
	struct module___249 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___246 *);
	void (*sync_state)(struct device___246 *);
	int (*remove)(struct device___246 *);
	void (*shutdown)(struct device___246 *);
	int (*suspend)(struct device___246 *, pm_message_t);
	int (*resume)(struct device___246 *);
	const struct attribute_group___253 **groups;
	const struct attribute_group___253 **dev_groups;
	const struct dev_pm_ops___246 *pm;
	void (*coredump)(struct device___246 *);
	struct driver_private *p;
};

struct device_type___246 {
	const char *name;
	const struct attribute_group___253 **groups;
	int (*uevent)(struct device___246 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___246 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___246 *);
	const struct dev_pm_ops___246 *pm;
};

struct class___246 {
	const char *name;
	struct module___249 *owner;
	const struct attribute_group___253 **class_groups;
	const struct attribute_group___253 **dev_groups;
	struct kobject___253 *dev_kobj;
	int (*dev_uevent)(struct device___246 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___246 *, umode_t *);
	void (*class_release)(struct class___246 *);
	void (*dev_release)(struct device___246 *);
	int (*shutdown_pre)(struct device___246 *);
	const struct kobj_ns_type_operations___61 *ns_type;
	const void * (*namespace)(struct device___246 *);
	void (*get_ownership)(struct device___246 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___246 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___106;

struct pipe_buffer___106 {
	struct page___270 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___106 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___106 {
	int (*confirm)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
	void (*release)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
	bool (*try_steal)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
	bool (*get)(struct pipe_inode_info___106 *, struct pipe_buffer___106 *);
};

typedef rx_handler_result_t rx_handler_func_t___74(struct sk_buff___75 **);

struct bpf_xdp_entity___68 {
	struct bpf_prog___68 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___74;

struct net_device_ops___74;

struct ethtool_ops___31;

struct l3mdev_ops___61;

struct xfrmdev_ops___74;

struct header_ops___74;

struct netdev_rx_queue___74;

struct mini_Qdisc___68;

struct netdev_queue___74;

struct Qdisc___68;

struct rtnl_link_ops___68;

struct dcbnl_rtnl_ops___74;

struct phy_device___14;

struct net_device___74 {
	char name[16];
	struct netdev_name_node___74 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___74 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___31 *ethtool_ops;
	const struct l3mdev_ops___61 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___74 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___74 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___253 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___74 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___68 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___74 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___68 *miniq_ingress;
	struct netdev_queue___74 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___74 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___68 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___68 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___74 = 0,
		NETREG_REGISTERED___74 = 1,
		NETREG_UNREGISTERING___74 = 2,
		NETREG_UNREGISTERED___74 = 3,
		NETREG_RELEASED___74 = 4,
		NETREG_DUMMY___74 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___74 = 0,
		RTNL_LINK_INITIALIZING___74 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___74 *);
	struct netpoll_info *npinfo;
	possible_net_t___74 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___246 dev;
	const struct attribute_group___253 *sysfs_groups[4];
	const struct attribute_group___253 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___68 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___74 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device___14 *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___68 xdp_state[3];
	long: 64;
};

struct netlink_callback___74 {
	struct sk_buff___75 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___75 *, struct netlink_callback___74 *);
	int (*done)(struct netlink_callback___74 *);
	void *data;
	struct module___249 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct ethtool_value {
	__u32 cmd;
	__u32 data;
};

enum tunable_type_id {
	ETHTOOL_TUNABLE_UNSPEC = 0,
	ETHTOOL_TUNABLE_U8 = 1,
	ETHTOOL_TUNABLE_U16 = 2,
	ETHTOOL_TUNABLE_U32 = 3,
	ETHTOOL_TUNABLE_U64 = 4,
	ETHTOOL_TUNABLE_STRING = 5,
	ETHTOOL_TUNABLE_S8 = 6,
	ETHTOOL_TUNABLE_S16 = 7,
	ETHTOOL_TUNABLE_S32 = 8,
	ETHTOOL_TUNABLE_S64 = 9,
};

enum phy_tunable_id {
	ETHTOOL_PHY_ID_UNSPEC = 0,
	ETHTOOL_PHY_DOWNSHIFT = 1,
	ETHTOOL_PHY_FAST_LINK_DOWN = 2,
	ETHTOOL_PHY_EDPD = 3,
	__ETHTOOL_PHY_TUNABLE_COUNT = 4,
};

struct ethtool_gstrings {
	__u32 cmd;
	__u32 string_set;
	__u32 len;
	__u8 data[0];
};

struct ethtool_sset_info {
	__u32 cmd;
	__u32 reserved;
	__u64 sset_mask;
	__u32 data[0];
};

struct ethtool_perm_addr {
	__u32 cmd;
	__u32 size;
	__u8 data[0];
};

enum ethtool_flags {
	ETH_FLAG_TXVLAN = 128,
	ETH_FLAG_RXVLAN = 256,
	ETH_FLAG_LRO = 32768,
	ETH_FLAG_NTUPLE = 134217728,
	ETH_FLAG_RXHASH = 268435456,
};

struct ethtool_rxfh {
	__u32 cmd;
	__u32 rss_context;
	__u32 indir_size;
	__u32 key_size;
	__u8 hfunc;
	__u8 rsvd8[3];
	__u32 rsvd32;
	__u32 rss_config[0];
};

struct ethtool_get_features_block {
	__u32 available;
	__u32 requested;
	__u32 active;
	__u32 never_changed;
};

struct ethtool_gfeatures {
	__u32 cmd;
	__u32 size;
	struct ethtool_get_features_block features[0];
};

struct ethtool_set_features_block {
	__u32 valid;
	__u32 requested;
};

struct ethtool_sfeatures {
	__u32 cmd;
	__u32 size;
	struct ethtool_set_features_block features[0];
};

enum ethtool_sfeatures_retval_bits {
	ETHTOOL_F_UNSUPPORTED__BIT = 0,
	ETHTOOL_F_WISH__BIT = 1,
	ETHTOOL_F_COMPAT__BIT = 2,
};

struct ethtool_per_queue_op {
	__u32 cmd;
	__u32 sub_command;
	__u32 queue_mask[128];
	char data[0];
};

enum ethtool_fec_config_bits {
	ETHTOOL_FEC_NONE_BIT = 0,
	ETHTOOL_FEC_AUTO_BIT = 1,
	ETHTOOL_FEC_OFF_BIT = 2,
	ETHTOOL_FEC_RS_BIT = 3,
	ETHTOOL_FEC_BASER_BIT = 4,
	ETHTOOL_FEC_LLRS_BIT = 5,
};

enum {
	ETH_RSS_HASH_TOP_BIT = 0,
	ETH_RSS_HASH_XOR_BIT = 1,
	ETH_RSS_HASH_CRC32_BIT = 2,
	ETH_RSS_HASH_FUNCS_COUNT = 3,
};

struct ethtool_ops___31 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___74 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___74 *);
	void (*get_regs)(struct net_device___74 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___74 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___74 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___74 *);
	void (*set_msglevel)(struct net_device___74 *, u32);
	int (*nway_reset)(struct net_device___74 *);
	u32 (*get_link)(struct net_device___74 *);
	int (*get_link_ext_state)(struct net_device___74 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___74 *);
	int (*get_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___74 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___74 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___74 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___74 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___74 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___74 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___74 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___74 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___74 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___74 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___74 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___74 *);
	void (*complete)(struct net_device___74 *);
	u32 (*get_priv_flags)(struct net_device___74 *);
	int (*set_priv_flags)(struct net_device___74 *, u32);
	int (*get_sset_count)(struct net_device___74 *, int);
	int (*get_rxnfc)(struct net_device___74 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___74 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___74 *, struct ethtool_flash *);
	int (*reset)(struct net_device___74 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___74 *);
	u32 (*get_rxfh_indir_size)(struct net_device___74 *);
	int (*get_rxfh)(struct net_device___74 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___74 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___74 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___74 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___74 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___74 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___74 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___74 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___74 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___74 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___74 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___74 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___74 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___74 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___74 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___74 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___74 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___74 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___74 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___74 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___74 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___74 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___74 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___74 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___74 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___74 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___74 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___74 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___74 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___74 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___74 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

struct flow_rule___6;

struct ethtool_rx_flow_rule {
	struct flow_rule___6 *rule;
	long unsigned int priv[0];
};

struct flow_action_entry___7 {
	enum flow_action_id id;
	enum flow_action_hw_stats hw_stats;
	action_destr destructor;
	void *destructor_priv;
	union {
		u32 chain_index;
		struct net_device___74 *dev;
		struct {
			u16 vid;
			__be16 proto;
			u8 prio;
		} vlan;
		struct {
			enum flow_action_mangle_base htype;
			u32 offset;
			u32 mask;
			u32 val;
		} mangle;
		struct ip_tunnel_info *tunnel;
		u32 csum_flags;
		u32 mark;
		u16 ptype;
		u32 priority;
		struct {
			u32 ctx;
			u32 index;
			u8 vf;
		} queue;
		struct {
			struct psample_group *psample_group;
			u32 rate;
			u32 trunc_size;
			bool truncate;
		} sample;
		struct {
			u32 index;
			u32 burst;
			u64 rate_bytes_ps;
			u64 burst_pkt;
			u64 rate_pkt_ps;
			u32 mtu;
		} police;
		struct {
			int action;
			u16 zone;
			struct nf_flowtable *flow_table;
		} ct;
		struct {
			long unsigned int cookie;
			u32 mark;
			u32 labels[4];
			bool orig_dir;
		} ct_metadata;
		struct {
			u32 label;
			__be16 proto;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_push;
		struct {
			__be16 proto;
		} mpls_pop;
		struct {
			u32 label;
			u8 tc;
			u8 bos;
			u8 ttl;
		} mpls_mangle;
		struct {
			u32 index;
			s32 prio;
			u64 basetime;
			u64 cycletime;
			u64 cycletimeext;
			u32 num_entries;
			struct action_gate_entry *entries;
		} gate;
		struct {
			u16 sid;
		} pppoe;
	};
	struct flow_action_cookie *cookie;
};

struct flow_action___7 {
	unsigned int num_entries;
	struct flow_action_entry___7 entries[0];
};

struct flow_rule___6 {
	struct flow_match match;
	struct flow_action___7 action;
};

struct ethtool_rx_flow_spec_input {
	const struct ethtool_rx_flow_spec *fs;
	u32 rss_ctx;
};

struct ethtool_phy_ops___2 {
	int (*get_sset_count)(struct phy_device___14 *);
	int (*get_strings)(struct phy_device___14 *, u8 *);
	int (*get_stats)(struct phy_device___14 *, struct ethtool_stats *, u64 *);
	int (*start_cable_test)(struct phy_device___14 *, struct netlink_ext_ack *);
	int (*start_cable_test_tdr)(struct phy_device___14 *, struct netlink_ext_ack *, const struct phy_tdr_config *);
};

struct mii_bus___17;

struct mdio_device___17 {
	struct device___246 dev;
	struct mii_bus___17 *bus;
	char modalias[32];
	int (*bus_match)(struct device___246 *, struct device_driver___246 *);
	void (*device_free)(struct mdio_device___17 *);
	void (*device_remove)(struct mdio_device___17 *);
	int addr;
	int flags;
	struct gpio_desc *reset_gpio;
	struct reset_control *reset_ctrl;
	unsigned int reset_assert_delay;
	unsigned int reset_deassert_delay;
};

struct phy_driver___14;

struct mii_timestamper___14;

struct phy_device___14 {
	struct mdio_device___17 mdio;
	struct phy_driver___14 *drv;
	u32 phy_id;
	struct phy_c45_device_ids c45_ids;
	unsigned int is_c45: 1;
	unsigned int is_internal: 1;
	unsigned int is_pseudo_fixed_link: 1;
	unsigned int is_gigabit_capable: 1;
	unsigned int has_fixups: 1;
	unsigned int suspended: 1;
	unsigned int suspended_by_mdio_bus: 1;
	unsigned int sysfs_links: 1;
	unsigned int loopback_enabled: 1;
	unsigned int downshifted_rate: 1;
	unsigned int is_on_sfp_module: 1;
	unsigned int mac_managed_pm: 1;
	unsigned int autoneg: 1;
	unsigned int link: 1;
	unsigned int autoneg_complete: 1;
	unsigned int interrupts: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum phy_state state;
	u32 dev_flags;
	phy_interface_t interface;
	int speed;
	int duplex;
	int port;
	int pause;
	int asym_pause;
	u8 master_slave_get;
	u8 master_slave_set;
	u8 master_slave_state;
	long unsigned int supported[2];
	long unsigned int advertising[2];
	long unsigned int lp_advertising[2];
	long unsigned int adv_old[2];
	u32 eee_broken_modes;
	struct phy_led_trigger *phy_led_triggers;
	unsigned int phy_num_led_triggers;
	struct phy_led_trigger *last_triggered;
	struct phy_led_trigger *led_link_trigger;
	int irq;
	void *priv;
	struct phy_package_shared *shared;
	struct sk_buff___75 *skb;
	void *ehdr;
	struct nlattr *nest;
	struct delayed_work state_queue;
	struct mutex lock;
	bool sfp_bus_attached;
	struct sfp_bus *sfp_bus;
	struct phylink *phylink;
	struct net_device___74 *attached_dev;
	struct mii_timestamper___14 *mii_ts;
	u8 mdix;
	u8 mdix_ctrl;
	void (*phy_link_change)(struct phy_device___14 *, bool);
	void (*adjust_link)(struct net_device___74 *);
	const struct macsec_ops *macsec_ops;
};

struct inet_frags___79;

struct fqdir___79 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___79 *f;
	struct net___79 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___79;

struct inet_frags___79 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___79 *, const void *);
	void (*destructor)(struct inet_frag_queue___79 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___79 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___75 *fragments_tail;
	struct sk_buff___75 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___79 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___61;

struct fib_lookup_arg___61;

struct fib_rules_ops___61 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___61 *, struct flowi *, int, struct fib_lookup_arg___61 *);
	bool (*suppress)(struct fib_rule___61 *, int, struct fib_lookup_arg___61 *);
	int (*match)(struct fib_rule___61 *, struct flowi *, int);
	int (*configure)(struct fib_rule___61 *, struct sk_buff___75 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___61 *);
	int (*compare)(struct fib_rule___61 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___61 *, struct sk_buff___75 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___61 *);
	void (*flush_cache)(struct fib_rules_ops___61 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___249 *owner;
	struct net___79 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___61 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___79 *);
	int (*fib_dump)(struct net___79 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___249 *owner;
	struct callback_head rcu;
};

struct dst_entry___61 {
	struct net_device___74 *dev;
	struct dst_ops___79 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___75 *);
	int (*output)(struct net___79 *, struct sock___61 *, struct sk_buff___75 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___61;

struct neigh_parms___61;

struct neigh_ops___61;

struct neighbour___61 {
	struct neighbour___61 *next;
	struct neigh_table___61 *tbl;
	struct neigh_parms___61 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___74 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___61 *, struct sk_buff___75 *);
	const struct neigh_ops___61 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___74 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___68 {
	struct bpf_prog___68 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___68 {
	struct callback_head rcu;
	struct bpf_prog_array_item___68 items[0];
};

struct bpf_prog_aux___77;

struct bpf_prog___68 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___77 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___240 {
	void * (*start)(struct seq_file___240 *, loff_t *);
	void (*stop)(struct seq_file___240 *, void *);
	void * (*next)(struct seq_file___240 *, void *, loff_t *);
	int (*show)(struct seq_file___240 *, void *);
};

struct dcbnl_rtnl_ops___74 {
	int (*ieee_getets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___74 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___74 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___74 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___74 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___74 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___74 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___74 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___74 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___74 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___74 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___74 *);
	u8 (*setstate)(struct net_device___74 *, u8);
	void (*getpermhwaddr)(struct net_device___74 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___74 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___74 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___74 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___74 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___74 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___74 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___74 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___74 *, int, u8 *);
	void (*setpfccfg)(struct net_device___74 *, int, u8);
	void (*getpfccfg)(struct net_device___74 *, int, u8 *);
	u8 (*setall)(struct net_device___74 *);
	u8 (*getcap)(struct net_device___74 *, int, u8 *);
	int (*getnumtcs)(struct net_device___74 *, int, u8 *);
	int (*setnumtcs)(struct net_device___74 *, int, u8);
	u8 (*getpfcstate)(struct net_device___74 *);
	void (*setpfcstate)(struct net_device___74 *, u8);
	void (*getbcncfg)(struct net_device___74 *, int, u32 *);
	void (*setbcncfg)(struct net_device___74 *, int, u32);
	void (*getbcnrp)(struct net_device___74 *, int, u8 *);
	void (*setbcnrp)(struct net_device___74 *, int, u8);
	int (*setapp)(struct net_device___74 *, u8, u16, u8);
	int (*getapp)(struct net_device___74 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___74 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___74 *, int, u8);
	u8 (*getdcbx)(struct net_device___74 *);
	u8 (*setdcbx)(struct net_device___74 *, u8);
	int (*peer_getappinfo)(struct net_device___74 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___74 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___74 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___74 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___74 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___74 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___77;

typedef int (*bpf_iter_init_seq_priv_t___76)(void *, struct bpf_iter_aux_info___77 *);

struct bpf_map___77;

struct bpf_iter_aux_info___77 {
	struct bpf_map___77 *map;
};

struct bpf_iter_seq_info___76 {
	const struct seq_operations___240 *seq_ops;
	bpf_iter_init_seq_priv_t___76 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___76 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___77 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___77 *, struct file___265 *);
	void (*map_free)(struct bpf_map___77 *);
	int (*map_get_next_key)(struct bpf_map___77 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___77 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___77 *, void *);
	int (*map_lookup_batch)(struct bpf_map___77 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___77 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___77 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___77 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___77 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___77 *, void *);
	int (*map_update_elem)(struct bpf_map___77 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___77 *, void *);
	int (*map_push_elem)(struct bpf_map___77 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___77 *, void *);
	int (*map_peek_elem)(struct bpf_map___77 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___77 *, struct file___265 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___77 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___77 *, void *, struct seq_file___240 *);
	int (*map_check_btf)(const struct bpf_map___77 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___77 *, struct bpf_prog_aux___77 *);
	void (*map_poke_untrack)(struct bpf_map___77 *, struct bpf_prog_aux___77 *);
	void (*map_poke_run)(struct bpf_map___77 *, u32, struct bpf_prog___68 *, struct bpf_prog___68 *);
	int (*map_direct_value_addr)(const struct bpf_map___77 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___77 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___77 *, struct vm_area_struct___270 *);
	__poll_t (*map_poll)(struct bpf_map___77 *, struct file___265 *, struct poll_table_struct___186 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___77 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___77 *, const struct bpf_map___77 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___77 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___76 *iter_seq_info;
};

struct bpf_map___77 {
	const struct bpf_map_ops___76 *ops;
	struct bpf_map___77 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___130 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___76;

struct bpf_jit_poke_descriptor___76;

struct bpf_prog_ops___68;

struct btf_mod_pair___76;

struct bpf_prog_offload___74;

struct bpf_prog_aux___77 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___68 *dst_prog;
	struct bpf_trampoline___76 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___68 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___76 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___68 *ops;
	struct bpf_map___77 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___76 *used_btfs;
	struct bpf_prog___68 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___77 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___74 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___74;

struct bpf_map_dev_ops___74 {
	int (*map_get_next_key)(struct bpf_offloaded_map___74 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___74 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___74 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___74 *, void *);
};

struct bpf_offloaded_map___74 {
	struct bpf_map___77 map;
	struct net_device___74 *netdev;
	const struct bpf_map_dev_ops___74 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___68 {
	int (*test_run)(struct bpf_prog___68 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___74 {
	struct bpf_prog___68 *prog;
	struct net_device___74 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___76 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___68 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___249 *mod;
};

struct bpf_jit_poke_descriptor___76 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___77 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___76 {
	struct btf *btf;
	struct module___249 *module;
};

struct cftype___192;

struct cgroup_subsys___192 {
	struct cgroup_subsys_state___192 * (*css_alloc)(struct cgroup_subsys_state___192 *);
	int (*css_online)(struct cgroup_subsys_state___192 *);
	void (*css_offline)(struct cgroup_subsys_state___192 *);
	void (*css_released)(struct cgroup_subsys_state___192 *);
	void (*css_free)(struct cgroup_subsys_state___192 *);
	void (*css_reset)(struct cgroup_subsys_state___192 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___192 *, int);
	int (*css_extra_stat_show)(struct seq_file___240 *, struct cgroup_subsys_state___192 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___272 *, struct css_set___192 *);
	void (*cancel_fork)(struct task_struct___272 *, struct css_set___192 *);
	void (*fork)(struct task_struct___272 *);
	void (*exit)(struct task_struct___272 *);
	void (*release)(struct task_struct___272 *);
	void (*bind)(struct cgroup_subsys_state___192 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___192 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___192 *dfl_cftypes;
	struct cftype___192 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___192 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___192 *updated_children;
	struct cgroup___192 *updated_next;
};

struct cgroup_root___192 {
	struct kernfs_root___253 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___192 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___192 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___192 *ss;
	struct list_head node;
	struct kernfs_ops___253 *kf_ops;
	int (*open)(struct kernfs_open_file___253 *);
	void (*release)(struct kernfs_open_file___253 *);
	u64 (*read_u64)(struct cgroup_subsys_state___192 *, struct cftype___192 *);
	s64 (*read_s64)(struct cgroup_subsys_state___192 *, struct cftype___192 *);
	int (*seq_show)(struct seq_file___240 *, void *);
	void * (*seq_start)(struct seq_file___240 *, loff_t *);
	void * (*seq_next)(struct seq_file___240 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___240 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___192 *, struct cftype___192 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___192 *, struct cftype___192 *, s64);
	ssize_t (*write)(struct kernfs_open_file___253 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___253 *, struct poll_table_struct___186 *);
};

struct xdp_rxq_info___74 {
	struct net_device___74 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___74 {
	struct net_device___74 *dev;
};

struct xdp_buff___74 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___74 *rxq;
	struct xdp_txq_info___74 *txq;
	u32 frame_sz;
};

struct xdp_frame___74 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___74 *dev_rx;
};

struct header_ops___74 {
	int (*create)(struct sk_buff___75 *, struct net_device___74 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___75 *, unsigned char *);
	int (*cache)(const struct neighbour___61 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___74 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___75 *);
};

struct xsk_buff_pool___2;

struct netdev_queue___74 {
	struct net_device___74 *dev;
	struct Qdisc___68 *qdisc;
	struct Qdisc___68 *qdisc_sleeping;
	struct kobject___253 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___74 *sb_dev;
	struct xsk_buff_pool___2 *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___68 {
	struct sk_buff___75 *head;
	struct sk_buff___75 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___68;

struct Qdisc___68 {
	int (*enqueue)(struct sk_buff___75 *, struct Qdisc___68 *, struct sk_buff___75 **);
	struct sk_buff___75 * (*dequeue)(struct Qdisc___68 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___68 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___74 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___74 gso_skb;
	struct qdisc_skb_head___68 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___68 *next_sched;
	struct sk_buff_head___74 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct xdp_umem___3;

struct xdp_buff_xsk___2;

struct xsk_buff_pool___2 {
	struct device___246 *dev;
	struct net_device___74 *netdev;
	struct list_head xsk_tx_list;
	spinlock_t xsk_tx_list_lock;
	refcount_t users;
	struct xdp_umem___3 *umem;
	struct work_struct work;
	struct list_head free_list;
	u32 heads_cnt;
	u16 queue_id;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	dma_addr_t *dma_pages;
	struct xdp_buff_xsk___2 *heads;
	u64 chunk_mask;
	u64 addrs_cnt;
	u32 free_list_cnt;
	u32 dma_pages_cnt;
	u32 free_heads_cnt;
	u32 headroom;
	u32 chunk_size;
	u32 frame_len;
	u8 cached_need_wakeup;
	bool uses_need_wakeup;
	bool dma_need_sync;
	bool unaligned;
	void *addrs;
	spinlock_t cq_lock;
	struct xdp_buff_xsk___2 *free_heads[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___74 {
	struct xdp_rxq_info___74 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___253 kobj;
	struct net_device___74 *dev;
	struct xsk_buff_pool___2 *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___74 {
	enum net_device_path_type type;
	const struct net_device___74 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___74 = 0,
				DEV_PATH_BR_VLAN_TAG___74 = 1,
				DEV_PATH_BR_VLAN_UNTAG___74 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___74 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___74 {
	const struct net_device___74 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___74 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___68 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___74 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___74 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___75 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___74 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___74 *dev;
	const char *name;
};

struct devlink_port___8;

struct net_device_ops___74 {
	int (*ndo_init)(struct net_device___74 *);
	void (*ndo_uninit)(struct net_device___74 *);
	int (*ndo_open)(struct net_device___74 *);
	int (*ndo_stop)(struct net_device___74 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___75 *, struct net_device___74 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___75 *, struct net_device___74 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___74 *, struct sk_buff___75 *, struct net_device___74 *);
	void (*ndo_change_rx_flags)(struct net_device___74 *, int);
	void (*ndo_set_rx_mode)(struct net_device___74 *);
	int (*ndo_set_mac_address)(struct net_device___74 *, void *);
	int (*ndo_validate_addr)(struct net_device___74 *);
	int (*ndo_do_ioctl)(struct net_device___74 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___74 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___74 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___74 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___74 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___74 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___74 *, int);
	int (*ndo_neigh_setup)(struct net_device___74 *, struct neigh_parms___61 *);
	void (*ndo_tx_timeout)(struct net_device___74 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___74 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___74 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___74 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___74 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___74 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___74 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___74 *);
	int (*ndo_netpoll_setup)(struct net_device___74 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___74 *);
	int (*ndo_set_vf_mac)(struct net_device___74 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___74 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___74 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___74 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___74 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___74 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___74 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___74 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___74 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___74 *, int, struct sk_buff___75 *);
	int (*ndo_get_vf_guid)(struct net_device___74 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___74 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___74 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___74 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___74 *);
	int (*ndo_fcoe_disable)(struct net_device___74 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___74 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___74 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___74 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___74 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___74 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___74 *, const struct sk_buff___75 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___74 *, struct net_device___74 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___74 *, struct net_device___74 *);
	struct net_device___74 * (*ndo_get_xmit_slave)(struct net_device___74 *, struct sk_buff___75 *, bool);
	struct net_device___74 * (*ndo_sk_get_lower_dev)(struct net_device___74 *, struct sock___61 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___74 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___74 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___74 *, struct neighbour___61 *);
	void (*ndo_neigh_destroy)(struct net_device___74 *, struct neighbour___61 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___75 *, struct netlink_callback___74 *, struct net_device___74 *, struct net_device___74 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___75 *, struct nlattr **, struct net_device___74 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___74 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___75 *, u32, u32, struct net_device___74 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___74 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___74 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___74 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___74 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___74 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___74 *, struct net_device___74 *);
	void (*ndo_dfwd_del_station)(struct net_device___74 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___74 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___74 *);
	int (*ndo_change_proto_down)(struct net_device___74 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___74 *, struct sk_buff___75 *);
	void (*ndo_set_rx_headroom)(struct net_device___74 *, int);
	int (*ndo_bpf)(struct net_device___74 *, struct netdev_bpf___74 *);
	int (*ndo_xdp_xmit)(struct net_device___74 *, int, struct xdp_frame___74 **, u32);
	struct net_device___74 * (*ndo_xdp_get_xmit_slave)(struct net_device___74 *, struct xdp_buff___74 *);
	int (*ndo_xsk_wakeup)(struct net_device___74 *, u32, u32);
	struct devlink_port___8 * (*ndo_get_devlink_port)(struct net_device___74 *);
	int (*ndo_tunnel_ctl)(struct net_device___74 *, struct ip_tunnel_parm *, int);
	struct net_device___74 * (*ndo_get_peer_dev)(struct net_device___74 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___74 *, struct net_device_path___74 *);
};

struct neigh_parms___61 {
	possible_net_t___74 net;
	struct net_device___74 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___61 *);
	struct neigh_table___61 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct devlink___8;

struct devlink_rate___8;

struct devlink_port___8 {
	struct list_head list;
	struct list_head param_list;
	struct list_head region_list;
	struct devlink___8 *devlink;
	unsigned int index;
	spinlock_t type_lock;
	enum devlink_port_type type;
	enum devlink_port_type desired_type;
	void *type_dev;
	struct devlink_port_attrs attrs;
	u8 attrs_set;
	u8 switch_port;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct delayed_work type_warn_dw;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_rate___8 *devlink_rate;
};

struct l3mdev_ops___61 {
	u32 (*l3mdev_fib_table)(const struct net_device___74 *);
	struct sk_buff___75 * (*l3mdev_l3_rcv)(struct net_device___74 *, struct sk_buff___75 *, u16);
	struct sk_buff___75 * (*l3mdev_l3_out)(struct net_device___74 *, struct sock___61 *, struct sk_buff___75 *, u16);
	struct dst_entry___61 * (*l3mdev_link_scope_lookup)(const struct net_device___74 *, struct flowi6 *);
};

struct tcf_proto___68;

struct tcf_block___68;

struct mini_Qdisc___68 {
	struct tcf_proto___68 *filter_list;
	struct tcf_block___68 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___68 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___74 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___74 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___79 *, struct net_device___74 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___74 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___74 *, struct list_head *);
	size_t (*get_size)(const struct net_device___74 *);
	int (*fill_info)(struct sk_buff___75 *, const struct net_device___74 *);
	size_t (*get_xstats_size)(const struct net_device___74 *);
	int (*fill_xstats)(struct sk_buff___75 *, const struct net_device___74 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___74 *, struct net_device___74 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___74 *, const struct net_device___74 *);
	int (*fill_slave_info)(struct sk_buff___75 *, const struct net_device___74 *, const struct net_device___74 *);
	struct net___79 * (*get_link_net)(const struct net_device___74 *);
	size_t (*get_linkxstats_size)(const struct net_device___74 *, int);
	int (*fill_linkxstats)(struct sk_buff___75 *, const struct net_device___74 *, int *, int);
};

struct mii_bus___17 {
	struct module___249 *owner;
	const char *name;
	char id[61];
	void *priv;
	int (*read)(struct mii_bus___17 *, int, int);
	int (*write)(struct mii_bus___17 *, int, int, u16);
	int (*reset)(struct mii_bus___17 *);
	struct mdio_bus_stats stats[32];
	struct mutex mdio_lock;
	struct device___246 *parent;
	enum {
		MDIOBUS_ALLOCATED___17 = 1,
		MDIOBUS_REGISTERED___17 = 2,
		MDIOBUS_UNREGISTERED___17 = 3,
		MDIOBUS_RELEASED___17 = 4,
	} state;
	struct device___246 dev;
	struct mdio_device___17 *mdio_map[32];
	u32 phy_mask;
	u32 phy_ignore_ta_mask;
	int irq[32];
	int reset_delay_us;
	int reset_post_delay_us;
	struct gpio_desc *reset_gpiod;
	enum {
		MDIOBUS_NO_CAP___17 = 0,
		MDIOBUS_C22___17 = 1,
		MDIOBUS_C45___17 = 2,
		MDIOBUS_C22_C45___17 = 3,
	} probe_capabilities;
	struct mutex shared_lock;
	struct phy_package_shared *shared[32];
};

struct mdio_driver_common___16 {
	struct device_driver___246 driver;
	int flags;
};

struct mii_timestamper___14 {
	bool (*rxtstamp)(struct mii_timestamper___14 *, struct sk_buff___75 *, int);
	void (*txtstamp)(struct mii_timestamper___14 *, struct sk_buff___75 *, int);
	int (*hwtstamp)(struct mii_timestamper___14 *, struct ifreq *);
	void (*link_state)(struct mii_timestamper___14 *, struct phy_device___14 *);
	int (*ts_info)(struct mii_timestamper___14 *, struct ethtool_ts_info *);
	struct device___246 *device;
};

struct phy_driver___14 {
	struct mdio_driver_common___16 mdiodrv;
	u32 phy_id;
	char *name;
	u32 phy_id_mask;
	const long unsigned int * const features;
	u32 flags;
	const void *driver_data;
	int (*soft_reset)(struct phy_device___14 *);
	int (*config_init)(struct phy_device___14 *);
	int (*probe)(struct phy_device___14 *);
	int (*get_features)(struct phy_device___14 *);
	int (*suspend)(struct phy_device___14 *);
	int (*resume)(struct phy_device___14 *);
	int (*config_aneg)(struct phy_device___14 *);
	int (*aneg_done)(struct phy_device___14 *);
	int (*read_status)(struct phy_device___14 *);
	int (*config_intr)(struct phy_device___14 *);
	irqreturn_t (*handle_interrupt)(struct phy_device___14 *);
	void (*remove)(struct phy_device___14 *);
	int (*match_phy_device)(struct phy_device___14 *);
	int (*set_wol)(struct phy_device___14 *, struct ethtool_wolinfo *);
	void (*get_wol)(struct phy_device___14 *, struct ethtool_wolinfo *);
	void (*link_change_notify)(struct phy_device___14 *);
	int (*read_mmd)(struct phy_device___14 *, int, u16);
	int (*write_mmd)(struct phy_device___14 *, int, u16, u16);
	int (*read_page)(struct phy_device___14 *);
	int (*write_page)(struct phy_device___14 *, int);
	int (*module_info)(struct phy_device___14 *, struct ethtool_modinfo *);
	int (*module_eeprom)(struct phy_device___14 *, struct ethtool_eeprom *, u8 *);
	int (*cable_test_start)(struct phy_device___14 *);
	int (*cable_test_tdr_start)(struct phy_device___14 *, const struct phy_tdr_config *);
	int (*cable_test_get_status)(struct phy_device___14 *, bool *);
	int (*get_sset_count)(struct phy_device___14 *);
	void (*get_strings)(struct phy_device___14 *, u8 *);
	void (*get_stats)(struct phy_device___14 *, struct ethtool_stats *, u64 *);
	int (*get_tunable)(struct phy_device___14 *, struct ethtool_tunable *, void *);
	int (*set_tunable)(struct phy_device___14 *, struct ethtool_tunable *, const void *);
	int (*set_loopback)(struct phy_device___14 *, bool);
	int (*get_sqi)(struct phy_device___14 *);
	int (*get_sqi_max)(struct phy_device___14 *);
};

struct devlink_ops___8;

struct devlink___8 {
	u32 index;
	struct list_head port_list;
	struct list_head rate_list;
	struct list_head sb_list;
	struct list_head dpipe_table_list;
	struct list_head resource_list;
	struct list_head param_list;
	struct list_head region_list;
	struct list_head reporter_list;
	struct mutex reporters_lock;
	struct devlink_dpipe_headers *dpipe_headers;
	struct list_head trap_list;
	struct list_head trap_group_list;
	struct list_head trap_policer_list;
	const struct devlink_ops___8 *ops;
	struct xarray snapshot_ids;
	struct devlink_dev_stats stats;
	struct device___246 *dev;
	possible_net_t___74 _net;
	struct mutex lock;
	u8 reload_failed;
	u8 reload_enabled;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	refcount_t refcount;
	struct completion comp;
	char priv[0];
};

struct devlink_ops___8 {
	u32 supported_flash_update_params;
	long unsigned int reload_actions;
	long unsigned int reload_limits;
	int (*reload_down)(struct devlink___8 *, bool, enum devlink_reload_action, enum devlink_reload_limit, struct netlink_ext_ack *);
	int (*reload_up)(struct devlink___8 *, enum devlink_reload_action, enum devlink_reload_limit, u32 *, struct netlink_ext_ack *);
	int (*port_type_set)(struct devlink_port___8 *, enum devlink_port_type);
	int (*port_split)(struct devlink___8 *, unsigned int, unsigned int, struct netlink_ext_ack *);
	int (*port_unsplit)(struct devlink___8 *, unsigned int, struct netlink_ext_ack *);
	int (*sb_pool_get)(struct devlink___8 *, unsigned int, u16, struct devlink_sb_pool_info *);
	int (*sb_pool_set)(struct devlink___8 *, unsigned int, u16, u32, enum devlink_sb_threshold_type, struct netlink_ext_ack *);
	int (*sb_port_pool_get)(struct devlink_port___8 *, unsigned int, u16, u32 *);
	int (*sb_port_pool_set)(struct devlink_port___8 *, unsigned int, u16, u32, struct netlink_ext_ack *);
	int (*sb_tc_pool_bind_get)(struct devlink_port___8 *, unsigned int, u16, enum devlink_sb_pool_type, u16 *, u32 *);
	int (*sb_tc_pool_bind_set)(struct devlink_port___8 *, unsigned int, u16, enum devlink_sb_pool_type, u16, u32, struct netlink_ext_ack *);
	int (*sb_occ_snapshot)(struct devlink___8 *, unsigned int);
	int (*sb_occ_max_clear)(struct devlink___8 *, unsigned int);
	int (*sb_occ_port_pool_get)(struct devlink_port___8 *, unsigned int, u16, u32 *, u32 *);
	int (*sb_occ_tc_port_bind_get)(struct devlink_port___8 *, unsigned int, u16, enum devlink_sb_pool_type, u32 *, u32 *);
	int (*eswitch_mode_get)(struct devlink___8 *, u16 *);
	int (*eswitch_mode_set)(struct devlink___8 *, u16, struct netlink_ext_ack *);
	int (*eswitch_inline_mode_get)(struct devlink___8 *, u8 *);
	int (*eswitch_inline_mode_set)(struct devlink___8 *, u8, struct netlink_ext_ack *);
	int (*eswitch_encap_mode_get)(struct devlink___8 *, enum devlink_eswitch_encap_mode *);
	int (*eswitch_encap_mode_set)(struct devlink___8 *, enum devlink_eswitch_encap_mode, struct netlink_ext_ack *);
	int (*info_get)(struct devlink___8 *, struct devlink_info_req *, struct netlink_ext_ack *);
	int (*flash_update)(struct devlink___8 *, struct devlink_flash_update_params *, struct netlink_ext_ack *);
	int (*trap_init)(struct devlink___8 *, const struct devlink_trap *, void *);
	void (*trap_fini)(struct devlink___8 *, const struct devlink_trap *, void *);
	int (*trap_action_set)(struct devlink___8 *, const struct devlink_trap *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_group_init)(struct devlink___8 *, const struct devlink_trap_group *);
	int (*trap_group_set)(struct devlink___8 *, const struct devlink_trap_group *, const struct devlink_trap_policer *, struct netlink_ext_ack *);
	int (*trap_group_action_set)(struct devlink___8 *, const struct devlink_trap_group *, enum devlink_trap_action, struct netlink_ext_ack *);
	int (*trap_drop_counter_get)(struct devlink___8 *, const struct devlink_trap *, u64 *);
	int (*trap_policer_init)(struct devlink___8 *, const struct devlink_trap_policer *);
	void (*trap_policer_fini)(struct devlink___8 *, const struct devlink_trap_policer *);
	int (*trap_policer_set)(struct devlink___8 *, const struct devlink_trap_policer *, u64, u64, struct netlink_ext_ack *);
	int (*trap_policer_counter_get)(struct devlink___8 *, const struct devlink_trap_policer *, u64 *);
	int (*port_function_hw_addr_get)(struct devlink_port___8 *, u8 *, int *, struct netlink_ext_ack *);
	int (*port_function_hw_addr_set)(struct devlink_port___8 *, const u8 *, int, struct netlink_ext_ack *);
	int (*port_new)(struct devlink___8 *, const struct devlink_port_new_attrs *, struct netlink_ext_ack *, unsigned int *);
	int (*port_del)(struct devlink___8 *, unsigned int, struct netlink_ext_ack *);
	int (*port_fn_state_get)(struct devlink_port___8 *, enum devlink_port_fn_state *, enum devlink_port_fn_opstate *, struct netlink_ext_ack *);
	int (*port_fn_state_set)(struct devlink_port___8 *, enum devlink_port_fn_state, struct netlink_ext_ack *);
	int (*rate_leaf_tx_share_set)(struct devlink_rate___8 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_leaf_tx_max_set)(struct devlink_rate___8 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_share_set)(struct devlink_rate___8 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_tx_max_set)(struct devlink_rate___8 *, void *, u64, struct netlink_ext_ack *);
	int (*rate_node_new)(struct devlink_rate___8 *, void **, struct netlink_ext_ack *);
	int (*rate_node_del)(struct devlink_rate___8 *, void *, struct netlink_ext_ack *);
	int (*rate_leaf_parent_set)(struct devlink_rate___8 *, struct devlink_rate___8 *, void *, void *, struct netlink_ext_ack *);
	int (*rate_node_parent_set)(struct devlink_rate___8 *, struct devlink_rate___8 *, void *, void *, struct netlink_ext_ack *);
};

struct devlink_rate___8 {
	struct list_head list;
	enum devlink_rate_type type;
	struct devlink___8 *devlink;
	void *priv;
	u64 tx_share;
	u64 tx_max;
	struct devlink_rate___8 *parent;
	union {
		struct devlink_port___8 *devlink_port;
		struct {
			char *name;
			refcount_t refcnt;
		};
	};
};

struct block_device_operations___156;

struct gendisk___159 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___159 *part0;
	const struct block_device_operations___156 *fops;
	struct request_queue___156 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___142 *bdi;
	struct kobject___253 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___253 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___156 {
	struct bio___156 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___182 *bip_vec;
	struct bio_vec___182 bip_inline_vecs[0];
};

struct blkcg___144;

struct blkg_policy_data___144;

struct blkcg_gq___144 {
	struct request_queue___156 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___144 *blkcg;
	struct blkcg_gq___144 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___144 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___156 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___156(struct request___156 *);

typedef void integrity_complete_fn___156(struct request___156 *, unsigned int);

struct blk_integrity_profile___156 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___156 *prepare_fn;
	integrity_complete_fn___156 *complete_fn;
	const char *name;
};

struct block_device_operations___156 {
	blk_qc_t (*submit_bio)(struct bio___156 *);
	int (*open)(struct block_device___159 *, fmode_t);
	void (*release)(struct gendisk___159 *, fmode_t);
	int (*rw_page)(struct block_device___159 *, sector_t, struct page___270 *, unsigned int);
	int (*ioctl)(struct block_device___159 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___159 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___159 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___159 *);
	int (*getgeo)(struct block_device___159 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___159 *, bool);
	void (*swap_slot_free_notify)(struct block_device___159 *, long unsigned int);
	int (*report_zones)(struct gendisk___159 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___159 *, umode_t *);
	struct module___249 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___159 *, sector_t *);
};

typedef void rq_end_io_fn___156(struct request___156 *, blk_status_t);

struct request___156 {
	struct request_queue___156 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___151 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___156 *bio;
	struct bio___156 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___182 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___156 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___156 *saved_end_io;
		} flush;
	};
	struct gendisk___159 *rq_disk;
	struct block_device___159 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___156 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___151 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___156 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___253 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___265 *debugfs_dir;
	struct dentry___265 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___156;

struct elevator_mq_ops___156 {
	int (*init_sched)(struct request_queue___156 *, struct elevator_type___156 *);
	void (*exit_sched)(struct elevator_queue___156 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___151 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___151 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___151 *);
	bool (*allow_merge)(struct request_queue___156 *, struct request___156 *, struct bio___156 *);
	bool (*bio_merge)(struct request_queue___156 *, struct bio___156 *, unsigned int);
	int (*request_merge)(struct request_queue___156 *, struct request___156 **, struct bio___156 *);
	void (*request_merged)(struct request_queue___156 *, struct request___156 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___156 *, struct request___156 *, struct request___156 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___156 *);
	void (*finish_request)(struct request___156 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___151 *, struct list_head *, bool);
	struct request___156 * (*dispatch_request)(struct blk_mq_hw_ctx___151 *);
	bool (*has_work)(struct blk_mq_hw_ctx___151 *);
	void (*completed_request)(struct request___156 *, u64);
	void (*requeue_request)(struct request___156 *);
	struct request___156 * (*former_request)(struct request_queue___156 *, struct request___156 *);
	struct request___156 * (*next_request)(struct request_queue___156 *, struct request___156 *);
	void (*init_icq)(struct io_cq___156 *);
	void (*exit_icq)(struct io_cq___156 *);
};

struct elv_fs_entry___156;

struct elevator_type___156 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___156 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___156 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___249 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___156 {
	struct elevator_type___156 *type;
	void *elevator_data;
	struct kobject___253 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___156 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___156 *, char *);
	ssize_t (*store)(struct elevator_queue___156 *, const char *, size_t);
};

struct blk_mq_queue_data___151;

struct blk_mq_ops___151 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___151 *, const struct blk_mq_queue_data___151 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___151 *);
	int (*get_budget)(struct request_queue___156 *);
	void (*put_budget)(struct request_queue___156 *, int);
	void (*set_rq_budget_token)(struct request___156 *, int);
	int (*get_rq_budget_token)(struct request___156 *);
	enum blk_eh_timer_return (*timeout)(struct request___156 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___151 *);
	void (*complete)(struct request___156 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___151 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___151 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___151 *, struct request___156 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___151 *, struct request___156 *, unsigned int);
	void (*initialize_rq_fn)(struct request___156 *);
	void (*cleanup_rq)(struct request___156 *);
	bool (*busy)(struct request_queue___156 *);
	int (*map_queues)(struct blk_mq_tag_set___151 *);
	void (*show_rq)(struct seq_file___240 *, struct request___156 *);
};

struct blk_mq_tag_set___151 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___151 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___151 {
	struct request___156 *rq;
	bool last;
};

struct blkcg_policy_data___144;

struct blkcg___144 {
	struct cgroup_subsys_state___192 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___144 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___144 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___144 {
	struct blkcg___144 *blkcg;
	int plid;
};

struct blkg_policy_data___144 {
	struct blkcg_gq___144 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___130 {
	struct mem_cgroup___130 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___130 {
	struct lruvec___138 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___130 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___130 *memcg;
};

struct obj_cgroup___130 {
	struct percpu_ref refcnt;
	struct mem_cgroup___130 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___68 {
	spinlock_t *lock;
	struct sk_buff___75 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___68;

struct Qdisc_ops___68 {
	struct Qdisc_ops___68 *next;
	const struct Qdisc_class_ops___68 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___75 *, struct Qdisc___68 *, struct sk_buff___75 **);
	struct sk_buff___75 * (*dequeue)(struct Qdisc___68 *);
	struct sk_buff___75 * (*peek)(struct Qdisc___68 *);
	int (*init)(struct Qdisc___68 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___68 *);
	void (*destroy)(struct Qdisc___68 *);
	int (*change)(struct Qdisc___68 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___68 *);
	int (*change_tx_queue_len)(struct Qdisc___68 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___68 *, unsigned int);
	int (*dump)(struct Qdisc___68 *, struct sk_buff___75 *);
	int (*dump_stats)(struct Qdisc___68 *, struct gnet_dump___68 *);
	void (*ingress_block_set)(struct Qdisc___68 *, u32);
	void (*egress_block_set)(struct Qdisc___68 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___68 *);
	u32 (*egress_block_get)(struct Qdisc___68 *);
	struct module___249 *owner;
};

struct Qdisc_class_ops___68 {
	unsigned int flags;
	struct netdev_queue___74 * (*select_queue)(struct Qdisc___68 *, struct tcmsg *);
	int (*graft)(struct Qdisc___68 *, long unsigned int, struct Qdisc___68 *, struct Qdisc___68 **, struct netlink_ext_ack *);
	struct Qdisc___68 * (*leaf)(struct Qdisc___68 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___68 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___68 *, u32);
	int (*change)(struct Qdisc___68 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___68 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___68 *, struct qdisc_walker *);
	struct tcf_block___68 * (*tcf_block)(struct Qdisc___68 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___68 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___68 *, long unsigned int);
	int (*dump)(struct Qdisc___68 *, long unsigned int, struct sk_buff___75 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___68 *, long unsigned int, struct gnet_dump___68 *);
};

struct tcf_chain___68;

struct tcf_block___68 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___79 *net;
	struct Qdisc___68 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___68 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___68;

struct tcf_proto_ops___68;

struct tcf_proto___68 {
	struct tcf_proto___68 *next;
	void *root;
	int (*classify)(struct sk_buff___75 *, const struct tcf_proto___68 *, struct tcf_result___68 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___68 *ops;
	struct tcf_chain___68 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___68 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___68 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___68 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___75 *, const struct tcf_proto___68 *, struct tcf_result___68 *);
	int (*init)(struct tcf_proto___68 *);
	void (*destroy)(struct tcf_proto___68 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___68 *, u32);
	void (*put)(struct tcf_proto___68 *, void *);
	int (*change)(struct net___79 *, struct sk_buff___75 *, struct tcf_proto___68 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___68 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___68 *);
	void (*walk)(struct tcf_proto___68 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___68 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___68 *, void *);
	void (*hw_del)(struct tcf_proto___68 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___79 *, struct tcf_chain___68 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___79 *, struct tcf_proto___68 *, void *, struct sk_buff___75 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___79 *, struct tcf_proto___68 *, void *, struct sk_buff___75 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___75 *, struct net___79 *, void *);
	struct module___249 *owner;
	int flags;
};

struct tcf_chain___68 {
	struct mutex filter_chain_lock;
	struct tcf_proto___68 *filter_chain;
	struct list_head list;
	struct tcf_block___68 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___68 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___61 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___68 *prog;
};

struct pneigh_entry___61;

struct neigh_hash_table___61;

struct neigh_table___61 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___74 *, __u32 *);
	bool (*key_eq)(const struct neighbour___61 *, const void *);
	int (*constructor)(struct neighbour___61 *);
	int (*pconstructor)(struct pneigh_entry___61 *);
	void (*pdestructor)(struct pneigh_entry___61 *);
	void (*proxy_redo)(struct sk_buff___75 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___74 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___61 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___74 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___61 *nht;
	struct pneigh_entry___61 **phash_buckets;
};

struct neigh_ops___61 {
	int family;
	void (*solicit)(struct neighbour___61 *, struct sk_buff___75 *);
	void (*error_report)(struct neighbour___61 *, struct sk_buff___75 *);
	int (*output)(struct neighbour___61 *, struct sk_buff___75 *);
	int (*connected_output)(struct neighbour___61 *, struct sk_buff___75 *);
};

struct pneigh_entry___61 {
	struct pneigh_entry___61 *next;
	possible_net_t___74 net;
	struct net_device___74 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___61 {
	struct neighbour___61 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___61 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___61 *ctarget;
	struct net___79 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___61 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___61 *rule;
	u32 table;
	int flags;
};

struct proto___61 {
	void (*close)(struct sock___61 *, long int);
	int (*pre_connect)(struct sock___61 *, struct sockaddr *, int);
	int (*connect)(struct sock___61 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___61 *, int);
	struct sock___61 * (*accept)(struct sock___61 *, int, int *, bool);
	int (*ioctl)(struct sock___61 *, int, long unsigned int);
	int (*init)(struct sock___61 *);
	void (*destroy)(struct sock___61 *);
	void (*shutdown)(struct sock___61 *, int);
	int (*setsockopt)(struct sock___61 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___61 *, int, int, char *, int *);
	void (*keepalive)(struct sock___61 *, int);
	int (*compat_ioctl)(struct sock___61 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___61 *, struct msghdr___63 *, size_t);
	int (*recvmsg)(struct sock___61 *, struct msghdr___63 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___61 *, struct page___270 *, int, size_t, int);
	int (*bind)(struct sock___61 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___61 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___61 *, struct sk_buff___75 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___61 *);
	int (*hash)(struct sock___61 *);
	void (*unhash)(struct sock___61 *);
	void (*rehash)(struct sock___61 *);
	int (*get_port)(struct sock___61 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___61 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___61 *, int);
	bool (*sock_is_readable)(struct sock___61 *);
	void (*enter_memory_pressure)(struct sock___61 *);
	void (*leave_memory_pressure)(struct sock___61 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___3 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___249 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___61 *, int);
};

struct xdp_umem___3 {
	void *addrs;
	u64 size;
	u32 headroom;
	u32 chunk_size;
	u32 chunks;
	u32 npgs;
	struct user_struct *user;
	refcount_t users;
	u8 flags;
	bool zc;
	struct page___270 **pgs;
	int id;
	struct list_head xsk_dma_list;
	struct work_struct work;
};

struct xdp_buff_xsk___2 {
	struct xdp_buff___74 xdp;
	dma_addr_t dma;
	dma_addr_t frame_dma;
	struct xsk_buff_pool___2 *pool;
	bool unaligned;
	u64 orig_addr;
	struct list_head free_list_node;
};

struct ethtool_link_usettings {
	struct ethtool_link_settings base;
	struct {
		__u32 supported[3];
		__u32 advertising[3];
		__u32 lp_advertising[3];
	} link_modes;
};

struct ethtool_rx_flow_key {
	struct flow_dissector_key_basic basic;
	union {
		struct flow_dissector_key_ipv4_addrs ipv4;
		struct flow_dissector_key_ipv6_addrs ipv6;
	};
	struct flow_dissector_key_ports tp;
	struct flow_dissector_key_ip ip;
	struct flow_dissector_key_vlan vlan;
	struct flow_dissector_key_eth_addrs eth_addrs;
};

struct ethtool_rx_flow_match {
	struct flow_dissector dissector;
	int: 32;
	struct ethtool_rx_flow_key key;
	struct ethtool_rx_flow_key mask;
};

struct ethtool_phy_ops___3 {
	int (*get_sset_count)(struct phy_device___2 *);
	int (*get_strings)(struct phy_device___2 *, u8 *);
	int (*get_stats)(struct phy_device___2 *, struct ethtool_stats *, u64 *);
	int (*start_cable_test)(struct phy_device___2 *, struct netlink_ext_ack *);
	int (*start_cable_test_tdr)(struct phy_device___2 *, struct netlink_ext_ack *, const struct phy_tdr_config *);
};

enum {
	ETHTOOL_UDP_TUNNEL_TYPE_VXLAN = 0,
	ETHTOOL_UDP_TUNNEL_TYPE_GENEVE = 1,
	ETHTOOL_UDP_TUNNEL_TYPE_VXLAN_GPE = 2,
	__ETHTOOL_UDP_TUNNEL_TYPE_CNT = 3,
};

struct link_mode_info {
	int speed;
	u8 lanes;
	u8 duplex;
};

struct netlink_skb_parms___14 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___50 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netdev_notifier_info___13 {
	struct net_device___63 *dev;
	struct netlink_ext_ack *extack;
};

enum {
	ETHTOOL_MSG_USER_NONE = 0,
	ETHTOOL_MSG_STRSET_GET = 1,
	ETHTOOL_MSG_LINKINFO_GET = 2,
	ETHTOOL_MSG_LINKINFO_SET = 3,
	ETHTOOL_MSG_LINKMODES_GET = 4,
	ETHTOOL_MSG_LINKMODES_SET = 5,
	ETHTOOL_MSG_LINKSTATE_GET = 6,
	ETHTOOL_MSG_DEBUG_GET = 7,
	ETHTOOL_MSG_DEBUG_SET = 8,
	ETHTOOL_MSG_WOL_GET = 9,
	ETHTOOL_MSG_WOL_SET = 10,
	ETHTOOL_MSG_FEATURES_GET = 11,
	ETHTOOL_MSG_FEATURES_SET = 12,
	ETHTOOL_MSG_PRIVFLAGS_GET = 13,
	ETHTOOL_MSG_PRIVFLAGS_SET = 14,
	ETHTOOL_MSG_RINGS_GET = 15,
	ETHTOOL_MSG_RINGS_SET = 16,
	ETHTOOL_MSG_CHANNELS_GET = 17,
	ETHTOOL_MSG_CHANNELS_SET = 18,
	ETHTOOL_MSG_COALESCE_GET = 19,
	ETHTOOL_MSG_COALESCE_SET = 20,
	ETHTOOL_MSG_PAUSE_GET = 21,
	ETHTOOL_MSG_PAUSE_SET = 22,
	ETHTOOL_MSG_EEE_GET = 23,
	ETHTOOL_MSG_EEE_SET = 24,
	ETHTOOL_MSG_TSINFO_GET = 25,
	ETHTOOL_MSG_CABLE_TEST_ACT = 26,
	ETHTOOL_MSG_CABLE_TEST_TDR_ACT = 27,
	ETHTOOL_MSG_TUNNEL_INFO_GET = 28,
	ETHTOOL_MSG_FEC_GET = 29,
	ETHTOOL_MSG_FEC_SET = 30,
	ETHTOOL_MSG_MODULE_EEPROM_GET = 31,
	ETHTOOL_MSG_STATS_GET = 32,
	ETHTOOL_MSG_PHC_VCLOCKS_GET = 33,
	__ETHTOOL_MSG_USER_CNT = 34,
	ETHTOOL_MSG_USER_MAX = 33,
};

enum {
	ETHTOOL_A_HEADER_UNSPEC = 0,
	ETHTOOL_A_HEADER_DEV_INDEX = 1,
	ETHTOOL_A_HEADER_DEV_NAME = 2,
	ETHTOOL_A_HEADER_FLAGS = 3,
	__ETHTOOL_A_HEADER_CNT = 4,
	ETHTOOL_A_HEADER_MAX = 3,
};

enum {
	ETHTOOL_A_STRSET_UNSPEC = 0,
	ETHTOOL_A_STRSET_HEADER = 1,
	ETHTOOL_A_STRSET_STRINGSETS = 2,
	ETHTOOL_A_STRSET_COUNTS_ONLY = 3,
	__ETHTOOL_A_STRSET_CNT = 4,
	ETHTOOL_A_STRSET_MAX = 3,
};

enum {
	ETHTOOL_A_LINKINFO_UNSPEC = 0,
	ETHTOOL_A_LINKINFO_HEADER = 1,
	ETHTOOL_A_LINKINFO_PORT = 2,
	ETHTOOL_A_LINKINFO_PHYADDR = 3,
	ETHTOOL_A_LINKINFO_TP_MDIX = 4,
	ETHTOOL_A_LINKINFO_TP_MDIX_CTRL = 5,
	ETHTOOL_A_LINKINFO_TRANSCEIVER = 6,
	__ETHTOOL_A_LINKINFO_CNT = 7,
	ETHTOOL_A_LINKINFO_MAX = 6,
};

enum {
	ETHTOOL_A_LINKMODES_UNSPEC = 0,
	ETHTOOL_A_LINKMODES_HEADER = 1,
	ETHTOOL_A_LINKMODES_AUTONEG = 2,
	ETHTOOL_A_LINKMODES_OURS = 3,
	ETHTOOL_A_LINKMODES_PEER = 4,
	ETHTOOL_A_LINKMODES_SPEED = 5,
	ETHTOOL_A_LINKMODES_DUPLEX = 6,
	ETHTOOL_A_LINKMODES_MASTER_SLAVE_CFG = 7,
	ETHTOOL_A_LINKMODES_MASTER_SLAVE_STATE = 8,
	ETHTOOL_A_LINKMODES_LANES = 9,
	__ETHTOOL_A_LINKMODES_CNT = 10,
	ETHTOOL_A_LINKMODES_MAX = 9,
};

enum {
	ETHTOOL_A_LINKSTATE_UNSPEC = 0,
	ETHTOOL_A_LINKSTATE_HEADER = 1,
	ETHTOOL_A_LINKSTATE_LINK = 2,
	ETHTOOL_A_LINKSTATE_SQI = 3,
	ETHTOOL_A_LINKSTATE_SQI_MAX = 4,
	ETHTOOL_A_LINKSTATE_EXT_STATE = 5,
	ETHTOOL_A_LINKSTATE_EXT_SUBSTATE = 6,
	__ETHTOOL_A_LINKSTATE_CNT = 7,
	ETHTOOL_A_LINKSTATE_MAX = 6,
};

enum {
	ETHTOOL_A_DEBUG_UNSPEC = 0,
	ETHTOOL_A_DEBUG_HEADER = 1,
	ETHTOOL_A_DEBUG_MSGMASK = 2,
	__ETHTOOL_A_DEBUG_CNT = 3,
	ETHTOOL_A_DEBUG_MAX = 2,
};

enum {
	ETHTOOL_A_WOL_UNSPEC = 0,
	ETHTOOL_A_WOL_HEADER = 1,
	ETHTOOL_A_WOL_MODES = 2,
	ETHTOOL_A_WOL_SOPASS = 3,
	__ETHTOOL_A_WOL_CNT = 4,
	ETHTOOL_A_WOL_MAX = 3,
};

enum {
	ETHTOOL_A_FEATURES_UNSPEC = 0,
	ETHTOOL_A_FEATURES_HEADER = 1,
	ETHTOOL_A_FEATURES_HW = 2,
	ETHTOOL_A_FEATURES_WANTED = 3,
	ETHTOOL_A_FEATURES_ACTIVE = 4,
	ETHTOOL_A_FEATURES_NOCHANGE = 5,
	__ETHTOOL_A_FEATURES_CNT = 6,
	ETHTOOL_A_FEATURES_MAX = 5,
};

enum {
	ETHTOOL_A_PRIVFLAGS_UNSPEC = 0,
	ETHTOOL_A_PRIVFLAGS_HEADER = 1,
	ETHTOOL_A_PRIVFLAGS_FLAGS = 2,
	__ETHTOOL_A_PRIVFLAGS_CNT = 3,
	ETHTOOL_A_PRIVFLAGS_MAX = 2,
};

enum {
	ETHTOOL_A_RINGS_UNSPEC = 0,
	ETHTOOL_A_RINGS_HEADER = 1,
	ETHTOOL_A_RINGS_RX_MAX = 2,
	ETHTOOL_A_RINGS_RX_MINI_MAX = 3,
	ETHTOOL_A_RINGS_RX_JUMBO_MAX = 4,
	ETHTOOL_A_RINGS_TX_MAX = 5,
	ETHTOOL_A_RINGS_RX = 6,
	ETHTOOL_A_RINGS_RX_MINI = 7,
	ETHTOOL_A_RINGS_RX_JUMBO = 8,
	ETHTOOL_A_RINGS_TX = 9,
	__ETHTOOL_A_RINGS_CNT = 10,
	ETHTOOL_A_RINGS_MAX = 9,
};

enum {
	ETHTOOL_A_CHANNELS_UNSPEC = 0,
	ETHTOOL_A_CHANNELS_HEADER = 1,
	ETHTOOL_A_CHANNELS_RX_MAX = 2,
	ETHTOOL_A_CHANNELS_TX_MAX = 3,
	ETHTOOL_A_CHANNELS_OTHER_MAX = 4,
	ETHTOOL_A_CHANNELS_COMBINED_MAX = 5,
	ETHTOOL_A_CHANNELS_RX_COUNT = 6,
	ETHTOOL_A_CHANNELS_TX_COUNT = 7,
	ETHTOOL_A_CHANNELS_OTHER_COUNT = 8,
	ETHTOOL_A_CHANNELS_COMBINED_COUNT = 9,
	__ETHTOOL_A_CHANNELS_CNT = 10,
	ETHTOOL_A_CHANNELS_MAX = 9,
};

enum {
	ETHTOOL_A_COALESCE_UNSPEC = 0,
	ETHTOOL_A_COALESCE_HEADER = 1,
	ETHTOOL_A_COALESCE_RX_USECS = 2,
	ETHTOOL_A_COALESCE_RX_MAX_FRAMES = 3,
	ETHTOOL_A_COALESCE_RX_USECS_IRQ = 4,
	ETHTOOL_A_COALESCE_RX_MAX_FRAMES_IRQ = 5,
	ETHTOOL_A_COALESCE_TX_USECS = 6,
	ETHTOOL_A_COALESCE_TX_MAX_FRAMES = 7,
	ETHTOOL_A_COALESCE_TX_USECS_IRQ = 8,
	ETHTOOL_A_COALESCE_TX_MAX_FRAMES_IRQ = 9,
	ETHTOOL_A_COALESCE_STATS_BLOCK_USECS = 10,
	ETHTOOL_A_COALESCE_USE_ADAPTIVE_RX = 11,
	ETHTOOL_A_COALESCE_USE_ADAPTIVE_TX = 12,
	ETHTOOL_A_COALESCE_PKT_RATE_LOW = 13,
	ETHTOOL_A_COALESCE_RX_USECS_LOW = 14,
	ETHTOOL_A_COALESCE_RX_MAX_FRAMES_LOW = 15,
	ETHTOOL_A_COALESCE_TX_USECS_LOW = 16,
	ETHTOOL_A_COALESCE_TX_MAX_FRAMES_LOW = 17,
	ETHTOOL_A_COALESCE_PKT_RATE_HIGH = 18,
	ETHTOOL_A_COALESCE_RX_USECS_HIGH = 19,
	ETHTOOL_A_COALESCE_RX_MAX_FRAMES_HIGH = 20,
	ETHTOOL_A_COALESCE_TX_USECS_HIGH = 21,
	ETHTOOL_A_COALESCE_TX_MAX_FRAMES_HIGH = 22,
	ETHTOOL_A_COALESCE_RATE_SAMPLE_INTERVAL = 23,
	ETHTOOL_A_COALESCE_USE_CQE_MODE_TX = 24,
	ETHTOOL_A_COALESCE_USE_CQE_MODE_RX = 25,
	__ETHTOOL_A_COALESCE_CNT = 26,
	ETHTOOL_A_COALESCE_MAX = 25,
};

enum {
	ETHTOOL_A_PAUSE_UNSPEC = 0,
	ETHTOOL_A_PAUSE_HEADER = 1,
	ETHTOOL_A_PAUSE_AUTONEG = 2,
	ETHTOOL_A_PAUSE_RX = 3,
	ETHTOOL_A_PAUSE_TX = 4,
	ETHTOOL_A_PAUSE_STATS = 5,
	__ETHTOOL_A_PAUSE_CNT = 6,
	ETHTOOL_A_PAUSE_MAX = 5,
};

enum {
	ETHTOOL_A_EEE_UNSPEC = 0,
	ETHTOOL_A_EEE_HEADER = 1,
	ETHTOOL_A_EEE_MODES_OURS = 2,
	ETHTOOL_A_EEE_MODES_PEER = 3,
	ETHTOOL_A_EEE_ACTIVE = 4,
	ETHTOOL_A_EEE_ENABLED = 5,
	ETHTOOL_A_EEE_TX_LPI_ENABLED = 6,
	ETHTOOL_A_EEE_TX_LPI_TIMER = 7,
	__ETHTOOL_A_EEE_CNT = 8,
	ETHTOOL_A_EEE_MAX = 7,
};

enum {
	ETHTOOL_A_TSINFO_UNSPEC = 0,
	ETHTOOL_A_TSINFO_HEADER = 1,
	ETHTOOL_A_TSINFO_TIMESTAMPING = 2,
	ETHTOOL_A_TSINFO_TX_TYPES = 3,
	ETHTOOL_A_TSINFO_RX_FILTERS = 4,
	ETHTOOL_A_TSINFO_PHC_INDEX = 5,
	__ETHTOOL_A_TSINFO_CNT = 6,
	ETHTOOL_A_TSINFO_MAX = 5,
};

enum {
	ETHTOOL_A_PHC_VCLOCKS_UNSPEC = 0,
	ETHTOOL_A_PHC_VCLOCKS_HEADER = 1,
	ETHTOOL_A_PHC_VCLOCKS_NUM = 2,
	ETHTOOL_A_PHC_VCLOCKS_INDEX = 3,
	__ETHTOOL_A_PHC_VCLOCKS_CNT = 4,
	ETHTOOL_A_PHC_VCLOCKS_MAX = 3,
};

enum {
	ETHTOOL_A_CABLE_TEST_UNSPEC = 0,
	ETHTOOL_A_CABLE_TEST_HEADER = 1,
	__ETHTOOL_A_CABLE_TEST_CNT = 2,
	ETHTOOL_A_CABLE_TEST_MAX = 1,
};

enum {
	ETHTOOL_A_CABLE_TEST_TDR_UNSPEC = 0,
	ETHTOOL_A_CABLE_TEST_TDR_HEADER = 1,
	ETHTOOL_A_CABLE_TEST_TDR_CFG = 2,
	__ETHTOOL_A_CABLE_TEST_TDR_CNT = 3,
	ETHTOOL_A_CABLE_TEST_TDR_MAX = 2,
};

enum {
	ETHTOOL_A_TUNNEL_INFO_UNSPEC = 0,
	ETHTOOL_A_TUNNEL_INFO_HEADER = 1,
	ETHTOOL_A_TUNNEL_INFO_UDP_PORTS = 2,
	__ETHTOOL_A_TUNNEL_INFO_CNT = 3,
	ETHTOOL_A_TUNNEL_INFO_MAX = 2,
};

enum {
	ETHTOOL_A_FEC_UNSPEC = 0,
	ETHTOOL_A_FEC_HEADER = 1,
	ETHTOOL_A_FEC_MODES = 2,
	ETHTOOL_A_FEC_AUTO = 3,
	ETHTOOL_A_FEC_ACTIVE = 4,
	ETHTOOL_A_FEC_STATS = 5,
	__ETHTOOL_A_FEC_CNT = 6,
	ETHTOOL_A_FEC_MAX = 5,
};

enum {
	ETHTOOL_A_MODULE_EEPROM_UNSPEC = 0,
	ETHTOOL_A_MODULE_EEPROM_HEADER = 1,
	ETHTOOL_A_MODULE_EEPROM_OFFSET = 2,
	ETHTOOL_A_MODULE_EEPROM_LENGTH = 3,
	ETHTOOL_A_MODULE_EEPROM_PAGE = 4,
	ETHTOOL_A_MODULE_EEPROM_BANK = 5,
	ETHTOOL_A_MODULE_EEPROM_I2C_ADDRESS = 6,
	ETHTOOL_A_MODULE_EEPROM_DATA = 7,
	__ETHTOOL_A_MODULE_EEPROM_CNT = 8,
	ETHTOOL_A_MODULE_EEPROM_MAX = 7,
};

enum {
	ETHTOOL_STATS_ETH_PHY = 0,
	ETHTOOL_STATS_ETH_MAC = 1,
	ETHTOOL_STATS_ETH_CTRL = 2,
	ETHTOOL_STATS_RMON = 3,
	__ETHTOOL_STATS_CNT = 4,
};

enum {
	ETHTOOL_A_STATS_ETH_PHY_5_SYM_ERR = 0,
	__ETHTOOL_A_STATS_ETH_PHY_CNT = 1,
	ETHTOOL_A_STATS_ETH_PHY_MAX = 0,
};

enum {
	ETHTOOL_A_STATS_ETH_MAC_2_TX_PKT = 0,
	ETHTOOL_A_STATS_ETH_MAC_3_SINGLE_COL = 1,
	ETHTOOL_A_STATS_ETH_MAC_4_MULTI_COL = 2,
	ETHTOOL_A_STATS_ETH_MAC_5_RX_PKT = 3,
	ETHTOOL_A_STATS_ETH_MAC_6_FCS_ERR = 4,
	ETHTOOL_A_STATS_ETH_MAC_7_ALIGN_ERR = 5,
	ETHTOOL_A_STATS_ETH_MAC_8_TX_BYTES = 6,
	ETHTOOL_A_STATS_ETH_MAC_9_TX_DEFER = 7,
	ETHTOOL_A_STATS_ETH_MAC_10_LATE_COL = 8,
	ETHTOOL_A_STATS_ETH_MAC_11_XS_COL = 9,
	ETHTOOL_A_STATS_ETH_MAC_12_TX_INT_ERR = 10,
	ETHTOOL_A_STATS_ETH_MAC_13_CS_ERR = 11,
	ETHTOOL_A_STATS_ETH_MAC_14_RX_BYTES = 12,
	ETHTOOL_A_STATS_ETH_MAC_15_RX_INT_ERR = 13,
	ETHTOOL_A_STATS_ETH_MAC_18_TX_MCAST = 14,
	ETHTOOL_A_STATS_ETH_MAC_19_TX_BCAST = 15,
	ETHTOOL_A_STATS_ETH_MAC_20_XS_DEFER = 16,
	ETHTOOL_A_STATS_ETH_MAC_21_RX_MCAST = 17,
	ETHTOOL_A_STATS_ETH_MAC_22_RX_BCAST = 18,
	ETHTOOL_A_STATS_ETH_MAC_23_IR_LEN_ERR = 19,
	ETHTOOL_A_STATS_ETH_MAC_24_OOR_LEN = 20,
	ETHTOOL_A_STATS_ETH_MAC_25_TOO_LONG_ERR = 21,
	__ETHTOOL_A_STATS_ETH_MAC_CNT = 22,
	ETHTOOL_A_STATS_ETH_MAC_MAX = 21,
};

enum {
	ETHTOOL_A_STATS_ETH_CTRL_3_TX = 0,
	ETHTOOL_A_STATS_ETH_CTRL_4_RX = 1,
	ETHTOOL_A_STATS_ETH_CTRL_5_RX_UNSUP = 2,
	__ETHTOOL_A_STATS_ETH_CTRL_CNT = 3,
	ETHTOOL_A_STATS_ETH_CTRL_MAX = 2,
};

enum {
	ETHTOOL_A_STATS_RMON_UNDERSIZE = 0,
	ETHTOOL_A_STATS_RMON_OVERSIZE = 1,
	ETHTOOL_A_STATS_RMON_FRAG = 2,
	ETHTOOL_A_STATS_RMON_JABBER = 3,
	__ETHTOOL_A_STATS_RMON_CNT = 4,
	ETHTOOL_A_STATS_RMON_MAX = 3,
};

enum ethtool_multicast_groups {
	ETHNL_MCGRP_MONITOR = 0,
};

struct genl_ops___6;

struct genl_info___5;

struct genl_small_ops___6;

struct genl_family___6 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___6 *, struct sk_buff___64 *, struct genl_info___5 *);
	void (*post_doit)(const struct genl_ops___6 *, struct sk_buff___64 *, struct genl_info___5 *);
	const struct genl_ops___6 *ops;
	const struct genl_small_ops___6 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___238 *module;
};

struct genl_ops___6 {
	int (*doit)(struct sk_buff___64 *, struct genl_info___5 *);
	int (*start)(struct netlink_callback___63 *);
	int (*dumpit)(struct sk_buff___64 *, struct netlink_callback___63 *);
	int (*done)(struct netlink_callback___63 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___5 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___63 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___6 {
	int (*doit)(struct sk_buff___64 *, struct genl_info___5 *);
	int (*dumpit)(struct sk_buff___64 *, struct netlink_callback___63 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_dumpit_info___4 {
	const struct genl_family___6 *family;
	struct genl_ops___6 op;
	struct nlattr **attrs;
};

struct ethnl_req_info {
	struct net_device___63 *dev;
	u32 flags;
};

struct ethnl_reply_data {
	struct net_device___63 *dev;
};

struct ethnl_request_ops {
	u8 request_cmd;
	u8 reply_cmd;
	u16 hdr_attr;
	unsigned int req_info_size;
	unsigned int reply_data_size;
	bool allow_nodev_do;
	int (*parse_request)(struct ethnl_req_info *, struct nlattr **, struct netlink_ext_ack *);
	int (*prepare_data)(const struct ethnl_req_info *, struct ethnl_reply_data *, struct genl_info___5 *);
	int (*reply_size)(const struct ethnl_req_info *, const struct ethnl_reply_data *);
	int (*fill_reply)(struct sk_buff___64 *, const struct ethnl_req_info *, const struct ethnl_reply_data *);
	void (*cleanup_data)(struct ethnl_reply_data *);
};

struct ethnl_dump_ctx {
	const struct ethnl_request_ops *ops;
	struct ethnl_req_info *req_info;
	struct ethnl_reply_data *reply_data;
	int pos_hash;
	int pos_idx;
};

typedef void (*ethnl_notify_handler_t)(struct net_device___63 *, unsigned int, const void *);

enum {
	ETHTOOL_A_BITSET_BIT_UNSPEC = 0,
	ETHTOOL_A_BITSET_BIT_INDEX = 1,
	ETHTOOL_A_BITSET_BIT_NAME = 2,
	ETHTOOL_A_BITSET_BIT_VALUE = 3,
	__ETHTOOL_A_BITSET_BIT_CNT = 4,
	ETHTOOL_A_BITSET_BIT_MAX = 3,
};

enum {
	ETHTOOL_A_BITSET_BITS_UNSPEC = 0,
	ETHTOOL_A_BITSET_BITS_BIT = 1,
	__ETHTOOL_A_BITSET_BITS_CNT = 2,
	ETHTOOL_A_BITSET_BITS_MAX = 1,
};

enum {
	ETHTOOL_A_BITSET_UNSPEC = 0,
	ETHTOOL_A_BITSET_NOMASK = 1,
	ETHTOOL_A_BITSET_SIZE = 2,
	ETHTOOL_A_BITSET_BITS = 3,
	ETHTOOL_A_BITSET_VALUE = 4,
	ETHTOOL_A_BITSET_MASK = 5,
	__ETHTOOL_A_BITSET_CNT = 6,
	ETHTOOL_A_BITSET_MAX = 5,
};

typedef const char (* const ethnl_string_array_t)[32];

struct ethtool_phy_ops___4 {
	int (*get_sset_count)(struct phy_device___12 *);
	int (*get_strings)(struct phy_device___12 *, u8 *);
	int (*get_stats)(struct phy_device___12 *, struct ethtool_stats *, u64 *);
	int (*start_cable_test)(struct phy_device___12 *, struct netlink_ext_ack *);
	int (*start_cable_test_tdr)(struct phy_device___12 *, struct netlink_ext_ack *, const struct phy_tdr_config *);
};

enum {
	ETHTOOL_A_STRING_UNSPEC = 0,
	ETHTOOL_A_STRING_INDEX = 1,
	ETHTOOL_A_STRING_VALUE = 2,
	__ETHTOOL_A_STRING_CNT = 3,
	ETHTOOL_A_STRING_MAX = 2,
};

enum {
	ETHTOOL_A_STRINGS_UNSPEC = 0,
	ETHTOOL_A_STRINGS_STRING = 1,
	__ETHTOOL_A_STRINGS_CNT = 2,
	ETHTOOL_A_STRINGS_MAX = 1,
};

enum {
	ETHTOOL_A_STRINGSET_UNSPEC = 0,
	ETHTOOL_A_STRINGSET_ID = 1,
	ETHTOOL_A_STRINGSET_COUNT = 2,
	ETHTOOL_A_STRINGSET_STRINGS = 3,
	__ETHTOOL_A_STRINGSET_CNT = 4,
	ETHTOOL_A_STRINGSET_MAX = 3,
};

enum {
	ETHTOOL_A_STRINGSETS_UNSPEC = 0,
	ETHTOOL_A_STRINGSETS_STRINGSET = 1,
	__ETHTOOL_A_STRINGSETS_CNT = 2,
	ETHTOOL_A_STRINGSETS_MAX = 1,
};

struct strset_info {
	bool per_dev;
	bool free_strings;
	unsigned int count;
	const char (*strings)[32];
};

struct strset_req_info {
	struct ethnl_req_info base;
	u32 req_ids;
	bool counts_only;
};

struct strset_reply_data {
	struct ethnl_reply_data base;
	struct strset_info sets[21];
};

struct linkinfo_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_link_ksettings ksettings;
	struct ethtool_link_settings *lsettings;
};

struct ethnl_req_info___2 {
	struct net_device___73 *dev;
	u32 flags;
};

struct ethnl_reply_data___2 {
	struct net_device___73 *dev;
};

struct ethnl_request_ops___2 {
	u8 request_cmd;
	u8 reply_cmd;
	u16 hdr_attr;
	unsigned int req_info_size;
	unsigned int reply_data_size;
	bool allow_nodev_do;
	int (*parse_request)(struct ethnl_req_info___2 *, struct nlattr **, struct netlink_ext_ack *);
	int (*prepare_data)(const struct ethnl_req_info___2 *, struct ethnl_reply_data___2 *, struct genl_info___3 *);
	int (*reply_size)(const struct ethnl_req_info___2 *, const struct ethnl_reply_data___2 *);
	int (*fill_reply)(struct sk_buff___74 *, const struct ethnl_req_info___2 *, const struct ethnl_reply_data___2 *);
	void (*cleanup_data)(struct ethnl_reply_data___2 *);
};

struct linkmodes_reply_data {
	struct ethnl_reply_data___2 base;
	struct ethtool_link_ksettings ksettings;
	struct ethtool_link_settings *lsettings;
	bool peer_empty;
};

struct linkstate_reply_data {
	struct ethnl_reply_data base;
	int link;
	int sqi;
	int sqi_max;
	bool link_ext_state_provided;
	struct ethtool_link_ext_state_info ethtool_link_ext_state_info;
};

struct debug_reply_data {
	struct ethnl_reply_data base;
	u32 msg_mask;
};

struct wol_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_wolinfo wol;
	bool show_sopass;
};

struct features_reply_data {
	struct ethnl_reply_data base;
	u32 hw[2];
	u32 wanted[2];
	u32 active[2];
	u32 nochange[2];
	u32 all[2];
};

struct privflags_reply_data {
	struct ethnl_reply_data base;
	const char (*priv_flag_names)[32];
	unsigned int n_priv_flags;
	u32 priv_flags;
};

struct rings_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_ringparam ringparam;
};

struct genl_info___6 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___74 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct ethnl_req_info___3 {
	struct net_device___74 *dev;
	u32 flags;
};

struct ethnl_reply_data___3 {
	struct net_device___74 *dev;
};

struct ethnl_request_ops___3 {
	u8 request_cmd;
	u8 reply_cmd;
	u16 hdr_attr;
	unsigned int req_info_size;
	unsigned int reply_data_size;
	bool allow_nodev_do;
	int (*parse_request)(struct ethnl_req_info___3 *, struct nlattr **, struct netlink_ext_ack *);
	int (*prepare_data)(const struct ethnl_req_info___3 *, struct ethnl_reply_data___3 *, struct genl_info___6 *);
	int (*reply_size)(const struct ethnl_req_info___3 *, const struct ethnl_reply_data___3 *);
	int (*fill_reply)(struct sk_buff___75 *, const struct ethnl_req_info___3 *, const struct ethnl_reply_data___3 *);
	void (*cleanup_data)(struct ethnl_reply_data___3 *);
};

struct channels_reply_data {
	struct ethnl_reply_data___3 base;
	struct ethtool_channels channels;
};

struct coalesce_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_coalesce coalesce;
	struct kernel_ethtool_coalesce kernel_coalesce;
	u32 supported_params;
};

enum {
	ETHTOOL_A_PAUSE_STAT_UNSPEC = 0,
	ETHTOOL_A_PAUSE_STAT_PAD = 1,
	ETHTOOL_A_PAUSE_STAT_TX_FRAMES = 2,
	ETHTOOL_A_PAUSE_STAT_RX_FRAMES = 3,
	__ETHTOOL_A_PAUSE_STAT_CNT = 4,
	ETHTOOL_A_PAUSE_STAT_MAX = 3,
};

struct pause_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_pauseparam pauseparam;
	struct ethtool_pause_stats pausestat;
};

struct eee_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_eee eee;
};

struct tsinfo_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_ts_info ts_info;
};

enum {
	ETHTOOL_A_CABLE_PAIR_A = 0,
	ETHTOOL_A_CABLE_PAIR_B = 1,
	ETHTOOL_A_CABLE_PAIR_C = 2,
	ETHTOOL_A_CABLE_PAIR_D = 3,
};

enum {
	ETHTOOL_A_CABLE_RESULT_UNSPEC = 0,
	ETHTOOL_A_CABLE_RESULT_PAIR = 1,
	ETHTOOL_A_CABLE_RESULT_CODE = 2,
	__ETHTOOL_A_CABLE_RESULT_CNT = 3,
	ETHTOOL_A_CABLE_RESULT_MAX = 2,
};

enum {
	ETHTOOL_A_CABLE_FAULT_LENGTH_UNSPEC = 0,
	ETHTOOL_A_CABLE_FAULT_LENGTH_PAIR = 1,
	ETHTOOL_A_CABLE_FAULT_LENGTH_CM = 2,
	__ETHTOOL_A_CABLE_FAULT_LENGTH_CNT = 3,
	ETHTOOL_A_CABLE_FAULT_LENGTH_MAX = 2,
};

enum {
	ETHTOOL_A_CABLE_TEST_NTF_STATUS_UNSPEC = 0,
	ETHTOOL_A_CABLE_TEST_NTF_STATUS_STARTED = 1,
	ETHTOOL_A_CABLE_TEST_NTF_STATUS_COMPLETED = 2,
};

enum {
	ETHTOOL_A_CABLE_NEST_UNSPEC = 0,
	ETHTOOL_A_CABLE_NEST_RESULT = 1,
	ETHTOOL_A_CABLE_NEST_FAULT_LENGTH = 2,
	__ETHTOOL_A_CABLE_NEST_CNT = 3,
	ETHTOOL_A_CABLE_NEST_MAX = 2,
};

enum {
	ETHTOOL_A_CABLE_TEST_NTF_UNSPEC = 0,
	ETHTOOL_A_CABLE_TEST_NTF_HEADER = 1,
	ETHTOOL_A_CABLE_TEST_NTF_STATUS = 2,
	ETHTOOL_A_CABLE_TEST_NTF_NEST = 3,
	__ETHTOOL_A_CABLE_TEST_NTF_CNT = 4,
	ETHTOOL_A_CABLE_TEST_NTF_MAX = 3,
};

enum {
	ETHTOOL_A_CABLE_TEST_TDR_CFG_UNSPEC = 0,
	ETHTOOL_A_CABLE_TEST_TDR_CFG_FIRST = 1,
	ETHTOOL_A_CABLE_TEST_TDR_CFG_LAST = 2,
	ETHTOOL_A_CABLE_TEST_TDR_CFG_STEP = 3,
	ETHTOOL_A_CABLE_TEST_TDR_CFG_PAIR = 4,
	__ETHTOOL_A_CABLE_TEST_TDR_CFG_CNT = 5,
	ETHTOOL_A_CABLE_TEST_TDR_CFG_MAX = 4,
};

enum {
	ETHTOOL_A_CABLE_AMPLITUDE_UNSPEC = 0,
	ETHTOOL_A_CABLE_AMPLITUDE_PAIR = 1,
	ETHTOOL_A_CABLE_AMPLITUDE_mV = 2,
	__ETHTOOL_A_CABLE_AMPLITUDE_CNT = 3,
	ETHTOOL_A_CABLE_AMPLITUDE_MAX = 2,
};

enum {
	ETHTOOL_A_CABLE_PULSE_UNSPEC = 0,
	ETHTOOL_A_CABLE_PULSE_mV = 1,
	__ETHTOOL_A_CABLE_PULSE_CNT = 2,
	ETHTOOL_A_CABLE_PULSE_MAX = 1,
};

enum {
	ETHTOOL_A_CABLE_STEP_UNSPEC = 0,
	ETHTOOL_A_CABLE_STEP_FIRST_DISTANCE = 1,
	ETHTOOL_A_CABLE_STEP_LAST_DISTANCE = 2,
	ETHTOOL_A_CABLE_STEP_STEP_DISTANCE = 3,
	__ETHTOOL_A_CABLE_STEP_CNT = 4,
	ETHTOOL_A_CABLE_STEP_MAX = 3,
};

enum {
	ETHTOOL_A_CABLE_TDR_NEST_UNSPEC = 0,
	ETHTOOL_A_CABLE_TDR_NEST_STEP = 1,
	ETHTOOL_A_CABLE_TDR_NEST_AMPLITUDE = 2,
	ETHTOOL_A_CABLE_TDR_NEST_PULSE = 3,
	__ETHTOOL_A_CABLE_TDR_NEST_CNT = 4,
	ETHTOOL_A_CABLE_TDR_NEST_MAX = 3,
};

enum {
	ETHTOOL_A_TUNNEL_UDP_ENTRY_UNSPEC = 0,
	ETHTOOL_A_TUNNEL_UDP_ENTRY_PORT = 1,
	ETHTOOL_A_TUNNEL_UDP_ENTRY_TYPE = 2,
	__ETHTOOL_A_TUNNEL_UDP_ENTRY_CNT = 3,
	ETHTOOL_A_TUNNEL_UDP_ENTRY_MAX = 2,
};

enum {
	ETHTOOL_A_TUNNEL_UDP_TABLE_UNSPEC = 0,
	ETHTOOL_A_TUNNEL_UDP_TABLE_SIZE = 1,
	ETHTOOL_A_TUNNEL_UDP_TABLE_TYPES = 2,
	ETHTOOL_A_TUNNEL_UDP_TABLE_ENTRY = 3,
	__ETHTOOL_A_TUNNEL_UDP_TABLE_CNT = 4,
	ETHTOOL_A_TUNNEL_UDP_TABLE_MAX = 3,
};

enum {
	ETHTOOL_A_TUNNEL_UDP_UNSPEC = 0,
	ETHTOOL_A_TUNNEL_UDP_TABLE = 1,
	__ETHTOOL_A_TUNNEL_UDP_CNT = 2,
	ETHTOOL_A_TUNNEL_UDP_MAX = 1,
};

enum udp_parsable_tunnel_type {
	UDP_TUNNEL_TYPE_VXLAN = 1,
	UDP_TUNNEL_TYPE_GENEVE = 2,
	UDP_TUNNEL_TYPE_VXLAN_GPE = 4,
};

enum udp_tunnel_nic_info_flags {
	UDP_TUNNEL_NIC_INFO_MAY_SLEEP = 1,
	UDP_TUNNEL_NIC_INFO_OPEN_ONLY = 2,
	UDP_TUNNEL_NIC_INFO_IPV4_ONLY = 4,
	UDP_TUNNEL_NIC_INFO_STATIC_IANA_VXLAN = 8,
};

struct udp_tunnel_nic_ops {
	void (*get_port)(struct net_device___6 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	void (*set_port_priv)(struct net_device___6 *, unsigned int, unsigned int, u8);
	void (*add_port)(struct net_device___6 *, struct udp_tunnel_info *);
	void (*del_port)(struct net_device___6 *, struct udp_tunnel_info *);
	void (*reset_ntf)(struct net_device___6 *);
	size_t (*dump_size)(struct net_device___6 *, unsigned int);
	int (*dump_write)(struct net_device___6 *, unsigned int, struct sk_buff___53 *);
};

struct genl_ops___7;

struct genl_info___7;

struct genl_small_ops___7;

struct genl_family___7 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok: 1;
	u8 parallel_ops: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___7 *, struct sk_buff___53 *, struct genl_info___7 *);
	void (*post_doit)(const struct genl_ops___7 *, struct sk_buff___53 *, struct genl_info___7 *);
	const struct genl_ops___7 *ops;
	const struct genl_small_ops___7 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___227 *module;
};

struct genl_ops___7 {
	int (*doit)(struct sk_buff___53 *, struct genl_info___7 *);
	int (*start)(struct netlink_callback___52 *);
	int (*dumpit)(struct sk_buff___53 *, struct netlink_callback___52 *);
	int (*done)(struct netlink_callback___52 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___7 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___52 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___7 {
	int (*doit)(struct sk_buff___53 *, struct genl_info___7 *);
	int (*dumpit)(struct sk_buff___53 *, struct netlink_callback___52 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_dumpit_info___5 {
	const struct genl_family___7 *family;
	struct genl_ops___7 op;
	struct nlattr **attrs;
};

struct ethnl_req_info___4 {
	struct net_device___6 *dev;
	u32 flags;
};

struct ethnl_tunnel_info_dump_ctx {
	struct ethnl_req_info___4 req_info;
	int pos_hash;
	int pos_idx;
};

enum {
	ETHTOOL_A_FEC_STAT_UNSPEC = 0,
	ETHTOOL_A_FEC_STAT_PAD = 1,
	ETHTOOL_A_FEC_STAT_CORRECTED = 2,
	ETHTOOL_A_FEC_STAT_UNCORR = 3,
	ETHTOOL_A_FEC_STAT_CORR_BITS = 4,
	__ETHTOOL_A_FEC_STAT_CNT = 5,
	ETHTOOL_A_FEC_STAT_MAX = 4,
};

struct fec_stat_grp {
	u64 stats[9];
	u8 cnt;
};

struct fec_reply_data {
	struct ethnl_reply_data base;
	long unsigned int fec_link_modes[2];
	u32 active_fec;
	u8 fec_auto;
	struct fec_stat_grp corr;
	struct fec_stat_grp uncorr;
	struct fec_stat_grp corr_bits;
};

struct eeprom_req_info {
	struct ethnl_req_info base;
	u32 offset;
	u32 length;
	u8 page;
	u8 bank;
	u8 i2c_address;
};

struct eeprom_reply_data {
	struct ethnl_reply_data base;
	u32 length;
	u8 *data;
};

enum {
	ETHTOOL_A_STATS_GRP_UNSPEC = 0,
	ETHTOOL_A_STATS_GRP_PAD = 1,
	ETHTOOL_A_STATS_GRP_ID = 2,
	ETHTOOL_A_STATS_GRP_SS_ID = 3,
	ETHTOOL_A_STATS_GRP_STAT = 4,
	ETHTOOL_A_STATS_GRP_HIST_RX = 5,
	ETHTOOL_A_STATS_GRP_HIST_TX = 6,
	ETHTOOL_A_STATS_GRP_HIST_BKT_LOW = 7,
	ETHTOOL_A_STATS_GRP_HIST_BKT_HI = 8,
	ETHTOOL_A_STATS_GRP_HIST_VAL = 9,
	__ETHTOOL_A_STATS_GRP_CNT = 10,
	ETHTOOL_A_STATS_GRP_MAX = 4,
};

struct stats_req_info {
	struct ethnl_req_info base;
	long unsigned int stat_mask[1];
};

struct stats_reply_data {
	struct ethnl_reply_data base;
	struct ethtool_eth_phy_stats phy_stats;
	struct ethtool_eth_mac_stats mac_stats;
	struct ethtool_eth_ctrl_stats ctrl_stats;
	struct ethtool_rmon_stats rmon_stats;
	const struct ethtool_rmon_hist_range *rmon_ranges;
};

struct phc_vclocks_reply_data {
	struct ethnl_reply_data base;
	int num;
	int *index;
};

struct dentry___266;

struct super_block___266;

struct module___250;

struct file_system_type___266 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___266 * (*mount)(struct file_system_type___266 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___266 *);
	struct module___250 *owner;
	struct file_system_type___266 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___266;

struct kiocb___266;

struct iov_iter___186;

struct poll_table_struct___187;

struct vm_area_struct___271;

struct inode___266;

struct file_lock___266;

struct page___271;

struct pipe_inode_info___107;

struct seq_file___241;

struct file_operations___267 {
	struct module___250 *owner;
	loff_t (*llseek)(struct file___266 *, loff_t, int);
	ssize_t (*read)(struct file___266 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___266 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___266 *, struct iov_iter___186 *);
	ssize_t (*write_iter)(struct kiocb___266 *, struct iov_iter___186 *);
	int (*iopoll)(struct kiocb___266 *, bool);
	int (*iterate)(struct file___266 *, struct dir_context *);
	int (*iterate_shared)(struct file___266 *, struct dir_context *);
	__poll_t (*poll)(struct file___266 *, struct poll_table_struct___187 *);
	long int (*unlocked_ioctl)(struct file___266 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___266 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___266 *, struct vm_area_struct___271 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___266 *, struct file___266 *);
	int (*flush)(struct file___266 *, fl_owner_t);
	int (*release)(struct inode___266 *, struct file___266 *);
	int (*fsync)(struct file___266 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___266 *, int);
	int (*lock)(struct file___266 *, int, struct file_lock___266 *);
	ssize_t (*sendpage)(struct file___266 *, struct page___271 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___266 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___266 *, long unsigned int);
	int (*flock)(struct file___266 *, int, struct file_lock___266 *);
	ssize_t (*splice_write)(struct pipe_inode_info___107 *, struct file___266 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___266 *, loff_t *, struct pipe_inode_info___107 *, size_t, unsigned int);
	int (*setlease)(struct file___266 *, long int, struct file_lock___266 **, void **);
	long int (*fallocate)(struct file___266 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___241 *, struct file___266 *);
	ssize_t (*copy_file_range)(struct file___266 *, loff_t, struct file___266 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___266 *, loff_t, struct file___266 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___266 *, loff_t, loff_t, int);
};

struct vmacache___271 {
	u64 seqnum;
	struct vm_area_struct___271 *vmas[4];
};

struct page_frag___271 {
	struct page___271 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___272;

struct pid___243;

struct nsproxy___252;

struct signal_struct___267;

struct bio_list___157;

struct backing_dev_info___143;

struct io_context___157;

struct css_set___193;

struct mem_cgroup___131;

struct request_queue___157;

struct vm_struct___249;

struct task_struct___273 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___273 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___272 *mm;
	struct mm_struct___272 *active_mm;
	struct vmacache___271 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___273 *real_parent;
	struct task_struct___273 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___273 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___243 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___252 *nsproxy;
	struct signal_struct___267 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___273 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___157 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___143 *backing_dev_info;
	struct io_context___157 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___193 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___107 *splice_pipe;
	struct page_frag___271 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___131 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___131 *active_memcg;
	struct request_queue___157 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___273 *oom_reaper_list;
	struct vm_struct___249 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___254;

struct kobj_type___254;

struct kernfs_node___254;

struct kobject___254 {
	const char *name;
	struct list_head entry;
	struct kobject___254 *parent;
	struct kset___254 *kset;
	struct kobj_type___254 *ktype;
	struct kernfs_node___254 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___251 {
	struct kobject___254 kobj;
	struct module___250 *mod;
	struct kobject___254 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___250 {
	struct module___250 *mod;
	struct latch_tree_node node;
};

struct module_layout___250 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___250 mtn;
};

struct module_attribute___250;

struct kernel_param___250;

struct module___250 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___251 mkobj;
	struct module_attribute___250 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___254 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___250 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___250 core_layout;
	struct module_layout___250 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___266;

struct dentry___266 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___266 *d_parent;
	struct qstr d_name;
	struct inode___266 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___266 *d_op;
	struct super_block___266 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___266;

struct address_space___266 {
	struct inode___266 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___266 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___266;

struct bdi_writeback___143;

struct inode___266 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___266 *i_op;
	struct super_block___266 *i_sb;
	struct address_space___266 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___143 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___267 *i_fop;
		void (*free_inode)(struct inode___266 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___266 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___107 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___266;

struct path___266;

struct dentry_operations___266 {
	int (*d_revalidate)(struct dentry___266 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___266 *, unsigned int);
	int (*d_hash)(const struct dentry___266 *, struct qstr *);
	int (*d_compare)(const struct dentry___266 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___266 *);
	int (*d_init)(struct dentry___266 *);
	void (*d_release)(struct dentry___266 *);
	void (*d_prune)(struct dentry___266 *);
	void (*d_iput)(struct dentry___266 *, struct inode___266 *);
	char * (*d_dname)(struct dentry___266 *, char *, int);
	struct vfsmount___266 * (*d_automount)(struct path___266 *);
	int (*d_manage)(const struct path___266 *, bool);
	struct dentry___266 * (*d_real)(struct dentry___266 *, const struct inode___266 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___266;

struct mem_dqinfo___266 {
	struct quota_format_type___266 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___266;

struct quota_info___266 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___266 *files[3];
	struct mem_dqinfo___266 info[3];
	const struct quota_format_ops___266 *ops[3];
};

struct rcuwait___267 {
	struct task_struct___273 *task;
};

struct percpu_rw_semaphore___267 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___267 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___266 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___267 rw_sem[3];
};

struct shrink_control___131;

struct shrinker___131 {
	long unsigned int (*count_objects)(struct shrinker___131 *, struct shrink_control___131 *);
	long unsigned int (*scan_objects)(struct shrinker___131 *, struct shrink_control___131 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___266;

struct dquot_operations___266;

struct quotactl_ops___266;

struct block_device___160;

struct super_block___266 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___266 *s_type;
	const struct super_operations___266 *s_op;
	const struct dquot_operations___266 *dq_op;
	const struct quotactl_ops___266 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___266 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___160 *s_bdev;
	struct backing_dev_info___143 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___266 s_dquot;
	struct sb_writers___266 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___266 *s_d_op;
	int cleancache_poolid;
	struct shrinker___131 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___266 {
	struct dentry___266 *mnt_root;
	struct super_block___266 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___266 {
	struct vfsmount___266 *mnt;
	struct dentry___266 *dentry;
};

struct pid_namespace___243;

struct upid___243 {
	int nr;
	struct pid_namespace___243 *ns;
};

struct pid_namespace___243 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___273 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___243 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___243 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___243 numbers[1];
};

typedef struct page___271 *pgtable_t___271;

struct page_pool___95;

struct dev_pagemap___261;

struct page___271 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___266 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___95 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___271 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___271 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___272 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___261 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___261;

struct vm_area_struct___271 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___271 *vm_next;
	struct vm_area_struct___271 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___272 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___261 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___266 *vm_file;
	struct file___266 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___267 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___273 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___273 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___243 *pids[4];
	struct pid___243 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___272 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___271;

struct mm_struct___272 {
	struct {
		struct vm_area_struct___271 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___266 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___271 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___273 *owner;
		struct user_namespace___26 *user_ns;
		struct file___266 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___80;

struct cgroup_namespace___193;

struct nsproxy___252 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___243 *pid_ns_for_children;
	struct net___80 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___193 *cgroup_ns;
};

struct bio___157;

struct bio_list___157 {
	struct bio___157 *head;
	struct bio___157 *tail;
};

struct cgroup_subsys_state___193;

struct bdi_writeback___143 {
	struct backing_dev_info___143 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___193 *memcg_css;
	struct cgroup_subsys_state___193 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___247;

struct backing_dev_info___143 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___143 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___247 *dev;
	char dev_name[64];
	struct device___247 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___266 *debug_dir;
};

struct io_cq___157;

struct io_context___157 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___157 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___193;

struct css_set___193 {
	struct cgroup_subsys_state___193 *subsys[14];
	refcount_t refcount;
	struct css_set___193 *dom_cset;
	struct cgroup___193 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___193 *mg_src_cgrp;
	struct cgroup___193 *mg_dst_cgrp;
	struct css_set___193 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___266;

struct pipe_buffer___107;

struct pipe_inode_info___107 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___271 *tmp_page;
	struct fasync_struct___266 *fasync_readers;
	struct fasync_struct___266 *fasync_writers;
	struct pipe_buffer___107 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___193;

struct cgroup_subsys_state___193 {
	struct cgroup___193 *cgroup;
	struct cgroup_subsys___193 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___193 *parent;
};

struct cgroup_file___193 {
	struct kernfs_node___254 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___131;

struct mem_cgroup_per_node___131;

struct mem_cgroup___131 {
	struct cgroup_subsys_state___193 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___193 events_file;
	struct cgroup_file___193 events_local_file;
	struct cgroup_file___193 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___131 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___273 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___131 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___157;

struct blk_integrity___157 {
	const struct blk_integrity_profile___157 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___157 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___157 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___157;

struct elevator_queue___157;

struct blk_mq_ops___152;

struct blk_mq_hw_ctx___152;

struct gendisk___160;

struct blkcg_gq___145;

struct blk_mq_tag_set___152;

struct request_queue___157 {
	struct request___157 *last_merge;
	struct elevator_queue___157 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___152 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___152 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___160 *disk;
	struct kobject___254 kobj;
	struct kobject___254 *mq_kobj;
	struct blk_integrity___157 integrity;
	struct device___247 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___145 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___152 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___157 bio_split;
	struct dentry___266 *debugfs_dir;
	struct dentry___266 *sched_debugfs_dir;
	struct dentry___266 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___249 {
	struct vm_struct___249 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___271 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___131 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___131 *memcg;
};

struct page_pool_params___95 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___247 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___95 {
	u32 count;
	struct page___271 *cache[128];
};

struct page_pool___95 {
	struct page_pool_params___95 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___271 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___95 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___261;

struct dev_pagemap___261 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___261 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___243 {
	rwlock_t lock;
	struct pid___243 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___266 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___266 f_path;
	struct inode___266 *f_inode;
	const struct file_operations___267 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___243 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___266 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___261;

struct vm_operations_struct___261 {
	void (*open)(struct vm_area_struct___271 *);
	void (*close)(struct vm_area_struct___271 *);
	int (*may_split)(struct vm_area_struct___271 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___271 *);
	int (*mprotect)(struct vm_area_struct___271 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___261 *);
	vm_fault_t (*huge_fault)(struct vm_fault___261 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___261 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___271 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___261 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___261 *);
	int (*access)(struct vm_area_struct___271 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___271 *);
	int (*set_policy)(struct vm_area_struct___271 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___271 *, long unsigned int);
	struct page___271 * (*find_special_page)(struct vm_area_struct___271 *, long unsigned int);
};

struct core_thread___271 {
	struct task_struct___273 *task;
	struct core_thread___271 *next;
};

struct core_state___271 {
	atomic_t nr_threads;
	struct core_thread___271 dumper;
	struct completion startup;
};

struct vm_fault___261 {
	const struct {
		struct vm_area_struct___271 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___271 *cow_page;
	struct page___271 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___271 prealloc_pte;
};

struct pglist_data___139;

struct lruvec___139 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___139 *pgdat;
};

struct zone___139 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___139 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___139 {
	struct zone___139 *zone;
	int zone_idx;
};

struct zonelist___139 {
	struct zoneref___139 _zonerefs[321];
};

struct pglist_data___139 {
	struct zone___139 node_zones[5];
	struct zonelist___139 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___273 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___273 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___139 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___193 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___273 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___69;

struct cgroup_bpf___69 {
	struct bpf_prog_array___69 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___69 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___193;

struct cgroup_rstat_cpu___193;

struct cgroup___193 {
	struct cgroup_subsys_state___193 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___254 *kn;
	struct cgroup_file___193 procs_file;
	struct cgroup_file___193 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___193 *subsys[14];
	struct cgroup_root___193 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___193 *dom_cgrp;
	struct cgroup___193 *old_dom_cgrp;
	struct cgroup_rstat_cpu___193 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___193 psi;
	struct cgroup_bpf___69 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___157 {
	struct request_queue___157 *q;
	struct io_context___157 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___266 {
	struct file___266 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___266 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___266 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___266 *ia_file;
};

struct dquot___266 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___266 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___266 {
	int qf_fmt_id;
	const struct quota_format_ops___266 *qf_ops;
	struct module___250 *qf_owner;
	struct quota_format_type___266 *qf_next;
};

struct quota_format_ops___266 {
	int (*check_quota_file)(struct super_block___266 *, int);
	int (*read_file_info)(struct super_block___266 *, int);
	int (*write_file_info)(struct super_block___266 *, int);
	int (*free_file_info)(struct super_block___266 *, int);
	int (*read_dqblk)(struct dquot___266 *);
	int (*commit_dqblk)(struct dquot___266 *);
	int (*release_dqblk)(struct dquot___266 *);
	int (*get_next_id)(struct super_block___266 *, struct kqid *);
};

struct dquot_operations___266 {
	int (*write_dquot)(struct dquot___266 *);
	struct dquot___266 * (*alloc_dquot)(struct super_block___266 *, int);
	void (*destroy_dquot)(struct dquot___266 *);
	int (*acquire_dquot)(struct dquot___266 *);
	int (*release_dquot)(struct dquot___266 *);
	int (*mark_dirty)(struct dquot___266 *);
	int (*write_info)(struct super_block___266 *, int);
	qsize_t * (*get_reserved_space)(struct inode___266 *);
	int (*get_projid)(struct inode___266 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___266 *, qsize_t *);
	int (*get_next_id)(struct super_block___266 *, struct kqid *);
};

struct quotactl_ops___266 {
	int (*quota_on)(struct super_block___266 *, int, int, const struct path___266 *);
	int (*quota_off)(struct super_block___266 *, int);
	int (*quota_enable)(struct super_block___266 *, unsigned int);
	int (*quota_disable)(struct super_block___266 *, unsigned int);
	int (*quota_sync)(struct super_block___266 *, int);
	int (*set_info)(struct super_block___266 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___266 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___266 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___266 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___266 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___266 *, unsigned int);
};

struct writeback_control___143;

struct address_space_operations___266 {
	int (*writepage)(struct page___271 *, struct writeback_control___143 *);
	int (*readpage)(struct file___266 *, struct page___271 *);
	int (*writepages)(struct address_space___266 *, struct writeback_control___143 *);
	int (*set_page_dirty)(struct page___271 *);
	int (*readpages)(struct file___266 *, struct address_space___266 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___266 *, struct address_space___266 *, loff_t, unsigned int, unsigned int, struct page___271 **, void **);
	int (*write_end)(struct file___266 *, struct address_space___266 *, loff_t, unsigned int, unsigned int, struct page___271 *, void *);
	sector_t (*bmap)(struct address_space___266 *, sector_t);
	void (*invalidatepage)(struct page___271 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___271 *, gfp_t);
	void (*freepage)(struct page___271 *);
	ssize_t (*direct_IO)(struct kiocb___266 *, struct iov_iter___186 *);
	int (*migratepage)(struct address_space___266 *, struct page___271 *, struct page___271 *, enum migrate_mode);
	bool (*isolate_page)(struct page___271 *, isolate_mode_t);
	void (*putback_page)(struct page___271 *);
	int (*launder_page)(struct page___271 *);
	int (*is_partially_uptodate)(struct page___271 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___271 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___266 *, struct page___271 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___266 *, sector_t *);
	void (*swap_deactivate)(struct file___266 *);
};

struct writeback_control___143 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___143 *wb;
	struct inode___266 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___183;

struct iov_iter___186 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___183 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___107 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___266 {
	struct dentry___266 * (*lookup)(struct inode___266 *, struct dentry___266 *, unsigned int);
	const char * (*get_link)(struct dentry___266 *, struct inode___266 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___266 *, int);
	struct posix_acl * (*get_acl)(struct inode___266 *, int, bool);
	int (*readlink)(struct dentry___266 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___266 *, struct dentry___266 *, umode_t, bool);
	int (*link)(struct dentry___266 *, struct inode___266 *, struct dentry___266 *);
	int (*unlink)(struct inode___266 *, struct dentry___266 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___266 *, struct dentry___266 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___266 *, struct dentry___266 *, umode_t);
	int (*rmdir)(struct inode___266 *, struct dentry___266 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___266 *, struct dentry___266 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___266 *, struct dentry___266 *, struct inode___266 *, struct dentry___266 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___266 *, struct iattr___266 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___266 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___266 *, char *, size_t);
	int (*fiemap)(struct inode___266 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___266 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___266 *, struct dentry___266 *, struct file___266 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___266 *, struct dentry___266 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___266 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___266 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___266 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___266 {
	void (*fl_copy_lock)(struct file_lock___266 *, struct file_lock___266 *);
	void (*fl_release_private)(struct file_lock___266 *);
};

struct lock_manager_operations___266;

struct file_lock___266 {
	struct file_lock___266 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___266 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___266 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___266 *fl_ops;
	const struct lock_manager_operations___266 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___266 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___266 *);
	int (*lm_grant)(struct file_lock___266 *, int);
	bool (*lm_break)(struct file_lock___266 *);
	int (*lm_change)(struct file_lock___266 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___266 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___266 *);
};

struct fasync_struct___266 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___266 *fa_next;
	struct file___266 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___266 {
	struct inode___266 * (*alloc_inode)(struct super_block___266 *);
	void (*destroy_inode)(struct inode___266 *);
	void (*free_inode)(struct inode___266 *);
	void (*dirty_inode)(struct inode___266 *, int);
	int (*write_inode)(struct inode___266 *, struct writeback_control___143 *);
	int (*drop_inode)(struct inode___266 *);
	void (*evict_inode)(struct inode___266 *);
	void (*put_super)(struct super_block___266 *);
	int (*sync_fs)(struct super_block___266 *, int);
	int (*freeze_super)(struct super_block___266 *);
	int (*freeze_fs)(struct super_block___266 *);
	int (*thaw_super)(struct super_block___266 *);
	int (*unfreeze_fs)(struct super_block___266 *);
	int (*statfs)(struct dentry___266 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___266 *, int *, char *);
	void (*umount_begin)(struct super_block___266 *);
	int (*show_options)(struct seq_file___241 *, struct dentry___266 *);
	int (*show_devname)(struct seq_file___241 *, struct dentry___266 *);
	int (*show_path)(struct seq_file___241 *, struct dentry___266 *);
	int (*show_stats)(struct seq_file___241 *, struct dentry___266 *);
	ssize_t (*quota_read)(struct super_block___266 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___266 *, int, const char *, size_t, loff_t);
	struct dquot___266 ** (*get_dquots)(struct inode___266 *);
	long int (*nr_cached_objects)(struct super_block___266 *, struct shrink_control___131 *);
	long int (*free_cached_objects)(struct super_block___266 *, struct shrink_control___131 *);
	struct file___266 * (*real_loop)(struct file___266 *);
};

struct wakeup_source___247;

struct dev_pm_info___247 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___247 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___247 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___247;

struct bus_type___247;

struct device_driver___247;

struct dev_pm_domain___247;

struct fwnode_handle___243;

struct class___247;

struct attribute_group___254;

struct device___247 {
	struct kobject___254 kobj;
	struct device___247 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___247 *type;
	struct bus_type___247 *bus;
	struct device_driver___247 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___247 power;
	struct dev_pm_domain___247 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___243 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___247 *class;
	const struct attribute_group___254 **groups;
	void (*release)(struct device___247 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___160 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___266 *bd_inode;
	struct super_block___266 *bd_super;
	void *bd_claiming;
	struct device___247 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___254 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___160 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___266 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___195)(struct file___266 *, wait_queue_head_t *, struct poll_table_struct___187 *);

struct poll_table_struct___187 {
	poll_queue_proc___195 _qproc;
	__poll_t _key;
};

struct seq_operations___241;

struct seq_file___241 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___241 *op;
	int poll_event;
	const struct file___266 *file;
	void *private;
};

typedef void bio_end_io_t___157(struct bio___157 *);

struct bio_vec___183 {
	struct page___271 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___157;

struct bio___157 {
	struct bio___157 *bi_next;
	struct block_device___160 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___157 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___145 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___157 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___183 *bi_io_vec;
	struct bio_set___157 *bi_pool;
	struct bio_vec___183 bi_inline_vecs[0];
};

struct dev_pagemap_ops___261 {
	void (*page_free)(struct page___271 *);
	void (*kill)(struct dev_pagemap___261 *);
	void (*cleanup)(struct dev_pagemap___261 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___261 *);
};

struct fwnode_operations___243;

struct fwnode_handle___243 {
	struct fwnode_handle___243 *secondary;
	const struct fwnode_operations___243 *ops;
	struct device___247 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___243;

struct fwnode_endpoint___243;

struct fwnode_operations___243 {
	struct fwnode_handle___243 * (*get)(struct fwnode_handle___243 *);
	void (*put)(struct fwnode_handle___243 *);
	bool (*device_is_available)(const struct fwnode_handle___243 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___243 *, const struct device___247 *);
	bool (*property_present)(const struct fwnode_handle___243 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___243 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___243 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___243 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*get_parent)(const struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*get_next_child_node)(const struct fwnode_handle___243 *, struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*get_named_child_node)(const struct fwnode_handle___243 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___243 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___243 *);
	struct fwnode_handle___243 * (*graph_get_next_endpoint)(const struct fwnode_handle___243 *, struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*graph_get_remote_endpoint)(const struct fwnode_handle___243 *);
	struct fwnode_handle___243 * (*graph_get_port_parent)(struct fwnode_handle___243 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___243 *, struct fwnode_endpoint___243 *);
	int (*add_links)(struct fwnode_handle___243 *);
};

struct fwnode_endpoint___243 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___243 *local_fwnode;
};

struct fwnode_reference_args___243 {
	struct fwnode_handle___243 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___254;

struct kernfs_elem_dir___254 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___254 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___254;

struct kernfs_root___254 {
	struct kernfs_node___254 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___254 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___254 {
	struct kernfs_node___254 *target_kn;
};

struct kernfs_ops___254;

struct kernfs_elem_attr___254 {
	const struct kernfs_ops___254 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___254 *notify_next;
};

struct kernfs_node___254 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___254 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___254 dir;
		struct kernfs_elem_symlink___254 symlink;
		struct kernfs_elem_attr___254 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___254;

struct kernfs_ops___254 {
	int (*open)(struct kernfs_open_file___254 *);
	void (*release)(struct kernfs_open_file___254 *);
	int (*seq_show)(struct seq_file___241 *, void *);
	void * (*seq_start)(struct seq_file___241 *, loff_t *);
	void * (*seq_next)(struct seq_file___241 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___241 *, void *);
	ssize_t (*read)(struct kernfs_open_file___254 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___254 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___254 *, struct poll_table_struct___187 *);
	int (*mmap)(struct kernfs_open_file___254 *, struct vm_area_struct___271 *);
};

struct kernfs_syscall_ops___254 {
	int (*show_options)(struct seq_file___241 *, struct kernfs_root___254 *);
	int (*mkdir)(struct kernfs_node___254 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___254 *);
	int (*rename)(struct kernfs_node___254 *, struct kernfs_node___254 *, const char *);
	int (*show_path)(struct seq_file___241 *, struct kernfs_node___254 *, struct kernfs_root___254 *);
};

struct kernfs_open_file___254 {
	struct kernfs_node___254 *kn;
	struct file___266 *file;
	struct seq_file___241 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___261 *vm_ops;
};

struct sock___62;

struct kobj_ns_type_operations___62 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___62 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___80 *net;
} possible_net_t___75;

struct proto___62;

struct sock_common___62 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___62 *skc_prot;
	possible_net_t___75 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___62 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___76;

struct sk_buff_head___75 {
	struct sk_buff___76 *next;
	struct sk_buff___76 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___62 {
	struct cgroup___193 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___62;

struct socket_wq___63;

struct dst_entry___62;

struct socket___64;

struct net_device___75;

struct sock_reuseport___15;

struct sock___62 {
	struct sock_common___62 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___75 sk_error_queue;
	struct sk_buff___76 *sk_rx_skb_cache;
	struct sk_buff_head___75 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___76 *head;
		struct sk_buff___76 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___62 *sk_filter;
	union {
		struct socket_wq___63 *sk_wq;
		struct socket_wq___63 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___62 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___62 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___76 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___76 *sk_tx_skb_cache;
	struct sk_buff_head___75 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___271 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___62 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___243 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___64 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___62 sk_cgrp_data;
	struct mem_cgroup___131 *sk_memcg;
	void (*sk_state_change)(struct sock___62 *);
	void (*sk_data_ready)(struct sock___62 *);
	void (*sk_write_space)(struct sock___62 *);
	void (*sk_error_report)(struct sock___62 *);
	int (*sk_backlog_rcv)(struct sock___62 *, struct sk_buff___76 *);
	struct sk_buff___76 * (*sk_validate_xmit_skb)(struct sock___62 *, struct net_device___75 *, struct sk_buff___76 *);
	void (*sk_destruct)(struct sock___62 *);
	struct sock_reuseport___15 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___254;

struct attribute_group___254 {
	const char *name;
	umode_t (*is_visible)(struct kobject___254 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___254 *, struct bin_attribute___254 *, int);
	struct attribute **attrs;
	struct bin_attribute___254 **bin_attrs;
};

struct bin_attribute___254 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___266 * (*f_mapping)();
	ssize_t (*read)(struct file___266 *, struct kobject___254 *, struct bin_attribute___254 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___266 *, struct kobject___254 *, struct bin_attribute___254 *, char *, loff_t, size_t);
	int (*mmap)(struct file___266 *, struct kobject___254 *, struct bin_attribute___254 *, struct vm_area_struct___271 *);
};

struct sysfs_ops___254 {
	ssize_t (*show)(struct kobject___254 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___254 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___254;

struct kset___254 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___254 kobj;
	const struct kset_uevent_ops___254 *uevent_ops;
};

struct kobj_type___254 {
	void (*release)(struct kobject___254 *);
	const struct sysfs_ops___254 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___254 **default_groups;
	const struct kobj_ns_type_operations___62 * (*child_ns_type)(struct kobject___254 *);
	const void * (*namespace)(struct kobject___254 *);
	void (*get_ownership)(struct kobject___254 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___254 {
	int (* const filter)(struct kset___254 *, struct kobject___254 *);
	const char * (* const name)(struct kset___254 *, struct kobject___254 *);
	int (* const uevent)(struct kset___254 *, struct kobject___254 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___250 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___250 *);
	int (*get)(char *, const struct kernel_param___250 *);
	void (*free)(void *);
};

struct kparam_array___250;

struct kernel_param___250 {
	const char *name;
	struct module___250 *mod;
	const struct kernel_param_ops___250 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___250 *arr;
	};
};

struct kparam_array___250 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___250 *ops;
	void *elem;
};

struct module_attribute___250 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___250 *, struct module_kobject___251 *, char *);
	ssize_t (*store)(struct module_attribute___250 *, struct module_kobject___251 *, const char *, size_t);
	void (*setup)(struct module___250 *, const char *);
	int (*test)(struct module___250 *);
	void (*free)(struct module___250 *);
};

struct ip_ra_chain___35;

struct fib_rules_ops___62;

struct fqdir___80;

struct tcp_congestion_ops___14;

struct fib_notifier_ops___62;

struct netns_ipv4___80 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___35 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___62 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___62 *fibnl;
	struct sock___62 **icmp_sk;
	struct sock___62 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___62 **tcp_sk;
	struct fqdir___80 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___14 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___62 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___62 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___62 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___62;

struct dst_ops___80 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___80 *);
	struct dst_entry___62 * (*check)(struct dst_entry___62 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___62 *);
	unsigned int (*mtu)(const struct dst_entry___62 *);
	u32 * (*cow_metrics)(struct dst_entry___62 *, long unsigned int);
	void (*destroy)(struct dst_entry___62 *);
	void (*ifdown)(struct dst_entry___62 *, struct net_device___75 *, int);
	struct dst_entry___62 * (*negative_advice)(struct dst_entry___62 *);
	void (*link_failure)(struct sk_buff___76 *);
	void (*update_pmtu)(struct dst_entry___62 *, struct sock___62 *, struct sk_buff___76 *, u32, bool);
	void (*redirect)(struct dst_entry___62 *, struct sock___62 *, struct sk_buff___76 *);
	int (*local_out)(struct net___80 *, struct sock___62 *, struct sk_buff___76 *);
	struct neighbour___62 * (*neigh_lookup)(const struct dst_entry___62 *, struct sk_buff___76 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___62 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___80 {
	struct dst_ops___80 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___80 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___62 *fib6_rules_ops;
	struct sock___62 **icmp_sk;
	struct sock___62 *ndisc_sk;
	struct sock___62 *tcp_sk;
	struct sock___62 *igmp_sk;
	struct sock___62 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___62 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___62 *notifier_ops;
	struct fib_notifier_ops___62 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___80 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___80 *fqdir;
};

struct netns_sctp___62 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___62 *ctl_sock;
	struct sock___62 *udp4_sock;
	struct sock___62 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___7;

struct netns_nf___7 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___7 *hooks_ipv4[5];
	struct nf_hook_entries___7 *hooks_ipv6[5];
	struct nf_hook_entries___7 *hooks_arp[3];
	struct nf_hook_entries___7 *hooks_bridge[5];
	struct nf_hook_entries___7 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___69;

struct netns_bpf___69 {
	struct bpf_prog_array___69 *run_array[2];
	struct bpf_prog___69 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___80 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___62 *nlsk;
	struct sock___62 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___80 xfrm4_dst_ops;
	struct dst_ops___80 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___80 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___62 *rtnl;
	struct sock___62 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___75 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___80 ipv4;
	struct netns_ipv6___80 ipv6;
	struct netns_ieee802154_lowpan___80 ieee802154_lowpan;
	struct netns_sctp___62 sctp;
	struct netns_nf___7 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___75 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___69 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___80 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___62 *crypto_nlsk;
	struct sock___62 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___193 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___193 *root_cset;
};

struct msghdr___64 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___186 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___266 *msg_iocb;
};

struct socket_wq___63 {
	wait_queue_head_t wait;
	struct fasync_struct___266 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___63;

struct socket___64 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___266 *file;
	struct sock___62 *sk;
	const struct proto_ops___63 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___63 wq;
};

typedef int (*sk_read_actor_t___62)(read_descriptor_t *, struct sk_buff___76 *, unsigned int, size_t);

struct proto_ops___63 {
	int family;
	struct module___250 *owner;
	int (*release)(struct socket___64 *);
	int (*bind)(struct socket___64 *, struct sockaddr *, int);
	int (*connect)(struct socket___64 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___64 *, struct socket___64 *);
	int (*accept)(struct socket___64 *, struct socket___64 *, int, bool);
	int (*getname)(struct socket___64 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___266 *, struct socket___64 *, struct poll_table_struct___187 *);
	int (*ioctl)(struct socket___64 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___64 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___64 *, void *, bool, bool);
	int (*listen)(struct socket___64 *, int);
	int (*shutdown)(struct socket___64 *, int);
	int (*setsockopt)(struct socket___64 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___64 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___241 *, struct socket___64 *);
	int (*sendmsg)(struct socket___64 *, struct msghdr___64 *, size_t);
	int (*recvmsg)(struct socket___64 *, struct msghdr___64 *, size_t, int);
	int (*mmap)(struct file___266 *, struct socket___64 *, struct vm_area_struct___271 *);
	ssize_t (*sendpage)(struct socket___64 *, struct page___271 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___64 *, loff_t *, struct pipe_inode_info___107 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___62 *, int);
	int (*peek_len)(struct socket___64 *);
	int (*read_sock)(struct sock___62 *, read_descriptor_t *, sk_read_actor_t___62);
	int (*sendpage_locked)(struct sock___62 *, struct page___271 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___62 *, struct msghdr___64 *, size_t);
	int (*set_rcvlowat)(struct sock___62 *, int);
};

struct sk_buff___76 {
	union {
		struct {
			struct sk_buff___76 *next;
			struct sk_buff___76 *prev;
			union {
				struct net_device___75 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___62 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___76 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___247 {
	int (*prepare)(struct device___247 *);
	void (*complete)(struct device___247 *);
	int (*suspend)(struct device___247 *);
	int (*resume)(struct device___247 *);
	int (*freeze)(struct device___247 *);
	int (*thaw)(struct device___247 *);
	int (*poweroff)(struct device___247 *);
	int (*restore)(struct device___247 *);
	int (*suspend_late)(struct device___247 *);
	int (*resume_early)(struct device___247 *);
	int (*freeze_late)(struct device___247 *);
	int (*thaw_early)(struct device___247 *);
	int (*poweroff_late)(struct device___247 *);
	int (*restore_early)(struct device___247 *);
	int (*suspend_noirq)(struct device___247 *);
	int (*resume_noirq)(struct device___247 *);
	int (*freeze_noirq)(struct device___247 *);
	int (*thaw_noirq)(struct device___247 *);
	int (*poweroff_noirq)(struct device___247 *);
	int (*restore_noirq)(struct device___247 *);
	int (*runtime_suspend)(struct device___247 *);
	int (*runtime_resume)(struct device___247 *);
	int (*runtime_idle)(struct device___247 *);
};

struct wakeup_source___247 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___247 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___247 {
	struct dev_pm_ops___247 ops;
	int (*start)(struct device___247 *);
	void (*detach)(struct device___247 *, bool);
	int (*activate)(struct device___247 *);
	void (*sync)(struct device___247 *);
	void (*dismiss)(struct device___247 *);
};

struct bus_type___247 {
	const char *name;
	const char *dev_name;
	struct device___247 *dev_root;
	const struct attribute_group___254 **bus_groups;
	const struct attribute_group___254 **dev_groups;
	const struct attribute_group___254 **drv_groups;
	int (*match)(struct device___247 *, struct device_driver___247 *);
	int (*uevent)(struct device___247 *, struct kobj_uevent_env *);
	int (*probe)(struct device___247 *);
	void (*sync_state)(struct device___247 *);
	void (*remove)(struct device___247 *);
	void (*shutdown)(struct device___247 *);
	int (*online)(struct device___247 *);
	int (*offline)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	int (*num_vf)(struct device___247 *);
	int (*dma_configure)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___247 {
	const char *name;
	struct bus_type___247 *bus;
	struct module___250 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___247 *);
	void (*sync_state)(struct device___247 *);
	int (*remove)(struct device___247 *);
	void (*shutdown)(struct device___247 *);
	int (*suspend)(struct device___247 *, pm_message_t);
	int (*resume)(struct device___247 *);
	const struct attribute_group___254 **groups;
	const struct attribute_group___254 **dev_groups;
	const struct dev_pm_ops___247 *pm;
	void (*coredump)(struct device___247 *);
	struct driver_private *p;
};

struct device_type___247 {
	const char *name;
	const struct attribute_group___254 **groups;
	int (*uevent)(struct device___247 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___247 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___247 *);
	const struct dev_pm_ops___247 *pm;
};

struct class___247 {
	const char *name;
	struct module___250 *owner;
	const struct attribute_group___254 **class_groups;
	const struct attribute_group___254 **dev_groups;
	struct kobject___254 *dev_kobj;
	int (*dev_uevent)(struct device___247 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___247 *, umode_t *);
	void (*class_release)(struct class___247 *);
	void (*dev_release)(struct device___247 *);
	int (*shutdown_pre)(struct device___247 *);
	const struct kobj_ns_type_operations___62 *ns_type;
	const void * (*namespace)(struct device___247 *);
	void (*get_ownership)(struct device___247 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___247 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___107;

struct pipe_buffer___107 {
	struct page___271 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___107 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___107 {
	int (*confirm)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
	void (*release)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
	bool (*try_steal)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
	bool (*get)(struct pipe_inode_info___107 *, struct pipe_buffer___107 *);
};

typedef rx_handler_result_t rx_handler_func_t___75(struct sk_buff___76 **);

struct bpf_xdp_entity___69 {
	struct bpf_prog___69 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___75;

struct net_device_ops___75;

struct l3mdev_ops___62;

struct ndisc_ops___44;

struct xfrmdev_ops___75;

struct header_ops___75;

struct in_device___7;

struct inet6_dev___44;

struct netdev_rx_queue___75;

struct mini_Qdisc___69;

struct netdev_queue___75;

struct Qdisc___69;

struct rtnl_link_ops___69;

struct dcbnl_rtnl_ops___75;

struct net_device___75 {
	char name[16];
	struct netdev_name_node___75 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___75 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___62 *l3mdev_ops;
	const struct ndisc_ops___44 *ndisc_ops;
	const struct xfrmdev_ops___75 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___75 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___254 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___7 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___44 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___75 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___69 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___75 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___69 *miniq_ingress;
	struct netdev_queue___75 *ingress_queue;
	struct nf_hook_entries___7 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___75 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___69 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___69 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___75 = 0,
		NETREG_REGISTERED___75 = 1,
		NETREG_UNREGISTERING___75 = 2,
		NETREG_UNREGISTERED___75 = 3,
		NETREG_RELEASED___75 = 4,
		NETREG_DUMMY___75 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___75 = 0,
		RTNL_LINK_INITIALIZING___75 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___75 *);
	struct netpoll_info *npinfo;
	possible_net_t___75 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___247 dev;
	const struct attribute_group___254 *sysfs_groups[4];
	const struct attribute_group___254 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___69 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___75 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___69 xdp_state[3];
	long: 64;
};

struct inet_frags___80;

struct fqdir___80 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___80 *f;
	struct net___80 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___80;

struct inet_frags___80 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___80 *, const void *);
	void (*destructor)(struct inet_frag_queue___80 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___80 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___76 *fragments_tail;
	struct sk_buff___76 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___80 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___35 {
	struct ip_ra_chain___35 *next;
	struct sock___62 *sk;
	union {
		void (*destructor)(struct sock___62 *);
		struct sock___62 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___62;

struct fib_lookup_arg___62;

struct fib_rules_ops___62 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___62 *, struct flowi *, int, struct fib_lookup_arg___62 *);
	bool (*suppress)(struct fib_rule___62 *, int, struct fib_lookup_arg___62 *);
	int (*match)(struct fib_rule___62 *, struct flowi *, int);
	int (*configure)(struct fib_rule___62 *, struct sk_buff___76 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___62 *);
	int (*compare)(struct fib_rule___62 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___62 *, struct sk_buff___76 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___62 *);
	void (*flush_cache)(struct fib_rules_ops___62 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___250 *owner;
	struct net___80 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___14 {
	u32 (*ssthresh)(struct sock___62 *);
	void (*cong_avoid)(struct sock___62 *, u32, u32);
	void (*set_state)(struct sock___62 *, u8);
	void (*cwnd_event)(struct sock___62 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___62 *, u32);
	void (*pkts_acked)(struct sock___62 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___62 *);
	void (*cong_control)(struct sock___62 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___62 *);
	u32 (*sndbuf_expand)(struct sock___62 *);
	size_t (*get_info)(struct sock___62 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___250 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___62 *);
	void (*release)(struct sock___62 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___62 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___80 *);
	int (*fib_dump)(struct net___80 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___250 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___38;

struct dst_entry___62 {
	struct net_device___75 *dev;
	struct dst_ops___80 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___76 *);
	int (*output)(struct net___80 *, struct sock___62 *, struct sk_buff___76 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___38 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___62;

struct neigh_parms___62;

struct neigh_ops___62;

struct neighbour___62 {
	struct neighbour___62 *next;
	struct neigh_table___62 *tbl;
	struct neigh_parms___62 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___75 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___62 *, struct sk_buff___76 *);
	const struct neigh_ops___62 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___75 *dev;
	u8 primary_key[0];
};

struct nf_hook_state___7;

typedef unsigned int nf_hookfn___7(void *, struct sk_buff___76 *, const struct nf_hook_state___7 *);

struct nf_hook_entry___7 {
	nf_hookfn___7 *hook;
	void *priv;
};

struct nf_hook_entries___7 {
	u16 num_hook_entries;
	struct nf_hook_entry___7 hooks[0];
};

struct bpf_prog_array_item___69 {
	struct bpf_prog___69 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___69 {
	struct callback_head rcu;
	struct bpf_prog_array_item___69 items[0];
};

struct bpf_prog_aux___78;

struct bpf_prog___69 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___78 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___241 {
	void * (*start)(struct seq_file___241 *, loff_t *);
	void (*stop)(struct seq_file___241 *, void *);
	void * (*next)(struct seq_file___241 *, void *, loff_t *);
	int (*show)(struct seq_file___241 *, void *);
};

struct pernet_operations___20 {
	struct list_head list;
	int (*init)(struct net___80 *);
	void (*pre_exit)(struct net___80 *);
	void (*exit)(struct net___80 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___75 {
	int (*ieee_getets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___75 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___75 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___75 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___75 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___75 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___75 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___75 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___75 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___75 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___75 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___75 *);
	u8 (*setstate)(struct net_device___75 *, u8);
	void (*getpermhwaddr)(struct net_device___75 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___75 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___75 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___75 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___75 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___75 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___75 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___75 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___75 *, int, u8 *);
	void (*setpfccfg)(struct net_device___75 *, int, u8);
	void (*getpfccfg)(struct net_device___75 *, int, u8 *);
	u8 (*setall)(struct net_device___75 *);
	u8 (*getcap)(struct net_device___75 *, int, u8 *);
	int (*getnumtcs)(struct net_device___75 *, int, u8 *);
	int (*setnumtcs)(struct net_device___75 *, int, u8);
	u8 (*getpfcstate)(struct net_device___75 *);
	void (*setpfcstate)(struct net_device___75 *, u8);
	void (*getbcncfg)(struct net_device___75 *, int, u32 *);
	void (*setbcncfg)(struct net_device___75 *, int, u32);
	void (*getbcnrp)(struct net_device___75 *, int, u8 *);
	void (*setbcnrp)(struct net_device___75 *, int, u8);
	int (*setapp)(struct net_device___75 *, u8, u16, u8);
	int (*getapp)(struct net_device___75 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___75 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___75 *, int, u8);
	u8 (*getdcbx)(struct net_device___75 *);
	u8 (*setdcbx)(struct net_device___75 *, u8);
	int (*peer_getappinfo)(struct net_device___75 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___75 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___75 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___75 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___75 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___75 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___78;

typedef int (*bpf_iter_init_seq_priv_t___77)(void *, struct bpf_iter_aux_info___78 *);

struct bpf_map___78;

struct bpf_iter_aux_info___78 {
	struct bpf_map___78 *map;
};

struct bpf_iter_seq_info___77 {
	const struct seq_operations___241 *seq_ops;
	bpf_iter_init_seq_priv_t___77 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___77 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___78 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___78 *, struct file___266 *);
	void (*map_free)(struct bpf_map___78 *);
	int (*map_get_next_key)(struct bpf_map___78 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___78 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___78 *, void *);
	int (*map_lookup_batch)(struct bpf_map___78 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___78 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___78 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___78 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___78 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___78 *, void *);
	int (*map_update_elem)(struct bpf_map___78 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___78 *, void *);
	int (*map_push_elem)(struct bpf_map___78 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___78 *, void *);
	int (*map_peek_elem)(struct bpf_map___78 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___78 *, struct file___266 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___78 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___78 *, void *, struct seq_file___241 *);
	int (*map_check_btf)(const struct bpf_map___78 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___78 *, struct bpf_prog_aux___78 *);
	void (*map_poke_untrack)(struct bpf_map___78 *, struct bpf_prog_aux___78 *);
	void (*map_poke_run)(struct bpf_map___78 *, u32, struct bpf_prog___69 *, struct bpf_prog___69 *);
	int (*map_direct_value_addr)(const struct bpf_map___78 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___78 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___78 *, struct vm_area_struct___271 *);
	__poll_t (*map_poll)(struct bpf_map___78 *, struct file___266 *, struct poll_table_struct___187 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___78 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___78 *, const struct bpf_map___78 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___78 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___77 *iter_seq_info;
};

struct bpf_map___78 {
	const struct bpf_map_ops___77 *ops;
	struct bpf_map___78 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___131 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___77;

struct bpf_jit_poke_descriptor___77;

struct bpf_prog_ops___69;

struct btf_mod_pair___77;

struct bpf_prog_offload___75;

struct bpf_prog_aux___78 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___69 *dst_prog;
	struct bpf_trampoline___77 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___69 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___77 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___69 *ops;
	struct bpf_map___78 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___77 *used_btfs;
	struct bpf_prog___69 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___78 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___75 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___75;

struct bpf_map_dev_ops___75 {
	int (*map_get_next_key)(struct bpf_offloaded_map___75 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___75 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___75 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___75 *, void *);
};

struct bpf_offloaded_map___75 {
	struct bpf_map___78 map;
	struct net_device___75 *netdev;
	const struct bpf_map_dev_ops___75 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___69 {
	int (*test_run)(struct bpf_prog___69 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___75 {
	struct bpf_prog___69 *prog;
	struct net_device___75 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___77 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___69 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___250 *mod;
};

struct bpf_jit_poke_descriptor___77 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___78 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___77 {
	struct btf *btf;
	struct module___250 *module;
};

struct cftype___193;

struct cgroup_subsys___193 {
	struct cgroup_subsys_state___193 * (*css_alloc)(struct cgroup_subsys_state___193 *);
	int (*css_online)(struct cgroup_subsys_state___193 *);
	void (*css_offline)(struct cgroup_subsys_state___193 *);
	void (*css_released)(struct cgroup_subsys_state___193 *);
	void (*css_free)(struct cgroup_subsys_state___193 *);
	void (*css_reset)(struct cgroup_subsys_state___193 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___193 *, int);
	int (*css_extra_stat_show)(struct seq_file___241 *, struct cgroup_subsys_state___193 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___273 *, struct css_set___193 *);
	void (*cancel_fork)(struct task_struct___273 *, struct css_set___193 *);
	void (*fork)(struct task_struct___273 *);
	void (*exit)(struct task_struct___273 *);
	void (*release)(struct task_struct___273 *);
	void (*bind)(struct cgroup_subsys_state___193 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___193 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___193 *dfl_cftypes;
	struct cftype___193 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___193 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___193 *updated_children;
	struct cgroup___193 *updated_next;
};

struct cgroup_root___193 {
	struct kernfs_root___254 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___193 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___193 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___193 *ss;
	struct list_head node;
	struct kernfs_ops___254 *kf_ops;
	int (*open)(struct kernfs_open_file___254 *);
	void (*release)(struct kernfs_open_file___254 *);
	u64 (*read_u64)(struct cgroup_subsys_state___193 *, struct cftype___193 *);
	s64 (*read_s64)(struct cgroup_subsys_state___193 *, struct cftype___193 *);
	int (*seq_show)(struct seq_file___241 *, void *);
	void * (*seq_start)(struct seq_file___241 *, loff_t *);
	void * (*seq_next)(struct seq_file___241 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___241 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___193 *, struct cftype___193 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___193 *, struct cftype___193 *, s64);
	ssize_t (*write)(struct kernfs_open_file___254 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___254 *, struct poll_table_struct___187 *);
};

struct xdp_rxq_info___75 {
	struct net_device___75 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___75 {
	struct net_device___75 *dev;
};

struct xdp_buff___75 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___75 *rxq;
	struct xdp_txq_info___75 *txq;
	u32 frame_sz;
};

struct xdp_frame___75 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___75 *dev_rx;
};

struct netlink_callback___75 {
	struct sk_buff___76 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___76 *, struct netlink_callback___75 *);
	int (*done)(struct netlink_callback___75 *);
	void *data;
	struct module___250 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___75 {
	int (*create)(struct sk_buff___76 *, struct net_device___75 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___76 *, unsigned char *);
	int (*cache)(const struct neighbour___62 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___75 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___76 *);
};

struct netdev_queue___75 {
	struct net_device___75 *dev;
	struct Qdisc___69 *qdisc;
	struct Qdisc___69 *qdisc_sleeping;
	struct kobject___254 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___75 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___69 {
	struct sk_buff___76 *head;
	struct sk_buff___76 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___69;

struct Qdisc___69 {
	int (*enqueue)(struct sk_buff___76 *, struct Qdisc___69 *, struct sk_buff___76 **);
	struct sk_buff___76 * (*dequeue)(struct Qdisc___69 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___69 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___75 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___75 gso_skb;
	struct qdisc_skb_head___69 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___69 *next_sched;
	struct sk_buff_head___75 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___75 {
	struct xdp_rxq_info___75 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___254 kobj;
	struct net_device___75 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___75 {
	enum net_device_path_type type;
	const struct net_device___75 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___75 = 0,
				DEV_PATH_BR_VLAN_TAG___75 = 1,
				DEV_PATH_BR_VLAN_UNTAG___75 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___75 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___75 {
	const struct net_device___75 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___75 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___69 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___75 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___75 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___76 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___75 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___75 *dev;
	const char *name;
};

struct net_device_ops___75 {
	int (*ndo_init)(struct net_device___75 *);
	void (*ndo_uninit)(struct net_device___75 *);
	int (*ndo_open)(struct net_device___75 *);
	int (*ndo_stop)(struct net_device___75 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___76 *, struct net_device___75 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___76 *, struct net_device___75 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___75 *, struct sk_buff___76 *, struct net_device___75 *);
	void (*ndo_change_rx_flags)(struct net_device___75 *, int);
	void (*ndo_set_rx_mode)(struct net_device___75 *);
	int (*ndo_set_mac_address)(struct net_device___75 *, void *);
	int (*ndo_validate_addr)(struct net_device___75 *);
	int (*ndo_do_ioctl)(struct net_device___75 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___75 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___75 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___75 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___75 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___75 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___75 *, int);
	int (*ndo_neigh_setup)(struct net_device___75 *, struct neigh_parms___62 *);
	void (*ndo_tx_timeout)(struct net_device___75 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___75 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___75 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___75 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___75 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___75 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___75 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___75 *);
	int (*ndo_netpoll_setup)(struct net_device___75 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___75 *);
	int (*ndo_set_vf_mac)(struct net_device___75 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___75 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___75 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___75 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___75 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___75 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___75 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___75 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___75 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___75 *, int, struct sk_buff___76 *);
	int (*ndo_get_vf_guid)(struct net_device___75 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___75 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___75 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___75 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___75 *);
	int (*ndo_fcoe_disable)(struct net_device___75 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___75 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___75 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___75 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___75 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___75 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___75 *, const struct sk_buff___76 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___75 *, struct net_device___75 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___75 *, struct net_device___75 *);
	struct net_device___75 * (*ndo_get_xmit_slave)(struct net_device___75 *, struct sk_buff___76 *, bool);
	struct net_device___75 * (*ndo_sk_get_lower_dev)(struct net_device___75 *, struct sock___62 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___75 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___75 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___75 *, struct neighbour___62 *);
	void (*ndo_neigh_destroy)(struct net_device___75 *, struct neighbour___62 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___76 *, struct netlink_callback___75 *, struct net_device___75 *, struct net_device___75 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___76 *, struct nlattr **, struct net_device___75 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___75 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___76 *, u32, u32, struct net_device___75 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___75 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___75 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___75 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___75 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___75 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___75 *, struct net_device___75 *);
	void (*ndo_dfwd_del_station)(struct net_device___75 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___75 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___75 *);
	int (*ndo_change_proto_down)(struct net_device___75 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___75 *, struct sk_buff___76 *);
	void (*ndo_set_rx_headroom)(struct net_device___75 *, int);
	int (*ndo_bpf)(struct net_device___75 *, struct netdev_bpf___75 *);
	int (*ndo_xdp_xmit)(struct net_device___75 *, int, struct xdp_frame___75 **, u32);
	struct net_device___75 * (*ndo_xdp_get_xmit_slave)(struct net_device___75 *, struct xdp_buff___75 *);
	int (*ndo_xsk_wakeup)(struct net_device___75 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___75 *);
	int (*ndo_tunnel_ctl)(struct net_device___75 *, struct ip_tunnel_parm *, int);
	struct net_device___75 * (*ndo_get_peer_dev)(struct net_device___75 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___75 *, struct net_device_path___75 *);
};

struct neigh_parms___62 {
	possible_net_t___75 net;
	struct net_device___75 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___62 *);
	struct neigh_table___62 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___62 {
	u32 (*l3mdev_fib_table)(const struct net_device___75 *);
	struct sk_buff___76 * (*l3mdev_l3_rcv)(struct net_device___75 *, struct sk_buff___76 *, u16);
	struct sk_buff___76 * (*l3mdev_l3_out)(struct net_device___75 *, struct sock___62 *, struct sk_buff___76 *, u16);
	struct dst_entry___62 * (*l3mdev_link_scope_lookup)(const struct net_device___75 *, struct flowi6 *);
};

struct ndisc_ops___44 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___75 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___75 *, struct neighbour___62 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___75 *, u8, struct neighbour___62 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___75 *, struct sk_buff___76 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___80 *, struct net_device___75 *, const struct prefix_info *, struct inet6_dev___44 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___7;

struct in_device___7 {
	struct net_device___75 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___7 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___62 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___44;

struct inet6_dev___44 {
	struct net_device___75 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___44 *mc_list;
	struct ifmcaddr6___44 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___75 mc_query_queue;
	struct sk_buff_head___75 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___12 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___62 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___69;

struct tcf_block___69;

struct mini_Qdisc___69 {
	struct tcf_proto___69 *filter_list;
	struct tcf_block___69 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___69 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___75 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___75 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___80 *, struct net_device___75 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___75 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___75 *, struct list_head *);
	size_t (*get_size)(const struct net_device___75 *);
	int (*fill_info)(struct sk_buff___76 *, const struct net_device___75 *);
	size_t (*get_xstats_size)(const struct net_device___75 *);
	int (*fill_xstats)(struct sk_buff___76 *, const struct net_device___75 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___75 *, struct net_device___75 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___75 *, const struct net_device___75 *);
	int (*fill_slave_info)(struct sk_buff___76 *, const struct net_device___75 *, const struct net_device___75 *);
	struct net___80 * (*get_link_net)(const struct net_device___75 *);
	size_t (*get_linkxstats_size)(const struct net_device___75 *, int);
	int (*fill_linkxstats)(struct sk_buff___76 *, const struct net_device___75 *, int *, int);
};

struct nf_hook_state___7 {
	u8 hook;
	u8 pf;
	struct net_device___75 *in;
	struct net_device___75 *out;
	struct sock___62 *sk;
	struct net___80 *net;
	int (*okfn)(struct net___80 *, struct sock___62 *, struct sk_buff___76 *);
};

struct nf_hook_ops___4 {
	nf_hookfn___7 *hook;
	struct net_device___75 *dev;
	void *priv;
	u8 pf;
	enum nf_hook_ops_type hook_ops_type: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	unsigned int hooknum;
	int priority;
};

struct nf_hook_entries_rcu_head {
	struct callback_head head;
	void *allocation;
};

struct nf_conn___3;

enum nf_nat_manip_type;

struct nf_nat_hook {
	int (*parse_nat_setup)(struct nf_conn___3 *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___76 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___76 *, struct nf_conn___3 *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct nf_conntrack_tuple___2;

struct nf_ct_hook {
	int (*update)(struct net___80 *, struct sk_buff___76 *);
	void (*destroy)(struct nf_conntrack *);
	bool (*get_tuple_skb)(struct nf_conntrack_tuple___2 *, const struct sk_buff___76 *);
};

struct nfnl_ct_hook {
	size_t (*build_size)(const struct nf_conn___3 *);
	int (*build)(struct sk_buff___76 *, struct nf_conn___3 *, enum ip_conntrack_info, u_int16_t, u_int16_t);
	int (*parse)(const struct nlattr *, struct nf_conn___3 *);
	int (*attach_expect)(const struct nlattr *, struct nf_conn___3 *, u32, u32);
	void (*seq_adjust)(struct sk_buff___76 *, struct nf_conn___3 *, enum ip_conntrack_info, s32);
};

struct block_device_operations___157;

struct gendisk___160 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___160 *part0;
	const struct block_device_operations___157 *fops;
	struct request_queue___157 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___143 *bdi;
	struct kobject___254 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___254 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___157 {
	struct bio___157 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___183 *bip_vec;
	struct bio_vec___183 bip_inline_vecs[0];
};

struct blkcg___145;

struct blkg_policy_data___145;

struct blkcg_gq___145 {
	struct request_queue___157 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___145 *blkcg;
	struct blkcg_gq___145 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___145 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___157 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___157(struct request___157 *);

typedef void integrity_complete_fn___157(struct request___157 *, unsigned int);

struct blk_integrity_profile___157 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___157 *prepare_fn;
	integrity_complete_fn___157 *complete_fn;
	const char *name;
};

struct block_device_operations___157 {
	blk_qc_t (*submit_bio)(struct bio___157 *);
	int (*open)(struct block_device___160 *, fmode_t);
	void (*release)(struct gendisk___160 *, fmode_t);
	int (*rw_page)(struct block_device___160 *, sector_t, struct page___271 *, unsigned int);
	int (*ioctl)(struct block_device___160 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___160 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___160 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___160 *);
	int (*getgeo)(struct block_device___160 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___160 *, bool);
	void (*swap_slot_free_notify)(struct block_device___160 *, long unsigned int);
	int (*report_zones)(struct gendisk___160 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___160 *, umode_t *);
	struct module___250 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___160 *, sector_t *);
};

typedef void rq_end_io_fn___157(struct request___157 *, blk_status_t);

struct request___157 {
	struct request_queue___157 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___152 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___157 *bio;
	struct bio___157 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___183 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___157 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___157 *saved_end_io;
		} flush;
	};
	struct gendisk___160 *rq_disk;
	struct block_device___160 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___157 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___152 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___157 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___254 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___266 *debugfs_dir;
	struct dentry___266 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___157;

struct elevator_mq_ops___157 {
	int (*init_sched)(struct request_queue___157 *, struct elevator_type___157 *);
	void (*exit_sched)(struct elevator_queue___157 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___152 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___152 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___152 *);
	bool (*allow_merge)(struct request_queue___157 *, struct request___157 *, struct bio___157 *);
	bool (*bio_merge)(struct request_queue___157 *, struct bio___157 *, unsigned int);
	int (*request_merge)(struct request_queue___157 *, struct request___157 **, struct bio___157 *);
	void (*request_merged)(struct request_queue___157 *, struct request___157 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___157 *, struct request___157 *, struct request___157 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___157 *);
	void (*finish_request)(struct request___157 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___152 *, struct list_head *, bool);
	struct request___157 * (*dispatch_request)(struct blk_mq_hw_ctx___152 *);
	bool (*has_work)(struct blk_mq_hw_ctx___152 *);
	void (*completed_request)(struct request___157 *, u64);
	void (*requeue_request)(struct request___157 *);
	struct request___157 * (*former_request)(struct request_queue___157 *, struct request___157 *);
	struct request___157 * (*next_request)(struct request_queue___157 *, struct request___157 *);
	void (*init_icq)(struct io_cq___157 *);
	void (*exit_icq)(struct io_cq___157 *);
};

struct elv_fs_entry___157;

struct elevator_type___157 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___157 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___157 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___250 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___157 {
	struct elevator_type___157 *type;
	void *elevator_data;
	struct kobject___254 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___157 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___157 *, char *);
	ssize_t (*store)(struct elevator_queue___157 *, const char *, size_t);
};

struct blk_mq_queue_data___152;

struct blk_mq_ops___152 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___152 *, const struct blk_mq_queue_data___152 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___152 *);
	int (*get_budget)(struct request_queue___157 *);
	void (*put_budget)(struct request_queue___157 *, int);
	void (*set_rq_budget_token)(struct request___157 *, int);
	int (*get_rq_budget_token)(struct request___157 *);
	enum blk_eh_timer_return (*timeout)(struct request___157 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___152 *);
	void (*complete)(struct request___157 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___152 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___152 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___152 *, struct request___157 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___152 *, struct request___157 *, unsigned int);
	void (*initialize_rq_fn)(struct request___157 *);
	void (*cleanup_rq)(struct request___157 *);
	bool (*busy)(struct request_queue___157 *);
	int (*map_queues)(struct blk_mq_tag_set___152 *);
	void (*show_rq)(struct seq_file___241 *, struct request___157 *);
};

struct blk_mq_tag_set___152 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___152 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___152 {
	struct request___157 *rq;
	bool last;
};

struct blkcg_policy_data___145;

struct blkcg___145 {
	struct cgroup_subsys_state___193 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___145 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___145 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___145 {
	struct blkcg___145 *blkcg;
	int plid;
};

struct blkg_policy_data___145 {
	struct blkcg_gq___145 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___131 {
	struct mem_cgroup___131 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___131 {
	struct lruvec___139 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___131 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___131 *memcg;
};

struct obj_cgroup___131 {
	struct percpu_ref refcnt;
	struct mem_cgroup___131 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___69 {
	spinlock_t *lock;
	struct sk_buff___76 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___69;

struct Qdisc_ops___69 {
	struct Qdisc_ops___69 *next;
	const struct Qdisc_class_ops___69 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___76 *, struct Qdisc___69 *, struct sk_buff___76 **);
	struct sk_buff___76 * (*dequeue)(struct Qdisc___69 *);
	struct sk_buff___76 * (*peek)(struct Qdisc___69 *);
	int (*init)(struct Qdisc___69 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___69 *);
	void (*destroy)(struct Qdisc___69 *);
	int (*change)(struct Qdisc___69 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___69 *);
	int (*change_tx_queue_len)(struct Qdisc___69 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___69 *, unsigned int);
	int (*dump)(struct Qdisc___69 *, struct sk_buff___76 *);
	int (*dump_stats)(struct Qdisc___69 *, struct gnet_dump___69 *);
	void (*ingress_block_set)(struct Qdisc___69 *, u32);
	void (*egress_block_set)(struct Qdisc___69 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___69 *);
	u32 (*egress_block_get)(struct Qdisc___69 *);
	struct module___250 *owner;
};

struct Qdisc_class_ops___69 {
	unsigned int flags;
	struct netdev_queue___75 * (*select_queue)(struct Qdisc___69 *, struct tcmsg *);
	int (*graft)(struct Qdisc___69 *, long unsigned int, struct Qdisc___69 *, struct Qdisc___69 **, struct netlink_ext_ack *);
	struct Qdisc___69 * (*leaf)(struct Qdisc___69 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___69 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___69 *, u32);
	int (*change)(struct Qdisc___69 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___69 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___69 *, struct qdisc_walker *);
	struct tcf_block___69 * (*tcf_block)(struct Qdisc___69 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___69 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___69 *, long unsigned int);
	int (*dump)(struct Qdisc___69 *, long unsigned int, struct sk_buff___76 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___69 *, long unsigned int, struct gnet_dump___69 *);
};

struct tcf_chain___69;

struct tcf_block___69 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___80 *net;
	struct Qdisc___69 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___69 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___69;

struct tcf_proto_ops___69;

struct tcf_proto___69 {
	struct tcf_proto___69 *next;
	void *root;
	int (*classify)(struct sk_buff___76 *, const struct tcf_proto___69 *, struct tcf_result___69 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___69 *ops;
	struct tcf_chain___69 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___69 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___69 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___69 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___76 *, const struct tcf_proto___69 *, struct tcf_result___69 *);
	int (*init)(struct tcf_proto___69 *);
	void (*destroy)(struct tcf_proto___69 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___69 *, u32);
	void (*put)(struct tcf_proto___69 *, void *);
	int (*change)(struct net___80 *, struct sk_buff___76 *, struct tcf_proto___69 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___69 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___69 *);
	void (*walk)(struct tcf_proto___69 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___69 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___69 *, void *);
	void (*hw_del)(struct tcf_proto___69 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___80 *, struct tcf_chain___69 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___80 *, struct tcf_proto___69 *, void *, struct sk_buff___76 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___80 *, struct tcf_proto___69 *, void *, struct sk_buff___76 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___76 *, struct net___80 *, void *);
	struct module___250 *owner;
	int flags;
};

struct tcf_chain___69 {
	struct mutex filter_chain_lock;
	struct tcf_proto___69 *filter_chain;
	struct list_head list;
	struct tcf_block___69 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___69 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___62 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___69 *prog;
};

struct pneigh_entry___62;

struct neigh_hash_table___62;

struct neigh_table___62 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___75 *, __u32 *);
	bool (*key_eq)(const struct neighbour___62 *, const void *);
	int (*constructor)(struct neighbour___62 *);
	int (*pconstructor)(struct pneigh_entry___62 *);
	void (*pdestructor)(struct pneigh_entry___62 *);
	void (*proxy_redo)(struct sk_buff___76 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___75 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___62 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___75 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___62 *nht;
	struct pneigh_entry___62 **phash_buckets;
};

struct neigh_ops___62 {
	int family;
	void (*solicit)(struct neighbour___62 *, struct sk_buff___76 *);
	void (*error_report)(struct neighbour___62 *, struct sk_buff___76 *);
	int (*output)(struct neighbour___62 *, struct sk_buff___76 *);
	int (*connected_output)(struct neighbour___62 *, struct sk_buff___76 *);
};

struct pneigh_entry___62 {
	struct pneigh_entry___62 *next;
	possible_net_t___75 net;
	struct net_device___75 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___62 {
	struct neighbour___62 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___38 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___80 *, struct sock___62 *, struct sk_buff___76 *);
	int (*orig_input)(struct sk_buff___76 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___62 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___62 *ctarget;
	struct net___80 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___62 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___62 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___47;

struct timewait_sock_ops___46;

struct proto___62 {
	void (*close)(struct sock___62 *, long int);
	int (*pre_connect)(struct sock___62 *, struct sockaddr *, int);
	int (*connect)(struct sock___62 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___62 *, int);
	struct sock___62 * (*accept)(struct sock___62 *, int, int *, bool);
	int (*ioctl)(struct sock___62 *, int, long unsigned int);
	int (*init)(struct sock___62 *);
	void (*destroy)(struct sock___62 *);
	void (*shutdown)(struct sock___62 *, int);
	int (*setsockopt)(struct sock___62 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___62 *, int, int, char *, int *);
	void (*keepalive)(struct sock___62 *, int);
	int (*compat_ioctl)(struct sock___62 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___62 *, struct msghdr___64 *, size_t);
	int (*recvmsg)(struct sock___62 *, struct msghdr___64 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___62 *, struct page___271 *, int, size_t, int);
	int (*bind)(struct sock___62 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___62 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___62 *, struct sk_buff___76 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___62 *);
	int (*hash)(struct sock___62 *);
	void (*unhash)(struct sock___62 *);
	void (*rehash)(struct sock___62 *);
	int (*get_port)(struct sock___62 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___62 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___62 *, int);
	bool (*sock_is_readable)(struct sock___62 *);
	void (*enter_memory_pressure)(struct sock___62 *);
	void (*leave_memory_pressure)(struct sock___62 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___47 *rsk_prot;
	struct timewait_sock_ops___46 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___250 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___62 *, int);
};

struct sock_reuseport___15 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___69 *prog;
	struct sock___62 *socks[0];
};

struct request_sock___48;

struct request_sock_ops___47 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___62 *, struct request_sock___48 *);
	void (*send_ack)(const struct sock___62 *, struct sk_buff___76 *, struct request_sock___48 *);
	void (*send_reset)(const struct sock___62 *, struct sk_buff___76 *);
	void (*destructor)(struct request_sock___48 *);
	void (*syn_ack_timeout)(const struct request_sock___48 *);
};

struct timewait_sock_ops___46 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___62 *, struct sock___62 *, void *);
	void (*twsk_destructor)(struct sock___62 *);
};

struct request_sock___48 {
	struct sock_common___62 __req_common;
	struct request_sock___48 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___47 *rsk_ops;
	struct sock___62 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___44 {
	struct in6_addr mca_addr;
	struct inet6_dev___44 *idev;
	struct ifmcaddr6___44 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct nf_queue_entry;

struct nf_ipv6_ops {
	void (*route_input)(struct sk_buff___76 *);
	int (*fragment)(struct net___80 *, struct sock___62 *, struct sk_buff___76 *, int (*)(struct net___80 *, struct sock___62 *, struct sk_buff___76 *));
	int (*reroute)(struct sk_buff___76 *, const struct nf_queue_entry *);
};

struct nf_queue_entry {
	struct list_head list;
	struct sk_buff___76 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct net_device___75 *physin;
	struct net_device___75 *physout;
	struct nf_hook_state___7 state;
	u16 size;
};

struct in_ifaddr___7 {
	struct hlist_node hash;
	struct in_ifaddr___7 *ifa_next;
	struct in_device___7 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct seq_net_private___5 {
	struct net___3 *net;
};

struct nf_loginfo {
	u_int8_t type;
	union {
		struct {
			u_int32_t copy_len;
			u_int16_t group;
			u_int16_t qthreshold;
			u_int16_t flags;
		} ulog;
		struct {
			u_int8_t level;
			u_int8_t logflags;
		} log;
	} u;
};

struct nf_log_buf {
	unsigned int count;
	char buf[1020];
};

struct nf_bridge_info {
	enum {
		BRNF_PROTO_UNCHANGED = 0,
		BRNF_PROTO_8021Q = 1,
		BRNF_PROTO_PPPOE = 2,
	} orig_proto: 8;
	u8 pkt_otherhost: 1;
	u8 in_prerouting: 1;
	u8 bridged_dnat: 1;
	__u16 frag_max_size;
	struct net_device___75 *physindev;
	struct net_device___75 *physoutdev;
	union {
		__be32 ipv4_daddr;
		struct in6_addr ipv6_daddr;
		char neigh_header[8];
	};
};

struct ip_rt_info {
	__be32 daddr;
	__be32 saddr;
	u_int8_t tos;
	u_int32_t mark;
};

struct ip6_rt_info {
	struct in6_addr daddr;
	struct in6_addr saddr;
	u_int32_t mark;
};

struct nf_queue_handler {
	int (*outfn)(struct nf_queue_entry *, unsigned int);
	void (*nf_hook_drop)(struct net___80 *);
};

typedef unsigned int nf_hookfn___8(void *, struct sk_buff___61 *, const struct nf_hook_state *);

struct nf_sockopt_ops {
	struct list_head list;
	u_int8_t pf;
	int set_optmin;
	int set_optmax;
	int (*set)(struct sock___48 *, int, sockptr_t, unsigned int);
	int get_optmin;
	int get_optmax;
	int (*get)(struct sock___48 *, int, void *, int *);
	struct module___235 *owner;
};

struct nf_queue_entry___2;

struct nf_ipv6_ops___2 {
	void (*route_input)(struct sk_buff___2 *);
	int (*fragment)(struct net___3 *, struct sock___22 *, struct sk_buff___2 *, int (*)(struct net___3 *, struct sock___22 *, struct sk_buff___2 *));
	int (*reroute)(struct sk_buff___2 *, const struct nf_queue_entry___2 *);
};

struct nf_queue_entry___2 {
	struct list_head list;
	struct sk_buff___2 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct net_device___2 *physin;
	struct net_device___2 *physout;
	struct nf_hook_state___2 state;
	u16 size;
};

struct dentry___267;

struct super_block___267;

struct module___251;

struct file_system_type___267 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___267 * (*mount)(struct file_system_type___267 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___267 *);
	struct module___251 *owner;
	struct file_system_type___267 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___267;

struct kiocb___267;

struct iov_iter___187;

struct poll_table_struct___188;

struct vm_area_struct___272;

struct inode___267;

struct file_lock___267;

struct page___272;

struct pipe_inode_info___108;

struct seq_file___242;

struct file_operations___268 {
	struct module___251 *owner;
	loff_t (*llseek)(struct file___267 *, loff_t, int);
	ssize_t (*read)(struct file___267 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___267 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___267 *, struct iov_iter___187 *);
	ssize_t (*write_iter)(struct kiocb___267 *, struct iov_iter___187 *);
	int (*iopoll)(struct kiocb___267 *, bool);
	int (*iterate)(struct file___267 *, struct dir_context *);
	int (*iterate_shared)(struct file___267 *, struct dir_context *);
	__poll_t (*poll)(struct file___267 *, struct poll_table_struct___188 *);
	long int (*unlocked_ioctl)(struct file___267 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___267 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___267 *, struct vm_area_struct___272 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___267 *, struct file___267 *);
	int (*flush)(struct file___267 *, fl_owner_t);
	int (*release)(struct inode___267 *, struct file___267 *);
	int (*fsync)(struct file___267 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___267 *, int);
	int (*lock)(struct file___267 *, int, struct file_lock___267 *);
	ssize_t (*sendpage)(struct file___267 *, struct page___272 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___267 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___267 *, long unsigned int);
	int (*flock)(struct file___267 *, int, struct file_lock___267 *);
	ssize_t (*splice_write)(struct pipe_inode_info___108 *, struct file___267 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___267 *, loff_t *, struct pipe_inode_info___108 *, size_t, unsigned int);
	int (*setlease)(struct file___267 *, long int, struct file_lock___267 **, void **);
	long int (*fallocate)(struct file___267 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___242 *, struct file___267 *);
	ssize_t (*copy_file_range)(struct file___267 *, loff_t, struct file___267 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___267 *, loff_t, struct file___267 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___267 *, loff_t, loff_t, int);
};

struct vmacache___272 {
	u64 seqnum;
	struct vm_area_struct___272 *vmas[4];
};

struct page_frag___272 {
	struct page___272 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___273;

struct pid___244;

struct nsproxy___253;

struct signal_struct___268;

struct bio_list___158;

struct backing_dev_info___144;

struct io_context___158;

struct css_set___194;

struct mem_cgroup___132;

struct request_queue___158;

struct vm_struct___250;

struct task_struct___274 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___274 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___273 *mm;
	struct mm_struct___273 *active_mm;
	struct vmacache___272 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___274 *real_parent;
	struct task_struct___274 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___274 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___244 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___253 *nsproxy;
	struct signal_struct___268 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___274 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___158 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___144 *backing_dev_info;
	struct io_context___158 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___194 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___108 *splice_pipe;
	struct page_frag___272 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___132 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___132 *active_memcg;
	struct request_queue___158 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___274 *oom_reaper_list;
	struct vm_struct___250 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___255;

struct kobj_type___255;

struct kernfs_node___255;

struct kobject___255 {
	const char *name;
	struct list_head entry;
	struct kobject___255 *parent;
	struct kset___255 *kset;
	struct kobj_type___255 *ktype;
	struct kernfs_node___255 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___252 {
	struct kobject___255 kobj;
	struct module___251 *mod;
	struct kobject___255 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___251 {
	struct module___251 *mod;
	struct latch_tree_node node;
};

struct module_layout___251 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___251 mtn;
};

struct module_attribute___251;

struct kernel_param___251;

struct module___251 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___252 mkobj;
	struct module_attribute___251 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___255 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___251 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___251 core_layout;
	struct module_layout___251 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___244;

struct upid___244 {
	int nr;
	struct pid_namespace___244 *ns;
};

struct pid_namespace___244 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___274 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___244 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___244 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___244 numbers[1];
};

typedef struct page___272 *pgtable_t___272;

struct address_space___267;

struct page_pool___96;

struct dev_pagemap___262;

struct page___272 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___267 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___96 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___272 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___272 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___273 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___262 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___262;

struct vm_area_struct___272 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___272 *vm_next;
	struct vm_area_struct___272 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___273 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___262 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___267 *vm_file;
	struct file___267 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___268 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___274 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___274 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___244 *pids[4];
	struct pid___244 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___273 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___272;

struct mm_struct___273 {
	struct {
		struct vm_area_struct___272 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___267 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___272 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___274 *owner;
		struct user_namespace___26 *user_ns;
		struct file___267 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___81;

struct cgroup_namespace___194;

struct nsproxy___253 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___244 *pid_ns_for_children;
	struct net___81 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___194 *cgroup_ns;
};

struct bio___158;

struct bio_list___158 {
	struct bio___158 *head;
	struct bio___158 *tail;
};

struct cgroup_subsys_state___194;

struct bdi_writeback___144 {
	struct backing_dev_info___144 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___194 *memcg_css;
	struct cgroup_subsys_state___194 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___248;

struct backing_dev_info___144 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___144 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___248 *dev;
	char dev_name[64];
	struct device___248 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___267 *debug_dir;
};

struct io_cq___158;

struct io_context___158 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___158 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___194;

struct css_set___194 {
	struct cgroup_subsys_state___194 *subsys[14];
	refcount_t refcount;
	struct css_set___194 *dom_cset;
	struct cgroup___194 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___194 *mg_src_cgrp;
	struct cgroup___194 *mg_dst_cgrp;
	struct css_set___194 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___267;

struct pipe_buffer___108;

struct pipe_inode_info___108 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___272 *tmp_page;
	struct fasync_struct___267 *fasync_readers;
	struct fasync_struct___267 *fasync_writers;
	struct pipe_buffer___108 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___194;

struct cgroup_subsys_state___194 {
	struct cgroup___194 *cgroup;
	struct cgroup_subsys___194 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___194 *parent;
};

struct cgroup_file___194 {
	struct kernfs_node___255 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___132;

struct mem_cgroup_per_node___132;

struct mem_cgroup___132 {
	struct cgroup_subsys_state___194 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___194 events_file;
	struct cgroup_file___194 events_local_file;
	struct cgroup_file___194 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___132 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___274 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___132 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___158;

struct blk_integrity___158 {
	const struct blk_integrity_profile___158 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___158 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___158 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___158;

struct elevator_queue___158;

struct blk_mq_ops___153;

struct blk_mq_hw_ctx___153;

struct gendisk___161;

struct blkcg_gq___146;

struct blk_mq_tag_set___153;

struct request_queue___158 {
	struct request___158 *last_merge;
	struct elevator_queue___158 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___153 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___153 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___161 *disk;
	struct kobject___255 kobj;
	struct kobject___255 *mq_kobj;
	struct blk_integrity___158 integrity;
	struct device___248 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___146 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___153 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___158 bio_split;
	struct dentry___267 *debugfs_dir;
	struct dentry___267 *sched_debugfs_dir;
	struct dentry___267 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___250 {
	struct vm_struct___250 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___272 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___267;

struct address_space___267 {
	struct inode___267 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___267 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___96 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___248 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___96 {
	u32 count;
	struct page___272 *cache[128];
};

struct page_pool___96 {
	struct page_pool_params___96 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___272 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___96 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___262;

struct dev_pagemap___262 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___262 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___267;

struct path___267 {
	struct vfsmount___267 *mnt;
	struct dentry___267 *dentry;
};

struct fown_struct___244 {
	rwlock_t lock;
	struct pid___244 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___267 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___267 f_path;
	struct inode___267 *f_inode;
	const struct file_operations___268 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___244 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___267 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___262;

struct vm_operations_struct___262 {
	void (*open)(struct vm_area_struct___272 *);
	void (*close)(struct vm_area_struct___272 *);
	int (*may_split)(struct vm_area_struct___272 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___272 *);
	int (*mprotect)(struct vm_area_struct___272 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___262 *);
	vm_fault_t (*huge_fault)(struct vm_fault___262 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___262 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___272 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___262 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___262 *);
	int (*access)(struct vm_area_struct___272 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___272 *);
	int (*set_policy)(struct vm_area_struct___272 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___272 *, long unsigned int);
	struct page___272 * (*find_special_page)(struct vm_area_struct___272 *, long unsigned int);
};

struct core_thread___272 {
	struct task_struct___274 *task;
	struct core_thread___272 *next;
};

struct core_state___272 {
	atomic_t nr_threads;
	struct core_thread___272 dumper;
	struct completion startup;
};

struct vm_fault___262 {
	const struct {
		struct vm_area_struct___272 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___272 *cow_page;
	struct page___272 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___272 prealloc_pte;
};

struct pglist_data___140;

struct lruvec___140 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___140 *pgdat;
};

struct zone___140 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___140 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___140 {
	struct zone___140 *zone;
	int zone_idx;
};

struct zonelist___140 {
	struct zoneref___140 _zonerefs[321];
};

struct pglist_data___140 {
	struct zone___140 node_zones[5];
	struct zonelist___140 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___274 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___274 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___140 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___267;

struct dentry___267 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___267 *d_parent;
	struct qstr d_name;
	struct inode___267 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___267 *d_op;
	struct super_block___267 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___267;

struct inode___267 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___267 *i_op;
	struct super_block___267 *i_sb;
	struct address_space___267 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___144 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___268 *i_fop;
		void (*free_inode)(struct inode___267 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___267 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___108 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___267 {
	int (*d_revalidate)(struct dentry___267 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___267 *, unsigned int);
	int (*d_hash)(const struct dentry___267 *, struct qstr *);
	int (*d_compare)(const struct dentry___267 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___267 *);
	int (*d_init)(struct dentry___267 *);
	void (*d_release)(struct dentry___267 *);
	void (*d_prune)(struct dentry___267 *);
	void (*d_iput)(struct dentry___267 *, struct inode___267 *);
	char * (*d_dname)(struct dentry___267 *, char *, int);
	struct vfsmount___267 * (*d_automount)(struct path___267 *);
	int (*d_manage)(const struct path___267 *, bool);
	struct dentry___267 * (*d_real)(struct dentry___267 *, const struct inode___267 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___267;

struct mem_dqinfo___267 {
	struct quota_format_type___267 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___267;

struct quota_info___267 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___267 *files[3];
	struct mem_dqinfo___267 info[3];
	const struct quota_format_ops___267 *ops[3];
};

struct rcuwait___268 {
	struct task_struct___274 *task;
};

struct percpu_rw_semaphore___268 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___268 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___267 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___268 rw_sem[3];
};

struct shrink_control___132;

struct shrinker___132 {
	long unsigned int (*count_objects)(struct shrinker___132 *, struct shrink_control___132 *);
	long unsigned int (*scan_objects)(struct shrinker___132 *, struct shrink_control___132 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___267;

struct dquot_operations___267;

struct quotactl_ops___267;

struct block_device___161;

struct super_block___267 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___267 *s_type;
	const struct super_operations___267 *s_op;
	const struct dquot_operations___267 *dq_op;
	const struct quotactl_ops___267 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___267 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___161 *s_bdev;
	struct backing_dev_info___144 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___267 s_dquot;
	struct sb_writers___267 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___267 *s_d_op;
	int cleancache_poolid;
	struct shrinker___132 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___267 {
	struct dentry___267 *mnt_root;
	struct super_block___267 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___132 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___132 *memcg;
};

struct psi_group___194 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___274 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___70;

struct cgroup_bpf___70 {
	struct bpf_prog_array___70 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___70 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___194;

struct cgroup_rstat_cpu___194;

struct cgroup___194 {
	struct cgroup_subsys_state___194 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___255 *kn;
	struct cgroup_file___194 procs_file;
	struct cgroup_file___194 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___194 *subsys[14];
	struct cgroup_root___194 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___194 *dom_cgrp;
	struct cgroup___194 *old_dom_cgrp;
	struct cgroup_rstat_cpu___194 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___194 psi;
	struct cgroup_bpf___70 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___158 {
	struct request_queue___158 *q;
	struct io_context___158 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___267 {
	struct file___267 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___267 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___267 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___267 *ia_file;
};

struct dquot___267 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___267 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___267 {
	int qf_fmt_id;
	const struct quota_format_ops___267 *qf_ops;
	struct module___251 *qf_owner;
	struct quota_format_type___267 *qf_next;
};

struct quota_format_ops___267 {
	int (*check_quota_file)(struct super_block___267 *, int);
	int (*read_file_info)(struct super_block___267 *, int);
	int (*write_file_info)(struct super_block___267 *, int);
	int (*free_file_info)(struct super_block___267 *, int);
	int (*read_dqblk)(struct dquot___267 *);
	int (*commit_dqblk)(struct dquot___267 *);
	int (*release_dqblk)(struct dquot___267 *);
	int (*get_next_id)(struct super_block___267 *, struct kqid *);
};

struct dquot_operations___267 {
	int (*write_dquot)(struct dquot___267 *);
	struct dquot___267 * (*alloc_dquot)(struct super_block___267 *, int);
	void (*destroy_dquot)(struct dquot___267 *);
	int (*acquire_dquot)(struct dquot___267 *);
	int (*release_dquot)(struct dquot___267 *);
	int (*mark_dirty)(struct dquot___267 *);
	int (*write_info)(struct super_block___267 *, int);
	qsize_t * (*get_reserved_space)(struct inode___267 *);
	int (*get_projid)(struct inode___267 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___267 *, qsize_t *);
	int (*get_next_id)(struct super_block___267 *, struct kqid *);
};

struct quotactl_ops___267 {
	int (*quota_on)(struct super_block___267 *, int, int, const struct path___267 *);
	int (*quota_off)(struct super_block___267 *, int);
	int (*quota_enable)(struct super_block___267 *, unsigned int);
	int (*quota_disable)(struct super_block___267 *, unsigned int);
	int (*quota_sync)(struct super_block___267 *, int);
	int (*set_info)(struct super_block___267 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___267 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___267 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___267 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___267 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___267 *, unsigned int);
};

struct writeback_control___144;

struct address_space_operations___267 {
	int (*writepage)(struct page___272 *, struct writeback_control___144 *);
	int (*readpage)(struct file___267 *, struct page___272 *);
	int (*writepages)(struct address_space___267 *, struct writeback_control___144 *);
	int (*set_page_dirty)(struct page___272 *);
	int (*readpages)(struct file___267 *, struct address_space___267 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___267 *, struct address_space___267 *, loff_t, unsigned int, unsigned int, struct page___272 **, void **);
	int (*write_end)(struct file___267 *, struct address_space___267 *, loff_t, unsigned int, unsigned int, struct page___272 *, void *);
	sector_t (*bmap)(struct address_space___267 *, sector_t);
	void (*invalidatepage)(struct page___272 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___272 *, gfp_t);
	void (*freepage)(struct page___272 *);
	ssize_t (*direct_IO)(struct kiocb___267 *, struct iov_iter___187 *);
	int (*migratepage)(struct address_space___267 *, struct page___272 *, struct page___272 *, enum migrate_mode);
	bool (*isolate_page)(struct page___272 *, isolate_mode_t);
	void (*putback_page)(struct page___272 *);
	int (*launder_page)(struct page___272 *);
	int (*is_partially_uptodate)(struct page___272 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___272 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___267 *, struct page___272 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___267 *, sector_t *);
	void (*swap_deactivate)(struct file___267 *);
};

struct writeback_control___144 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___144 *wb;
	struct inode___267 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___184;

struct iov_iter___187 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___184 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___108 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___267 {
	struct dentry___267 * (*lookup)(struct inode___267 *, struct dentry___267 *, unsigned int);
	const char * (*get_link)(struct dentry___267 *, struct inode___267 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___267 *, int);
	struct posix_acl * (*get_acl)(struct inode___267 *, int, bool);
	int (*readlink)(struct dentry___267 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___267 *, struct dentry___267 *, umode_t, bool);
	int (*link)(struct dentry___267 *, struct inode___267 *, struct dentry___267 *);
	int (*unlink)(struct inode___267 *, struct dentry___267 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___267 *, struct dentry___267 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___267 *, struct dentry___267 *, umode_t);
	int (*rmdir)(struct inode___267 *, struct dentry___267 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___267 *, struct dentry___267 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___267 *, struct dentry___267 *, struct inode___267 *, struct dentry___267 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___267 *, struct iattr___267 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___267 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___267 *, char *, size_t);
	int (*fiemap)(struct inode___267 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___267 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___267 *, struct dentry___267 *, struct file___267 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___267 *, struct dentry___267 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___267 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___267 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___267 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___267 {
	void (*fl_copy_lock)(struct file_lock___267 *, struct file_lock___267 *);
	void (*fl_release_private)(struct file_lock___267 *);
};

struct lock_manager_operations___267;

struct file_lock___267 {
	struct file_lock___267 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___267 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___267 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___267 *fl_ops;
	const struct lock_manager_operations___267 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___267 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___267 *);
	int (*lm_grant)(struct file_lock___267 *, int);
	bool (*lm_break)(struct file_lock___267 *);
	int (*lm_change)(struct file_lock___267 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___267 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___267 *);
};

struct fasync_struct___267 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___267 *fa_next;
	struct file___267 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___267 {
	struct inode___267 * (*alloc_inode)(struct super_block___267 *);
	void (*destroy_inode)(struct inode___267 *);
	void (*free_inode)(struct inode___267 *);
	void (*dirty_inode)(struct inode___267 *, int);
	int (*write_inode)(struct inode___267 *, struct writeback_control___144 *);
	int (*drop_inode)(struct inode___267 *);
	void (*evict_inode)(struct inode___267 *);
	void (*put_super)(struct super_block___267 *);
	int (*sync_fs)(struct super_block___267 *, int);
	int (*freeze_super)(struct super_block___267 *);
	int (*freeze_fs)(struct super_block___267 *);
	int (*thaw_super)(struct super_block___267 *);
	int (*unfreeze_fs)(struct super_block___267 *);
	int (*statfs)(struct dentry___267 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___267 *, int *, char *);
	void (*umount_begin)(struct super_block___267 *);
	int (*show_options)(struct seq_file___242 *, struct dentry___267 *);
	int (*show_devname)(struct seq_file___242 *, struct dentry___267 *);
	int (*show_path)(struct seq_file___242 *, struct dentry___267 *);
	int (*show_stats)(struct seq_file___242 *, struct dentry___267 *);
	ssize_t (*quota_read)(struct super_block___267 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___267 *, int, const char *, size_t, loff_t);
	struct dquot___267 ** (*get_dquots)(struct inode___267 *);
	long int (*nr_cached_objects)(struct super_block___267 *, struct shrink_control___132 *);
	long int (*free_cached_objects)(struct super_block___267 *, struct shrink_control___132 *);
	struct file___267 * (*real_loop)(struct file___267 *);
};

struct wakeup_source___248;

struct dev_pm_info___248 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___248 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___248 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___248;

struct bus_type___248;

struct device_driver___248;

struct dev_pm_domain___248;

struct fwnode_handle___244;

struct class___248;

struct attribute_group___255;

struct device___248 {
	struct kobject___255 kobj;
	struct device___248 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___248 *type;
	struct bus_type___248 *bus;
	struct device_driver___248 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___248 power;
	struct dev_pm_domain___248 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___244 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___248 *class;
	const struct attribute_group___255 **groups;
	void (*release)(struct device___248 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___161 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___267 *bd_inode;
	struct super_block___267 *bd_super;
	void *bd_claiming;
	struct device___248 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___255 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___161 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___267 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___196)(struct file___267 *, wait_queue_head_t *, struct poll_table_struct___188 *);

struct poll_table_struct___188 {
	poll_queue_proc___196 _qproc;
	__poll_t _key;
};

struct seq_operations___242;

struct seq_file___242 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___242 *op;
	int poll_event;
	const struct file___267 *file;
	void *private;
};

typedef void bio_end_io_t___158(struct bio___158 *);

struct bio_vec___184 {
	struct page___272 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___158;

struct bio___158 {
	struct bio___158 *bi_next;
	struct block_device___161 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___158 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___146 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___158 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___184 *bi_io_vec;
	struct bio_set___158 *bi_pool;
	struct bio_vec___184 bi_inline_vecs[0];
};

struct kernfs_root___255;

struct kernfs_elem_dir___255 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___255 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___255;

struct kernfs_root___255 {
	struct kernfs_node___255 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___255 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___255 {
	struct kernfs_node___255 *target_kn;
};

struct kernfs_ops___255;

struct kernfs_elem_attr___255 {
	const struct kernfs_ops___255 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___255 *notify_next;
};

struct kernfs_node___255 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___255 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___255 dir;
		struct kernfs_elem_symlink___255 symlink;
		struct kernfs_elem_attr___255 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___255;

struct kernfs_ops___255 {
	int (*open)(struct kernfs_open_file___255 *);
	void (*release)(struct kernfs_open_file___255 *);
	int (*seq_show)(struct seq_file___242 *, void *);
	void * (*seq_start)(struct seq_file___242 *, loff_t *);
	void * (*seq_next)(struct seq_file___242 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___242 *, void *);
	ssize_t (*read)(struct kernfs_open_file___255 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___255 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___255 *, struct poll_table_struct___188 *);
	int (*mmap)(struct kernfs_open_file___255 *, struct vm_area_struct___272 *);
};

struct kernfs_syscall_ops___255 {
	int (*show_options)(struct seq_file___242 *, struct kernfs_root___255 *);
	int (*mkdir)(struct kernfs_node___255 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___255 *);
	int (*rename)(struct kernfs_node___255 *, struct kernfs_node___255 *, const char *);
	int (*show_path)(struct seq_file___242 *, struct kernfs_node___255 *, struct kernfs_root___255 *);
};

struct kernfs_open_file___255 {
	struct kernfs_node___255 *kn;
	struct file___267 *file;
	struct seq_file___242 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___262 *vm_ops;
};

struct sock___63;

struct kobj_ns_type_operations___63 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___63 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___81 *net;
} possible_net_t___76;

struct proto___63;

struct sock_common___63 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___63 *skc_prot;
	possible_net_t___76 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___63 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___77;

struct sk_buff_head___76 {
	struct sk_buff___77 *next;
	struct sk_buff___77 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___63 {
	struct cgroup___194 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___63;

struct socket_wq___64;

struct xfrm_policy___8;

struct dst_entry___63;

struct socket___65;

struct net_device___76;

struct sock_reuseport___16;

struct sock___63 {
	struct sock_common___63 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___76 sk_error_queue;
	struct sk_buff___77 *sk_rx_skb_cache;
	struct sk_buff_head___76 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___77 *head;
		struct sk_buff___77 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___63 *sk_filter;
	union {
		struct socket_wq___64 *sk_wq;
		struct socket_wq___64 *sk_wq_raw;
	};
	struct xfrm_policy___8 *sk_policy[2];
	struct dst_entry___63 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___63 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___77 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___77 *sk_tx_skb_cache;
	struct sk_buff_head___76 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___272 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___63 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___244 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___65 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___63 sk_cgrp_data;
	struct mem_cgroup___132 *sk_memcg;
	void (*sk_state_change)(struct sock___63 *);
	void (*sk_data_ready)(struct sock___63 *);
	void (*sk_write_space)(struct sock___63 *);
	void (*sk_error_report)(struct sock___63 *);
	int (*sk_backlog_rcv)(struct sock___63 *, struct sk_buff___77 *);
	struct sk_buff___77 * (*sk_validate_xmit_skb)(struct sock___63 *, struct net_device___76 *, struct sk_buff___77 *);
	void (*sk_destruct)(struct sock___63 *);
	struct sock_reuseport___16 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___255;

struct attribute_group___255 {
	const char *name;
	umode_t (*is_visible)(struct kobject___255 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___255 *, struct bin_attribute___255 *, int);
	struct attribute **attrs;
	struct bin_attribute___255 **bin_attrs;
};

struct bin_attribute___255 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___267 * (*f_mapping)();
	ssize_t (*read)(struct file___267 *, struct kobject___255 *, struct bin_attribute___255 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___267 *, struct kobject___255 *, struct bin_attribute___255 *, char *, loff_t, size_t);
	int (*mmap)(struct file___267 *, struct kobject___255 *, struct bin_attribute___255 *, struct vm_area_struct___272 *);
};

struct sysfs_ops___255 {
	ssize_t (*show)(struct kobject___255 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___255 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___255;

struct kset___255 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___255 kobj;
	const struct kset_uevent_ops___255 *uevent_ops;
};

struct kobj_type___255 {
	void (*release)(struct kobject___255 *);
	const struct sysfs_ops___255 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___255 **default_groups;
	const struct kobj_ns_type_operations___63 * (*child_ns_type)(struct kobject___255 *);
	const void * (*namespace)(struct kobject___255 *);
	void (*get_ownership)(struct kobject___255 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___255 {
	int (* const filter)(struct kset___255 *, struct kobject___255 *);
	const char * (* const name)(struct kset___255 *, struct kobject___255 *);
	int (* const uevent)(struct kset___255 *, struct kobject___255 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___251 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___251 *);
	int (*get)(char *, const struct kernel_param___251 *);
	void (*free)(void *);
};

struct kparam_array___251;

struct kernel_param___251 {
	const char *name;
	struct module___251 *mod;
	const struct kernel_param_ops___251 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___251 *arr;
	};
};

struct kparam_array___251 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___251 *ops;
	void *elem;
};

struct module_attribute___251 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___251 *, struct module_kobject___252 *, char *);
	ssize_t (*store)(struct module_attribute___251 *, struct module_kobject___252 *, const char *, size_t);
	void (*setup)(struct module___251 *, const char *);
	int (*test)(struct module___251 *);
	void (*free)(struct module___251 *);
};

struct dev_pagemap_ops___262 {
	void (*page_free)(struct page___272 *);
	void (*kill)(struct dev_pagemap___262 *);
	void (*cleanup)(struct dev_pagemap___262 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___262 *);
};

struct msghdr___65 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___187 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___267 *msg_iocb;
};

struct ip_mreqn {
	struct in_addr imr_multiaddr;
	struct in_addr imr_address;
	int imr_ifindex;
};

struct sk_buff___77 {
	union {
		struct {
			struct sk_buff___77 *next;
			struct sk_buff___77 *prev;
			union {
				struct net_device___76 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___63 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___77 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___81;

struct fqdir___81 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___81 *f;
	struct net___81 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___81;

struct inet_frags___81 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___81 *, const void *);
	void (*destructor)(struct inet_frag_queue___81 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___36;

struct fib_rules_ops___63;

struct tcp_congestion_ops___15;

struct fib_notifier_ops___63;

struct netns_ipv4___81 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___36 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___63 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___63 *fibnl;
	struct sock___63 **icmp_sk;
	struct sock___63 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___63 **tcp_sk;
	struct fqdir___81 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___15 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___63 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___63 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___63 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___63;

struct dst_ops___81 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___81 *);
	struct dst_entry___63 * (*check)(struct dst_entry___63 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___63 *);
	unsigned int (*mtu)(const struct dst_entry___63 *);
	u32 * (*cow_metrics)(struct dst_entry___63 *, long unsigned int);
	void (*destroy)(struct dst_entry___63 *);
	void (*ifdown)(struct dst_entry___63 *, struct net_device___76 *, int);
	struct dst_entry___63 * (*negative_advice)(struct dst_entry___63 *);
	void (*link_failure)(struct sk_buff___77 *);
	void (*update_pmtu)(struct dst_entry___63 *, struct sock___63 *, struct sk_buff___77 *, u32, bool);
	void (*redirect)(struct dst_entry___63 *, struct sock___63 *, struct sk_buff___77 *);
	int (*local_out)(struct net___81 *, struct sock___63 *, struct sk_buff___77 *);
	struct neighbour___63 * (*neigh_lookup)(const struct dst_entry___63 *, struct sk_buff___77 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___63 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___13;

struct rt6_info___13;

struct fib6_table___13;

struct netns_ipv6___81 {
	struct dst_ops___81 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___81 *fqdir;
	struct fib6_info___13 *fib6_null_entry;
	struct rt6_info___13 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___13 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___13 *ip6_prohibit_entry;
	struct rt6_info___13 *ip6_blk_hole_entry;
	struct fib6_table___13 *fib6_local_tbl;
	struct fib_rules_ops___63 *fib6_rules_ops;
	struct sock___63 **icmp_sk;
	struct sock___63 *ndisc_sk;
	struct sock___63 *tcp_sk;
	struct sock___63 *igmp_sk;
	struct sock___63 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___63 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___63 *notifier_ops;
	struct fib_notifier_ops___63 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___81 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___81 *fqdir;
};

struct netns_sctp___63 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___63 *ctl_sock;
	struct sock___63 *udp4_sock;
	struct sock___63 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___8;

struct netns_nf___8 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___8 *hooks_ipv4[5];
	struct nf_hook_entries___8 *hooks_ipv6[5];
	struct nf_hook_entries___8 *hooks_arp[3];
	struct nf_hook_entries___8 *hooks_bridge[5];
	struct nf_hook_entries___8 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___70;

struct netns_bpf___70 {
	struct bpf_prog_array___70 *run_array[2];
	struct bpf_prog___70 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___81 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___63 *nlsk;
	struct sock___63 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___81 xfrm4_dst_ops;
	struct dst_ops___81 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___81 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___63 *rtnl;
	struct sock___63 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___76 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___81 ipv4;
	struct netns_ipv6___81 ipv6;
	struct netns_ieee802154_lowpan___81 ieee802154_lowpan;
	struct netns_sctp___63 sctp;
	struct netns_nf___8 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___76 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___70 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___81 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___63 *crypto_nlsk;
	struct sock___63 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___81 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___77 *fragments_tail;
	struct sk_buff___77 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___81 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___36 {
	struct ip_ra_chain___36 *next;
	struct sock___63 *sk;
	union {
		void (*destructor)(struct sock___63 *);
		struct sock___63 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___63;

struct fib_lookup_arg___63;

struct fib_rules_ops___63 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___63 *, struct flowi *, int, struct fib_lookup_arg___63 *);
	bool (*suppress)(struct fib_rule___63 *, int, struct fib_lookup_arg___63 *);
	int (*match)(struct fib_rule___63 *, struct flowi *, int);
	int (*configure)(struct fib_rule___63 *, struct sk_buff___77 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___63 *);
	int (*compare)(struct fib_rule___63 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___63 *, struct sk_buff___77 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___63 *);
	void (*flush_cache)(struct fib_rules_ops___63 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___251 *owner;
	struct net___81 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___15 {
	u32 (*ssthresh)(struct sock___63 *);
	void (*cong_avoid)(struct sock___63 *, u32, u32);
	void (*set_state)(struct sock___63 *, u8);
	void (*cwnd_event)(struct sock___63 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___63 *, u32);
	void (*pkts_acked)(struct sock___63 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___63 *);
	void (*cong_control)(struct sock___63 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___63 *);
	u32 (*sndbuf_expand)(struct sock___63 *);
	size_t (*get_info)(struct sock___63 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___251 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___63 *);
	void (*release)(struct sock___63 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___63 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___81 *);
	int (*fib_dump)(struct net___81 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___251 *owner;
	struct callback_head rcu;
};

struct xfrm_state___8;

struct lwtunnel_state___39;

struct dst_entry___63 {
	struct net_device___76 *dev;
	struct dst_ops___81 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___8 *xfrm;
	int (*input)(struct sk_buff___77 *);
	int (*output)(struct net___81 *, struct sock___63 *, struct sk_buff___77 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___39 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___76(struct sk_buff___77 **);

struct bpf_xdp_entity___70 {
	struct bpf_prog___70 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___76;

struct net_device_ops___76;

struct l3mdev_ops___63;

struct ndisc_ops___45;

struct xfrmdev_ops___76;

struct header_ops___76;

struct in_device___8;

struct inet6_dev___45;

struct netdev_rx_queue___76;

struct mini_Qdisc___70;

struct netdev_queue___76;

struct Qdisc___70;

struct rtnl_link_ops___70;

struct dcbnl_rtnl_ops___76;

struct net_device___76 {
	char name[16];
	struct netdev_name_node___76 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___76 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___63 *l3mdev_ops;
	const struct ndisc_ops___45 *ndisc_ops;
	const struct xfrmdev_ops___76 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___76 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___255 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___8 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___45 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___76 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___70 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___76 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___70 *miniq_ingress;
	struct netdev_queue___76 *ingress_queue;
	struct nf_hook_entries___8 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___76 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___70 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___70 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___76 = 0,
		NETREG_REGISTERED___76 = 1,
		NETREG_UNREGISTERING___76 = 2,
		NETREG_UNREGISTERED___76 = 3,
		NETREG_RELEASED___76 = 4,
		NETREG_DUMMY___76 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___76 = 0,
		RTNL_LINK_INITIALIZING___76 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___76 *);
	struct netpoll_info *npinfo;
	possible_net_t___76 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___248 dev;
	const struct attribute_group___255 *sysfs_groups[4];
	const struct attribute_group___255 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___70 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___76 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___70 xdp_state[3];
	long: 64;
};

struct neigh_table___63;

struct neigh_parms___63;

struct neigh_ops___63;

struct neighbour___63 {
	struct neighbour___63 *next;
	struct neigh_table___63 *tbl;
	struct neigh_parms___63 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___76 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___63 *, struct sk_buff___77 *);
	const struct neigh_ops___63 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___76 *dev;
	u8 primary_key[0];
};

struct rtable___13;

struct fnhe_hash_bucket___13;

struct fib_nh_common___13 {
	struct net_device___76 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___39 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___13 **nhc_pcpu_rth_output;
	struct rtable___13 *nhc_rth_input;
	struct fnhe_hash_bucket___13 *nhc_exceptions;
};

struct fib6_nh___13 {
	struct fib_nh_common___13 nh_common;
	long unsigned int last_probe;
	struct rt6_info___13 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___13;

struct nexthop___8;

struct fib6_info___13 {
	struct fib6_table___13 *fib6_table;
	struct fib6_info___13 *fib6_next;
	struct fib6_node___13 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___8 *nh;
	struct fib6_nh___13 fib6_nh[0];
};

struct rt6_info___13 {
	struct dst_entry___63 dst;
	struct fib6_info___13 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___45 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___13 {
	struct fib6_node___13 *parent;
	struct fib6_node___13 *left;
	struct fib6_node___13 *right;
	struct fib6_node___13 *subtree;
	struct fib6_info___13 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___13 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___13 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___13 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___8;

typedef unsigned int nf_hookfn___9(void *, struct sk_buff___77 *, const struct nf_hook_state___8 *);

struct nf_hook_entry___8 {
	nf_hookfn___9 *hook;
	void *priv;
};

struct nf_hook_entries___8 {
	u16 num_hook_entries;
	struct nf_hook_entry___8 hooks[0];
};

struct bpf_prog_array_item___70 {
	struct bpf_prog___70 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___70 {
	struct callback_head rcu;
	struct bpf_prog_array_item___70 items[0];
};

struct bpf_prog_aux___79;

struct bpf_prog___70 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___79 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___244;

struct fwnode_handle___244 {
	struct fwnode_handle___244 *secondary;
	const struct fwnode_operations___244 *ops;
	struct device___248 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___244;

struct fwnode_endpoint___244;

struct fwnode_operations___244 {
	struct fwnode_handle___244 * (*get)(struct fwnode_handle___244 *);
	void (*put)(struct fwnode_handle___244 *);
	bool (*device_is_available)(const struct fwnode_handle___244 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___244 *, const struct device___248 *);
	bool (*property_present)(const struct fwnode_handle___244 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___244 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___244 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___244 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*get_parent)(const struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*get_next_child_node)(const struct fwnode_handle___244 *, struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*get_named_child_node)(const struct fwnode_handle___244 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___244 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___244 *);
	struct fwnode_handle___244 * (*graph_get_next_endpoint)(const struct fwnode_handle___244 *, struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*graph_get_remote_endpoint)(const struct fwnode_handle___244 *);
	struct fwnode_handle___244 * (*graph_get_port_parent)(struct fwnode_handle___244 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___244 *, struct fwnode_endpoint___244 *);
	int (*add_links)(struct fwnode_handle___244 *);
};

struct fwnode_endpoint___244 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___244 *local_fwnode;
};

struct fwnode_reference_args___244 {
	struct fwnode_handle___244 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___194 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___194 *root_cset;
};

struct socket_wq___64 {
	wait_queue_head_t wait;
	struct fasync_struct___267 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___64;

struct socket___65 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___267 *file;
	struct sock___63 *sk;
	const struct proto_ops___64 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___64 wq;
};

typedef int (*sk_read_actor_t___63)(read_descriptor_t *, struct sk_buff___77 *, unsigned int, size_t);

struct proto_ops___64 {
	int family;
	struct module___251 *owner;
	int (*release)(struct socket___65 *);
	int (*bind)(struct socket___65 *, struct sockaddr *, int);
	int (*connect)(struct socket___65 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___65 *, struct socket___65 *);
	int (*accept)(struct socket___65 *, struct socket___65 *, int, bool);
	int (*getname)(struct socket___65 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___267 *, struct socket___65 *, struct poll_table_struct___188 *);
	int (*ioctl)(struct socket___65 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___65 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___65 *, void *, bool, bool);
	int (*listen)(struct socket___65 *, int);
	int (*shutdown)(struct socket___65 *, int);
	int (*setsockopt)(struct socket___65 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___65 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___242 *, struct socket___65 *);
	int (*sendmsg)(struct socket___65 *, struct msghdr___65 *, size_t);
	int (*recvmsg)(struct socket___65 *, struct msghdr___65 *, size_t, int);
	int (*mmap)(struct file___267 *, struct socket___65 *, struct vm_area_struct___272 *);
	ssize_t (*sendpage)(struct socket___65 *, struct page___272 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___65 *, loff_t *, struct pipe_inode_info___108 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___63 *, int);
	int (*peek_len)(struct socket___65 *);
	int (*read_sock)(struct sock___63 *, read_descriptor_t *, sk_read_actor_t___63);
	int (*sendpage_locked)(struct sock___63 *, struct page___272 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___63 *, struct msghdr___65 *, size_t);
	int (*set_rcvlowat)(struct sock___63 *, int);
};

struct dev_pm_ops___248 {
	int (*prepare)(struct device___248 *);
	void (*complete)(struct device___248 *);
	int (*suspend)(struct device___248 *);
	int (*resume)(struct device___248 *);
	int (*freeze)(struct device___248 *);
	int (*thaw)(struct device___248 *);
	int (*poweroff)(struct device___248 *);
	int (*restore)(struct device___248 *);
	int (*suspend_late)(struct device___248 *);
	int (*resume_early)(struct device___248 *);
	int (*freeze_late)(struct device___248 *);
	int (*thaw_early)(struct device___248 *);
	int (*poweroff_late)(struct device___248 *);
	int (*restore_early)(struct device___248 *);
	int (*suspend_noirq)(struct device___248 *);
	int (*resume_noirq)(struct device___248 *);
	int (*freeze_noirq)(struct device___248 *);
	int (*thaw_noirq)(struct device___248 *);
	int (*poweroff_noirq)(struct device___248 *);
	int (*restore_noirq)(struct device___248 *);
	int (*runtime_suspend)(struct device___248 *);
	int (*runtime_resume)(struct device___248 *);
	int (*runtime_idle)(struct device___248 *);
};

struct wakeup_source___248 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___248 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___248 {
	struct dev_pm_ops___248 ops;
	int (*start)(struct device___248 *);
	void (*detach)(struct device___248 *, bool);
	int (*activate)(struct device___248 *);
	void (*sync)(struct device___248 *);
	void (*dismiss)(struct device___248 *);
};

struct bus_type___248 {
	const char *name;
	const char *dev_name;
	struct device___248 *dev_root;
	const struct attribute_group___255 **bus_groups;
	const struct attribute_group___255 **dev_groups;
	const struct attribute_group___255 **drv_groups;
	int (*match)(struct device___248 *, struct device_driver___248 *);
	int (*uevent)(struct device___248 *, struct kobj_uevent_env *);
	int (*probe)(struct device___248 *);
	void (*sync_state)(struct device___248 *);
	void (*remove)(struct device___248 *);
	void (*shutdown)(struct device___248 *);
	int (*online)(struct device___248 *);
	int (*offline)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	int (*num_vf)(struct device___248 *);
	int (*dma_configure)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___248 {
	const char *name;
	struct bus_type___248 *bus;
	struct module___251 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___248 *);
	void (*sync_state)(struct device___248 *);
	int (*remove)(struct device___248 *);
	void (*shutdown)(struct device___248 *);
	int (*suspend)(struct device___248 *, pm_message_t);
	int (*resume)(struct device___248 *);
	const struct attribute_group___255 **groups;
	const struct attribute_group___255 **dev_groups;
	const struct dev_pm_ops___248 *pm;
	void (*coredump)(struct device___248 *);
	struct driver_private *p;
};

struct device_type___248 {
	const char *name;
	const struct attribute_group___255 **groups;
	int (*uevent)(struct device___248 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___248 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___248 *);
	const struct dev_pm_ops___248 *pm;
};

struct class___248 {
	const char *name;
	struct module___251 *owner;
	const struct attribute_group___255 **class_groups;
	const struct attribute_group___255 **dev_groups;
	struct kobject___255 *dev_kobj;
	int (*dev_uevent)(struct device___248 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___248 *, umode_t *);
	void (*class_release)(struct class___248 *);
	void (*dev_release)(struct device___248 *);
	int (*shutdown_pre)(struct device___248 *);
	const struct kobj_ns_type_operations___63 *ns_type;
	const void * (*namespace)(struct device___248 *);
	void (*get_ownership)(struct device___248 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___248 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___108;

struct pipe_buffer___108 {
	struct page___272 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___108 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___108 {
	int (*confirm)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
	void (*release)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
	bool (*try_steal)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
	bool (*get)(struct pipe_inode_info___108 *, struct pipe_buffer___108 *);
};

struct seq_operations___242 {
	void * (*start)(struct seq_file___242 *, loff_t *);
	void (*stop)(struct seq_file___242 *, void *);
	void * (*next)(struct seq_file___242 *, void *, loff_t *);
	int (*show)(struct seq_file___242 *, void *);
};

struct pernet_operations___21 {
	struct list_head list;
	int (*init)(struct net___81 *);
	void (*pre_exit)(struct net___81 *);
	void (*exit)(struct net___81 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___76 {
	int (*ieee_getets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___76 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___76 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___76 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___76 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___76 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___76 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___76 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___76 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___76 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___76 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___76 *);
	u8 (*setstate)(struct net_device___76 *, u8);
	void (*getpermhwaddr)(struct net_device___76 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___76 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___76 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___76 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___76 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___76 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___76 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___76 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___76 *, int, u8 *);
	void (*setpfccfg)(struct net_device___76 *, int, u8);
	void (*getpfccfg)(struct net_device___76 *, int, u8 *);
	u8 (*setall)(struct net_device___76 *);
	u8 (*getcap)(struct net_device___76 *, int, u8 *);
	int (*getnumtcs)(struct net_device___76 *, int, u8 *);
	int (*setnumtcs)(struct net_device___76 *, int, u8);
	u8 (*getpfcstate)(struct net_device___76 *);
	void (*setpfcstate)(struct net_device___76 *, u8);
	void (*getbcncfg)(struct net_device___76 *, int, u32 *);
	void (*setbcncfg)(struct net_device___76 *, int, u32);
	void (*getbcnrp)(struct net_device___76 *, int, u8 *);
	void (*setbcnrp)(struct net_device___76 *, int, u8);
	int (*setapp)(struct net_device___76 *, u8, u16, u8);
	int (*getapp)(struct net_device___76 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___76 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___76 *, int, u8);
	u8 (*getdcbx)(struct net_device___76 *);
	u8 (*setdcbx)(struct net_device___76 *, u8);
	int (*peer_getappinfo)(struct net_device___76 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___76 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___76 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___76 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___76 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___76 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___79;

typedef int (*bpf_iter_init_seq_priv_t___78)(void *, struct bpf_iter_aux_info___79 *);

struct bpf_map___79;

struct bpf_iter_aux_info___79 {
	struct bpf_map___79 *map;
};

struct bpf_iter_seq_info___78 {
	const struct seq_operations___242 *seq_ops;
	bpf_iter_init_seq_priv_t___78 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___78 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___79 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___79 *, struct file___267 *);
	void (*map_free)(struct bpf_map___79 *);
	int (*map_get_next_key)(struct bpf_map___79 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___79 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___79 *, void *);
	int (*map_lookup_batch)(struct bpf_map___79 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___79 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___79 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___79 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___79 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___79 *, void *);
	int (*map_update_elem)(struct bpf_map___79 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___79 *, void *);
	int (*map_push_elem)(struct bpf_map___79 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___79 *, void *);
	int (*map_peek_elem)(struct bpf_map___79 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___79 *, struct file___267 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___79 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___79 *, void *, struct seq_file___242 *);
	int (*map_check_btf)(const struct bpf_map___79 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___79 *, struct bpf_prog_aux___79 *);
	void (*map_poke_untrack)(struct bpf_map___79 *, struct bpf_prog_aux___79 *);
	void (*map_poke_run)(struct bpf_map___79 *, u32, struct bpf_prog___70 *, struct bpf_prog___70 *);
	int (*map_direct_value_addr)(const struct bpf_map___79 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___79 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___79 *, struct vm_area_struct___272 *);
	__poll_t (*map_poll)(struct bpf_map___79 *, struct file___267 *, struct poll_table_struct___188 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___79 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___79 *, const struct bpf_map___79 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___79 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___78 *iter_seq_info;
};

struct bpf_map___79 {
	const struct bpf_map_ops___78 *ops;
	struct bpf_map___79 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___132 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___78;

struct bpf_jit_poke_descriptor___78;

struct bpf_prog_ops___70;

struct btf_mod_pair___78;

struct bpf_prog_offload___76;

struct bpf_prog_aux___79 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___70 *dst_prog;
	struct bpf_trampoline___78 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___70 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___78 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___70 *ops;
	struct bpf_map___79 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___78 *used_btfs;
	struct bpf_prog___70 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___79 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___76 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___76;

struct bpf_map_dev_ops___76 {
	int (*map_get_next_key)(struct bpf_offloaded_map___76 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___76 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___76 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___76 *, void *);
};

struct bpf_offloaded_map___76 {
	struct bpf_map___79 map;
	struct net_device___76 *netdev;
	const struct bpf_map_dev_ops___76 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___70 {
	int (*test_run)(struct bpf_prog___70 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___76 {
	struct bpf_prog___70 *prog;
	struct net_device___76 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___78 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___70 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___251 *mod;
};

struct bpf_jit_poke_descriptor___78 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___79 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___78 {
	struct btf *btf;
	struct module___251 *module;
};

struct cftype___194;

struct cgroup_subsys___194 {
	struct cgroup_subsys_state___194 * (*css_alloc)(struct cgroup_subsys_state___194 *);
	int (*css_online)(struct cgroup_subsys_state___194 *);
	void (*css_offline)(struct cgroup_subsys_state___194 *);
	void (*css_released)(struct cgroup_subsys_state___194 *);
	void (*css_free)(struct cgroup_subsys_state___194 *);
	void (*css_reset)(struct cgroup_subsys_state___194 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___194 *, int);
	int (*css_extra_stat_show)(struct seq_file___242 *, struct cgroup_subsys_state___194 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___274 *, struct css_set___194 *);
	void (*cancel_fork)(struct task_struct___274 *, struct css_set___194 *);
	void (*fork)(struct task_struct___274 *);
	void (*exit)(struct task_struct___274 *);
	void (*release)(struct task_struct___274 *);
	void (*bind)(struct cgroup_subsys_state___194 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___194 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___194 *dfl_cftypes;
	struct cftype___194 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___194 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___194 *updated_children;
	struct cgroup___194 *updated_next;
};

struct cgroup_root___194 {
	struct kernfs_root___255 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___194 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___194 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___194 *ss;
	struct list_head node;
	struct kernfs_ops___255 *kf_ops;
	int (*open)(struct kernfs_open_file___255 *);
	void (*release)(struct kernfs_open_file___255 *);
	u64 (*read_u64)(struct cgroup_subsys_state___194 *, struct cftype___194 *);
	s64 (*read_s64)(struct cgroup_subsys_state___194 *, struct cftype___194 *);
	int (*seq_show)(struct seq_file___242 *, void *);
	void * (*seq_start)(struct seq_file___242 *, loff_t *);
	void * (*seq_next)(struct seq_file___242 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___242 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___194 *, struct cftype___194 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___194 *, struct cftype___194 *, s64);
	ssize_t (*write)(struct kernfs_open_file___255 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___255 *, struct poll_table_struct___188 *);
};

struct xdp_rxq_info___76 {
	struct net_device___76 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___76 {
	struct net_device___76 *dev;
};

struct xdp_buff___76 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___76 *rxq;
	struct xdp_txq_info___76 *txq;
	u32 frame_sz;
};

struct xdp_frame___76 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___76 *dev_rx;
};

struct netlink_skb_parms___15 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___63 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___76 {
	struct sk_buff___77 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___77 *, struct netlink_callback___76 *);
	int (*done)(struct netlink_callback___76 *);
	void *data;
	struct module___251 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___76 {
	int (*create)(struct sk_buff___77 *, struct net_device___76 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___77 *, unsigned char *);
	int (*cache)(const struct neighbour___63 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___76 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___77 *);
};

struct netdev_queue___76 {
	struct net_device___76 *dev;
	struct Qdisc___70 *qdisc;
	struct Qdisc___70 *qdisc_sleeping;
	struct kobject___255 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___76 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___70 {
	struct sk_buff___77 *head;
	struct sk_buff___77 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___70;

struct Qdisc___70 {
	int (*enqueue)(struct sk_buff___77 *, struct Qdisc___70 *, struct sk_buff___77 **);
	struct sk_buff___77 * (*dequeue)(struct Qdisc___70 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___70 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___76 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___76 gso_skb;
	struct qdisc_skb_head___70 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___70 *next_sched;
	struct sk_buff_head___76 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___76 {
	struct xdp_rxq_info___76 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___255 kobj;
	struct net_device___76 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___76 {
	enum net_device_path_type type;
	const struct net_device___76 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___76 = 0,
				DEV_PATH_BR_VLAN_TAG___76 = 1,
				DEV_PATH_BR_VLAN_UNTAG___76 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___76 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___76 {
	const struct net_device___76 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___76 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___70 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___76 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___76 {
	int (*xdo_dev_state_add)(struct xfrm_state___8 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___8 *);
	void (*xdo_dev_state_free)(struct xfrm_state___8 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___77 *, struct xfrm_state___8 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___8 *);
};

struct xfrm_state_offload___8 {
	struct net_device___76 *dev;
	struct net_device___76 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___8;

struct xfrm_type_offload___8;

struct xfrm_state___8 {
	possible_net_t___76 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___63 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___8 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___8 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___272 xfrag;
	const struct xfrm_type___8 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___8 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___76 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___76 *dev;
	const char *name;
};

struct net_device_ops___76 {
	int (*ndo_init)(struct net_device___76 *);
	void (*ndo_uninit)(struct net_device___76 *);
	int (*ndo_open)(struct net_device___76 *);
	int (*ndo_stop)(struct net_device___76 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___77 *, struct net_device___76 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___77 *, struct net_device___76 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___76 *, struct sk_buff___77 *, struct net_device___76 *);
	void (*ndo_change_rx_flags)(struct net_device___76 *, int);
	void (*ndo_set_rx_mode)(struct net_device___76 *);
	int (*ndo_set_mac_address)(struct net_device___76 *, void *);
	int (*ndo_validate_addr)(struct net_device___76 *);
	int (*ndo_do_ioctl)(struct net_device___76 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___76 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___76 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___76 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___76 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___76 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___76 *, int);
	int (*ndo_neigh_setup)(struct net_device___76 *, struct neigh_parms___63 *);
	void (*ndo_tx_timeout)(struct net_device___76 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___76 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___76 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___76 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___76 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___76 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___76 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___76 *);
	int (*ndo_netpoll_setup)(struct net_device___76 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___76 *);
	int (*ndo_set_vf_mac)(struct net_device___76 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___76 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___76 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___76 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___76 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___76 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___76 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___76 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___76 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___76 *, int, struct sk_buff___77 *);
	int (*ndo_get_vf_guid)(struct net_device___76 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___76 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___76 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___76 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___76 *);
	int (*ndo_fcoe_disable)(struct net_device___76 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___76 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___76 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___76 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___76 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___76 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___76 *, const struct sk_buff___77 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___76 *, struct net_device___76 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___76 *, struct net_device___76 *);
	struct net_device___76 * (*ndo_get_xmit_slave)(struct net_device___76 *, struct sk_buff___77 *, bool);
	struct net_device___76 * (*ndo_sk_get_lower_dev)(struct net_device___76 *, struct sock___63 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___76 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___76 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___76 *, struct neighbour___63 *);
	void (*ndo_neigh_destroy)(struct net_device___76 *, struct neighbour___63 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___77 *, struct netlink_callback___76 *, struct net_device___76 *, struct net_device___76 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___77 *, struct nlattr **, struct net_device___76 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___76 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___77 *, u32, u32, struct net_device___76 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___76 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___76 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___76 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___76 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___76 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___76 *, struct net_device___76 *);
	void (*ndo_dfwd_del_station)(struct net_device___76 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___76 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___76 *);
	int (*ndo_change_proto_down)(struct net_device___76 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___76 *, struct sk_buff___77 *);
	void (*ndo_set_rx_headroom)(struct net_device___76 *, int);
	int (*ndo_bpf)(struct net_device___76 *, struct netdev_bpf___76 *);
	int (*ndo_xdp_xmit)(struct net_device___76 *, int, struct xdp_frame___76 **, u32);
	struct net_device___76 * (*ndo_xdp_get_xmit_slave)(struct net_device___76 *, struct xdp_buff___76 *);
	int (*ndo_xsk_wakeup)(struct net_device___76 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___76 *);
	int (*ndo_tunnel_ctl)(struct net_device___76 *, struct ip_tunnel_parm *, int);
	struct net_device___76 * (*ndo_get_peer_dev)(struct net_device___76 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___76 *, struct net_device_path___76 *);
};

struct neigh_parms___63 {
	possible_net_t___76 net;
	struct net_device___76 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___63 *);
	struct neigh_table___63 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___63 {
	u32 (*l3mdev_fib_table)(const struct net_device___76 *);
	struct sk_buff___77 * (*l3mdev_l3_rcv)(struct net_device___76 *, struct sk_buff___77 *, u16);
	struct sk_buff___77 * (*l3mdev_l3_out)(struct net_device___76 *, struct sock___63 *, struct sk_buff___77 *, u16);
	struct dst_entry___63 * (*l3mdev_link_scope_lookup)(const struct net_device___76 *, struct flowi6 *);
};

struct ndisc_ops___45 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___76 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___76 *, struct neighbour___63 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___76 *, u8, struct neighbour___63 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___76 *, struct sk_buff___77 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___81 *, struct net_device___76 *, const struct prefix_info *, struct inet6_dev___45 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___8;

struct ip_mc_list___2;

struct in_device___8 {
	struct net_device___76 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___8 *ifa_list;
	struct ip_mc_list___2 *mc_list;
	struct ip_mc_list___2 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___2 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___63 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___45;

struct ifacaddr6___13;

struct inet6_dev___45 {
	struct net_device___76 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___45 *mc_list;
	struct ifmcaddr6___45 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___76 mc_query_queue;
	struct sk_buff_head___76 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___13 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___63 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___70;

struct tcf_block___70;

struct mini_Qdisc___70 {
	struct tcf_proto___70 *filter_list;
	struct tcf_block___70 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___70 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___76 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___76 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___81 *, struct net_device___76 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___76 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___76 *, struct list_head *);
	size_t (*get_size)(const struct net_device___76 *);
	int (*fill_info)(struct sk_buff___77 *, const struct net_device___76 *);
	size_t (*get_xstats_size)(const struct net_device___76 *);
	int (*fill_xstats)(struct sk_buff___77 *, const struct net_device___76 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___76 *, struct net_device___76 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___76 *, const struct net_device___76 *);
	int (*fill_slave_info)(struct sk_buff___77 *, const struct net_device___76 *, const struct net_device___76 *);
	struct net___81 * (*get_link_net)(const struct net_device___76 *);
	size_t (*get_linkxstats_size)(const struct net_device___76 *, int);
	int (*fill_linkxstats)(struct sk_buff___77 *, const struct net_device___76 *, int *, int);
};

struct rtmsg {
	unsigned char rtm_family;
	unsigned char rtm_dst_len;
	unsigned char rtm_src_len;
	unsigned char rtm_tos;
	unsigned char rtm_table;
	unsigned char rtm_protocol;
	unsigned char rtm_scope;
	unsigned char rtm_type;
	unsigned int rtm_flags;
};

struct rtvia {
	__kernel_sa_family_t rtvia_family;
	__u8 rtvia_addr[0];
};

struct in_ifaddr___8 {
	struct hlist_node hash;
	struct in_ifaddr___8 *ifa_next;
	struct in_device___8 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_sf_list;

struct ip_mc_list___2 {
	struct in_device___8 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___2 *next;
		struct ip_mc_list___2 *next_rcu;
	};
	struct ip_mc_list___2 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct ip_sf_socklist {
	unsigned int sl_max;
	unsigned int sl_count;
	struct callback_head rcu;
	__be32 sl_addr[0];
};

struct ip_mc_socklist {
	struct ip_mc_socklist *next_rcu;
	struct ip_mreqn multi;
	unsigned int sfmode;
	struct ip_sf_socklist *sflist;
	struct callback_head rcu;
};

struct ip_sf_list {
	struct ip_sf_list *sf_next;
	long unsigned int sf_count[2];
	__be32 sf_inaddr;
	unsigned char sf_gsresp;
	unsigned char sf_oldin;
	unsigned char sf_crcount;
};

struct nl_info___4 {
	struct nlmsghdr *nlh;
	struct net___81 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

typedef int (*rtnl_doit_func___8)(struct sk_buff___77 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___8)(struct sk_buff___77 *, struct netlink_callback___76 *);

struct fib_rule___63 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___63 *ctarget;
	struct net___81 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___63 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___63 *rule;
	u32 table;
	int flags;
};

struct block_device_operations___158;

struct gendisk___161 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___161 *part0;
	const struct block_device_operations___158 *fops;
	struct request_queue___158 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___144 *bdi;
	struct kobject___255 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___255 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___158 {
	struct bio___158 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___184 *bip_vec;
	struct bio_vec___184 bip_inline_vecs[0];
};

struct blkcg___146;

struct blkg_policy_data___146;

struct blkcg_gq___146 {
	struct request_queue___158 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___146 *blkcg;
	struct blkcg_gq___146 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___146 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___158 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___158(struct request___158 *);

typedef void integrity_complete_fn___158(struct request___158 *, unsigned int);

struct blk_integrity_profile___158 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___158 *prepare_fn;
	integrity_complete_fn___158 *complete_fn;
	const char *name;
};

struct block_device_operations___158 {
	blk_qc_t (*submit_bio)(struct bio___158 *);
	int (*open)(struct block_device___161 *, fmode_t);
	void (*release)(struct gendisk___161 *, fmode_t);
	int (*rw_page)(struct block_device___161 *, sector_t, struct page___272 *, unsigned int);
	int (*ioctl)(struct block_device___161 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___161 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___161 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___161 *);
	int (*getgeo)(struct block_device___161 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___161 *, bool);
	void (*swap_slot_free_notify)(struct block_device___161 *, long unsigned int);
	int (*report_zones)(struct gendisk___161 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___161 *, umode_t *);
	struct module___251 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___161 *, sector_t *);
};

typedef void rq_end_io_fn___158(struct request___158 *, blk_status_t);

struct request___158 {
	struct request_queue___158 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___153 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___158 *bio;
	struct bio___158 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___184 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___158 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___158 *saved_end_io;
		} flush;
	};
	struct gendisk___161 *rq_disk;
	struct block_device___161 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___158 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___153 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___158 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___255 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___267 *debugfs_dir;
	struct dentry___267 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___158;

struct elevator_mq_ops___158 {
	int (*init_sched)(struct request_queue___158 *, struct elevator_type___158 *);
	void (*exit_sched)(struct elevator_queue___158 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___153 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___153 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___153 *);
	bool (*allow_merge)(struct request_queue___158 *, struct request___158 *, struct bio___158 *);
	bool (*bio_merge)(struct request_queue___158 *, struct bio___158 *, unsigned int);
	int (*request_merge)(struct request_queue___158 *, struct request___158 **, struct bio___158 *);
	void (*request_merged)(struct request_queue___158 *, struct request___158 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___158 *, struct request___158 *, struct request___158 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___158 *);
	void (*finish_request)(struct request___158 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___153 *, struct list_head *, bool);
	struct request___158 * (*dispatch_request)(struct blk_mq_hw_ctx___153 *);
	bool (*has_work)(struct blk_mq_hw_ctx___153 *);
	void (*completed_request)(struct request___158 *, u64);
	void (*requeue_request)(struct request___158 *);
	struct request___158 * (*former_request)(struct request_queue___158 *, struct request___158 *);
	struct request___158 * (*next_request)(struct request_queue___158 *, struct request___158 *);
	void (*init_icq)(struct io_cq___158 *);
	void (*exit_icq)(struct io_cq___158 *);
};

struct elv_fs_entry___158;

struct elevator_type___158 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___158 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___158 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___251 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___158 {
	struct elevator_type___158 *type;
	void *elevator_data;
	struct kobject___255 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___158 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___158 *, char *);
	ssize_t (*store)(struct elevator_queue___158 *, const char *, size_t);
};

struct blk_mq_queue_data___153;

struct blk_mq_ops___153 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___153 *, const struct blk_mq_queue_data___153 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___153 *);
	int (*get_budget)(struct request_queue___158 *);
	void (*put_budget)(struct request_queue___158 *, int);
	void (*set_rq_budget_token)(struct request___158 *, int);
	int (*get_rq_budget_token)(struct request___158 *);
	enum blk_eh_timer_return (*timeout)(struct request___158 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___153 *);
	void (*complete)(struct request___158 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___153 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___153 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___153 *, struct request___158 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___153 *, struct request___158 *, unsigned int);
	void (*initialize_rq_fn)(struct request___158 *);
	void (*cleanup_rq)(struct request___158 *);
	bool (*busy)(struct request_queue___158 *);
	int (*map_queues)(struct blk_mq_tag_set___153 *);
	void (*show_rq)(struct seq_file___242 *, struct request___158 *);
};

struct blk_mq_tag_set___153 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___153 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___153 {
	struct request___158 *rq;
	bool last;
};

struct blkcg_policy_data___146;

struct blkcg___146 {
	struct cgroup_subsys_state___194 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___146 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___146 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___146 {
	struct blkcg___146 *blkcg;
	int plid;
};

struct blkg_policy_data___146 {
	struct blkcg_gq___146 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___132 {
	struct mem_cgroup___132 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___132 {
	struct lruvec___140 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___132 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___132 *memcg;
};

struct obj_cgroup___132 {
	struct percpu_ref refcnt;
	struct mem_cgroup___132 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___70 {
	spinlock_t *lock;
	struct sk_buff___77 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___70;

struct Qdisc_ops___70 {
	struct Qdisc_ops___70 *next;
	const struct Qdisc_class_ops___70 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___77 *, struct Qdisc___70 *, struct sk_buff___77 **);
	struct sk_buff___77 * (*dequeue)(struct Qdisc___70 *);
	struct sk_buff___77 * (*peek)(struct Qdisc___70 *);
	int (*init)(struct Qdisc___70 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___70 *);
	void (*destroy)(struct Qdisc___70 *);
	int (*change)(struct Qdisc___70 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___70 *);
	int (*change_tx_queue_len)(struct Qdisc___70 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___70 *, unsigned int);
	int (*dump)(struct Qdisc___70 *, struct sk_buff___77 *);
	int (*dump_stats)(struct Qdisc___70 *, struct gnet_dump___70 *);
	void (*ingress_block_set)(struct Qdisc___70 *, u32);
	void (*egress_block_set)(struct Qdisc___70 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___70 *);
	u32 (*egress_block_get)(struct Qdisc___70 *);
	struct module___251 *owner;
};

struct Qdisc_class_ops___70 {
	unsigned int flags;
	struct netdev_queue___76 * (*select_queue)(struct Qdisc___70 *, struct tcmsg *);
	int (*graft)(struct Qdisc___70 *, long unsigned int, struct Qdisc___70 *, struct Qdisc___70 **, struct netlink_ext_ack *);
	struct Qdisc___70 * (*leaf)(struct Qdisc___70 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___70 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___70 *, u32);
	int (*change)(struct Qdisc___70 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___70 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___70 *, struct qdisc_walker *);
	struct tcf_block___70 * (*tcf_block)(struct Qdisc___70 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___70 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___70 *, long unsigned int);
	int (*dump)(struct Qdisc___70 *, long unsigned int, struct sk_buff___77 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___70 *, long unsigned int, struct gnet_dump___70 *);
};

struct tcf_chain___70;

struct tcf_block___70 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___81 *net;
	struct Qdisc___70 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___70 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___70;

struct tcf_proto_ops___70;

struct tcf_proto___70 {
	struct tcf_proto___70 *next;
	void *root;
	int (*classify)(struct sk_buff___77 *, const struct tcf_proto___70 *, struct tcf_result___70 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___70 *ops;
	struct tcf_chain___70 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___70 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___70 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___70 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___77 *, const struct tcf_proto___70 *, struct tcf_result___70 *);
	int (*init)(struct tcf_proto___70 *);
	void (*destroy)(struct tcf_proto___70 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___70 *, u32);
	void (*put)(struct tcf_proto___70 *, void *);
	int (*change)(struct net___81 *, struct sk_buff___77 *, struct tcf_proto___70 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___70 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___70 *);
	void (*walk)(struct tcf_proto___70 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___70 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___70 *, void *);
	void (*hw_del)(struct tcf_proto___70 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___81 *, struct tcf_chain___70 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___81 *, struct tcf_proto___70 *, void *, struct sk_buff___77 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___81 *, struct tcf_proto___70 *, void *, struct sk_buff___77 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___77 *, struct net___81 *, void *);
	struct module___251 *owner;
	int flags;
};

struct tcf_chain___70 {
	struct mutex filter_chain_lock;
	struct tcf_proto___70 *filter_chain;
	struct list_head list;
	struct tcf_block___70 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___70 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___63 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___70 *prog;
};

struct pneigh_entry___63;

struct neigh_hash_table___63;

struct neigh_table___63 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___76 *, __u32 *);
	bool (*key_eq)(const struct neighbour___63 *, const void *);
	int (*constructor)(struct neighbour___63 *);
	int (*pconstructor)(struct pneigh_entry___63 *);
	void (*pdestructor)(struct pneigh_entry___63 *);
	void (*proxy_redo)(struct sk_buff___77 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___76 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___63 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___76 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___63 *nht;
	struct pneigh_entry___63 **phash_buckets;
};

struct neigh_ops___63 {
	int family;
	void (*solicit)(struct neighbour___63 *, struct sk_buff___77 *);
	void (*error_report)(struct neighbour___63 *, struct sk_buff___77 *);
	int (*output)(struct neighbour___63 *, struct sk_buff___77 *);
	int (*connected_output)(struct neighbour___63 *, struct sk_buff___77 *);
};

struct pneigh_entry___63 {
	struct pneigh_entry___63 *next;
	possible_net_t___76 net;
	struct net_device___76 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___63 {
	struct neighbour___63 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___39 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___81 *, struct sock___63 *, struct sk_buff___77 *);
	int (*orig_input)(struct sk_buff___77 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct request_sock_ops___48;

struct timewait_sock_ops___47;

struct proto___63 {
	void (*close)(struct sock___63 *, long int);
	int (*pre_connect)(struct sock___63 *, struct sockaddr *, int);
	int (*connect)(struct sock___63 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___63 *, int);
	struct sock___63 * (*accept)(struct sock___63 *, int, int *, bool);
	int (*ioctl)(struct sock___63 *, int, long unsigned int);
	int (*init)(struct sock___63 *);
	void (*destroy)(struct sock___63 *);
	void (*shutdown)(struct sock___63 *, int);
	int (*setsockopt)(struct sock___63 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___63 *, int, int, char *, int *);
	void (*keepalive)(struct sock___63 *, int);
	int (*compat_ioctl)(struct sock___63 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___63 *, struct msghdr___65 *, size_t);
	int (*recvmsg)(struct sock___63 *, struct msghdr___65 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___63 *, struct page___272 *, int, size_t, int);
	int (*bind)(struct sock___63 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___63 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___63 *, struct sk_buff___77 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___63 *);
	int (*hash)(struct sock___63 *);
	void (*unhash)(struct sock___63 *);
	void (*rehash)(struct sock___63 *);
	int (*get_port)(struct sock___63 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___63 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___63 *, int);
	bool (*sock_is_readable)(struct sock___63 *);
	void (*enter_memory_pressure)(struct sock___63 *);
	void (*leave_memory_pressure)(struct sock___63 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___48 *rsk_prot;
	struct timewait_sock_ops___47 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___251 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___63 *, int);
};

struct xfrm_policy_queue___8 {
	struct sk_buff_head___76 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___8 {
	possible_net_t___76 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___8 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___16 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___70 *prog;
	struct sock___63 *socks[0];
};

struct request_sock___49;

struct request_sock_ops___48 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___63 *, struct request_sock___49 *);
	void (*send_ack)(const struct sock___63 *, struct sk_buff___77 *, struct request_sock___49 *);
	void (*send_reset)(const struct sock___63 *, struct sk_buff___77 *);
	void (*destructor)(struct request_sock___49 *);
	void (*syn_ack_timeout)(const struct request_sock___49 *);
};

struct timewait_sock_ops___47 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___63 *, struct sock___63 *, void *);
	void (*twsk_destructor)(struct sock___63 *);
};

struct request_sock___49 {
	struct sock_common___63 __req_common;
	struct request_sock___49 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___48 *rsk_ops;
	struct sock___63 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___5 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___63 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___5 {
	struct inet_cork___5 base;
	struct flowi fl;
};

struct ipv6_pinfo___5;

struct inet_sock___5 {
	struct sock___63 sk;
	struct ipv6_pinfo___5 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___5 cork;
};

struct ipv6_fl_socklist___5;

struct ipv6_pinfo___5 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___5 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___77 *pktoptions;
	struct sk_buff___77 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___5;

struct ipv6_fl_socklist___5 {
	struct ipv6_fl_socklist___5 *next;
	struct ip6_flowlabel___5 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___45 {
	struct in6_addr mca_addr;
	struct inet6_dev___45 *idev;
	struct ifmcaddr6___45 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___13 {
	struct in6_addr aca_addr;
	struct fib6_info___13 *aca_rt;
	struct ifacaddr6___13 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result___4;

struct fib6_config___4;

struct ipv6_stub___4 {
	int (*ipv6_sock_mc_join)(struct sock___63 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___63 *, int, const struct in6_addr *);
	struct dst_entry___63 * (*ipv6_dst_lookup_flow)(struct net___81 *, const struct sock___63 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___77 *);
	struct fib6_table___13 * (*fib6_get_table)(struct net___81 *, u32);
	int (*fib6_lookup)(struct net___81 *, int, struct flowi6 *, struct fib6_result___4 *, int);
	int (*fib6_table_lookup)(struct net___81 *, struct fib6_table___13 *, int, struct flowi6 *, struct fib6_result___4 *, int);
	void (*fib6_select_path)(const struct net___81 *, struct fib6_result___4 *, struct flowi6 *, int, bool, const struct sk_buff___77 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___4 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___81 *, struct fib6_nh___13 *, struct fib6_config___4 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___13 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___13 *);
	void (*fib6_update_sernum)(struct net___81 *, struct fib6_info___13 *);
	int (*ip6_del_rt)(struct net___81 *, struct fib6_info___13 *, bool);
	void (*fib6_rt_update)(struct net___81 *, struct fib6_info___13 *, struct nl_info___4 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___76 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___77 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___63 *, struct sk_buff___77 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___77 *, int, __be32, int);
	struct neigh_table___63 *nd_tbl;
	int (*ipv6_fragment)(struct net___81 *, struct sock___63 *, struct sk_buff___77 *, int (*)(struct net___81 *, struct sock___63 *, struct sk_buff___77 *));
	struct net_device___76 * (*ipv6_dev_find)(struct net___81 *, const struct in6_addr *, struct net_device___76 *);
};

struct fib6_result___4 {
	struct fib6_nh___13 *nh;
	struct fib6_info___13 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___13 *rt6;
};

struct fib6_config___4 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___4 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct ip6_flowlabel___5 {
	struct ip6_flowlabel___5 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___244 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___81 *fl_net;
};

struct ipv4_addr_key {
	__be32 addr;
	int vif;
};

struct inetpeer_addr {
	union {
		struct ipv4_addr_key a4;
		struct in6_addr a6;
		u32 key[4];
	};
	__u16 family;
};

struct inet_peer {
	struct rb_node rb_node;
	struct inetpeer_addr daddr;
	u32 metrics[17];
	u32 rate_tokens;
	u32 n_redirects;
	long unsigned int rate_last;
	union {
		struct {
			atomic_t rid;
		};
		struct callback_head rcu;
	};
	__u32 dtime;
	refcount_t refcnt;
};

struct fib_nh_exception___13 {
	struct fib_nh_exception___13 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___13 *fnhe_rth_input;
	struct rtable___13 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___13 {
	struct dst_entry___63 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___13 {
	struct fib_nh_exception___13 *chain;
};

struct fib_info___8;

struct fib_nh___8 {
	struct fib_nh_common___13 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___8 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___8 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___81 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___8 *nh;
	struct callback_head rcu;
	struct fib_nh___8 fib_nh[0];
};

struct nh_info___8;

struct nh_group___8;

struct nexthop___8 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___81 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___8 *nh_info;
		struct nh_group___8 *nh_grp;
	};
};

struct fib_result___2 {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_nh_common___13 *nhc;
	struct fib_info___8 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct fib_rt_info {
	struct fib_info___8 *fi;
	u32 tb_id;
	__be32 dst;
	int dst_len;
	u8 tos;
	u8 type;
	u8 offload: 1;
	u8 trap: 1;
	u8 offload_failed: 1;
	u8 unused: 5;
	long: 59;
	long: 64;
	long: 64;
};

struct nf_hook_state___8 {
	u8 hook;
	u8 pf;
	struct net_device___76 *in;
	struct net_device___76 *out;
	struct sock___63 *sk;
	struct net___81 *net;
	int (*okfn)(struct net___81 *, struct sock___63 *, struct sk_buff___77 *);
};

struct uncached_list {
	spinlock_t lock;
	struct list_head head;
};

struct ip_rt_acct {
	__u32 o_bytes;
	__u32 o_packets;
	__u32 i_bytes;
	__u32 i_packets;
};

struct rt_cache_stat {
	unsigned int in_slow_tot;
	unsigned int in_slow_mc;
	unsigned int in_no_route;
	unsigned int in_brd;
	unsigned int in_martian_dst;
	unsigned int in_martian_src;
	unsigned int out_slow_tot;
	unsigned int out_slow_mc;
};

struct nh_info___8 {
	struct hlist_node dev_hash;
	struct nexthop___8 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___13 fib_nhc;
		struct fib_nh___8 fib_nh;
		struct fib6_nh___13 fib6_nh;
	};
};

struct nh_grp_entry___8;

struct nh_res_bucket___8 {
	struct nh_grp_entry___8 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___8 {
	struct nexthop___8 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___8 *nh_parent;
};

struct nh_res_table___8 {
	struct net___81 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___8 nh_buckets[0];
};

struct nh_group___8 {
	struct nh_group___8 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___8 *res_table;
	struct nh_grp_entry___8 nh_entries[0];
};

struct hw_port_info___6 {
	struct net_device___76 *lower_dev;
	u32 port_id;
};

struct metadata_dst___7 {
	struct dst_entry___63 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___6 port_info;
	} u;
};

struct xfrm_type___8 {
	struct module___251 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___8 *);
	void (*destructor)(struct xfrm_state___8 *);
	int (*input)(struct xfrm_state___8 *, struct sk_buff___77 *);
	int (*output)(struct xfrm_state___8 *, struct sk_buff___77 *);
	int (*reject)(struct xfrm_state___8 *, struct sk_buff___77 *, const struct flowi *);
};

struct xfrm_type_offload___8 {
	struct module___251 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___8 *, struct sk_buff___77 *);
	int (*input_tail)(struct xfrm_state___8 *, struct sk_buff___77 *);
	int (*xmit)(struct xfrm_state___8 *, struct sk_buff___77 *, netdev_features_t);
};

struct xfrm_dst___4 {
	union {
		struct dst_entry___63 dst;
		struct rtable___13 rt;
		struct rt6_info___13 rt6;
	} u;
	struct dst_entry___63 *route;
	struct dst_entry___63 *child;
	struct dst_entry___63 *path;
	struct xfrm_policy___8 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct fib_alias {
	struct hlist_node fa_list;
	struct fib_info___8 *fa_info;
	u8 fa_tos;
	u8 fa_type;
	u8 fa_state;
	u8 fa_slen;
	u32 tb_id;
	s16 fa_default;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	struct callback_head rcu;
};

struct fib_prop {
	int error;
	u8 scope;
};

struct net_protocol___2 {
	int (*early_demux)(struct sk_buff___61 *);
	int (*early_demux_handler)(struct sk_buff___61 *);
	int (*handler)(struct sk_buff___61 *);
	int (*err_handler)(struct sk_buff___61 *, u32);
	unsigned int no_policy;
	unsigned int icmp_strict_tag_validation;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_offload {
	struct offload_callbacks callbacks;
	unsigned int flags;
};

struct dentry___268;

struct super_block___268;

struct module___252;

struct file_system_type___268 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___268 * (*mount)(struct file_system_type___268 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___268 *);
	struct module___252 *owner;
	struct file_system_type___268 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___268;

struct kiocb___268;

struct iov_iter___188;

struct poll_table_struct___189;

struct vm_area_struct___273;

struct inode___268;

struct file_lock___268;

struct page___273;

struct pipe_inode_info___109;

struct seq_file___243;

struct file_operations___269 {
	struct module___252 *owner;
	loff_t (*llseek)(struct file___268 *, loff_t, int);
	ssize_t (*read)(struct file___268 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___268 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___268 *, struct iov_iter___188 *);
	ssize_t (*write_iter)(struct kiocb___268 *, struct iov_iter___188 *);
	int (*iopoll)(struct kiocb___268 *, bool);
	int (*iterate)(struct file___268 *, struct dir_context *);
	int (*iterate_shared)(struct file___268 *, struct dir_context *);
	__poll_t (*poll)(struct file___268 *, struct poll_table_struct___189 *);
	long int (*unlocked_ioctl)(struct file___268 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___268 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___268 *, struct vm_area_struct___273 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___268 *, struct file___268 *);
	int (*flush)(struct file___268 *, fl_owner_t);
	int (*release)(struct inode___268 *, struct file___268 *);
	int (*fsync)(struct file___268 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___268 *, int);
	int (*lock)(struct file___268 *, int, struct file_lock___268 *);
	ssize_t (*sendpage)(struct file___268 *, struct page___273 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___268 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___268 *, long unsigned int);
	int (*flock)(struct file___268 *, int, struct file_lock___268 *);
	ssize_t (*splice_write)(struct pipe_inode_info___109 *, struct file___268 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___268 *, loff_t *, struct pipe_inode_info___109 *, size_t, unsigned int);
	int (*setlease)(struct file___268 *, long int, struct file_lock___268 **, void **);
	long int (*fallocate)(struct file___268 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___243 *, struct file___268 *);
	ssize_t (*copy_file_range)(struct file___268 *, loff_t, struct file___268 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___268 *, loff_t, struct file___268 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___268 *, loff_t, loff_t, int);
};

struct vmacache___273 {
	u64 seqnum;
	struct vm_area_struct___273 *vmas[4];
};

struct page_frag___273 {
	struct page___273 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___274;

struct pid___245;

struct nsproxy___254;

struct signal_struct___269;

struct bio_list___159;

struct backing_dev_info___145;

struct io_context___159;

struct css_set___195;

struct mem_cgroup___133;

struct request_queue___159;

struct vm_struct___251;

struct task_struct___275 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___275 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___274 *mm;
	struct mm_struct___274 *active_mm;
	struct vmacache___273 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___275 *real_parent;
	struct task_struct___275 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___275 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___245 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___254 *nsproxy;
	struct signal_struct___269 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___275 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___159 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___145 *backing_dev_info;
	struct io_context___159 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___195 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___109 *splice_pipe;
	struct page_frag___273 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___133 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___133 *active_memcg;
	struct request_queue___159 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___275 *oom_reaper_list;
	struct vm_struct___251 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___256;

struct kobj_type___256;

struct kernfs_node___256;

struct kobject___256 {
	const char *name;
	struct list_head entry;
	struct kobject___256 *parent;
	struct kset___256 *kset;
	struct kobj_type___256 *ktype;
	struct kernfs_node___256 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___253 {
	struct kobject___256 kobj;
	struct module___252 *mod;
	struct kobject___256 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___252 {
	struct module___252 *mod;
	struct latch_tree_node node;
};

struct module_layout___252 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___252 mtn;
};

struct module_attribute___252;

struct kernel_param___252;

struct module___252 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___253 mkobj;
	struct module_attribute___252 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___256 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___252 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___252 core_layout;
	struct module_layout___252 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___245;

struct upid___245 {
	int nr;
	struct pid_namespace___245 *ns;
};

struct pid_namespace___245 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___275 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___245 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___245 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___245 numbers[1];
};

typedef struct page___273 *pgtable_t___273;

struct address_space___268;

struct page_pool___97;

struct dev_pagemap___263;

struct page___273 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___268 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___97 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___273 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___273 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___274 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___263 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___263;

struct vm_area_struct___273 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___273 *vm_next;
	struct vm_area_struct___273 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___274 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___263 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___268 *vm_file;
	struct file___268 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___269 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___275 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___275 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___245 *pids[4];
	struct pid___245 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___274 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___273;

struct mm_struct___274 {
	struct {
		struct vm_area_struct___273 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___268 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___273 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___275 *owner;
		struct user_namespace___26 *user_ns;
		struct file___268 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___82;

struct cgroup_namespace___195;

struct nsproxy___254 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___245 *pid_ns_for_children;
	struct net___82 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___195 *cgroup_ns;
};

struct bio___159;

struct bio_list___159 {
	struct bio___159 *head;
	struct bio___159 *tail;
};

struct cgroup_subsys_state___195;

struct bdi_writeback___145 {
	struct backing_dev_info___145 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___195 *memcg_css;
	struct cgroup_subsys_state___195 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___249;

struct backing_dev_info___145 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___145 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___249 *dev;
	char dev_name[64];
	struct device___249 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___268 *debug_dir;
};

struct io_cq___159;

struct io_context___159 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___159 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___195;

struct css_set___195 {
	struct cgroup_subsys_state___195 *subsys[14];
	refcount_t refcount;
	struct css_set___195 *dom_cset;
	struct cgroup___195 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___195 *mg_src_cgrp;
	struct cgroup___195 *mg_dst_cgrp;
	struct css_set___195 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___268;

struct pipe_buffer___109;

struct pipe_inode_info___109 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___273 *tmp_page;
	struct fasync_struct___268 *fasync_readers;
	struct fasync_struct___268 *fasync_writers;
	struct pipe_buffer___109 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___195;

struct cgroup_subsys_state___195 {
	struct cgroup___195 *cgroup;
	struct cgroup_subsys___195 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___195 *parent;
};

struct cgroup_file___195 {
	struct kernfs_node___256 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___133;

struct mem_cgroup_per_node___133;

struct mem_cgroup___133 {
	struct cgroup_subsys_state___195 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___195 events_file;
	struct cgroup_file___195 events_local_file;
	struct cgroup_file___195 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___133 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___275 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___133 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___159;

struct blk_integrity___159 {
	const struct blk_integrity_profile___159 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___159 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___159 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___159;

struct elevator_queue___159;

struct blk_mq_ops___154;

struct blk_mq_hw_ctx___154;

struct gendisk___162;

struct blkcg_gq___147;

struct blk_mq_tag_set___154;

struct request_queue___159 {
	struct request___159 *last_merge;
	struct elevator_queue___159 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___154 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___154 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___162 *disk;
	struct kobject___256 kobj;
	struct kobject___256 *mq_kobj;
	struct blk_integrity___159 integrity;
	struct device___249 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___147 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___154 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___159 bio_split;
	struct dentry___268 *debugfs_dir;
	struct dentry___268 *sched_debugfs_dir;
	struct dentry___268 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___251 {
	struct vm_struct___251 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___273 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___268;

struct address_space___268 {
	struct inode___268 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___268 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___97 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___249 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___97 {
	u32 count;
	struct page___273 *cache[128];
};

struct page_pool___97 {
	struct page_pool_params___97 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___273 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___97 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___263;

struct dev_pagemap___263 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___263 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___268;

struct path___268 {
	struct vfsmount___268 *mnt;
	struct dentry___268 *dentry;
};

struct fown_struct___245 {
	rwlock_t lock;
	struct pid___245 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___268 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___268 f_path;
	struct inode___268 *f_inode;
	const struct file_operations___269 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___245 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___268 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___263;

struct vm_operations_struct___263 {
	void (*open)(struct vm_area_struct___273 *);
	void (*close)(struct vm_area_struct___273 *);
	int (*may_split)(struct vm_area_struct___273 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___273 *);
	int (*mprotect)(struct vm_area_struct___273 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___263 *);
	vm_fault_t (*huge_fault)(struct vm_fault___263 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___263 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___273 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___263 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___263 *);
	int (*access)(struct vm_area_struct___273 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___273 *);
	int (*set_policy)(struct vm_area_struct___273 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___273 *, long unsigned int);
	struct page___273 * (*find_special_page)(struct vm_area_struct___273 *, long unsigned int);
};

struct core_thread___273 {
	struct task_struct___275 *task;
	struct core_thread___273 *next;
};

struct core_state___273 {
	atomic_t nr_threads;
	struct core_thread___273 dumper;
	struct completion startup;
};

struct vm_fault___263 {
	const struct {
		struct vm_area_struct___273 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___273 *cow_page;
	struct page___273 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___273 prealloc_pte;
};

struct pglist_data___141;

struct lruvec___141 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___141 *pgdat;
};

struct zone___141 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___141 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___141 {
	struct zone___141 *zone;
	int zone_idx;
};

struct zonelist___141 {
	struct zoneref___141 _zonerefs[321];
};

struct pglist_data___141 {
	struct zone___141 node_zones[5];
	struct zonelist___141 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___275 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___275 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___141 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___268;

struct dentry___268 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___268 *d_parent;
	struct qstr d_name;
	struct inode___268 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___268 *d_op;
	struct super_block___268 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___268;

struct inode___268 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___268 *i_op;
	struct super_block___268 *i_sb;
	struct address_space___268 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___145 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___269 *i_fop;
		void (*free_inode)(struct inode___268 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___268 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___109 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___268 {
	int (*d_revalidate)(struct dentry___268 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___268 *, unsigned int);
	int (*d_hash)(const struct dentry___268 *, struct qstr *);
	int (*d_compare)(const struct dentry___268 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___268 *);
	int (*d_init)(struct dentry___268 *);
	void (*d_release)(struct dentry___268 *);
	void (*d_prune)(struct dentry___268 *);
	void (*d_iput)(struct dentry___268 *, struct inode___268 *);
	char * (*d_dname)(struct dentry___268 *, char *, int);
	struct vfsmount___268 * (*d_automount)(struct path___268 *);
	int (*d_manage)(const struct path___268 *, bool);
	struct dentry___268 * (*d_real)(struct dentry___268 *, const struct inode___268 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___268;

struct mem_dqinfo___268 {
	struct quota_format_type___268 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___268;

struct quota_info___268 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___268 *files[3];
	struct mem_dqinfo___268 info[3];
	const struct quota_format_ops___268 *ops[3];
};

struct rcuwait___269 {
	struct task_struct___275 *task;
};

struct percpu_rw_semaphore___269 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___269 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___268 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___269 rw_sem[3];
};

struct shrink_control___133;

struct shrinker___133 {
	long unsigned int (*count_objects)(struct shrinker___133 *, struct shrink_control___133 *);
	long unsigned int (*scan_objects)(struct shrinker___133 *, struct shrink_control___133 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___268;

struct dquot_operations___268;

struct quotactl_ops___268;

struct block_device___162;

struct super_block___268 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___268 *s_type;
	const struct super_operations___268 *s_op;
	const struct dquot_operations___268 *dq_op;
	const struct quotactl_ops___268 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___268 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___162 *s_bdev;
	struct backing_dev_info___145 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___268 s_dquot;
	struct sb_writers___268 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___268 *s_d_op;
	int cleancache_poolid;
	struct shrinker___133 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___268 {
	struct dentry___268 *mnt_root;
	struct super_block___268 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___133 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___133 *memcg;
};

struct psi_group___195 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___275 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___71;

struct cgroup_bpf___71 {
	struct bpf_prog_array___71 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___71 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___195;

struct cgroup_rstat_cpu___195;

struct cgroup___195 {
	struct cgroup_subsys_state___195 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___256 *kn;
	struct cgroup_file___195 procs_file;
	struct cgroup_file___195 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___195 *subsys[14];
	struct cgroup_root___195 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___195 *dom_cgrp;
	struct cgroup___195 *old_dom_cgrp;
	struct cgroup_rstat_cpu___195 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___195 psi;
	struct cgroup_bpf___71 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___159 {
	struct request_queue___159 *q;
	struct io_context___159 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___268 {
	struct file___268 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___268 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___268 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___268 *ia_file;
};

struct dquot___268 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___268 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___268 {
	int qf_fmt_id;
	const struct quota_format_ops___268 *qf_ops;
	struct module___252 *qf_owner;
	struct quota_format_type___268 *qf_next;
};

struct quota_format_ops___268 {
	int (*check_quota_file)(struct super_block___268 *, int);
	int (*read_file_info)(struct super_block___268 *, int);
	int (*write_file_info)(struct super_block___268 *, int);
	int (*free_file_info)(struct super_block___268 *, int);
	int (*read_dqblk)(struct dquot___268 *);
	int (*commit_dqblk)(struct dquot___268 *);
	int (*release_dqblk)(struct dquot___268 *);
	int (*get_next_id)(struct super_block___268 *, struct kqid *);
};

struct dquot_operations___268 {
	int (*write_dquot)(struct dquot___268 *);
	struct dquot___268 * (*alloc_dquot)(struct super_block___268 *, int);
	void (*destroy_dquot)(struct dquot___268 *);
	int (*acquire_dquot)(struct dquot___268 *);
	int (*release_dquot)(struct dquot___268 *);
	int (*mark_dirty)(struct dquot___268 *);
	int (*write_info)(struct super_block___268 *, int);
	qsize_t * (*get_reserved_space)(struct inode___268 *);
	int (*get_projid)(struct inode___268 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___268 *, qsize_t *);
	int (*get_next_id)(struct super_block___268 *, struct kqid *);
};

struct quotactl_ops___268 {
	int (*quota_on)(struct super_block___268 *, int, int, const struct path___268 *);
	int (*quota_off)(struct super_block___268 *, int);
	int (*quota_enable)(struct super_block___268 *, unsigned int);
	int (*quota_disable)(struct super_block___268 *, unsigned int);
	int (*quota_sync)(struct super_block___268 *, int);
	int (*set_info)(struct super_block___268 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___268 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___268 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___268 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___268 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___268 *, unsigned int);
};

struct writeback_control___145;

struct address_space_operations___268 {
	int (*writepage)(struct page___273 *, struct writeback_control___145 *);
	int (*readpage)(struct file___268 *, struct page___273 *);
	int (*writepages)(struct address_space___268 *, struct writeback_control___145 *);
	int (*set_page_dirty)(struct page___273 *);
	int (*readpages)(struct file___268 *, struct address_space___268 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___268 *, struct address_space___268 *, loff_t, unsigned int, unsigned int, struct page___273 **, void **);
	int (*write_end)(struct file___268 *, struct address_space___268 *, loff_t, unsigned int, unsigned int, struct page___273 *, void *);
	sector_t (*bmap)(struct address_space___268 *, sector_t);
	void (*invalidatepage)(struct page___273 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___273 *, gfp_t);
	void (*freepage)(struct page___273 *);
	ssize_t (*direct_IO)(struct kiocb___268 *, struct iov_iter___188 *);
	int (*migratepage)(struct address_space___268 *, struct page___273 *, struct page___273 *, enum migrate_mode);
	bool (*isolate_page)(struct page___273 *, isolate_mode_t);
	void (*putback_page)(struct page___273 *);
	int (*launder_page)(struct page___273 *);
	int (*is_partially_uptodate)(struct page___273 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___273 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___268 *, struct page___273 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___268 *, sector_t *);
	void (*swap_deactivate)(struct file___268 *);
};

struct writeback_control___145 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___145 *wb;
	struct inode___268 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___185;

struct iov_iter___188 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___185 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___109 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___268 {
	struct dentry___268 * (*lookup)(struct inode___268 *, struct dentry___268 *, unsigned int);
	const char * (*get_link)(struct dentry___268 *, struct inode___268 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___268 *, int);
	struct posix_acl * (*get_acl)(struct inode___268 *, int, bool);
	int (*readlink)(struct dentry___268 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___268 *, struct dentry___268 *, umode_t, bool);
	int (*link)(struct dentry___268 *, struct inode___268 *, struct dentry___268 *);
	int (*unlink)(struct inode___268 *, struct dentry___268 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___268 *, struct dentry___268 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___268 *, struct dentry___268 *, umode_t);
	int (*rmdir)(struct inode___268 *, struct dentry___268 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___268 *, struct dentry___268 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___268 *, struct dentry___268 *, struct inode___268 *, struct dentry___268 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___268 *, struct iattr___268 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___268 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___268 *, char *, size_t);
	int (*fiemap)(struct inode___268 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___268 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___268 *, struct dentry___268 *, struct file___268 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___268 *, struct dentry___268 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___268 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___268 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___268 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___268 {
	void (*fl_copy_lock)(struct file_lock___268 *, struct file_lock___268 *);
	void (*fl_release_private)(struct file_lock___268 *);
};

struct lock_manager_operations___268;

struct file_lock___268 {
	struct file_lock___268 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___268 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___268 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___268 *fl_ops;
	const struct lock_manager_operations___268 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___268 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___268 *);
	int (*lm_grant)(struct file_lock___268 *, int);
	bool (*lm_break)(struct file_lock___268 *);
	int (*lm_change)(struct file_lock___268 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___268 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___268 *);
};

struct fasync_struct___268 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___268 *fa_next;
	struct file___268 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___268 {
	struct inode___268 * (*alloc_inode)(struct super_block___268 *);
	void (*destroy_inode)(struct inode___268 *);
	void (*free_inode)(struct inode___268 *);
	void (*dirty_inode)(struct inode___268 *, int);
	int (*write_inode)(struct inode___268 *, struct writeback_control___145 *);
	int (*drop_inode)(struct inode___268 *);
	void (*evict_inode)(struct inode___268 *);
	void (*put_super)(struct super_block___268 *);
	int (*sync_fs)(struct super_block___268 *, int);
	int (*freeze_super)(struct super_block___268 *);
	int (*freeze_fs)(struct super_block___268 *);
	int (*thaw_super)(struct super_block___268 *);
	int (*unfreeze_fs)(struct super_block___268 *);
	int (*statfs)(struct dentry___268 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___268 *, int *, char *);
	void (*umount_begin)(struct super_block___268 *);
	int (*show_options)(struct seq_file___243 *, struct dentry___268 *);
	int (*show_devname)(struct seq_file___243 *, struct dentry___268 *);
	int (*show_path)(struct seq_file___243 *, struct dentry___268 *);
	int (*show_stats)(struct seq_file___243 *, struct dentry___268 *);
	ssize_t (*quota_read)(struct super_block___268 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___268 *, int, const char *, size_t, loff_t);
	struct dquot___268 ** (*get_dquots)(struct inode___268 *);
	long int (*nr_cached_objects)(struct super_block___268 *, struct shrink_control___133 *);
	long int (*free_cached_objects)(struct super_block___268 *, struct shrink_control___133 *);
	struct file___268 * (*real_loop)(struct file___268 *);
};

struct wakeup_source___249;

struct dev_pm_info___249 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___249 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___249 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___249;

struct bus_type___249;

struct device_driver___249;

struct dev_pm_domain___249;

struct fwnode_handle___245;

struct class___249;

struct attribute_group___256;

struct device___249 {
	struct kobject___256 kobj;
	struct device___249 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___249 *type;
	struct bus_type___249 *bus;
	struct device_driver___249 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___249 power;
	struct dev_pm_domain___249 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___245 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___249 *class;
	const struct attribute_group___256 **groups;
	void (*release)(struct device___249 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___162 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___268 *bd_inode;
	struct super_block___268 *bd_super;
	void *bd_claiming;
	struct device___249 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___256 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___162 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___268 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___197)(struct file___268 *, wait_queue_head_t *, struct poll_table_struct___189 *);

struct poll_table_struct___189 {
	poll_queue_proc___197 _qproc;
	__poll_t _key;
};

struct seq_operations___243;

struct seq_file___243 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___243 *op;
	int poll_event;
	const struct file___268 *file;
	void *private;
};

typedef void bio_end_io_t___159(struct bio___159 *);

struct bio_vec___185 {
	struct page___273 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___159;

struct bio___159 {
	struct bio___159 *bi_next;
	struct block_device___162 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___159 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___147 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___159 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___185 *bi_io_vec;
	struct bio_set___159 *bi_pool;
	struct bio_vec___185 bi_inline_vecs[0];
};

struct kernfs_root___256;

struct kernfs_elem_dir___256 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___256 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___256;

struct kernfs_root___256 {
	struct kernfs_node___256 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___256 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___256 {
	struct kernfs_node___256 *target_kn;
};

struct kernfs_ops___256;

struct kernfs_elem_attr___256 {
	const struct kernfs_ops___256 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___256 *notify_next;
};

struct kernfs_node___256 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___256 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___256 dir;
		struct kernfs_elem_symlink___256 symlink;
		struct kernfs_elem_attr___256 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___256;

struct kernfs_ops___256 {
	int (*open)(struct kernfs_open_file___256 *);
	void (*release)(struct kernfs_open_file___256 *);
	int (*seq_show)(struct seq_file___243 *, void *);
	void * (*seq_start)(struct seq_file___243 *, loff_t *);
	void * (*seq_next)(struct seq_file___243 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___243 *, void *);
	ssize_t (*read)(struct kernfs_open_file___256 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___256 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___256 *, struct poll_table_struct___189 *);
	int (*mmap)(struct kernfs_open_file___256 *, struct vm_area_struct___273 *);
};

struct kernfs_syscall_ops___256 {
	int (*show_options)(struct seq_file___243 *, struct kernfs_root___256 *);
	int (*mkdir)(struct kernfs_node___256 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___256 *);
	int (*rename)(struct kernfs_node___256 *, struct kernfs_node___256 *, const char *);
	int (*show_path)(struct seq_file___243 *, struct kernfs_node___256 *, struct kernfs_root___256 *);
};

struct kernfs_open_file___256 {
	struct kernfs_node___256 *kn;
	struct file___268 *file;
	struct seq_file___243 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___263 *vm_ops;
};

struct sock___64;

struct kobj_ns_type_operations___64 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___64 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___82 *net;
} possible_net_t___77;

struct proto___64;

struct sock_common___64 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___64 *skc_prot;
	possible_net_t___77 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___64 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___78;

struct sk_buff_head___77 {
	struct sk_buff___78 *next;
	struct sk_buff___78 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___64 {
	struct cgroup___195 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___64;

struct socket_wq___65;

struct xfrm_policy___9;

struct dst_entry___64;

struct socket___66;

struct net_device___77;

struct sock___64 {
	struct sock_common___64 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___77 sk_error_queue;
	struct sk_buff___78 *sk_rx_skb_cache;
	struct sk_buff_head___77 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___78 *head;
		struct sk_buff___78 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___64 *sk_filter;
	union {
		struct socket_wq___65 *sk_wq;
		struct socket_wq___65 *sk_wq_raw;
	};
	struct xfrm_policy___9 *sk_policy[2];
	struct dst_entry___64 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___64 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___78 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___78 *sk_tx_skb_cache;
	struct sk_buff_head___77 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___273 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___64 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___245 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___66 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___64 sk_cgrp_data;
	struct mem_cgroup___133 *sk_memcg;
	void (*sk_state_change)(struct sock___64 *);
	void (*sk_data_ready)(struct sock___64 *);
	void (*sk_write_space)(struct sock___64 *);
	void (*sk_error_report)(struct sock___64 *);
	int (*sk_backlog_rcv)(struct sock___64 *, struct sk_buff___78 *);
	struct sk_buff___78 * (*sk_validate_xmit_skb)(struct sock___64 *, struct net_device___77 *, struct sk_buff___78 *);
	void (*sk_destruct)(struct sock___64 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___256;

struct attribute_group___256 {
	const char *name;
	umode_t (*is_visible)(struct kobject___256 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___256 *, struct bin_attribute___256 *, int);
	struct attribute **attrs;
	struct bin_attribute___256 **bin_attrs;
};

struct bin_attribute___256 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___268 * (*f_mapping)();
	ssize_t (*read)(struct file___268 *, struct kobject___256 *, struct bin_attribute___256 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___268 *, struct kobject___256 *, struct bin_attribute___256 *, char *, loff_t, size_t);
	int (*mmap)(struct file___268 *, struct kobject___256 *, struct bin_attribute___256 *, struct vm_area_struct___273 *);
};

struct sysfs_ops___256 {
	ssize_t (*show)(struct kobject___256 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___256 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___256;

struct kset___256 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___256 kobj;
	const struct kset_uevent_ops___256 *uevent_ops;
};

struct kobj_type___256 {
	void (*release)(struct kobject___256 *);
	const struct sysfs_ops___256 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___256 **default_groups;
	const struct kobj_ns_type_operations___64 * (*child_ns_type)(struct kobject___256 *);
	const void * (*namespace)(struct kobject___256 *);
	void (*get_ownership)(struct kobject___256 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___256 {
	int (* const filter)(struct kset___256 *, struct kobject___256 *);
	const char * (* const name)(struct kset___256 *, struct kobject___256 *);
	int (* const uevent)(struct kset___256 *, struct kobject___256 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___252 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___252 *);
	int (*get)(char *, const struct kernel_param___252 *);
	void (*free)(void *);
};

struct kparam_array___252;

struct kernel_param___252 {
	const char *name;
	struct module___252 *mod;
	const struct kernel_param_ops___252 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___252 *arr;
	};
};

struct kparam_array___252 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___252 *ops;
	void *elem;
};

struct module_attribute___252 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___252 *, struct module_kobject___253 *, char *);
	ssize_t (*store)(struct module_attribute___252 *, struct module_kobject___253 *, const char *, size_t);
	void (*setup)(struct module___252 *, const char *);
	int (*test)(struct module___252 *);
	void (*free)(struct module___252 *);
};

struct dev_pagemap_ops___263 {
	void (*page_free)(struct page___273 *);
	void (*kill)(struct dev_pagemap___263 *);
	void (*cleanup)(struct dev_pagemap___263 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___263 *);
};

struct msghdr___66 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___188 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___268 *msg_iocb;
};

struct socket_wq___65 {
	wait_queue_head_t wait;
	struct fasync_struct___268 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___65;

struct socket___66 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___268 *file;
	struct sock___64 *sk;
	const struct proto_ops___65 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___65 wq;
};

typedef int (*sk_read_actor_t___64)(read_descriptor_t *, struct sk_buff___78 *, unsigned int, size_t);

struct proto_ops___65 {
	int family;
	struct module___252 *owner;
	int (*release)(struct socket___66 *);
	int (*bind)(struct socket___66 *, struct sockaddr *, int);
	int (*connect)(struct socket___66 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___66 *, struct socket___66 *);
	int (*accept)(struct socket___66 *, struct socket___66 *, int, bool);
	int (*getname)(struct socket___66 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___268 *, struct socket___66 *, struct poll_table_struct___189 *);
	int (*ioctl)(struct socket___66 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___66 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___66 *, void *, bool, bool);
	int (*listen)(struct socket___66 *, int);
	int (*shutdown)(struct socket___66 *, int);
	int (*setsockopt)(struct socket___66 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___66 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___243 *, struct socket___66 *);
	int (*sendmsg)(struct socket___66 *, struct msghdr___66 *, size_t);
	int (*recvmsg)(struct socket___66 *, struct msghdr___66 *, size_t, int);
	int (*mmap)(struct file___268 *, struct socket___66 *, struct vm_area_struct___273 *);
	ssize_t (*sendpage)(struct socket___66 *, struct page___273 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___66 *, loff_t *, struct pipe_inode_info___109 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___64 *, int);
	int (*peek_len)(struct socket___66 *);
	int (*read_sock)(struct sock___64 *, read_descriptor_t *, sk_read_actor_t___64);
	int (*sendpage_locked)(struct sock___64 *, struct page___273 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___64 *, struct msghdr___66 *, size_t);
	int (*set_rcvlowat)(struct sock___64 *, int);
};

struct sk_buff___78 {
	union {
		struct {
			struct sk_buff___78 *next;
			struct sk_buff___78 *prev;
			union {
				struct net_device___77 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___64 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___78 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___37;

struct fib_rules_ops___64;

struct fqdir___82;

struct fib_notifier_ops___64;

struct netns_ipv4___82 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___37 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___64 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___64 *fibnl;
	struct sock___64 **icmp_sk;
	struct sock___64 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___64 **tcp_sk;
	struct fqdir___82 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___64 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___64 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___64 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___64;

struct dst_ops___82 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___82 *);
	struct dst_entry___64 * (*check)(struct dst_entry___64 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___64 *);
	unsigned int (*mtu)(const struct dst_entry___64 *);
	u32 * (*cow_metrics)(struct dst_entry___64 *, long unsigned int);
	void (*destroy)(struct dst_entry___64 *);
	void (*ifdown)(struct dst_entry___64 *, struct net_device___77 *, int);
	struct dst_entry___64 * (*negative_advice)(struct dst_entry___64 *);
	void (*link_failure)(struct sk_buff___78 *);
	void (*update_pmtu)(struct dst_entry___64 *, struct sock___64 *, struct sk_buff___78 *, u32, bool);
	void (*redirect)(struct dst_entry___64 *, struct sock___64 *, struct sk_buff___78 *);
	int (*local_out)(struct net___82 *, struct sock___64 *, struct sk_buff___78 *);
	struct neighbour___64 * (*neigh_lookup)(const struct dst_entry___64 *, struct sk_buff___78 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___64 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___14;

struct rt6_info___14;

struct fib6_table___14;

struct netns_ipv6___82 {
	struct dst_ops___82 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___82 *fqdir;
	struct fib6_info___14 *fib6_null_entry;
	struct rt6_info___14 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___14 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___14 *ip6_prohibit_entry;
	struct rt6_info___14 *ip6_blk_hole_entry;
	struct fib6_table___14 *fib6_local_tbl;
	struct fib_rules_ops___64 *fib6_rules_ops;
	struct sock___64 **icmp_sk;
	struct sock___64 *ndisc_sk;
	struct sock___64 *tcp_sk;
	struct sock___64 *igmp_sk;
	struct sock___64 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___64 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___64 *notifier_ops;
	struct fib_notifier_ops___64 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___82 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___82 *fqdir;
};

struct netns_sctp___64 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___64 *ctl_sock;
	struct sock___64 *udp4_sock;
	struct sock___64 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___9;

struct netns_nf___9 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___9 *hooks_ipv4[5];
	struct nf_hook_entries___9 *hooks_ipv6[5];
	struct nf_hook_entries___9 *hooks_arp[3];
	struct nf_hook_entries___9 *hooks_bridge[5];
	struct nf_hook_entries___9 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___71;

struct netns_bpf___71 {
	struct bpf_prog_array___71 *run_array[2];
	struct bpf_prog___71 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___82 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___64 *nlsk;
	struct sock___64 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___82 xfrm4_dst_ops;
	struct dst_ops___82 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___82 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___64 *rtnl;
	struct sock___64 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___77 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___82 ipv4;
	struct netns_ipv6___82 ipv6;
	struct netns_ieee802154_lowpan___82 ieee802154_lowpan;
	struct netns_sctp___64 sctp;
	struct netns_nf___9 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___77 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___71 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___82 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___64 *crypto_nlsk;
	struct sock___64 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___82;

struct fqdir___82 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___82 *f;
	struct net___82 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___82;

struct inet_frags___82 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___82 *, const void *);
	void (*destructor)(struct inet_frag_queue___82 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___82 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___78 *fragments_tail;
	struct sk_buff___78 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___82 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___37 {
	struct ip_ra_chain___37 *next;
	struct sock___64 *sk;
	union {
		void (*destructor)(struct sock___64 *);
		struct sock___64 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___64;

struct fib_lookup_arg___64;

struct fib_rules_ops___64 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___64 *, struct flowi *, int, struct fib_lookup_arg___64 *);
	bool (*suppress)(struct fib_rule___64 *, int, struct fib_lookup_arg___64 *);
	int (*match)(struct fib_rule___64 *, struct flowi *, int);
	int (*configure)(struct fib_rule___64 *, struct sk_buff___78 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___64 *);
	int (*compare)(struct fib_rule___64 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___64 *, struct sk_buff___78 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___64 *);
	void (*flush_cache)(struct fib_rules_ops___64 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___252 *owner;
	struct net___82 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___64 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___82 *);
	int (*fib_dump)(struct net___82 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___252 *owner;
	struct callback_head rcu;
};

struct xfrm_state___9;

struct lwtunnel_state___40;

struct dst_entry___64 {
	struct net_device___77 *dev;
	struct dst_ops___82 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___9 *xfrm;
	int (*input)(struct sk_buff___78 *);
	int (*output)(struct net___82 *, struct sock___64 *, struct sk_buff___78 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___40 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___77(struct sk_buff___78 **);

struct bpf_xdp_entity___71 {
	struct bpf_prog___71 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___77;

struct net_device_ops___77;

struct l3mdev_ops___64;

struct ndisc_ops___46;

struct xfrmdev_ops___77;

struct header_ops___77;

struct in_device___9;

struct inet6_dev___46;

struct netdev_rx_queue___77;

struct mini_Qdisc___71;

struct netdev_queue___77;

struct Qdisc___71;

struct rtnl_link_ops___71;

struct dcbnl_rtnl_ops___77;

struct net_device___77 {
	char name[16];
	struct netdev_name_node___77 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___77 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___64 *l3mdev_ops;
	const struct ndisc_ops___46 *ndisc_ops;
	const struct xfrmdev_ops___77 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___77 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___256 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___9 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___46 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___77 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___71 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___77 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___71 *miniq_ingress;
	struct netdev_queue___77 *ingress_queue;
	struct nf_hook_entries___9 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___77 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___71 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___71 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___77 = 0,
		NETREG_REGISTERED___77 = 1,
		NETREG_UNREGISTERING___77 = 2,
		NETREG_UNREGISTERED___77 = 3,
		NETREG_RELEASED___77 = 4,
		NETREG_DUMMY___77 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___77 = 0,
		RTNL_LINK_INITIALIZING___77 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___77 *);
	struct netpoll_info *npinfo;
	possible_net_t___77 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___249 dev;
	const struct attribute_group___256 *sysfs_groups[4];
	const struct attribute_group___256 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___71 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___77 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___71 xdp_state[3];
	long: 64;
};

struct neigh_table___64;

struct neigh_parms___64;

struct neigh_ops___64;

struct neighbour___64 {
	struct neighbour___64 *next;
	struct neigh_table___64 *tbl;
	struct neigh_parms___64 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___77 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___64 *, struct sk_buff___78 *);
	const struct neigh_ops___64 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___77 *dev;
	u8 primary_key[0];
};

struct rtable___14;

struct fnhe_hash_bucket___14;

struct fib_nh_common___14 {
	struct net_device___77 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___40 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___14 **nhc_pcpu_rth_output;
	struct rtable___14 *nhc_rth_input;
	struct fnhe_hash_bucket___14 *nhc_exceptions;
};

struct fib6_nh___14 {
	struct fib_nh_common___14 nh_common;
	long unsigned int last_probe;
	struct rt6_info___14 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___14;

struct nexthop___9;

struct fib6_info___14 {
	struct fib6_table___14 *fib6_table;
	struct fib6_info___14 *fib6_next;
	struct fib6_node___14 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___9 *nh;
	struct fib6_nh___14 fib6_nh[0];
};

struct rt6_info___14 {
	struct dst_entry___64 dst;
	struct fib6_info___14 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___46 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___14 {
	struct fib6_node___14 *parent;
	struct fib6_node___14 *left;
	struct fib6_node___14 *right;
	struct fib6_node___14 *subtree;
	struct fib6_info___14 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___14 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___14 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___14 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___9;

typedef unsigned int nf_hookfn___10(void *, struct sk_buff___78 *, const struct nf_hook_state___9 *);

struct nf_hook_entry___9 {
	nf_hookfn___10 *hook;
	void *priv;
};

struct nf_hook_entries___9 {
	u16 num_hook_entries;
	struct nf_hook_entry___9 hooks[0];
};

struct bpf_prog_array_item___71 {
	struct bpf_prog___71 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___71 {
	struct callback_head rcu;
	struct bpf_prog_array_item___71 items[0];
};

struct bpf_prog_aux___80;

struct bpf_prog___71 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___80 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___245;

struct fwnode_handle___245 {
	struct fwnode_handle___245 *secondary;
	const struct fwnode_operations___245 *ops;
	struct device___249 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___245;

struct fwnode_endpoint___245;

struct fwnode_operations___245 {
	struct fwnode_handle___245 * (*get)(struct fwnode_handle___245 *);
	void (*put)(struct fwnode_handle___245 *);
	bool (*device_is_available)(const struct fwnode_handle___245 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___245 *, const struct device___249 *);
	bool (*property_present)(const struct fwnode_handle___245 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___245 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___245 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___245 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*get_parent)(const struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*get_next_child_node)(const struct fwnode_handle___245 *, struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*get_named_child_node)(const struct fwnode_handle___245 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___245 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___245 *);
	struct fwnode_handle___245 * (*graph_get_next_endpoint)(const struct fwnode_handle___245 *, struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*graph_get_remote_endpoint)(const struct fwnode_handle___245 *);
	struct fwnode_handle___245 * (*graph_get_port_parent)(struct fwnode_handle___245 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___245 *, struct fwnode_endpoint___245 *);
	int (*add_links)(struct fwnode_handle___245 *);
};

struct fwnode_endpoint___245 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___245 *local_fwnode;
};

struct fwnode_reference_args___245 {
	struct fwnode_handle___245 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___195 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___195 *root_cset;
};

struct dev_pm_ops___249 {
	int (*prepare)(struct device___249 *);
	void (*complete)(struct device___249 *);
	int (*suspend)(struct device___249 *);
	int (*resume)(struct device___249 *);
	int (*freeze)(struct device___249 *);
	int (*thaw)(struct device___249 *);
	int (*poweroff)(struct device___249 *);
	int (*restore)(struct device___249 *);
	int (*suspend_late)(struct device___249 *);
	int (*resume_early)(struct device___249 *);
	int (*freeze_late)(struct device___249 *);
	int (*thaw_early)(struct device___249 *);
	int (*poweroff_late)(struct device___249 *);
	int (*restore_early)(struct device___249 *);
	int (*suspend_noirq)(struct device___249 *);
	int (*resume_noirq)(struct device___249 *);
	int (*freeze_noirq)(struct device___249 *);
	int (*thaw_noirq)(struct device___249 *);
	int (*poweroff_noirq)(struct device___249 *);
	int (*restore_noirq)(struct device___249 *);
	int (*runtime_suspend)(struct device___249 *);
	int (*runtime_resume)(struct device___249 *);
	int (*runtime_idle)(struct device___249 *);
};

struct wakeup_source___249 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___249 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___249 {
	struct dev_pm_ops___249 ops;
	int (*start)(struct device___249 *);
	void (*detach)(struct device___249 *, bool);
	int (*activate)(struct device___249 *);
	void (*sync)(struct device___249 *);
	void (*dismiss)(struct device___249 *);
};

struct bus_type___249 {
	const char *name;
	const char *dev_name;
	struct device___249 *dev_root;
	const struct attribute_group___256 **bus_groups;
	const struct attribute_group___256 **dev_groups;
	const struct attribute_group___256 **drv_groups;
	int (*match)(struct device___249 *, struct device_driver___249 *);
	int (*uevent)(struct device___249 *, struct kobj_uevent_env *);
	int (*probe)(struct device___249 *);
	void (*sync_state)(struct device___249 *);
	void (*remove)(struct device___249 *);
	void (*shutdown)(struct device___249 *);
	int (*online)(struct device___249 *);
	int (*offline)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	int (*num_vf)(struct device___249 *);
	int (*dma_configure)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___249 {
	const char *name;
	struct bus_type___249 *bus;
	struct module___252 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___249 *);
	void (*sync_state)(struct device___249 *);
	int (*remove)(struct device___249 *);
	void (*shutdown)(struct device___249 *);
	int (*suspend)(struct device___249 *, pm_message_t);
	int (*resume)(struct device___249 *);
	const struct attribute_group___256 **groups;
	const struct attribute_group___256 **dev_groups;
	const struct dev_pm_ops___249 *pm;
	void (*coredump)(struct device___249 *);
	struct driver_private *p;
};

struct device_type___249 {
	const char *name;
	const struct attribute_group___256 **groups;
	int (*uevent)(struct device___249 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___249 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___249 *);
	const struct dev_pm_ops___249 *pm;
};

struct class___249 {
	const char *name;
	struct module___252 *owner;
	const struct attribute_group___256 **class_groups;
	const struct attribute_group___256 **dev_groups;
	struct kobject___256 *dev_kobj;
	int (*dev_uevent)(struct device___249 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___249 *, umode_t *);
	void (*class_release)(struct class___249 *);
	void (*dev_release)(struct device___249 *);
	int (*shutdown_pre)(struct device___249 *);
	const struct kobj_ns_type_operations___64 *ns_type;
	const void * (*namespace)(struct device___249 *);
	void (*get_ownership)(struct device___249 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___249 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___109;

struct pipe_buffer___109 {
	struct page___273 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___109 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___109 {
	int (*confirm)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
	void (*release)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
	bool (*try_steal)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
	bool (*get)(struct pipe_inode_info___109 *, struct pipe_buffer___109 *);
};

typedef struct bio_vec___185 skb_frag_t___23;

struct skb_shared_info___22 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___78 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___23 frags[17];
};

struct seq_operations___243 {
	void * (*start)(struct seq_file___243 *, loff_t *);
	void (*stop)(struct seq_file___243 *, void *);
	void * (*next)(struct seq_file___243 *, void *, loff_t *);
	int (*show)(struct seq_file___243 *, void *);
};

struct dcbnl_rtnl_ops___77 {
	int (*ieee_getets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___77 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___77 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___77 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___77 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___77 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___77 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___77 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___77 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___77 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___77 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___77 *);
	u8 (*setstate)(struct net_device___77 *, u8);
	void (*getpermhwaddr)(struct net_device___77 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___77 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___77 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___77 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___77 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___77 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___77 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___77 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___77 *, int, u8 *);
	void (*setpfccfg)(struct net_device___77 *, int, u8);
	void (*getpfccfg)(struct net_device___77 *, int, u8 *);
	u8 (*setall)(struct net_device___77 *);
	u8 (*getcap)(struct net_device___77 *, int, u8 *);
	int (*getnumtcs)(struct net_device___77 *, int, u8 *);
	int (*setnumtcs)(struct net_device___77 *, int, u8);
	u8 (*getpfcstate)(struct net_device___77 *);
	void (*setpfcstate)(struct net_device___77 *, u8);
	void (*getbcncfg)(struct net_device___77 *, int, u32 *);
	void (*setbcncfg)(struct net_device___77 *, int, u32);
	void (*getbcnrp)(struct net_device___77 *, int, u8 *);
	void (*setbcnrp)(struct net_device___77 *, int, u8);
	int (*setapp)(struct net_device___77 *, u8, u16, u8);
	int (*getapp)(struct net_device___77 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___77 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___77 *, int, u8);
	u8 (*getdcbx)(struct net_device___77 *);
	u8 (*setdcbx)(struct net_device___77 *, u8);
	int (*peer_getappinfo)(struct net_device___77 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___77 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___77 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___77 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___77 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___77 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___80;

typedef int (*bpf_iter_init_seq_priv_t___79)(void *, struct bpf_iter_aux_info___80 *);

struct bpf_map___80;

struct bpf_iter_aux_info___80 {
	struct bpf_map___80 *map;
};

struct bpf_iter_seq_info___79 {
	const struct seq_operations___243 *seq_ops;
	bpf_iter_init_seq_priv_t___79 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___79 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___80 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___80 *, struct file___268 *);
	void (*map_free)(struct bpf_map___80 *);
	int (*map_get_next_key)(struct bpf_map___80 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___80 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___80 *, void *);
	int (*map_lookup_batch)(struct bpf_map___80 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___80 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___80 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___80 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___80 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___80 *, void *);
	int (*map_update_elem)(struct bpf_map___80 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___80 *, void *);
	int (*map_push_elem)(struct bpf_map___80 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___80 *, void *);
	int (*map_peek_elem)(struct bpf_map___80 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___80 *, struct file___268 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___80 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___80 *, void *, struct seq_file___243 *);
	int (*map_check_btf)(const struct bpf_map___80 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___80 *, struct bpf_prog_aux___80 *);
	void (*map_poke_untrack)(struct bpf_map___80 *, struct bpf_prog_aux___80 *);
	void (*map_poke_run)(struct bpf_map___80 *, u32, struct bpf_prog___71 *, struct bpf_prog___71 *);
	int (*map_direct_value_addr)(const struct bpf_map___80 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___80 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___80 *, struct vm_area_struct___273 *);
	__poll_t (*map_poll)(struct bpf_map___80 *, struct file___268 *, struct poll_table_struct___189 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___80 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___80 *, const struct bpf_map___80 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___80 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___79 *iter_seq_info;
};

struct bpf_map___80 {
	const struct bpf_map_ops___79 *ops;
	struct bpf_map___80 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___133 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___79;

struct bpf_jit_poke_descriptor___79;

struct bpf_prog_ops___71;

struct btf_mod_pair___79;

struct bpf_prog_offload___77;

struct bpf_prog_aux___80 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___71 *dst_prog;
	struct bpf_trampoline___79 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___71 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___79 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___71 *ops;
	struct bpf_map___80 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___79 *used_btfs;
	struct bpf_prog___71 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___80 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___77 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___77;

struct bpf_map_dev_ops___77 {
	int (*map_get_next_key)(struct bpf_offloaded_map___77 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___77 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___77 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___77 *, void *);
};

struct bpf_offloaded_map___77 {
	struct bpf_map___80 map;
	struct net_device___77 *netdev;
	const struct bpf_map_dev_ops___77 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___71 {
	int (*test_run)(struct bpf_prog___71 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___77 {
	struct bpf_prog___71 *prog;
	struct net_device___77 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___79 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___71 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___252 *mod;
};

struct bpf_jit_poke_descriptor___79 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___80 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___79 {
	struct btf *btf;
	struct module___252 *module;
};

struct cftype___195;

struct cgroup_subsys___195 {
	struct cgroup_subsys_state___195 * (*css_alloc)(struct cgroup_subsys_state___195 *);
	int (*css_online)(struct cgroup_subsys_state___195 *);
	void (*css_offline)(struct cgroup_subsys_state___195 *);
	void (*css_released)(struct cgroup_subsys_state___195 *);
	void (*css_free)(struct cgroup_subsys_state___195 *);
	void (*css_reset)(struct cgroup_subsys_state___195 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___195 *, int);
	int (*css_extra_stat_show)(struct seq_file___243 *, struct cgroup_subsys_state___195 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___275 *, struct css_set___195 *);
	void (*cancel_fork)(struct task_struct___275 *, struct css_set___195 *);
	void (*fork)(struct task_struct___275 *);
	void (*exit)(struct task_struct___275 *);
	void (*release)(struct task_struct___275 *);
	void (*bind)(struct cgroup_subsys_state___195 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___195 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___195 *dfl_cftypes;
	struct cftype___195 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___195 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___195 *updated_children;
	struct cgroup___195 *updated_next;
};

struct cgroup_root___195 {
	struct kernfs_root___256 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___195 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___195 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___195 *ss;
	struct list_head node;
	struct kernfs_ops___256 *kf_ops;
	int (*open)(struct kernfs_open_file___256 *);
	void (*release)(struct kernfs_open_file___256 *);
	u64 (*read_u64)(struct cgroup_subsys_state___195 *, struct cftype___195 *);
	s64 (*read_s64)(struct cgroup_subsys_state___195 *, struct cftype___195 *);
	int (*seq_show)(struct seq_file___243 *, void *);
	void * (*seq_start)(struct seq_file___243 *, loff_t *);
	void * (*seq_next)(struct seq_file___243 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___243 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___195 *, struct cftype___195 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___195 *, struct cftype___195 *, s64);
	ssize_t (*write)(struct kernfs_open_file___256 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___256 *, struct poll_table_struct___189 *);
};

struct xdp_rxq_info___77 {
	struct net_device___77 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___77 {
	struct net_device___77 *dev;
};

struct xdp_buff___77 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___77 *rxq;
	struct xdp_txq_info___77 *txq;
	u32 frame_sz;
};

struct xdp_frame___77 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___77 *dev_rx;
};

struct netlink_callback___77 {
	struct sk_buff___78 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___78 *, struct netlink_callback___77 *);
	int (*done)(struct netlink_callback___77 *);
	void *data;
	struct module___252 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___77 {
	int (*create)(struct sk_buff___78 *, struct net_device___77 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___78 *, unsigned char *);
	int (*cache)(const struct neighbour___64 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___77 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___78 *);
};

struct netdev_queue___77 {
	struct net_device___77 *dev;
	struct Qdisc___71 *qdisc;
	struct Qdisc___71 *qdisc_sleeping;
	struct kobject___256 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___77 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___71 {
	struct sk_buff___78 *head;
	struct sk_buff___78 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___71;

struct Qdisc___71 {
	int (*enqueue)(struct sk_buff___78 *, struct Qdisc___71 *, struct sk_buff___78 **);
	struct sk_buff___78 * (*dequeue)(struct Qdisc___71 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___71 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___77 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___77 gso_skb;
	struct qdisc_skb_head___71 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___71 *next_sched;
	struct sk_buff_head___77 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___77 {
	struct xdp_rxq_info___77 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___256 kobj;
	struct net_device___77 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___77 {
	enum net_device_path_type type;
	const struct net_device___77 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___77 = 0,
				DEV_PATH_BR_VLAN_TAG___77 = 1,
				DEV_PATH_BR_VLAN_UNTAG___77 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___77 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___77 {
	const struct net_device___77 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___77 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___71 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___77 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___77 {
	int (*xdo_dev_state_add)(struct xfrm_state___9 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___9 *);
	void (*xdo_dev_state_free)(struct xfrm_state___9 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___78 *, struct xfrm_state___9 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___9 *);
};

struct xfrm_state_offload___9 {
	struct net_device___77 *dev;
	struct net_device___77 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___9;

struct xfrm_type_offload___9;

struct xfrm_state___9 {
	possible_net_t___77 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___64 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___9 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___9 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___273 xfrag;
	const struct xfrm_type___9 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___9 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___77 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___77 *dev;
	const char *name;
};

struct net_device_ops___77 {
	int (*ndo_init)(struct net_device___77 *);
	void (*ndo_uninit)(struct net_device___77 *);
	int (*ndo_open)(struct net_device___77 *);
	int (*ndo_stop)(struct net_device___77 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___78 *, struct net_device___77 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___78 *, struct net_device___77 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___77 *, struct sk_buff___78 *, struct net_device___77 *);
	void (*ndo_change_rx_flags)(struct net_device___77 *, int);
	void (*ndo_set_rx_mode)(struct net_device___77 *);
	int (*ndo_set_mac_address)(struct net_device___77 *, void *);
	int (*ndo_validate_addr)(struct net_device___77 *);
	int (*ndo_do_ioctl)(struct net_device___77 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___77 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___77 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___77 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___77 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___77 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___77 *, int);
	int (*ndo_neigh_setup)(struct net_device___77 *, struct neigh_parms___64 *);
	void (*ndo_tx_timeout)(struct net_device___77 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___77 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___77 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___77 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___77 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___77 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___77 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___77 *);
	int (*ndo_netpoll_setup)(struct net_device___77 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___77 *);
	int (*ndo_set_vf_mac)(struct net_device___77 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___77 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___77 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___77 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___77 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___77 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___77 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___77 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___77 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___77 *, int, struct sk_buff___78 *);
	int (*ndo_get_vf_guid)(struct net_device___77 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___77 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___77 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___77 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___77 *);
	int (*ndo_fcoe_disable)(struct net_device___77 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___77 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___77 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___77 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___77 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___77 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___77 *, const struct sk_buff___78 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___77 *, struct net_device___77 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___77 *, struct net_device___77 *);
	struct net_device___77 * (*ndo_get_xmit_slave)(struct net_device___77 *, struct sk_buff___78 *, bool);
	struct net_device___77 * (*ndo_sk_get_lower_dev)(struct net_device___77 *, struct sock___64 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___77 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___77 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___77 *, struct neighbour___64 *);
	void (*ndo_neigh_destroy)(struct net_device___77 *, struct neighbour___64 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___78 *, struct netlink_callback___77 *, struct net_device___77 *, struct net_device___77 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___78 *, struct nlattr **, struct net_device___77 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___77 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___78 *, u32, u32, struct net_device___77 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___77 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___77 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___77 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___77 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___77 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___77 *, struct net_device___77 *);
	void (*ndo_dfwd_del_station)(struct net_device___77 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___77 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___77 *);
	int (*ndo_change_proto_down)(struct net_device___77 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___77 *, struct sk_buff___78 *);
	void (*ndo_set_rx_headroom)(struct net_device___77 *, int);
	int (*ndo_bpf)(struct net_device___77 *, struct netdev_bpf___77 *);
	int (*ndo_xdp_xmit)(struct net_device___77 *, int, struct xdp_frame___77 **, u32);
	struct net_device___77 * (*ndo_xdp_get_xmit_slave)(struct net_device___77 *, struct xdp_buff___77 *);
	int (*ndo_xsk_wakeup)(struct net_device___77 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___77 *);
	int (*ndo_tunnel_ctl)(struct net_device___77 *, struct ip_tunnel_parm *, int);
	struct net_device___77 * (*ndo_get_peer_dev)(struct net_device___77 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___77 *, struct net_device_path___77 *);
};

struct neigh_parms___64 {
	possible_net_t___77 net;
	struct net_device___77 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___64 *);
	struct neigh_table___64 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___64 {
	u32 (*l3mdev_fib_table)(const struct net_device___77 *);
	struct sk_buff___78 * (*l3mdev_l3_rcv)(struct net_device___77 *, struct sk_buff___78 *, u16);
	struct sk_buff___78 * (*l3mdev_l3_out)(struct net_device___77 *, struct sock___64 *, struct sk_buff___78 *, u16);
	struct dst_entry___64 * (*l3mdev_link_scope_lookup)(const struct net_device___77 *, struct flowi6 *);
};

struct ndisc_ops___46 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___77 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___77 *, struct neighbour___64 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___77 *, u8, struct neighbour___64 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___77 *, struct sk_buff___78 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___82 *, struct net_device___77 *, const struct prefix_info *, struct inet6_dev___46 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___9;

struct in_device___9 {
	struct net_device___77 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___9 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___64 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___46;

struct ifacaddr6___14;

struct inet6_dev___46 {
	struct net_device___77 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___46 *mc_list;
	struct ifmcaddr6___46 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___77 mc_query_queue;
	struct sk_buff_head___77 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___14 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___64 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___71;

struct tcf_block___71;

struct mini_Qdisc___71 {
	struct tcf_proto___71 *filter_list;
	struct tcf_block___71 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___71 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___77 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___77 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___82 *, struct net_device___77 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___77 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___77 *, struct list_head *);
	size_t (*get_size)(const struct net_device___77 *);
	int (*fill_info)(struct sk_buff___78 *, const struct net_device___77 *);
	size_t (*get_xstats_size)(const struct net_device___77 *);
	int (*fill_xstats)(struct sk_buff___78 *, const struct net_device___77 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___77 *, struct net_device___77 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___77 *, const struct net_device___77 *);
	int (*fill_slave_info)(struct sk_buff___78 *, const struct net_device___77 *, const struct net_device___77 *);
	struct net___82 * (*get_link_net)(const struct net_device___77 *);
	size_t (*get_linkxstats_size)(const struct net_device___77 *, int);
	int (*fill_linkxstats)(struct sk_buff___78 *, const struct net_device___77 *, int *, int);
};

struct packet_type___4 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___77 *dev;
	int (*func)(struct sk_buff___78 *, struct net_device___77 *, struct packet_type___4 *, struct net_device___77 *);
	void (*list_func)(struct list_head *, struct packet_type___4 *, struct net_device___77 *);
	bool (*id_match)(struct packet_type___4 *, struct sock___64 *);
	struct net___82 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct in_ifaddr___9 {
	struct hlist_node hash;
	struct in_ifaddr___9 *ifa_next;
	struct in_device___9 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct block_device_operations___159;

struct gendisk___162 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___162 *part0;
	const struct block_device_operations___159 *fops;
	struct request_queue___159 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___145 *bdi;
	struct kobject___256 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___256 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___159 {
	struct bio___159 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___185 *bip_vec;
	struct bio_vec___185 bip_inline_vecs[0];
};

struct blkcg___147;

struct blkg_policy_data___147;

struct blkcg_gq___147 {
	struct request_queue___159 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___147 *blkcg;
	struct blkcg_gq___147 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___147 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___159 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___159(struct request___159 *);

typedef void integrity_complete_fn___159(struct request___159 *, unsigned int);

struct blk_integrity_profile___159 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___159 *prepare_fn;
	integrity_complete_fn___159 *complete_fn;
	const char *name;
};

struct block_device_operations___159 {
	blk_qc_t (*submit_bio)(struct bio___159 *);
	int (*open)(struct block_device___162 *, fmode_t);
	void (*release)(struct gendisk___162 *, fmode_t);
	int (*rw_page)(struct block_device___162 *, sector_t, struct page___273 *, unsigned int);
	int (*ioctl)(struct block_device___162 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___162 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___162 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___162 *);
	int (*getgeo)(struct block_device___162 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___162 *, bool);
	void (*swap_slot_free_notify)(struct block_device___162 *, long unsigned int);
	int (*report_zones)(struct gendisk___162 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___162 *, umode_t *);
	struct module___252 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___162 *, sector_t *);
};

typedef void rq_end_io_fn___159(struct request___159 *, blk_status_t);

struct request___159 {
	struct request_queue___159 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___154 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___159 *bio;
	struct bio___159 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___185 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___159 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___159 *saved_end_io;
		} flush;
	};
	struct gendisk___162 *rq_disk;
	struct block_device___162 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___159 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___154 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___159 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___256 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___268 *debugfs_dir;
	struct dentry___268 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___159;

struct elevator_mq_ops___159 {
	int (*init_sched)(struct request_queue___159 *, struct elevator_type___159 *);
	void (*exit_sched)(struct elevator_queue___159 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___154 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___154 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___154 *);
	bool (*allow_merge)(struct request_queue___159 *, struct request___159 *, struct bio___159 *);
	bool (*bio_merge)(struct request_queue___159 *, struct bio___159 *, unsigned int);
	int (*request_merge)(struct request_queue___159 *, struct request___159 **, struct bio___159 *);
	void (*request_merged)(struct request_queue___159 *, struct request___159 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___159 *, struct request___159 *, struct request___159 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___159 *);
	void (*finish_request)(struct request___159 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___154 *, struct list_head *, bool);
	struct request___159 * (*dispatch_request)(struct blk_mq_hw_ctx___154 *);
	bool (*has_work)(struct blk_mq_hw_ctx___154 *);
	void (*completed_request)(struct request___159 *, u64);
	void (*requeue_request)(struct request___159 *);
	struct request___159 * (*former_request)(struct request_queue___159 *, struct request___159 *);
	struct request___159 * (*next_request)(struct request_queue___159 *, struct request___159 *);
	void (*init_icq)(struct io_cq___159 *);
	void (*exit_icq)(struct io_cq___159 *);
};

struct elv_fs_entry___159;

struct elevator_type___159 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___159 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___159 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___252 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___159 {
	struct elevator_type___159 *type;
	void *elevator_data;
	struct kobject___256 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___159 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___159 *, char *);
	ssize_t (*store)(struct elevator_queue___159 *, const char *, size_t);
};

struct blk_mq_queue_data___154;

struct blk_mq_ops___154 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___154 *, const struct blk_mq_queue_data___154 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___154 *);
	int (*get_budget)(struct request_queue___159 *);
	void (*put_budget)(struct request_queue___159 *, int);
	void (*set_rq_budget_token)(struct request___159 *, int);
	int (*get_rq_budget_token)(struct request___159 *);
	enum blk_eh_timer_return (*timeout)(struct request___159 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___154 *);
	void (*complete)(struct request___159 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___154 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___154 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___154 *, struct request___159 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___154 *, struct request___159 *, unsigned int);
	void (*initialize_rq_fn)(struct request___159 *);
	void (*cleanup_rq)(struct request___159 *);
	bool (*busy)(struct request_queue___159 *);
	int (*map_queues)(struct blk_mq_tag_set___154 *);
	void (*show_rq)(struct seq_file___243 *, struct request___159 *);
};

struct blk_mq_tag_set___154 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___154 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___154 {
	struct request___159 *rq;
	bool last;
};

struct blkcg_policy_data___147;

struct blkcg___147 {
	struct cgroup_subsys_state___195 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___147 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___147 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___147 {
	struct blkcg___147 *blkcg;
	int plid;
};

struct blkg_policy_data___147 {
	struct blkcg_gq___147 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___133 {
	struct mem_cgroup___133 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___133 {
	struct lruvec___141 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___133 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___133 *memcg;
};

struct obj_cgroup___133 {
	struct percpu_ref refcnt;
	struct mem_cgroup___133 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___71 {
	spinlock_t *lock;
	struct sk_buff___78 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___71;

struct Qdisc_ops___71 {
	struct Qdisc_ops___71 *next;
	const struct Qdisc_class_ops___71 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___78 *, struct Qdisc___71 *, struct sk_buff___78 **);
	struct sk_buff___78 * (*dequeue)(struct Qdisc___71 *);
	struct sk_buff___78 * (*peek)(struct Qdisc___71 *);
	int (*init)(struct Qdisc___71 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___71 *);
	void (*destroy)(struct Qdisc___71 *);
	int (*change)(struct Qdisc___71 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___71 *);
	int (*change_tx_queue_len)(struct Qdisc___71 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___71 *, unsigned int);
	int (*dump)(struct Qdisc___71 *, struct sk_buff___78 *);
	int (*dump_stats)(struct Qdisc___71 *, struct gnet_dump___71 *);
	void (*ingress_block_set)(struct Qdisc___71 *, u32);
	void (*egress_block_set)(struct Qdisc___71 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___71 *);
	u32 (*egress_block_get)(struct Qdisc___71 *);
	struct module___252 *owner;
};

struct Qdisc_class_ops___71 {
	unsigned int flags;
	struct netdev_queue___77 * (*select_queue)(struct Qdisc___71 *, struct tcmsg *);
	int (*graft)(struct Qdisc___71 *, long unsigned int, struct Qdisc___71 *, struct Qdisc___71 **, struct netlink_ext_ack *);
	struct Qdisc___71 * (*leaf)(struct Qdisc___71 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___71 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___71 *, u32);
	int (*change)(struct Qdisc___71 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___71 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___71 *, struct qdisc_walker *);
	struct tcf_block___71 * (*tcf_block)(struct Qdisc___71 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___71 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___71 *, long unsigned int);
	int (*dump)(struct Qdisc___71 *, long unsigned int, struct sk_buff___78 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___71 *, long unsigned int, struct gnet_dump___71 *);
};

struct tcf_chain___71;

struct tcf_block___71 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___82 *net;
	struct Qdisc___71 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___71 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___71;

struct tcf_proto_ops___71;

struct tcf_proto___71 {
	struct tcf_proto___71 *next;
	void *root;
	int (*classify)(struct sk_buff___78 *, const struct tcf_proto___71 *, struct tcf_result___71 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___71 *ops;
	struct tcf_chain___71 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___71 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___71 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___71 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___78 *, const struct tcf_proto___71 *, struct tcf_result___71 *);
	int (*init)(struct tcf_proto___71 *);
	void (*destroy)(struct tcf_proto___71 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___71 *, u32);
	void (*put)(struct tcf_proto___71 *, void *);
	int (*change)(struct net___82 *, struct sk_buff___78 *, struct tcf_proto___71 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___71 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___71 *);
	void (*walk)(struct tcf_proto___71 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___71 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___71 *, void *);
	void (*hw_del)(struct tcf_proto___71 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___82 *, struct tcf_chain___71 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___82 *, struct tcf_proto___71 *, void *, struct sk_buff___78 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___82 *, struct tcf_proto___71 *, void *, struct sk_buff___78 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___78 *, struct net___82 *, void *);
	struct module___252 *owner;
	int flags;
};

struct tcf_chain___71 {
	struct mutex filter_chain_lock;
	struct tcf_proto___71 *filter_chain;
	struct list_head list;
	struct tcf_block___71 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___71 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___64 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___71 *prog;
};

struct pneigh_entry___64;

struct neigh_hash_table___64;

struct neigh_table___64 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___77 *, __u32 *);
	bool (*key_eq)(const struct neighbour___64 *, const void *);
	int (*constructor)(struct neighbour___64 *);
	int (*pconstructor)(struct pneigh_entry___64 *);
	void (*pdestructor)(struct pneigh_entry___64 *);
	void (*proxy_redo)(struct sk_buff___78 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___77 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___64 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___77 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___64 *nht;
	struct pneigh_entry___64 **phash_buckets;
};

struct neigh_ops___64 {
	int family;
	void (*solicit)(struct neighbour___64 *, struct sk_buff___78 *);
	void (*error_report)(struct neighbour___64 *, struct sk_buff___78 *);
	int (*output)(struct neighbour___64 *, struct sk_buff___78 *);
	int (*connected_output)(struct neighbour___64 *, struct sk_buff___78 *);
};

struct pneigh_entry___64 {
	struct pneigh_entry___64 *next;
	possible_net_t___77 net;
	struct net_device___77 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___64 {
	struct neighbour___64 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___40 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___82 *, struct sock___64 *, struct sk_buff___78 *);
	int (*orig_input)(struct sk_buff___78 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___64 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___64 *ctarget;
	struct net___82 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___64 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___64 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___49;

struct timewait_sock_ops___48;

struct proto___64 {
	void (*close)(struct sock___64 *, long int);
	int (*pre_connect)(struct sock___64 *, struct sockaddr *, int);
	int (*connect)(struct sock___64 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___64 *, int);
	struct sock___64 * (*accept)(struct sock___64 *, int, int *, bool);
	int (*ioctl)(struct sock___64 *, int, long unsigned int);
	int (*init)(struct sock___64 *);
	void (*destroy)(struct sock___64 *);
	void (*shutdown)(struct sock___64 *, int);
	int (*setsockopt)(struct sock___64 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___64 *, int, int, char *, int *);
	void (*keepalive)(struct sock___64 *, int);
	int (*compat_ioctl)(struct sock___64 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___64 *, struct msghdr___66 *, size_t);
	int (*recvmsg)(struct sock___64 *, struct msghdr___66 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___64 *, struct page___273 *, int, size_t, int);
	int (*bind)(struct sock___64 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___64 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___64 *, struct sk_buff___78 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___64 *);
	int (*hash)(struct sock___64 *);
	void (*unhash)(struct sock___64 *);
	void (*rehash)(struct sock___64 *);
	int (*get_port)(struct sock___64 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___64 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___64 *, int);
	bool (*sock_is_readable)(struct sock___64 *);
	void (*enter_memory_pressure)(struct sock___64 *);
	void (*leave_memory_pressure)(struct sock___64 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___49 *rsk_prot;
	struct timewait_sock_ops___48 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___252 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___64 *, int);
};

struct xfrm_policy_queue___9 {
	struct sk_buff_head___77 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___9 {
	possible_net_t___77 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___9 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct raw_hashinfo {
	rwlock_t lock;
	struct hlist_head ht[256];
};

struct request_sock___50;

struct request_sock_ops___49 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___64 *, struct request_sock___50 *);
	void (*send_ack)(const struct sock___64 *, struct sk_buff___78 *, struct request_sock___50 *);
	void (*send_reset)(const struct sock___64 *, struct sk_buff___78 *);
	void (*destructor)(struct request_sock___50 *);
	void (*syn_ack_timeout)(const struct request_sock___50 *);
};

struct timewait_sock_ops___48 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___64 *, struct sock___64 *, void *);
	void (*twsk_destructor)(struct sock___64 *);
};

struct request_sock___50 {
	struct sock_common___64 __req_common;
	struct request_sock___50 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___49 *rsk_ops;
	struct sock___64 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___6 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___64 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___6 {
	struct inet_cork___6 base;
	struct flowi fl;
};

struct ipv6_pinfo___6;

struct inet_sock___6 {
	struct sock___64 sk;
	struct ipv6_pinfo___6 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___6 cork;
};

struct ipv6_fl_socklist___6;

struct ipv6_pinfo___6 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___6 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___78 *pktoptions;
	struct sk_buff___78 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___6;

struct ipv6_fl_socklist___6 {
	struct ipv6_fl_socklist___6 *next;
	struct ip6_flowlabel___6 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___46 {
	struct in6_addr mca_addr;
	struct inet6_dev___46 *idev;
	struct ifmcaddr6___46 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___14 {
	struct in6_addr aca_addr;
	struct fib6_info___14 *aca_rt;
	struct ifacaddr6___14 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___6 {
	struct ip6_flowlabel___6 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___245 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___82 *fl_net;
};

struct fib_nh_exception___14 {
	struct fib_nh_exception___14 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___14 *fnhe_rth_input;
	struct rtable___14 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___14 {
	struct dst_entry___64 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___14 {
	struct fib_nh_exception___14 *chain;
};

struct fib_info___9;

struct fib_nh___9 {
	struct fib_nh_common___14 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___9 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___9 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___82 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___9 *nh;
	struct callback_head rcu;
	struct fib_nh___9 fib_nh[0];
};

struct nh_info___9;

struct nh_group___9;

struct nexthop___9 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___82 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___9 *nh_info;
		struct nh_group___9 *nh_grp;
	};
};

enum ip_defrag_users {
	IP_DEFRAG_LOCAL_DELIVER = 0,
	IP_DEFRAG_CALL_RA_CHAIN = 1,
	IP_DEFRAG_CONNTRACK_IN = 2,
	__IP_DEFRAG_CONNTRACK_IN_END = 65537,
	IP_DEFRAG_CONNTRACK_OUT = 65538,
	__IP_DEFRAG_CONNTRACK_OUT_END = 131073,
	IP_DEFRAG_CONNTRACK_BRIDGE_IN = 131074,
	__IP_DEFRAG_CONNTRACK_BRIDGE_IN = 196609,
	IP_DEFRAG_VS_IN = 196610,
	IP_DEFRAG_VS_OUT = 196611,
	IP_DEFRAG_VS_FWD = 196612,
	IP_DEFRAG_AF_PACKET = 196613,
	IP_DEFRAG_MACVLAN = 196614,
};

struct net_protocol___3 {
	int (*early_demux)(struct sk_buff___78 *);
	int (*early_demux_handler)(struct sk_buff___78 *);
	int (*handler)(struct sk_buff___78 *);
	int (*err_handler)(struct sk_buff___78 *, u32);
	unsigned int no_policy: 1;
	unsigned int icmp_strict_tag_validation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct nf_hook_state___9 {
	u8 hook;
	u8 pf;
	struct net_device___77 *in;
	struct net_device___77 *out;
	struct sock___64 *sk;
	struct net___82 *net;
	int (*okfn)(struct net___82 *, struct sock___64 *, struct sk_buff___78 *);
};

struct xfrm_type___9 {
	struct module___252 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___9 *);
	void (*destructor)(struct xfrm_state___9 *);
	int (*input)(struct xfrm_state___9 *, struct sk_buff___78 *);
	int (*output)(struct xfrm_state___9 *, struct sk_buff___78 *);
	int (*reject)(struct xfrm_state___9 *, struct sk_buff___78 *, const struct flowi *);
};

struct xfrm_type_offload___9 {
	struct module___252 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___9 *, struct sk_buff___78 *);
	int (*input_tail)(struct xfrm_state___9 *, struct sk_buff___78 *);
	int (*xmit)(struct xfrm_state___9 *, struct sk_buff___78 *, netdev_features_t);
};

struct nh_info___9 {
	struct hlist_node dev_hash;
	struct nexthop___9 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___14 fib_nhc;
		struct fib_nh___9 fib_nh;
		struct fib6_nh___14 fib6_nh;
	};
};

struct nh_grp_entry___9;

struct nh_res_bucket___9 {
	struct nh_grp_entry___9 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___9 {
	struct nexthop___9 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___9 *nh_parent;
};

struct nh_res_table___9 {
	struct net___82 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___9 nh_buckets[0];
};

struct nh_group___9 {
	struct nh_group___9 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___9 *res_table;
	struct nh_grp_entry___9 nh_entries[0];
};

enum {
	INET_FRAG_FIRST_IN = 1,
	INET_FRAG_LAST_IN = 2,
	INET_FRAG_COMPLETE = 4,
	INET_FRAG_HASH_DEAD = 8,
};

struct ipq {
	struct inet_frag_queue___29 q;
	u8 ecn;
	u16 max_df_size;
	int iif;
	unsigned int rid;
	struct inet_peer *peer;
};

struct dentry___269;

struct super_block___269;

struct module___253;

struct file_system_type___269 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___269 * (*mount)(struct file_system_type___269 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___269 *);
	struct module___253 *owner;
	struct file_system_type___269 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___269;

struct kiocb___269;

struct iov_iter___189;

struct poll_table_struct___190;

struct vm_area_struct___274;

struct inode___269;

struct file_lock___269;

struct page___274;

struct pipe_inode_info___110;

struct seq_file___244;

struct file_operations___270 {
	struct module___253 *owner;
	loff_t (*llseek)(struct file___269 *, loff_t, int);
	ssize_t (*read)(struct file___269 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___269 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___269 *, struct iov_iter___189 *);
	ssize_t (*write_iter)(struct kiocb___269 *, struct iov_iter___189 *);
	int (*iopoll)(struct kiocb___269 *, bool);
	int (*iterate)(struct file___269 *, struct dir_context *);
	int (*iterate_shared)(struct file___269 *, struct dir_context *);
	__poll_t (*poll)(struct file___269 *, struct poll_table_struct___190 *);
	long int (*unlocked_ioctl)(struct file___269 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___269 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___269 *, struct vm_area_struct___274 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___269 *, struct file___269 *);
	int (*flush)(struct file___269 *, fl_owner_t);
	int (*release)(struct inode___269 *, struct file___269 *);
	int (*fsync)(struct file___269 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___269 *, int);
	int (*lock)(struct file___269 *, int, struct file_lock___269 *);
	ssize_t (*sendpage)(struct file___269 *, struct page___274 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___269 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___269 *, long unsigned int);
	int (*flock)(struct file___269 *, int, struct file_lock___269 *);
	ssize_t (*splice_write)(struct pipe_inode_info___110 *, struct file___269 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___269 *, loff_t *, struct pipe_inode_info___110 *, size_t, unsigned int);
	int (*setlease)(struct file___269 *, long int, struct file_lock___269 **, void **);
	long int (*fallocate)(struct file___269 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___244 *, struct file___269 *);
	ssize_t (*copy_file_range)(struct file___269 *, loff_t, struct file___269 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___269 *, loff_t, struct file___269 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___269 *, loff_t, loff_t, int);
};

struct vmacache___274 {
	u64 seqnum;
	struct vm_area_struct___274 *vmas[4];
};

struct page_frag___274 {
	struct page___274 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___275;

struct pid___246;

struct nsproxy___255;

struct signal_struct___270;

struct bio_list___160;

struct backing_dev_info___146;

struct io_context___160;

struct css_set___196;

struct mem_cgroup___134;

struct request_queue___160;

struct vm_struct___252;

struct task_struct___276 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___276 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___275 *mm;
	struct mm_struct___275 *active_mm;
	struct vmacache___274 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___276 *real_parent;
	struct task_struct___276 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___276 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___246 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___255 *nsproxy;
	struct signal_struct___270 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___276 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___160 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___146 *backing_dev_info;
	struct io_context___160 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___196 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___110 *splice_pipe;
	struct page_frag___274 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___134 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___134 *active_memcg;
	struct request_queue___160 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___276 *oom_reaper_list;
	struct vm_struct___252 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___257;

struct kobj_type___257;

struct kernfs_node___257;

struct kobject___257 {
	const char *name;
	struct list_head entry;
	struct kobject___257 *parent;
	struct kset___257 *kset;
	struct kobj_type___257 *ktype;
	struct kernfs_node___257 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___254 {
	struct kobject___257 kobj;
	struct module___253 *mod;
	struct kobject___257 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___253 {
	struct module___253 *mod;
	struct latch_tree_node node;
};

struct module_layout___253 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___253 mtn;
};

struct module_attribute___253;

struct kernel_param___253;

struct module___253 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___254 mkobj;
	struct module_attribute___253 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___257 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___253 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___253 core_layout;
	struct module_layout___253 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___274 *pgtable_t___274;

struct address_space___269;

struct page_pool___98;

struct dev_pagemap___264;

struct page___274 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___269 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___98 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___274 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___274 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___275 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___264 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___264;

struct vm_area_struct___274 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___274 *vm_next;
	struct vm_area_struct___274 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___275 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___264 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___269 *vm_file;
	struct file___269 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___274;

struct mm_struct___275 {
	struct {
		struct vm_area_struct___274 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___269 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___274 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___276 *owner;
		struct user_namespace___26 *user_ns;
		struct file___269 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___269;

struct address_space___269 {
	struct inode___269 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___269 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___250;

struct page_pool_params___98 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___250 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___98 {
	u32 count;
	struct page___274 *cache[128];
};

struct page_pool___98 {
	struct page_pool_params___98 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___274 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___98 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___264;

struct dev_pagemap___264 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___264 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___269;

struct path___269 {
	struct vfsmount___269 *mnt;
	struct dentry___269 *dentry;
};

struct fown_struct___246 {
	rwlock_t lock;
	struct pid___246 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___269 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___269 f_path;
	struct inode___269 *f_inode;
	const struct file_operations___270 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___246 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___269 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___264;

struct vm_operations_struct___264 {
	void (*open)(struct vm_area_struct___274 *);
	void (*close)(struct vm_area_struct___274 *);
	int (*may_split)(struct vm_area_struct___274 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___274 *);
	int (*mprotect)(struct vm_area_struct___274 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___264 *);
	vm_fault_t (*huge_fault)(struct vm_fault___264 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___264 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___274 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___264 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___264 *);
	int (*access)(struct vm_area_struct___274 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___274 *);
	int (*set_policy)(struct vm_area_struct___274 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___274 *, long unsigned int);
	struct page___274 * (*find_special_page)(struct vm_area_struct___274 *, long unsigned int);
};

struct core_thread___274 {
	struct task_struct___276 *task;
	struct core_thread___274 *next;
};

struct core_state___274 {
	atomic_t nr_threads;
	struct core_thread___274 dumper;
	struct completion startup;
};

struct vm_fault___264 {
	const struct {
		struct vm_area_struct___274 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___274 *cow_page;
	struct page___274 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___274 prealloc_pte;
};

struct pglist_data___142;

struct lruvec___142 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___142 *pgdat;
};

struct zone___142 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___142 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___142 {
	struct zone___142 *zone;
	int zone_idx;
};

struct zonelist___142 {
	struct zoneref___142 _zonerefs[321];
};

struct pglist_data___142 {
	struct zone___142 node_zones[5];
	struct zonelist___142 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___276 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___276 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___142 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___134 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___134 *memcg;
};

struct cgroup___196;

struct cgroup_subsys___196;

struct cgroup_subsys_state___196 {
	struct cgroup___196 *cgroup;
	struct cgroup_subsys___196 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___196 *parent;
};

struct cgroup_file___196 {
	struct kernfs_node___257 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___134;

struct mem_cgroup_per_node___134;

struct mem_cgroup___134 {
	struct cgroup_subsys_state___196 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___196 events_file;
	struct cgroup_file___196 events_local_file;
	struct cgroup_file___196 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___134 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___276 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___134 *nodeinfo[0];
	long: 64;
};

struct shrinker___134 {
	long unsigned int (*count_objects)(struct shrinker___134 *, struct shrink_control___134 *);
	long unsigned int (*scan_objects)(struct shrinker___134 *, struct shrink_control___134 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___264 {
	void (*page_free)(struct page___274 *);
	void (*kill)(struct dev_pagemap___264 *);
	void (*cleanup)(struct dev_pagemap___264 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___264 *);
};

struct pid_namespace___246;

struct upid___246 {
	int nr;
	struct pid_namespace___246 *ns;
};

struct pid_namespace___246 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___276 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___246 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___246 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___246 numbers[1];
};

struct signal_struct___270 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___276 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___276 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___246 *pids[4];
	struct pid___246 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___275 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___83;

struct cgroup_namespace___196;

struct nsproxy___255 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___246 *pid_ns_for_children;
	struct net___83 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___196 *cgroup_ns;
};

struct bio___160;

struct bio_list___160 {
	struct bio___160 *head;
	struct bio___160 *tail;
};

struct bdi_writeback___146 {
	struct backing_dev_info___146 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___196 *memcg_css;
	struct cgroup_subsys_state___196 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___146 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___146 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___250 *dev;
	char dev_name[64];
	struct device___250 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___269 *debug_dir;
};

struct io_cq___160;

struct io_context___160 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___160 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___196 {
	struct cgroup_subsys_state___196 *subsys[14];
	refcount_t refcount;
	struct css_set___196 *dom_cset;
	struct cgroup___196 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___196 *mg_src_cgrp;
	struct cgroup___196 *mg_dst_cgrp;
	struct css_set___196 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___269;

struct pipe_buffer___110;

struct pipe_inode_info___110 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___274 *tmp_page;
	struct fasync_struct___269 *fasync_readers;
	struct fasync_struct___269 *fasync_writers;
	struct pipe_buffer___110 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___160;

struct blk_integrity___160 {
	const struct blk_integrity_profile___160 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___160 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___160 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___160;

struct elevator_queue___160;

struct blk_mq_ops___155;

struct blk_mq_hw_ctx___155;

struct gendisk___163;

struct blkcg_gq___148;

struct blk_mq_tag_set___155;

struct request_queue___160 {
	struct request___160 *last_merge;
	struct elevator_queue___160 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___155 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___155 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___163 *disk;
	struct kobject___257 kobj;
	struct kobject___257 *mq_kobj;
	struct blk_integrity___160 integrity;
	struct device___250 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___148 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___155 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___160 bio_split;
	struct dentry___269 *debugfs_dir;
	struct dentry___269 *sched_debugfs_dir;
	struct dentry___269 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___252 {
	struct vm_struct___252 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___274 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___269;

struct dentry___269 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___269 *d_parent;
	struct qstr d_name;
	struct inode___269 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___269 *d_op;
	struct super_block___269 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___269;

struct inode___269 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___269 *i_op;
	struct super_block___269 *i_sb;
	struct address_space___269 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___146 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___270 *i_fop;
		void (*free_inode)(struct inode___269 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___269 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___110 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___269 {
	int (*d_revalidate)(struct dentry___269 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___269 *, unsigned int);
	int (*d_hash)(const struct dentry___269 *, struct qstr *);
	int (*d_compare)(const struct dentry___269 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___269 *);
	int (*d_init)(struct dentry___269 *);
	void (*d_release)(struct dentry___269 *);
	void (*d_prune)(struct dentry___269 *);
	void (*d_iput)(struct dentry___269 *, struct inode___269 *);
	char * (*d_dname)(struct dentry___269 *, char *, int);
	struct vfsmount___269 * (*d_automount)(struct path___269 *);
	int (*d_manage)(const struct path___269 *, bool);
	struct dentry___269 * (*d_real)(struct dentry___269 *, const struct inode___269 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___269;

struct mem_dqinfo___269 {
	struct quota_format_type___269 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___269;

struct quota_info___269 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___269 *files[3];
	struct mem_dqinfo___269 info[3];
	const struct quota_format_ops___269 *ops[3];
};

struct rcuwait___270 {
	struct task_struct___276 *task;
};

struct percpu_rw_semaphore___270 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___270 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___269 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___270 rw_sem[3];
};

struct super_operations___269;

struct dquot_operations___269;

struct quotactl_ops___269;

struct block_device___163;

struct super_block___269 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___269 *s_type;
	const struct super_operations___269 *s_op;
	const struct dquot_operations___269 *dq_op;
	const struct quotactl_ops___269 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___269 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___163 *s_bdev;
	struct backing_dev_info___146 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___269 s_dquot;
	struct sb_writers___269 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___269 *s_d_op;
	int cleancache_poolid;
	struct shrinker___134 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___269 {
	struct dentry___269 *mnt_root;
	struct super_block___269 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___196 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___276 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___72;

struct cgroup_bpf___72 {
	struct bpf_prog_array___72 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___72 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___196;

struct cgroup_rstat_cpu___196;

struct cgroup___196 {
	struct cgroup_subsys_state___196 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___257 *kn;
	struct cgroup_file___196 procs_file;
	struct cgroup_file___196 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___196 *subsys[14];
	struct cgroup_root___196 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___196 *dom_cgrp;
	struct cgroup___196 *old_dom_cgrp;
	struct cgroup_rstat_cpu___196 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___196 psi;
	struct cgroup_bpf___72 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___160 {
	struct request_queue___160 *q;
	struct io_context___160 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___269 {
	struct file___269 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___269 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___114 *ki_waitq;
	};
};

struct iattr___269 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___269 *ia_file;
};

struct dquot___269 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___269 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___269 {
	int qf_fmt_id;
	const struct quota_format_ops___269 *qf_ops;
	struct module___253 *qf_owner;
	struct quota_format_type___269 *qf_next;
};

struct quota_format_ops___269 {
	int (*check_quota_file)(struct super_block___269 *, int);
	int (*read_file_info)(struct super_block___269 *, int);
	int (*write_file_info)(struct super_block___269 *, int);
	int (*free_file_info)(struct super_block___269 *, int);
	int (*read_dqblk)(struct dquot___269 *);
	int (*commit_dqblk)(struct dquot___269 *);
	int (*release_dqblk)(struct dquot___269 *);
	int (*get_next_id)(struct super_block___269 *, struct kqid *);
};

struct dquot_operations___269 {
	int (*write_dquot)(struct dquot___269 *);
	struct dquot___269 * (*alloc_dquot)(struct super_block___269 *, int);
	void (*destroy_dquot)(struct dquot___269 *);
	int (*acquire_dquot)(struct dquot___269 *);
	int (*release_dquot)(struct dquot___269 *);
	int (*mark_dirty)(struct dquot___269 *);
	int (*write_info)(struct super_block___269 *, int);
	qsize_t * (*get_reserved_space)(struct inode___269 *);
	int (*get_projid)(struct inode___269 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___269 *, qsize_t *);
	int (*get_next_id)(struct super_block___269 *, struct kqid *);
};

struct quotactl_ops___269 {
	int (*quota_on)(struct super_block___269 *, int, int, const struct path___269 *);
	int (*quota_off)(struct super_block___269 *, int);
	int (*quota_enable)(struct super_block___269 *, unsigned int);
	int (*quota_disable)(struct super_block___269 *, unsigned int);
	int (*quota_sync)(struct super_block___269 *, int);
	int (*set_info)(struct super_block___269 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___269 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___269 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___269 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___269 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___269 *, unsigned int);
};

struct writeback_control___146;

struct address_space_operations___269 {
	int (*writepage)(struct page___274 *, struct writeback_control___146 *);
	int (*readpage)(struct file___269 *, struct page___274 *);
	int (*writepages)(struct address_space___269 *, struct writeback_control___146 *);
	int (*set_page_dirty)(struct page___274 *);
	int (*readpages)(struct file___269 *, struct address_space___269 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___269 *, struct address_space___269 *, loff_t, unsigned int, unsigned int, struct page___274 **, void **);
	int (*write_end)(struct file___269 *, struct address_space___269 *, loff_t, unsigned int, unsigned int, struct page___274 *, void *);
	sector_t (*bmap)(struct address_space___269 *, sector_t);
	void (*invalidatepage)(struct page___274 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___274 *, gfp_t);
	void (*freepage)(struct page___274 *);
	ssize_t (*direct_IO)(struct kiocb___269 *, struct iov_iter___189 *);
	int (*migratepage)(struct address_space___269 *, struct page___274 *, struct page___274 *, enum migrate_mode);
	bool (*isolate_page)(struct page___274 *, isolate_mode_t);
	void (*putback_page)(struct page___274 *);
	int (*launder_page)(struct page___274 *);
	int (*is_partially_uptodate)(struct page___274 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___274 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___269 *, struct page___274 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___269 *, sector_t *);
	void (*swap_deactivate)(struct file___269 *);
};

struct writeback_control___146 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___146 *wb;
	struct inode___269 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___186;

struct iov_iter___189 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___186 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___110 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___269 {
	struct dentry___269 * (*lookup)(struct inode___269 *, struct dentry___269 *, unsigned int);
	const char * (*get_link)(struct dentry___269 *, struct inode___269 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___269 *, int);
	struct posix_acl * (*get_acl)(struct inode___269 *, int, bool);
	int (*readlink)(struct dentry___269 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___269 *, struct dentry___269 *, umode_t, bool);
	int (*link)(struct dentry___269 *, struct inode___269 *, struct dentry___269 *);
	int (*unlink)(struct inode___269 *, struct dentry___269 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___269 *, struct dentry___269 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___269 *, struct dentry___269 *, umode_t);
	int (*rmdir)(struct inode___269 *, struct dentry___269 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___269 *, struct dentry___269 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___269 *, struct dentry___269 *, struct inode___269 *, struct dentry___269 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___269 *, struct iattr___269 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___269 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___269 *, char *, size_t);
	int (*fiemap)(struct inode___269 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___269 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___269 *, struct dentry___269 *, struct file___269 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___269 *, struct dentry___269 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___269 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___269 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___269 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___269 {
	void (*fl_copy_lock)(struct file_lock___269 *, struct file_lock___269 *);
	void (*fl_release_private)(struct file_lock___269 *);
};

struct lock_manager_operations___269;

struct file_lock___269 {
	struct file_lock___269 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___269 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___269 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___269 *fl_ops;
	const struct lock_manager_operations___269 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___269 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___269 *);
	int (*lm_grant)(struct file_lock___269 *, int);
	bool (*lm_break)(struct file_lock___269 *);
	int (*lm_change)(struct file_lock___269 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___269 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___269 *);
};

struct fasync_struct___269 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___269 *fa_next;
	struct file___269 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___269 {
	struct inode___269 * (*alloc_inode)(struct super_block___269 *);
	void (*destroy_inode)(struct inode___269 *);
	void (*free_inode)(struct inode___269 *);
	void (*dirty_inode)(struct inode___269 *, int);
	int (*write_inode)(struct inode___269 *, struct writeback_control___146 *);
	int (*drop_inode)(struct inode___269 *);
	void (*evict_inode)(struct inode___269 *);
	void (*put_super)(struct super_block___269 *);
	int (*sync_fs)(struct super_block___269 *, int);
	int (*freeze_super)(struct super_block___269 *);
	int (*freeze_fs)(struct super_block___269 *);
	int (*thaw_super)(struct super_block___269 *);
	int (*unfreeze_fs)(struct super_block___269 *);
	int (*statfs)(struct dentry___269 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___269 *, int *, char *);
	void (*umount_begin)(struct super_block___269 *);
	int (*show_options)(struct seq_file___244 *, struct dentry___269 *);
	int (*show_devname)(struct seq_file___244 *, struct dentry___269 *);
	int (*show_path)(struct seq_file___244 *, struct dentry___269 *);
	int (*show_stats)(struct seq_file___244 *, struct dentry___269 *);
	ssize_t (*quota_read)(struct super_block___269 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___269 *, int, const char *, size_t, loff_t);
	struct dquot___269 ** (*get_dquots)(struct inode___269 *);
	long int (*nr_cached_objects)(struct super_block___269 *, struct shrink_control___134 *);
	long int (*free_cached_objects)(struct super_block___269 *, struct shrink_control___134 *);
	struct file___269 * (*real_loop)(struct file___269 *);
};

struct wakeup_source___250;

struct dev_pm_info___250 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___250 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___250 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___250;

struct bus_type___250;

struct device_driver___250;

struct dev_pm_domain___250;

struct fwnode_handle___246;

struct class___250;

struct attribute_group___257;

struct device___250 {
	struct kobject___257 kobj;
	struct device___250 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___250 *type;
	struct bus_type___250 *bus;
	struct device_driver___250 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___250 power;
	struct dev_pm_domain___250 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___246 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___250 *class;
	const struct attribute_group___257 **groups;
	void (*release)(struct device___250 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___163 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___269 *bd_inode;
	struct super_block___269 *bd_super;
	void *bd_claiming;
	struct device___250 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___257 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___163 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___269 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___198)(struct file___269 *, wait_queue_head_t *, struct poll_table_struct___190 *);

struct poll_table_struct___190 {
	poll_queue_proc___198 _qproc;
	__poll_t _key;
};

struct seq_operations___244;

struct seq_file___244 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___244 *op;
	int poll_event;
	const struct file___269 *file;
	void *private;
};

typedef void bio_end_io_t___160(struct bio___160 *);

struct bio_vec___186 {
	struct page___274 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___160;

struct bio___160 {
	struct bio___160 *bi_next;
	struct block_device___163 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___160 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___148 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___160 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___186 *bi_io_vec;
	struct bio_set___160 *bi_pool;
	struct bio_vec___186 bi_inline_vecs[0];
};

struct fwnode_operations___246;

struct fwnode_handle___246 {
	struct fwnode_handle___246 *secondary;
	const struct fwnode_operations___246 *ops;
	struct device___250 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___246;

struct fwnode_endpoint___246;

struct fwnode_operations___246 {
	struct fwnode_handle___246 * (*get)(struct fwnode_handle___246 *);
	void (*put)(struct fwnode_handle___246 *);
	bool (*device_is_available)(const struct fwnode_handle___246 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___246 *, const struct device___250 *);
	bool (*property_present)(const struct fwnode_handle___246 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___246 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___246 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___246 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*get_parent)(const struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*get_next_child_node)(const struct fwnode_handle___246 *, struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*get_named_child_node)(const struct fwnode_handle___246 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___246 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___246 *);
	struct fwnode_handle___246 * (*graph_get_next_endpoint)(const struct fwnode_handle___246 *, struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*graph_get_remote_endpoint)(const struct fwnode_handle___246 *);
	struct fwnode_handle___246 * (*graph_get_port_parent)(struct fwnode_handle___246 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___246 *, struct fwnode_endpoint___246 *);
	int (*add_links)(struct fwnode_handle___246 *);
};

struct fwnode_endpoint___246 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___246 *local_fwnode;
};

struct fwnode_reference_args___246 {
	struct fwnode_handle___246 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___257;

struct kernfs_elem_dir___257 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___257 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___257;

struct kernfs_root___257 {
	struct kernfs_node___257 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___257 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___257 {
	struct kernfs_node___257 *target_kn;
};

struct kernfs_ops___257;

struct kernfs_elem_attr___257 {
	const struct kernfs_ops___257 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___257 *notify_next;
};

struct kernfs_node___257 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___257 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___257 dir;
		struct kernfs_elem_symlink___257 symlink;
		struct kernfs_elem_attr___257 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___257;

struct kernfs_ops___257 {
	int (*open)(struct kernfs_open_file___257 *);
	void (*release)(struct kernfs_open_file___257 *);
	int (*seq_show)(struct seq_file___244 *, void *);
	void * (*seq_start)(struct seq_file___244 *, loff_t *);
	void * (*seq_next)(struct seq_file___244 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___244 *, void *);
	ssize_t (*read)(struct kernfs_open_file___257 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___257 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___257 *, struct poll_table_struct___190 *);
	int (*mmap)(struct kernfs_open_file___257 *, struct vm_area_struct___274 *);
};

struct kernfs_syscall_ops___257 {
	int (*show_options)(struct seq_file___244 *, struct kernfs_root___257 *);
	int (*mkdir)(struct kernfs_node___257 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___257 *);
	int (*rename)(struct kernfs_node___257 *, struct kernfs_node___257 *, const char *);
	int (*show_path)(struct seq_file___244 *, struct kernfs_node___257 *, struct kernfs_root___257 *);
};

struct kernfs_open_file___257 {
	struct kernfs_node___257 *kn;
	struct file___269 *file;
	struct seq_file___244 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___264 *vm_ops;
};

struct sock___65;

struct kobj_ns_type_operations___65 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___65 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___83 *net;
} possible_net_t___78;

struct proto___65;

struct sock_common___65 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___65 *skc_prot;
	possible_net_t___78 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___65 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___79;

struct sk_buff_head___78 {
	struct sk_buff___79 *next;
	struct sk_buff___79 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___65 {
	struct cgroup___196 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___65;

struct socket_wq___66;

struct xfrm_policy___10;

struct dst_entry___65;

struct socket___67;

struct net_device___78;

struct sock_reuseport___17;

struct sock___65 {
	struct sock_common___65 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___78 sk_error_queue;
	struct sk_buff___79 *sk_rx_skb_cache;
	struct sk_buff_head___78 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___79 *head;
		struct sk_buff___79 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___65 *sk_filter;
	union {
		struct socket_wq___66 *sk_wq;
		struct socket_wq___66 *sk_wq_raw;
	};
	struct xfrm_policy___10 *sk_policy[2];
	struct dst_entry___65 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___65 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___79 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___79 *sk_tx_skb_cache;
	struct sk_buff_head___78 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___274 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___65 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___246 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___67 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___65 sk_cgrp_data;
	struct mem_cgroup___134 *sk_memcg;
	void (*sk_state_change)(struct sock___65 *);
	void (*sk_data_ready)(struct sock___65 *);
	void (*sk_write_space)(struct sock___65 *);
	void (*sk_error_report)(struct sock___65 *);
	int (*sk_backlog_rcv)(struct sock___65 *, struct sk_buff___79 *);
	struct sk_buff___79 * (*sk_validate_xmit_skb)(struct sock___65 *, struct net_device___78 *, struct sk_buff___79 *);
	void (*sk_destruct)(struct sock___65 *);
	struct sock_reuseport___17 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___257;

struct attribute_group___257 {
	const char *name;
	umode_t (*is_visible)(struct kobject___257 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___257 *, struct bin_attribute___257 *, int);
	struct attribute **attrs;
	struct bin_attribute___257 **bin_attrs;
};

struct bin_attribute___257 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___269 * (*f_mapping)();
	ssize_t (*read)(struct file___269 *, struct kobject___257 *, struct bin_attribute___257 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___269 *, struct kobject___257 *, struct bin_attribute___257 *, char *, loff_t, size_t);
	int (*mmap)(struct file___269 *, struct kobject___257 *, struct bin_attribute___257 *, struct vm_area_struct___274 *);
};

struct sysfs_ops___257 {
	ssize_t (*show)(struct kobject___257 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___257 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___257;

struct kset___257 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___257 kobj;
	const struct kset_uevent_ops___257 *uevent_ops;
};

struct kobj_type___257 {
	void (*release)(struct kobject___257 *);
	const struct sysfs_ops___257 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___257 **default_groups;
	const struct kobj_ns_type_operations___65 * (*child_ns_type)(struct kobject___257 *);
	const void * (*namespace)(struct kobject___257 *);
	void (*get_ownership)(struct kobject___257 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___257 {
	int (* const filter)(struct kset___257 *, struct kobject___257 *);
	const char * (* const name)(struct kset___257 *, struct kobject___257 *);
	int (* const uevent)(struct kset___257 *, struct kobject___257 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___253 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___253 *);
	int (*get)(char *, const struct kernel_param___253 *);
	void (*free)(void *);
};

struct kparam_array___253;

struct kernel_param___253 {
	const char *name;
	struct module___253 *mod;
	const struct kernel_param_ops___253 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___253 *arr;
	};
};

struct kparam_array___253 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___253 *ops;
	void *elem;
};

struct module_attribute___253 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___253 *, struct module_kobject___254 *, char *);
	ssize_t (*store)(struct module_attribute___253 *, struct module_kobject___254 *, const char *, size_t);
	void (*setup)(struct module___253 *, const char *);
	int (*test)(struct module___253 *);
	void (*free)(struct module___253 *);
};

struct ip_ra_chain___38;

struct fib_rules_ops___65;

struct fqdir___83;

struct tcp_congestion_ops___16;

struct fib_notifier_ops___65;

struct netns_ipv4___83 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___38 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___65 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___65 *fibnl;
	struct sock___65 **icmp_sk;
	struct sock___65 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___65 **tcp_sk;
	struct fqdir___83 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___16 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___65 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___65 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___65 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___65;

struct dst_ops___83 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___83 *);
	struct dst_entry___65 * (*check)(struct dst_entry___65 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___65 *);
	unsigned int (*mtu)(const struct dst_entry___65 *);
	u32 * (*cow_metrics)(struct dst_entry___65 *, long unsigned int);
	void (*destroy)(struct dst_entry___65 *);
	void (*ifdown)(struct dst_entry___65 *, struct net_device___78 *, int);
	struct dst_entry___65 * (*negative_advice)(struct dst_entry___65 *);
	void (*link_failure)(struct sk_buff___79 *);
	void (*update_pmtu)(struct dst_entry___65 *, struct sock___65 *, struct sk_buff___79 *, u32, bool);
	void (*redirect)(struct dst_entry___65 *, struct sock___65 *, struct sk_buff___79 *);
	int (*local_out)(struct net___83 *, struct sock___65 *, struct sk_buff___79 *);
	struct neighbour___65 * (*neigh_lookup)(const struct dst_entry___65 *, struct sk_buff___79 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___65 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___15;

struct rt6_info___15;

struct fib6_table___15;

struct netns_ipv6___83 {
	struct dst_ops___83 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___83 *fqdir;
	struct fib6_info___15 *fib6_null_entry;
	struct rt6_info___15 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___15 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___15 *ip6_prohibit_entry;
	struct rt6_info___15 *ip6_blk_hole_entry;
	struct fib6_table___15 *fib6_local_tbl;
	struct fib_rules_ops___65 *fib6_rules_ops;
	struct sock___65 **icmp_sk;
	struct sock___65 *ndisc_sk;
	struct sock___65 *tcp_sk;
	struct sock___65 *igmp_sk;
	struct sock___65 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___65 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___65 *notifier_ops;
	struct fib_notifier_ops___65 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___83 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___83 *fqdir;
};

struct netns_sctp___65 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___65 *ctl_sock;
	struct sock___65 *udp4_sock;
	struct sock___65 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___10;

struct netns_nf___10 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___10 *hooks_ipv4[5];
	struct nf_hook_entries___10 *hooks_ipv6[5];
	struct nf_hook_entries___10 *hooks_arp[3];
	struct nf_hook_entries___10 *hooks_bridge[5];
	struct nf_hook_entries___10 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___72;

struct netns_bpf___72 {
	struct bpf_prog_array___72 *run_array[2];
	struct bpf_prog___72 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___83 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___65 *nlsk;
	struct sock___65 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___83 xfrm4_dst_ops;
	struct dst_ops___83 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___83 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___65 *rtnl;
	struct sock___65 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___78 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___83 ipv4;
	struct netns_ipv6___83 ipv6;
	struct netns_ieee802154_lowpan___83 ieee802154_lowpan;
	struct netns_sctp___65 sctp;
	struct netns_nf___10 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___78 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___72 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___83 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___65 *crypto_nlsk;
	struct sock___65 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___196 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___196 *root_cset;
};

struct msghdr___67 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___189 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___269 *msg_iocb;
};

struct socket_wq___66 {
	wait_queue_head_t wait;
	struct fasync_struct___269 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___66;

struct socket___67 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___269 *file;
	struct sock___65 *sk;
	const struct proto_ops___66 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___66 wq;
};

typedef int (*sk_read_actor_t___65)(read_descriptor_t *, struct sk_buff___79 *, unsigned int, size_t);

struct proto_ops___66 {
	int family;
	struct module___253 *owner;
	int (*release)(struct socket___67 *);
	int (*bind)(struct socket___67 *, struct sockaddr *, int);
	int (*connect)(struct socket___67 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___67 *, struct socket___67 *);
	int (*accept)(struct socket___67 *, struct socket___67 *, int, bool);
	int (*getname)(struct socket___67 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___269 *, struct socket___67 *, struct poll_table_struct___190 *);
	int (*ioctl)(struct socket___67 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___67 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___67 *, void *, bool, bool);
	int (*listen)(struct socket___67 *, int);
	int (*shutdown)(struct socket___67 *, int);
	int (*setsockopt)(struct socket___67 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___67 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___244 *, struct socket___67 *);
	int (*sendmsg)(struct socket___67 *, struct msghdr___67 *, size_t);
	int (*recvmsg)(struct socket___67 *, struct msghdr___67 *, size_t, int);
	int (*mmap)(struct file___269 *, struct socket___67 *, struct vm_area_struct___274 *);
	ssize_t (*sendpage)(struct socket___67 *, struct page___274 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___67 *, loff_t *, struct pipe_inode_info___110 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___65 *, int);
	int (*peek_len)(struct socket___67 *);
	int (*read_sock)(struct sock___65 *, read_descriptor_t *, sk_read_actor_t___65);
	int (*sendpage_locked)(struct sock___65 *, struct page___274 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___65 *, struct msghdr___67 *, size_t);
	int (*set_rcvlowat)(struct sock___65 *, int);
};

struct sk_buff___79 {
	union {
		struct {
			struct sk_buff___79 *next;
			struct sk_buff___79 *prev;
			union {
				struct net_device___78 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___65 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___79 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___250 {
	int (*prepare)(struct device___250 *);
	void (*complete)(struct device___250 *);
	int (*suspend)(struct device___250 *);
	int (*resume)(struct device___250 *);
	int (*freeze)(struct device___250 *);
	int (*thaw)(struct device___250 *);
	int (*poweroff)(struct device___250 *);
	int (*restore)(struct device___250 *);
	int (*suspend_late)(struct device___250 *);
	int (*resume_early)(struct device___250 *);
	int (*freeze_late)(struct device___250 *);
	int (*thaw_early)(struct device___250 *);
	int (*poweroff_late)(struct device___250 *);
	int (*restore_early)(struct device___250 *);
	int (*suspend_noirq)(struct device___250 *);
	int (*resume_noirq)(struct device___250 *);
	int (*freeze_noirq)(struct device___250 *);
	int (*thaw_noirq)(struct device___250 *);
	int (*poweroff_noirq)(struct device___250 *);
	int (*restore_noirq)(struct device___250 *);
	int (*runtime_suspend)(struct device___250 *);
	int (*runtime_resume)(struct device___250 *);
	int (*runtime_idle)(struct device___250 *);
};

struct wakeup_source___250 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___250 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___250 {
	struct dev_pm_ops___250 ops;
	int (*start)(struct device___250 *);
	void (*detach)(struct device___250 *, bool);
	int (*activate)(struct device___250 *);
	void (*sync)(struct device___250 *);
	void (*dismiss)(struct device___250 *);
};

struct bus_type___250 {
	const char *name;
	const char *dev_name;
	struct device___250 *dev_root;
	const struct attribute_group___257 **bus_groups;
	const struct attribute_group___257 **dev_groups;
	const struct attribute_group___257 **drv_groups;
	int (*match)(struct device___250 *, struct device_driver___250 *);
	int (*uevent)(struct device___250 *, struct kobj_uevent_env *);
	int (*probe)(struct device___250 *);
	void (*sync_state)(struct device___250 *);
	void (*remove)(struct device___250 *);
	void (*shutdown)(struct device___250 *);
	int (*online)(struct device___250 *);
	int (*offline)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	int (*num_vf)(struct device___250 *);
	int (*dma_configure)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___250 {
	const char *name;
	struct bus_type___250 *bus;
	struct module___253 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___250 *);
	void (*sync_state)(struct device___250 *);
	int (*remove)(struct device___250 *);
	void (*shutdown)(struct device___250 *);
	int (*suspend)(struct device___250 *, pm_message_t);
	int (*resume)(struct device___250 *);
	const struct attribute_group___257 **groups;
	const struct attribute_group___257 **dev_groups;
	const struct dev_pm_ops___250 *pm;
	void (*coredump)(struct device___250 *);
	struct driver_private *p;
};

struct device_type___250 {
	const char *name;
	const struct attribute_group___257 **groups;
	int (*uevent)(struct device___250 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___250 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___250 *);
	const struct dev_pm_ops___250 *pm;
};

struct class___250 {
	const char *name;
	struct module___253 *owner;
	const struct attribute_group___257 **class_groups;
	const struct attribute_group___257 **dev_groups;
	struct kobject___257 *dev_kobj;
	int (*dev_uevent)(struct device___250 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___250 *, umode_t *);
	void (*class_release)(struct class___250 *);
	void (*dev_release)(struct device___250 *);
	int (*shutdown_pre)(struct device___250 *);
	const struct kobj_ns_type_operations___65 *ns_type;
	const void * (*namespace)(struct device___250 *);
	void (*get_ownership)(struct device___250 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___250 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___110;

struct pipe_buffer___110 {
	struct page___274 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___110 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___110 {
	int (*confirm)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
	void (*release)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
	bool (*try_steal)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
	bool (*get)(struct pipe_inode_info___110 *, struct pipe_buffer___110 *);
};

typedef rx_handler_result_t rx_handler_func_t___78(struct sk_buff___79 **);

struct bpf_xdp_entity___72 {
	struct bpf_prog___72 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___78;

struct net_device_ops___78;

struct l3mdev_ops___65;

struct ndisc_ops___47;

struct xfrmdev_ops___78;

struct header_ops___78;

struct inet6_dev___47;

struct netdev_rx_queue___78;

struct mini_Qdisc___72;

struct netdev_queue___78;

struct Qdisc___72;

struct rtnl_link_ops___72;

struct dcbnl_rtnl_ops___78;

struct net_device___78 {
	char name[16];
	struct netdev_name_node___78 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___78 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___65 *l3mdev_ops;
	const struct ndisc_ops___47 *ndisc_ops;
	const struct xfrmdev_ops___78 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___78 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___257 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___47 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___78 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___72 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___78 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___72 *miniq_ingress;
	struct netdev_queue___78 *ingress_queue;
	struct nf_hook_entries___10 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___78 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___72 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___72 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___78 = 0,
		NETREG_REGISTERED___78 = 1,
		NETREG_UNREGISTERING___78 = 2,
		NETREG_UNREGISTERED___78 = 3,
		NETREG_RELEASED___78 = 4,
		NETREG_DUMMY___78 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___78 = 0,
		RTNL_LINK_INITIALIZING___78 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___78 *);
	struct netpoll_info *npinfo;
	possible_net_t___78 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___250 dev;
	const struct attribute_group___257 *sysfs_groups[4];
	const struct attribute_group___257 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___72 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___78 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___72 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___186 skb_frag_t___24;

struct skb_shared_info___23 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___79 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___24 frags[17];
};

struct inet_frags___83;

struct fqdir___83 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___83 *f;
	struct net___83 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___83;

struct inet_frags___83 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___83 *, const void *);
	void (*destructor)(struct inet_frag_queue___83 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___83 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___79 *fragments_tail;
	struct sk_buff___79 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___83 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___38 {
	struct ip_ra_chain___38 *next;
	struct sock___65 *sk;
	union {
		void (*destructor)(struct sock___65 *);
		struct sock___65 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___65;

struct fib_lookup_arg___65;

struct fib_rules_ops___65 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___65 *, struct flowi *, int, struct fib_lookup_arg___65 *);
	bool (*suppress)(struct fib_rule___65 *, int, struct fib_lookup_arg___65 *);
	int (*match)(struct fib_rule___65 *, struct flowi *, int);
	int (*configure)(struct fib_rule___65 *, struct sk_buff___79 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___65 *);
	int (*compare)(struct fib_rule___65 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___65 *, struct sk_buff___79 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___65 *);
	void (*flush_cache)(struct fib_rules_ops___65 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___253 *owner;
	struct net___83 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___16 {
	u32 (*ssthresh)(struct sock___65 *);
	void (*cong_avoid)(struct sock___65 *, u32, u32);
	void (*set_state)(struct sock___65 *, u8);
	void (*cwnd_event)(struct sock___65 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___65 *, u32);
	void (*pkts_acked)(struct sock___65 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___65 *);
	void (*cong_control)(struct sock___65 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___65 *);
	u32 (*sndbuf_expand)(struct sock___65 *);
	size_t (*get_info)(struct sock___65 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___253 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___65 *);
	void (*release)(struct sock___65 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___65 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___83 *);
	int (*fib_dump)(struct net___83 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___253 *owner;
	struct callback_head rcu;
};

struct xfrm_state___10;

struct lwtunnel_state___41;

struct dst_entry___65 {
	struct net_device___78 *dev;
	struct dst_ops___83 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___10 *xfrm;
	int (*input)(struct sk_buff___79 *);
	int (*output)(struct net___83 *, struct sock___65 *, struct sk_buff___79 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___41 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___65;

struct neigh_parms___65;

struct neigh_ops___65;

struct neighbour___65 {
	struct neighbour___65 *next;
	struct neigh_table___65 *tbl;
	struct neigh_parms___65 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___78 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___65 *, struct sk_buff___79 *);
	const struct neigh_ops___65 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___78 *dev;
	u8 primary_key[0];
};

struct rtable___15;

struct fnhe_hash_bucket___15;

struct fib_nh_common___15 {
	struct net_device___78 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___41 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___15 **nhc_pcpu_rth_output;
	struct rtable___15 *nhc_rth_input;
	struct fnhe_hash_bucket___15 *nhc_exceptions;
};

struct fib6_nh___15 {
	struct fib_nh_common___15 nh_common;
	long unsigned int last_probe;
	struct rt6_info___15 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___15;

struct fib6_info___15 {
	struct fib6_table___15 *fib6_table;
	struct fib6_info___15 *fib6_next;
	struct fib6_node___15 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___15 fib6_nh[0];
};

struct rt6_info___15 {
	struct dst_entry___65 dst;
	struct fib6_info___15 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___47 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___15 {
	struct fib6_node___15 *parent;
	struct fib6_node___15 *left;
	struct fib6_node___15 *right;
	struct fib6_node___15 *subtree;
	struct fib6_info___15 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___15 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___15 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___15 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___10;

typedef unsigned int nf_hookfn___11(void *, struct sk_buff___79 *, const struct nf_hook_state___10 *);

struct nf_hook_entry___10 {
	nf_hookfn___11 *hook;
	void *priv;
};

struct nf_hook_entries___10 {
	u16 num_hook_entries;
	struct nf_hook_entry___10 hooks[0];
};

struct bpf_prog_array_item___72 {
	struct bpf_prog___72 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___72 {
	struct callback_head rcu;
	struct bpf_prog_array_item___72 items[0];
};

struct bpf_prog_aux___81;

struct bpf_prog___72 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___81 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___244 {
	void * (*start)(struct seq_file___244 *, loff_t *);
	void (*stop)(struct seq_file___244 *, void *);
	void * (*next)(struct seq_file___244 *, void *, loff_t *);
	int (*show)(struct seq_file___244 *, void *);
};

struct dcbnl_rtnl_ops___78 {
	int (*ieee_getets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___78 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___78 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___78 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___78 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___78 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___78 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___78 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___78 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___78 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___78 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___78 *);
	u8 (*setstate)(struct net_device___78 *, u8);
	void (*getpermhwaddr)(struct net_device___78 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___78 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___78 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___78 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___78 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___78 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___78 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___78 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___78 *, int, u8 *);
	void (*setpfccfg)(struct net_device___78 *, int, u8);
	void (*getpfccfg)(struct net_device___78 *, int, u8 *);
	u8 (*setall)(struct net_device___78 *);
	u8 (*getcap)(struct net_device___78 *, int, u8 *);
	int (*getnumtcs)(struct net_device___78 *, int, u8 *);
	int (*setnumtcs)(struct net_device___78 *, int, u8);
	u8 (*getpfcstate)(struct net_device___78 *);
	void (*setpfcstate)(struct net_device___78 *, u8);
	void (*getbcncfg)(struct net_device___78 *, int, u32 *);
	void (*setbcncfg)(struct net_device___78 *, int, u32);
	void (*getbcnrp)(struct net_device___78 *, int, u8 *);
	void (*setbcnrp)(struct net_device___78 *, int, u8);
	int (*setapp)(struct net_device___78 *, u8, u16, u8);
	int (*getapp)(struct net_device___78 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___78 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___78 *, int, u8);
	u8 (*getdcbx)(struct net_device___78 *);
	u8 (*setdcbx)(struct net_device___78 *, u8);
	int (*peer_getappinfo)(struct net_device___78 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___78 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___78 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___78 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___78 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___78 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___81;

typedef int (*bpf_iter_init_seq_priv_t___80)(void *, struct bpf_iter_aux_info___81 *);

struct bpf_map___81;

struct bpf_iter_aux_info___81 {
	struct bpf_map___81 *map;
};

struct bpf_iter_seq_info___80 {
	const struct seq_operations___244 *seq_ops;
	bpf_iter_init_seq_priv_t___80 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___80 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___81 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___81 *, struct file___269 *);
	void (*map_free)(struct bpf_map___81 *);
	int (*map_get_next_key)(struct bpf_map___81 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___81 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___81 *, void *);
	int (*map_lookup_batch)(struct bpf_map___81 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___81 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___81 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___81 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___81 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___81 *, void *);
	int (*map_update_elem)(struct bpf_map___81 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___81 *, void *);
	int (*map_push_elem)(struct bpf_map___81 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___81 *, void *);
	int (*map_peek_elem)(struct bpf_map___81 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___81 *, struct file___269 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___81 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___81 *, void *, struct seq_file___244 *);
	int (*map_check_btf)(const struct bpf_map___81 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___81 *, struct bpf_prog_aux___81 *);
	void (*map_poke_untrack)(struct bpf_map___81 *, struct bpf_prog_aux___81 *);
	void (*map_poke_run)(struct bpf_map___81 *, u32, struct bpf_prog___72 *, struct bpf_prog___72 *);
	int (*map_direct_value_addr)(const struct bpf_map___81 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___81 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___81 *, struct vm_area_struct___274 *);
	__poll_t (*map_poll)(struct bpf_map___81 *, struct file___269 *, struct poll_table_struct___190 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___81 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___81 *, const struct bpf_map___81 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___81 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___80 *iter_seq_info;
};

struct bpf_map___81 {
	const struct bpf_map_ops___80 *ops;
	struct bpf_map___81 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___134 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___80;

struct bpf_jit_poke_descriptor___80;

struct bpf_prog_ops___72;

struct btf_mod_pair___80;

struct bpf_prog_offload___78;

struct bpf_prog_aux___81 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___72 *dst_prog;
	struct bpf_trampoline___80 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___72 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___80 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___72 *ops;
	struct bpf_map___81 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___80 *used_btfs;
	struct bpf_prog___72 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___81 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___78 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___78;

struct bpf_map_dev_ops___78 {
	int (*map_get_next_key)(struct bpf_offloaded_map___78 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___78 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___78 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___78 *, void *);
};

struct bpf_offloaded_map___78 {
	struct bpf_map___81 map;
	struct net_device___78 *netdev;
	const struct bpf_map_dev_ops___78 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___72 {
	int (*test_run)(struct bpf_prog___72 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___78 {
	struct bpf_prog___72 *prog;
	struct net_device___78 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___80 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___72 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___253 *mod;
};

struct bpf_jit_poke_descriptor___80 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___81 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___80 {
	struct btf *btf;
	struct module___253 *module;
};

struct cftype___196;

struct cgroup_subsys___196 {
	struct cgroup_subsys_state___196 * (*css_alloc)(struct cgroup_subsys_state___196 *);
	int (*css_online)(struct cgroup_subsys_state___196 *);
	void (*css_offline)(struct cgroup_subsys_state___196 *);
	void (*css_released)(struct cgroup_subsys_state___196 *);
	void (*css_free)(struct cgroup_subsys_state___196 *);
	void (*css_reset)(struct cgroup_subsys_state___196 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___196 *, int);
	int (*css_extra_stat_show)(struct seq_file___244 *, struct cgroup_subsys_state___196 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___276 *, struct css_set___196 *);
	void (*cancel_fork)(struct task_struct___276 *, struct css_set___196 *);
	void (*fork)(struct task_struct___276 *);
	void (*exit)(struct task_struct___276 *);
	void (*release)(struct task_struct___276 *);
	void (*bind)(struct cgroup_subsys_state___196 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___196 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___196 *dfl_cftypes;
	struct cftype___196 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___196 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___196 *updated_children;
	struct cgroup___196 *updated_next;
};

struct cgroup_root___196 {
	struct kernfs_root___257 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___196 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___196 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___196 *ss;
	struct list_head node;
	struct kernfs_ops___257 *kf_ops;
	int (*open)(struct kernfs_open_file___257 *);
	void (*release)(struct kernfs_open_file___257 *);
	u64 (*read_u64)(struct cgroup_subsys_state___196 *, struct cftype___196 *);
	s64 (*read_s64)(struct cgroup_subsys_state___196 *, struct cftype___196 *);
	int (*seq_show)(struct seq_file___244 *, void *);
	void * (*seq_start)(struct seq_file___244 *, loff_t *);
	void * (*seq_next)(struct seq_file___244 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___244 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___196 *, struct cftype___196 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___196 *, struct cftype___196 *, s64);
	ssize_t (*write)(struct kernfs_open_file___257 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___257 *, struct poll_table_struct___190 *);
};

struct xdp_rxq_info___78 {
	struct net_device___78 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___78 {
	struct net_device___78 *dev;
};

struct xdp_buff___78 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___78 *rxq;
	struct xdp_txq_info___78 *txq;
	u32 frame_sz;
};

struct xdp_frame___78 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___78 *dev_rx;
};

struct netlink_callback___78 {
	struct sk_buff___79 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___79 *, struct netlink_callback___78 *);
	int (*done)(struct netlink_callback___78 *);
	void *data;
	struct module___253 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___78 {
	int (*create)(struct sk_buff___79 *, struct net_device___78 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___79 *, unsigned char *);
	int (*cache)(const struct neighbour___65 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___78 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___79 *);
};

struct netdev_queue___78 {
	struct net_device___78 *dev;
	struct Qdisc___72 *qdisc;
	struct Qdisc___72 *qdisc_sleeping;
	struct kobject___257 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___78 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___72 {
	struct sk_buff___79 *head;
	struct sk_buff___79 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___72;

struct Qdisc___72 {
	int (*enqueue)(struct sk_buff___79 *, struct Qdisc___72 *, struct sk_buff___79 **);
	struct sk_buff___79 * (*dequeue)(struct Qdisc___72 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___72 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___78 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___78 gso_skb;
	struct qdisc_skb_head___72 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___72 *next_sched;
	struct sk_buff_head___78 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___78 {
	struct xdp_rxq_info___78 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___257 kobj;
	struct net_device___78 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___78 {
	enum net_device_path_type type;
	const struct net_device___78 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___78 = 0,
				DEV_PATH_BR_VLAN_TAG___78 = 1,
				DEV_PATH_BR_VLAN_UNTAG___78 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___78 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___78 {
	const struct net_device___78 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___78 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___72 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___78 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___78 {
	int (*xdo_dev_state_add)(struct xfrm_state___10 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___10 *);
	void (*xdo_dev_state_free)(struct xfrm_state___10 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___79 *, struct xfrm_state___10 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___10 *);
};

struct xfrm_state_offload___10 {
	struct net_device___78 *dev;
	struct net_device___78 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___10;

struct xfrm_type_offload___10;

struct xfrm_state___10 {
	possible_net_t___78 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___65 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___10 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___10 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___274 xfrag;
	const struct xfrm_type___10 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___10 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___78 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___78 *dev;
	const char *name;
};

struct net_device_ops___78 {
	int (*ndo_init)(struct net_device___78 *);
	void (*ndo_uninit)(struct net_device___78 *);
	int (*ndo_open)(struct net_device___78 *);
	int (*ndo_stop)(struct net_device___78 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___79 *, struct net_device___78 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___79 *, struct net_device___78 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___78 *, struct sk_buff___79 *, struct net_device___78 *);
	void (*ndo_change_rx_flags)(struct net_device___78 *, int);
	void (*ndo_set_rx_mode)(struct net_device___78 *);
	int (*ndo_set_mac_address)(struct net_device___78 *, void *);
	int (*ndo_validate_addr)(struct net_device___78 *);
	int (*ndo_do_ioctl)(struct net_device___78 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___78 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___78 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___78 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___78 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___78 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___78 *, int);
	int (*ndo_neigh_setup)(struct net_device___78 *, struct neigh_parms___65 *);
	void (*ndo_tx_timeout)(struct net_device___78 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___78 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___78 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___78 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___78 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___78 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___78 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___78 *);
	int (*ndo_netpoll_setup)(struct net_device___78 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___78 *);
	int (*ndo_set_vf_mac)(struct net_device___78 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___78 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___78 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___78 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___78 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___78 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___78 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___78 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___78 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___78 *, int, struct sk_buff___79 *);
	int (*ndo_get_vf_guid)(struct net_device___78 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___78 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___78 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___78 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___78 *);
	int (*ndo_fcoe_disable)(struct net_device___78 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___78 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___78 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___78 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___78 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___78 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___78 *, const struct sk_buff___79 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___78 *, struct net_device___78 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___78 *, struct net_device___78 *);
	struct net_device___78 * (*ndo_get_xmit_slave)(struct net_device___78 *, struct sk_buff___79 *, bool);
	struct net_device___78 * (*ndo_sk_get_lower_dev)(struct net_device___78 *, struct sock___65 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___78 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___78 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___78 *, struct neighbour___65 *);
	void (*ndo_neigh_destroy)(struct net_device___78 *, struct neighbour___65 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___79 *, struct netlink_callback___78 *, struct net_device___78 *, struct net_device___78 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___79 *, struct nlattr **, struct net_device___78 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___78 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___79 *, u32, u32, struct net_device___78 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___78 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___78 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___78 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___78 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___78 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___78 *, struct net_device___78 *);
	void (*ndo_dfwd_del_station)(struct net_device___78 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___78 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___78 *);
	int (*ndo_change_proto_down)(struct net_device___78 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___78 *, struct sk_buff___79 *);
	void (*ndo_set_rx_headroom)(struct net_device___78 *, int);
	int (*ndo_bpf)(struct net_device___78 *, struct netdev_bpf___78 *);
	int (*ndo_xdp_xmit)(struct net_device___78 *, int, struct xdp_frame___78 **, u32);
	struct net_device___78 * (*ndo_xdp_get_xmit_slave)(struct net_device___78 *, struct xdp_buff___78 *);
	int (*ndo_xsk_wakeup)(struct net_device___78 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___78 *);
	int (*ndo_tunnel_ctl)(struct net_device___78 *, struct ip_tunnel_parm *, int);
	struct net_device___78 * (*ndo_get_peer_dev)(struct net_device___78 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___78 *, struct net_device_path___78 *);
};

struct neigh_parms___65 {
	possible_net_t___78 net;
	struct net_device___78 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___65 *);
	struct neigh_table___65 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___65 {
	u32 (*l3mdev_fib_table)(const struct net_device___78 *);
	struct sk_buff___79 * (*l3mdev_l3_rcv)(struct net_device___78 *, struct sk_buff___79 *, u16);
	struct sk_buff___79 * (*l3mdev_l3_out)(struct net_device___78 *, struct sock___65 *, struct sk_buff___79 *, u16);
	struct dst_entry___65 * (*l3mdev_link_scope_lookup)(const struct net_device___78 *, struct flowi6 *);
};

struct ndisc_ops___47 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___78 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___78 *, struct neighbour___65 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___78 *, u8, struct neighbour___65 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___78 *, struct sk_buff___79 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___83 *, struct net_device___78 *, const struct prefix_info *, struct inet6_dev___47 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___47;

struct ifacaddr6___15;

struct inet6_dev___47 {
	struct net_device___78 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___47 *mc_list;
	struct ifmcaddr6___47 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___78 mc_query_queue;
	struct sk_buff_head___78 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___15 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___65 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___72;

struct tcf_block___72;

struct mini_Qdisc___72 {
	struct tcf_proto___72 *filter_list;
	struct tcf_block___72 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___72 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___78 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___78 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___83 *, struct net_device___78 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___78 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___78 *, struct list_head *);
	size_t (*get_size)(const struct net_device___78 *);
	int (*fill_info)(struct sk_buff___79 *, const struct net_device___78 *);
	size_t (*get_xstats_size)(const struct net_device___78 *);
	int (*fill_xstats)(struct sk_buff___79 *, const struct net_device___78 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___78 *, struct net_device___78 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___78 *, const struct net_device___78 *);
	int (*fill_slave_info)(struct sk_buff___79 *, const struct net_device___78 *, const struct net_device___78 *);
	struct net___83 * (*get_link_net)(const struct net_device___78 *);
	size_t (*get_linkxstats_size)(const struct net_device___78 *, int);
	int (*fill_linkxstats)(struct sk_buff___79 *, const struct net_device___78 *, int *, int);
};

struct block_device_operations___160;

struct gendisk___163 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___163 *part0;
	const struct block_device_operations___160 *fops;
	struct request_queue___160 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___146 *bdi;
	struct kobject___257 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___257 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___160 {
	struct bio___160 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___186 *bip_vec;
	struct bio_vec___186 bip_inline_vecs[0];
};

struct blkcg___148;

struct blkg_policy_data___148;

struct blkcg_gq___148 {
	struct request_queue___160 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___148 *blkcg;
	struct blkcg_gq___148 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___148 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___160 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___160(struct request___160 *);

typedef void integrity_complete_fn___160(struct request___160 *, unsigned int);

struct blk_integrity_profile___160 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___160 *prepare_fn;
	integrity_complete_fn___160 *complete_fn;
	const char *name;
};

struct block_device_operations___160 {
	blk_qc_t (*submit_bio)(struct bio___160 *);
	int (*open)(struct block_device___163 *, fmode_t);
	void (*release)(struct gendisk___163 *, fmode_t);
	int (*rw_page)(struct block_device___163 *, sector_t, struct page___274 *, unsigned int);
	int (*ioctl)(struct block_device___163 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___163 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___163 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___163 *);
	int (*getgeo)(struct block_device___163 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___163 *, bool);
	void (*swap_slot_free_notify)(struct block_device___163 *, long unsigned int);
	int (*report_zones)(struct gendisk___163 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___163 *, umode_t *);
	struct module___253 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___163 *, sector_t *);
};

typedef void rq_end_io_fn___160(struct request___160 *, blk_status_t);

struct request___160 {
	struct request_queue___160 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___155 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___160 *bio;
	struct bio___160 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___186 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___160 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___160 *saved_end_io;
		} flush;
	};
	struct gendisk___163 *rq_disk;
	struct block_device___163 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___160 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___155 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___160 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___257 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___269 *debugfs_dir;
	struct dentry___269 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___160;

struct elevator_mq_ops___160 {
	int (*init_sched)(struct request_queue___160 *, struct elevator_type___160 *);
	void (*exit_sched)(struct elevator_queue___160 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___155 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___155 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___155 *);
	bool (*allow_merge)(struct request_queue___160 *, struct request___160 *, struct bio___160 *);
	bool (*bio_merge)(struct request_queue___160 *, struct bio___160 *, unsigned int);
	int (*request_merge)(struct request_queue___160 *, struct request___160 **, struct bio___160 *);
	void (*request_merged)(struct request_queue___160 *, struct request___160 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___160 *, struct request___160 *, struct request___160 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___160 *);
	void (*finish_request)(struct request___160 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___155 *, struct list_head *, bool);
	struct request___160 * (*dispatch_request)(struct blk_mq_hw_ctx___155 *);
	bool (*has_work)(struct blk_mq_hw_ctx___155 *);
	void (*completed_request)(struct request___160 *, u64);
	void (*requeue_request)(struct request___160 *);
	struct request___160 * (*former_request)(struct request_queue___160 *, struct request___160 *);
	struct request___160 * (*next_request)(struct request_queue___160 *, struct request___160 *);
	void (*init_icq)(struct io_cq___160 *);
	void (*exit_icq)(struct io_cq___160 *);
};

struct elv_fs_entry___160;

struct elevator_type___160 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___160 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___160 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___253 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___160 {
	struct elevator_type___160 *type;
	void *elevator_data;
	struct kobject___257 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___160 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___160 *, char *);
	ssize_t (*store)(struct elevator_queue___160 *, const char *, size_t);
};

struct blk_mq_queue_data___155;

struct blk_mq_ops___155 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___155 *, const struct blk_mq_queue_data___155 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___155 *);
	int (*get_budget)(struct request_queue___160 *);
	void (*put_budget)(struct request_queue___160 *, int);
	void (*set_rq_budget_token)(struct request___160 *, int);
	int (*get_rq_budget_token)(struct request___160 *);
	enum blk_eh_timer_return (*timeout)(struct request___160 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___155 *);
	void (*complete)(struct request___160 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___155 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___155 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___155 *, struct request___160 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___155 *, struct request___160 *, unsigned int);
	void (*initialize_rq_fn)(struct request___160 *);
	void (*cleanup_rq)(struct request___160 *);
	bool (*busy)(struct request_queue___160 *);
	int (*map_queues)(struct blk_mq_tag_set___155 *);
	void (*show_rq)(struct seq_file___244 *, struct request___160 *);
};

struct blk_mq_tag_set___155 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___155 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___155 {
	struct request___160 *rq;
	bool last;
};

struct blkcg_policy_data___148;

struct blkcg___148 {
	struct cgroup_subsys_state___196 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___148 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___148 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___148 {
	struct blkcg___148 *blkcg;
	int plid;
};

struct blkg_policy_data___148 {
	struct blkcg_gq___148 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___134 {
	struct mem_cgroup___134 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___134 {
	struct lruvec___142 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___134 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___134 *memcg;
};

struct obj_cgroup___134 {
	struct percpu_ref refcnt;
	struct mem_cgroup___134 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___72 {
	spinlock_t *lock;
	struct sk_buff___79 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___72;

struct Qdisc_ops___72 {
	struct Qdisc_ops___72 *next;
	const struct Qdisc_class_ops___72 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___79 *, struct Qdisc___72 *, struct sk_buff___79 **);
	struct sk_buff___79 * (*dequeue)(struct Qdisc___72 *);
	struct sk_buff___79 * (*peek)(struct Qdisc___72 *);
	int (*init)(struct Qdisc___72 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___72 *);
	void (*destroy)(struct Qdisc___72 *);
	int (*change)(struct Qdisc___72 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___72 *);
	int (*change_tx_queue_len)(struct Qdisc___72 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___72 *, unsigned int);
	int (*dump)(struct Qdisc___72 *, struct sk_buff___79 *);
	int (*dump_stats)(struct Qdisc___72 *, struct gnet_dump___72 *);
	void (*ingress_block_set)(struct Qdisc___72 *, u32);
	void (*egress_block_set)(struct Qdisc___72 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___72 *);
	u32 (*egress_block_get)(struct Qdisc___72 *);
	struct module___253 *owner;
};

struct Qdisc_class_ops___72 {
	unsigned int flags;
	struct netdev_queue___78 * (*select_queue)(struct Qdisc___72 *, struct tcmsg *);
	int (*graft)(struct Qdisc___72 *, long unsigned int, struct Qdisc___72 *, struct Qdisc___72 **, struct netlink_ext_ack *);
	struct Qdisc___72 * (*leaf)(struct Qdisc___72 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___72 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___72 *, u32);
	int (*change)(struct Qdisc___72 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___72 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___72 *, struct qdisc_walker *);
	struct tcf_block___72 * (*tcf_block)(struct Qdisc___72 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___72 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___72 *, long unsigned int);
	int (*dump)(struct Qdisc___72 *, long unsigned int, struct sk_buff___79 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___72 *, long unsigned int, struct gnet_dump___72 *);
};

struct tcf_chain___72;

struct tcf_block___72 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___83 *net;
	struct Qdisc___72 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___72 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___72;

struct tcf_proto_ops___72;

struct tcf_proto___72 {
	struct tcf_proto___72 *next;
	void *root;
	int (*classify)(struct sk_buff___79 *, const struct tcf_proto___72 *, struct tcf_result___72 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___72 *ops;
	struct tcf_chain___72 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___72 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___72 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___72 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___79 *, const struct tcf_proto___72 *, struct tcf_result___72 *);
	int (*init)(struct tcf_proto___72 *);
	void (*destroy)(struct tcf_proto___72 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___72 *, u32);
	void (*put)(struct tcf_proto___72 *, void *);
	int (*change)(struct net___83 *, struct sk_buff___79 *, struct tcf_proto___72 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___72 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___72 *);
	void (*walk)(struct tcf_proto___72 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___72 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___72 *, void *);
	void (*hw_del)(struct tcf_proto___72 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___83 *, struct tcf_chain___72 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___83 *, struct tcf_proto___72 *, void *, struct sk_buff___79 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___83 *, struct tcf_proto___72 *, void *, struct sk_buff___79 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___79 *, struct net___83 *, void *);
	struct module___253 *owner;
	int flags;
};

struct tcf_chain___72 {
	struct mutex filter_chain_lock;
	struct tcf_proto___72 *filter_chain;
	struct list_head list;
	struct tcf_block___72 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___72 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___65 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___72 *prog;
};

struct pneigh_entry___65;

struct neigh_hash_table___65;

struct neigh_table___65 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___78 *, __u32 *);
	bool (*key_eq)(const struct neighbour___65 *, const void *);
	int (*constructor)(struct neighbour___65 *);
	int (*pconstructor)(struct pneigh_entry___65 *);
	void (*pdestructor)(struct pneigh_entry___65 *);
	void (*proxy_redo)(struct sk_buff___79 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___78 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___65 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___78 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___65 *nht;
	struct pneigh_entry___65 **phash_buckets;
};

struct neigh_ops___65 {
	int family;
	void (*solicit)(struct neighbour___65 *, struct sk_buff___79 *);
	void (*error_report)(struct neighbour___65 *, struct sk_buff___79 *);
	int (*output)(struct neighbour___65 *, struct sk_buff___79 *);
	int (*connected_output)(struct neighbour___65 *, struct sk_buff___79 *);
};

struct pneigh_entry___65 {
	struct pneigh_entry___65 *next;
	possible_net_t___78 net;
	struct net_device___78 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___65 {
	struct neighbour___65 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___41 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___83 *, struct sock___65 *, struct sk_buff___79 *);
	int (*orig_input)(struct sk_buff___79 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___65 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___65 *ctarget;
	struct net___83 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___65 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___65 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___50;

struct timewait_sock_ops___49;

struct proto___65 {
	void (*close)(struct sock___65 *, long int);
	int (*pre_connect)(struct sock___65 *, struct sockaddr *, int);
	int (*connect)(struct sock___65 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___65 *, int);
	struct sock___65 * (*accept)(struct sock___65 *, int, int *, bool);
	int (*ioctl)(struct sock___65 *, int, long unsigned int);
	int (*init)(struct sock___65 *);
	void (*destroy)(struct sock___65 *);
	void (*shutdown)(struct sock___65 *, int);
	int (*setsockopt)(struct sock___65 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___65 *, int, int, char *, int *);
	void (*keepalive)(struct sock___65 *, int);
	int (*compat_ioctl)(struct sock___65 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___65 *, struct msghdr___67 *, size_t);
	int (*recvmsg)(struct sock___65 *, struct msghdr___67 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___65 *, struct page___274 *, int, size_t, int);
	int (*bind)(struct sock___65 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___65 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___65 *, struct sk_buff___79 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___65 *);
	int (*hash)(struct sock___65 *);
	void (*unhash)(struct sock___65 *);
	void (*rehash)(struct sock___65 *);
	int (*get_port)(struct sock___65 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___65 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___65 *, int);
	bool (*sock_is_readable)(struct sock___65 *);
	void (*enter_memory_pressure)(struct sock___65 *);
	void (*leave_memory_pressure)(struct sock___65 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___50 *rsk_prot;
	struct timewait_sock_ops___49 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___253 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___65 *, int);
};

struct xfrm_policy_queue___10 {
	struct sk_buff_head___78 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___10 {
	possible_net_t___78 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___10 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___17 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___72 *prog;
	struct sock___65 *socks[0];
};

struct request_sock___51;

struct request_sock_ops___50 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___65 *, struct request_sock___51 *);
	void (*send_ack)(const struct sock___65 *, struct sk_buff___79 *, struct request_sock___51 *);
	void (*send_reset)(const struct sock___65 *, struct sk_buff___79 *);
	void (*destructor)(struct request_sock___51 *);
	void (*syn_ack_timeout)(const struct request_sock___51 *);
};

struct timewait_sock_ops___49 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___65 *, struct sock___65 *, void *);
	void (*twsk_destructor)(struct sock___65 *);
};

struct request_sock___51 {
	struct sock_common___65 __req_common;
	struct request_sock___51 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___50 *rsk_ops;
	struct sock___65 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___47 {
	struct in6_addr mca_addr;
	struct inet6_dev___47 *idev;
	struct ifmcaddr6___47 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___15 {
	struct in6_addr aca_addr;
	struct fib6_info___15 *aca_rt;
	struct ifacaddr6___15 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___15 {
	struct fib_nh_exception___15 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___15 *fnhe_rth_input;
	struct rtable___15 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___15 {
	struct dst_entry___65 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___15 {
	struct fib_nh_exception___15 *chain;
};

struct nf_hook_state___10 {
	u8 hook;
	u8 pf;
	struct net_device___78 *in;
	struct net_device___78 *out;
	struct sock___65 *sk;
	struct net___83 *net;
	int (*okfn)(struct net___83 *, struct sock___65 *, struct sk_buff___79 *);
};

struct xfrm_type___10 {
	struct module___253 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___10 *);
	void (*destructor)(struct xfrm_state___10 *);
	int (*input)(struct xfrm_state___10 *, struct sk_buff___79 *);
	int (*output)(struct xfrm_state___10 *, struct sk_buff___79 *);
	int (*reject)(struct xfrm_state___10 *, struct sk_buff___79 *, const struct flowi *);
};

struct xfrm_type_offload___10 {
	struct module___253 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___10 *, struct sk_buff___79 *);
	int (*input_tail)(struct xfrm_state___10 *, struct sk_buff___79 *);
	int (*xmit)(struct xfrm_state___10 *, struct sk_buff___79 *, netdev_features_t);
};

struct sec_path___5 {
	int len;
	int olen;
	struct xfrm_state___10 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ip_options_rcu___2 {
	struct callback_head rcu;
	struct ip_options___2 opt;
};

struct nl_info___5 {
	struct nlmsghdr *nlh;
	struct net___83 *nl_net;
	u32 portid;
	u8 skip_notify;
	u8 skip_notify_kernel;
	long: 56;
	long: 64;
	long: 64;
};

struct ip_options_data {
	struct ip_options_rcu opt;
	char data[40];
};

struct fib6_config___5;

struct ipv6_stub___5 {
	int (*ipv6_sock_mc_join)(struct sock___65 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___65 *, int, const struct in6_addr *);
	struct dst_entry___65 * (*ipv6_dst_lookup_flow)(struct net___83 *, const struct sock___65 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___79 *);
	struct fib6_table___15 * (*fib6_get_table)(struct net___83 *, u32);
	int (*fib6_lookup)(struct net___83 *, int, struct flowi6 *, struct fib6_result___3 *, int);
	int (*fib6_table_lookup)(struct net___83 *, struct fib6_table___15 *, int, struct flowi6 *, struct fib6_result___3 *, int);
	void (*fib6_select_path)(const struct net___83 *, struct fib6_result___3 *, struct flowi6 *, int, bool, const struct sk_buff___79 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___3 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___83 *, struct fib6_nh___15 *, struct fib6_config___5 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___15 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___15 *);
	void (*fib6_update_sernum)(struct net___83 *, struct fib6_info___15 *);
	int (*ip6_del_rt)(struct net___83 *, struct fib6_info___15 *, bool);
	void (*fib6_rt_update)(struct net___83 *, struct fib6_info___15 *, struct nl_info___5 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___78 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___79 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___65 *, struct sk_buff___79 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___79 *, int, __be32, int);
	struct neigh_table___65 *nd_tbl;
	int (*ipv6_fragment)(struct net___83 *, struct sock___65 *, struct sk_buff___79 *, int (*)(struct net___83 *, struct sock___65 *, struct sk_buff___79 *));
	struct net_device___78 * (*ipv6_dev_find)(struct net___83 *, const struct in6_addr *, struct net_device___78 *);
};

struct fib6_config___5 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___5 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct ipcm_cookie {
	struct sockcm_cookie sockc;
	__be32 addr;
	int oif;
	struct ip_options_rcu *opt;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
};

struct ip_fraglist_iter {
	struct sk_buff___79 *frag;
	struct iphdr *iph;
	int offset;
	unsigned int hlen;
};

struct ip_frag_state {
	bool DF;
	unsigned int hlen;
	unsigned int ll_rs;
	unsigned int mtu;
	unsigned int left;
	int offset;
	int ptr;
	__be16 not_last_frag;
};

struct ip_reply_arg {
	struct kvec iov[1];
	int flags;
	__wsum csum;
	int csumoffset;
	int bound_dev_if;
	u8 tos;
	kuid_t uid;
};

struct ip_mreq_source {
	__be32 imr_multiaddr;
	__be32 imr_interface;
	__be32 imr_sourceaddr;
};

struct ip_msfilter {
	union {
		struct {
			__be32 imsf_multiaddr_aux;
			__be32 imsf_interface_aux;
			__u32 imsf_fmode_aux;
			__u32 imsf_numsrc_aux;
			__be32 imsf_slist[1];
		};
		struct {
			__be32 imsf_multiaddr;
			__be32 imsf_interface;
			__u32 imsf_fmode;
			__u32 imsf_numsrc;
			__be32 imsf_slist_flex[0];
		};
	};
};

struct group_req {
	__u32 gr_interface;
	struct __kernel_sockaddr_storage gr_group;
};

struct group_source_req {
	__u32 gsr_interface;
	struct __kernel_sockaddr_storage gsr_group;
	struct __kernel_sockaddr_storage gsr_source;
};

struct group_filter {
	union {
		struct {
			__u32 gf_interface_aux;
			struct __kernel_sockaddr_storage gf_group_aux;
			__u32 gf_fmode_aux;
			__u32 gf_numsrc_aux;
			struct __kernel_sockaddr_storage gf_slist[1];
		};
		struct {
			__u32 gf_interface;
			struct __kernel_sockaddr_storage gf_group;
			__u32 gf_fmode;
			__u32 gf_numsrc;
			struct __kernel_sockaddr_storage gf_slist_flex[0];
		};
	};
};

struct in_pktinfo {
	int ipi_ifindex;
	struct in_addr ipi_spec_dst;
	struct in_addr ipi_addr;
};

struct ip_mc_list {
	struct in_device *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list *next;
		struct ip_mc_list *next_rcu;
	};
	struct ip_mc_list *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

typedef unsigned int nf_hookfn___12(void *, struct sk_buff___79 *, const struct nf_hook_state___5 *);

struct compat_group_req {
	__u32 gr_interface;
	struct __kernel_sockaddr_storage gr_group;
} __attribute__((packed));

struct compat_group_source_req {
	__u32 gsr_interface;
	struct __kernel_sockaddr_storage gsr_group;
	struct __kernel_sockaddr_storage gsr_source;
} __attribute__((packed));

struct compat_group_filter {
	union {
		struct {
			__u32 gf_interface_aux;
			struct __kernel_sockaddr_storage gf_group_aux;
			__u32 gf_fmode_aux;
			__u32 gf_numsrc_aux;
			struct __kernel_sockaddr_storage gf_slist[1];
		} __attribute__((packed));
		struct {
			__u32 gf_interface;
			struct __kernel_sockaddr_storage gf_group;
			__u32 gf_fmode;
			__u32 gf_numsrc;
			struct __kernel_sockaddr_storage gf_slist_flex[0];
		} __attribute__((packed));
	};
} __attribute__((packed));

enum {
	BPFILTER_IPT_SO_SET_REPLACE = 64,
	BPFILTER_IPT_SO_SET_ADD_COUNTERS = 65,
	BPFILTER_IPT_SET_MAX = 66,
};

enum {
	BPFILTER_IPT_SO_GET_INFO = 64,
	BPFILTER_IPT_SO_GET_ENTRIES = 65,
	BPFILTER_IPT_SO_GET_REVISION_MATCH = 66,
	BPFILTER_IPT_SO_GET_REVISION_TARGET = 67,
	BPFILTER_IPT_GET_MAX = 68,
};

struct inet_request_sock___3 {
	struct request_sock___51 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___79 *pktopts;
		};
	};
};

struct tcp_request_sock_ops___2;

struct tcp_request_sock___2 {
	struct inet_request_sock___3 req;
	const struct tcp_request_sock_ops___2 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

enum tcp_synack_type {
	TCP_SYNACK_NORMAL = 0,
	TCP_SYNACK_FASTOPEN = 1,
	TCP_SYNACK_COOKIE = 2,
};

struct tcp_request_sock_ops___2 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___65 *, const struct sock___65 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___65 *, const struct sk_buff___79 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___79 *, __u16 *);
	struct dst_entry___65 * (*route_req)(const struct sock___65 *, struct sk_buff___79 *, struct flowi *, struct request_sock___51 *);
	u32 (*init_seq)(const struct sk_buff___79 *);
	u32 (*init_ts_off)(const struct net___83 *, const struct sk_buff___79 *);
	int (*send_synack)(const struct sock___65 *, struct dst_entry___65 *, struct flowi *, struct request_sock___51 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___79 *);
};

struct dentry___270;

struct super_block___270;

struct module___254;

struct file_system_type___270 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___270 * (*mount)(struct file_system_type___270 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___270 *);
	struct module___254 *owner;
	struct file_system_type___270 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___270;

struct kiocb___270;

struct iov_iter___190;

struct poll_table_struct___191;

struct vm_area_struct___275;

struct inode___270;

struct file_lock___270;

struct page___275;

struct pipe_inode_info___111;

struct seq_file___245;

struct file_operations___271 {
	struct module___254 *owner;
	loff_t (*llseek)(struct file___270 *, loff_t, int);
	ssize_t (*read)(struct file___270 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___270 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___270 *, struct iov_iter___190 *);
	ssize_t (*write_iter)(struct kiocb___270 *, struct iov_iter___190 *);
	int (*iopoll)(struct kiocb___270 *, bool);
	int (*iterate)(struct file___270 *, struct dir_context *);
	int (*iterate_shared)(struct file___270 *, struct dir_context *);
	__poll_t (*poll)(struct file___270 *, struct poll_table_struct___191 *);
	long int (*unlocked_ioctl)(struct file___270 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___270 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___270 *, struct vm_area_struct___275 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___270 *, struct file___270 *);
	int (*flush)(struct file___270 *, fl_owner_t);
	int (*release)(struct inode___270 *, struct file___270 *);
	int (*fsync)(struct file___270 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___270 *, int);
	int (*lock)(struct file___270 *, int, struct file_lock___270 *);
	ssize_t (*sendpage)(struct file___270 *, struct page___275 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___270 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___270 *, long unsigned int);
	int (*flock)(struct file___270 *, int, struct file_lock___270 *);
	ssize_t (*splice_write)(struct pipe_inode_info___111 *, struct file___270 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___270 *, loff_t *, struct pipe_inode_info___111 *, size_t, unsigned int);
	int (*setlease)(struct file___270 *, long int, struct file_lock___270 **, void **);
	long int (*fallocate)(struct file___270 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___245 *, struct file___270 *);
	ssize_t (*copy_file_range)(struct file___270 *, loff_t, struct file___270 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___270 *, loff_t, struct file___270 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___270 *, loff_t, loff_t, int);
};

struct vmacache___275 {
	u64 seqnum;
	struct vm_area_struct___275 *vmas[4];
};

struct page_frag___275 {
	struct page___275 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___276;

struct pid___247;

struct nsproxy___256;

struct signal_struct___271;

struct bio_list___161;

struct backing_dev_info___147;

struct io_context___161;

struct css_set___197;

struct mem_cgroup___135;

struct request_queue___161;

struct vm_struct___253;

struct task_struct___277 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___277 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___276 *mm;
	struct mm_struct___276 *active_mm;
	struct vmacache___275 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___277 *real_parent;
	struct task_struct___277 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___277 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___247 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___256 *nsproxy;
	struct signal_struct___271 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___277 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___161 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___147 *backing_dev_info;
	struct io_context___161 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___197 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___111 *splice_pipe;
	struct page_frag___275 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___135 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___135 *active_memcg;
	struct request_queue___161 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___277 *oom_reaper_list;
	struct vm_struct___253 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___258;

struct kobj_type___258;

struct kernfs_node___258;

struct kobject___258 {
	const char *name;
	struct list_head entry;
	struct kobject___258 *parent;
	struct kset___258 *kset;
	struct kobj_type___258 *ktype;
	struct kernfs_node___258 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___255 {
	struct kobject___258 kobj;
	struct module___254 *mod;
	struct kobject___258 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___254 {
	struct module___254 *mod;
	struct latch_tree_node node;
};

struct module_layout___254 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___254 mtn;
};

struct module_attribute___254;

struct kernel_param___254;

struct module___254 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___255 mkobj;
	struct module_attribute___254 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___258 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___254 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___254 core_layout;
	struct module_layout___254 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___275 *pgtable_t___275;

struct address_space___270;

struct page_pool___99;

struct dev_pagemap___265;

struct page___275 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___270 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___99 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___275 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___275 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___276 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___265 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___265;

struct vm_area_struct___275 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___275 *vm_next;
	struct vm_area_struct___275 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___276 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___265 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___270 *vm_file;
	struct file___270 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___275;

struct mm_struct___276 {
	struct {
		struct vm_area_struct___275 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___270 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___275 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___277 *owner;
		struct user_namespace___26 *user_ns;
		struct file___270 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___270;

struct address_space___270 {
	struct inode___270 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___270 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___251;

struct page_pool_params___99 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___251 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___99 {
	u32 count;
	struct page___275 *cache[128];
};

struct page_pool___99 {
	struct page_pool_params___99 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___275 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___99 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___265;

struct dev_pagemap___265 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___265 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___270;

struct path___270 {
	struct vfsmount___270 *mnt;
	struct dentry___270 *dentry;
};

struct fown_struct___247 {
	rwlock_t lock;
	struct pid___247 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___270 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___270 f_path;
	struct inode___270 *f_inode;
	const struct file_operations___271 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___247 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___270 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___265;

struct vm_operations_struct___265 {
	void (*open)(struct vm_area_struct___275 *);
	void (*close)(struct vm_area_struct___275 *);
	int (*may_split)(struct vm_area_struct___275 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___275 *);
	int (*mprotect)(struct vm_area_struct___275 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___265 *);
	vm_fault_t (*huge_fault)(struct vm_fault___265 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___265 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___275 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___265 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___265 *);
	int (*access)(struct vm_area_struct___275 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___275 *);
	int (*set_policy)(struct vm_area_struct___275 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___275 *, long unsigned int);
	struct page___275 * (*find_special_page)(struct vm_area_struct___275 *, long unsigned int);
};

struct core_thread___275 {
	struct task_struct___277 *task;
	struct core_thread___275 *next;
};

struct core_state___275 {
	atomic_t nr_threads;
	struct core_thread___275 dumper;
	struct completion startup;
};

struct vm_fault___265 {
	const struct {
		struct vm_area_struct___275 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___275 *cow_page;
	struct page___275 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___275 prealloc_pte;
};

struct pglist_data___143;

struct lruvec___143 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___143 *pgdat;
};

struct zone___143 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___143 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___143 {
	struct zone___143 *zone;
	int zone_idx;
};

struct zonelist___143 {
	struct zoneref___143 _zonerefs[321];
};

struct pglist_data___143 {
	struct zone___143 node_zones[5];
	struct zonelist___143 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___277 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___277 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___143 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct crypto_async_request___10;

typedef void (*crypto_completion_t___10)(struct crypto_async_request___10 *, int);

struct crypto_tfm___25;

struct crypto_async_request___10 {
	struct list_head list;
	crypto_completion_t___10 complete;
	void *data;
	struct crypto_tfm___25 *tfm;
	u32 flags;
};

struct crypto_alg___25;

struct crypto_tfm___25 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___25 *);
	struct crypto_alg___25 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___25 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___25 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___25 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___25 *, u8 *, const u8 *);
};

struct compress_alg___25 {
	int (*coa_compress)(struct crypto_tfm___25 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___25 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___25 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___25 cipher;
		struct compress_alg___25 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___25 *);
	void (*cra_exit)(struct crypto_tfm___25 *);
	void (*cra_destroy)(struct crypto_alg___25 *);
	struct module___254 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ahash_request___7 {
	struct crypto_async_request___10 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_ahash___6 {
	int (*init)(struct ahash_request___7 *);
	int (*update)(struct ahash_request___7 *);
	int (*final)(struct ahash_request___7 *);
	int (*finup)(struct ahash_request___7 *);
	int (*digest)(struct ahash_request___7 *);
	int (*export)(struct ahash_request___7 *, void *);
	int (*import)(struct ahash_request___7 *, const void *);
	int (*setkey)(struct crypto_ahash___6 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___25 base;
};

struct pid_namespace___247;

struct upid___247 {
	int nr;
	struct pid_namespace___247 *ns;
};

struct pid_namespace___247 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___277 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___247 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___247 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___247 numbers[1];
};

struct signal_struct___271 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___277 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___277 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___247 *pids[4];
	struct pid___247 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___276 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___84;

struct cgroup_namespace___197;

struct nsproxy___256 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___247 *pid_ns_for_children;
	struct net___84 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___197 *cgroup_ns;
};

struct bio___161;

struct bio_list___161 {
	struct bio___161 *head;
	struct bio___161 *tail;
};

struct cgroup_subsys_state___197;

struct bdi_writeback___147 {
	struct backing_dev_info___147 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___197 *memcg_css;
	struct cgroup_subsys_state___197 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___147 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___147 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___251 *dev;
	char dev_name[64];
	struct device___251 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___270 *debug_dir;
};

struct io_cq___161;

struct io_context___161 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___161 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___197;

struct css_set___197 {
	struct cgroup_subsys_state___197 *subsys[14];
	refcount_t refcount;
	struct css_set___197 *dom_cset;
	struct cgroup___197 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___197 *mg_src_cgrp;
	struct cgroup___197 *mg_dst_cgrp;
	struct css_set___197 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___270;

struct pipe_buffer___111;

struct pipe_inode_info___111 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___275 *tmp_page;
	struct fasync_struct___270 *fasync_readers;
	struct fasync_struct___270 *fasync_writers;
	struct pipe_buffer___111 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___197;

struct cgroup_subsys_state___197 {
	struct cgroup___197 *cgroup;
	struct cgroup_subsys___197 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___197 *parent;
};

struct cgroup_file___197 {
	struct kernfs_node___258 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___135;

struct mem_cgroup_per_node___135;

struct mem_cgroup___135 {
	struct cgroup_subsys_state___197 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___197 events_file;
	struct cgroup_file___197 events_local_file;
	struct cgroup_file___197 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___135 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___277 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___135 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___161;

struct blk_integrity___161 {
	const struct blk_integrity_profile___161 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___161 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___161 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___161;

struct elevator_queue___161;

struct blk_mq_ops___156;

struct blk_mq_hw_ctx___156;

struct gendisk___164;

struct blkcg_gq___149;

struct blk_mq_tag_set___156;

struct request_queue___161 {
	struct request___161 *last_merge;
	struct elevator_queue___161 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___156 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___156 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___164 *disk;
	struct kobject___258 kobj;
	struct kobject___258 *mq_kobj;
	struct blk_integrity___161 integrity;
	struct device___251 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___149 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___156 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___161 bio_split;
	struct dentry___270 *debugfs_dir;
	struct dentry___270 *sched_debugfs_dir;
	struct dentry___270 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___253 {
	struct vm_struct___253 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___275 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___270;

struct dentry___270 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___270 *d_parent;
	struct qstr d_name;
	struct inode___270 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___270 *d_op;
	struct super_block___270 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___270;

struct inode___270 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___270 *i_op;
	struct super_block___270 *i_sb;
	struct address_space___270 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___147 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___271 *i_fop;
		void (*free_inode)(struct inode___270 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___270 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___111 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___270 {
	int (*d_revalidate)(struct dentry___270 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___270 *, unsigned int);
	int (*d_hash)(const struct dentry___270 *, struct qstr *);
	int (*d_compare)(const struct dentry___270 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___270 *);
	int (*d_init)(struct dentry___270 *);
	void (*d_release)(struct dentry___270 *);
	void (*d_prune)(struct dentry___270 *);
	void (*d_iput)(struct dentry___270 *, struct inode___270 *);
	char * (*d_dname)(struct dentry___270 *, char *, int);
	struct vfsmount___270 * (*d_automount)(struct path___270 *);
	int (*d_manage)(const struct path___270 *, bool);
	struct dentry___270 * (*d_real)(struct dentry___270 *, const struct inode___270 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___270;

struct mem_dqinfo___270 {
	struct quota_format_type___270 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___270;

struct quota_info___270 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___270 *files[3];
	struct mem_dqinfo___270 info[3];
	const struct quota_format_ops___270 *ops[3];
};

struct rcuwait___271 {
	struct task_struct___277 *task;
};

struct percpu_rw_semaphore___271 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___271 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___270 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___271 rw_sem[3];
};

struct shrink_control___135;

struct shrinker___135 {
	long unsigned int (*count_objects)(struct shrinker___135 *, struct shrink_control___135 *);
	long unsigned int (*scan_objects)(struct shrinker___135 *, struct shrink_control___135 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___270;

struct dquot_operations___270;

struct quotactl_ops___270;

struct block_device___164;

struct super_block___270 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___270 *s_type;
	const struct super_operations___270 *s_op;
	const struct dquot_operations___270 *dq_op;
	const struct quotactl_ops___270 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___270 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___164 *s_bdev;
	struct backing_dev_info___147 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___270 s_dquot;
	struct sb_writers___270 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___270 *s_d_op;
	int cleancache_poolid;
	struct shrinker___135 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___270 {
	struct dentry___270 *mnt_root;
	struct super_block___270 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___135 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___135 *memcg;
};

struct psi_group___197 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___277 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___73;

struct cgroup_bpf___73 {
	struct bpf_prog_array___73 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___73 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___197;

struct cgroup_rstat_cpu___197;

struct cgroup___197 {
	struct cgroup_subsys_state___197 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___258 *kn;
	struct cgroup_file___197 procs_file;
	struct cgroup_file___197 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___197 *subsys[14];
	struct cgroup_root___197 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___197 *dom_cgrp;
	struct cgroup___197 *old_dom_cgrp;
	struct cgroup_rstat_cpu___197 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___197 psi;
	struct cgroup_bpf___73 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___161 {
	struct request_queue___161 *q;
	struct io_context___161 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___115;

struct kiocb___270 {
	struct file___270 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___270 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___115 *ki_waitq;
	};
};

struct iattr___270 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___270 *ia_file;
};

struct dquot___270 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___270 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___270 {
	int qf_fmt_id;
	const struct quota_format_ops___270 *qf_ops;
	struct module___254 *qf_owner;
	struct quota_format_type___270 *qf_next;
};

struct quota_format_ops___270 {
	int (*check_quota_file)(struct super_block___270 *, int);
	int (*read_file_info)(struct super_block___270 *, int);
	int (*write_file_info)(struct super_block___270 *, int);
	int (*free_file_info)(struct super_block___270 *, int);
	int (*read_dqblk)(struct dquot___270 *);
	int (*commit_dqblk)(struct dquot___270 *);
	int (*release_dqblk)(struct dquot___270 *);
	int (*get_next_id)(struct super_block___270 *, struct kqid *);
};

struct dquot_operations___270 {
	int (*write_dquot)(struct dquot___270 *);
	struct dquot___270 * (*alloc_dquot)(struct super_block___270 *, int);
	void (*destroy_dquot)(struct dquot___270 *);
	int (*acquire_dquot)(struct dquot___270 *);
	int (*release_dquot)(struct dquot___270 *);
	int (*mark_dirty)(struct dquot___270 *);
	int (*write_info)(struct super_block___270 *, int);
	qsize_t * (*get_reserved_space)(struct inode___270 *);
	int (*get_projid)(struct inode___270 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___270 *, qsize_t *);
	int (*get_next_id)(struct super_block___270 *, struct kqid *);
};

struct quotactl_ops___270 {
	int (*quota_on)(struct super_block___270 *, int, int, const struct path___270 *);
	int (*quota_off)(struct super_block___270 *, int);
	int (*quota_enable)(struct super_block___270 *, unsigned int);
	int (*quota_disable)(struct super_block___270 *, unsigned int);
	int (*quota_sync)(struct super_block___270 *, int);
	int (*set_info)(struct super_block___270 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___270 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___270 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___270 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___270 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___270 *, unsigned int);
};

struct wait_page_queue___115 {
	struct page___275 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___147;

struct readahead_control___115;

struct swap_info_struct___68;

struct address_space_operations___270 {
	int (*writepage)(struct page___275 *, struct writeback_control___147 *);
	int (*readpage)(struct file___270 *, struct page___275 *);
	int (*writepages)(struct address_space___270 *, struct writeback_control___147 *);
	int (*set_page_dirty)(struct page___275 *);
	int (*readpages)(struct file___270 *, struct address_space___270 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___115 *);
	int (*write_begin)(struct file___270 *, struct address_space___270 *, loff_t, unsigned int, unsigned int, struct page___275 **, void **);
	int (*write_end)(struct file___270 *, struct address_space___270 *, loff_t, unsigned int, unsigned int, struct page___275 *, void *);
	sector_t (*bmap)(struct address_space___270 *, sector_t);
	void (*invalidatepage)(struct page___275 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___275 *, gfp_t);
	void (*freepage)(struct page___275 *);
	ssize_t (*direct_IO)(struct kiocb___270 *, struct iov_iter___190 *);
	int (*migratepage)(struct address_space___270 *, struct page___275 *, struct page___275 *, enum migrate_mode);
	bool (*isolate_page)(struct page___275 *, isolate_mode_t);
	void (*putback_page)(struct page___275 *);
	int (*launder_page)(struct page___275 *);
	int (*is_partially_uptodate)(struct page___275 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___275 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___270 *, struct page___275 *);
	int (*swap_activate)(struct swap_info_struct___68 *, struct file___270 *, sector_t *);
	void (*swap_deactivate)(struct file___270 *);
};

struct writeback_control___147 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___147 *wb;
	struct inode___270 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___115 {
	struct file___270 *file;
	struct address_space___270 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___187;

struct iov_iter___190 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___187 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___111 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___68 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___164 *bdev;
	struct file___270 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___270 {
	struct dentry___270 * (*lookup)(struct inode___270 *, struct dentry___270 *, unsigned int);
	const char * (*get_link)(struct dentry___270 *, struct inode___270 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___270 *, int);
	struct posix_acl * (*get_acl)(struct inode___270 *, int, bool);
	int (*readlink)(struct dentry___270 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___270 *, struct dentry___270 *, umode_t, bool);
	int (*link)(struct dentry___270 *, struct inode___270 *, struct dentry___270 *);
	int (*unlink)(struct inode___270 *, struct dentry___270 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___270 *, struct dentry___270 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___270 *, struct dentry___270 *, umode_t);
	int (*rmdir)(struct inode___270 *, struct dentry___270 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___270 *, struct dentry___270 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___270 *, struct dentry___270 *, struct inode___270 *, struct dentry___270 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___270 *, struct iattr___270 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___270 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___270 *, char *, size_t);
	int (*fiemap)(struct inode___270 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___270 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___270 *, struct dentry___270 *, struct file___270 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___270 *, struct dentry___270 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___270 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___270 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___270 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___270 {
	void (*fl_copy_lock)(struct file_lock___270 *, struct file_lock___270 *);
	void (*fl_release_private)(struct file_lock___270 *);
};

struct lock_manager_operations___270;

struct file_lock___270 {
	struct file_lock___270 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___270 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___270 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___270 *fl_ops;
	const struct lock_manager_operations___270 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___270 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___270 *);
	int (*lm_grant)(struct file_lock___270 *, int);
	bool (*lm_break)(struct file_lock___270 *);
	int (*lm_change)(struct file_lock___270 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___270 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___270 *);
};

struct fasync_struct___270 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___270 *fa_next;
	struct file___270 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___270 {
	struct inode___270 * (*alloc_inode)(struct super_block___270 *);
	void (*destroy_inode)(struct inode___270 *);
	void (*free_inode)(struct inode___270 *);
	void (*dirty_inode)(struct inode___270 *, int);
	int (*write_inode)(struct inode___270 *, struct writeback_control___147 *);
	int (*drop_inode)(struct inode___270 *);
	void (*evict_inode)(struct inode___270 *);
	void (*put_super)(struct super_block___270 *);
	int (*sync_fs)(struct super_block___270 *, int);
	int (*freeze_super)(struct super_block___270 *);
	int (*freeze_fs)(struct super_block___270 *);
	int (*thaw_super)(struct super_block___270 *);
	int (*unfreeze_fs)(struct super_block___270 *);
	int (*statfs)(struct dentry___270 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___270 *, int *, char *);
	void (*umount_begin)(struct super_block___270 *);
	int (*show_options)(struct seq_file___245 *, struct dentry___270 *);
	int (*show_devname)(struct seq_file___245 *, struct dentry___270 *);
	int (*show_path)(struct seq_file___245 *, struct dentry___270 *);
	int (*show_stats)(struct seq_file___245 *, struct dentry___270 *);
	ssize_t (*quota_read)(struct super_block___270 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___270 *, int, const char *, size_t, loff_t);
	struct dquot___270 ** (*get_dquots)(struct inode___270 *);
	long int (*nr_cached_objects)(struct super_block___270 *, struct shrink_control___135 *);
	long int (*free_cached_objects)(struct super_block___270 *, struct shrink_control___135 *);
	struct file___270 * (*real_loop)(struct file___270 *);
};

struct wakeup_source___251;

struct dev_pm_info___251 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___251 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___251 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___251;

struct bus_type___251;

struct device_driver___251;

struct dev_pm_domain___251;

struct fwnode_handle___247;

struct class___251;

struct attribute_group___258;

struct device___251 {
	struct kobject___258 kobj;
	struct device___251 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___251 *type;
	struct bus_type___251 *bus;
	struct device_driver___251 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___251 power;
	struct dev_pm_domain___251 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___247 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___251 *class;
	const struct attribute_group___258 **groups;
	void (*release)(struct device___251 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___164 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___270 *bd_inode;
	struct super_block___270 *bd_super;
	void *bd_claiming;
	struct device___251 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___258 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___164 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___270 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___199)(struct file___270 *, wait_queue_head_t *, struct poll_table_struct___191 *);

struct poll_table_struct___191 {
	poll_queue_proc___199 _qproc;
	__poll_t _key;
};

struct seq_operations___245;

struct seq_file___245 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___245 *op;
	int poll_event;
	const struct file___270 *file;
	void *private;
};

typedef void bio_end_io_t___161(struct bio___161 *);

struct bio_vec___187 {
	struct page___275 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___161;

struct bio___161 {
	struct bio___161 *bi_next;
	struct block_device___164 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___161 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___149 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___161 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___187 *bi_io_vec;
	struct bio_set___161 *bi_pool;
	struct bio_vec___187 bi_inline_vecs[0];
};

struct kernfs_root___258;

struct kernfs_elem_dir___258 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___258 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___258;

struct kernfs_root___258 {
	struct kernfs_node___258 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___258 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___258 {
	struct kernfs_node___258 *target_kn;
};

struct kernfs_ops___258;

struct kernfs_elem_attr___258 {
	const struct kernfs_ops___258 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___258 *notify_next;
};

struct kernfs_node___258 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___258 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___258 dir;
		struct kernfs_elem_symlink___258 symlink;
		struct kernfs_elem_attr___258 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___258;

struct kernfs_ops___258 {
	int (*open)(struct kernfs_open_file___258 *);
	void (*release)(struct kernfs_open_file___258 *);
	int (*seq_show)(struct seq_file___245 *, void *);
	void * (*seq_start)(struct seq_file___245 *, loff_t *);
	void * (*seq_next)(struct seq_file___245 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___245 *, void *);
	ssize_t (*read)(struct kernfs_open_file___258 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___258 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___258 *, struct poll_table_struct___191 *);
	int (*mmap)(struct kernfs_open_file___258 *, struct vm_area_struct___275 *);
};

struct kernfs_syscall_ops___258 {
	int (*show_options)(struct seq_file___245 *, struct kernfs_root___258 *);
	int (*mkdir)(struct kernfs_node___258 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___258 *);
	int (*rename)(struct kernfs_node___258 *, struct kernfs_node___258 *, const char *);
	int (*show_path)(struct seq_file___245 *, struct kernfs_node___258 *, struct kernfs_root___258 *);
};

struct kernfs_open_file___258 {
	struct kernfs_node___258 *kn;
	struct file___270 *file;
	struct seq_file___245 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___265 *vm_ops;
};

struct sock___66;

struct kobj_ns_type_operations___66 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___66 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___84 *net;
} possible_net_t___79;

struct proto___66;

struct sock_common___66 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___66 *skc_prot;
	possible_net_t___79 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___66 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___80;

struct sk_buff_head___79 {
	struct sk_buff___80 *next;
	struct sk_buff___80 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___66 {
	struct cgroup___197 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___66;

struct socket_wq___67;

struct xfrm_policy___11;

struct dst_entry___66;

struct socket___68;

struct net_device___79;

struct sock_reuseport___18;

struct sock___66 {
	struct sock_common___66 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___79 sk_error_queue;
	struct sk_buff___80 *sk_rx_skb_cache;
	struct sk_buff_head___79 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___80 *head;
		struct sk_buff___80 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___66 *sk_filter;
	union {
		struct socket_wq___67 *sk_wq;
		struct socket_wq___67 *sk_wq_raw;
	};
	struct xfrm_policy___11 *sk_policy[2];
	struct dst_entry___66 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___66 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___80 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___80 *sk_tx_skb_cache;
	struct sk_buff_head___79 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___275 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___66 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___247 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___68 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___66 sk_cgrp_data;
	struct mem_cgroup___135 *sk_memcg;
	void (*sk_state_change)(struct sock___66 *);
	void (*sk_data_ready)(struct sock___66 *);
	void (*sk_write_space)(struct sock___66 *);
	void (*sk_error_report)(struct sock___66 *);
	int (*sk_backlog_rcv)(struct sock___66 *, struct sk_buff___80 *);
	struct sk_buff___80 * (*sk_validate_xmit_skb)(struct sock___66 *, struct net_device___79 *, struct sk_buff___80 *);
	void (*sk_destruct)(struct sock___66 *);
	struct sock_reuseport___18 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___258;

struct attribute_group___258 {
	const char *name;
	umode_t (*is_visible)(struct kobject___258 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___258 *, struct bin_attribute___258 *, int);
	struct attribute **attrs;
	struct bin_attribute___258 **bin_attrs;
};

struct bin_attribute___258 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___270 * (*f_mapping)();
	ssize_t (*read)(struct file___270 *, struct kobject___258 *, struct bin_attribute___258 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___270 *, struct kobject___258 *, struct bin_attribute___258 *, char *, loff_t, size_t);
	int (*mmap)(struct file___270 *, struct kobject___258 *, struct bin_attribute___258 *, struct vm_area_struct___275 *);
};

struct sysfs_ops___258 {
	ssize_t (*show)(struct kobject___258 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___258 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___258;

struct kset___258 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___258 kobj;
	const struct kset_uevent_ops___258 *uevent_ops;
};

struct kobj_type___258 {
	void (*release)(struct kobject___258 *);
	const struct sysfs_ops___258 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___258 **default_groups;
	const struct kobj_ns_type_operations___66 * (*child_ns_type)(struct kobject___258 *);
	const void * (*namespace)(struct kobject___258 *);
	void (*get_ownership)(struct kobject___258 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___258 {
	int (* const filter)(struct kset___258 *, struct kobject___258 *);
	const char * (* const name)(struct kset___258 *, struct kobject___258 *);
	int (* const uevent)(struct kset___258 *, struct kobject___258 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___254 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___254 *);
	int (*get)(char *, const struct kernel_param___254 *);
	void (*free)(void *);
};

struct kparam_array___254;

struct kernel_param___254 {
	const char *name;
	struct module___254 *mod;
	const struct kernel_param_ops___254 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___254 *arr;
	};
};

struct kparam_array___254 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___254 *ops;
	void *elem;
};

struct module_attribute___254 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___254 *, struct module_kobject___255 *, char *);
	ssize_t (*store)(struct module_attribute___254 *, struct module_kobject___255 *, const char *, size_t);
	void (*setup)(struct module___254 *, const char *);
	int (*test)(struct module___254 *);
	void (*free)(struct module___254 *);
};

typedef struct poll_table_struct___191 poll_table___49;

struct dev_pagemap_ops___265 {
	void (*page_free)(struct page___275 *);
	void (*kill)(struct dev_pagemap___265 *);
	void (*cleanup)(struct dev_pagemap___265 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___265 *);
};

struct fwnode_operations___247;

struct fwnode_handle___247 {
	struct fwnode_handle___247 *secondary;
	const struct fwnode_operations___247 *ops;
	struct device___251 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___247;

struct fwnode_endpoint___247;

struct fwnode_operations___247 {
	struct fwnode_handle___247 * (*get)(struct fwnode_handle___247 *);
	void (*put)(struct fwnode_handle___247 *);
	bool (*device_is_available)(const struct fwnode_handle___247 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___247 *, const struct device___251 *);
	bool (*property_present)(const struct fwnode_handle___247 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___247 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___247 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___247 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*get_parent)(const struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*get_next_child_node)(const struct fwnode_handle___247 *, struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*get_named_child_node)(const struct fwnode_handle___247 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___247 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___247 *);
	struct fwnode_handle___247 * (*graph_get_next_endpoint)(const struct fwnode_handle___247 *, struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*graph_get_remote_endpoint)(const struct fwnode_handle___247 *);
	struct fwnode_handle___247 * (*graph_get_port_parent)(struct fwnode_handle___247 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___247 *, struct fwnode_endpoint___247 *);
	int (*add_links)(struct fwnode_handle___247 *);
};

struct fwnode_endpoint___247 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___247 *local_fwnode;
};

struct fwnode_reference_args___247 {
	struct fwnode_handle___247 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___39;

struct fib_rules_ops___66;

struct fqdir___84;

struct tcp_congestion_ops___17;

struct fib_notifier_ops___66;

struct netns_ipv4___84 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___39 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___66 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___66 *fibnl;
	struct sock___66 **icmp_sk;
	struct sock___66 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___66 **tcp_sk;
	struct fqdir___84 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___17 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___66 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___66 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___66 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___66;

struct dst_ops___84 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___84 *);
	struct dst_entry___66 * (*check)(struct dst_entry___66 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___66 *);
	unsigned int (*mtu)(const struct dst_entry___66 *);
	u32 * (*cow_metrics)(struct dst_entry___66 *, long unsigned int);
	void (*destroy)(struct dst_entry___66 *);
	void (*ifdown)(struct dst_entry___66 *, struct net_device___79 *, int);
	struct dst_entry___66 * (*negative_advice)(struct dst_entry___66 *);
	void (*link_failure)(struct sk_buff___80 *);
	void (*update_pmtu)(struct dst_entry___66 *, struct sock___66 *, struct sk_buff___80 *, u32, bool);
	void (*redirect)(struct dst_entry___66 *, struct sock___66 *, struct sk_buff___80 *);
	int (*local_out)(struct net___84 *, struct sock___66 *, struct sk_buff___80 *);
	struct neighbour___66 * (*neigh_lookup)(const struct dst_entry___66 *, struct sk_buff___80 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___66 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___16;

struct rt6_info___16;

struct fib6_table___16;

struct netns_ipv6___84 {
	struct dst_ops___84 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___84 *fqdir;
	struct fib6_info___16 *fib6_null_entry;
	struct rt6_info___16 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___16 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___16 *ip6_prohibit_entry;
	struct rt6_info___16 *ip6_blk_hole_entry;
	struct fib6_table___16 *fib6_local_tbl;
	struct fib_rules_ops___66 *fib6_rules_ops;
	struct sock___66 **icmp_sk;
	struct sock___66 *ndisc_sk;
	struct sock___66 *tcp_sk;
	struct sock___66 *igmp_sk;
	struct sock___66 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___66 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___66 *notifier_ops;
	struct fib_notifier_ops___66 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___84 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___84 *fqdir;
};

struct netns_sctp___66 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___66 *ctl_sock;
	struct sock___66 *udp4_sock;
	struct sock___66 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___73;

struct netns_bpf___73 {
	struct bpf_prog_array___73 *run_array[2];
	struct bpf_prog___73 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___84 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___66 *nlsk;
	struct sock___66 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___84 xfrm4_dst_ops;
	struct dst_ops___84 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___84 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___66 *rtnl;
	struct sock___66 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___79 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___84 ipv4;
	struct netns_ipv6___84 ipv6;
	struct netns_ieee802154_lowpan___84 ieee802154_lowpan;
	struct netns_sctp___66 sctp;
	struct netns_nf___10 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___79 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___73 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___84 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___66 *crypto_nlsk;
	struct sock___66 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___197 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___197 *root_cset;
};

struct msghdr___68 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___190 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___270 *msg_iocb;
};

struct socket_wq___67 {
	wait_queue_head_t wait;
	struct fasync_struct___270 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___67;

struct socket___68 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___270 *file;
	struct sock___66 *sk;
	const struct proto_ops___67 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___67 wq;
};

typedef int (*sk_read_actor_t___66)(read_descriptor_t *, struct sk_buff___80 *, unsigned int, size_t);

struct proto_ops___67 {
	int family;
	struct module___254 *owner;
	int (*release)(struct socket___68 *);
	int (*bind)(struct socket___68 *, struct sockaddr *, int);
	int (*connect)(struct socket___68 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___68 *, struct socket___68 *);
	int (*accept)(struct socket___68 *, struct socket___68 *, int, bool);
	int (*getname)(struct socket___68 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___270 *, struct socket___68 *, struct poll_table_struct___191 *);
	int (*ioctl)(struct socket___68 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___68 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___68 *, void *, bool, bool);
	int (*listen)(struct socket___68 *, int);
	int (*shutdown)(struct socket___68 *, int);
	int (*setsockopt)(struct socket___68 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___68 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___245 *, struct socket___68 *);
	int (*sendmsg)(struct socket___68 *, struct msghdr___68 *, size_t);
	int (*recvmsg)(struct socket___68 *, struct msghdr___68 *, size_t, int);
	int (*mmap)(struct file___270 *, struct socket___68 *, struct vm_area_struct___275 *);
	ssize_t (*sendpage)(struct socket___68 *, struct page___275 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___68 *, loff_t *, struct pipe_inode_info___111 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___66 *, int);
	int (*peek_len)(struct socket___68 *);
	int (*read_sock)(struct sock___66 *, read_descriptor_t *, sk_read_actor_t___66);
	int (*sendpage_locked)(struct sock___66 *, struct page___275 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___66 *, struct msghdr___68 *, size_t);
	int (*set_rcvlowat)(struct sock___66 *, int);
};

struct sk_buff___80 {
	union {
		struct {
			struct sk_buff___80 *next;
			struct sk_buff___80 *prev;
			union {
				struct net_device___79 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___66 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___80 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___251 {
	int (*prepare)(struct device___251 *);
	void (*complete)(struct device___251 *);
	int (*suspend)(struct device___251 *);
	int (*resume)(struct device___251 *);
	int (*freeze)(struct device___251 *);
	int (*thaw)(struct device___251 *);
	int (*poweroff)(struct device___251 *);
	int (*restore)(struct device___251 *);
	int (*suspend_late)(struct device___251 *);
	int (*resume_early)(struct device___251 *);
	int (*freeze_late)(struct device___251 *);
	int (*thaw_early)(struct device___251 *);
	int (*poweroff_late)(struct device___251 *);
	int (*restore_early)(struct device___251 *);
	int (*suspend_noirq)(struct device___251 *);
	int (*resume_noirq)(struct device___251 *);
	int (*freeze_noirq)(struct device___251 *);
	int (*thaw_noirq)(struct device___251 *);
	int (*poweroff_noirq)(struct device___251 *);
	int (*restore_noirq)(struct device___251 *);
	int (*runtime_suspend)(struct device___251 *);
	int (*runtime_resume)(struct device___251 *);
	int (*runtime_idle)(struct device___251 *);
};

struct wakeup_source___251 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___251 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___251 {
	struct dev_pm_ops___251 ops;
	int (*start)(struct device___251 *);
	void (*detach)(struct device___251 *, bool);
	int (*activate)(struct device___251 *);
	void (*sync)(struct device___251 *);
	void (*dismiss)(struct device___251 *);
};

struct bus_type___251 {
	const char *name;
	const char *dev_name;
	struct device___251 *dev_root;
	const struct attribute_group___258 **bus_groups;
	const struct attribute_group___258 **dev_groups;
	const struct attribute_group___258 **drv_groups;
	int (*match)(struct device___251 *, struct device_driver___251 *);
	int (*uevent)(struct device___251 *, struct kobj_uevent_env *);
	int (*probe)(struct device___251 *);
	void (*sync_state)(struct device___251 *);
	void (*remove)(struct device___251 *);
	void (*shutdown)(struct device___251 *);
	int (*online)(struct device___251 *);
	int (*offline)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	int (*num_vf)(struct device___251 *);
	int (*dma_configure)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___251 {
	const char *name;
	struct bus_type___251 *bus;
	struct module___254 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___251 *);
	void (*sync_state)(struct device___251 *);
	int (*remove)(struct device___251 *);
	void (*shutdown)(struct device___251 *);
	int (*suspend)(struct device___251 *, pm_message_t);
	int (*resume)(struct device___251 *);
	const struct attribute_group___258 **groups;
	const struct attribute_group___258 **dev_groups;
	const struct dev_pm_ops___251 *pm;
	void (*coredump)(struct device___251 *);
	struct driver_private *p;
};

struct device_type___251 {
	const char *name;
	const struct attribute_group___258 **groups;
	int (*uevent)(struct device___251 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___251 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___251 *);
	const struct dev_pm_ops___251 *pm;
};

struct class___251 {
	const char *name;
	struct module___254 *owner;
	const struct attribute_group___258 **class_groups;
	const struct attribute_group___258 **dev_groups;
	struct kobject___258 *dev_kobj;
	int (*dev_uevent)(struct device___251 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___251 *, umode_t *);
	void (*class_release)(struct class___251 *);
	void (*dev_release)(struct device___251 *);
	int (*shutdown_pre)(struct device___251 *);
	const struct kobj_ns_type_operations___66 *ns_type;
	const void * (*namespace)(struct device___251 *);
	void (*get_ownership)(struct device___251 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___251 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___111;

struct pipe_buffer___111 {
	struct page___275 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___111 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___111 {
	int (*confirm)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
	void (*release)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
	bool (*try_steal)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
	bool (*get)(struct pipe_inode_info___111 *, struct pipe_buffer___111 *);
};

typedef rx_handler_result_t rx_handler_func_t___79(struct sk_buff___80 **);

struct bpf_xdp_entity___73 {
	struct bpf_prog___73 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___79;

struct net_device_ops___79;

struct l3mdev_ops___66;

struct ndisc_ops___48;

struct xfrmdev_ops___79;

struct header_ops___79;

struct inet6_dev___48;

struct netdev_rx_queue___79;

struct mini_Qdisc___73;

struct netdev_queue___79;

struct Qdisc___73;

struct rtnl_link_ops___73;

struct dcbnl_rtnl_ops___79;

struct net_device___79 {
	char name[16];
	struct netdev_name_node___79 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___79 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___66 *l3mdev_ops;
	const struct ndisc_ops___48 *ndisc_ops;
	const struct xfrmdev_ops___79 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___79 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___258 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___48 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___79 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___73 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___79 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___73 *miniq_ingress;
	struct netdev_queue___79 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___79 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___73 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___73 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___79 = 0,
		NETREG_REGISTERED___79 = 1,
		NETREG_UNREGISTERING___79 = 2,
		NETREG_UNREGISTERED___79 = 3,
		NETREG_RELEASED___79 = 4,
		NETREG_DUMMY___79 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___79 = 0,
		RTNL_LINK_INITIALIZING___79 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___79 *);
	struct netpoll_info *npinfo;
	possible_net_t___79 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___251 dev;
	const struct attribute_group___258 *sysfs_groups[4];
	const struct attribute_group___258 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___73 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___79 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___73 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___187 skb_frag_t___25;

struct ubuf_info___7 {
	void (*callback)(struct sk_buff___80 *, struct ubuf_info___7 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___24 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___80 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___25 frags[17];
};

struct netlink_callback___79 {
	struct sk_buff___80 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___80 *, struct netlink_callback___79 *);
	int (*done)(struct netlink_callback___79 *);
	void *data;
	struct module___254 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct tcpvegas_info {
	__u32 tcpv_enabled;
	__u32 tcpv_rttcnt;
	__u32 tcpv_rtt;
	__u32 tcpv_minrtt;
};

struct tcp_dctcp_info {
	__u16 dctcp_enabled;
	__u16 dctcp_ce_state;
	__u32 dctcp_alpha;
	__u32 dctcp_ab_ecn;
	__u32 dctcp_ab_tot;
};

struct tcp_bbr_info {
	__u32 bbr_bw_lo;
	__u32 bbr_bw_hi;
	__u32 bbr_min_rtt;
	__u32 bbr_pacing_gain;
	__u32 bbr_cwnd_gain;
};

union tcp_cc_info {
	struct tcpvegas_info vegas;
	struct tcp_dctcp_info dctcp;
	struct tcp_bbr_info bbr;
};

struct seq_operations___245 {
	void * (*start)(struct seq_file___245 *, loff_t *);
	void (*stop)(struct seq_file___245 *, void *);
	void * (*next)(struct seq_file___245 *, void *, loff_t *);
	int (*show)(struct seq_file___245 *, void *);
};

enum {
	BPF_TCP_ESTABLISHED = 1,
	BPF_TCP_SYN_SENT = 2,
	BPF_TCP_SYN_RECV = 3,
	BPF_TCP_FIN_WAIT1 = 4,
	BPF_TCP_FIN_WAIT2 = 5,
	BPF_TCP_TIME_WAIT = 6,
	BPF_TCP_CLOSE = 7,
	BPF_TCP_CLOSE_WAIT = 8,
	BPF_TCP_LAST_ACK = 9,
	BPF_TCP_LISTEN = 10,
	BPF_TCP_CLOSING = 11,
	BPF_TCP_NEW_SYN_RECV = 12,
	BPF_TCP_MAX_STATES = 13,
};

struct bpf_iter_aux_info___82;

typedef int (*bpf_iter_init_seq_priv_t___81)(void *, struct bpf_iter_aux_info___82 *);

struct bpf_map___82;

struct bpf_iter_aux_info___82 {
	struct bpf_map___82 *map;
};

struct bpf_iter_seq_info___81 {
	const struct seq_operations___245 *seq_ops;
	bpf_iter_init_seq_priv_t___81 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___82;

struct bpf_map_ops___81 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___82 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___82 *, struct file___270 *);
	void (*map_free)(struct bpf_map___82 *);
	int (*map_get_next_key)(struct bpf_map___82 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___82 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___82 *, void *);
	int (*map_lookup_batch)(struct bpf_map___82 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___82 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___82 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___82 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___82 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___82 *, void *);
	int (*map_update_elem)(struct bpf_map___82 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___82 *, void *);
	int (*map_push_elem)(struct bpf_map___82 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___82 *, void *);
	int (*map_peek_elem)(struct bpf_map___82 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___82 *, struct file___270 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___82 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___82 *, void *, struct seq_file___245 *);
	int (*map_check_btf)(const struct bpf_map___82 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___82 *, struct bpf_prog_aux___82 *);
	void (*map_poke_untrack)(struct bpf_map___82 *, struct bpf_prog_aux___82 *);
	void (*map_poke_run)(struct bpf_map___82 *, u32, struct bpf_prog___73 *, struct bpf_prog___73 *);
	int (*map_direct_value_addr)(const struct bpf_map___82 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___82 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___82 *, struct vm_area_struct___275 *);
	__poll_t (*map_poll)(struct bpf_map___82 *, struct file___270 *, struct poll_table_struct___191 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___82 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___82 *, const struct bpf_map___82 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___82 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___81 *iter_seq_info;
};

struct bpf_map___82 {
	const struct bpf_map_ops___81 *ops;
	struct bpf_map___82 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___135 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___81;

struct bpf_jit_poke_descriptor___81;

struct bpf_prog_ops___73;

struct btf_mod_pair___81;

struct bpf_prog_offload___79;

struct bpf_prog_aux___82 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___73 *dst_prog;
	struct bpf_trampoline___81 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___73 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___81 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___73 *ops;
	struct bpf_map___82 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___81 *used_btfs;
	struct bpf_prog___73 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___82 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___79 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___73 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___82 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___79;

struct bpf_map_dev_ops___79 {
	int (*map_get_next_key)(struct bpf_offloaded_map___79 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___79 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___79 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___79 *, void *);
};

struct bpf_offloaded_map___79 {
	struct bpf_map___82 map;
	struct net_device___79 *netdev;
	const struct bpf_map_dev_ops___79 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___73 {
	int (*test_run)(struct bpf_prog___73 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___79 {
	struct bpf_prog___73 *prog;
	struct net_device___79 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___81 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___73 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___254 *mod;
};

struct bpf_jit_poke_descriptor___81 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___82 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___81 {
	struct btf *btf;
	struct module___254 *module;
};

struct bpf_prog_array_item___73 {
	struct bpf_prog___73 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___73 {
	struct callback_head rcu;
	struct bpf_prog_array_item___73 items[0];
};

struct cftype___197;

struct cgroup_subsys___197 {
	struct cgroup_subsys_state___197 * (*css_alloc)(struct cgroup_subsys_state___197 *);
	int (*css_online)(struct cgroup_subsys_state___197 *);
	void (*css_offline)(struct cgroup_subsys_state___197 *);
	void (*css_released)(struct cgroup_subsys_state___197 *);
	void (*css_free)(struct cgroup_subsys_state___197 *);
	void (*css_reset)(struct cgroup_subsys_state___197 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___197 *, int);
	int (*css_extra_stat_show)(struct seq_file___245 *, struct cgroup_subsys_state___197 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___277 *, struct css_set___197 *);
	void (*cancel_fork)(struct task_struct___277 *, struct css_set___197 *);
	void (*fork)(struct task_struct___277 *);
	void (*exit)(struct task_struct___277 *);
	void (*release)(struct task_struct___277 *);
	void (*bind)(struct cgroup_subsys_state___197 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___197 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___197 *dfl_cftypes;
	struct cftype___197 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___197 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___197 *updated_children;
	struct cgroup___197 *updated_next;
};

struct cgroup_root___197 {
	struct kernfs_root___258 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___197 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___197 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___197 *ss;
	struct list_head node;
	struct kernfs_ops___258 *kf_ops;
	int (*open)(struct kernfs_open_file___258 *);
	void (*release)(struct kernfs_open_file___258 *);
	u64 (*read_u64)(struct cgroup_subsys_state___197 *, struct cftype___197 *);
	s64 (*read_s64)(struct cgroup_subsys_state___197 *, struct cftype___197 *);
	int (*seq_show)(struct seq_file___245 *, void *);
	void * (*seq_start)(struct seq_file___245 *, loff_t *);
	void * (*seq_next)(struct seq_file___245 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___245 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___197 *, struct cftype___197 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___197 *, struct cftype___197 *, s64);
	ssize_t (*write)(struct kernfs_open_file___258 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___258 *, struct poll_table_struct___191 *);
};

struct block_device_operations___161;

struct gendisk___164 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___164 *part0;
	const struct block_device_operations___161 *fops;
	struct request_queue___161 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___147 *bdi;
	struct kobject___258 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___258 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___161 {
	struct bio___161 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___187 *bip_vec;
	struct bio_vec___187 bip_inline_vecs[0];
};

struct blkcg___149;

struct blkg_policy_data___149;

struct blkcg_gq___149 {
	struct request_queue___161 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___149 *blkcg;
	struct blkcg_gq___149 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___149 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___161 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___161(struct request___161 *);

typedef void integrity_complete_fn___161(struct request___161 *, unsigned int);

struct blk_integrity_profile___161 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___161 *prepare_fn;
	integrity_complete_fn___161 *complete_fn;
	const char *name;
};

struct block_device_operations___161 {
	blk_qc_t (*submit_bio)(struct bio___161 *);
	int (*open)(struct block_device___164 *, fmode_t);
	void (*release)(struct gendisk___164 *, fmode_t);
	int (*rw_page)(struct block_device___164 *, sector_t, struct page___275 *, unsigned int);
	int (*ioctl)(struct block_device___164 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___164 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___164 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___164 *);
	int (*getgeo)(struct block_device___164 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___164 *, bool);
	void (*swap_slot_free_notify)(struct block_device___164 *, long unsigned int);
	int (*report_zones)(struct gendisk___164 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___164 *, umode_t *);
	struct module___254 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___164 *, sector_t *);
};

typedef void rq_end_io_fn___161(struct request___161 *, blk_status_t);

struct request___161 {
	struct request_queue___161 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___156 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___161 *bio;
	struct bio___161 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___187 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___161 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___161 *saved_end_io;
		} flush;
	};
	struct gendisk___164 *rq_disk;
	struct block_device___164 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___161 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___156 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___161 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___258 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___270 *debugfs_dir;
	struct dentry___270 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___161;

struct elevator_mq_ops___161 {
	int (*init_sched)(struct request_queue___161 *, struct elevator_type___161 *);
	void (*exit_sched)(struct elevator_queue___161 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___156 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___156 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___156 *);
	bool (*allow_merge)(struct request_queue___161 *, struct request___161 *, struct bio___161 *);
	bool (*bio_merge)(struct request_queue___161 *, struct bio___161 *, unsigned int);
	int (*request_merge)(struct request_queue___161 *, struct request___161 **, struct bio___161 *);
	void (*request_merged)(struct request_queue___161 *, struct request___161 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___161 *, struct request___161 *, struct request___161 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___161 *);
	void (*finish_request)(struct request___161 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___156 *, struct list_head *, bool);
	struct request___161 * (*dispatch_request)(struct blk_mq_hw_ctx___156 *);
	bool (*has_work)(struct blk_mq_hw_ctx___156 *);
	void (*completed_request)(struct request___161 *, u64);
	void (*requeue_request)(struct request___161 *);
	struct request___161 * (*former_request)(struct request_queue___161 *, struct request___161 *);
	struct request___161 * (*next_request)(struct request_queue___161 *, struct request___161 *);
	void (*init_icq)(struct io_cq___161 *);
	void (*exit_icq)(struct io_cq___161 *);
};

struct elv_fs_entry___161;

struct elevator_type___161 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___161 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___161 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___254 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___161 {
	struct elevator_type___161 *type;
	void *elevator_data;
	struct kobject___258 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___161 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___161 *, char *);
	ssize_t (*store)(struct elevator_queue___161 *, const char *, size_t);
};

struct blk_mq_queue_data___156;

struct blk_mq_ops___156 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___156 *, const struct blk_mq_queue_data___156 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___156 *);
	int (*get_budget)(struct request_queue___161 *);
	void (*put_budget)(struct request_queue___161 *, int);
	void (*set_rq_budget_token)(struct request___161 *, int);
	int (*get_rq_budget_token)(struct request___161 *);
	enum blk_eh_timer_return (*timeout)(struct request___161 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___156 *);
	void (*complete)(struct request___161 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___156 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___156 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___156 *, struct request___161 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___156 *, struct request___161 *, unsigned int);
	void (*initialize_rq_fn)(struct request___161 *);
	void (*cleanup_rq)(struct request___161 *);
	bool (*busy)(struct request_queue___161 *);
	int (*map_queues)(struct blk_mq_tag_set___156 *);
	void (*show_rq)(struct seq_file___245 *, struct request___161 *);
};

struct blk_mq_tag_set___156 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___156 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___156 {
	struct request___161 *rq;
	bool last;
};

struct blkcg_policy_data___149;

struct blkcg___149 {
	struct cgroup_subsys_state___197 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___149 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___149 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___149 {
	struct blkcg___149 *blkcg;
	int plid;
};

struct blkg_policy_data___149 {
	struct blkcg_gq___149 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___135 {
	struct mem_cgroup___135 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___135 {
	struct lruvec___143 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___135 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___135 *memcg;
};

struct obj_cgroup___135 {
	struct percpu_ref refcnt;
	struct mem_cgroup___135 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct inet_frags___84;

struct fqdir___84 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___84 *f;
	struct net___84 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___84;

struct inet_frags___84 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___84 *, const void *);
	void (*destructor)(struct inet_frag_queue___84 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___84 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___80 *fragments_tail;
	struct sk_buff___80 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___84 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___39 {
	struct ip_ra_chain___39 *next;
	struct sock___66 *sk;
	union {
		void (*destructor)(struct sock___66 *);
		struct sock___66 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___66;

struct fib_lookup_arg___66;

struct fib_rules_ops___66 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___66 *, struct flowi *, int, struct fib_lookup_arg___66 *);
	bool (*suppress)(struct fib_rule___66 *, int, struct fib_lookup_arg___66 *);
	int (*match)(struct fib_rule___66 *, struct flowi *, int);
	int (*configure)(struct fib_rule___66 *, struct sk_buff___80 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___66 *);
	int (*compare)(struct fib_rule___66 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___66 *, struct sk_buff___80 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___66 *);
	void (*flush_cache)(struct fib_rules_ops___66 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___254 *owner;
	struct net___84 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___17 {
	u32 (*ssthresh)(struct sock___66 *);
	void (*cong_avoid)(struct sock___66 *, u32, u32);
	void (*set_state)(struct sock___66 *, u8);
	void (*cwnd_event)(struct sock___66 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___66 *, u32);
	void (*pkts_acked)(struct sock___66 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___66 *);
	void (*cong_control)(struct sock___66 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___66 *);
	u32 (*sndbuf_expand)(struct sock___66 *);
	size_t (*get_info)(struct sock___66 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___254 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___66 *);
	void (*release)(struct sock___66 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___66 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___84 *);
	int (*fib_dump)(struct net___84 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___254 *owner;
	struct callback_head rcu;
};

struct xfrm_state___11;

struct lwtunnel_state___42;

struct dst_entry___66 {
	struct net_device___79 *dev;
	struct dst_ops___84 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___11 *xfrm;
	int (*input)(struct sk_buff___80 *);
	int (*output)(struct net___84 *, struct sock___66 *, struct sk_buff___80 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___42 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___66;

struct neigh_parms___66;

struct neigh_ops___66;

struct neighbour___66 {
	struct neighbour___66 *next;
	struct neigh_table___66 *tbl;
	struct neigh_parms___66 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___79 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___66 *, struct sk_buff___80 *);
	const struct neigh_ops___66 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___79 *dev;
	u8 primary_key[0];
};

struct rtable___16;

struct fnhe_hash_bucket___16;

struct fib_nh_common___16 {
	struct net_device___79 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___42 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___16 **nhc_pcpu_rth_output;
	struct rtable___16 *nhc_rth_input;
	struct fnhe_hash_bucket___16 *nhc_exceptions;
};

struct fib6_nh___16 {
	struct fib_nh_common___16 nh_common;
	long unsigned int last_probe;
	struct rt6_info___16 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___16;

struct fib6_info___16 {
	struct fib6_table___16 *fib6_table;
	struct fib6_info___16 *fib6_next;
	struct fib6_node___16 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___16 fib6_nh[0];
};

struct rt6_info___16 {
	struct dst_entry___66 dst;
	struct fib6_info___16 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___48 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___16 {
	struct fib6_node___16 *parent;
	struct fib6_node___16 *left;
	struct fib6_node___16 *right;
	struct fib6_node___16 *subtree;
	struct fib6_info___16 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___16 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___16 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___16 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct dcbnl_rtnl_ops___79 {
	int (*ieee_getets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___79 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___79 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___79 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___79 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___79 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___79 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___79 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___79 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___79 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___79 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___79 *);
	u8 (*setstate)(struct net_device___79 *, u8);
	void (*getpermhwaddr)(struct net_device___79 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___79 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___79 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___79 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___79 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___79 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___79 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___79 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___79 *, int, u8 *);
	void (*setpfccfg)(struct net_device___79 *, int, u8);
	void (*getpfccfg)(struct net_device___79 *, int, u8 *);
	u8 (*setall)(struct net_device___79 *);
	u8 (*getcap)(struct net_device___79 *, int, u8 *);
	int (*getnumtcs)(struct net_device___79 *, int, u8 *);
	int (*setnumtcs)(struct net_device___79 *, int, u8);
	u8 (*getpfcstate)(struct net_device___79 *);
	void (*setpfcstate)(struct net_device___79 *, u8);
	void (*getbcncfg)(struct net_device___79 *, int, u32 *);
	void (*setbcncfg)(struct net_device___79 *, int, u32);
	void (*getbcnrp)(struct net_device___79 *, int, u8 *);
	void (*setbcnrp)(struct net_device___79 *, int, u8);
	int (*setapp)(struct net_device___79 *, u8, u16, u8);
	int (*getapp)(struct net_device___79 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___79 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___79 *, int, u8);
	u8 (*getdcbx)(struct net_device___79 *);
	u8 (*setdcbx)(struct net_device___79 *, u8);
	int (*peer_getappinfo)(struct net_device___79 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___79 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___79 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___79 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___79 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___79 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___79 {
	struct net_device___79 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___79 {
	struct net_device___79 *dev;
};

struct xdp_buff___79 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___79 *rxq;
	struct xdp_txq_info___79 *txq;
	u32 frame_sz;
};

struct xdp_frame___79 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___79 *dev_rx;
};

struct header_ops___79 {
	int (*create)(struct sk_buff___80 *, struct net_device___79 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___80 *, unsigned char *);
	int (*cache)(const struct neighbour___66 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___79 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___80 *);
};

struct netdev_queue___79 {
	struct net_device___79 *dev;
	struct Qdisc___73 *qdisc;
	struct Qdisc___73 *qdisc_sleeping;
	struct kobject___258 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___79 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___73 {
	struct sk_buff___80 *head;
	struct sk_buff___80 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___73;

struct Qdisc___73 {
	int (*enqueue)(struct sk_buff___80 *, struct Qdisc___73 *, struct sk_buff___80 **);
	struct sk_buff___80 * (*dequeue)(struct Qdisc___73 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___73 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___79 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___79 gso_skb;
	struct qdisc_skb_head___73 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___73 *next_sched;
	struct sk_buff_head___79 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___79 {
	struct xdp_rxq_info___79 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___258 kobj;
	struct net_device___79 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___79 {
	enum net_device_path_type type;
	const struct net_device___79 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___79 = 0,
				DEV_PATH_BR_VLAN_TAG___79 = 1,
				DEV_PATH_BR_VLAN_UNTAG___79 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___79 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___79 {
	const struct net_device___79 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___79 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___73 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___79 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___79 {
	int (*xdo_dev_state_add)(struct xfrm_state___11 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___11 *);
	void (*xdo_dev_state_free)(struct xfrm_state___11 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___80 *, struct xfrm_state___11 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___11 *);
};

struct xfrm_state_offload___11 {
	struct net_device___79 *dev;
	struct net_device___79 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___11;

struct xfrm_type_offload___11;

struct xfrm_state___11 {
	possible_net_t___79 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___66 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___11 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___11 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___275 xfrag;
	const struct xfrm_type___11 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___11 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___79 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___79 *dev;
	const char *name;
};

struct net_device_ops___79 {
	int (*ndo_init)(struct net_device___79 *);
	void (*ndo_uninit)(struct net_device___79 *);
	int (*ndo_open)(struct net_device___79 *);
	int (*ndo_stop)(struct net_device___79 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___80 *, struct net_device___79 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___80 *, struct net_device___79 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___79 *, struct sk_buff___80 *, struct net_device___79 *);
	void (*ndo_change_rx_flags)(struct net_device___79 *, int);
	void (*ndo_set_rx_mode)(struct net_device___79 *);
	int (*ndo_set_mac_address)(struct net_device___79 *, void *);
	int (*ndo_validate_addr)(struct net_device___79 *);
	int (*ndo_do_ioctl)(struct net_device___79 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___79 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___79 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___79 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___79 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___79 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___79 *, int);
	int (*ndo_neigh_setup)(struct net_device___79 *, struct neigh_parms___66 *);
	void (*ndo_tx_timeout)(struct net_device___79 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___79 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___79 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___79 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___79 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___79 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___79 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___79 *);
	int (*ndo_netpoll_setup)(struct net_device___79 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___79 *);
	int (*ndo_set_vf_mac)(struct net_device___79 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___79 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___79 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___79 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___79 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___79 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___79 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___79 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___79 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___79 *, int, struct sk_buff___80 *);
	int (*ndo_get_vf_guid)(struct net_device___79 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___79 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___79 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___79 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___79 *);
	int (*ndo_fcoe_disable)(struct net_device___79 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___79 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___79 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___79 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___79 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___79 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___79 *, const struct sk_buff___80 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___79 *, struct net_device___79 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___79 *, struct net_device___79 *);
	struct net_device___79 * (*ndo_get_xmit_slave)(struct net_device___79 *, struct sk_buff___80 *, bool);
	struct net_device___79 * (*ndo_sk_get_lower_dev)(struct net_device___79 *, struct sock___66 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___79 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___79 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___79 *, struct neighbour___66 *);
	void (*ndo_neigh_destroy)(struct net_device___79 *, struct neighbour___66 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___80 *, struct netlink_callback___79 *, struct net_device___79 *, struct net_device___79 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___80 *, struct nlattr **, struct net_device___79 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___79 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___80 *, u32, u32, struct net_device___79 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___79 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___79 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___79 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___79 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___79 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___79 *, struct net_device___79 *);
	void (*ndo_dfwd_del_station)(struct net_device___79 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___79 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___79 *);
	int (*ndo_change_proto_down)(struct net_device___79 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___79 *, struct sk_buff___80 *);
	void (*ndo_set_rx_headroom)(struct net_device___79 *, int);
	int (*ndo_bpf)(struct net_device___79 *, struct netdev_bpf___79 *);
	int (*ndo_xdp_xmit)(struct net_device___79 *, int, struct xdp_frame___79 **, u32);
	struct net_device___79 * (*ndo_xdp_get_xmit_slave)(struct net_device___79 *, struct xdp_buff___79 *);
	int (*ndo_xsk_wakeup)(struct net_device___79 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___79 *);
	int (*ndo_tunnel_ctl)(struct net_device___79 *, struct ip_tunnel_parm *, int);
	struct net_device___79 * (*ndo_get_peer_dev)(struct net_device___79 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___79 *, struct net_device_path___79 *);
};

struct neigh_parms___66 {
	possible_net_t___79 net;
	struct net_device___79 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___66 *);
	struct neigh_table___66 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___66 {
	u32 (*l3mdev_fib_table)(const struct net_device___79 *);
	struct sk_buff___80 * (*l3mdev_l3_rcv)(struct net_device___79 *, struct sk_buff___80 *, u16);
	struct sk_buff___80 * (*l3mdev_l3_out)(struct net_device___79 *, struct sock___66 *, struct sk_buff___80 *, u16);
	struct dst_entry___66 * (*l3mdev_link_scope_lookup)(const struct net_device___79 *, struct flowi6 *);
};

struct ndisc_ops___48 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___79 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___79 *, struct neighbour___66 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___79 *, u8, struct neighbour___66 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___79 *, struct sk_buff___80 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___84 *, struct net_device___79 *, const struct prefix_info *, struct inet6_dev___48 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___48;

struct ifacaddr6___16;

struct inet6_dev___48 {
	struct net_device___79 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___48 *mc_list;
	struct ifmcaddr6___48 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___79 mc_query_queue;
	struct sk_buff_head___79 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___16 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___66 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___73;

struct tcf_block___73;

struct mini_Qdisc___73 {
	struct tcf_proto___73 *filter_list;
	struct tcf_block___73 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___73 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___79 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___79 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___84 *, struct net_device___79 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___79 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___79 *, struct list_head *);
	size_t (*get_size)(const struct net_device___79 *);
	int (*fill_info)(struct sk_buff___80 *, const struct net_device___79 *);
	size_t (*get_xstats_size)(const struct net_device___79 *);
	int (*fill_xstats)(struct sk_buff___80 *, const struct net_device___79 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___79 *, struct net_device___79 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___79 *, const struct net_device___79 *);
	int (*fill_slave_info)(struct sk_buff___80 *, const struct net_device___79 *, const struct net_device___79 *);
	struct net___84 * (*get_link_net)(const struct net_device___79 *);
	size_t (*get_linkxstats_size)(const struct net_device___79 *, int);
	int (*fill_linkxstats)(struct sk_buff___80 *, const struct net_device___79 *, int *, int);
};

struct gnet_dump___73 {
	spinlock_t *lock;
	struct sk_buff___80 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___73;

struct Qdisc_ops___73 {
	struct Qdisc_ops___73 *next;
	const struct Qdisc_class_ops___73 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___80 *, struct Qdisc___73 *, struct sk_buff___80 **);
	struct sk_buff___80 * (*dequeue)(struct Qdisc___73 *);
	struct sk_buff___80 * (*peek)(struct Qdisc___73 *);
	int (*init)(struct Qdisc___73 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___73 *);
	void (*destroy)(struct Qdisc___73 *);
	int (*change)(struct Qdisc___73 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___73 *);
	int (*change_tx_queue_len)(struct Qdisc___73 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___73 *, unsigned int);
	int (*dump)(struct Qdisc___73 *, struct sk_buff___80 *);
	int (*dump_stats)(struct Qdisc___73 *, struct gnet_dump___73 *);
	void (*ingress_block_set)(struct Qdisc___73 *, u32);
	void (*egress_block_set)(struct Qdisc___73 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___73 *);
	u32 (*egress_block_get)(struct Qdisc___73 *);
	struct module___254 *owner;
};

struct Qdisc_class_ops___73 {
	unsigned int flags;
	struct netdev_queue___79 * (*select_queue)(struct Qdisc___73 *, struct tcmsg *);
	int (*graft)(struct Qdisc___73 *, long unsigned int, struct Qdisc___73 *, struct Qdisc___73 **, struct netlink_ext_ack *);
	struct Qdisc___73 * (*leaf)(struct Qdisc___73 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___73 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___73 *, u32);
	int (*change)(struct Qdisc___73 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___73 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___73 *, struct qdisc_walker *);
	struct tcf_block___73 * (*tcf_block)(struct Qdisc___73 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___73 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___73 *, long unsigned int);
	int (*dump)(struct Qdisc___73 *, long unsigned int, struct sk_buff___80 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___73 *, long unsigned int, struct gnet_dump___73 *);
};

struct tcf_chain___73;

struct tcf_block___73 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___84 *net;
	struct Qdisc___73 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___73 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___73;

struct tcf_proto_ops___73;

struct tcf_proto___73 {
	struct tcf_proto___73 *next;
	void *root;
	int (*classify)(struct sk_buff___80 *, const struct tcf_proto___73 *, struct tcf_result___73 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___73 *ops;
	struct tcf_chain___73 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___73 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___73 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___73 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___80 *, const struct tcf_proto___73 *, struct tcf_result___73 *);
	int (*init)(struct tcf_proto___73 *);
	void (*destroy)(struct tcf_proto___73 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___73 *, u32);
	void (*put)(struct tcf_proto___73 *, void *);
	int (*change)(struct net___84 *, struct sk_buff___80 *, struct tcf_proto___73 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___73 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___73 *);
	void (*walk)(struct tcf_proto___73 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___73 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___73 *, void *);
	void (*hw_del)(struct tcf_proto___73 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___84 *, struct tcf_chain___73 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___84 *, struct tcf_proto___73 *, void *, struct sk_buff___80 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___84 *, struct tcf_proto___73 *, void *, struct sk_buff___80 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___80 *, struct net___84 *, void *);
	struct module___254 *owner;
	int flags;
};

struct tcf_chain___73 {
	struct mutex filter_chain_lock;
	struct tcf_proto___73 *filter_chain;
	struct list_head list;
	struct tcf_block___73 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___73 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___66 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___73 *prog;
};

struct bpf_sock_ops_kern___4 {
	struct sock___66 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___80 *syn_skb;
	struct sk_buff___80 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct pneigh_entry___66;

struct neigh_hash_table___66;

struct neigh_table___66 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___79 *, __u32 *);
	bool (*key_eq)(const struct neighbour___66 *, const void *);
	int (*constructor)(struct neighbour___66 *);
	int (*pconstructor)(struct pneigh_entry___66 *);
	void (*pdestructor)(struct pneigh_entry___66 *);
	void (*proxy_redo)(struct sk_buff___80 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___79 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___66 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___79 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___66 *nht;
	struct pneigh_entry___66 **phash_buckets;
};

struct neigh_ops___66 {
	int family;
	void (*solicit)(struct neighbour___66 *, struct sk_buff___80 *);
	void (*error_report)(struct neighbour___66 *, struct sk_buff___80 *);
	int (*output)(struct neighbour___66 *, struct sk_buff___80 *);
	int (*connected_output)(struct neighbour___66 *, struct sk_buff___80 *);
};

struct pneigh_entry___66 {
	struct pneigh_entry___66 *next;
	possible_net_t___79 net;
	struct net_device___79 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___66 {
	struct neighbour___66 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___42 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___84 *, struct sock___66 *, struct sk_buff___80 *);
	int (*orig_input)(struct sk_buff___80 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___66 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___66 *ctarget;
	struct net___84 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___66 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___66 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___51;

struct timewait_sock_ops___50;

struct proto___66 {
	void (*close)(struct sock___66 *, long int);
	int (*pre_connect)(struct sock___66 *, struct sockaddr *, int);
	int (*connect)(struct sock___66 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___66 *, int);
	struct sock___66 * (*accept)(struct sock___66 *, int, int *, bool);
	int (*ioctl)(struct sock___66 *, int, long unsigned int);
	int (*init)(struct sock___66 *);
	void (*destroy)(struct sock___66 *);
	void (*shutdown)(struct sock___66 *, int);
	int (*setsockopt)(struct sock___66 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___66 *, int, int, char *, int *);
	void (*keepalive)(struct sock___66 *, int);
	int (*compat_ioctl)(struct sock___66 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___66 *, struct msghdr___68 *, size_t);
	int (*recvmsg)(struct sock___66 *, struct msghdr___68 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___66 *, struct page___275 *, int, size_t, int);
	int (*bind)(struct sock___66 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___66 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___66 *, struct sk_buff___80 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___66 *);
	int (*hash)(struct sock___66 *);
	void (*unhash)(struct sock___66 *);
	void (*rehash)(struct sock___66 *);
	int (*get_port)(struct sock___66 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___66 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___66 *, int);
	bool (*sock_is_readable)(struct sock___66 *);
	void (*enter_memory_pressure)(struct sock___66 *);
	void (*leave_memory_pressure)(struct sock___66 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___51 *rsk_prot;
	struct timewait_sock_ops___50 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___254 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___66 *, int);
};

struct xfrm_policy_queue___11 {
	struct sk_buff_head___79 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___11 {
	possible_net_t___79 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___11 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___18 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___73 *prog;
	struct sock___66 *socks[0];
};

struct request_sock___52;

struct request_sock_ops___51 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___66 *, struct request_sock___52 *);
	void (*send_ack)(const struct sock___66 *, struct sk_buff___80 *, struct request_sock___52 *);
	void (*send_reset)(const struct sock___66 *, struct sk_buff___80 *);
	void (*destructor)(struct request_sock___52 *);
	void (*syn_ack_timeout)(const struct request_sock___52 *);
};

struct timewait_sock_ops___50 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___66 *, struct sock___66 *, void *);
	void (*twsk_destructor)(struct sock___66 *);
};

struct request_sock___52 {
	struct sock_common___66 __req_common;
	struct request_sock___52 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___51 *rsk_ops;
	struct sock___66 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___4 {
	struct request_sock___52 *rskq_rst_head;
	struct request_sock___52 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___4 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___52 *rskq_accept_head;
	struct request_sock___52 *rskq_accept_tail;
	struct fastopen_queue___4 fastopenq;
};

struct inet_cork___7 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___66 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___7 {
	struct inet_cork___7 base;
	struct flowi fl;
};

struct ipv6_pinfo___7;

struct inet_sock___7 {
	struct sock___66 sk;
	struct ipv6_pinfo___7 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___7 cork;
};

struct ipv6_fl_socklist___7;

struct ipv6_pinfo___7 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___7 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___80 *pktoptions;
	struct sk_buff___80 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___4 {
	int (*queue_xmit)(struct sock___66 *, struct sk_buff___80 *, struct flowi *);
	void (*send_check)(struct sock___66 *, struct sk_buff___80 *);
	int (*rebuild_header)(struct sock___66 *);
	void (*sk_rx_dst_set)(struct sock___66 *, const struct sk_buff___80 *);
	int (*conn_request)(struct sock___66 *, struct sk_buff___80 *);
	struct sock___66 * (*syn_recv_sock)(const struct sock___66 *, struct sk_buff___80 *, struct request_sock___52 *, struct dst_entry___66 *, struct request_sock___52 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___66 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___66 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___66 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___66 *);
};

struct inet_bind_bucket___4;

struct tcp_ulp_ops___4;

struct inet_connection_sock___4 {
	struct inet_sock___7 icsk_inet;
	struct request_sock_queue___4 icsk_accept_queue;
	struct inet_bind_bucket___4 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___17 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___4 *icsk_af_ops;
	const struct tcp_ulp_ops___4 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___66 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___66 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___4 {
	possible_net_t___79 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___4 {
	struct list_head list;
	int (*init)(struct sock___66 *);
	void (*update)(struct sock___66 *, struct proto___66 *, void (*)(struct sock___66 *));
	void (*release)(struct sock___66 *);
	int (*get_info)(const struct sock___66 *, struct sk_buff___80 *);
	size_t (*get_info_size)(const struct sock___66 *);
	void (*clone)(const struct request_sock___52 *, struct sock___66 *, const gfp_t);
	char name[16];
	struct module___254 *owner;
};

enum inet_csk_ack_state_t {
	ICSK_ACK_SCHED = 1,
	ICSK_ACK_TIMER = 2,
	ICSK_ACK_PUSHED = 4,
	ICSK_ACK_PUSHED2 = 8,
	ICSK_ACK_NOW = 16,
};

enum {
	TCP_FLAG_CWR = 32768,
	TCP_FLAG_ECE = 16384,
	TCP_FLAG_URG = 8192,
	TCP_FLAG_ACK = 4096,
	TCP_FLAG_PSH = 2048,
	TCP_FLAG_RST = 1024,
	TCP_FLAG_SYN = 512,
	TCP_FLAG_FIN = 256,
	TCP_RESERVED_BITS = 15,
	TCP_DATA_OFFSET = 240,
};

struct tcp_repair_opt {
	__u32 opt_code;
	__u32 opt_val;
};

struct tcp_repair_window {
	__u32 snd_wl1;
	__u32 snd_wnd;
	__u32 max_window;
	__u32 rcv_wnd;
	__u32 rcv_wup;
};

enum {
	TCP_NO_QUEUE = 0,
	TCP_RECV_QUEUE = 1,
	TCP_SEND_QUEUE = 2,
	TCP_QUEUES_NR = 3,
};

struct tcp_info {
	__u8 tcpi_state;
	__u8 tcpi_ca_state;
	__u8 tcpi_retransmits;
	__u8 tcpi_probes;
	__u8 tcpi_backoff;
	__u8 tcpi_options;
	__u8 tcpi_snd_wscale: 4;
	__u8 tcpi_rcv_wscale: 4;
	__u8 tcpi_delivery_rate_app_limited: 1;
	__u8 tcpi_fastopen_client_fail: 2;
	long: 62;
	__u32 tcpi_rto;
	__u32 tcpi_ato;
	__u32 tcpi_snd_mss;
	__u32 tcpi_rcv_mss;
	__u32 tcpi_unacked;
	__u32 tcpi_sacked;
	__u32 tcpi_lost;
	__u32 tcpi_retrans;
	__u32 tcpi_fackets;
	__u32 tcpi_last_data_sent;
	__u32 tcpi_last_ack_sent;
	__u32 tcpi_last_data_recv;
	__u32 tcpi_last_ack_recv;
	__u32 tcpi_pmtu;
	__u32 tcpi_rcv_ssthresh;
	__u32 tcpi_rtt;
	__u32 tcpi_rttvar;
	__u32 tcpi_snd_ssthresh;
	__u32 tcpi_snd_cwnd;
	__u32 tcpi_advmss;
	__u32 tcpi_reordering;
	__u32 tcpi_rcv_rtt;
	__u32 tcpi_rcv_space;
	__u32 tcpi_total_retrans;
	__u64 tcpi_pacing_rate;
	__u64 tcpi_max_pacing_rate;
	__u64 tcpi_bytes_acked;
	__u64 tcpi_bytes_received;
	__u32 tcpi_segs_out;
	__u32 tcpi_segs_in;
	__u32 tcpi_notsent_bytes;
	__u32 tcpi_min_rtt;
	__u32 tcpi_data_segs_in;
	__u32 tcpi_data_segs_out;
	__u64 tcpi_delivery_rate;
	__u64 tcpi_busy_time;
	__u64 tcpi_rwnd_limited;
	__u64 tcpi_sndbuf_limited;
	__u32 tcpi_delivered;
	__u32 tcpi_delivered_ce;
	__u64 tcpi_bytes_sent;
	__u64 tcpi_bytes_retrans;
	__u32 tcpi_dsack_dups;
	__u32 tcpi_reord_seen;
	__u32 tcpi_rcv_ooopack;
	__u32 tcpi_snd_wnd;
};

enum {
	TCP_NLA_PAD = 0,
	TCP_NLA_BUSY = 1,
	TCP_NLA_RWND_LIMITED = 2,
	TCP_NLA_SNDBUF_LIMITED = 3,
	TCP_NLA_DATA_SEGS_OUT = 4,
	TCP_NLA_TOTAL_RETRANS = 5,
	TCP_NLA_PACING_RATE = 6,
	TCP_NLA_DELIVERY_RATE = 7,
	TCP_NLA_SND_CWND = 8,
	TCP_NLA_REORDERING = 9,
	TCP_NLA_MIN_RTT = 10,
	TCP_NLA_RECUR_RETRANS = 11,
	TCP_NLA_DELIVERY_RATE_APP_LMT = 12,
	TCP_NLA_SNDQ_SIZE = 13,
	TCP_NLA_CA_STATE = 14,
	TCP_NLA_SND_SSTHRESH = 15,
	TCP_NLA_DELIVERED = 16,
	TCP_NLA_DELIVERED_CE = 17,
	TCP_NLA_BYTES_SENT = 18,
	TCP_NLA_BYTES_RETRANS = 19,
	TCP_NLA_DSACK_DUPS = 20,
	TCP_NLA_REORD_SEEN = 21,
	TCP_NLA_SRTT = 22,
	TCP_NLA_TIMEOUT_REHASH = 23,
	TCP_NLA_BYTES_NOTSENT = 24,
	TCP_NLA_EDT = 25,
	TCP_NLA_TTL = 26,
};

struct tcp_zerocopy_receive {
	__u64 address;
	__u32 length;
	__u32 recv_skip_hint;
	__u32 inq;
	__s32 err;
	__u64 copybuf_address;
	__s32 copybuf_len;
	__u32 flags;
	__u64 msg_control;
	__u64 msg_controllen;
	__u32 msg_flags;
	__u32 reserved;
};

struct tcp_sock_af_ops___5;

struct tcp_fastopen_request___5;

struct tcp_sock___5 {
	struct inet_connection_sock___4 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___80 *lost_skb_hint;
	struct sk_buff___80 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___80 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___80 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___5 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___5 *fastopen_req;
	struct request_sock___52 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___5 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___66 *, const struct sock___66 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___66 *, const struct sk_buff___80 *);
	int (*md5_parse)(struct sock___66 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___5 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___68 *data;
	size_t size;
	int copied;
	struct ubuf_info___7 *uarg;
};

struct ip6_flowlabel___7;

struct ipv6_fl_socklist___7 {
	struct ipv6_fl_socklist___7 *next;
	struct ip6_flowlabel___7 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___48 {
	struct in6_addr mca_addr;
	struct inet6_dev___48 *idev;
	struct ifmcaddr6___48 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___16 {
	struct in6_addr aca_addr;
	struct fib6_info___16 *aca_rt;
	struct ifacaddr6___16 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___7 {
	struct ip6_flowlabel___7 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___247 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___84 *fl_net;
};

struct fib_nh_exception___16 {
	struct fib_nh_exception___16 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___16 *fnhe_rth_input;
	struct rtable___16 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___16 {
	struct dst_entry___66 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___16 {
	struct fib_nh_exception___16 *chain;
};

struct tcp_md5sig_pool {
	struct ahash_request___7 *md5_req;
	void *scratch;
};

enum tcp_chrono {
	TCP_CHRONO_UNSPEC = 0,
	TCP_CHRONO_BUSY = 1,
	TCP_CHRONO_RWND_LIMITED = 2,
	TCP_CHRONO_SNDBUF_LIMITED = 3,
	__TCP_CHRONO_MAX = 4,
};

struct xfrm_type___11 {
	struct module___254 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___11 *);
	void (*destructor)(struct xfrm_state___11 *);
	int (*input)(struct xfrm_state___11 *, struct sk_buff___80 *);
	int (*output)(struct xfrm_state___11 *, struct sk_buff___80 *);
	int (*reject)(struct xfrm_state___11 *, struct sk_buff___80 *, const struct flowi *);
};

struct xfrm_type_offload___11 {
	struct module___254 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___11 *, struct sk_buff___80 *);
	int (*input_tail)(struct xfrm_state___11 *, struct sk_buff___80 *);
	int (*xmit)(struct xfrm_state___11 *, struct sk_buff___80 *, netdev_features_t);
};

enum {
	TCP_CMSG_INQ = 1,
	TCP_CMSG_TS = 2,
};

struct tcp_splice_state {
	struct pipe_inode_info___111 *pipe;
	size_t len;
	unsigned int flags;
};

typedef struct bio_vec___92 skb_frag_t___26;

struct ubuf_info___8 {
	void (*callback)(struct sk_buff___34 *, struct ubuf_info___8 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___25 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___34 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___26 frags[17];
};

struct bpf_sock_ops_kern___5 {
	struct sock___27 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___34 *syn_skb;
	struct sk_buff___34 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct fastopen_queue___5 {
	struct request_sock___17 *rskq_rst_head;
	struct request_sock___17 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___5 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___17 *rskq_accept_head;
	struct request_sock___17 *rskq_accept_tail;
	struct fastopen_queue___5 fastopenq;
};

struct inet_request_sock___4 {
	struct request_sock___17 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___34 *pktopts;
		};
	};
};

struct inet_cork___8 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___26 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___8 {
	struct inet_cork___8 base;
	struct flowi fl;
};

struct ipv6_pinfo___8;

struct inet_sock___8 {
	struct sock___27 sk;
	struct ipv6_pinfo___8 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___8 cork;
};

struct ipv6_fl_socklist___8;

struct ipv6_pinfo___8 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___8 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___34 *pktoptions;
	struct sk_buff___34 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___5 {
	int (*queue_xmit)(struct sock___27 *, struct sk_buff___34 *, struct flowi *);
	void (*send_check)(struct sock___27 *, struct sk_buff___34 *);
	int (*rebuild_header)(struct sock___27 *);
	void (*sk_rx_dst_set)(struct sock___27 *, const struct sk_buff___34 *);
	int (*conn_request)(struct sock___27 *, struct sk_buff___34 *);
	struct sock___27 * (*syn_recv_sock)(const struct sock___27 *, struct sk_buff___34 *, struct request_sock___17 *, struct dst_entry___26 *, struct request_sock___17 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___27 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___27 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___27 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___27 *);
};

struct inet_bind_bucket___5;

struct tcp_ulp_ops___5;

struct inet_connection_sock___5 {
	struct inet_sock___8 icsk_inet;
	struct request_sock_queue___5 icsk_accept_queue;
	struct inet_bind_bucket___5 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___4 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___5 *icsk_af_ops;
	const struct tcp_ulp_ops___5 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___27 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___27 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___5 {
	possible_net_t___33 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___5 {
	struct list_head list;
	int (*init)(struct sock___27 *);
	void (*update)(struct sock___27 *, struct proto___26 *, void (*)(struct sock___27 *));
	void (*release)(struct sock___27 *);
	int (*get_info)(const struct sock___27 *, struct sk_buff___34 *);
	size_t (*get_info_size)(const struct sock___27 *);
	void (*clone)(const struct request_sock___17 *, struct sock___27 *, const gfp_t);
	char name[16];
	struct module___149 *owner;
};

union tcp_word_hdr___2 {
	struct tcphdr___2 hdr;
	__be32 words[5];
};

enum tcp_fastopen_client_fail {
	TFO_STATUS_UNSPEC = 0,
	TFO_COOKIE_UNAVAILABLE = 1,
	TFO_DATA_NOT_ACKED = 2,
	TFO_SYN_RETRANSMITTED = 3,
};

struct tcp_sack_block_wire {
	__be32 start_seq;
	__be32 end_seq;
};

struct tcp_request_sock_ops___3;

struct tcp_request_sock___3 {
	struct inet_request_sock___4 req;
	const struct tcp_request_sock_ops___3 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_request_sock_ops___3 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___27 *, const struct sock___27 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___27 *, const struct sk_buff___34 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___34 *, __u16 *);
	struct dst_entry___26 * (*route_req)(const struct sock___27 *, struct sk_buff___34 *, struct flowi *, struct request_sock___17 *);
	u32 (*init_seq)(const struct sk_buff___34 *);
	u32 (*init_ts_off)(const struct net___38 *, const struct sk_buff___34 *);
	int (*send_synack)(const struct sock___27 *, struct dst_entry___26 *, struct flowi *, struct request_sock___17 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___34 *);
};

struct tcp_sock_af_ops___6;

struct tcp_fastopen_request___6;

struct tcp_sock___6 {
	struct inet_connection_sock___5 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___34 *lost_skb_hint;
	struct sk_buff___34 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___34 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___34 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___6 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___6 *fastopen_req;
	struct request_sock___17 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___6 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___27 *, const struct sock___27 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___27 *, const struct sk_buff___34 *);
	int (*md5_parse)(struct sock___27 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___6 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___27 *data;
	size_t size;
	int copied;
	struct ubuf_info___8 *uarg;
};

struct ip6_flowlabel___8;

struct ipv6_fl_socklist___8 {
	struct ipv6_fl_socklist___8 *next;
	struct ip6_flowlabel___8 *fl;
	struct callback_head rcu;
};

struct static_key_false_deferred {
	struct static_key_false key;
	long unsigned int timeout;
	struct delayed_work work;
};

struct ip6_flowlabel___8 {
	struct ip6_flowlabel___8 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___146 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___38 *fl_net;
};

struct mptcp_ext {
	union {
		u64 data_ack;
		u32 data_ack32;
	};
	u64 data_seq;
	u32 subflow_seq;
	u16 data_len;
	__sum16 csum;
	u8 use_map: 1;
	u8 dsn64: 1;
	u8 data_fin: 1;
	u8 use_ack: 1;
	u8 ack64: 1;
	u8 mpc_map: 1;
	u8 frozen: 1;
	u8 reset_transient: 1;
	u8 reset_reason: 4;
	u8 csum_reqd: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
};

enum tcp_queue {
	TCP_FRAG_IN_WRITE_QUEUE = 0,
	TCP_FRAG_IN_RTX_QUEUE = 1,
};

enum tcp_ca_ack_event_flags {
	CA_ACK_SLOWPATH = 1,
	CA_ACK_WIN_UPDATE = 2,
	CA_ACK_ECE = 4,
};

struct tcp_sacktag_state {
	u64 first_sackt;
	u64 last_sackt;
	u32 reord;
	u32 sack_delivered;
	int flag;
	unsigned int mss_now;
	struct rate_sample *rate;
};

struct dentry___271;

struct super_block___271;

struct module___255;

struct file_system_type___271 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___271 * (*mount)(struct file_system_type___271 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___271 *);
	struct module___255 *owner;
	struct file_system_type___271 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___271;

struct kiocb___271;

struct iov_iter___191;

struct poll_table_struct___192;

struct vm_area_struct___276;

struct inode___271;

struct file_lock___271;

struct page___276;

struct pipe_inode_info___112;

struct seq_file___246;

struct file_operations___272 {
	struct module___255 *owner;
	loff_t (*llseek)(struct file___271 *, loff_t, int);
	ssize_t (*read)(struct file___271 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___271 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___271 *, struct iov_iter___191 *);
	ssize_t (*write_iter)(struct kiocb___271 *, struct iov_iter___191 *);
	int (*iopoll)(struct kiocb___271 *, bool);
	int (*iterate)(struct file___271 *, struct dir_context *);
	int (*iterate_shared)(struct file___271 *, struct dir_context *);
	__poll_t (*poll)(struct file___271 *, struct poll_table_struct___192 *);
	long int (*unlocked_ioctl)(struct file___271 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___271 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___271 *, struct vm_area_struct___276 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___271 *, struct file___271 *);
	int (*flush)(struct file___271 *, fl_owner_t);
	int (*release)(struct inode___271 *, struct file___271 *);
	int (*fsync)(struct file___271 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___271 *, int);
	int (*lock)(struct file___271 *, int, struct file_lock___271 *);
	ssize_t (*sendpage)(struct file___271 *, struct page___276 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___271 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___271 *, long unsigned int);
	int (*flock)(struct file___271 *, int, struct file_lock___271 *);
	ssize_t (*splice_write)(struct pipe_inode_info___112 *, struct file___271 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___271 *, loff_t *, struct pipe_inode_info___112 *, size_t, unsigned int);
	int (*setlease)(struct file___271 *, long int, struct file_lock___271 **, void **);
	long int (*fallocate)(struct file___271 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___246 *, struct file___271 *);
	ssize_t (*copy_file_range)(struct file___271 *, loff_t, struct file___271 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___271 *, loff_t, struct file___271 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___271 *, loff_t, loff_t, int);
};

struct vmacache___276 {
	u64 seqnum;
	struct vm_area_struct___276 *vmas[4];
};

struct page_frag___276 {
	struct page___276 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___277;

struct pid___248;

struct nsproxy___257;

struct signal_struct___272;

struct bio_list___162;

struct backing_dev_info___148;

struct io_context___162;

struct css_set___198;

struct mem_cgroup___136;

struct request_queue___162;

struct vm_struct___254;

struct task_struct___278 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___278 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___277 *mm;
	struct mm_struct___277 *active_mm;
	struct vmacache___276 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___278 *real_parent;
	struct task_struct___278 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___278 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___248 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___257 *nsproxy;
	struct signal_struct___272 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___278 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___162 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___148 *backing_dev_info;
	struct io_context___162 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___198 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___112 *splice_pipe;
	struct page_frag___276 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___136 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___136 *active_memcg;
	struct request_queue___162 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___278 *oom_reaper_list;
	struct vm_struct___254 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___259;

struct kobj_type___259;

struct kernfs_node___259;

struct kobject___259 {
	const char *name;
	struct list_head entry;
	struct kobject___259 *parent;
	struct kset___259 *kset;
	struct kobj_type___259 *ktype;
	struct kernfs_node___259 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___256 {
	struct kobject___259 kobj;
	struct module___255 *mod;
	struct kobject___259 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___255 {
	struct module___255 *mod;
	struct latch_tree_node node;
};

struct module_layout___255 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___255 mtn;
};

struct module_attribute___255;

struct kernel_param___255;

struct module___255 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___256 mkobj;
	struct module_attribute___255 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___259 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___255 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___255 core_layout;
	struct module_layout___255 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___271;

struct dentry___271 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___271 *d_parent;
	struct qstr d_name;
	struct inode___271 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___271 *d_op;
	struct super_block___271 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___271;

struct address_space___271 {
	struct inode___271 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___271 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___271;

struct bdi_writeback___148;

struct inode___271 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___271 *i_op;
	struct super_block___271 *i_sb;
	struct address_space___271 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___148 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___272 *i_fop;
		void (*free_inode)(struct inode___271 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___271 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___112 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___271;

struct path___271;

struct dentry_operations___271 {
	int (*d_revalidate)(struct dentry___271 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___271 *, unsigned int);
	int (*d_hash)(const struct dentry___271 *, struct qstr *);
	int (*d_compare)(const struct dentry___271 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___271 *);
	int (*d_init)(struct dentry___271 *);
	void (*d_release)(struct dentry___271 *);
	void (*d_prune)(struct dentry___271 *);
	void (*d_iput)(struct dentry___271 *, struct inode___271 *);
	char * (*d_dname)(struct dentry___271 *, char *, int);
	struct vfsmount___271 * (*d_automount)(struct path___271 *);
	int (*d_manage)(const struct path___271 *, bool);
	struct dentry___271 * (*d_real)(struct dentry___271 *, const struct inode___271 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___271;

struct mem_dqinfo___271 {
	struct quota_format_type___271 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___271;

struct quota_info___271 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___271 *files[3];
	struct mem_dqinfo___271 info[3];
	const struct quota_format_ops___271 *ops[3];
};

struct rcuwait___272 {
	struct task_struct___278 *task;
};

struct percpu_rw_semaphore___272 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___272 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___271 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___272 rw_sem[3];
};

struct shrink_control___136;

struct shrinker___136 {
	long unsigned int (*count_objects)(struct shrinker___136 *, struct shrink_control___136 *);
	long unsigned int (*scan_objects)(struct shrinker___136 *, struct shrink_control___136 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___271;

struct dquot_operations___271;

struct quotactl_ops___271;

struct block_device___165;

struct super_block___271 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___271 *s_type;
	const struct super_operations___271 *s_op;
	const struct dquot_operations___271 *dq_op;
	const struct quotactl_ops___271 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___271 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___165 *s_bdev;
	struct backing_dev_info___148 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___271 s_dquot;
	struct sb_writers___271 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___271 *s_d_op;
	int cleancache_poolid;
	struct shrinker___136 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___271 {
	struct dentry___271 *mnt_root;
	struct super_block___271 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___271 {
	struct vfsmount___271 *mnt;
	struct dentry___271 *dentry;
};

struct pid_namespace___248;

struct upid___248 {
	int nr;
	struct pid_namespace___248 *ns;
};

struct pid_namespace___248 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___278 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___248 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___248 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___248 numbers[1];
};

typedef struct page___276 *pgtable_t___276;

struct page_pool___100;

struct dev_pagemap___266;

struct page___276 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___271 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___100 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___276 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___276 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___277 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___266 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___266;

struct vm_area_struct___276 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___276 *vm_next;
	struct vm_area_struct___276 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___277 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___266 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___271 *vm_file;
	struct file___271 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___272 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___278 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___278 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___248 *pids[4];
	struct pid___248 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___277 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___276;

struct mm_struct___277 {
	struct {
		struct vm_area_struct___276 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___271 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___276 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___278 *owner;
		struct user_namespace___26 *user_ns;
		struct file___271 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___85;

struct cgroup_namespace___198;

struct nsproxy___257 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___248 *pid_ns_for_children;
	struct net___85 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___198 *cgroup_ns;
};

struct bio___162;

struct bio_list___162 {
	struct bio___162 *head;
	struct bio___162 *tail;
};

struct cgroup_subsys_state___198;

struct bdi_writeback___148 {
	struct backing_dev_info___148 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___198 *memcg_css;
	struct cgroup_subsys_state___198 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___252;

struct backing_dev_info___148 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___148 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___252 *dev;
	char dev_name[64];
	struct device___252 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___271 *debug_dir;
};

struct io_cq___162;

struct io_context___162 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___162 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___198;

struct css_set___198 {
	struct cgroup_subsys_state___198 *subsys[14];
	refcount_t refcount;
	struct css_set___198 *dom_cset;
	struct cgroup___198 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___198 *mg_src_cgrp;
	struct cgroup___198 *mg_dst_cgrp;
	struct css_set___198 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___271;

struct pipe_buffer___112;

struct pipe_inode_info___112 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___276 *tmp_page;
	struct fasync_struct___271 *fasync_readers;
	struct fasync_struct___271 *fasync_writers;
	struct pipe_buffer___112 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___198;

struct cgroup_subsys_state___198 {
	struct cgroup___198 *cgroup;
	struct cgroup_subsys___198 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___198 *parent;
};

struct cgroup_file___198 {
	struct kernfs_node___259 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___136;

struct mem_cgroup_per_node___136;

struct mem_cgroup___136 {
	struct cgroup_subsys_state___198 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___198 events_file;
	struct cgroup_file___198 events_local_file;
	struct cgroup_file___198 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___136 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___278 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___136 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___162;

struct blk_integrity___162 {
	const struct blk_integrity_profile___162 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___162 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___162 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___162;

struct elevator_queue___162;

struct blk_mq_ops___157;

struct blk_mq_hw_ctx___157;

struct gendisk___165;

struct blkcg_gq___150;

struct blk_mq_tag_set___157;

struct request_queue___162 {
	struct request___162 *last_merge;
	struct elevator_queue___162 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___157 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___157 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___165 *disk;
	struct kobject___259 kobj;
	struct kobject___259 *mq_kobj;
	struct blk_integrity___162 integrity;
	struct device___252 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___150 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___157 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___162 bio_split;
	struct dentry___271 *debugfs_dir;
	struct dentry___271 *sched_debugfs_dir;
	struct dentry___271 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___254 {
	struct vm_struct___254 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___276 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___136 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___136 *memcg;
};

struct page_pool_params___100 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___252 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___100 {
	u32 count;
	struct page___276 *cache[128];
};

struct page_pool___100 {
	struct page_pool_params___100 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___276 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___100 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___266;

struct dev_pagemap___266 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___266 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___248 {
	rwlock_t lock;
	struct pid___248 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___271 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___271 f_path;
	struct inode___271 *f_inode;
	const struct file_operations___272 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___248 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___271 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___266;

struct vm_operations_struct___266 {
	void (*open)(struct vm_area_struct___276 *);
	void (*close)(struct vm_area_struct___276 *);
	int (*may_split)(struct vm_area_struct___276 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___276 *);
	int (*mprotect)(struct vm_area_struct___276 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___266 *);
	vm_fault_t (*huge_fault)(struct vm_fault___266 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___266 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___276 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___266 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___266 *);
	int (*access)(struct vm_area_struct___276 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___276 *);
	int (*set_policy)(struct vm_area_struct___276 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___276 *, long unsigned int);
	struct page___276 * (*find_special_page)(struct vm_area_struct___276 *, long unsigned int);
};

struct core_thread___276 {
	struct task_struct___278 *task;
	struct core_thread___276 *next;
};

struct core_state___276 {
	atomic_t nr_threads;
	struct core_thread___276 dumper;
	struct completion startup;
};

struct vm_fault___266 {
	const struct {
		struct vm_area_struct___276 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___276 *cow_page;
	struct page___276 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___276 prealloc_pte;
};

struct pglist_data___144;

struct lruvec___144 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___144 *pgdat;
};

struct zone___144 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___144 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___144 {
	struct zone___144 *zone;
	int zone_idx;
};

struct zonelist___144 {
	struct zoneref___144 _zonerefs[321];
};

struct pglist_data___144 {
	struct zone___144 node_zones[5];
	struct zonelist___144 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___278 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___278 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___144 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___198 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___278 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___74;

struct cgroup_bpf___74 {
	struct bpf_prog_array___74 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___74 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___198;

struct cgroup_rstat_cpu___198;

struct cgroup___198 {
	struct cgroup_subsys_state___198 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___259 *kn;
	struct cgroup_file___198 procs_file;
	struct cgroup_file___198 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___198 *subsys[14];
	struct cgroup_root___198 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___198 *dom_cgrp;
	struct cgroup___198 *old_dom_cgrp;
	struct cgroup_rstat_cpu___198 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___198 psi;
	struct cgroup_bpf___74 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___162 {
	struct request_queue___162 *q;
	struct io_context___162 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___271 {
	struct file___271 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___271 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___115 *ki_waitq;
	};
};

struct iattr___271 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___271 *ia_file;
};

struct dquot___271 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___271 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___271 {
	int qf_fmt_id;
	const struct quota_format_ops___271 *qf_ops;
	struct module___255 *qf_owner;
	struct quota_format_type___271 *qf_next;
};

struct quota_format_ops___271 {
	int (*check_quota_file)(struct super_block___271 *, int);
	int (*read_file_info)(struct super_block___271 *, int);
	int (*write_file_info)(struct super_block___271 *, int);
	int (*free_file_info)(struct super_block___271 *, int);
	int (*read_dqblk)(struct dquot___271 *);
	int (*commit_dqblk)(struct dquot___271 *);
	int (*release_dqblk)(struct dquot___271 *);
	int (*get_next_id)(struct super_block___271 *, struct kqid *);
};

struct dquot_operations___271 {
	int (*write_dquot)(struct dquot___271 *);
	struct dquot___271 * (*alloc_dquot)(struct super_block___271 *, int);
	void (*destroy_dquot)(struct dquot___271 *);
	int (*acquire_dquot)(struct dquot___271 *);
	int (*release_dquot)(struct dquot___271 *);
	int (*mark_dirty)(struct dquot___271 *);
	int (*write_info)(struct super_block___271 *, int);
	qsize_t * (*get_reserved_space)(struct inode___271 *);
	int (*get_projid)(struct inode___271 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___271 *, qsize_t *);
	int (*get_next_id)(struct super_block___271 *, struct kqid *);
};

struct quotactl_ops___271 {
	int (*quota_on)(struct super_block___271 *, int, int, const struct path___271 *);
	int (*quota_off)(struct super_block___271 *, int);
	int (*quota_enable)(struct super_block___271 *, unsigned int);
	int (*quota_disable)(struct super_block___271 *, unsigned int);
	int (*quota_sync)(struct super_block___271 *, int);
	int (*set_info)(struct super_block___271 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___271 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___271 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___271 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___271 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___271 *, unsigned int);
};

struct writeback_control___148;

struct address_space_operations___271 {
	int (*writepage)(struct page___276 *, struct writeback_control___148 *);
	int (*readpage)(struct file___271 *, struct page___276 *);
	int (*writepages)(struct address_space___271 *, struct writeback_control___148 *);
	int (*set_page_dirty)(struct page___276 *);
	int (*readpages)(struct file___271 *, struct address_space___271 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___271 *, struct address_space___271 *, loff_t, unsigned int, unsigned int, struct page___276 **, void **);
	int (*write_end)(struct file___271 *, struct address_space___271 *, loff_t, unsigned int, unsigned int, struct page___276 *, void *);
	sector_t (*bmap)(struct address_space___271 *, sector_t);
	void (*invalidatepage)(struct page___276 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___276 *, gfp_t);
	void (*freepage)(struct page___276 *);
	ssize_t (*direct_IO)(struct kiocb___271 *, struct iov_iter___191 *);
	int (*migratepage)(struct address_space___271 *, struct page___276 *, struct page___276 *, enum migrate_mode);
	bool (*isolate_page)(struct page___276 *, isolate_mode_t);
	void (*putback_page)(struct page___276 *);
	int (*launder_page)(struct page___276 *);
	int (*is_partially_uptodate)(struct page___276 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___276 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___271 *, struct page___276 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___271 *, sector_t *);
	void (*swap_deactivate)(struct file___271 *);
};

struct writeback_control___148 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___148 *wb;
	struct inode___271 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___188;

struct iov_iter___191 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___188 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___112 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___271 {
	struct dentry___271 * (*lookup)(struct inode___271 *, struct dentry___271 *, unsigned int);
	const char * (*get_link)(struct dentry___271 *, struct inode___271 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___271 *, int);
	struct posix_acl * (*get_acl)(struct inode___271 *, int, bool);
	int (*readlink)(struct dentry___271 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___271 *, struct dentry___271 *, umode_t, bool);
	int (*link)(struct dentry___271 *, struct inode___271 *, struct dentry___271 *);
	int (*unlink)(struct inode___271 *, struct dentry___271 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___271 *, struct dentry___271 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___271 *, struct dentry___271 *, umode_t);
	int (*rmdir)(struct inode___271 *, struct dentry___271 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___271 *, struct dentry___271 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___271 *, struct dentry___271 *, struct inode___271 *, struct dentry___271 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___271 *, struct iattr___271 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___271 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___271 *, char *, size_t);
	int (*fiemap)(struct inode___271 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___271 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___271 *, struct dentry___271 *, struct file___271 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___271 *, struct dentry___271 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___271 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___271 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___271 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___271 {
	void (*fl_copy_lock)(struct file_lock___271 *, struct file_lock___271 *);
	void (*fl_release_private)(struct file_lock___271 *);
};

struct lock_manager_operations___271;

struct file_lock___271 {
	struct file_lock___271 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___271 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___271 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___271 *fl_ops;
	const struct lock_manager_operations___271 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___271 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___271 *);
	int (*lm_grant)(struct file_lock___271 *, int);
	bool (*lm_break)(struct file_lock___271 *);
	int (*lm_change)(struct file_lock___271 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___271 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___271 *);
};

struct fasync_struct___271 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___271 *fa_next;
	struct file___271 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___271 {
	struct inode___271 * (*alloc_inode)(struct super_block___271 *);
	void (*destroy_inode)(struct inode___271 *);
	void (*free_inode)(struct inode___271 *);
	void (*dirty_inode)(struct inode___271 *, int);
	int (*write_inode)(struct inode___271 *, struct writeback_control___148 *);
	int (*drop_inode)(struct inode___271 *);
	void (*evict_inode)(struct inode___271 *);
	void (*put_super)(struct super_block___271 *);
	int (*sync_fs)(struct super_block___271 *, int);
	int (*freeze_super)(struct super_block___271 *);
	int (*freeze_fs)(struct super_block___271 *);
	int (*thaw_super)(struct super_block___271 *);
	int (*unfreeze_fs)(struct super_block___271 *);
	int (*statfs)(struct dentry___271 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___271 *, int *, char *);
	void (*umount_begin)(struct super_block___271 *);
	int (*show_options)(struct seq_file___246 *, struct dentry___271 *);
	int (*show_devname)(struct seq_file___246 *, struct dentry___271 *);
	int (*show_path)(struct seq_file___246 *, struct dentry___271 *);
	int (*show_stats)(struct seq_file___246 *, struct dentry___271 *);
	ssize_t (*quota_read)(struct super_block___271 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___271 *, int, const char *, size_t, loff_t);
	struct dquot___271 ** (*get_dquots)(struct inode___271 *);
	long int (*nr_cached_objects)(struct super_block___271 *, struct shrink_control___136 *);
	long int (*free_cached_objects)(struct super_block___271 *, struct shrink_control___136 *);
	struct file___271 * (*real_loop)(struct file___271 *);
};

struct wakeup_source___252;

struct dev_pm_info___252 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___252 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___252 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___252;

struct bus_type___252;

struct device_driver___252;

struct dev_pm_domain___252;

struct fwnode_handle___248;

struct class___252;

struct attribute_group___259;

struct device___252 {
	struct kobject___259 kobj;
	struct device___252 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___252 *type;
	struct bus_type___252 *bus;
	struct device_driver___252 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___252 power;
	struct dev_pm_domain___252 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___248 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___252 *class;
	const struct attribute_group___259 **groups;
	void (*release)(struct device___252 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___165 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___271 *bd_inode;
	struct super_block___271 *bd_super;
	void *bd_claiming;
	struct device___252 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___259 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___165 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___271 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___200)(struct file___271 *, wait_queue_head_t *, struct poll_table_struct___192 *);

struct poll_table_struct___192 {
	poll_queue_proc___200 _qproc;
	__poll_t _key;
};

struct seq_operations___246;

struct seq_file___246 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___246 *op;
	int poll_event;
	const struct file___271 *file;
	void *private;
};

typedef void bio_end_io_t___162(struct bio___162 *);

struct bio_vec___188 {
	struct page___276 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___162;

struct bio___162 {
	struct bio___162 *bi_next;
	struct block_device___165 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___162 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___150 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___162 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___188 *bi_io_vec;
	struct bio_set___162 *bi_pool;
	struct bio_vec___188 bi_inline_vecs[0];
};

struct dev_pagemap_ops___266 {
	void (*page_free)(struct page___276 *);
	void (*kill)(struct dev_pagemap___266 *);
	void (*cleanup)(struct dev_pagemap___266 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___266 *);
};

struct fwnode_operations___248;

struct fwnode_handle___248 {
	struct fwnode_handle___248 *secondary;
	const struct fwnode_operations___248 *ops;
	struct device___252 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___248;

struct fwnode_endpoint___248;

struct fwnode_operations___248 {
	struct fwnode_handle___248 * (*get)(struct fwnode_handle___248 *);
	void (*put)(struct fwnode_handle___248 *);
	bool (*device_is_available)(const struct fwnode_handle___248 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___248 *, const struct device___252 *);
	bool (*property_present)(const struct fwnode_handle___248 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___248 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___248 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___248 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*get_parent)(const struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*get_next_child_node)(const struct fwnode_handle___248 *, struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*get_named_child_node)(const struct fwnode_handle___248 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___248 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___248 *);
	struct fwnode_handle___248 * (*graph_get_next_endpoint)(const struct fwnode_handle___248 *, struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*graph_get_remote_endpoint)(const struct fwnode_handle___248 *);
	struct fwnode_handle___248 * (*graph_get_port_parent)(struct fwnode_handle___248 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___248 *, struct fwnode_endpoint___248 *);
	int (*add_links)(struct fwnode_handle___248 *);
};

struct fwnode_endpoint___248 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___248 *local_fwnode;
};

struct fwnode_reference_args___248 {
	struct fwnode_handle___248 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___259;

struct kernfs_elem_dir___259 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___259 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___259;

struct kernfs_root___259 {
	struct kernfs_node___259 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___259 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___259 {
	struct kernfs_node___259 *target_kn;
};

struct kernfs_ops___259;

struct kernfs_elem_attr___259 {
	const struct kernfs_ops___259 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___259 *notify_next;
};

struct kernfs_node___259 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___259 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___259 dir;
		struct kernfs_elem_symlink___259 symlink;
		struct kernfs_elem_attr___259 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___259;

struct kernfs_ops___259 {
	int (*open)(struct kernfs_open_file___259 *);
	void (*release)(struct kernfs_open_file___259 *);
	int (*seq_show)(struct seq_file___246 *, void *);
	void * (*seq_start)(struct seq_file___246 *, loff_t *);
	void * (*seq_next)(struct seq_file___246 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___246 *, void *);
	ssize_t (*read)(struct kernfs_open_file___259 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___259 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___259 *, struct poll_table_struct___192 *);
	int (*mmap)(struct kernfs_open_file___259 *, struct vm_area_struct___276 *);
};

struct kernfs_syscall_ops___259 {
	int (*show_options)(struct seq_file___246 *, struct kernfs_root___259 *);
	int (*mkdir)(struct kernfs_node___259 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___259 *);
	int (*rename)(struct kernfs_node___259 *, struct kernfs_node___259 *, const char *);
	int (*show_path)(struct seq_file___246 *, struct kernfs_node___259 *, struct kernfs_root___259 *);
};

struct kernfs_open_file___259 {
	struct kernfs_node___259 *kn;
	struct file___271 *file;
	struct seq_file___246 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___266 *vm_ops;
};

struct sock___67;

struct kobj_ns_type_operations___67 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___67 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___85 *net;
} possible_net_t___80;

struct proto___67;

struct sock_common___67 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___67 *skc_prot;
	possible_net_t___80 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___67 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___81;

struct sk_buff_head___80 {
	struct sk_buff___81 *next;
	struct sk_buff___81 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___67 {
	struct cgroup___198 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___67;

struct socket_wq___68;

struct dst_entry___67;

struct socket___69;

struct net_device___80;

struct sock_reuseport___19;

struct sock___67 {
	struct sock_common___67 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___80 sk_error_queue;
	struct sk_buff___81 *sk_rx_skb_cache;
	struct sk_buff_head___80 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___81 *head;
		struct sk_buff___81 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___67 *sk_filter;
	union {
		struct socket_wq___68 *sk_wq;
		struct socket_wq___68 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___67 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___67 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___81 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___81 *sk_tx_skb_cache;
	struct sk_buff_head___80 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___276 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___67 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___248 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___69 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___67 sk_cgrp_data;
	struct mem_cgroup___136 *sk_memcg;
	void (*sk_state_change)(struct sock___67 *);
	void (*sk_data_ready)(struct sock___67 *);
	void (*sk_write_space)(struct sock___67 *);
	void (*sk_error_report)(struct sock___67 *);
	int (*sk_backlog_rcv)(struct sock___67 *, struct sk_buff___81 *);
	struct sk_buff___81 * (*sk_validate_xmit_skb)(struct sock___67 *, struct net_device___80 *, struct sk_buff___81 *);
	void (*sk_destruct)(struct sock___67 *);
	struct sock_reuseport___19 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___259;

struct attribute_group___259 {
	const char *name;
	umode_t (*is_visible)(struct kobject___259 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___259 *, struct bin_attribute___259 *, int);
	struct attribute **attrs;
	struct bin_attribute___259 **bin_attrs;
};

struct bin_attribute___259 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___271 * (*f_mapping)();
	ssize_t (*read)(struct file___271 *, struct kobject___259 *, struct bin_attribute___259 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___271 *, struct kobject___259 *, struct bin_attribute___259 *, char *, loff_t, size_t);
	int (*mmap)(struct file___271 *, struct kobject___259 *, struct bin_attribute___259 *, struct vm_area_struct___276 *);
};

struct sysfs_ops___259 {
	ssize_t (*show)(struct kobject___259 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___259 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___259;

struct kset___259 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___259 kobj;
	const struct kset_uevent_ops___259 *uevent_ops;
};

struct kobj_type___259 {
	void (*release)(struct kobject___259 *);
	const struct sysfs_ops___259 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___259 **default_groups;
	const struct kobj_ns_type_operations___67 * (*child_ns_type)(struct kobject___259 *);
	const void * (*namespace)(struct kobject___259 *);
	void (*get_ownership)(struct kobject___259 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___259 {
	int (* const filter)(struct kset___259 *, struct kobject___259 *);
	const char * (* const name)(struct kset___259 *, struct kobject___259 *);
	int (* const uevent)(struct kset___259 *, struct kobject___259 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___255 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___255 *);
	int (*get)(char *, const struct kernel_param___255 *);
	void (*free)(void *);
};

struct kparam_array___255;

struct kernel_param___255 {
	const char *name;
	struct module___255 *mod;
	const struct kernel_param_ops___255 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___255 *arr;
	};
};

struct kparam_array___255 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___255 *ops;
	void *elem;
};

struct module_attribute___255 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___255 *, struct module_kobject___256 *, char *);
	ssize_t (*store)(struct module_attribute___255 *, struct module_kobject___256 *, const char *, size_t);
	void (*setup)(struct module___255 *, const char *);
	int (*test)(struct module___255 *);
	void (*free)(struct module___255 *);
};

struct ip_ra_chain___40;

struct fib_rules_ops___67;

struct fqdir___85;

struct tcp_congestion_ops___18;

struct fib_notifier_ops___67;

struct netns_ipv4___85 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___40 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___67 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___67 *fibnl;
	struct sock___67 **icmp_sk;
	struct sock___67 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___67 **tcp_sk;
	struct fqdir___85 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___18 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___67 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___67 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___67 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___67;

struct dst_ops___85 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___85 *);
	struct dst_entry___67 * (*check)(struct dst_entry___67 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___67 *);
	unsigned int (*mtu)(const struct dst_entry___67 *);
	u32 * (*cow_metrics)(struct dst_entry___67 *, long unsigned int);
	void (*destroy)(struct dst_entry___67 *);
	void (*ifdown)(struct dst_entry___67 *, struct net_device___80 *, int);
	struct dst_entry___67 * (*negative_advice)(struct dst_entry___67 *);
	void (*link_failure)(struct sk_buff___81 *);
	void (*update_pmtu)(struct dst_entry___67 *, struct sock___67 *, struct sk_buff___81 *, u32, bool);
	void (*redirect)(struct dst_entry___67 *, struct sock___67 *, struct sk_buff___81 *);
	int (*local_out)(struct net___85 *, struct sock___67 *, struct sk_buff___81 *);
	struct neighbour___67 * (*neigh_lookup)(const struct dst_entry___67 *, struct sk_buff___81 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___67 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___85 {
	struct dst_ops___85 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___85 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___67 *fib6_rules_ops;
	struct sock___67 **icmp_sk;
	struct sock___67 *ndisc_sk;
	struct sock___67 *tcp_sk;
	struct sock___67 *igmp_sk;
	struct sock___67 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___67 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___67 *notifier_ops;
	struct fib_notifier_ops___67 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___85 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___85 *fqdir;
};

struct netns_sctp___67 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___67 *ctl_sock;
	struct sock___67 *udp4_sock;
	struct sock___67 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___74;

struct netns_bpf___74 {
	struct bpf_prog_array___74 *run_array[2];
	struct bpf_prog___74 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___85 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___67 *nlsk;
	struct sock___67 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___85 xfrm4_dst_ops;
	struct dst_ops___85 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___85 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___67 *rtnl;
	struct sock___67 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___80 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___85 ipv4;
	struct netns_ipv6___85 ipv6;
	struct netns_ieee802154_lowpan___85 ieee802154_lowpan;
	struct netns_sctp___67 sctp;
	struct netns_nf___10 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___80 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___74 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___85 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___67 *crypto_nlsk;
	struct sock___67 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___198 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___198 *root_cset;
};

struct msghdr___69 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___191 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___271 *msg_iocb;
};

struct socket_wq___68 {
	wait_queue_head_t wait;
	struct fasync_struct___271 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___68;

struct socket___69 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___271 *file;
	struct sock___67 *sk;
	const struct proto_ops___68 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___68 wq;
};

typedef int (*sk_read_actor_t___67)(read_descriptor_t *, struct sk_buff___81 *, unsigned int, size_t);

struct proto_ops___68 {
	int family;
	struct module___255 *owner;
	int (*release)(struct socket___69 *);
	int (*bind)(struct socket___69 *, struct sockaddr *, int);
	int (*connect)(struct socket___69 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___69 *, struct socket___69 *);
	int (*accept)(struct socket___69 *, struct socket___69 *, int, bool);
	int (*getname)(struct socket___69 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___271 *, struct socket___69 *, struct poll_table_struct___192 *);
	int (*ioctl)(struct socket___69 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___69 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___69 *, void *, bool, bool);
	int (*listen)(struct socket___69 *, int);
	int (*shutdown)(struct socket___69 *, int);
	int (*setsockopt)(struct socket___69 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___69 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___246 *, struct socket___69 *);
	int (*sendmsg)(struct socket___69 *, struct msghdr___69 *, size_t);
	int (*recvmsg)(struct socket___69 *, struct msghdr___69 *, size_t, int);
	int (*mmap)(struct file___271 *, struct socket___69 *, struct vm_area_struct___276 *);
	ssize_t (*sendpage)(struct socket___69 *, struct page___276 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___69 *, loff_t *, struct pipe_inode_info___112 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___67 *, int);
	int (*peek_len)(struct socket___69 *);
	int (*read_sock)(struct sock___67 *, read_descriptor_t *, sk_read_actor_t___67);
	int (*sendpage_locked)(struct sock___67 *, struct page___276 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___67 *, struct msghdr___69 *, size_t);
	int (*set_rcvlowat)(struct sock___67 *, int);
};

struct sk_buff___81 {
	union {
		struct {
			struct sk_buff___81 *next;
			struct sk_buff___81 *prev;
			union {
				struct net_device___80 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___67 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___81 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___252 {
	int (*prepare)(struct device___252 *);
	void (*complete)(struct device___252 *);
	int (*suspend)(struct device___252 *);
	int (*resume)(struct device___252 *);
	int (*freeze)(struct device___252 *);
	int (*thaw)(struct device___252 *);
	int (*poweroff)(struct device___252 *);
	int (*restore)(struct device___252 *);
	int (*suspend_late)(struct device___252 *);
	int (*resume_early)(struct device___252 *);
	int (*freeze_late)(struct device___252 *);
	int (*thaw_early)(struct device___252 *);
	int (*poweroff_late)(struct device___252 *);
	int (*restore_early)(struct device___252 *);
	int (*suspend_noirq)(struct device___252 *);
	int (*resume_noirq)(struct device___252 *);
	int (*freeze_noirq)(struct device___252 *);
	int (*thaw_noirq)(struct device___252 *);
	int (*poweroff_noirq)(struct device___252 *);
	int (*restore_noirq)(struct device___252 *);
	int (*runtime_suspend)(struct device___252 *);
	int (*runtime_resume)(struct device___252 *);
	int (*runtime_idle)(struct device___252 *);
};

struct wakeup_source___252 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___252 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___252 {
	struct dev_pm_ops___252 ops;
	int (*start)(struct device___252 *);
	void (*detach)(struct device___252 *, bool);
	int (*activate)(struct device___252 *);
	void (*sync)(struct device___252 *);
	void (*dismiss)(struct device___252 *);
};

struct bus_type___252 {
	const char *name;
	const char *dev_name;
	struct device___252 *dev_root;
	const struct attribute_group___259 **bus_groups;
	const struct attribute_group___259 **dev_groups;
	const struct attribute_group___259 **drv_groups;
	int (*match)(struct device___252 *, struct device_driver___252 *);
	int (*uevent)(struct device___252 *, struct kobj_uevent_env *);
	int (*probe)(struct device___252 *);
	void (*sync_state)(struct device___252 *);
	void (*remove)(struct device___252 *);
	void (*shutdown)(struct device___252 *);
	int (*online)(struct device___252 *);
	int (*offline)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	int (*num_vf)(struct device___252 *);
	int (*dma_configure)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___252 {
	const char *name;
	struct bus_type___252 *bus;
	struct module___255 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___252 *);
	void (*sync_state)(struct device___252 *);
	int (*remove)(struct device___252 *);
	void (*shutdown)(struct device___252 *);
	int (*suspend)(struct device___252 *, pm_message_t);
	int (*resume)(struct device___252 *);
	const struct attribute_group___259 **groups;
	const struct attribute_group___259 **dev_groups;
	const struct dev_pm_ops___252 *pm;
	void (*coredump)(struct device___252 *);
	struct driver_private *p;
};

struct device_type___252 {
	const char *name;
	const struct attribute_group___259 **groups;
	int (*uevent)(struct device___252 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___252 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___252 *);
	const struct dev_pm_ops___252 *pm;
};

struct class___252 {
	const char *name;
	struct module___255 *owner;
	const struct attribute_group___259 **class_groups;
	const struct attribute_group___259 **dev_groups;
	struct kobject___259 *dev_kobj;
	int (*dev_uevent)(struct device___252 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___252 *, umode_t *);
	void (*class_release)(struct class___252 *);
	void (*dev_release)(struct device___252 *);
	int (*shutdown_pre)(struct device___252 *);
	const struct kobj_ns_type_operations___67 *ns_type;
	const void * (*namespace)(struct device___252 *);
	void (*get_ownership)(struct device___252 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___252 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___112;

struct pipe_buffer___112 {
	struct page___276 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___112 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___112 {
	int (*confirm)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
	void (*release)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
	bool (*try_steal)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
	bool (*get)(struct pipe_inode_info___112 *, struct pipe_buffer___112 *);
};

typedef rx_handler_result_t rx_handler_func_t___80(struct sk_buff___81 **);

struct bpf_xdp_entity___74 {
	struct bpf_prog___74 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___80;

struct net_device_ops___80;

struct l3mdev_ops___67;

struct ndisc_ops___49;

struct xfrmdev_ops___80;

struct header_ops___80;

struct inet6_dev___49;

struct netdev_rx_queue___80;

struct mini_Qdisc___74;

struct netdev_queue___80;

struct Qdisc___74;

struct rtnl_link_ops___74;

struct dcbnl_rtnl_ops___80;

struct net_device___80 {
	char name[16];
	struct netdev_name_node___80 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___80 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___67 *l3mdev_ops;
	const struct ndisc_ops___49 *ndisc_ops;
	const struct xfrmdev_ops___80 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___80 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___259 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___49 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___80 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___74 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___80 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___74 *miniq_ingress;
	struct netdev_queue___80 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___80 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___74 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___74 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___80 = 0,
		NETREG_REGISTERED___80 = 1,
		NETREG_UNREGISTERING___80 = 2,
		NETREG_UNREGISTERED___80 = 3,
		NETREG_RELEASED___80 = 4,
		NETREG_DUMMY___80 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___80 = 0,
		RTNL_LINK_INITIALIZING___80 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___80 *);
	struct netpoll_info *npinfo;
	possible_net_t___80 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___252 dev;
	const struct attribute_group___259 *sysfs_groups[4];
	const struct attribute_group___259 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___74 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___80 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___74 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___188 skb_frag_t___27;

struct ubuf_info___9 {
	void (*callback)(struct sk_buff___81 *, struct ubuf_info___9 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___26 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___81 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___27 frags[17];
};

struct sk_buff_fclones___2 {
	struct sk_buff___81 skb1;
	struct sk_buff___81 skb2;
	refcount_t fclone_ref;
};

enum pkt_hash_types {
	PKT_HASH_TYPE_NONE = 0,
	PKT_HASH_TYPE_L2 = 1,
	PKT_HASH_TYPE_L3 = 2,
	PKT_HASH_TYPE_L4 = 3,
};

struct inet_frags___85;

struct fqdir___85 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___85 *f;
	struct net___85 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___85;

struct inet_frags___85 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___85 *, const void *);
	void (*destructor)(struct inet_frag_queue___85 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___85 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___81 *fragments_tail;
	struct sk_buff___81 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___85 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___40 {
	struct ip_ra_chain___40 *next;
	struct sock___67 *sk;
	union {
		void (*destructor)(struct sock___67 *);
		struct sock___67 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___67;

struct fib_lookup_arg___67;

struct fib_rules_ops___67 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___67 *, struct flowi *, int, struct fib_lookup_arg___67 *);
	bool (*suppress)(struct fib_rule___67 *, int, struct fib_lookup_arg___67 *);
	int (*match)(struct fib_rule___67 *, struct flowi *, int);
	int (*configure)(struct fib_rule___67 *, struct sk_buff___81 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___67 *);
	int (*compare)(struct fib_rule___67 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___67 *, struct sk_buff___81 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___67 *);
	void (*flush_cache)(struct fib_rules_ops___67 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___255 *owner;
	struct net___85 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___18 {
	u32 (*ssthresh)(struct sock___67 *);
	void (*cong_avoid)(struct sock___67 *, u32, u32);
	void (*set_state)(struct sock___67 *, u8);
	void (*cwnd_event)(struct sock___67 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___67 *, u32);
	void (*pkts_acked)(struct sock___67 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___67 *);
	void (*cong_control)(struct sock___67 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___67 *);
	u32 (*sndbuf_expand)(struct sock___67 *);
	size_t (*get_info)(struct sock___67 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___255 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___67 *);
	void (*release)(struct sock___67 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___67 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___85 *);
	int (*fib_dump)(struct net___85 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___255 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___43;

struct dst_entry___67 {
	struct net_device___80 *dev;
	struct dst_ops___85 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___81 *);
	int (*output)(struct net___85 *, struct sock___67 *, struct sk_buff___81 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___43 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___67;

struct neigh_parms___67;

struct neigh_ops___67;

struct neighbour___67 {
	struct neighbour___67 *next;
	struct neigh_table___67 *tbl;
	struct neigh_parms___67 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___80 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___67 *, struct sk_buff___81 *);
	const struct neigh_ops___67 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___80 *dev;
	u8 primary_key[0];
};

enum {
	BPF_WRITE_HDR_TCP_CURRENT_MSS = 1,
	BPF_WRITE_HDR_TCP_SYNACK_COOKIE = 2,
};

struct bpf_prog_array_item___74 {
	struct bpf_prog___74 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___74 {
	struct callback_head rcu;
	struct bpf_prog_array_item___74 items[0];
};

struct bpf_prog_aux___83;

struct bpf_prog___74 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___83 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___246 {
	void * (*start)(struct seq_file___246 *, loff_t *);
	void (*stop)(struct seq_file___246 *, void *);
	void * (*next)(struct seq_file___246 *, void *, loff_t *);
	int (*show)(struct seq_file___246 *, void *);
};

struct dcbnl_rtnl_ops___80 {
	int (*ieee_getets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___80 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___80 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___80 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___80 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___80 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___80 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___80 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___80 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___80 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___80 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___80 *);
	u8 (*setstate)(struct net_device___80 *, u8);
	void (*getpermhwaddr)(struct net_device___80 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___80 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___80 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___80 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___80 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___80 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___80 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___80 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___80 *, int, u8 *);
	void (*setpfccfg)(struct net_device___80 *, int, u8);
	void (*getpfccfg)(struct net_device___80 *, int, u8 *);
	u8 (*setall)(struct net_device___80 *);
	u8 (*getcap)(struct net_device___80 *, int, u8 *);
	int (*getnumtcs)(struct net_device___80 *, int, u8 *);
	int (*setnumtcs)(struct net_device___80 *, int, u8);
	u8 (*getpfcstate)(struct net_device___80 *);
	void (*setpfcstate)(struct net_device___80 *, u8);
	void (*getbcncfg)(struct net_device___80 *, int, u32 *);
	void (*setbcncfg)(struct net_device___80 *, int, u32);
	void (*getbcnrp)(struct net_device___80 *, int, u8 *);
	void (*setbcnrp)(struct net_device___80 *, int, u8);
	int (*setapp)(struct net_device___80 *, u8, u16, u8);
	int (*getapp)(struct net_device___80 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___80 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___80 *, int, u8);
	u8 (*getdcbx)(struct net_device___80 *);
	u8 (*setdcbx)(struct net_device___80 *, u8);
	int (*peer_getappinfo)(struct net_device___80 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___80 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___80 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___80 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___80 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___80 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___83;

typedef int (*bpf_iter_init_seq_priv_t___82)(void *, struct bpf_iter_aux_info___83 *);

struct bpf_map___83;

struct bpf_iter_aux_info___83 {
	struct bpf_map___83 *map;
};

struct bpf_iter_seq_info___82 {
	const struct seq_operations___246 *seq_ops;
	bpf_iter_init_seq_priv_t___82 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___82 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___83 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___83 *, struct file___271 *);
	void (*map_free)(struct bpf_map___83 *);
	int (*map_get_next_key)(struct bpf_map___83 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___83 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___83 *, void *);
	int (*map_lookup_batch)(struct bpf_map___83 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___83 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___83 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___83 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___83 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___83 *, void *);
	int (*map_update_elem)(struct bpf_map___83 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___83 *, void *);
	int (*map_push_elem)(struct bpf_map___83 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___83 *, void *);
	int (*map_peek_elem)(struct bpf_map___83 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___83 *, struct file___271 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___83 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___83 *, void *, struct seq_file___246 *);
	int (*map_check_btf)(const struct bpf_map___83 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___83 *, struct bpf_prog_aux___83 *);
	void (*map_poke_untrack)(struct bpf_map___83 *, struct bpf_prog_aux___83 *);
	void (*map_poke_run)(struct bpf_map___83 *, u32, struct bpf_prog___74 *, struct bpf_prog___74 *);
	int (*map_direct_value_addr)(const struct bpf_map___83 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___83 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___83 *, struct vm_area_struct___276 *);
	__poll_t (*map_poll)(struct bpf_map___83 *, struct file___271 *, struct poll_table_struct___192 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___83 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___83 *, const struct bpf_map___83 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___83 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___82 *iter_seq_info;
};

struct bpf_map___83 {
	const struct bpf_map_ops___82 *ops;
	struct bpf_map___83 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___136 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___82;

struct bpf_jit_poke_descriptor___82;

struct bpf_prog_ops___74;

struct btf_mod_pair___82;

struct bpf_prog_offload___80;

struct bpf_prog_aux___83 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___74 *dst_prog;
	struct bpf_trampoline___82 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___74 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___82 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___74 *ops;
	struct bpf_map___83 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___82 *used_btfs;
	struct bpf_prog___74 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___83 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___80 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___80;

struct bpf_map_dev_ops___80 {
	int (*map_get_next_key)(struct bpf_offloaded_map___80 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___80 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___80 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___80 *, void *);
};

struct bpf_offloaded_map___80 {
	struct bpf_map___83 map;
	struct net_device___80 *netdev;
	const struct bpf_map_dev_ops___80 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___74 {
	int (*test_run)(struct bpf_prog___74 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___80 {
	struct bpf_prog___74 *prog;
	struct net_device___80 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___82 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___74 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___255 *mod;
};

struct bpf_jit_poke_descriptor___82 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___83 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___82 {
	struct btf *btf;
	struct module___255 *module;
};

struct cftype___198;

struct cgroup_subsys___198 {
	struct cgroup_subsys_state___198 * (*css_alloc)(struct cgroup_subsys_state___198 *);
	int (*css_online)(struct cgroup_subsys_state___198 *);
	void (*css_offline)(struct cgroup_subsys_state___198 *);
	void (*css_released)(struct cgroup_subsys_state___198 *);
	void (*css_free)(struct cgroup_subsys_state___198 *);
	void (*css_reset)(struct cgroup_subsys_state___198 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___198 *, int);
	int (*css_extra_stat_show)(struct seq_file___246 *, struct cgroup_subsys_state___198 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___278 *, struct css_set___198 *);
	void (*cancel_fork)(struct task_struct___278 *, struct css_set___198 *);
	void (*fork)(struct task_struct___278 *);
	void (*exit)(struct task_struct___278 *);
	void (*release)(struct task_struct___278 *);
	void (*bind)(struct cgroup_subsys_state___198 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___198 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___198 *dfl_cftypes;
	struct cftype___198 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___198 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___198 *updated_children;
	struct cgroup___198 *updated_next;
};

struct cgroup_root___198 {
	struct kernfs_root___259 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___198 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___198 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___198 *ss;
	struct list_head node;
	struct kernfs_ops___259 *kf_ops;
	int (*open)(struct kernfs_open_file___259 *);
	void (*release)(struct kernfs_open_file___259 *);
	u64 (*read_u64)(struct cgroup_subsys_state___198 *, struct cftype___198 *);
	s64 (*read_s64)(struct cgroup_subsys_state___198 *, struct cftype___198 *);
	int (*seq_show)(struct seq_file___246 *, void *);
	void * (*seq_start)(struct seq_file___246 *, loff_t *);
	void * (*seq_next)(struct seq_file___246 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___246 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___198 *, struct cftype___198 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___198 *, struct cftype___198 *, s64);
	ssize_t (*write)(struct kernfs_open_file___259 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___259 *, struct poll_table_struct___192 *);
};

struct xdp_rxq_info___80 {
	struct net_device___80 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___80 {
	struct net_device___80 *dev;
};

struct xdp_buff___80 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___80 *rxq;
	struct xdp_txq_info___80 *txq;
	u32 frame_sz;
};

struct xdp_frame___80 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___80 *dev_rx;
};

struct netlink_callback___80 {
	struct sk_buff___81 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___81 *, struct netlink_callback___80 *);
	int (*done)(struct netlink_callback___80 *);
	void *data;
	struct module___255 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___80 {
	int (*create)(struct sk_buff___81 *, struct net_device___80 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___81 *, unsigned char *);
	int (*cache)(const struct neighbour___67 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___80 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___81 *);
};

struct netdev_queue___80 {
	struct net_device___80 *dev;
	struct Qdisc___74 *qdisc;
	struct Qdisc___74 *qdisc_sleeping;
	struct kobject___259 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___80 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___74 {
	struct sk_buff___81 *head;
	struct sk_buff___81 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___74;

struct Qdisc___74 {
	int (*enqueue)(struct sk_buff___81 *, struct Qdisc___74 *, struct sk_buff___81 **);
	struct sk_buff___81 * (*dequeue)(struct Qdisc___74 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___74 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___80 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___80 gso_skb;
	struct qdisc_skb_head___74 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___74 *next_sched;
	struct sk_buff_head___80 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___80 {
	struct xdp_rxq_info___80 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___259 kobj;
	struct net_device___80 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___80 {
	enum net_device_path_type type;
	const struct net_device___80 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___80 = 0,
				DEV_PATH_BR_VLAN_TAG___80 = 1,
				DEV_PATH_BR_VLAN_UNTAG___80 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___80 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___80 {
	const struct net_device___80 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___80 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___74 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___80 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___80 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___81 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___80 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___80 *dev;
	const char *name;
};

struct net_device_ops___80 {
	int (*ndo_init)(struct net_device___80 *);
	void (*ndo_uninit)(struct net_device___80 *);
	int (*ndo_open)(struct net_device___80 *);
	int (*ndo_stop)(struct net_device___80 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___81 *, struct net_device___80 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___81 *, struct net_device___80 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___80 *, struct sk_buff___81 *, struct net_device___80 *);
	void (*ndo_change_rx_flags)(struct net_device___80 *, int);
	void (*ndo_set_rx_mode)(struct net_device___80 *);
	int (*ndo_set_mac_address)(struct net_device___80 *, void *);
	int (*ndo_validate_addr)(struct net_device___80 *);
	int (*ndo_do_ioctl)(struct net_device___80 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___80 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___80 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___80 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___80 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___80 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___80 *, int);
	int (*ndo_neigh_setup)(struct net_device___80 *, struct neigh_parms___67 *);
	void (*ndo_tx_timeout)(struct net_device___80 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___80 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___80 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___80 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___80 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___80 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___80 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___80 *);
	int (*ndo_netpoll_setup)(struct net_device___80 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___80 *);
	int (*ndo_set_vf_mac)(struct net_device___80 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___80 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___80 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___80 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___80 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___80 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___80 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___80 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___80 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___80 *, int, struct sk_buff___81 *);
	int (*ndo_get_vf_guid)(struct net_device___80 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___80 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___80 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___80 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___80 *);
	int (*ndo_fcoe_disable)(struct net_device___80 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___80 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___80 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___80 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___80 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___80 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___80 *, const struct sk_buff___81 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___80 *, struct net_device___80 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___80 *, struct net_device___80 *);
	struct net_device___80 * (*ndo_get_xmit_slave)(struct net_device___80 *, struct sk_buff___81 *, bool);
	struct net_device___80 * (*ndo_sk_get_lower_dev)(struct net_device___80 *, struct sock___67 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___80 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___80 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___80 *, struct neighbour___67 *);
	void (*ndo_neigh_destroy)(struct net_device___80 *, struct neighbour___67 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___81 *, struct netlink_callback___80 *, struct net_device___80 *, struct net_device___80 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___81 *, struct nlattr **, struct net_device___80 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___80 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___81 *, u32, u32, struct net_device___80 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___80 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___80 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___80 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___80 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___80 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___80 *, struct net_device___80 *);
	void (*ndo_dfwd_del_station)(struct net_device___80 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___80 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___80 *);
	int (*ndo_change_proto_down)(struct net_device___80 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___80 *, struct sk_buff___81 *);
	void (*ndo_set_rx_headroom)(struct net_device___80 *, int);
	int (*ndo_bpf)(struct net_device___80 *, struct netdev_bpf___80 *);
	int (*ndo_xdp_xmit)(struct net_device___80 *, int, struct xdp_frame___80 **, u32);
	struct net_device___80 * (*ndo_xdp_get_xmit_slave)(struct net_device___80 *, struct xdp_buff___80 *);
	int (*ndo_xsk_wakeup)(struct net_device___80 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___80 *);
	int (*ndo_tunnel_ctl)(struct net_device___80 *, struct ip_tunnel_parm *, int);
	struct net_device___80 * (*ndo_get_peer_dev)(struct net_device___80 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___80 *, struct net_device_path___80 *);
};

struct neigh_parms___67 {
	possible_net_t___80 net;
	struct net_device___80 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___67 *);
	struct neigh_table___67 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___67 {
	u32 (*l3mdev_fib_table)(const struct net_device___80 *);
	struct sk_buff___81 * (*l3mdev_l3_rcv)(struct net_device___80 *, struct sk_buff___81 *, u16);
	struct sk_buff___81 * (*l3mdev_l3_out)(struct net_device___80 *, struct sock___67 *, struct sk_buff___81 *, u16);
	struct dst_entry___67 * (*l3mdev_link_scope_lookup)(const struct net_device___80 *, struct flowi6 *);
};

struct ndisc_ops___49 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___80 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___80 *, struct neighbour___67 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___80 *, u8, struct neighbour___67 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___80 *, struct sk_buff___81 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___85 *, struct net_device___80 *, const struct prefix_info *, struct inet6_dev___49 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___49;

struct inet6_dev___49 {
	struct net_device___80 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___49 *mc_list;
	struct ifmcaddr6___49 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___80 mc_query_queue;
	struct sk_buff_head___80 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___16 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___67 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___74;

struct tcf_block___74;

struct mini_Qdisc___74 {
	struct tcf_proto___74 *filter_list;
	struct tcf_block___74 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___74 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___80 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___80 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___85 *, struct net_device___80 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___80 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___80 *, struct list_head *);
	size_t (*get_size)(const struct net_device___80 *);
	int (*fill_info)(struct sk_buff___81 *, const struct net_device___80 *);
	size_t (*get_xstats_size)(const struct net_device___80 *);
	int (*fill_xstats)(struct sk_buff___81 *, const struct net_device___80 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___80 *, struct net_device___80 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___80 *, const struct net_device___80 *);
	int (*fill_slave_info)(struct sk_buff___81 *, const struct net_device___80 *, const struct net_device___80 *);
	struct net___85 * (*get_link_net)(const struct net_device___80 *);
	size_t (*get_linkxstats_size)(const struct net_device___80 *, int);
	int (*fill_linkxstats)(struct sk_buff___81 *, const struct net_device___80 *, int *, int);
};

struct block_device_operations___162;

struct gendisk___165 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___165 *part0;
	const struct block_device_operations___162 *fops;
	struct request_queue___162 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___148 *bdi;
	struct kobject___259 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___259 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___162 {
	struct bio___162 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___188 *bip_vec;
	struct bio_vec___188 bip_inline_vecs[0];
};

struct blkcg___150;

struct blkg_policy_data___150;

struct blkcg_gq___150 {
	struct request_queue___162 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___150 *blkcg;
	struct blkcg_gq___150 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___150 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___162 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___162(struct request___162 *);

typedef void integrity_complete_fn___162(struct request___162 *, unsigned int);

struct blk_integrity_profile___162 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___162 *prepare_fn;
	integrity_complete_fn___162 *complete_fn;
	const char *name;
};

struct block_device_operations___162 {
	blk_qc_t (*submit_bio)(struct bio___162 *);
	int (*open)(struct block_device___165 *, fmode_t);
	void (*release)(struct gendisk___165 *, fmode_t);
	int (*rw_page)(struct block_device___165 *, sector_t, struct page___276 *, unsigned int);
	int (*ioctl)(struct block_device___165 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___165 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___165 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___165 *);
	int (*getgeo)(struct block_device___165 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___165 *, bool);
	void (*swap_slot_free_notify)(struct block_device___165 *, long unsigned int);
	int (*report_zones)(struct gendisk___165 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___165 *, umode_t *);
	struct module___255 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___165 *, sector_t *);
};

typedef void rq_end_io_fn___162(struct request___162 *, blk_status_t);

struct request___162 {
	struct request_queue___162 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___157 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___162 *bio;
	struct bio___162 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___188 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___162 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___162 *saved_end_io;
		} flush;
	};
	struct gendisk___165 *rq_disk;
	struct block_device___165 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___162 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___157 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___162 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___259 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___271 *debugfs_dir;
	struct dentry___271 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___162;

struct elevator_mq_ops___162 {
	int (*init_sched)(struct request_queue___162 *, struct elevator_type___162 *);
	void (*exit_sched)(struct elevator_queue___162 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___157 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___157 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___157 *);
	bool (*allow_merge)(struct request_queue___162 *, struct request___162 *, struct bio___162 *);
	bool (*bio_merge)(struct request_queue___162 *, struct bio___162 *, unsigned int);
	int (*request_merge)(struct request_queue___162 *, struct request___162 **, struct bio___162 *);
	void (*request_merged)(struct request_queue___162 *, struct request___162 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___162 *, struct request___162 *, struct request___162 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___162 *);
	void (*finish_request)(struct request___162 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___157 *, struct list_head *, bool);
	struct request___162 * (*dispatch_request)(struct blk_mq_hw_ctx___157 *);
	bool (*has_work)(struct blk_mq_hw_ctx___157 *);
	void (*completed_request)(struct request___162 *, u64);
	void (*requeue_request)(struct request___162 *);
	struct request___162 * (*former_request)(struct request_queue___162 *, struct request___162 *);
	struct request___162 * (*next_request)(struct request_queue___162 *, struct request___162 *);
	void (*init_icq)(struct io_cq___162 *);
	void (*exit_icq)(struct io_cq___162 *);
};

struct elv_fs_entry___162;

struct elevator_type___162 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___162 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___162 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___255 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___162 {
	struct elevator_type___162 *type;
	void *elevator_data;
	struct kobject___259 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___162 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___162 *, char *);
	ssize_t (*store)(struct elevator_queue___162 *, const char *, size_t);
};

struct blk_mq_queue_data___157;

struct blk_mq_ops___157 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___157 *, const struct blk_mq_queue_data___157 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___157 *);
	int (*get_budget)(struct request_queue___162 *);
	void (*put_budget)(struct request_queue___162 *, int);
	void (*set_rq_budget_token)(struct request___162 *, int);
	int (*get_rq_budget_token)(struct request___162 *);
	enum blk_eh_timer_return (*timeout)(struct request___162 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___157 *);
	void (*complete)(struct request___162 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___157 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___157 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___157 *, struct request___162 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___157 *, struct request___162 *, unsigned int);
	void (*initialize_rq_fn)(struct request___162 *);
	void (*cleanup_rq)(struct request___162 *);
	bool (*busy)(struct request_queue___162 *);
	int (*map_queues)(struct blk_mq_tag_set___157 *);
	void (*show_rq)(struct seq_file___246 *, struct request___162 *);
};

struct blk_mq_tag_set___157 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___157 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___157 {
	struct request___162 *rq;
	bool last;
};

struct blkcg_policy_data___150;

struct blkcg___150 {
	struct cgroup_subsys_state___198 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___150 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___150 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___150 {
	struct blkcg___150 *blkcg;
	int plid;
};

struct blkg_policy_data___150 {
	struct blkcg_gq___150 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___136 {
	struct mem_cgroup___136 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___136 {
	struct lruvec___144 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___136 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___136 *memcg;
};

struct obj_cgroup___136 {
	struct percpu_ref refcnt;
	struct mem_cgroup___136 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___74 {
	spinlock_t *lock;
	struct sk_buff___81 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___74;

struct Qdisc_ops___74 {
	struct Qdisc_ops___74 *next;
	const struct Qdisc_class_ops___74 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___81 *, struct Qdisc___74 *, struct sk_buff___81 **);
	struct sk_buff___81 * (*dequeue)(struct Qdisc___74 *);
	struct sk_buff___81 * (*peek)(struct Qdisc___74 *);
	int (*init)(struct Qdisc___74 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___74 *);
	void (*destroy)(struct Qdisc___74 *);
	int (*change)(struct Qdisc___74 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___74 *);
	int (*change_tx_queue_len)(struct Qdisc___74 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___74 *, unsigned int);
	int (*dump)(struct Qdisc___74 *, struct sk_buff___81 *);
	int (*dump_stats)(struct Qdisc___74 *, struct gnet_dump___74 *);
	void (*ingress_block_set)(struct Qdisc___74 *, u32);
	void (*egress_block_set)(struct Qdisc___74 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___74 *);
	u32 (*egress_block_get)(struct Qdisc___74 *);
	struct module___255 *owner;
};

struct Qdisc_class_ops___74 {
	unsigned int flags;
	struct netdev_queue___80 * (*select_queue)(struct Qdisc___74 *, struct tcmsg *);
	int (*graft)(struct Qdisc___74 *, long unsigned int, struct Qdisc___74 *, struct Qdisc___74 **, struct netlink_ext_ack *);
	struct Qdisc___74 * (*leaf)(struct Qdisc___74 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___74 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___74 *, u32);
	int (*change)(struct Qdisc___74 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___74 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___74 *, struct qdisc_walker *);
	struct tcf_block___74 * (*tcf_block)(struct Qdisc___74 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___74 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___74 *, long unsigned int);
	int (*dump)(struct Qdisc___74 *, long unsigned int, struct sk_buff___81 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___74 *, long unsigned int, struct gnet_dump___74 *);
};

struct tcf_chain___74;

struct tcf_block___74 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___85 *net;
	struct Qdisc___74 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___74 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___74;

struct tcf_proto_ops___74;

struct tcf_proto___74 {
	struct tcf_proto___74 *next;
	void *root;
	int (*classify)(struct sk_buff___81 *, const struct tcf_proto___74 *, struct tcf_result___74 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___74 *ops;
	struct tcf_chain___74 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___74 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___74 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___74 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___81 *, const struct tcf_proto___74 *, struct tcf_result___74 *);
	int (*init)(struct tcf_proto___74 *);
	void (*destroy)(struct tcf_proto___74 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___74 *, u32);
	void (*put)(struct tcf_proto___74 *, void *);
	int (*change)(struct net___85 *, struct sk_buff___81 *, struct tcf_proto___74 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___74 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___74 *);
	void (*walk)(struct tcf_proto___74 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___74 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___74 *, void *);
	void (*hw_del)(struct tcf_proto___74 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___85 *, struct tcf_chain___74 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___85 *, struct tcf_proto___74 *, void *, struct sk_buff___81 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___85 *, struct tcf_proto___74 *, void *, struct sk_buff___81 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___81 *, struct net___85 *, void *);
	struct module___255 *owner;
	int flags;
};

struct tcf_chain___74 {
	struct mutex filter_chain_lock;
	struct tcf_proto___74 *filter_chain;
	struct list_head list;
	struct tcf_block___74 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___74 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___67 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___74 *prog;
};

struct bpf_sock_ops_kern___6 {
	struct sock___67 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___81 *syn_skb;
	struct sk_buff___81 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct pneigh_entry___67;

struct neigh_hash_table___67;

struct neigh_table___67 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___80 *, __u32 *);
	bool (*key_eq)(const struct neighbour___67 *, const void *);
	int (*constructor)(struct neighbour___67 *);
	int (*pconstructor)(struct pneigh_entry___67 *);
	void (*pdestructor)(struct pneigh_entry___67 *);
	void (*proxy_redo)(struct sk_buff___81 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___80 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___67 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___80 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___67 *nht;
	struct pneigh_entry___67 **phash_buckets;
};

struct neigh_ops___67 {
	int family;
	void (*solicit)(struct neighbour___67 *, struct sk_buff___81 *);
	void (*error_report)(struct neighbour___67 *, struct sk_buff___81 *);
	int (*output)(struct neighbour___67 *, struct sk_buff___81 *);
	int (*connected_output)(struct neighbour___67 *, struct sk_buff___81 *);
};

struct pneigh_entry___67 {
	struct pneigh_entry___67 *next;
	possible_net_t___80 net;
	struct net_device___80 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___67 {
	struct neighbour___67 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___43 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___85 *, struct sock___67 *, struct sk_buff___81 *);
	int (*orig_input)(struct sk_buff___81 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___67 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___67 *ctarget;
	struct net___85 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___67 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___67 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___52;

struct timewait_sock_ops___51;

struct proto___67 {
	void (*close)(struct sock___67 *, long int);
	int (*pre_connect)(struct sock___67 *, struct sockaddr *, int);
	int (*connect)(struct sock___67 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___67 *, int);
	struct sock___67 * (*accept)(struct sock___67 *, int, int *, bool);
	int (*ioctl)(struct sock___67 *, int, long unsigned int);
	int (*init)(struct sock___67 *);
	void (*destroy)(struct sock___67 *);
	void (*shutdown)(struct sock___67 *, int);
	int (*setsockopt)(struct sock___67 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___67 *, int, int, char *, int *);
	void (*keepalive)(struct sock___67 *, int);
	int (*compat_ioctl)(struct sock___67 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___67 *, struct msghdr___69 *, size_t);
	int (*recvmsg)(struct sock___67 *, struct msghdr___69 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___67 *, struct page___276 *, int, size_t, int);
	int (*bind)(struct sock___67 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___67 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___67 *, struct sk_buff___81 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___67 *);
	int (*hash)(struct sock___67 *);
	void (*unhash)(struct sock___67 *);
	void (*rehash)(struct sock___67 *);
	int (*get_port)(struct sock___67 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___67 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___67 *, int);
	bool (*sock_is_readable)(struct sock___67 *);
	void (*enter_memory_pressure)(struct sock___67 *);
	void (*leave_memory_pressure)(struct sock___67 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___52 *rsk_prot;
	struct timewait_sock_ops___51 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___255 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___67 *, int);
};

struct sock_reuseport___19 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___74 *prog;
	struct sock___67 *socks[0];
};

struct request_sock___53;

struct request_sock_ops___52 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___67 *, struct request_sock___53 *);
	void (*send_ack)(const struct sock___67 *, struct sk_buff___81 *, struct request_sock___53 *);
	void (*send_reset)(const struct sock___67 *, struct sk_buff___81 *);
	void (*destructor)(struct request_sock___53 *);
	void (*syn_ack_timeout)(const struct request_sock___53 *);
};

struct timewait_sock_ops___51 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___67 *, struct sock___67 *, void *);
	void (*twsk_destructor)(struct sock___67 *);
};

struct request_sock___53 {
	struct sock_common___67 __req_common;
	struct request_sock___53 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___52 *rsk_ops;
	struct sock___67 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___6 {
	struct request_sock___53 *rskq_rst_head;
	struct request_sock___53 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___6 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___53 *rskq_accept_head;
	struct request_sock___53 *rskq_accept_tail;
	struct fastopen_queue___6 fastopenq;
};

struct inet_request_sock___5 {
	struct request_sock___53 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___81 *pktopts;
		};
	};
};

struct inet_cork___9 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___67 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___9 {
	struct inet_cork___9 base;
	struct flowi fl;
};

struct ipv6_pinfo___9;

struct inet_sock___9 {
	struct sock___67 sk;
	struct ipv6_pinfo___9 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___9 cork;
};

struct ipv6_fl_socklist___9;

struct ipv6_pinfo___9 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___9 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___81 *pktoptions;
	struct sk_buff___81 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___6 {
	int (*queue_xmit)(struct sock___67 *, struct sk_buff___81 *, struct flowi *);
	void (*send_check)(struct sock___67 *, struct sk_buff___81 *);
	int (*rebuild_header)(struct sock___67 *);
	void (*sk_rx_dst_set)(struct sock___67 *, const struct sk_buff___81 *);
	int (*conn_request)(struct sock___67 *, struct sk_buff___81 *);
	struct sock___67 * (*syn_recv_sock)(const struct sock___67 *, struct sk_buff___81 *, struct request_sock___53 *, struct dst_entry___67 *, struct request_sock___53 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___67 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___67 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___67 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___67 *);
};

struct inet_bind_bucket___6;

struct tcp_ulp_ops___6;

struct inet_connection_sock___6 {
	struct inet_sock___9 icsk_inet;
	struct request_sock_queue___6 icsk_accept_queue;
	struct inet_bind_bucket___6 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___18 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___6 *icsk_af_ops;
	const struct tcp_ulp_ops___6 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___67 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___67 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___6 {
	possible_net_t___80 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___6 {
	struct list_head list;
	int (*init)(struct sock___67 *);
	void (*update)(struct sock___67 *, struct proto___67 *, void (*)(struct sock___67 *));
	void (*release)(struct sock___67 *);
	int (*get_info)(const struct sock___67 *, struct sk_buff___81 *);
	size_t (*get_info_size)(const struct sock___67 *);
	void (*clone)(const struct request_sock___53 *, struct sock___67 *, const gfp_t);
	char name[16];
	struct module___255 *owner;
};

struct tcp_request_sock_ops___4;

struct tcp_request_sock___4 {
	struct inet_request_sock___5 req;
	const struct tcp_request_sock_ops___4 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_request_sock_ops___4 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___67 *, const struct sock___67 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___67 *, const struct sk_buff___81 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___81 *, __u16 *);
	struct dst_entry___67 * (*route_req)(const struct sock___67 *, struct sk_buff___81 *, struct flowi *, struct request_sock___53 *);
	u32 (*init_seq)(const struct sk_buff___81 *);
	u32 (*init_ts_off)(const struct net___85 *, const struct sk_buff___81 *);
	int (*send_synack)(const struct sock___67 *, struct dst_entry___67 *, struct flowi *, struct request_sock___53 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___81 *);
};

struct tcp_sock_af_ops___7;

struct tcp_fastopen_request___7;

struct tcp_sock___7 {
	struct inet_connection_sock___6 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___81 *lost_skb_hint;
	struct sk_buff___81 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___81 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___81 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___7 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___7 *fastopen_req;
	struct request_sock___53 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___7 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___67 *, const struct sock___67 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___67 *, const struct sk_buff___81 *);
	int (*md5_parse)(struct sock___67 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___7 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___69 *data;
	size_t size;
	int copied;
	struct ubuf_info___9 *uarg;
};

enum tsq_flags {
	TSQF_THROTTLED = 1,
	TSQF_QUEUED = 2,
	TCPF_TSQ_DEFERRED = 4,
	TCPF_WRITE_TIMER_DEFERRED = 8,
	TCPF_DELACK_TIMER_DEFERRED = 16,
	TCPF_MTU_REDUCED_DEFERRED = 32,
};

struct ip6_flowlabel___9;

struct ipv6_fl_socklist___9 {
	struct ipv6_fl_socklist___9 *next;
	struct ip6_flowlabel___9 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___49 {
	struct in6_addr mca_addr;
	struct inet6_dev___49 *idev;
	struct ifmcaddr6___49 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___9 {
	struct ip6_flowlabel___9 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___248 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___85 *fl_net;
};

struct mptcp_rm_list {
	u8 ids[8];
	u8 nr;
};

struct mptcp_addr_info {
	u8 id;
	sa_family_t family;
	__be16 port;
	union {
		struct in_addr addr;
		struct in6_addr addr6;
	};
};

struct mptcp_out_options {
	u16 suboptions;
	struct mptcp_rm_list rm_list;
	u8 join_id;
	u8 backup;
	u8 reset_reason: 4;
	u8 reset_transient: 1;
	u8 csum_reqd: 1;
	u8 allow_join_id0: 1;
	long: 63;
	long: 64;
	union {
		struct {
			u64 sndr_key;
			u64 rcvr_key;
			u64 data_seq;
			u32 subflow_seq;
			u16 data_len;
			__sum16 csum;
		};
		struct {
			struct mptcp_addr_info addr;
			u64 ahmac;
		};
		struct {
			struct mptcp_ext ext_copy;
			u64 fail_seq;
		};
		struct {
			u32 nonce;
			u32 token;
			u64 thmac;
			u8 hmac[20];
		};
	};
};

struct tcp_out_options {
	u16 options;
	u16 mss;
	u8 ws;
	u8 num_sack_blocks;
	u8 hash_size;
	u8 bpf_opt_len;
	__u8 *hash_location;
	__u32 tsval;
	__u32 tsecr;
	struct tcp_fastopen_cookie *fastopen_cookie;
	struct mptcp_out_options mptcp;
};

struct tsq_tasklet {
	struct tasklet_struct tasklet;
	struct list_head head;
};

struct dentry___272;

struct super_block___272;

struct module___256;

struct file_system_type___272 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___272 * (*mount)(struct file_system_type___272 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___272 *);
	struct module___256 *owner;
	struct file_system_type___272 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___272;

struct kiocb___272;

struct iov_iter___192;

struct poll_table_struct___193;

struct vm_area_struct___277;

struct inode___272;

struct file_lock___272;

struct page___277;

struct pipe_inode_info___113;

struct seq_file___247;

struct file_operations___273 {
	struct module___256 *owner;
	loff_t (*llseek)(struct file___272 *, loff_t, int);
	ssize_t (*read)(struct file___272 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___272 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___272 *, struct iov_iter___192 *);
	ssize_t (*write_iter)(struct kiocb___272 *, struct iov_iter___192 *);
	int (*iopoll)(struct kiocb___272 *, bool);
	int (*iterate)(struct file___272 *, struct dir_context *);
	int (*iterate_shared)(struct file___272 *, struct dir_context *);
	__poll_t (*poll)(struct file___272 *, struct poll_table_struct___193 *);
	long int (*unlocked_ioctl)(struct file___272 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___272 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___272 *, struct vm_area_struct___277 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___272 *, struct file___272 *);
	int (*flush)(struct file___272 *, fl_owner_t);
	int (*release)(struct inode___272 *, struct file___272 *);
	int (*fsync)(struct file___272 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___272 *, int);
	int (*lock)(struct file___272 *, int, struct file_lock___272 *);
	ssize_t (*sendpage)(struct file___272 *, struct page___277 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___272 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___272 *, long unsigned int);
	int (*flock)(struct file___272 *, int, struct file_lock___272 *);
	ssize_t (*splice_write)(struct pipe_inode_info___113 *, struct file___272 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___272 *, loff_t *, struct pipe_inode_info___113 *, size_t, unsigned int);
	int (*setlease)(struct file___272 *, long int, struct file_lock___272 **, void **);
	long int (*fallocate)(struct file___272 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___247 *, struct file___272 *);
	ssize_t (*copy_file_range)(struct file___272 *, loff_t, struct file___272 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___272 *, loff_t, struct file___272 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___272 *, loff_t, loff_t, int);
};

struct vmacache___277 {
	u64 seqnum;
	struct vm_area_struct___277 *vmas[4];
};

struct page_frag___277 {
	struct page___277 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___278;

struct pid___249;

struct nsproxy___258;

struct signal_struct___273;

struct bio_list___163;

struct backing_dev_info___149;

struct io_context___163;

struct css_set___199;

struct mem_cgroup___137;

struct request_queue___163;

struct vm_struct___255;

struct task_struct___279 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___279 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___278 *mm;
	struct mm_struct___278 *active_mm;
	struct vmacache___277 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___279 *real_parent;
	struct task_struct___279 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___279 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___249 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___258 *nsproxy;
	struct signal_struct___273 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___279 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___163 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___149 *backing_dev_info;
	struct io_context___163 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___199 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___113 *splice_pipe;
	struct page_frag___277 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___137 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___137 *active_memcg;
	struct request_queue___163 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___279 *oom_reaper_list;
	struct vm_struct___255 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___260;

struct kobj_type___260;

struct kernfs_node___260;

struct kobject___260 {
	const char *name;
	struct list_head entry;
	struct kobject___260 *parent;
	struct kset___260 *kset;
	struct kobj_type___260 *ktype;
	struct kernfs_node___260 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___257 {
	struct kobject___260 kobj;
	struct module___256 *mod;
	struct kobject___260 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___256 {
	struct module___256 *mod;
	struct latch_tree_node node;
};

struct module_layout___256 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___256 mtn;
};

struct module_attribute___256;

struct kernel_param___256;

struct module___256 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___257 mkobj;
	struct module_attribute___256 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___260 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___256 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___256 core_layout;
	struct module_layout___256 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___249;

struct upid___249 {
	int nr;
	struct pid_namespace___249 *ns;
};

struct pid_namespace___249 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___279 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___249 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___249 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___249 numbers[1];
};

typedef struct page___277 *pgtable_t___277;

struct address_space___272;

struct page_pool___101;

struct dev_pagemap___267;

struct page___277 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___272 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___101 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___277 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___277 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___278 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___267 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___267;

struct vm_area_struct___277 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___277 *vm_next;
	struct vm_area_struct___277 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___278 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___267 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___272 *vm_file;
	struct file___272 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___273 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___279 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___279 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___249 *pids[4];
	struct pid___249 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___278 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___277;

struct mm_struct___278 {
	struct {
		struct vm_area_struct___277 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___272 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___277 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___279 *owner;
		struct user_namespace___26 *user_ns;
		struct file___272 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___86;

struct cgroup_namespace___199;

struct nsproxy___258 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___249 *pid_ns_for_children;
	struct net___86 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___199 *cgroup_ns;
};

struct bio___163;

struct bio_list___163 {
	struct bio___163 *head;
	struct bio___163 *tail;
};

struct cgroup_subsys_state___199;

struct bdi_writeback___149 {
	struct backing_dev_info___149 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___199 *memcg_css;
	struct cgroup_subsys_state___199 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___253;

struct backing_dev_info___149 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___149 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___253 *dev;
	char dev_name[64];
	struct device___253 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___272 *debug_dir;
};

struct io_cq___163;

struct io_context___163 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___163 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___199;

struct css_set___199 {
	struct cgroup_subsys_state___199 *subsys[14];
	refcount_t refcount;
	struct css_set___199 *dom_cset;
	struct cgroup___199 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___199 *mg_src_cgrp;
	struct cgroup___199 *mg_dst_cgrp;
	struct css_set___199 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___272;

struct pipe_buffer___113;

struct pipe_inode_info___113 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___277 *tmp_page;
	struct fasync_struct___272 *fasync_readers;
	struct fasync_struct___272 *fasync_writers;
	struct pipe_buffer___113 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___199;

struct cgroup_subsys_state___199 {
	struct cgroup___199 *cgroup;
	struct cgroup_subsys___199 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___199 *parent;
};

struct cgroup_file___199 {
	struct kernfs_node___260 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___137;

struct mem_cgroup_per_node___137;

struct mem_cgroup___137 {
	struct cgroup_subsys_state___199 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___199 events_file;
	struct cgroup_file___199 events_local_file;
	struct cgroup_file___199 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___137 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___279 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___137 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___163;

struct blk_integrity___163 {
	const struct blk_integrity_profile___163 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___163 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___163 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___163;

struct elevator_queue___163;

struct blk_mq_ops___158;

struct blk_mq_hw_ctx___158;

struct gendisk___166;

struct blkcg_gq___151;

struct blk_mq_tag_set___158;

struct request_queue___163 {
	struct request___163 *last_merge;
	struct elevator_queue___163 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___158 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___158 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___166 *disk;
	struct kobject___260 kobj;
	struct kobject___260 *mq_kobj;
	struct blk_integrity___163 integrity;
	struct device___253 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___151 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___158 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___163 bio_split;
	struct dentry___272 *debugfs_dir;
	struct dentry___272 *sched_debugfs_dir;
	struct dentry___272 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___255 {
	struct vm_struct___255 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___277 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___272;

struct address_space___272 {
	struct inode___272 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___272 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___101 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___253 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___101 {
	u32 count;
	struct page___277 *cache[128];
};

struct page_pool___101 {
	struct page_pool_params___101 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___277 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___101 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___267;

struct dev_pagemap___267 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___267 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___272;

struct path___272 {
	struct vfsmount___272 *mnt;
	struct dentry___272 *dentry;
};

struct fown_struct___249 {
	rwlock_t lock;
	struct pid___249 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___272 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___272 f_path;
	struct inode___272 *f_inode;
	const struct file_operations___273 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___249 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___272 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___267;

struct vm_operations_struct___267 {
	void (*open)(struct vm_area_struct___277 *);
	void (*close)(struct vm_area_struct___277 *);
	int (*may_split)(struct vm_area_struct___277 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___277 *);
	int (*mprotect)(struct vm_area_struct___277 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___267 *);
	vm_fault_t (*huge_fault)(struct vm_fault___267 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___267 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___277 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___267 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___267 *);
	int (*access)(struct vm_area_struct___277 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___277 *);
	int (*set_policy)(struct vm_area_struct___277 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___277 *, long unsigned int);
	struct page___277 * (*find_special_page)(struct vm_area_struct___277 *, long unsigned int);
};

struct core_thread___277 {
	struct task_struct___279 *task;
	struct core_thread___277 *next;
};

struct core_state___277 {
	atomic_t nr_threads;
	struct core_thread___277 dumper;
	struct completion startup;
};

struct vm_fault___267 {
	const struct {
		struct vm_area_struct___277 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___277 *cow_page;
	struct page___277 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___277 prealloc_pte;
};

struct pglist_data___145;

struct lruvec___145 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___145 *pgdat;
};

struct zone___145 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___145 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___145 {
	struct zone___145 *zone;
	int zone_idx;
};

struct zonelist___145 {
	struct zoneref___145 _zonerefs[321];
};

struct pglist_data___145 {
	struct zone___145 node_zones[5];
	struct zonelist___145 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___279 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___279 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___145 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___272;

struct dentry___272 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___272 *d_parent;
	struct qstr d_name;
	struct inode___272 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___272 *d_op;
	struct super_block___272 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___272;

struct inode___272 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___272 *i_op;
	struct super_block___272 *i_sb;
	struct address_space___272 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___149 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___273 *i_fop;
		void (*free_inode)(struct inode___272 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___272 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___113 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___272 {
	int (*d_revalidate)(struct dentry___272 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___272 *, unsigned int);
	int (*d_hash)(const struct dentry___272 *, struct qstr *);
	int (*d_compare)(const struct dentry___272 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___272 *);
	int (*d_init)(struct dentry___272 *);
	void (*d_release)(struct dentry___272 *);
	void (*d_prune)(struct dentry___272 *);
	void (*d_iput)(struct dentry___272 *, struct inode___272 *);
	char * (*d_dname)(struct dentry___272 *, char *, int);
	struct vfsmount___272 * (*d_automount)(struct path___272 *);
	int (*d_manage)(const struct path___272 *, bool);
	struct dentry___272 * (*d_real)(struct dentry___272 *, const struct inode___272 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___272;

struct mem_dqinfo___272 {
	struct quota_format_type___272 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___272;

struct quota_info___272 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___272 *files[3];
	struct mem_dqinfo___272 info[3];
	const struct quota_format_ops___272 *ops[3];
};

struct rcuwait___273 {
	struct task_struct___279 *task;
};

struct percpu_rw_semaphore___273 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___273 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___272 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___273 rw_sem[3];
};

struct shrink_control___137;

struct shrinker___137 {
	long unsigned int (*count_objects)(struct shrinker___137 *, struct shrink_control___137 *);
	long unsigned int (*scan_objects)(struct shrinker___137 *, struct shrink_control___137 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___272;

struct dquot_operations___272;

struct quotactl_ops___272;

struct block_device___166;

struct super_block___272 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___272 *s_type;
	const struct super_operations___272 *s_op;
	const struct dquot_operations___272 *dq_op;
	const struct quotactl_ops___272 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___272 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___166 *s_bdev;
	struct backing_dev_info___149 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___272 s_dquot;
	struct sb_writers___272 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___272 *s_d_op;
	int cleancache_poolid;
	struct shrinker___137 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___272 {
	struct dentry___272 *mnt_root;
	struct super_block___272 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___137 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___137 *memcg;
};

struct psi_group___199 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___279 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___75;

struct cgroup_bpf___75 {
	struct bpf_prog_array___75 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___75 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___199;

struct cgroup_rstat_cpu___199;

struct cgroup___199 {
	struct cgroup_subsys_state___199 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___260 *kn;
	struct cgroup_file___199 procs_file;
	struct cgroup_file___199 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___199 *subsys[14];
	struct cgroup_root___199 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___199 *dom_cgrp;
	struct cgroup___199 *old_dom_cgrp;
	struct cgroup_rstat_cpu___199 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___199 psi;
	struct cgroup_bpf___75 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___163 {
	struct request_queue___163 *q;
	struct io_context___163 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___272 {
	struct file___272 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___272 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___115 *ki_waitq;
	};
};

struct iattr___272 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___272 *ia_file;
};

struct dquot___272 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___272 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___272 {
	int qf_fmt_id;
	const struct quota_format_ops___272 *qf_ops;
	struct module___256 *qf_owner;
	struct quota_format_type___272 *qf_next;
};

struct quota_format_ops___272 {
	int (*check_quota_file)(struct super_block___272 *, int);
	int (*read_file_info)(struct super_block___272 *, int);
	int (*write_file_info)(struct super_block___272 *, int);
	int (*free_file_info)(struct super_block___272 *, int);
	int (*read_dqblk)(struct dquot___272 *);
	int (*commit_dqblk)(struct dquot___272 *);
	int (*release_dqblk)(struct dquot___272 *);
	int (*get_next_id)(struct super_block___272 *, struct kqid *);
};

struct dquot_operations___272 {
	int (*write_dquot)(struct dquot___272 *);
	struct dquot___272 * (*alloc_dquot)(struct super_block___272 *, int);
	void (*destroy_dquot)(struct dquot___272 *);
	int (*acquire_dquot)(struct dquot___272 *);
	int (*release_dquot)(struct dquot___272 *);
	int (*mark_dirty)(struct dquot___272 *);
	int (*write_info)(struct super_block___272 *, int);
	qsize_t * (*get_reserved_space)(struct inode___272 *);
	int (*get_projid)(struct inode___272 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___272 *, qsize_t *);
	int (*get_next_id)(struct super_block___272 *, struct kqid *);
};

struct quotactl_ops___272 {
	int (*quota_on)(struct super_block___272 *, int, int, const struct path___272 *);
	int (*quota_off)(struct super_block___272 *, int);
	int (*quota_enable)(struct super_block___272 *, unsigned int);
	int (*quota_disable)(struct super_block___272 *, unsigned int);
	int (*quota_sync)(struct super_block___272 *, int);
	int (*set_info)(struct super_block___272 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___272 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___272 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___272 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___272 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___272 *, unsigned int);
};

struct writeback_control___149;

struct address_space_operations___272 {
	int (*writepage)(struct page___277 *, struct writeback_control___149 *);
	int (*readpage)(struct file___272 *, struct page___277 *);
	int (*writepages)(struct address_space___272 *, struct writeback_control___149 *);
	int (*set_page_dirty)(struct page___277 *);
	int (*readpages)(struct file___272 *, struct address_space___272 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___272 *, struct address_space___272 *, loff_t, unsigned int, unsigned int, struct page___277 **, void **);
	int (*write_end)(struct file___272 *, struct address_space___272 *, loff_t, unsigned int, unsigned int, struct page___277 *, void *);
	sector_t (*bmap)(struct address_space___272 *, sector_t);
	void (*invalidatepage)(struct page___277 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___277 *, gfp_t);
	void (*freepage)(struct page___277 *);
	ssize_t (*direct_IO)(struct kiocb___272 *, struct iov_iter___192 *);
	int (*migratepage)(struct address_space___272 *, struct page___277 *, struct page___277 *, enum migrate_mode);
	bool (*isolate_page)(struct page___277 *, isolate_mode_t);
	void (*putback_page)(struct page___277 *);
	int (*launder_page)(struct page___277 *);
	int (*is_partially_uptodate)(struct page___277 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___277 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___272 *, struct page___277 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___272 *, sector_t *);
	void (*swap_deactivate)(struct file___272 *);
};

struct writeback_control___149 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___149 *wb;
	struct inode___272 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___189;

struct iov_iter___192 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___189 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___113 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___272 {
	struct dentry___272 * (*lookup)(struct inode___272 *, struct dentry___272 *, unsigned int);
	const char * (*get_link)(struct dentry___272 *, struct inode___272 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___272 *, int);
	struct posix_acl * (*get_acl)(struct inode___272 *, int, bool);
	int (*readlink)(struct dentry___272 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___272 *, struct dentry___272 *, umode_t, bool);
	int (*link)(struct dentry___272 *, struct inode___272 *, struct dentry___272 *);
	int (*unlink)(struct inode___272 *, struct dentry___272 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___272 *, struct dentry___272 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___272 *, struct dentry___272 *, umode_t);
	int (*rmdir)(struct inode___272 *, struct dentry___272 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___272 *, struct dentry___272 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___272 *, struct dentry___272 *, struct inode___272 *, struct dentry___272 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___272 *, struct iattr___272 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___272 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___272 *, char *, size_t);
	int (*fiemap)(struct inode___272 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___272 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___272 *, struct dentry___272 *, struct file___272 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___272 *, struct dentry___272 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___272 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___272 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___272 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___272 {
	void (*fl_copy_lock)(struct file_lock___272 *, struct file_lock___272 *);
	void (*fl_release_private)(struct file_lock___272 *);
};

struct lock_manager_operations___272;

struct file_lock___272 {
	struct file_lock___272 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___272 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___272 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___272 *fl_ops;
	const struct lock_manager_operations___272 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___272 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___272 *);
	int (*lm_grant)(struct file_lock___272 *, int);
	bool (*lm_break)(struct file_lock___272 *);
	int (*lm_change)(struct file_lock___272 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___272 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___272 *);
};

struct fasync_struct___272 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___272 *fa_next;
	struct file___272 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___272 {
	struct inode___272 * (*alloc_inode)(struct super_block___272 *);
	void (*destroy_inode)(struct inode___272 *);
	void (*free_inode)(struct inode___272 *);
	void (*dirty_inode)(struct inode___272 *, int);
	int (*write_inode)(struct inode___272 *, struct writeback_control___149 *);
	int (*drop_inode)(struct inode___272 *);
	void (*evict_inode)(struct inode___272 *);
	void (*put_super)(struct super_block___272 *);
	int (*sync_fs)(struct super_block___272 *, int);
	int (*freeze_super)(struct super_block___272 *);
	int (*freeze_fs)(struct super_block___272 *);
	int (*thaw_super)(struct super_block___272 *);
	int (*unfreeze_fs)(struct super_block___272 *);
	int (*statfs)(struct dentry___272 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___272 *, int *, char *);
	void (*umount_begin)(struct super_block___272 *);
	int (*show_options)(struct seq_file___247 *, struct dentry___272 *);
	int (*show_devname)(struct seq_file___247 *, struct dentry___272 *);
	int (*show_path)(struct seq_file___247 *, struct dentry___272 *);
	int (*show_stats)(struct seq_file___247 *, struct dentry___272 *);
	ssize_t (*quota_read)(struct super_block___272 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___272 *, int, const char *, size_t, loff_t);
	struct dquot___272 ** (*get_dquots)(struct inode___272 *);
	long int (*nr_cached_objects)(struct super_block___272 *, struct shrink_control___137 *);
	long int (*free_cached_objects)(struct super_block___272 *, struct shrink_control___137 *);
	struct file___272 * (*real_loop)(struct file___272 *);
};

struct wakeup_source___253;

struct dev_pm_info___253 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___253 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___253 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___253;

struct bus_type___253;

struct device_driver___253;

struct dev_pm_domain___253;

struct fwnode_handle___249;

struct class___253;

struct attribute_group___260;

struct device___253 {
	struct kobject___260 kobj;
	struct device___253 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___253 *type;
	struct bus_type___253 *bus;
	struct device_driver___253 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___253 power;
	struct dev_pm_domain___253 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___249 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___253 *class;
	const struct attribute_group___260 **groups;
	void (*release)(struct device___253 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___166 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___272 *bd_inode;
	struct super_block___272 *bd_super;
	void *bd_claiming;
	struct device___253 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___260 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___166 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___272 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___201)(struct file___272 *, wait_queue_head_t *, struct poll_table_struct___193 *);

struct poll_table_struct___193 {
	poll_queue_proc___201 _qproc;
	__poll_t _key;
};

struct seq_operations___247;

struct seq_file___247 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___247 *op;
	int poll_event;
	const struct file___272 *file;
	void *private;
};

typedef void bio_end_io_t___163(struct bio___163 *);

struct bio_vec___189 {
	struct page___277 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___163;

struct bio___163 {
	struct bio___163 *bi_next;
	struct block_device___166 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___163 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___151 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___163 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___189 *bi_io_vec;
	struct bio_set___163 *bi_pool;
	struct bio_vec___189 bi_inline_vecs[0];
};

struct kernfs_root___260;

struct kernfs_elem_dir___260 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___260 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___260;

struct kernfs_root___260 {
	struct kernfs_node___260 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___260 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___260 {
	struct kernfs_node___260 *target_kn;
};

struct kernfs_ops___260;

struct kernfs_elem_attr___260 {
	const struct kernfs_ops___260 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___260 *notify_next;
};

struct kernfs_node___260 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___260 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___260 dir;
		struct kernfs_elem_symlink___260 symlink;
		struct kernfs_elem_attr___260 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___260;

struct kernfs_ops___260 {
	int (*open)(struct kernfs_open_file___260 *);
	void (*release)(struct kernfs_open_file___260 *);
	int (*seq_show)(struct seq_file___247 *, void *);
	void * (*seq_start)(struct seq_file___247 *, loff_t *);
	void * (*seq_next)(struct seq_file___247 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___247 *, void *);
	ssize_t (*read)(struct kernfs_open_file___260 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___260 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___260 *, struct poll_table_struct___193 *);
	int (*mmap)(struct kernfs_open_file___260 *, struct vm_area_struct___277 *);
};

struct kernfs_syscall_ops___260 {
	int (*show_options)(struct seq_file___247 *, struct kernfs_root___260 *);
	int (*mkdir)(struct kernfs_node___260 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___260 *);
	int (*rename)(struct kernfs_node___260 *, struct kernfs_node___260 *, const char *);
	int (*show_path)(struct seq_file___247 *, struct kernfs_node___260 *, struct kernfs_root___260 *);
};

struct kernfs_open_file___260 {
	struct kernfs_node___260 *kn;
	struct file___272 *file;
	struct seq_file___247 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___267 *vm_ops;
};

struct sock___68;

struct kobj_ns_type_operations___68 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___68 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___86 *net;
} possible_net_t___81;

struct proto___68;

struct sock_common___68 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___68 *skc_prot;
	possible_net_t___81 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___68 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___82;

struct sk_buff_head___81 {
	struct sk_buff___82 *next;
	struct sk_buff___82 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___68 {
	struct cgroup___199 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___68;

struct socket_wq___69;

struct xfrm_policy___12;

struct dst_entry___68;

struct socket___70;

struct net_device___81;

struct sock_reuseport___20;

struct sock___68 {
	struct sock_common___68 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___81 sk_error_queue;
	struct sk_buff___82 *sk_rx_skb_cache;
	struct sk_buff_head___81 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___82 *head;
		struct sk_buff___82 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___68 *sk_filter;
	union {
		struct socket_wq___69 *sk_wq;
		struct socket_wq___69 *sk_wq_raw;
	};
	struct xfrm_policy___12 *sk_policy[2];
	struct dst_entry___68 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___68 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___82 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___82 *sk_tx_skb_cache;
	struct sk_buff_head___81 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___277 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___68 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___249 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___70 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___68 sk_cgrp_data;
	struct mem_cgroup___137 *sk_memcg;
	void (*sk_state_change)(struct sock___68 *);
	void (*sk_data_ready)(struct sock___68 *);
	void (*sk_write_space)(struct sock___68 *);
	void (*sk_error_report)(struct sock___68 *);
	int (*sk_backlog_rcv)(struct sock___68 *, struct sk_buff___82 *);
	struct sk_buff___82 * (*sk_validate_xmit_skb)(struct sock___68 *, struct net_device___81 *, struct sk_buff___82 *);
	void (*sk_destruct)(struct sock___68 *);
	struct sock_reuseport___20 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___260;

struct attribute_group___260 {
	const char *name;
	umode_t (*is_visible)(struct kobject___260 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___260 *, struct bin_attribute___260 *, int);
	struct attribute **attrs;
	struct bin_attribute___260 **bin_attrs;
};

struct bin_attribute___260 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___272 * (*f_mapping)();
	ssize_t (*read)(struct file___272 *, struct kobject___260 *, struct bin_attribute___260 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___272 *, struct kobject___260 *, struct bin_attribute___260 *, char *, loff_t, size_t);
	int (*mmap)(struct file___272 *, struct kobject___260 *, struct bin_attribute___260 *, struct vm_area_struct___277 *);
};

struct sysfs_ops___260 {
	ssize_t (*show)(struct kobject___260 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___260 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___260;

struct kset___260 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___260 kobj;
	const struct kset_uevent_ops___260 *uevent_ops;
};

struct kobj_type___260 {
	void (*release)(struct kobject___260 *);
	const struct sysfs_ops___260 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___260 **default_groups;
	const struct kobj_ns_type_operations___68 * (*child_ns_type)(struct kobject___260 *);
	const void * (*namespace)(struct kobject___260 *);
	void (*get_ownership)(struct kobject___260 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___260 {
	int (* const filter)(struct kset___260 *, struct kobject___260 *);
	const char * (* const name)(struct kset___260 *, struct kobject___260 *);
	int (* const uevent)(struct kset___260 *, struct kobject___260 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___256 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___256 *);
	int (*get)(char *, const struct kernel_param___256 *);
	void (*free)(void *);
};

struct kparam_array___256;

struct kernel_param___256 {
	const char *name;
	struct module___256 *mod;
	const struct kernel_param_ops___256 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___256 *arr;
	};
};

struct kparam_array___256 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___256 *ops;
	void *elem;
};

struct module_attribute___256 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___256 *, struct module_kobject___257 *, char *);
	ssize_t (*store)(struct module_attribute___256 *, struct module_kobject___257 *, const char *, size_t);
	void (*setup)(struct module___256 *, const char *);
	int (*test)(struct module___256 *);
	void (*free)(struct module___256 *);
};

struct msghdr___70 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___192 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___272 *msg_iocb;
};

struct sk_buff___82 {
	union {
		struct {
			struct sk_buff___82 *next;
			struct sk_buff___82 *prev;
			union {
				struct net_device___81 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___68 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___82 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___86;

struct fqdir___86 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___86 *f;
	struct net___86 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___86;

struct inet_frags___86 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___86 *, const void *);
	void (*destructor)(struct inet_frag_queue___86 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___41;

struct fib_rules_ops___68;

struct tcp_congestion_ops___19;

struct fib_notifier_ops___68;

struct netns_ipv4___86 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___41 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___68 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___68 *fibnl;
	struct sock___68 **icmp_sk;
	struct sock___68 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___68 **tcp_sk;
	struct fqdir___86 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___19 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___68 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___68 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___68 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___68;

struct dst_ops___86 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___86 *);
	struct dst_entry___68 * (*check)(struct dst_entry___68 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___68 *);
	unsigned int (*mtu)(const struct dst_entry___68 *);
	u32 * (*cow_metrics)(struct dst_entry___68 *, long unsigned int);
	void (*destroy)(struct dst_entry___68 *);
	void (*ifdown)(struct dst_entry___68 *, struct net_device___81 *, int);
	struct dst_entry___68 * (*negative_advice)(struct dst_entry___68 *);
	void (*link_failure)(struct sk_buff___82 *);
	void (*update_pmtu)(struct dst_entry___68 *, struct sock___68 *, struct sk_buff___82 *, u32, bool);
	void (*redirect)(struct dst_entry___68 *, struct sock___68 *, struct sk_buff___82 *);
	int (*local_out)(struct net___86 *, struct sock___68 *, struct sk_buff___82 *);
	struct neighbour___68 * (*neigh_lookup)(const struct dst_entry___68 *, struct sk_buff___82 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___68 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___17;

struct rt6_info___17;

struct fib6_table___17;

struct netns_ipv6___86 {
	struct dst_ops___86 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___86 *fqdir;
	struct fib6_info___17 *fib6_null_entry;
	struct rt6_info___17 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___17 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___17 *ip6_prohibit_entry;
	struct rt6_info___17 *ip6_blk_hole_entry;
	struct fib6_table___17 *fib6_local_tbl;
	struct fib_rules_ops___68 *fib6_rules_ops;
	struct sock___68 **icmp_sk;
	struct sock___68 *ndisc_sk;
	struct sock___68 *tcp_sk;
	struct sock___68 *igmp_sk;
	struct sock___68 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___68 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___68 *notifier_ops;
	struct fib_notifier_ops___68 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___86 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___86 *fqdir;
};

struct netns_sctp___68 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___68 *ctl_sock;
	struct sock___68 *udp4_sock;
	struct sock___68 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___75;

struct netns_bpf___75 {
	struct bpf_prog_array___75 *run_array[2];
	struct bpf_prog___75 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___86 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___68 *nlsk;
	struct sock___68 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___86 xfrm4_dst_ops;
	struct dst_ops___86 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___86 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___68 *rtnl;
	struct sock___68 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___81 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___86 ipv4;
	struct netns_ipv6___86 ipv6;
	struct netns_ieee802154_lowpan___86 ieee802154_lowpan;
	struct netns_sctp___68 sctp;
	struct netns_nf___10 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___81 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___75 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___86 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___68 *crypto_nlsk;
	struct sock___68 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___86 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___82 *fragments_tail;
	struct sk_buff___82 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___86 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___41 {
	struct ip_ra_chain___41 *next;
	struct sock___68 *sk;
	union {
		void (*destructor)(struct sock___68 *);
		struct sock___68 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___68;

struct fib_lookup_arg___68;

struct fib_rules_ops___68 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___68 *, struct flowi *, int, struct fib_lookup_arg___68 *);
	bool (*suppress)(struct fib_rule___68 *, int, struct fib_lookup_arg___68 *);
	int (*match)(struct fib_rule___68 *, struct flowi *, int);
	int (*configure)(struct fib_rule___68 *, struct sk_buff___82 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___68 *);
	int (*compare)(struct fib_rule___68 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___68 *, struct sk_buff___82 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___68 *);
	void (*flush_cache)(struct fib_rules_ops___68 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___256 *owner;
	struct net___86 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___19 {
	u32 (*ssthresh)(struct sock___68 *);
	void (*cong_avoid)(struct sock___68 *, u32, u32);
	void (*set_state)(struct sock___68 *, u8);
	void (*cwnd_event)(struct sock___68 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___68 *, u32);
	void (*pkts_acked)(struct sock___68 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___68 *);
	void (*cong_control)(struct sock___68 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___68 *);
	u32 (*sndbuf_expand)(struct sock___68 *);
	size_t (*get_info)(struct sock___68 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___256 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___68 *);
	void (*release)(struct sock___68 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___68 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___86 *);
	int (*fib_dump)(struct net___86 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___256 *owner;
	struct callback_head rcu;
};

struct xfrm_state___12;

struct lwtunnel_state___44;

struct dst_entry___68 {
	struct net_device___81 *dev;
	struct dst_ops___86 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___12 *xfrm;
	int (*input)(struct sk_buff___82 *);
	int (*output)(struct net___86 *, struct sock___68 *, struct sk_buff___82 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___44 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___81(struct sk_buff___82 **);

struct bpf_xdp_entity___75 {
	struct bpf_prog___75 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___81;

struct net_device_ops___81;

struct l3mdev_ops___68;

struct ndisc_ops___50;

struct xfrmdev_ops___81;

struct header_ops___81;

struct in_device___10;

struct inet6_dev___50;

struct netdev_rx_queue___81;

struct mini_Qdisc___75;

struct netdev_queue___81;

struct Qdisc___75;

struct rtnl_link_ops___75;

struct dcbnl_rtnl_ops___81;

struct net_device___81 {
	char name[16];
	struct netdev_name_node___81 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___81 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___68 *l3mdev_ops;
	const struct ndisc_ops___50 *ndisc_ops;
	const struct xfrmdev_ops___81 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___81 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___260 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___10 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___50 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___81 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___75 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___81 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___75 *miniq_ingress;
	struct netdev_queue___81 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___81 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___75 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___75 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___81 = 0,
		NETREG_REGISTERED___81 = 1,
		NETREG_UNREGISTERING___81 = 2,
		NETREG_UNREGISTERED___81 = 3,
		NETREG_RELEASED___81 = 4,
		NETREG_DUMMY___81 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___81 = 0,
		RTNL_LINK_INITIALIZING___81 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___81 *);
	struct netpoll_info *npinfo;
	possible_net_t___81 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___253 dev;
	const struct attribute_group___260 *sysfs_groups[4];
	const struct attribute_group___260 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___75 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___81 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___75 xdp_state[3];
	long: 64;
};

struct neigh_table___68;

struct neigh_parms___68;

struct neigh_ops___68;

struct neighbour___68 {
	struct neighbour___68 *next;
	struct neigh_table___68 *tbl;
	struct neigh_parms___68 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___81 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___68 *, struct sk_buff___82 *);
	const struct neigh_ops___68 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___81 *dev;
	u8 primary_key[0];
};

struct rtable___17;

struct fnhe_hash_bucket___17;

struct fib_nh_common___17 {
	struct net_device___81 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___44 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___17 **nhc_pcpu_rth_output;
	struct rtable___17 *nhc_rth_input;
	struct fnhe_hash_bucket___17 *nhc_exceptions;
};

struct fib6_nh___17 {
	struct fib_nh_common___17 nh_common;
	long unsigned int last_probe;
	struct rt6_info___17 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___17;

struct fib6_info___17 {
	struct fib6_table___17 *fib6_table;
	struct fib6_info___17 *fib6_next;
	struct fib6_node___17 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___17 fib6_nh[0];
};

struct rt6_info___17 {
	struct dst_entry___68 dst;
	struct fib6_info___17 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___50 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___17 {
	struct fib6_node___17 *parent;
	struct fib6_node___17 *left;
	struct fib6_node___17 *right;
	struct fib6_node___17 *subtree;
	struct fib6_info___17 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___17 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___17 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___17 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___75 {
	struct bpf_prog___75 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___75 {
	struct callback_head rcu;
	struct bpf_prog_array_item___75 items[0];
};

struct bpf_prog_aux___84;

struct bpf_prog___75 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___84 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___267 {
	void (*page_free)(struct page___277 *);
	void (*kill)(struct dev_pagemap___267 *);
	void (*cleanup)(struct dev_pagemap___267 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___267 *);
};

struct fwnode_operations___249;

struct fwnode_handle___249 {
	struct fwnode_handle___249 *secondary;
	const struct fwnode_operations___249 *ops;
	struct device___253 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___249;

struct fwnode_endpoint___249;

struct fwnode_operations___249 {
	struct fwnode_handle___249 * (*get)(struct fwnode_handle___249 *);
	void (*put)(struct fwnode_handle___249 *);
	bool (*device_is_available)(const struct fwnode_handle___249 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___249 *, const struct device___253 *);
	bool (*property_present)(const struct fwnode_handle___249 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___249 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___249 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___249 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*get_parent)(const struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*get_next_child_node)(const struct fwnode_handle___249 *, struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*get_named_child_node)(const struct fwnode_handle___249 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___249 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___249 *);
	struct fwnode_handle___249 * (*graph_get_next_endpoint)(const struct fwnode_handle___249 *, struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*graph_get_remote_endpoint)(const struct fwnode_handle___249 *);
	struct fwnode_handle___249 * (*graph_get_port_parent)(struct fwnode_handle___249 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___249 *, struct fwnode_endpoint___249 *);
	int (*add_links)(struct fwnode_handle___249 *);
};

struct fwnode_endpoint___249 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___249 *local_fwnode;
};

struct fwnode_reference_args___249 {
	struct fwnode_handle___249 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___199 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___199 *root_cset;
};

struct socket_wq___69 {
	wait_queue_head_t wait;
	struct fasync_struct___272 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___69;

struct socket___70 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___272 *file;
	struct sock___68 *sk;
	const struct proto_ops___69 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___69 wq;
};

typedef int (*sk_read_actor_t___68)(read_descriptor_t *, struct sk_buff___82 *, unsigned int, size_t);

struct proto_ops___69 {
	int family;
	struct module___256 *owner;
	int (*release)(struct socket___70 *);
	int (*bind)(struct socket___70 *, struct sockaddr *, int);
	int (*connect)(struct socket___70 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___70 *, struct socket___70 *);
	int (*accept)(struct socket___70 *, struct socket___70 *, int, bool);
	int (*getname)(struct socket___70 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___272 *, struct socket___70 *, struct poll_table_struct___193 *);
	int (*ioctl)(struct socket___70 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___70 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___70 *, void *, bool, bool);
	int (*listen)(struct socket___70 *, int);
	int (*shutdown)(struct socket___70 *, int);
	int (*setsockopt)(struct socket___70 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___70 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___247 *, struct socket___70 *);
	int (*sendmsg)(struct socket___70 *, struct msghdr___70 *, size_t);
	int (*recvmsg)(struct socket___70 *, struct msghdr___70 *, size_t, int);
	int (*mmap)(struct file___272 *, struct socket___70 *, struct vm_area_struct___277 *);
	ssize_t (*sendpage)(struct socket___70 *, struct page___277 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___70 *, loff_t *, struct pipe_inode_info___113 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___68 *, int);
	int (*peek_len)(struct socket___70 *);
	int (*read_sock)(struct sock___68 *, read_descriptor_t *, sk_read_actor_t___68);
	int (*sendpage_locked)(struct sock___68 *, struct page___277 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___68 *, struct msghdr___70 *, size_t);
	int (*set_rcvlowat)(struct sock___68 *, int);
};

struct dev_pm_ops___253 {
	int (*prepare)(struct device___253 *);
	void (*complete)(struct device___253 *);
	int (*suspend)(struct device___253 *);
	int (*resume)(struct device___253 *);
	int (*freeze)(struct device___253 *);
	int (*thaw)(struct device___253 *);
	int (*poweroff)(struct device___253 *);
	int (*restore)(struct device___253 *);
	int (*suspend_late)(struct device___253 *);
	int (*resume_early)(struct device___253 *);
	int (*freeze_late)(struct device___253 *);
	int (*thaw_early)(struct device___253 *);
	int (*poweroff_late)(struct device___253 *);
	int (*restore_early)(struct device___253 *);
	int (*suspend_noirq)(struct device___253 *);
	int (*resume_noirq)(struct device___253 *);
	int (*freeze_noirq)(struct device___253 *);
	int (*thaw_noirq)(struct device___253 *);
	int (*poweroff_noirq)(struct device___253 *);
	int (*restore_noirq)(struct device___253 *);
	int (*runtime_suspend)(struct device___253 *);
	int (*runtime_resume)(struct device___253 *);
	int (*runtime_idle)(struct device___253 *);
};

struct wakeup_source___253 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___253 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___253 {
	struct dev_pm_ops___253 ops;
	int (*start)(struct device___253 *);
	void (*detach)(struct device___253 *, bool);
	int (*activate)(struct device___253 *);
	void (*sync)(struct device___253 *);
	void (*dismiss)(struct device___253 *);
};

struct bus_type___253 {
	const char *name;
	const char *dev_name;
	struct device___253 *dev_root;
	const struct attribute_group___260 **bus_groups;
	const struct attribute_group___260 **dev_groups;
	const struct attribute_group___260 **drv_groups;
	int (*match)(struct device___253 *, struct device_driver___253 *);
	int (*uevent)(struct device___253 *, struct kobj_uevent_env *);
	int (*probe)(struct device___253 *);
	void (*sync_state)(struct device___253 *);
	void (*remove)(struct device___253 *);
	void (*shutdown)(struct device___253 *);
	int (*online)(struct device___253 *);
	int (*offline)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	int (*num_vf)(struct device___253 *);
	int (*dma_configure)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___253 {
	const char *name;
	struct bus_type___253 *bus;
	struct module___256 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___253 *);
	void (*sync_state)(struct device___253 *);
	int (*remove)(struct device___253 *);
	void (*shutdown)(struct device___253 *);
	int (*suspend)(struct device___253 *, pm_message_t);
	int (*resume)(struct device___253 *);
	const struct attribute_group___260 **groups;
	const struct attribute_group___260 **dev_groups;
	const struct dev_pm_ops___253 *pm;
	void (*coredump)(struct device___253 *);
	struct driver_private *p;
};

struct device_type___253 {
	const char *name;
	const struct attribute_group___260 **groups;
	int (*uevent)(struct device___253 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___253 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___253 *);
	const struct dev_pm_ops___253 *pm;
};

struct class___253 {
	const char *name;
	struct module___256 *owner;
	const struct attribute_group___260 **class_groups;
	const struct attribute_group___260 **dev_groups;
	struct kobject___260 *dev_kobj;
	int (*dev_uevent)(struct device___253 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___253 *, umode_t *);
	void (*class_release)(struct class___253 *);
	void (*dev_release)(struct device___253 *);
	int (*shutdown_pre)(struct device___253 *);
	const struct kobj_ns_type_operations___68 *ns_type;
	const void * (*namespace)(struct device___253 *);
	void (*get_ownership)(struct device___253 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___253 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___113;

struct pipe_buffer___113 {
	struct page___277 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___113 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___113 {
	int (*confirm)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
	void (*release)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
	bool (*try_steal)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
	bool (*get)(struct pipe_inode_info___113 *, struct pipe_buffer___113 *);
};

typedef struct bio_vec___189 skb_frag_t___28;

struct ubuf_info___10 {
	void (*callback)(struct sk_buff___82 *, struct ubuf_info___10 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___27 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___82 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___28 frags[17];
};

struct seq_operations___247 {
	void * (*start)(struct seq_file___247 *, loff_t *);
	void (*stop)(struct seq_file___247 *, void *);
	void * (*next)(struct seq_file___247 *, void *, loff_t *);
	int (*show)(struct seq_file___247 *, void *);
};

struct seq_net_private___6 {
	struct net___86 *net;
};

struct pernet_operations___22 {
	struct list_head list;
	int (*init)(struct net___86 *);
	void (*pre_exit)(struct net___86 *);
	void (*exit)(struct net___86 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___81 {
	int (*ieee_getets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___81 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___81 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___81 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___81 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___81 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___81 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___81 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___81 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___81 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___81 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___81 *);
	u8 (*setstate)(struct net_device___81 *, u8);
	void (*getpermhwaddr)(struct net_device___81 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___81 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___81 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___81 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___81 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___81 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___81 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___81 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___81 *, int, u8 *);
	void (*setpfccfg)(struct net_device___81 *, int, u8);
	void (*getpfccfg)(struct net_device___81 *, int, u8 *);
	u8 (*setall)(struct net_device___81 *);
	u8 (*getcap)(struct net_device___81 *, int, u8 *);
	int (*getnumtcs)(struct net_device___81 *, int, u8 *);
	int (*setnumtcs)(struct net_device___81 *, int, u8);
	u8 (*getpfcstate)(struct net_device___81 *);
	void (*setpfcstate)(struct net_device___81 *, u8);
	void (*getbcncfg)(struct net_device___81 *, int, u32 *);
	void (*setbcncfg)(struct net_device___81 *, int, u32);
	void (*getbcnrp)(struct net_device___81 *, int, u8 *);
	void (*setbcnrp)(struct net_device___81 *, int, u8);
	int (*setapp)(struct net_device___81 *, u8, u16, u8);
	int (*getapp)(struct net_device___81 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___81 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___81 *, int, u8);
	u8 (*getdcbx)(struct net_device___81 *);
	u8 (*setdcbx)(struct net_device___81 *, u8);
	int (*peer_getappinfo)(struct net_device___81 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___81 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___81 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___81 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___81 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___81 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___84;

typedef int (*bpf_iter_init_seq_priv_t___83)(void *, struct bpf_iter_aux_info___84 *);

struct bpf_map___84;

struct bpf_iter_aux_info___84 {
	struct bpf_map___84 *map;
};

struct bpf_iter_seq_info___83 {
	const struct seq_operations___247 *seq_ops;
	bpf_iter_init_seq_priv_t___83 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___83 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___84 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___84 *, struct file___272 *);
	void (*map_free)(struct bpf_map___84 *);
	int (*map_get_next_key)(struct bpf_map___84 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___84 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___84 *, void *);
	int (*map_lookup_batch)(struct bpf_map___84 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___84 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___84 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___84 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___84 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___84 *, void *);
	int (*map_update_elem)(struct bpf_map___84 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___84 *, void *);
	int (*map_push_elem)(struct bpf_map___84 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___84 *, void *);
	int (*map_peek_elem)(struct bpf_map___84 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___84 *, struct file___272 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___84 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___84 *, void *, struct seq_file___247 *);
	int (*map_check_btf)(const struct bpf_map___84 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___84 *, struct bpf_prog_aux___84 *);
	void (*map_poke_untrack)(struct bpf_map___84 *, struct bpf_prog_aux___84 *);
	void (*map_poke_run)(struct bpf_map___84 *, u32, struct bpf_prog___75 *, struct bpf_prog___75 *);
	int (*map_direct_value_addr)(const struct bpf_map___84 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___84 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___84 *, struct vm_area_struct___277 *);
	__poll_t (*map_poll)(struct bpf_map___84 *, struct file___272 *, struct poll_table_struct___193 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___84 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___84 *, const struct bpf_map___84 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___84 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___83 *iter_seq_info;
};

struct bpf_map___84 {
	const struct bpf_map_ops___83 *ops;
	struct bpf_map___84 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___137 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___83;

struct bpf_jit_poke_descriptor___83;

struct bpf_prog_ops___75;

struct btf_mod_pair___83;

struct bpf_prog_offload___81;

struct bpf_prog_aux___84 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___75 *dst_prog;
	struct bpf_trampoline___83 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___75 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___83 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___75 *ops;
	struct bpf_map___84 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___83 *used_btfs;
	struct bpf_prog___75 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___84 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___81 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___81;

struct bpf_map_dev_ops___81 {
	int (*map_get_next_key)(struct bpf_offloaded_map___81 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___81 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___81 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___81 *, void *);
};

struct bpf_offloaded_map___81 {
	struct bpf_map___84 map;
	struct net_device___81 *netdev;
	const struct bpf_map_dev_ops___81 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_func_proto___13 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___75 *);
};

struct bpf_prog_ops___75 {
	int (*test_run)(struct bpf_prog___75 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___81 {
	struct bpf_prog___75 *prog;
	struct net_device___81 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___83 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___75 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___256 *mod;
};

struct bpf_jit_poke_descriptor___83 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___84 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___83 {
	struct btf *btf;
	struct module___256 *module;
};

typedef int (*bpf_iter_attach_target_t___5)(struct bpf_prog___75 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___84 *);

typedef void (*bpf_iter_detach_target_t___5)(struct bpf_iter_aux_info___84 *);

typedef void (*bpf_iter_show_fdinfo_t___5)(const struct bpf_iter_aux_info___84 *, struct seq_file___247 *);

typedef int (*bpf_iter_fill_link_info_t___5)(const struct bpf_iter_aux_info___84 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___13 * (*bpf_iter_get_func_proto_t___6)(enum bpf_func_id, const struct bpf_prog___75 *);

struct bpf_iter_reg___5 {
	const char *target;
	bpf_iter_attach_target_t___5 attach_target;
	bpf_iter_detach_target_t___5 detach_target;
	bpf_iter_show_fdinfo_t___5 show_fdinfo;
	bpf_iter_fill_link_info_t___5 fill_link_info;
	bpf_iter_get_func_proto_t___6 get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___83 *seq_info;
};

struct bpf_iter_meta___6 {
	union {
		struct seq_file___247 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct cftype___199;

struct cgroup_subsys___199 {
	struct cgroup_subsys_state___199 * (*css_alloc)(struct cgroup_subsys_state___199 *);
	int (*css_online)(struct cgroup_subsys_state___199 *);
	void (*css_offline)(struct cgroup_subsys_state___199 *);
	void (*css_released)(struct cgroup_subsys_state___199 *);
	void (*css_free)(struct cgroup_subsys_state___199 *);
	void (*css_reset)(struct cgroup_subsys_state___199 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___199 *, int);
	int (*css_extra_stat_show)(struct seq_file___247 *, struct cgroup_subsys_state___199 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___279 *, struct css_set___199 *);
	void (*cancel_fork)(struct task_struct___279 *, struct css_set___199 *);
	void (*fork)(struct task_struct___279 *);
	void (*exit)(struct task_struct___279 *);
	void (*release)(struct task_struct___279 *);
	void (*bind)(struct cgroup_subsys_state___199 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___199 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___199 *dfl_cftypes;
	struct cftype___199 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___199 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___199 *updated_children;
	struct cgroup___199 *updated_next;
};

struct cgroup_root___199 {
	struct kernfs_root___260 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___199 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___199 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___199 *ss;
	struct list_head node;
	struct kernfs_ops___260 *kf_ops;
	int (*open)(struct kernfs_open_file___260 *);
	void (*release)(struct kernfs_open_file___260 *);
	u64 (*read_u64)(struct cgroup_subsys_state___199 *, struct cftype___199 *);
	s64 (*read_s64)(struct cgroup_subsys_state___199 *, struct cftype___199 *);
	int (*seq_show)(struct seq_file___247 *, void *);
	void * (*seq_start)(struct seq_file___247 *, loff_t *);
	void * (*seq_next)(struct seq_file___247 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___247 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___199 *, struct cftype___199 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___199 *, struct cftype___199 *, s64);
	ssize_t (*write)(struct kernfs_open_file___260 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___260 *, struct poll_table_struct___193 *);
};

struct xdp_rxq_info___81 {
	struct net_device___81 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___81 {
	struct net_device___81 *dev;
};

struct xdp_buff___81 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___81 *rxq;
	struct xdp_txq_info___81 *txq;
	u32 frame_sz;
};

struct xdp_frame___81 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___81 *dev_rx;
};

struct netlink_callback___81 {
	struct sk_buff___82 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___82 *, struct netlink_callback___81 *);
	int (*done)(struct netlink_callback___81 *);
	void *data;
	struct module___256 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___81 {
	int (*create)(struct sk_buff___82 *, struct net_device___81 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___82 *, unsigned char *);
	int (*cache)(const struct neighbour___68 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___81 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___82 *);
};

struct netdev_queue___81 {
	struct net_device___81 *dev;
	struct Qdisc___75 *qdisc;
	struct Qdisc___75 *qdisc_sleeping;
	struct kobject___260 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___81 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___75 {
	struct sk_buff___82 *head;
	struct sk_buff___82 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___75;

struct Qdisc___75 {
	int (*enqueue)(struct sk_buff___82 *, struct Qdisc___75 *, struct sk_buff___82 **);
	struct sk_buff___82 * (*dequeue)(struct Qdisc___75 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___75 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___81 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___81 gso_skb;
	struct qdisc_skb_head___75 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___75 *next_sched;
	struct sk_buff_head___81 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___81 {
	struct xdp_rxq_info___81 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___260 kobj;
	struct net_device___81 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___81 {
	enum net_device_path_type type;
	const struct net_device___81 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___81 = 0,
				DEV_PATH_BR_VLAN_TAG___81 = 1,
				DEV_PATH_BR_VLAN_UNTAG___81 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___81 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___81 {
	const struct net_device___81 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___81 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___75 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___81 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___81 {
	int (*xdo_dev_state_add)(struct xfrm_state___12 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___12 *);
	void (*xdo_dev_state_free)(struct xfrm_state___12 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___82 *, struct xfrm_state___12 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___12 *);
};

struct xfrm_state_offload___12 {
	struct net_device___81 *dev;
	struct net_device___81 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___12;

struct xfrm_type_offload___12;

struct xfrm_state___12 {
	possible_net_t___81 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___68 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___12 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___12 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___277 xfrag;
	const struct xfrm_type___12 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___12 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___81 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___81 *dev;
	const char *name;
};

struct net_device_ops___81 {
	int (*ndo_init)(struct net_device___81 *);
	void (*ndo_uninit)(struct net_device___81 *);
	int (*ndo_open)(struct net_device___81 *);
	int (*ndo_stop)(struct net_device___81 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___82 *, struct net_device___81 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___82 *, struct net_device___81 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___81 *, struct sk_buff___82 *, struct net_device___81 *);
	void (*ndo_change_rx_flags)(struct net_device___81 *, int);
	void (*ndo_set_rx_mode)(struct net_device___81 *);
	int (*ndo_set_mac_address)(struct net_device___81 *, void *);
	int (*ndo_validate_addr)(struct net_device___81 *);
	int (*ndo_do_ioctl)(struct net_device___81 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___81 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___81 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___81 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___81 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___81 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___81 *, int);
	int (*ndo_neigh_setup)(struct net_device___81 *, struct neigh_parms___68 *);
	void (*ndo_tx_timeout)(struct net_device___81 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___81 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___81 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___81 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___81 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___81 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___81 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___81 *);
	int (*ndo_netpoll_setup)(struct net_device___81 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___81 *);
	int (*ndo_set_vf_mac)(struct net_device___81 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___81 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___81 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___81 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___81 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___81 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___81 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___81 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___81 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___81 *, int, struct sk_buff___82 *);
	int (*ndo_get_vf_guid)(struct net_device___81 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___81 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___81 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___81 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___81 *);
	int (*ndo_fcoe_disable)(struct net_device___81 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___81 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___81 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___81 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___81 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___81 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___81 *, const struct sk_buff___82 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___81 *, struct net_device___81 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___81 *, struct net_device___81 *);
	struct net_device___81 * (*ndo_get_xmit_slave)(struct net_device___81 *, struct sk_buff___82 *, bool);
	struct net_device___81 * (*ndo_sk_get_lower_dev)(struct net_device___81 *, struct sock___68 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___81 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___81 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___81 *, struct neighbour___68 *);
	void (*ndo_neigh_destroy)(struct net_device___81 *, struct neighbour___68 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___82 *, struct netlink_callback___81 *, struct net_device___81 *, struct net_device___81 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___82 *, struct nlattr **, struct net_device___81 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___81 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___82 *, u32, u32, struct net_device___81 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___81 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___81 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___81 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___81 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___81 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___81 *, struct net_device___81 *);
	void (*ndo_dfwd_del_station)(struct net_device___81 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___81 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___81 *);
	int (*ndo_change_proto_down)(struct net_device___81 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___81 *, struct sk_buff___82 *);
	void (*ndo_set_rx_headroom)(struct net_device___81 *, int);
	int (*ndo_bpf)(struct net_device___81 *, struct netdev_bpf___81 *);
	int (*ndo_xdp_xmit)(struct net_device___81 *, int, struct xdp_frame___81 **, u32);
	struct net_device___81 * (*ndo_xdp_get_xmit_slave)(struct net_device___81 *, struct xdp_buff___81 *);
	int (*ndo_xsk_wakeup)(struct net_device___81 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___81 *);
	int (*ndo_tunnel_ctl)(struct net_device___81 *, struct ip_tunnel_parm *, int);
	struct net_device___81 * (*ndo_get_peer_dev)(struct net_device___81 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___81 *, struct net_device_path___81 *);
};

struct neigh_parms___68 {
	possible_net_t___81 net;
	struct net_device___81 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___68 *);
	struct neigh_table___68 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___68 {
	u32 (*l3mdev_fib_table)(const struct net_device___81 *);
	struct sk_buff___82 * (*l3mdev_l3_rcv)(struct net_device___81 *, struct sk_buff___82 *, u16);
	struct sk_buff___82 * (*l3mdev_l3_out)(struct net_device___81 *, struct sock___68 *, struct sk_buff___82 *, u16);
	struct dst_entry___68 * (*l3mdev_link_scope_lookup)(const struct net_device___81 *, struct flowi6 *);
};

struct ndisc_ops___50 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___81 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___81 *, struct neighbour___68 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___81 *, u8, struct neighbour___68 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___81 *, struct sk_buff___82 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___86 *, struct net_device___81 *, const struct prefix_info *, struct inet6_dev___50 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___10;

struct in_device___10 {
	struct net_device___81 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___10 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___68 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___50;

struct ifacaddr6___17;

struct inet6_dev___50 {
	struct net_device___81 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___50 *mc_list;
	struct ifmcaddr6___50 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___81 mc_query_queue;
	struct sk_buff_head___81 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___17 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___68 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___75;

struct tcf_block___75;

struct mini_Qdisc___75 {
	struct tcf_proto___75 *filter_list;
	struct tcf_block___75 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___75 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___81 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___81 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___86 *, struct net_device___81 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___81 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___81 *, struct list_head *);
	size_t (*get_size)(const struct net_device___81 *);
	int (*fill_info)(struct sk_buff___82 *, const struct net_device___81 *);
	size_t (*get_xstats_size)(const struct net_device___81 *);
	int (*fill_xstats)(struct sk_buff___82 *, const struct net_device___81 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___81 *, struct net_device___81 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___81 *, const struct net_device___81 *);
	int (*fill_slave_info)(struct sk_buff___82 *, const struct net_device___81 *, const struct net_device___81 *);
	struct net___86 * (*get_link_net)(const struct net_device___81 *);
	size_t (*get_linkxstats_size)(const struct net_device___81 *, int);
	int (*fill_linkxstats)(struct sk_buff___82 *, const struct net_device___81 *, int *, int);
};

struct block_device_operations___163;

struct gendisk___166 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___166 *part0;
	const struct block_device_operations___163 *fops;
	struct request_queue___163 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___149 *bdi;
	struct kobject___260 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___260 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___163 {
	struct bio___163 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___189 *bip_vec;
	struct bio_vec___189 bip_inline_vecs[0];
};

struct blkcg___151;

struct blkg_policy_data___151;

struct blkcg_gq___151 {
	struct request_queue___163 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___151 *blkcg;
	struct blkcg_gq___151 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___151 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___163 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___163(struct request___163 *);

typedef void integrity_complete_fn___163(struct request___163 *, unsigned int);

struct blk_integrity_profile___163 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___163 *prepare_fn;
	integrity_complete_fn___163 *complete_fn;
	const char *name;
};

struct block_device_operations___163 {
	blk_qc_t (*submit_bio)(struct bio___163 *);
	int (*open)(struct block_device___166 *, fmode_t);
	void (*release)(struct gendisk___166 *, fmode_t);
	int (*rw_page)(struct block_device___166 *, sector_t, struct page___277 *, unsigned int);
	int (*ioctl)(struct block_device___166 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___166 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___166 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___166 *);
	int (*getgeo)(struct block_device___166 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___166 *, bool);
	void (*swap_slot_free_notify)(struct block_device___166 *, long unsigned int);
	int (*report_zones)(struct gendisk___166 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___166 *, umode_t *);
	struct module___256 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___166 *, sector_t *);
};

typedef void rq_end_io_fn___163(struct request___163 *, blk_status_t);

struct request___163 {
	struct request_queue___163 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___158 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___163 *bio;
	struct bio___163 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___189 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___163 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___163 *saved_end_io;
		} flush;
	};
	struct gendisk___166 *rq_disk;
	struct block_device___166 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___163 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___158 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___163 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___260 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___272 *debugfs_dir;
	struct dentry___272 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___163;

struct elevator_mq_ops___163 {
	int (*init_sched)(struct request_queue___163 *, struct elevator_type___163 *);
	void (*exit_sched)(struct elevator_queue___163 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___158 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___158 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___158 *);
	bool (*allow_merge)(struct request_queue___163 *, struct request___163 *, struct bio___163 *);
	bool (*bio_merge)(struct request_queue___163 *, struct bio___163 *, unsigned int);
	int (*request_merge)(struct request_queue___163 *, struct request___163 **, struct bio___163 *);
	void (*request_merged)(struct request_queue___163 *, struct request___163 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___163 *, struct request___163 *, struct request___163 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___163 *);
	void (*finish_request)(struct request___163 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___158 *, struct list_head *, bool);
	struct request___163 * (*dispatch_request)(struct blk_mq_hw_ctx___158 *);
	bool (*has_work)(struct blk_mq_hw_ctx___158 *);
	void (*completed_request)(struct request___163 *, u64);
	void (*requeue_request)(struct request___163 *);
	struct request___163 * (*former_request)(struct request_queue___163 *, struct request___163 *);
	struct request___163 * (*next_request)(struct request_queue___163 *, struct request___163 *);
	void (*init_icq)(struct io_cq___163 *);
	void (*exit_icq)(struct io_cq___163 *);
};

struct elv_fs_entry___163;

struct elevator_type___163 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___163 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___163 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___256 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___163 {
	struct elevator_type___163 *type;
	void *elevator_data;
	struct kobject___260 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___163 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___163 *, char *);
	ssize_t (*store)(struct elevator_queue___163 *, const char *, size_t);
};

struct blk_mq_queue_data___158;

struct blk_mq_ops___158 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___158 *, const struct blk_mq_queue_data___158 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___158 *);
	int (*get_budget)(struct request_queue___163 *);
	void (*put_budget)(struct request_queue___163 *, int);
	void (*set_rq_budget_token)(struct request___163 *, int);
	int (*get_rq_budget_token)(struct request___163 *);
	enum blk_eh_timer_return (*timeout)(struct request___163 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___158 *);
	void (*complete)(struct request___163 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___158 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___158 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___158 *, struct request___163 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___158 *, struct request___163 *, unsigned int);
	void (*initialize_rq_fn)(struct request___163 *);
	void (*cleanup_rq)(struct request___163 *);
	bool (*busy)(struct request_queue___163 *);
	int (*map_queues)(struct blk_mq_tag_set___158 *);
	void (*show_rq)(struct seq_file___247 *, struct request___163 *);
};

struct blk_mq_tag_set___158 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___158 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___158 {
	struct request___163 *rq;
	bool last;
};

struct blkcg_policy_data___151;

struct blkcg___151 {
	struct cgroup_subsys_state___199 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___151 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___151 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___151 {
	struct blkcg___151 *blkcg;
	int plid;
};

struct blkg_policy_data___151 {
	struct blkcg_gq___151 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___137 {
	struct mem_cgroup___137 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___137 {
	struct lruvec___145 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___137 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___137 *memcg;
};

struct obj_cgroup___137 {
	struct percpu_ref refcnt;
	struct mem_cgroup___137 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___75 {
	spinlock_t *lock;
	struct sk_buff___82 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___75;

struct Qdisc_ops___75 {
	struct Qdisc_ops___75 *next;
	const struct Qdisc_class_ops___75 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___82 *, struct Qdisc___75 *, struct sk_buff___82 **);
	struct sk_buff___82 * (*dequeue)(struct Qdisc___75 *);
	struct sk_buff___82 * (*peek)(struct Qdisc___75 *);
	int (*init)(struct Qdisc___75 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___75 *);
	void (*destroy)(struct Qdisc___75 *);
	int (*change)(struct Qdisc___75 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___75 *);
	int (*change_tx_queue_len)(struct Qdisc___75 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___75 *, unsigned int);
	int (*dump)(struct Qdisc___75 *, struct sk_buff___82 *);
	int (*dump_stats)(struct Qdisc___75 *, struct gnet_dump___75 *);
	void (*ingress_block_set)(struct Qdisc___75 *, u32);
	void (*egress_block_set)(struct Qdisc___75 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___75 *);
	u32 (*egress_block_get)(struct Qdisc___75 *);
	struct module___256 *owner;
};

struct Qdisc_class_ops___75 {
	unsigned int flags;
	struct netdev_queue___81 * (*select_queue)(struct Qdisc___75 *, struct tcmsg *);
	int (*graft)(struct Qdisc___75 *, long unsigned int, struct Qdisc___75 *, struct Qdisc___75 **, struct netlink_ext_ack *);
	struct Qdisc___75 * (*leaf)(struct Qdisc___75 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___75 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___75 *, u32);
	int (*change)(struct Qdisc___75 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___75 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___75 *, struct qdisc_walker *);
	struct tcf_block___75 * (*tcf_block)(struct Qdisc___75 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___75 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___75 *, long unsigned int);
	int (*dump)(struct Qdisc___75 *, long unsigned int, struct sk_buff___82 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___75 *, long unsigned int, struct gnet_dump___75 *);
};

struct tcf_chain___75;

struct tcf_block___75 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___86 *net;
	struct Qdisc___75 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___75 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___75;

struct tcf_proto_ops___75;

struct tcf_proto___75 {
	struct tcf_proto___75 *next;
	void *root;
	int (*classify)(struct sk_buff___82 *, const struct tcf_proto___75 *, struct tcf_result___75 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___75 *ops;
	struct tcf_chain___75 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___75 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___75 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___75 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___82 *, const struct tcf_proto___75 *, struct tcf_result___75 *);
	int (*init)(struct tcf_proto___75 *);
	void (*destroy)(struct tcf_proto___75 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___75 *, u32);
	void (*put)(struct tcf_proto___75 *, void *);
	int (*change)(struct net___86 *, struct sk_buff___82 *, struct tcf_proto___75 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___75 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___75 *);
	void (*walk)(struct tcf_proto___75 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___75 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___75 *, void *);
	void (*hw_del)(struct tcf_proto___75 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___86 *, struct tcf_chain___75 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___86 *, struct tcf_proto___75 *, void *, struct sk_buff___82 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___86 *, struct tcf_proto___75 *, void *, struct sk_buff___82 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___82 *, struct net___86 *, void *);
	struct module___256 *owner;
	int flags;
};

struct tcf_chain___75 {
	struct mutex filter_chain_lock;
	struct tcf_proto___75 *filter_chain;
	struct list_head list;
	struct tcf_block___75 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___75 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___68 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___75 *prog;
};

struct bpf_sock_ops_kern___7 {
	struct sock___68 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___82 *syn_skb;
	struct sk_buff___82 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct pneigh_entry___68;

struct neigh_hash_table___68;

struct neigh_table___68 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___81 *, __u32 *);
	bool (*key_eq)(const struct neighbour___68 *, const void *);
	int (*constructor)(struct neighbour___68 *);
	int (*pconstructor)(struct pneigh_entry___68 *);
	void (*pdestructor)(struct pneigh_entry___68 *);
	void (*proxy_redo)(struct sk_buff___82 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___81 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___68 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___81 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___68 *nht;
	struct pneigh_entry___68 **phash_buckets;
};

struct neigh_ops___68 {
	int family;
	void (*solicit)(struct neighbour___68 *, struct sk_buff___82 *);
	void (*error_report)(struct neighbour___68 *, struct sk_buff___82 *);
	int (*output)(struct neighbour___68 *, struct sk_buff___82 *);
	int (*connected_output)(struct neighbour___68 *, struct sk_buff___82 *);
};

struct pneigh_entry___68 {
	struct pneigh_entry___68 *next;
	possible_net_t___81 net;
	struct net_device___81 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___68 {
	struct neighbour___68 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___44 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___86 *, struct sock___68 *, struct sk_buff___82 *);
	int (*orig_input)(struct sk_buff___82 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___68 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___68 *ctarget;
	struct net___86 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___68 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___68 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___53;

struct timewait_sock_ops___52;

struct proto___68 {
	void (*close)(struct sock___68 *, long int);
	int (*pre_connect)(struct sock___68 *, struct sockaddr *, int);
	int (*connect)(struct sock___68 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___68 *, int);
	struct sock___68 * (*accept)(struct sock___68 *, int, int *, bool);
	int (*ioctl)(struct sock___68 *, int, long unsigned int);
	int (*init)(struct sock___68 *);
	void (*destroy)(struct sock___68 *);
	void (*shutdown)(struct sock___68 *, int);
	int (*setsockopt)(struct sock___68 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___68 *, int, int, char *, int *);
	void (*keepalive)(struct sock___68 *, int);
	int (*compat_ioctl)(struct sock___68 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___68 *, struct msghdr___70 *, size_t);
	int (*recvmsg)(struct sock___68 *, struct msghdr___70 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___68 *, struct page___277 *, int, size_t, int);
	int (*bind)(struct sock___68 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___68 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___68 *, struct sk_buff___82 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___68 *);
	int (*hash)(struct sock___68 *);
	void (*unhash)(struct sock___68 *);
	void (*rehash)(struct sock___68 *);
	int (*get_port)(struct sock___68 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___68 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___68 *, int);
	bool (*sock_is_readable)(struct sock___68 *);
	void (*enter_memory_pressure)(struct sock___68 *);
	void (*leave_memory_pressure)(struct sock___68 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___53 *rsk_prot;
	struct timewait_sock_ops___52 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___256 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___68 *, int);
};

struct xfrm_policy_queue___12 {
	struct sk_buff_head___81 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___12 {
	possible_net_t___81 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___12 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___20 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___75 *prog;
	struct sock___68 *socks[0];
};

struct request_sock___54;

struct request_sock_ops___53 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___68 *, struct request_sock___54 *);
	void (*send_ack)(const struct sock___68 *, struct sk_buff___82 *, struct request_sock___54 *);
	void (*send_reset)(const struct sock___68 *, struct sk_buff___82 *);
	void (*destructor)(struct request_sock___54 *);
	void (*syn_ack_timeout)(const struct request_sock___54 *);
};

struct timewait_sock_ops___52 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___68 *, struct sock___68 *, void *);
	void (*twsk_destructor)(struct sock___68 *);
};

struct request_sock___54 {
	struct sock_common___68 __req_common;
	struct request_sock___54 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___53 *rsk_ops;
	struct sock___68 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___7 {
	struct request_sock___54 *rskq_rst_head;
	struct request_sock___54 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___7 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___54 *rskq_accept_head;
	struct request_sock___54 *rskq_accept_tail;
	struct fastopen_queue___7 fastopenq;
};

struct inet_request_sock___6 {
	struct request_sock___54 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___82 *pktopts;
		};
	};
};

struct inet_cork___10 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___68 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___10 {
	struct inet_cork___10 base;
	struct flowi fl;
};

struct ipv6_pinfo___10;

struct inet_sock___10 {
	struct sock___68 sk;
	struct ipv6_pinfo___10 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___10 cork;
};

struct ipv6_fl_socklist___10;

struct ipv6_pinfo___10 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___10 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___82 *pktoptions;
	struct sk_buff___82 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___7 {
	int (*queue_xmit)(struct sock___68 *, struct sk_buff___82 *, struct flowi *);
	void (*send_check)(struct sock___68 *, struct sk_buff___82 *);
	int (*rebuild_header)(struct sock___68 *);
	void (*sk_rx_dst_set)(struct sock___68 *, const struct sk_buff___82 *);
	int (*conn_request)(struct sock___68 *, struct sk_buff___82 *);
	struct sock___68 * (*syn_recv_sock)(const struct sock___68 *, struct sk_buff___82 *, struct request_sock___54 *, struct dst_entry___68 *, struct request_sock___54 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___68 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___68 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___68 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___68 *);
};

struct inet_bind_bucket___7;

struct tcp_ulp_ops___7;

struct inet_connection_sock___7 {
	struct inet_sock___10 icsk_inet;
	struct request_sock_queue___7 icsk_accept_queue;
	struct inet_bind_bucket___7 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___19 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___7 *icsk_af_ops;
	const struct tcp_ulp_ops___7 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___68 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___68 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___7 {
	possible_net_t___81 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___7 {
	struct list_head list;
	int (*init)(struct sock___68 *);
	void (*update)(struct sock___68 *, struct proto___68 *, void (*)(struct sock___68 *));
	void (*release)(struct sock___68 *);
	int (*get_info)(const struct sock___68 *, struct sk_buff___82 *);
	size_t (*get_info_size)(const struct sock___68 *);
	void (*clone)(const struct request_sock___54 *, struct sock___68 *, const gfp_t);
	char name[16];
	struct module___256 *owner;
};

struct inet_timewait_sock___2 {
	struct sock_common___68 __tw_common;
	__u32 tw_mark;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_kill: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tw_txhash;
	u32 tw_priority;
	struct timer_list tw_timer;
	struct inet_bind_bucket___7 *tw_tb;
};

struct tcp_md5sig {
	struct __kernel_sockaddr_storage tcpm_addr;
	__u8 tcpm_flags;
	__u8 tcpm_prefixlen;
	__u16 tcpm_keylen;
	int tcpm_ifindex;
	__u8 tcpm_key[80];
};

struct tcp_request_sock_ops___5;

struct tcp_request_sock___5 {
	struct inet_request_sock___6 req;
	const struct tcp_request_sock_ops___5 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_request_sock_ops___5 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___68 *, const struct sock___68 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___68 *, const struct sk_buff___82 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___82 *, __u16 *);
	struct dst_entry___68 * (*route_req)(const struct sock___68 *, struct sk_buff___82 *, struct flowi *, struct request_sock___54 *);
	u32 (*init_seq)(const struct sk_buff___82 *);
	u32 (*init_ts_off)(const struct net___86 *, const struct sk_buff___82 *);
	int (*send_synack)(const struct sock___68 *, struct dst_entry___68 *, struct flowi *, struct request_sock___54 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___82 *);
};

struct tcp_sock_af_ops___8;

struct tcp_fastopen_request___8;

struct tcp_sock___8 {
	struct inet_connection_sock___7 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___82 *lost_skb_hint;
	struct sk_buff___82 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___82 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___82 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___8 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___8 *fastopen_req;
	struct request_sock___54 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___8 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___68 *, const struct sock___68 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___68 *, const struct sk_buff___82 *);
	int (*md5_parse)(struct sock___68 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___8 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___70 *data;
	size_t size;
	int copied;
	struct ubuf_info___10 *uarg;
};

struct tcp_timewait_sock___2 {
	struct inet_timewait_sock___2 tw_sk;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	int tw_ts_recent_stamp;
	u32 tw_tx_delay;
	struct tcp_md5sig_key *tw_md5_key;
};

struct ip6_flowlabel___10;

struct ipv6_fl_socklist___10 {
	struct ipv6_fl_socklist___10 *next;
	struct ip6_flowlabel___10 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___50 {
	struct in6_addr mca_addr;
	struct inet6_dev___50 *idev;
	struct ifmcaddr6___50 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___17 {
	struct in6_addr aca_addr;
	struct fib6_info___17 *aca_rt;
	struct ifacaddr6___17 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___10 {
	struct ip6_flowlabel___10 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___249 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___86 *fl_net;
};

struct fib_nh_exception___17 {
	struct fib_nh_exception___17 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___17 *fnhe_rth_input;
	struct rtable___17 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___17 {
	struct dst_entry___68 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___17 {
	struct fib_nh_exception___17 *chain;
};

struct icmp_err {
	int errno;
	unsigned int fatal: 1;
	long: 63;
};

enum tcp_tw_status {
	TCP_TW_SUCCESS = 0,
	TCP_TW_RST = 1,
	TCP_TW_ACK = 2,
	TCP_TW_SYN = 3,
};

struct tcp4_pseudohdr {
	__be32 saddr;
	__be32 daddr;
	__u8 pad;
	__u8 protocol;
	__be16 len;
};

struct ahash_request___8;

struct tcp_md5sig_pool___2 {
	struct ahash_request___8 *md5_req;
	void *scratch;
};

struct crypto_async_request___11;

typedef void (*crypto_completion_t___11)(struct crypto_async_request___11 *, int);

struct crypto_tfm___26;

struct crypto_async_request___11 {
	struct list_head list;
	crypto_completion_t___11 complete;
	void *data;
	struct crypto_tfm___26 *tfm;
	u32 flags;
};

struct ahash_request___8 {
	struct crypto_async_request___11 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

enum tcp_seq_states {
	TCP_SEQ_STATE_LISTENING = 0,
	TCP_SEQ_STATE_ESTABLISHED = 1,
};

struct tcp_seq_afinfo {
	sa_family_t family;
};

struct tcp_iter_state {
	struct seq_net_private___6 p;
	enum tcp_seq_states state;
	struct sock___68 *syn_wait_sk;
	int bucket;
	int offset;
	int sbucket;
	int num;
	loff_t last_pos;
};

struct xfrm_type___12 {
	struct module___256 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___12 *);
	void (*destructor)(struct xfrm_state___12 *);
	int (*input)(struct xfrm_state___12 *, struct sk_buff___82 *);
	int (*output)(struct xfrm_state___12 *, struct sk_buff___82 *);
	int (*reject)(struct xfrm_state___12 *, struct sk_buff___82 *, const struct flowi *);
};

struct xfrm_type_offload___12 {
	struct module___256 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___12 *, struct sk_buff___82 *);
	int (*input_tail)(struct xfrm_state___12 *, struct sk_buff___82 *);
	int (*xmit)(struct xfrm_state___12 *, struct sk_buff___82 *, netdev_features_t);
};

struct in_ifaddr___10 {
	struct hlist_node hash;
	struct in_ifaddr___10 *ifa_next;
	struct in_device___10 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct crypto_alg___26;

struct crypto_tfm___26 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___26 *);
	struct crypto_alg___26 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___26 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___26 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___26 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___26 *, u8 *, const u8 *);
};

struct compress_alg___26 {
	int (*coa_compress)(struct crypto_tfm___26 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___26 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___26 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___26 cipher;
		struct compress_alg___26 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___26 *);
	void (*cra_exit)(struct crypto_tfm___26 *);
	void (*cra_destroy)(struct crypto_alg___26 *);
	struct module___256 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_ahash___7 {
	int (*init)(struct ahash_request___8 *);
	int (*update)(struct ahash_request___8 *);
	int (*final)(struct ahash_request___8 *);
	int (*finup)(struct ahash_request___8 *);
	int (*digest)(struct ahash_request___8 *);
	int (*export)(struct ahash_request___8 *, void *);
	int (*import)(struct ahash_request___8 *, const void *);
	int (*setkey)(struct crypto_ahash___7 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___26 base;
};

struct bpf_tcp_iter_state {
	struct tcp_iter_state state;
	unsigned int cur_sk;
	unsigned int end_sk;
	unsigned int max_sk;
	struct sock___68 **batch;
	bool st_bucket_done;
};

struct bpf_iter__tcp {
	union {
		struct bpf_iter_meta___6 *meta;
	};
	union {
		struct sock_common___68 *sk_common;
	};
	uid_t uid;
};

struct netlink_skb_parms___16 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___66 *sk;
	bool nsid_is_set;
	int nsid;
};

enum tcp_metric_index {
	TCP_METRIC_RTT = 0,
	TCP_METRIC_RTTVAR = 1,
	TCP_METRIC_SSTHRESH = 2,
	TCP_METRIC_CWND = 3,
	TCP_METRIC_REORDERING = 4,
	TCP_METRIC_RTT_US = 5,
	TCP_METRIC_RTTVAR_US = 6,
	__TCP_METRIC_MAX = 7,
};

enum {
	TCP_METRICS_ATTR_UNSPEC = 0,
	TCP_METRICS_ATTR_ADDR_IPV4 = 1,
	TCP_METRICS_ATTR_ADDR_IPV6 = 2,
	TCP_METRICS_ATTR_AGE = 3,
	TCP_METRICS_ATTR_TW_TSVAL = 4,
	TCP_METRICS_ATTR_TW_TS_STAMP = 5,
	TCP_METRICS_ATTR_VALS = 6,
	TCP_METRICS_ATTR_FOPEN_MSS = 7,
	TCP_METRICS_ATTR_FOPEN_SYN_DROPS = 8,
	TCP_METRICS_ATTR_FOPEN_SYN_DROP_TS = 9,
	TCP_METRICS_ATTR_FOPEN_COOKIE = 10,
	TCP_METRICS_ATTR_SADDR_IPV4 = 11,
	TCP_METRICS_ATTR_SADDR_IPV6 = 12,
	TCP_METRICS_ATTR_PAD = 13,
	__TCP_METRICS_ATTR_MAX = 14,
};

enum {
	TCP_METRICS_CMD_UNSPEC = 0,
	TCP_METRICS_CMD_GET = 1,
	TCP_METRICS_CMD_DEL = 2,
	__TCP_METRICS_CMD_MAX = 3,
};

struct genl_ops___8;

struct genl_info___8;

struct genl_small_ops___8;

struct genl_family___8 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok: 1;
	u8 parallel_ops: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___8 *, struct sk_buff___80 *, struct genl_info___8 *);
	void (*post_doit)(const struct genl_ops___8 *, struct sk_buff___80 *, struct genl_info___8 *);
	const struct genl_ops___8 *ops;
	const struct genl_small_ops___8 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___254 *module;
};

struct genl_ops___8 {
	int (*doit)(struct sk_buff___80 *, struct genl_info___8 *);
	int (*start)(struct netlink_callback___79 *);
	int (*dumpit)(struct sk_buff___80 *, struct netlink_callback___79 *);
	int (*done)(struct netlink_callback___79 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___8 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___79 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___8 {
	int (*doit)(struct sk_buff___80 *, struct genl_info___8 *);
	int (*dumpit)(struct sk_buff___80 *, struct netlink_callback___79 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct tcp_fastopen_metrics {
	u16 mss;
	u16 syn_loss: 10;
	u16 try_exp: 2;
	long unsigned int last_syn_loss;
	struct tcp_fastopen_cookie cookie;
};

struct tcp_metrics_block {
	struct tcp_metrics_block *tcpm_next;
	possible_net_t___79 tcpm_net;
	struct inetpeer_addr tcpm_saddr;
	struct inetpeer_addr tcpm_daddr;
	long unsigned int tcpm_stamp;
	u32 tcpm_lock;
	u32 tcpm_vals[5];
	struct tcp_fastopen_metrics tcpm_fastopen;
	struct callback_head callback_head;
};

struct tcpm_hash_bucket {
	struct tcp_metrics_block *chain;
};

typedef struct bio_vec___183 skb_frag_t___29;

struct napi_gro_cb___4 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___76 *last;
};

struct offload_callbacks___3 {
	struct sk_buff___76 * (*gso_segment)(struct sk_buff___76 *, netdev_features_t);
	struct sk_buff___76 * (*gro_receive)(struct list_head *, struct sk_buff___76 *);
	int (*gro_complete)(struct sk_buff___76 *, int);
};

union tcp_word_hdr___3 {
	struct tcphdr___3 hdr;
	__be32 words[5];
};

struct net_offload___2 {
	struct offload_callbacks___3 callbacks;
	unsigned int flags;
};

struct inet_cork___11 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___35 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___11 {
	struct inet_cork___11 base;
	struct flowi fl;
};

struct ipv6_pinfo___11;

struct inet_sock___11 {
	struct sock___36 sk;
	struct ipv6_pinfo___11 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___11 cork;
};

struct ipv6_fl_socklist___11;

struct ipv6_pinfo___11 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___11 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___47 *pktoptions;
	struct sk_buff___47 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___11;

struct ipv6_fl_socklist___11 {
	struct ipv6_fl_socklist___11 *next;
	struct ip6_flowlabel___11 *fl;
	struct callback_head rcu;
};

struct ip6_flowlabel___11 {
	struct ip6_flowlabel___11 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___205 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___51 *fl_net;
};

struct rtable___18 {
	struct dst_entry___35 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct dentry___273;

struct super_block___273;

struct module___257;

struct file_system_type___273 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___273 * (*mount)(struct file_system_type___273 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___273 *);
	struct module___257 *owner;
	struct file_system_type___273 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___273;

struct kiocb___273;

struct iov_iter___193;

struct poll_table_struct___194;

struct vm_area_struct___278;

struct inode___273;

struct file_lock___273;

struct page___278;

struct pipe_inode_info___114;

struct seq_file___248;

struct file_operations___274 {
	struct module___257 *owner;
	loff_t (*llseek)(struct file___273 *, loff_t, int);
	ssize_t (*read)(struct file___273 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___273 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___273 *, struct iov_iter___193 *);
	ssize_t (*write_iter)(struct kiocb___273 *, struct iov_iter___193 *);
	int (*iopoll)(struct kiocb___273 *, bool);
	int (*iterate)(struct file___273 *, struct dir_context *);
	int (*iterate_shared)(struct file___273 *, struct dir_context *);
	__poll_t (*poll)(struct file___273 *, struct poll_table_struct___194 *);
	long int (*unlocked_ioctl)(struct file___273 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___273 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___273 *, struct vm_area_struct___278 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___273 *, struct file___273 *);
	int (*flush)(struct file___273 *, fl_owner_t);
	int (*release)(struct inode___273 *, struct file___273 *);
	int (*fsync)(struct file___273 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___273 *, int);
	int (*lock)(struct file___273 *, int, struct file_lock___273 *);
	ssize_t (*sendpage)(struct file___273 *, struct page___278 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___273 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___273 *, long unsigned int);
	int (*flock)(struct file___273 *, int, struct file_lock___273 *);
	ssize_t (*splice_write)(struct pipe_inode_info___114 *, struct file___273 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___273 *, loff_t *, struct pipe_inode_info___114 *, size_t, unsigned int);
	int (*setlease)(struct file___273 *, long int, struct file_lock___273 **, void **);
	long int (*fallocate)(struct file___273 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___248 *, struct file___273 *);
	ssize_t (*copy_file_range)(struct file___273 *, loff_t, struct file___273 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___273 *, loff_t, struct file___273 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___273 *, loff_t, loff_t, int);
};

struct vmacache___278 {
	u64 seqnum;
	struct vm_area_struct___278 *vmas[4];
};

struct page_frag___278 {
	struct page___278 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___279;

struct pid___250;

struct nsproxy___259;

struct signal_struct___274;

struct bio_list___164;

struct backing_dev_info___150;

struct io_context___164;

struct css_set___200;

struct mem_cgroup___138;

struct request_queue___164;

struct vm_struct___256;

struct task_struct___280 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___280 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___279 *mm;
	struct mm_struct___279 *active_mm;
	struct vmacache___278 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___280 *real_parent;
	struct task_struct___280 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___280 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___250 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___259 *nsproxy;
	struct signal_struct___274 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___280 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___164 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___150 *backing_dev_info;
	struct io_context___164 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___200 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___114 *splice_pipe;
	struct page_frag___278 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___138 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___138 *active_memcg;
	struct request_queue___164 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___280 *oom_reaper_list;
	struct vm_struct___256 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___261;

struct kobj_type___261;

struct kernfs_node___261;

struct kobject___261 {
	const char *name;
	struct list_head entry;
	struct kobject___261 *parent;
	struct kset___261 *kset;
	struct kobj_type___261 *ktype;
	struct kernfs_node___261 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___258 {
	struct kobject___261 kobj;
	struct module___257 *mod;
	struct kobject___261 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___257 {
	struct module___257 *mod;
	struct latch_tree_node node;
};

struct module_layout___257 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___257 mtn;
};

struct module_attribute___257;

struct kernel_param___257;

struct module___257 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___258 mkobj;
	struct module_attribute___257 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___261 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___257 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___257 core_layout;
	struct module_layout___257 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___250;

struct upid___250 {
	int nr;
	struct pid_namespace___250 *ns;
};

struct pid_namespace___250 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___280 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___250 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___250 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___250 numbers[1];
};

typedef struct page___278 *pgtable_t___278;

struct address_space___273;

struct page_pool___102;

struct dev_pagemap___268;

struct page___278 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___273 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___102 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___278 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___278 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___279 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___268 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___268;

struct vm_area_struct___278 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___278 *vm_next;
	struct vm_area_struct___278 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___279 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___268 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___273 *vm_file;
	struct file___273 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___274 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___280 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___280 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___250 *pids[4];
	struct pid___250 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___279 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___278;

struct mm_struct___279 {
	struct {
		struct vm_area_struct___278 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___273 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___278 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___280 *owner;
		struct user_namespace___26 *user_ns;
		struct file___273 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___87;

struct cgroup_namespace___200;

struct nsproxy___259 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___250 *pid_ns_for_children;
	struct net___87 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___200 *cgroup_ns;
};

struct bio___164;

struct bio_list___164 {
	struct bio___164 *head;
	struct bio___164 *tail;
};

struct cgroup_subsys_state___200;

struct bdi_writeback___150 {
	struct backing_dev_info___150 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___200 *memcg_css;
	struct cgroup_subsys_state___200 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___254;

struct backing_dev_info___150 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___150 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___254 *dev;
	char dev_name[64];
	struct device___254 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___273 *debug_dir;
};

struct io_cq___164;

struct io_context___164 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___164 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___200;

struct css_set___200 {
	struct cgroup_subsys_state___200 *subsys[14];
	refcount_t refcount;
	struct css_set___200 *dom_cset;
	struct cgroup___200 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___200 *mg_src_cgrp;
	struct cgroup___200 *mg_dst_cgrp;
	struct css_set___200 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___273;

struct pipe_buffer___114;

struct pipe_inode_info___114 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___278 *tmp_page;
	struct fasync_struct___273 *fasync_readers;
	struct fasync_struct___273 *fasync_writers;
	struct pipe_buffer___114 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___200;

struct cgroup_subsys_state___200 {
	struct cgroup___200 *cgroup;
	struct cgroup_subsys___200 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___200 *parent;
};

struct cgroup_file___200 {
	struct kernfs_node___261 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___138;

struct mem_cgroup_per_node___138;

struct mem_cgroup___138 {
	struct cgroup_subsys_state___200 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___200 events_file;
	struct cgroup_file___200 events_local_file;
	struct cgroup_file___200 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___138 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___280 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___138 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___164;

struct blk_integrity___164 {
	const struct blk_integrity_profile___164 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___164 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___164 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___164;

struct elevator_queue___164;

struct blk_mq_ops___159;

struct blk_mq_hw_ctx___159;

struct gendisk___167;

struct blkcg_gq___152;

struct blk_mq_tag_set___159;

struct request_queue___164 {
	struct request___164 *last_merge;
	struct elevator_queue___164 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___159 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___159 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___167 *disk;
	struct kobject___261 kobj;
	struct kobject___261 *mq_kobj;
	struct blk_integrity___164 integrity;
	struct device___254 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___152 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___159 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___164 bio_split;
	struct dentry___273 *debugfs_dir;
	struct dentry___273 *sched_debugfs_dir;
	struct dentry___273 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___256 {
	struct vm_struct___256 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___278 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___273;

struct address_space___273 {
	struct inode___273 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___273 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___102 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___254 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___102 {
	u32 count;
	struct page___278 *cache[128];
};

struct page_pool___102 {
	struct page_pool_params___102 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___278 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___102 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___268;

struct dev_pagemap___268 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___268 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___273;

struct path___273 {
	struct vfsmount___273 *mnt;
	struct dentry___273 *dentry;
};

struct fown_struct___250 {
	rwlock_t lock;
	struct pid___250 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___273 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___273 f_path;
	struct inode___273 *f_inode;
	const struct file_operations___274 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___250 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___273 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___268;

struct vm_operations_struct___268 {
	void (*open)(struct vm_area_struct___278 *);
	void (*close)(struct vm_area_struct___278 *);
	int (*may_split)(struct vm_area_struct___278 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___278 *);
	int (*mprotect)(struct vm_area_struct___278 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___268 *);
	vm_fault_t (*huge_fault)(struct vm_fault___268 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___268 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___278 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___268 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___268 *);
	int (*access)(struct vm_area_struct___278 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___278 *);
	int (*set_policy)(struct vm_area_struct___278 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___278 *, long unsigned int);
	struct page___278 * (*find_special_page)(struct vm_area_struct___278 *, long unsigned int);
};

struct core_thread___278 {
	struct task_struct___280 *task;
	struct core_thread___278 *next;
};

struct core_state___278 {
	atomic_t nr_threads;
	struct core_thread___278 dumper;
	struct completion startup;
};

struct vm_fault___268 {
	const struct {
		struct vm_area_struct___278 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___278 *cow_page;
	struct page___278 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___278 prealloc_pte;
};

struct pglist_data___146;

struct lruvec___146 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___146 *pgdat;
};

struct zone___146 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___146 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___146 {
	struct zone___146 *zone;
	int zone_idx;
};

struct zonelist___146 {
	struct zoneref___146 _zonerefs[321];
};

struct pglist_data___146 {
	struct zone___146 node_zones[5];
	struct zonelist___146 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___280 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___280 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___146 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct bio_vec___190 {
	struct page___278 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___193 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___190 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___114 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___71 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___193 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___273 *msg_iocb;
};

struct kiocb___273 {
	struct file___273 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___273 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___115 *ki_waitq;
	};
};

struct dentry_operations___273;

struct dentry___273 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___273 *d_parent;
	struct qstr d_name;
	struct inode___273 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___273 *d_op;
	struct super_block___273 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___273;

struct inode___273 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___273 *i_op;
	struct super_block___273 *i_sb;
	struct address_space___273 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___150 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___274 *i_fop;
		void (*free_inode)(struct inode___273 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___273 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___114 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___273 {
	int (*d_revalidate)(struct dentry___273 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___273 *, unsigned int);
	int (*d_hash)(const struct dentry___273 *, struct qstr *);
	int (*d_compare)(const struct dentry___273 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___273 *);
	int (*d_init)(struct dentry___273 *);
	void (*d_release)(struct dentry___273 *);
	void (*d_prune)(struct dentry___273 *);
	void (*d_iput)(struct dentry___273 *, struct inode___273 *);
	char * (*d_dname)(struct dentry___273 *, char *, int);
	struct vfsmount___273 * (*d_automount)(struct path___273 *);
	int (*d_manage)(const struct path___273 *, bool);
	struct dentry___273 * (*d_real)(struct dentry___273 *, const struct inode___273 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___273;

struct mem_dqinfo___273 {
	struct quota_format_type___273 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___273;

struct quota_info___273 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___273 *files[3];
	struct mem_dqinfo___273 info[3];
	const struct quota_format_ops___273 *ops[3];
};

struct rcuwait___274 {
	struct task_struct___280 *task;
};

struct percpu_rw_semaphore___274 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___274 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___273 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___274 rw_sem[3];
};

struct shrink_control___138;

struct shrinker___138 {
	long unsigned int (*count_objects)(struct shrinker___138 *, struct shrink_control___138 *);
	long unsigned int (*scan_objects)(struct shrinker___138 *, struct shrink_control___138 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___273;

struct dquot_operations___273;

struct quotactl_ops___273;

struct block_device___167;

struct super_block___273 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___273 *s_type;
	const struct super_operations___273 *s_op;
	const struct dquot_operations___273 *dq_op;
	const struct quotactl_ops___273 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___273 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___167 *s_bdev;
	struct backing_dev_info___150 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___273 s_dquot;
	struct sb_writers___273 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___273 *s_d_op;
	int cleancache_poolid;
	struct shrinker___138 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___273 {
	struct dentry___273 *mnt_root;
	struct super_block___273 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___138 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___138 *memcg;
};

struct psi_group___200 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___280 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___76;

struct cgroup_bpf___76 {
	struct bpf_prog_array___76 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___76 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___200;

struct cgroup_rstat_cpu___200;

struct cgroup___200 {
	struct cgroup_subsys_state___200 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___261 *kn;
	struct cgroup_file___200 procs_file;
	struct cgroup_file___200 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___200 *subsys[14];
	struct cgroup_root___200 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___200 *dom_cgrp;
	struct cgroup___200 *old_dom_cgrp;
	struct cgroup_rstat_cpu___200 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___200 psi;
	struct cgroup_bpf___76 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___164 {
	struct request_queue___164 *q;
	struct io_context___164 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___273 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___273 *ia_file;
};

struct dquot___273 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___273 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___273 {
	int qf_fmt_id;
	const struct quota_format_ops___273 *qf_ops;
	struct module___257 *qf_owner;
	struct quota_format_type___273 *qf_next;
};

struct quota_format_ops___273 {
	int (*check_quota_file)(struct super_block___273 *, int);
	int (*read_file_info)(struct super_block___273 *, int);
	int (*write_file_info)(struct super_block___273 *, int);
	int (*free_file_info)(struct super_block___273 *, int);
	int (*read_dqblk)(struct dquot___273 *);
	int (*commit_dqblk)(struct dquot___273 *);
	int (*release_dqblk)(struct dquot___273 *);
	int (*get_next_id)(struct super_block___273 *, struct kqid *);
};

struct dquot_operations___273 {
	int (*write_dquot)(struct dquot___273 *);
	struct dquot___273 * (*alloc_dquot)(struct super_block___273 *, int);
	void (*destroy_dquot)(struct dquot___273 *);
	int (*acquire_dquot)(struct dquot___273 *);
	int (*release_dquot)(struct dquot___273 *);
	int (*mark_dirty)(struct dquot___273 *);
	int (*write_info)(struct super_block___273 *, int);
	qsize_t * (*get_reserved_space)(struct inode___273 *);
	int (*get_projid)(struct inode___273 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___273 *, qsize_t *);
	int (*get_next_id)(struct super_block___273 *, struct kqid *);
};

struct quotactl_ops___273 {
	int (*quota_on)(struct super_block___273 *, int, int, const struct path___273 *);
	int (*quota_off)(struct super_block___273 *, int);
	int (*quota_enable)(struct super_block___273 *, unsigned int);
	int (*quota_disable)(struct super_block___273 *, unsigned int);
	int (*quota_sync)(struct super_block___273 *, int);
	int (*set_info)(struct super_block___273 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___273 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___273 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___273 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___273 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___273 *, unsigned int);
};

struct writeback_control___150;

struct address_space_operations___273 {
	int (*writepage)(struct page___278 *, struct writeback_control___150 *);
	int (*readpage)(struct file___273 *, struct page___278 *);
	int (*writepages)(struct address_space___273 *, struct writeback_control___150 *);
	int (*set_page_dirty)(struct page___278 *);
	int (*readpages)(struct file___273 *, struct address_space___273 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___273 *, struct address_space___273 *, loff_t, unsigned int, unsigned int, struct page___278 **, void **);
	int (*write_end)(struct file___273 *, struct address_space___273 *, loff_t, unsigned int, unsigned int, struct page___278 *, void *);
	sector_t (*bmap)(struct address_space___273 *, sector_t);
	void (*invalidatepage)(struct page___278 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___278 *, gfp_t);
	void (*freepage)(struct page___278 *);
	ssize_t (*direct_IO)(struct kiocb___273 *, struct iov_iter___193 *);
	int (*migratepage)(struct address_space___273 *, struct page___278 *, struct page___278 *, enum migrate_mode);
	bool (*isolate_page)(struct page___278 *, isolate_mode_t);
	void (*putback_page)(struct page___278 *);
	int (*launder_page)(struct page___278 *);
	int (*is_partially_uptodate)(struct page___278 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___278 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___273 *, struct page___278 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___273 *, sector_t *);
	void (*swap_deactivate)(struct file___273 *);
};

struct writeback_control___150 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___150 *wb;
	struct inode___273 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___273 {
	struct dentry___273 * (*lookup)(struct inode___273 *, struct dentry___273 *, unsigned int);
	const char * (*get_link)(struct dentry___273 *, struct inode___273 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___273 *, int);
	struct posix_acl * (*get_acl)(struct inode___273 *, int, bool);
	int (*readlink)(struct dentry___273 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___273 *, struct dentry___273 *, umode_t, bool);
	int (*link)(struct dentry___273 *, struct inode___273 *, struct dentry___273 *);
	int (*unlink)(struct inode___273 *, struct dentry___273 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___273 *, struct dentry___273 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___273 *, struct dentry___273 *, umode_t);
	int (*rmdir)(struct inode___273 *, struct dentry___273 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___273 *, struct dentry___273 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___273 *, struct dentry___273 *, struct inode___273 *, struct dentry___273 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___273 *, struct iattr___273 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___273 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___273 *, char *, size_t);
	int (*fiemap)(struct inode___273 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___273 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___273 *, struct dentry___273 *, struct file___273 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___273 *, struct dentry___273 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___273 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___273 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___273 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___273 {
	void (*fl_copy_lock)(struct file_lock___273 *, struct file_lock___273 *);
	void (*fl_release_private)(struct file_lock___273 *);
};

struct lock_manager_operations___273;

struct file_lock___273 {
	struct file_lock___273 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___273 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___273 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___273 *fl_ops;
	const struct lock_manager_operations___273 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___273 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___273 *);
	int (*lm_grant)(struct file_lock___273 *, int);
	bool (*lm_break)(struct file_lock___273 *);
	int (*lm_change)(struct file_lock___273 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___273 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___273 *);
};

struct fasync_struct___273 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___273 *fa_next;
	struct file___273 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___273 {
	struct inode___273 * (*alloc_inode)(struct super_block___273 *);
	void (*destroy_inode)(struct inode___273 *);
	void (*free_inode)(struct inode___273 *);
	void (*dirty_inode)(struct inode___273 *, int);
	int (*write_inode)(struct inode___273 *, struct writeback_control___150 *);
	int (*drop_inode)(struct inode___273 *);
	void (*evict_inode)(struct inode___273 *);
	void (*put_super)(struct super_block___273 *);
	int (*sync_fs)(struct super_block___273 *, int);
	int (*freeze_super)(struct super_block___273 *);
	int (*freeze_fs)(struct super_block___273 *);
	int (*thaw_super)(struct super_block___273 *);
	int (*unfreeze_fs)(struct super_block___273 *);
	int (*statfs)(struct dentry___273 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___273 *, int *, char *);
	void (*umount_begin)(struct super_block___273 *);
	int (*show_options)(struct seq_file___248 *, struct dentry___273 *);
	int (*show_devname)(struct seq_file___248 *, struct dentry___273 *);
	int (*show_path)(struct seq_file___248 *, struct dentry___273 *);
	int (*show_stats)(struct seq_file___248 *, struct dentry___273 *);
	ssize_t (*quota_read)(struct super_block___273 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___273 *, int, const char *, size_t, loff_t);
	struct dquot___273 ** (*get_dquots)(struct inode___273 *);
	long int (*nr_cached_objects)(struct super_block___273 *, struct shrink_control___138 *);
	long int (*free_cached_objects)(struct super_block___273 *, struct shrink_control___138 *);
	struct file___273 * (*real_loop)(struct file___273 *);
};

struct wakeup_source___254;

struct dev_pm_info___254 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___254 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___254 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___254;

struct bus_type___254;

struct device_driver___254;

struct dev_pm_domain___254;

struct fwnode_handle___250;

struct class___254;

struct attribute_group___261;

struct device___254 {
	struct kobject___261 kobj;
	struct device___254 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___254 *type;
	struct bus_type___254 *bus;
	struct device_driver___254 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___254 power;
	struct dev_pm_domain___254 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___250 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___254 *class;
	const struct attribute_group___261 **groups;
	void (*release)(struct device___254 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___167 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___273 *bd_inode;
	struct super_block___273 *bd_super;
	void *bd_claiming;
	struct device___254 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___261 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___167 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___273 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___202)(struct file___273 *, wait_queue_head_t *, struct poll_table_struct___194 *);

struct poll_table_struct___194 {
	poll_queue_proc___202 _qproc;
	__poll_t _key;
};

struct seq_operations___248;

struct seq_file___248 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___248 *op;
	int poll_event;
	const struct file___273 *file;
	void *private;
};

typedef void bio_end_io_t___164(struct bio___164 *);

struct bio_integrity_payload___164;

struct bio___164 {
	struct bio___164 *bi_next;
	struct block_device___167 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___164 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___152 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___164 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___190 *bi_io_vec;
	struct bio_set___164 *bi_pool;
	struct bio_vec___190 bi_inline_vecs[0];
};

struct dev_pagemap_ops___268 {
	void (*page_free)(struct page___278 *);
	void (*kill)(struct dev_pagemap___268 *);
	void (*cleanup)(struct dev_pagemap___268 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___268 *);
};

struct fwnode_operations___250;

struct fwnode_handle___250 {
	struct fwnode_handle___250 *secondary;
	const struct fwnode_operations___250 *ops;
	struct device___254 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___250;

struct fwnode_endpoint___250;

struct fwnode_operations___250 {
	struct fwnode_handle___250 * (*get)(struct fwnode_handle___250 *);
	void (*put)(struct fwnode_handle___250 *);
	bool (*device_is_available)(const struct fwnode_handle___250 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___250 *, const struct device___254 *);
	bool (*property_present)(const struct fwnode_handle___250 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___250 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___250 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___250 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*get_parent)(const struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*get_next_child_node)(const struct fwnode_handle___250 *, struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*get_named_child_node)(const struct fwnode_handle___250 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___250 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___250 *);
	struct fwnode_handle___250 * (*graph_get_next_endpoint)(const struct fwnode_handle___250 *, struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*graph_get_remote_endpoint)(const struct fwnode_handle___250 *);
	struct fwnode_handle___250 * (*graph_get_port_parent)(struct fwnode_handle___250 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___250 *, struct fwnode_endpoint___250 *);
	int (*add_links)(struct fwnode_handle___250 *);
};

struct fwnode_endpoint___250 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___250 *local_fwnode;
};

struct fwnode_reference_args___250 {
	struct fwnode_handle___250 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___261;

struct kernfs_elem_dir___261 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___261 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___261;

struct kernfs_root___261 {
	struct kernfs_node___261 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___261 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___261 {
	struct kernfs_node___261 *target_kn;
};

struct kernfs_ops___261;

struct kernfs_elem_attr___261 {
	const struct kernfs_ops___261 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___261 *notify_next;
};

struct kernfs_node___261 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___261 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___261 dir;
		struct kernfs_elem_symlink___261 symlink;
		struct kernfs_elem_attr___261 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___261;

struct kernfs_ops___261 {
	int (*open)(struct kernfs_open_file___261 *);
	void (*release)(struct kernfs_open_file___261 *);
	int (*seq_show)(struct seq_file___248 *, void *);
	void * (*seq_start)(struct seq_file___248 *, loff_t *);
	void * (*seq_next)(struct seq_file___248 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___248 *, void *);
	ssize_t (*read)(struct kernfs_open_file___261 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___261 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___261 *, struct poll_table_struct___194 *);
	int (*mmap)(struct kernfs_open_file___261 *, struct vm_area_struct___278 *);
};

struct kernfs_syscall_ops___261 {
	int (*show_options)(struct seq_file___248 *, struct kernfs_root___261 *);
	int (*mkdir)(struct kernfs_node___261 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___261 *);
	int (*rename)(struct kernfs_node___261 *, struct kernfs_node___261 *, const char *);
	int (*show_path)(struct seq_file___248 *, struct kernfs_node___261 *, struct kernfs_root___261 *);
};

struct kernfs_open_file___261 {
	struct kernfs_node___261 *kn;
	struct file___273 *file;
	struct seq_file___248 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___268 *vm_ops;
};

struct sock___69;

struct kobj_ns_type_operations___69 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___69 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___87 *net;
} possible_net_t___82;

struct proto___69;

struct sock_common___69 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___69 *skc_prot;
	possible_net_t___82 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___69 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___83;

struct sk_buff_head___82 {
	struct sk_buff___83 *next;
	struct sk_buff___83 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___69 {
	struct cgroup___200 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___69;

struct socket_wq___70;

struct xfrm_policy___13;

struct dst_entry___69;

struct socket___71;

struct net_device___82;

struct sock___69 {
	struct sock_common___69 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___82 sk_error_queue;
	struct sk_buff___83 *sk_rx_skb_cache;
	struct sk_buff_head___82 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___83 *head;
		struct sk_buff___83 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___69 *sk_filter;
	union {
		struct socket_wq___70 *sk_wq;
		struct socket_wq___70 *sk_wq_raw;
	};
	struct xfrm_policy___13 *sk_policy[2];
	struct dst_entry___69 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___69 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___83 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___83 *sk_tx_skb_cache;
	struct sk_buff_head___82 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___278 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___69 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___250 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___71 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___69 sk_cgrp_data;
	struct mem_cgroup___138 *sk_memcg;
	void (*sk_state_change)(struct sock___69 *);
	void (*sk_data_ready)(struct sock___69 *);
	void (*sk_write_space)(struct sock___69 *);
	void (*sk_error_report)(struct sock___69 *);
	int (*sk_backlog_rcv)(struct sock___69 *, struct sk_buff___83 *);
	struct sk_buff___83 * (*sk_validate_xmit_skb)(struct sock___69 *, struct net_device___82 *, struct sk_buff___83 *);
	void (*sk_destruct)(struct sock___69 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___261;

struct attribute_group___261 {
	const char *name;
	umode_t (*is_visible)(struct kobject___261 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___261 *, struct bin_attribute___261 *, int);
	struct attribute **attrs;
	struct bin_attribute___261 **bin_attrs;
};

struct bin_attribute___261 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___273 * (*f_mapping)();
	ssize_t (*read)(struct file___273 *, struct kobject___261 *, struct bin_attribute___261 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___273 *, struct kobject___261 *, struct bin_attribute___261 *, char *, loff_t, size_t);
	int (*mmap)(struct file___273 *, struct kobject___261 *, struct bin_attribute___261 *, struct vm_area_struct___278 *);
};

struct sysfs_ops___261 {
	ssize_t (*show)(struct kobject___261 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___261 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___261;

struct kset___261 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___261 kobj;
	const struct kset_uevent_ops___261 *uevent_ops;
};

struct kobj_type___261 {
	void (*release)(struct kobject___261 *);
	const struct sysfs_ops___261 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___261 **default_groups;
	const struct kobj_ns_type_operations___69 * (*child_ns_type)(struct kobject___261 *);
	const void * (*namespace)(struct kobject___261 *);
	void (*get_ownership)(struct kobject___261 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___261 {
	int (* const filter)(struct kset___261 *, struct kobject___261 *);
	const char * (* const name)(struct kset___261 *, struct kobject___261 *);
	int (* const uevent)(struct kset___261 *, struct kobject___261 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___257 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___257 *);
	int (*get)(char *, const struct kernel_param___257 *);
	void (*free)(void *);
};

struct kparam_array___257;

struct kernel_param___257 {
	const char *name;
	struct module___257 *mod;
	const struct kernel_param_ops___257 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___257 *arr;
	};
};

struct kparam_array___257 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___257 *ops;
	void *elem;
};

struct module_attribute___257 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___257 *, struct module_kobject___258 *, char *);
	ssize_t (*store)(struct module_attribute___257 *, struct module_kobject___258 *, const char *, size_t);
	void (*setup)(struct module___257 *, const char *);
	int (*test)(struct module___257 *);
	void (*free)(struct module___257 *);
};

struct ip_ra_chain___42;

struct fib_rules_ops___69;

struct fqdir___87;

struct fib_notifier_ops___69;

struct netns_ipv4___87 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___42 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___69 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___69 *fibnl;
	struct sock___69 **icmp_sk;
	struct sock___69 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___69 **tcp_sk;
	struct fqdir___87 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___69 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___69 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___69 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___69;

struct dst_ops___87 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___87 *);
	struct dst_entry___69 * (*check)(struct dst_entry___69 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___69 *);
	unsigned int (*mtu)(const struct dst_entry___69 *);
	u32 * (*cow_metrics)(struct dst_entry___69 *, long unsigned int);
	void (*destroy)(struct dst_entry___69 *);
	void (*ifdown)(struct dst_entry___69 *, struct net_device___82 *, int);
	struct dst_entry___69 * (*negative_advice)(struct dst_entry___69 *);
	void (*link_failure)(struct sk_buff___83 *);
	void (*update_pmtu)(struct dst_entry___69 *, struct sock___69 *, struct sk_buff___83 *, u32, bool);
	void (*redirect)(struct dst_entry___69 *, struct sock___69 *, struct sk_buff___83 *);
	int (*local_out)(struct net___87 *, struct sock___69 *, struct sk_buff___83 *);
	struct neighbour___69 * (*neigh_lookup)(const struct dst_entry___69 *, struct sk_buff___83 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___69 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___18;

struct rt6_info___18;

struct fib6_table___18;

struct netns_ipv6___87 {
	struct dst_ops___87 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___87 *fqdir;
	struct fib6_info___18 *fib6_null_entry;
	struct rt6_info___18 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___18 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___18 *ip6_prohibit_entry;
	struct rt6_info___18 *ip6_blk_hole_entry;
	struct fib6_table___18 *fib6_local_tbl;
	struct fib_rules_ops___69 *fib6_rules_ops;
	struct sock___69 **icmp_sk;
	struct sock___69 *ndisc_sk;
	struct sock___69 *tcp_sk;
	struct sock___69 *igmp_sk;
	struct sock___69 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___69 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___69 *notifier_ops;
	struct fib_notifier_ops___69 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___87 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___87 *fqdir;
};

struct netns_sctp___69 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___69 *ctl_sock;
	struct sock___69 *udp4_sock;
	struct sock___69 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___11;

struct netns_nf___11 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___11 *hooks_ipv4[5];
	struct nf_hook_entries___11 *hooks_ipv6[5];
	struct nf_hook_entries___11 *hooks_arp[3];
	struct nf_hook_entries___11 *hooks_bridge[5];
	struct nf_hook_entries___11 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___76;

struct netns_bpf___76 {
	struct bpf_prog_array___76 *run_array[2];
	struct bpf_prog___76 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___87 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___69 *nlsk;
	struct sock___69 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___87 xfrm4_dst_ops;
	struct dst_ops___87 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___87 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___69 *rtnl;
	struct sock___69 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___82 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___87 ipv4;
	struct netns_ipv6___87 ipv6;
	struct netns_ieee802154_lowpan___87 ieee802154_lowpan;
	struct netns_sctp___69 sctp;
	struct netns_nf___11 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___82 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___76 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___87 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___69 *crypto_nlsk;
	struct sock___69 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___200 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___200 *root_cset;
};

struct socket_wq___70 {
	wait_queue_head_t wait;
	struct fasync_struct___273 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___70;

struct socket___71 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___273 *file;
	struct sock___69 *sk;
	const struct proto_ops___70 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___70 wq;
};

typedef int (*sk_read_actor_t___69)(read_descriptor_t *, struct sk_buff___83 *, unsigned int, size_t);

struct proto_ops___70 {
	int family;
	struct module___257 *owner;
	int (*release)(struct socket___71 *);
	int (*bind)(struct socket___71 *, struct sockaddr *, int);
	int (*connect)(struct socket___71 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___71 *, struct socket___71 *);
	int (*accept)(struct socket___71 *, struct socket___71 *, int, bool);
	int (*getname)(struct socket___71 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___273 *, struct socket___71 *, struct poll_table_struct___194 *);
	int (*ioctl)(struct socket___71 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___71 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___71 *, void *, bool, bool);
	int (*listen)(struct socket___71 *, int);
	int (*shutdown)(struct socket___71 *, int);
	int (*setsockopt)(struct socket___71 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___71 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___248 *, struct socket___71 *);
	int (*sendmsg)(struct socket___71 *, struct msghdr___71 *, size_t);
	int (*recvmsg)(struct socket___71 *, struct msghdr___71 *, size_t, int);
	int (*mmap)(struct file___273 *, struct socket___71 *, struct vm_area_struct___278 *);
	ssize_t (*sendpage)(struct socket___71 *, struct page___278 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___71 *, loff_t *, struct pipe_inode_info___114 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___69 *, int);
	int (*peek_len)(struct socket___71 *);
	int (*read_sock)(struct sock___69 *, read_descriptor_t *, sk_read_actor_t___69);
	int (*sendpage_locked)(struct sock___69 *, struct page___278 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___69 *, struct msghdr___71 *, size_t);
	int (*set_rcvlowat)(struct sock___69 *, int);
};

struct sk_buff___83 {
	union {
		struct {
			struct sk_buff___83 *next;
			struct sk_buff___83 *prev;
			union {
				struct net_device___82 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___69 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___83 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___254 {
	int (*prepare)(struct device___254 *);
	void (*complete)(struct device___254 *);
	int (*suspend)(struct device___254 *);
	int (*resume)(struct device___254 *);
	int (*freeze)(struct device___254 *);
	int (*thaw)(struct device___254 *);
	int (*poweroff)(struct device___254 *);
	int (*restore)(struct device___254 *);
	int (*suspend_late)(struct device___254 *);
	int (*resume_early)(struct device___254 *);
	int (*freeze_late)(struct device___254 *);
	int (*thaw_early)(struct device___254 *);
	int (*poweroff_late)(struct device___254 *);
	int (*restore_early)(struct device___254 *);
	int (*suspend_noirq)(struct device___254 *);
	int (*resume_noirq)(struct device___254 *);
	int (*freeze_noirq)(struct device___254 *);
	int (*thaw_noirq)(struct device___254 *);
	int (*poweroff_noirq)(struct device___254 *);
	int (*restore_noirq)(struct device___254 *);
	int (*runtime_suspend)(struct device___254 *);
	int (*runtime_resume)(struct device___254 *);
	int (*runtime_idle)(struct device___254 *);
};

struct wakeup_source___254 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___254 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___254 {
	struct dev_pm_ops___254 ops;
	int (*start)(struct device___254 *);
	void (*detach)(struct device___254 *, bool);
	int (*activate)(struct device___254 *);
	void (*sync)(struct device___254 *);
	void (*dismiss)(struct device___254 *);
};

struct bus_type___254 {
	const char *name;
	const char *dev_name;
	struct device___254 *dev_root;
	const struct attribute_group___261 **bus_groups;
	const struct attribute_group___261 **dev_groups;
	const struct attribute_group___261 **drv_groups;
	int (*match)(struct device___254 *, struct device_driver___254 *);
	int (*uevent)(struct device___254 *, struct kobj_uevent_env *);
	int (*probe)(struct device___254 *);
	void (*sync_state)(struct device___254 *);
	void (*remove)(struct device___254 *);
	void (*shutdown)(struct device___254 *);
	int (*online)(struct device___254 *);
	int (*offline)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	int (*num_vf)(struct device___254 *);
	int (*dma_configure)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___254 {
	const char *name;
	struct bus_type___254 *bus;
	struct module___257 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___254 *);
	void (*sync_state)(struct device___254 *);
	int (*remove)(struct device___254 *);
	void (*shutdown)(struct device___254 *);
	int (*suspend)(struct device___254 *, pm_message_t);
	int (*resume)(struct device___254 *);
	const struct attribute_group___261 **groups;
	const struct attribute_group___261 **dev_groups;
	const struct dev_pm_ops___254 *pm;
	void (*coredump)(struct device___254 *);
	struct driver_private *p;
};

struct device_type___254 {
	const char *name;
	const struct attribute_group___261 **groups;
	int (*uevent)(struct device___254 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___254 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___254 *);
	const struct dev_pm_ops___254 *pm;
};

struct class___254 {
	const char *name;
	struct module___257 *owner;
	const struct attribute_group___261 **class_groups;
	const struct attribute_group___261 **dev_groups;
	struct kobject___261 *dev_kobj;
	int (*dev_uevent)(struct device___254 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___254 *, umode_t *);
	void (*class_release)(struct class___254 *);
	void (*dev_release)(struct device___254 *);
	int (*shutdown_pre)(struct device___254 *);
	const struct kobj_ns_type_operations___69 *ns_type;
	const void * (*namespace)(struct device___254 *);
	void (*get_ownership)(struct device___254 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___254 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___114;

struct pipe_buffer___114 {
	struct page___278 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___114 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___114 {
	int (*confirm)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
	void (*release)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
	bool (*try_steal)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
	bool (*get)(struct pipe_inode_info___114 *, struct pipe_buffer___114 *);
};

typedef rx_handler_result_t rx_handler_func_t___82(struct sk_buff___83 **);

struct bpf_xdp_entity___76 {
	struct bpf_prog___76 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___82;

struct net_device_ops___82;

struct l3mdev_ops___69;

struct ndisc_ops___51;

struct xfrmdev_ops___82;

struct header_ops___82;

struct inet6_dev___51;

struct netdev_rx_queue___82;

struct mini_Qdisc___76;

struct netdev_queue___82;

struct Qdisc___76;

struct rtnl_link_ops___76;

struct dcbnl_rtnl_ops___82;

struct net_device___82 {
	char name[16];
	struct netdev_name_node___82 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___82 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___69 *l3mdev_ops;
	const struct ndisc_ops___51 *ndisc_ops;
	const struct xfrmdev_ops___82 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___82 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___261 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___51 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___82 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___76 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___82 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___76 *miniq_ingress;
	struct netdev_queue___82 *ingress_queue;
	struct nf_hook_entries___11 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___82 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___76 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___76 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___82 = 0,
		NETREG_REGISTERED___82 = 1,
		NETREG_UNREGISTERING___82 = 2,
		NETREG_UNREGISTERED___82 = 3,
		NETREG_RELEASED___82 = 4,
		NETREG_DUMMY___82 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___82 = 0,
		RTNL_LINK_INITIALIZING___82 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___82 *);
	struct netpoll_info *npinfo;
	possible_net_t___82 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___254 dev;
	const struct attribute_group___261 *sysfs_groups[4];
	const struct attribute_group___261 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___76 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___82 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___76 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___190 skb_frag_t___30;

struct skb_shared_info___28 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___83 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___30 frags[17];
};

struct inet_frags___87;

struct fqdir___87 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___87 *f;
	struct net___87 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___87;

struct inet_frags___87 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___87 *, const void *);
	void (*destructor)(struct inet_frag_queue___87 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___87 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___83 *fragments_tail;
	struct sk_buff___83 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___87 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___42 {
	struct ip_ra_chain___42 *next;
	struct sock___69 *sk;
	union {
		void (*destructor)(struct sock___69 *);
		struct sock___69 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___69;

struct fib_lookup_arg___69;

struct fib_rules_ops___69 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___69 *, struct flowi *, int, struct fib_lookup_arg___69 *);
	bool (*suppress)(struct fib_rule___69 *, int, struct fib_lookup_arg___69 *);
	int (*match)(struct fib_rule___69 *, struct flowi *, int);
	int (*configure)(struct fib_rule___69 *, struct sk_buff___83 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___69 *);
	int (*compare)(struct fib_rule___69 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___69 *, struct sk_buff___83 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___69 *);
	void (*flush_cache)(struct fib_rules_ops___69 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___257 *owner;
	struct net___87 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___69 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___87 *);
	int (*fib_dump)(struct net___87 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___257 *owner;
	struct callback_head rcu;
};

struct xfrm_state___13;

struct lwtunnel_state___45;

struct dst_entry___69 {
	struct net_device___82 *dev;
	struct dst_ops___87 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___13 *xfrm;
	int (*input)(struct sk_buff___83 *);
	int (*output)(struct net___87 *, struct sock___69 *, struct sk_buff___83 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___45 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___69;

struct neigh_parms___69;

struct neigh_ops___69;

struct neighbour___69 {
	struct neighbour___69 *next;
	struct neigh_table___69 *tbl;
	struct neigh_parms___69 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___82 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___69 *, struct sk_buff___83 *);
	const struct neigh_ops___69 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___82 *dev;
	u8 primary_key[0];
};

struct rtable___19;

struct fnhe_hash_bucket___18;

struct fib_nh_common___18 {
	struct net_device___82 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___45 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___19 **nhc_pcpu_rth_output;
	struct rtable___19 *nhc_rth_input;
	struct fnhe_hash_bucket___18 *nhc_exceptions;
};

struct fib6_nh___18 {
	struct fib_nh_common___18 nh_common;
	long unsigned int last_probe;
	struct rt6_info___18 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___18;

struct fib6_info___18 {
	struct fib6_table___18 *fib6_table;
	struct fib6_info___18 *fib6_next;
	struct fib6_node___18 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___18 fib6_nh[0];
};

struct rt6_info___18 {
	struct dst_entry___69 dst;
	struct fib6_info___18 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___51 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___18 {
	struct fib6_node___18 *parent;
	struct fib6_node___18 *left;
	struct fib6_node___18 *right;
	struct fib6_node___18 *subtree;
	struct fib6_info___18 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___18 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___18 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___18 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___11;

typedef unsigned int nf_hookfn___13(void *, struct sk_buff___83 *, const struct nf_hook_state___11 *);

struct nf_hook_entry___11 {
	nf_hookfn___13 *hook;
	void *priv;
};

struct nf_hook_entries___11 {
	u16 num_hook_entries;
	struct nf_hook_entry___11 hooks[0];
};

struct bpf_prog_array_item___76 {
	struct bpf_prog___76 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___76 {
	struct callback_head rcu;
	struct bpf_prog_array_item___76 items[0];
};

struct bpf_prog_aux___85;

struct bpf_prog___76 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___85 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___248 {
	void * (*start)(struct seq_file___248 *, loff_t *);
	void (*stop)(struct seq_file___248 *, void *);
	void * (*next)(struct seq_file___248 *, void *, loff_t *);
	int (*show)(struct seq_file___248 *, void *);
};

struct seq_net_private___7 {
	struct net___87 *net;
};

struct pernet_operations___23 {
	struct list_head list;
	int (*init)(struct net___87 *);
	void (*pre_exit)(struct net___87 *);
	void (*exit)(struct net___87 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___82 {
	int (*ieee_getets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___82 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___82 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___82 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___82 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___82 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___82 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___82 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___82 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___82 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___82 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___82 *);
	u8 (*setstate)(struct net_device___82 *, u8);
	void (*getpermhwaddr)(struct net_device___82 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___82 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___82 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___82 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___82 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___82 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___82 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___82 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___82 *, int, u8 *);
	void (*setpfccfg)(struct net_device___82 *, int, u8);
	void (*getpfccfg)(struct net_device___82 *, int, u8 *);
	u8 (*setall)(struct net_device___82 *);
	u8 (*getcap)(struct net_device___82 *, int, u8 *);
	int (*getnumtcs)(struct net_device___82 *, int, u8 *);
	int (*setnumtcs)(struct net_device___82 *, int, u8);
	u8 (*getpfcstate)(struct net_device___82 *);
	void (*setpfcstate)(struct net_device___82 *, u8);
	void (*getbcncfg)(struct net_device___82 *, int, u32 *);
	void (*setbcncfg)(struct net_device___82 *, int, u32);
	void (*getbcnrp)(struct net_device___82 *, int, u8 *);
	void (*setbcnrp)(struct net_device___82 *, int, u8);
	int (*setapp)(struct net_device___82 *, u8, u16, u8);
	int (*getapp)(struct net_device___82 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___82 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___82 *, int, u8);
	u8 (*getdcbx)(struct net_device___82 *);
	u8 (*setdcbx)(struct net_device___82 *, u8);
	int (*peer_getappinfo)(struct net_device___82 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___82 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___82 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___82 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___82 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___82 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___85;

typedef int (*bpf_iter_init_seq_priv_t___84)(void *, struct bpf_iter_aux_info___85 *);

struct bpf_map___85;

struct bpf_iter_aux_info___85 {
	struct bpf_map___85 *map;
};

struct bpf_iter_seq_info___84 {
	const struct seq_operations___248 *seq_ops;
	bpf_iter_init_seq_priv_t___84 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___84 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___85 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___85 *, struct file___273 *);
	void (*map_free)(struct bpf_map___85 *);
	int (*map_get_next_key)(struct bpf_map___85 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___85 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___85 *, void *);
	int (*map_lookup_batch)(struct bpf_map___85 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___85 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___85 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___85 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___85 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___85 *, void *);
	int (*map_update_elem)(struct bpf_map___85 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___85 *, void *);
	int (*map_push_elem)(struct bpf_map___85 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___85 *, void *);
	int (*map_peek_elem)(struct bpf_map___85 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___85 *, struct file___273 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___85 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___85 *, void *, struct seq_file___248 *);
	int (*map_check_btf)(const struct bpf_map___85 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___85 *, struct bpf_prog_aux___85 *);
	void (*map_poke_untrack)(struct bpf_map___85 *, struct bpf_prog_aux___85 *);
	void (*map_poke_run)(struct bpf_map___85 *, u32, struct bpf_prog___76 *, struct bpf_prog___76 *);
	int (*map_direct_value_addr)(const struct bpf_map___85 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___85 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___85 *, struct vm_area_struct___278 *);
	__poll_t (*map_poll)(struct bpf_map___85 *, struct file___273 *, struct poll_table_struct___194 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___85 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___85 *, const struct bpf_map___85 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___85 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___84 *iter_seq_info;
};

struct bpf_map___85 {
	const struct bpf_map_ops___84 *ops;
	struct bpf_map___85 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___138 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___84;

struct bpf_jit_poke_descriptor___84;

struct bpf_prog_ops___76;

struct btf_mod_pair___84;

struct bpf_prog_offload___82;

struct bpf_prog_aux___85 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___76 *dst_prog;
	struct bpf_trampoline___84 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___76 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___84 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___76 *ops;
	struct bpf_map___85 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___84 *used_btfs;
	struct bpf_prog___76 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___85 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___82 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___82;

struct bpf_map_dev_ops___82 {
	int (*map_get_next_key)(struct bpf_offloaded_map___82 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___82 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___82 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___82 *, void *);
};

struct bpf_offloaded_map___82 {
	struct bpf_map___85 map;
	struct net_device___82 *netdev;
	const struct bpf_map_dev_ops___82 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___76 {
	int (*test_run)(struct bpf_prog___76 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___82 {
	struct bpf_prog___76 *prog;
	struct net_device___82 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___84 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___76 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___257 *mod;
};

struct bpf_jit_poke_descriptor___84 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___85 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___84 {
	struct btf *btf;
	struct module___257 *module;
};

struct cftype___200;

struct cgroup_subsys___200 {
	struct cgroup_subsys_state___200 * (*css_alloc)(struct cgroup_subsys_state___200 *);
	int (*css_online)(struct cgroup_subsys_state___200 *);
	void (*css_offline)(struct cgroup_subsys_state___200 *);
	void (*css_released)(struct cgroup_subsys_state___200 *);
	void (*css_free)(struct cgroup_subsys_state___200 *);
	void (*css_reset)(struct cgroup_subsys_state___200 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___200 *, int);
	int (*css_extra_stat_show)(struct seq_file___248 *, struct cgroup_subsys_state___200 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___280 *, struct css_set___200 *);
	void (*cancel_fork)(struct task_struct___280 *, struct css_set___200 *);
	void (*fork)(struct task_struct___280 *);
	void (*exit)(struct task_struct___280 *);
	void (*release)(struct task_struct___280 *);
	void (*bind)(struct cgroup_subsys_state___200 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___200 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___200 *dfl_cftypes;
	struct cftype___200 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___200 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___200 *updated_children;
	struct cgroup___200 *updated_next;
};

struct cgroup_root___200 {
	struct kernfs_root___261 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___200 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___200 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___200 *ss;
	struct list_head node;
	struct kernfs_ops___261 *kf_ops;
	int (*open)(struct kernfs_open_file___261 *);
	void (*release)(struct kernfs_open_file___261 *);
	u64 (*read_u64)(struct cgroup_subsys_state___200 *, struct cftype___200 *);
	s64 (*read_s64)(struct cgroup_subsys_state___200 *, struct cftype___200 *);
	int (*seq_show)(struct seq_file___248 *, void *);
	void * (*seq_start)(struct seq_file___248 *, loff_t *);
	void * (*seq_next)(struct seq_file___248 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___248 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___200 *, struct cftype___200 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___200 *, struct cftype___200 *, s64);
	ssize_t (*write)(struct kernfs_open_file___261 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___261 *, struct poll_table_struct___194 *);
};

struct xdp_rxq_info___82 {
	struct net_device___82 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___82 {
	struct net_device___82 *dev;
};

struct xdp_buff___82 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___82 *rxq;
	struct xdp_txq_info___82 *txq;
	u32 frame_sz;
};

struct xdp_frame___82 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___82 *dev_rx;
};

struct netlink_callback___82 {
	struct sk_buff___83 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___83 *, struct netlink_callback___82 *);
	int (*done)(struct netlink_callback___82 *);
	void *data;
	struct module___257 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___82 {
	int (*create)(struct sk_buff___83 *, struct net_device___82 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___83 *, unsigned char *);
	int (*cache)(const struct neighbour___69 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___82 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___83 *);
};

struct netdev_queue___82 {
	struct net_device___82 *dev;
	struct Qdisc___76 *qdisc;
	struct Qdisc___76 *qdisc_sleeping;
	struct kobject___261 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___82 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___76 {
	struct sk_buff___83 *head;
	struct sk_buff___83 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___76;

struct Qdisc___76 {
	int (*enqueue)(struct sk_buff___83 *, struct Qdisc___76 *, struct sk_buff___83 **);
	struct sk_buff___83 * (*dequeue)(struct Qdisc___76 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___76 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___82 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___82 gso_skb;
	struct qdisc_skb_head___76 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___76 *next_sched;
	struct sk_buff_head___82 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___82 {
	struct xdp_rxq_info___82 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___261 kobj;
	struct net_device___82 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___82 {
	enum net_device_path_type type;
	const struct net_device___82 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___82 = 0,
				DEV_PATH_BR_VLAN_TAG___82 = 1,
				DEV_PATH_BR_VLAN_UNTAG___82 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___82 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___82 {
	const struct net_device___82 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___82 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___76 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___82 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___82 {
	int (*xdo_dev_state_add)(struct xfrm_state___13 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___13 *);
	void (*xdo_dev_state_free)(struct xfrm_state___13 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___83 *, struct xfrm_state___13 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___13 *);
};

struct xfrm_state_offload___13 {
	struct net_device___82 *dev;
	struct net_device___82 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___13;

struct xfrm_type_offload___13;

struct xfrm_state___13 {
	possible_net_t___82 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___69 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___13 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___13 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___278 xfrag;
	const struct xfrm_type___13 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___13 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___82 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___82 *dev;
	const char *name;
};

struct net_device_ops___82 {
	int (*ndo_init)(struct net_device___82 *);
	void (*ndo_uninit)(struct net_device___82 *);
	int (*ndo_open)(struct net_device___82 *);
	int (*ndo_stop)(struct net_device___82 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___83 *, struct net_device___82 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___83 *, struct net_device___82 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___82 *, struct sk_buff___83 *, struct net_device___82 *);
	void (*ndo_change_rx_flags)(struct net_device___82 *, int);
	void (*ndo_set_rx_mode)(struct net_device___82 *);
	int (*ndo_set_mac_address)(struct net_device___82 *, void *);
	int (*ndo_validate_addr)(struct net_device___82 *);
	int (*ndo_do_ioctl)(struct net_device___82 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___82 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___82 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___82 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___82 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___82 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___82 *, int);
	int (*ndo_neigh_setup)(struct net_device___82 *, struct neigh_parms___69 *);
	void (*ndo_tx_timeout)(struct net_device___82 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___82 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___82 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___82 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___82 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___82 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___82 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___82 *);
	int (*ndo_netpoll_setup)(struct net_device___82 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___82 *);
	int (*ndo_set_vf_mac)(struct net_device___82 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___82 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___82 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___82 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___82 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___82 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___82 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___82 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___82 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___82 *, int, struct sk_buff___83 *);
	int (*ndo_get_vf_guid)(struct net_device___82 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___82 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___82 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___82 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___82 *);
	int (*ndo_fcoe_disable)(struct net_device___82 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___82 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___82 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___82 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___82 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___82 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___82 *, const struct sk_buff___83 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___82 *, struct net_device___82 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___82 *, struct net_device___82 *);
	struct net_device___82 * (*ndo_get_xmit_slave)(struct net_device___82 *, struct sk_buff___83 *, bool);
	struct net_device___82 * (*ndo_sk_get_lower_dev)(struct net_device___82 *, struct sock___69 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___82 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___82 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___82 *, struct neighbour___69 *);
	void (*ndo_neigh_destroy)(struct net_device___82 *, struct neighbour___69 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___83 *, struct netlink_callback___82 *, struct net_device___82 *, struct net_device___82 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___83 *, struct nlattr **, struct net_device___82 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___82 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___83 *, u32, u32, struct net_device___82 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___82 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___82 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___82 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___82 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___82 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___82 *, struct net_device___82 *);
	void (*ndo_dfwd_del_station)(struct net_device___82 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___82 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___82 *);
	int (*ndo_change_proto_down)(struct net_device___82 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___82 *, struct sk_buff___83 *);
	void (*ndo_set_rx_headroom)(struct net_device___82 *, int);
	int (*ndo_bpf)(struct net_device___82 *, struct netdev_bpf___82 *);
	int (*ndo_xdp_xmit)(struct net_device___82 *, int, struct xdp_frame___82 **, u32);
	struct net_device___82 * (*ndo_xdp_get_xmit_slave)(struct net_device___82 *, struct xdp_buff___82 *);
	int (*ndo_xsk_wakeup)(struct net_device___82 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___82 *);
	int (*ndo_tunnel_ctl)(struct net_device___82 *, struct ip_tunnel_parm *, int);
	struct net_device___82 * (*ndo_get_peer_dev)(struct net_device___82 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___82 *, struct net_device_path___82 *);
};

struct neigh_parms___69 {
	possible_net_t___82 net;
	struct net_device___82 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___69 *);
	struct neigh_table___69 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___69 {
	u32 (*l3mdev_fib_table)(const struct net_device___82 *);
	struct sk_buff___83 * (*l3mdev_l3_rcv)(struct net_device___82 *, struct sk_buff___83 *, u16);
	struct sk_buff___83 * (*l3mdev_l3_out)(struct net_device___82 *, struct sock___69 *, struct sk_buff___83 *, u16);
	struct dst_entry___69 * (*l3mdev_link_scope_lookup)(const struct net_device___82 *, struct flowi6 *);
};

struct ndisc_ops___51 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___82 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___82 *, struct neighbour___69 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___82 *, u8, struct neighbour___69 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___82 *, struct sk_buff___83 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___87 *, struct net_device___82 *, const struct prefix_info *, struct inet6_dev___51 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___51;

struct ifacaddr6___18;

struct inet6_dev___51 {
	struct net_device___82 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___51 *mc_list;
	struct ifmcaddr6___51 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___82 mc_query_queue;
	struct sk_buff_head___82 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___18 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___69 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___76;

struct tcf_block___76;

struct mini_Qdisc___76 {
	struct tcf_proto___76 *filter_list;
	struct tcf_block___76 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___76 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___82 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___82 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___87 *, struct net_device___82 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___82 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___82 *, struct list_head *);
	size_t (*get_size)(const struct net_device___82 *);
	int (*fill_info)(struct sk_buff___83 *, const struct net_device___82 *);
	size_t (*get_xstats_size)(const struct net_device___82 *);
	int (*fill_xstats)(struct sk_buff___83 *, const struct net_device___82 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___82 *, struct net_device___82 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___82 *, const struct net_device___82 *);
	int (*fill_slave_info)(struct sk_buff___83 *, const struct net_device___82 *, const struct net_device___82 *);
	struct net___87 * (*get_link_net)(const struct net_device___82 *);
	size_t (*get_linkxstats_size)(const struct net_device___82 *, int);
	int (*fill_linkxstats)(struct sk_buff___83 *, const struct net_device___82 *, int *, int);
};

struct fib_rule___69 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___69 *ctarget;
	struct net___87 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___69 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___69 *rule;
	u32 table;
	int flags;
};

struct block_device_operations___164;

struct gendisk___167 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___167 *part0;
	const struct block_device_operations___164 *fops;
	struct request_queue___164 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___150 *bdi;
	struct kobject___261 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___261 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___164 {
	struct bio___164 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___190 *bip_vec;
	struct bio_vec___190 bip_inline_vecs[0];
};

struct blkcg___152;

struct blkg_policy_data___152;

struct blkcg_gq___152 {
	struct request_queue___164 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___152 *blkcg;
	struct blkcg_gq___152 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___152 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___164 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___164(struct request___164 *);

typedef void integrity_complete_fn___164(struct request___164 *, unsigned int);

struct blk_integrity_profile___164 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___164 *prepare_fn;
	integrity_complete_fn___164 *complete_fn;
	const char *name;
};

struct block_device_operations___164 {
	blk_qc_t (*submit_bio)(struct bio___164 *);
	int (*open)(struct block_device___167 *, fmode_t);
	void (*release)(struct gendisk___167 *, fmode_t);
	int (*rw_page)(struct block_device___167 *, sector_t, struct page___278 *, unsigned int);
	int (*ioctl)(struct block_device___167 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___167 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___167 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___167 *);
	int (*getgeo)(struct block_device___167 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___167 *, bool);
	void (*swap_slot_free_notify)(struct block_device___167 *, long unsigned int);
	int (*report_zones)(struct gendisk___167 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___167 *, umode_t *);
	struct module___257 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___167 *, sector_t *);
};

typedef void rq_end_io_fn___164(struct request___164 *, blk_status_t);

struct request___164 {
	struct request_queue___164 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___159 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___164 *bio;
	struct bio___164 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___190 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___164 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___164 *saved_end_io;
		} flush;
	};
	struct gendisk___167 *rq_disk;
	struct block_device___167 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___164 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___159 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___164 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___261 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___273 *debugfs_dir;
	struct dentry___273 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___164;

struct elevator_mq_ops___164 {
	int (*init_sched)(struct request_queue___164 *, struct elevator_type___164 *);
	void (*exit_sched)(struct elevator_queue___164 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___159 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___159 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___159 *);
	bool (*allow_merge)(struct request_queue___164 *, struct request___164 *, struct bio___164 *);
	bool (*bio_merge)(struct request_queue___164 *, struct bio___164 *, unsigned int);
	int (*request_merge)(struct request_queue___164 *, struct request___164 **, struct bio___164 *);
	void (*request_merged)(struct request_queue___164 *, struct request___164 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___164 *, struct request___164 *, struct request___164 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___164 *);
	void (*finish_request)(struct request___164 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___159 *, struct list_head *, bool);
	struct request___164 * (*dispatch_request)(struct blk_mq_hw_ctx___159 *);
	bool (*has_work)(struct blk_mq_hw_ctx___159 *);
	void (*completed_request)(struct request___164 *, u64);
	void (*requeue_request)(struct request___164 *);
	struct request___164 * (*former_request)(struct request_queue___164 *, struct request___164 *);
	struct request___164 * (*next_request)(struct request_queue___164 *, struct request___164 *);
	void (*init_icq)(struct io_cq___164 *);
	void (*exit_icq)(struct io_cq___164 *);
};

struct elv_fs_entry___164;

struct elevator_type___164 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___164 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___164 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___257 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___164 {
	struct elevator_type___164 *type;
	void *elevator_data;
	struct kobject___261 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___164 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___164 *, char *);
	ssize_t (*store)(struct elevator_queue___164 *, const char *, size_t);
};

struct blk_mq_queue_data___159;

struct blk_mq_ops___159 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___159 *, const struct blk_mq_queue_data___159 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___159 *);
	int (*get_budget)(struct request_queue___164 *);
	void (*put_budget)(struct request_queue___164 *, int);
	void (*set_rq_budget_token)(struct request___164 *, int);
	int (*get_rq_budget_token)(struct request___164 *);
	enum blk_eh_timer_return (*timeout)(struct request___164 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___159 *);
	void (*complete)(struct request___164 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___159 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___159 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___159 *, struct request___164 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___159 *, struct request___164 *, unsigned int);
	void (*initialize_rq_fn)(struct request___164 *);
	void (*cleanup_rq)(struct request___164 *);
	bool (*busy)(struct request_queue___164 *);
	int (*map_queues)(struct blk_mq_tag_set___159 *);
	void (*show_rq)(struct seq_file___248 *, struct request___164 *);
};

struct blk_mq_tag_set___159 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___159 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___159 {
	struct request___164 *rq;
	bool last;
};

struct blkcg_policy_data___152;

struct blkcg___152 {
	struct cgroup_subsys_state___200 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___152 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___152 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___152 {
	struct blkcg___152 *blkcg;
	int plid;
};

struct blkg_policy_data___152 {
	struct blkcg_gq___152 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___138 {
	struct mem_cgroup___138 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___138 {
	struct lruvec___146 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___138 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___138 *memcg;
};

struct obj_cgroup___138 {
	struct percpu_ref refcnt;
	struct mem_cgroup___138 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___76 {
	spinlock_t *lock;
	struct sk_buff___83 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___76;

struct Qdisc_ops___76 {
	struct Qdisc_ops___76 *next;
	const struct Qdisc_class_ops___76 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___83 *, struct Qdisc___76 *, struct sk_buff___83 **);
	struct sk_buff___83 * (*dequeue)(struct Qdisc___76 *);
	struct sk_buff___83 * (*peek)(struct Qdisc___76 *);
	int (*init)(struct Qdisc___76 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___76 *);
	void (*destroy)(struct Qdisc___76 *);
	int (*change)(struct Qdisc___76 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___76 *);
	int (*change_tx_queue_len)(struct Qdisc___76 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___76 *, unsigned int);
	int (*dump)(struct Qdisc___76 *, struct sk_buff___83 *);
	int (*dump_stats)(struct Qdisc___76 *, struct gnet_dump___76 *);
	void (*ingress_block_set)(struct Qdisc___76 *, u32);
	void (*egress_block_set)(struct Qdisc___76 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___76 *);
	u32 (*egress_block_get)(struct Qdisc___76 *);
	struct module___257 *owner;
};

struct Qdisc_class_ops___76 {
	unsigned int flags;
	struct netdev_queue___82 * (*select_queue)(struct Qdisc___76 *, struct tcmsg *);
	int (*graft)(struct Qdisc___76 *, long unsigned int, struct Qdisc___76 *, struct Qdisc___76 **, struct netlink_ext_ack *);
	struct Qdisc___76 * (*leaf)(struct Qdisc___76 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___76 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___76 *, u32);
	int (*change)(struct Qdisc___76 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___76 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___76 *, struct qdisc_walker *);
	struct tcf_block___76 * (*tcf_block)(struct Qdisc___76 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___76 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___76 *, long unsigned int);
	int (*dump)(struct Qdisc___76 *, long unsigned int, struct sk_buff___83 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___76 *, long unsigned int, struct gnet_dump___76 *);
};

struct tcf_chain___76;

struct tcf_block___76 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___87 *net;
	struct Qdisc___76 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___76 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___76;

struct tcf_proto_ops___76;

struct tcf_proto___76 {
	struct tcf_proto___76 *next;
	void *root;
	int (*classify)(struct sk_buff___83 *, const struct tcf_proto___76 *, struct tcf_result___76 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___76 *ops;
	struct tcf_chain___76 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___76 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___76 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___76 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___83 *, const struct tcf_proto___76 *, struct tcf_result___76 *);
	int (*init)(struct tcf_proto___76 *);
	void (*destroy)(struct tcf_proto___76 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___76 *, u32);
	void (*put)(struct tcf_proto___76 *, void *);
	int (*change)(struct net___87 *, struct sk_buff___83 *, struct tcf_proto___76 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___76 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___76 *);
	void (*walk)(struct tcf_proto___76 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___76 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___76 *, void *);
	void (*hw_del)(struct tcf_proto___76 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___87 *, struct tcf_chain___76 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___87 *, struct tcf_proto___76 *, void *, struct sk_buff___83 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___87 *, struct tcf_proto___76 *, void *, struct sk_buff___83 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___83 *, struct net___87 *, void *);
	struct module___257 *owner;
	int flags;
};

struct tcf_chain___76 {
	struct mutex filter_chain_lock;
	struct tcf_proto___76 *filter_chain;
	struct list_head list;
	struct tcf_block___76 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___76 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___69 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___76 *prog;
};

struct pneigh_entry___69;

struct neigh_hash_table___69;

struct neigh_table___69 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___82 *, __u32 *);
	bool (*key_eq)(const struct neighbour___69 *, const void *);
	int (*constructor)(struct neighbour___69 *);
	int (*pconstructor)(struct pneigh_entry___69 *);
	void (*pdestructor)(struct pneigh_entry___69 *);
	void (*proxy_redo)(struct sk_buff___83 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___82 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___69 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___82 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___69 *nht;
	struct pneigh_entry___69 **phash_buckets;
};

struct neigh_ops___69 {
	int family;
	void (*solicit)(struct neighbour___69 *, struct sk_buff___83 *);
	void (*error_report)(struct neighbour___69 *, struct sk_buff___83 *);
	int (*output)(struct neighbour___69 *, struct sk_buff___83 *);
	int (*connected_output)(struct neighbour___69 *, struct sk_buff___83 *);
};

struct pneigh_entry___69 {
	struct pneigh_entry___69 *next;
	possible_net_t___82 net;
	struct net_device___82 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___69 {
	struct neighbour___69 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___45 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___87 *, struct sock___69 *, struct sk_buff___83 *);
	int (*orig_input)(struct sk_buff___83 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct request_sock_ops___54;

struct timewait_sock_ops___53;

struct proto___69 {
	void (*close)(struct sock___69 *, long int);
	int (*pre_connect)(struct sock___69 *, struct sockaddr *, int);
	int (*connect)(struct sock___69 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___69 *, int);
	struct sock___69 * (*accept)(struct sock___69 *, int, int *, bool);
	int (*ioctl)(struct sock___69 *, int, long unsigned int);
	int (*init)(struct sock___69 *);
	void (*destroy)(struct sock___69 *);
	void (*shutdown)(struct sock___69 *, int);
	int (*setsockopt)(struct sock___69 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___69 *, int, int, char *, int *);
	void (*keepalive)(struct sock___69 *, int);
	int (*compat_ioctl)(struct sock___69 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___69 *, struct msghdr___71 *, size_t);
	int (*recvmsg)(struct sock___69 *, struct msghdr___71 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___69 *, struct page___278 *, int, size_t, int);
	int (*bind)(struct sock___69 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___69 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___69 *, struct sk_buff___83 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___69 *);
	int (*hash)(struct sock___69 *);
	void (*unhash)(struct sock___69 *);
	void (*rehash)(struct sock___69 *);
	int (*get_port)(struct sock___69 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___69 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___69 *, int);
	bool (*sock_is_readable)(struct sock___69 *);
	void (*enter_memory_pressure)(struct sock___69 *);
	void (*leave_memory_pressure)(struct sock___69 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___54 *rsk_prot;
	struct timewait_sock_ops___53 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___257 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___69 *, int);
};

struct xfrm_policy_queue___13 {
	struct sk_buff_head___82 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___13 {
	possible_net_t___82 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___13 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct request_sock___55;

struct request_sock_ops___54 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___69 *, struct request_sock___55 *);
	void (*send_ack)(const struct sock___69 *, struct sk_buff___83 *, struct request_sock___55 *);
	void (*send_reset)(const struct sock___69 *, struct sk_buff___83 *);
	void (*destructor)(struct request_sock___55 *);
	void (*syn_ack_timeout)(const struct request_sock___55 *);
};

struct timewait_sock_ops___53 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___69 *, struct sock___69 *, void *);
	void (*twsk_destructor)(struct sock___69 *);
};

struct request_sock___55 {
	struct sock_common___69 __req_common;
	struct request_sock___55 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___54 *rsk_ops;
	struct sock___69 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___12 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___69 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___12 {
	struct inet_cork___12 base;
	struct flowi fl;
};

struct ipv6_pinfo___12;

struct inet_sock___12 {
	struct sock___69 sk;
	struct ipv6_pinfo___12 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___12 cork;
};

struct ipv6_fl_socklist___12;

struct ipv6_pinfo___12 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___12 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___83 *pktoptions;
	struct sk_buff___83 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___12;

struct ipv6_fl_socklist___12 {
	struct ipv6_fl_socklist___12 *next;
	struct ip6_flowlabel___12 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___51 {
	struct in6_addr mca_addr;
	struct inet6_dev___51 *idev;
	struct ifmcaddr6___51 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___18 {
	struct in6_addr aca_addr;
	struct fib6_info___18 *aca_rt;
	struct ifacaddr6___18 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___12 {
	struct ip6_flowlabel___12 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___250 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___87 *fl_net;
};

struct fib_nh_exception___18 {
	struct fib_nh_exception___18 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___19 *fnhe_rth_input;
	struct rtable___19 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___19 {
	struct dst_entry___69 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___18 {
	struct fib_nh_exception___18 *chain;
};

struct icmphdr___2 {
	__u8 type;
	__u8 code;
	__sum16 checksum;
	union {
		struct {
			__be16 id;
			__be16 sequence;
		} echo;
		__be32 gateway;
		struct {
			__be16 __unused;
			__be16 mtu;
		} frag;
		__u8 reserved[4];
	} un;
};

struct icmp_filter {
	__u32 data;
};

struct raw_iter_state {
	struct seq_net_private___7 p;
	int bucket;
};

struct raw_sock {
	struct inet_sock___12 inet;
	struct icmp_filter filter;
	u32 ipmr_table;
};

struct xfrm_type___13 {
	struct module___257 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___13 *);
	void (*destructor)(struct xfrm_state___13 *);
	int (*input)(struct xfrm_state___13 *, struct sk_buff___83 *);
	int (*output)(struct xfrm_state___13 *, struct sk_buff___83 *);
	int (*reject)(struct xfrm_state___13 *, struct sk_buff___83 *, const struct flowi *);
};

struct xfrm_type_offload___13 {
	struct module___257 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___13 *, struct sk_buff___83 *);
	int (*input_tail)(struct xfrm_state___13 *, struct sk_buff___83 *);
	int (*xmit)(struct xfrm_state___13 *, struct sk_buff___83 *, netdev_features_t);
};

struct nf_hook_state___11 {
	u8 hook;
	u8 pf;
	struct net_device___82 *in;
	struct net_device___82 *out;
	struct sock___69 *sk;
	struct net___87 *net;
	int (*okfn)(struct net___87 *, struct sock___69 *, struct sk_buff___83 *);
};

struct raw_frag_vec {
	struct msghdr___71 *msg;
	union {
		struct icmphdr___2 icmph;
		char c[1];
	} hdr;
	int hlen;
};

struct dentry___274;

struct super_block___274;

struct module___258;

struct file_system_type___274 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___274 * (*mount)(struct file_system_type___274 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___274 *);
	struct module___258 *owner;
	struct file_system_type___274 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___274;

struct kiocb___274;

struct iov_iter___194;

struct poll_table_struct___195;

struct vm_area_struct___279;

struct inode___274;

struct file_lock___274;

struct page___279;

struct pipe_inode_info___115;

struct seq_file___249;

struct file_operations___275 {
	struct module___258 *owner;
	loff_t (*llseek)(struct file___274 *, loff_t, int);
	ssize_t (*read)(struct file___274 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___274 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___274 *, struct iov_iter___194 *);
	ssize_t (*write_iter)(struct kiocb___274 *, struct iov_iter___194 *);
	int (*iopoll)(struct kiocb___274 *, bool);
	int (*iterate)(struct file___274 *, struct dir_context *);
	int (*iterate_shared)(struct file___274 *, struct dir_context *);
	__poll_t (*poll)(struct file___274 *, struct poll_table_struct___195 *);
	long int (*unlocked_ioctl)(struct file___274 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___274 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___274 *, struct vm_area_struct___279 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___274 *, struct file___274 *);
	int (*flush)(struct file___274 *, fl_owner_t);
	int (*release)(struct inode___274 *, struct file___274 *);
	int (*fsync)(struct file___274 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___274 *, int);
	int (*lock)(struct file___274 *, int, struct file_lock___274 *);
	ssize_t (*sendpage)(struct file___274 *, struct page___279 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___274 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___274 *, long unsigned int);
	int (*flock)(struct file___274 *, int, struct file_lock___274 *);
	ssize_t (*splice_write)(struct pipe_inode_info___115 *, struct file___274 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___274 *, loff_t *, struct pipe_inode_info___115 *, size_t, unsigned int);
	int (*setlease)(struct file___274 *, long int, struct file_lock___274 **, void **);
	long int (*fallocate)(struct file___274 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___249 *, struct file___274 *);
	ssize_t (*copy_file_range)(struct file___274 *, loff_t, struct file___274 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___274 *, loff_t, struct file___274 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___274 *, loff_t, loff_t, int);
};

struct vmacache___279 {
	u64 seqnum;
	struct vm_area_struct___279 *vmas[4];
};

struct page_frag___279 {
	struct page___279 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___280;

struct pid___251;

struct nsproxy___260;

struct signal_struct___275;

struct bio_list___165;

struct backing_dev_info___151;

struct io_context___165;

struct css_set___201;

struct mem_cgroup___139;

struct request_queue___165;

struct vm_struct___257;

struct task_struct___281 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___281 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___280 *mm;
	struct mm_struct___280 *active_mm;
	struct vmacache___279 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___281 *real_parent;
	struct task_struct___281 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___281 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___251 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___260 *nsproxy;
	struct signal_struct___275 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___281 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___165 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___151 *backing_dev_info;
	struct io_context___165 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___201 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___115 *splice_pipe;
	struct page_frag___279 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___139 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___139 *active_memcg;
	struct request_queue___165 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___281 *oom_reaper_list;
	struct vm_struct___257 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___262;

struct kobj_type___262;

struct kernfs_node___262;

struct kobject___262 {
	const char *name;
	struct list_head entry;
	struct kobject___262 *parent;
	struct kset___262 *kset;
	struct kobj_type___262 *ktype;
	struct kernfs_node___262 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___259 {
	struct kobject___262 kobj;
	struct module___258 *mod;
	struct kobject___262 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___258 {
	struct module___258 *mod;
	struct latch_tree_node node;
};

struct module_layout___258 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___258 mtn;
};

struct module_attribute___258;

struct kernel_param___258;

struct module___258 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___259 mkobj;
	struct module_attribute___258 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___262 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___258 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___258 core_layout;
	struct module_layout___258 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___251;

struct upid___251 {
	int nr;
	struct pid_namespace___251 *ns;
};

struct pid_namespace___251 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___281 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___251 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___251 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___251 numbers[1];
};

typedef struct page___279 *pgtable_t___279;

struct address_space___274;

struct page_pool___103;

struct dev_pagemap___269;

struct page___279 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___274 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___103 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___279 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___279 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___280 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___269 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___269;

struct vm_area_struct___279 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___279 *vm_next;
	struct vm_area_struct___279 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___280 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___269 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___274 *vm_file;
	struct file___274 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___275 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___281 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___281 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___251 *pids[4];
	struct pid___251 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___280 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___279;

struct mm_struct___280 {
	struct {
		struct vm_area_struct___279 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___274 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___279 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___281 *owner;
		struct user_namespace___26 *user_ns;
		struct file___274 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___88;

struct cgroup_namespace___201;

struct nsproxy___260 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___251 *pid_ns_for_children;
	struct net___88 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___201 *cgroup_ns;
};

struct bio___165;

struct bio_list___165 {
	struct bio___165 *head;
	struct bio___165 *tail;
};

struct cgroup_subsys_state___201;

struct bdi_writeback___151 {
	struct backing_dev_info___151 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___201 *memcg_css;
	struct cgroup_subsys_state___201 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___255;

struct backing_dev_info___151 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___151 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___255 *dev;
	char dev_name[64];
	struct device___255 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___274 *debug_dir;
};

struct io_cq___165;

struct io_context___165 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___165 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___201;

struct css_set___201 {
	struct cgroup_subsys_state___201 *subsys[14];
	refcount_t refcount;
	struct css_set___201 *dom_cset;
	struct cgroup___201 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___201 *mg_src_cgrp;
	struct cgroup___201 *mg_dst_cgrp;
	struct css_set___201 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___274;

struct pipe_buffer___115;

struct pipe_inode_info___115 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___279 *tmp_page;
	struct fasync_struct___274 *fasync_readers;
	struct fasync_struct___274 *fasync_writers;
	struct pipe_buffer___115 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___201;

struct cgroup_subsys_state___201 {
	struct cgroup___201 *cgroup;
	struct cgroup_subsys___201 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___201 *parent;
};

struct cgroup_file___201 {
	struct kernfs_node___262 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___139;

struct mem_cgroup_per_node___139;

struct mem_cgroup___139 {
	struct cgroup_subsys_state___201 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___201 events_file;
	struct cgroup_file___201 events_local_file;
	struct cgroup_file___201 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___139 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___281 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___139 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___165;

struct blk_integrity___165 {
	const struct blk_integrity_profile___165 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___165 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___165 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___165;

struct elevator_queue___165;

struct blk_mq_ops___160;

struct blk_mq_hw_ctx___160;

struct gendisk___168;

struct blkcg_gq___153;

struct blk_mq_tag_set___160;

struct request_queue___165 {
	struct request___165 *last_merge;
	struct elevator_queue___165 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___160 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___160 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___168 *disk;
	struct kobject___262 kobj;
	struct kobject___262 *mq_kobj;
	struct blk_integrity___165 integrity;
	struct device___255 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___153 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___160 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___165 bio_split;
	struct dentry___274 *debugfs_dir;
	struct dentry___274 *sched_debugfs_dir;
	struct dentry___274 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___257 {
	struct vm_struct___257 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___279 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___274;

struct address_space___274 {
	struct inode___274 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___274 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___103 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___255 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___103 {
	u32 count;
	struct page___279 *cache[128];
};

struct page_pool___103 {
	struct page_pool_params___103 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___279 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___103 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___269;

struct dev_pagemap___269 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___269 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___274;

struct path___274 {
	struct vfsmount___274 *mnt;
	struct dentry___274 *dentry;
};

struct fown_struct___251 {
	rwlock_t lock;
	struct pid___251 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___274 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___274 f_path;
	struct inode___274 *f_inode;
	const struct file_operations___275 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___251 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___274 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___269;

struct vm_operations_struct___269 {
	void (*open)(struct vm_area_struct___279 *);
	void (*close)(struct vm_area_struct___279 *);
	int (*may_split)(struct vm_area_struct___279 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___279 *);
	int (*mprotect)(struct vm_area_struct___279 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___269 *);
	vm_fault_t (*huge_fault)(struct vm_fault___269 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___269 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___279 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___269 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___269 *);
	int (*access)(struct vm_area_struct___279 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___279 *);
	int (*set_policy)(struct vm_area_struct___279 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___279 *, long unsigned int);
	struct page___279 * (*find_special_page)(struct vm_area_struct___279 *, long unsigned int);
};

struct core_thread___279 {
	struct task_struct___281 *task;
	struct core_thread___279 *next;
};

struct core_state___279 {
	atomic_t nr_threads;
	struct core_thread___279 dumper;
	struct completion startup;
};

struct vm_fault___269 {
	const struct {
		struct vm_area_struct___279 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___279 *cow_page;
	struct page___279 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___279 prealloc_pte;
};

struct pglist_data___147;

struct lruvec___147 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___147 *pgdat;
};

struct zone___147 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___147 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___147 {
	struct zone___147 *zone;
	int zone_idx;
};

struct zonelist___147 {
	struct zoneref___147 _zonerefs[321];
};

struct pglist_data___147 {
	struct zone___147 node_zones[5];
	struct zonelist___147 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___281 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___281 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___147 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___139 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___139 *memcg;
};

struct shrinker___139 {
	long unsigned int (*count_objects)(struct shrinker___139 *, struct shrink_control___139 *);
	long unsigned int (*scan_objects)(struct shrinker___139 *, struct shrink_control___139 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___269 {
	void (*page_free)(struct page___279 *);
	void (*kill)(struct dev_pagemap___269 *);
	void (*cleanup)(struct dev_pagemap___269 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___269 *);
};

struct dentry_operations___274;

struct dentry___274 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___274 *d_parent;
	struct qstr d_name;
	struct inode___274 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___274 *d_op;
	struct super_block___274 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___274;

struct inode___274 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___274 *i_op;
	struct super_block___274 *i_sb;
	struct address_space___274 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___151 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___275 *i_fop;
		void (*free_inode)(struct inode___274 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___274 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___115 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___274 {
	int (*d_revalidate)(struct dentry___274 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___274 *, unsigned int);
	int (*d_hash)(const struct dentry___274 *, struct qstr *);
	int (*d_compare)(const struct dentry___274 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___274 *);
	int (*d_init)(struct dentry___274 *);
	void (*d_release)(struct dentry___274 *);
	void (*d_prune)(struct dentry___274 *);
	void (*d_iput)(struct dentry___274 *, struct inode___274 *);
	char * (*d_dname)(struct dentry___274 *, char *, int);
	struct vfsmount___274 * (*d_automount)(struct path___274 *);
	int (*d_manage)(const struct path___274 *, bool);
	struct dentry___274 * (*d_real)(struct dentry___274 *, const struct inode___274 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___274;

struct mem_dqinfo___274 {
	struct quota_format_type___274 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___274;

struct quota_info___274 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___274 *files[3];
	struct mem_dqinfo___274 info[3];
	const struct quota_format_ops___274 *ops[3];
};

struct rcuwait___275 {
	struct task_struct___281 *task;
};

struct percpu_rw_semaphore___275 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___275 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___274 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___275 rw_sem[3];
};

struct super_operations___274;

struct dquot_operations___274;

struct quotactl_ops___274;

struct block_device___168;

struct super_block___274 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___274 *s_type;
	const struct super_operations___274 *s_op;
	const struct dquot_operations___274 *dq_op;
	const struct quotactl_ops___274 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___274 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___168 *s_bdev;
	struct backing_dev_info___151 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___274 s_dquot;
	struct sb_writers___274 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___274 *s_d_op;
	int cleancache_poolid;
	struct shrinker___139 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___274 {
	struct dentry___274 *mnt_root;
	struct super_block___274 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___201 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___281 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___77;

struct cgroup_bpf___77 {
	struct bpf_prog_array___77 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___77 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___201;

struct cgroup_rstat_cpu___201;

struct cgroup___201 {
	struct cgroup_subsys_state___201 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___262 *kn;
	struct cgroup_file___201 procs_file;
	struct cgroup_file___201 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___201 *subsys[14];
	struct cgroup_root___201 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___201 *dom_cgrp;
	struct cgroup___201 *old_dom_cgrp;
	struct cgroup_rstat_cpu___201 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___201 psi;
	struct cgroup_bpf___77 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___165 {
	struct request_queue___165 *q;
	struct io_context___165 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___116;

struct kiocb___274 {
	struct file___274 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___274 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___274 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___274 *ia_file;
};

struct dquot___274 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___274 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___274 {
	int qf_fmt_id;
	const struct quota_format_ops___274 *qf_ops;
	struct module___258 *qf_owner;
	struct quota_format_type___274 *qf_next;
};

struct quota_format_ops___274 {
	int (*check_quota_file)(struct super_block___274 *, int);
	int (*read_file_info)(struct super_block___274 *, int);
	int (*write_file_info)(struct super_block___274 *, int);
	int (*free_file_info)(struct super_block___274 *, int);
	int (*read_dqblk)(struct dquot___274 *);
	int (*commit_dqblk)(struct dquot___274 *);
	int (*release_dqblk)(struct dquot___274 *);
	int (*get_next_id)(struct super_block___274 *, struct kqid *);
};

struct dquot_operations___274 {
	int (*write_dquot)(struct dquot___274 *);
	struct dquot___274 * (*alloc_dquot)(struct super_block___274 *, int);
	void (*destroy_dquot)(struct dquot___274 *);
	int (*acquire_dquot)(struct dquot___274 *);
	int (*release_dquot)(struct dquot___274 *);
	int (*mark_dirty)(struct dquot___274 *);
	int (*write_info)(struct super_block___274 *, int);
	qsize_t * (*get_reserved_space)(struct inode___274 *);
	int (*get_projid)(struct inode___274 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___274 *, qsize_t *);
	int (*get_next_id)(struct super_block___274 *, struct kqid *);
};

struct quotactl_ops___274 {
	int (*quota_on)(struct super_block___274 *, int, int, const struct path___274 *);
	int (*quota_off)(struct super_block___274 *, int);
	int (*quota_enable)(struct super_block___274 *, unsigned int);
	int (*quota_disable)(struct super_block___274 *, unsigned int);
	int (*quota_sync)(struct super_block___274 *, int);
	int (*set_info)(struct super_block___274 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___274 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___274 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___274 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___274 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___274 *, unsigned int);
};

struct wait_page_queue___116 {
	struct page___279 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___151;

struct readahead_control___116;

struct swap_info_struct___69;

struct address_space_operations___274 {
	int (*writepage)(struct page___279 *, struct writeback_control___151 *);
	int (*readpage)(struct file___274 *, struct page___279 *);
	int (*writepages)(struct address_space___274 *, struct writeback_control___151 *);
	int (*set_page_dirty)(struct page___279 *);
	int (*readpages)(struct file___274 *, struct address_space___274 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___116 *);
	int (*write_begin)(struct file___274 *, struct address_space___274 *, loff_t, unsigned int, unsigned int, struct page___279 **, void **);
	int (*write_end)(struct file___274 *, struct address_space___274 *, loff_t, unsigned int, unsigned int, struct page___279 *, void *);
	sector_t (*bmap)(struct address_space___274 *, sector_t);
	void (*invalidatepage)(struct page___279 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___279 *, gfp_t);
	void (*freepage)(struct page___279 *);
	ssize_t (*direct_IO)(struct kiocb___274 *, struct iov_iter___194 *);
	int (*migratepage)(struct address_space___274 *, struct page___279 *, struct page___279 *, enum migrate_mode);
	bool (*isolate_page)(struct page___279 *, isolate_mode_t);
	void (*putback_page)(struct page___279 *);
	int (*launder_page)(struct page___279 *);
	int (*is_partially_uptodate)(struct page___279 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___279 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___274 *, struct page___279 *);
	int (*swap_activate)(struct swap_info_struct___69 *, struct file___274 *, sector_t *);
	void (*swap_deactivate)(struct file___274 *);
};

struct writeback_control___151 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___151 *wb;
	struct inode___274 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___116 {
	struct file___274 *file;
	struct address_space___274 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___191;

struct iov_iter___194 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___191 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___115 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___69 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___168 *bdev;
	struct file___274 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___274 {
	struct dentry___274 * (*lookup)(struct inode___274 *, struct dentry___274 *, unsigned int);
	const char * (*get_link)(struct dentry___274 *, struct inode___274 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___274 *, int);
	struct posix_acl * (*get_acl)(struct inode___274 *, int, bool);
	int (*readlink)(struct dentry___274 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___274 *, struct dentry___274 *, umode_t, bool);
	int (*link)(struct dentry___274 *, struct inode___274 *, struct dentry___274 *);
	int (*unlink)(struct inode___274 *, struct dentry___274 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___274 *, struct dentry___274 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___274 *, struct dentry___274 *, umode_t);
	int (*rmdir)(struct inode___274 *, struct dentry___274 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___274 *, struct dentry___274 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___274 *, struct dentry___274 *, struct inode___274 *, struct dentry___274 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___274 *, struct iattr___274 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___274 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___274 *, char *, size_t);
	int (*fiemap)(struct inode___274 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___274 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___274 *, struct dentry___274 *, struct file___274 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___274 *, struct dentry___274 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___274 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___274 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___274 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___274 {
	void (*fl_copy_lock)(struct file_lock___274 *, struct file_lock___274 *);
	void (*fl_release_private)(struct file_lock___274 *);
};

struct lock_manager_operations___274;

struct file_lock___274 {
	struct file_lock___274 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___274 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___274 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___274 *fl_ops;
	const struct lock_manager_operations___274 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___274 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___274 *);
	int (*lm_grant)(struct file_lock___274 *, int);
	bool (*lm_break)(struct file_lock___274 *);
	int (*lm_change)(struct file_lock___274 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___274 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___274 *);
};

struct fasync_struct___274 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___274 *fa_next;
	struct file___274 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___274 {
	struct inode___274 * (*alloc_inode)(struct super_block___274 *);
	void (*destroy_inode)(struct inode___274 *);
	void (*free_inode)(struct inode___274 *);
	void (*dirty_inode)(struct inode___274 *, int);
	int (*write_inode)(struct inode___274 *, struct writeback_control___151 *);
	int (*drop_inode)(struct inode___274 *);
	void (*evict_inode)(struct inode___274 *);
	void (*put_super)(struct super_block___274 *);
	int (*sync_fs)(struct super_block___274 *, int);
	int (*freeze_super)(struct super_block___274 *);
	int (*freeze_fs)(struct super_block___274 *);
	int (*thaw_super)(struct super_block___274 *);
	int (*unfreeze_fs)(struct super_block___274 *);
	int (*statfs)(struct dentry___274 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___274 *, int *, char *);
	void (*umount_begin)(struct super_block___274 *);
	int (*show_options)(struct seq_file___249 *, struct dentry___274 *);
	int (*show_devname)(struct seq_file___249 *, struct dentry___274 *);
	int (*show_path)(struct seq_file___249 *, struct dentry___274 *);
	int (*show_stats)(struct seq_file___249 *, struct dentry___274 *);
	ssize_t (*quota_read)(struct super_block___274 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___274 *, int, const char *, size_t, loff_t);
	struct dquot___274 ** (*get_dquots)(struct inode___274 *);
	long int (*nr_cached_objects)(struct super_block___274 *, struct shrink_control___139 *);
	long int (*free_cached_objects)(struct super_block___274 *, struct shrink_control___139 *);
	struct file___274 * (*real_loop)(struct file___274 *);
};

struct wakeup_source___255;

struct dev_pm_info___255 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___255 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___255 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___255;

struct bus_type___255;

struct device_driver___255;

struct dev_pm_domain___255;

struct fwnode_handle___251;

struct class___255;

struct attribute_group___262;

struct device___255 {
	struct kobject___262 kobj;
	struct device___255 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___255 *type;
	struct bus_type___255 *bus;
	struct device_driver___255 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___255 power;
	struct dev_pm_domain___255 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___251 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___255 *class;
	const struct attribute_group___262 **groups;
	void (*release)(struct device___255 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___168 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___274 *bd_inode;
	struct super_block___274 *bd_super;
	void *bd_claiming;
	struct device___255 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___262 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___168 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___274 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___203)(struct file___274 *, wait_queue_head_t *, struct poll_table_struct___195 *);

struct poll_table_struct___195 {
	poll_queue_proc___203 _qproc;
	__poll_t _key;
};

struct seq_operations___249;

struct seq_file___249 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___249 *op;
	int poll_event;
	const struct file___274 *file;
	void *private;
};

typedef void bio_end_io_t___165(struct bio___165 *);

struct bio_vec___191 {
	struct page___279 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___165;

struct bio___165 {
	struct bio___165 *bi_next;
	struct block_device___168 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___165 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___153 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___165 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___191 *bi_io_vec;
	struct bio_set___165 *bi_pool;
	struct bio_vec___191 bi_inline_vecs[0];
};

struct fwnode_operations___251;

struct fwnode_handle___251 {
	struct fwnode_handle___251 *secondary;
	const struct fwnode_operations___251 *ops;
	struct device___255 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___251;

struct fwnode_endpoint___251;

struct fwnode_operations___251 {
	struct fwnode_handle___251 * (*get)(struct fwnode_handle___251 *);
	void (*put)(struct fwnode_handle___251 *);
	bool (*device_is_available)(const struct fwnode_handle___251 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___251 *, const struct device___255 *);
	bool (*property_present)(const struct fwnode_handle___251 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___251 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___251 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___251 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*get_parent)(const struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*get_next_child_node)(const struct fwnode_handle___251 *, struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*get_named_child_node)(const struct fwnode_handle___251 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___251 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___251 *);
	struct fwnode_handle___251 * (*graph_get_next_endpoint)(const struct fwnode_handle___251 *, struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*graph_get_remote_endpoint)(const struct fwnode_handle___251 *);
	struct fwnode_handle___251 * (*graph_get_port_parent)(struct fwnode_handle___251 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___251 *, struct fwnode_endpoint___251 *);
	int (*add_links)(struct fwnode_handle___251 *);
};

struct fwnode_endpoint___251 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___251 *local_fwnode;
};

struct fwnode_reference_args___251 {
	struct fwnode_handle___251 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___262;

struct kernfs_elem_dir___262 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___262 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___262;

struct kernfs_root___262 {
	struct kernfs_node___262 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___262 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___262 {
	struct kernfs_node___262 *target_kn;
};

struct kernfs_ops___262;

struct kernfs_elem_attr___262 {
	const struct kernfs_ops___262 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___262 *notify_next;
};

struct kernfs_node___262 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___262 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___262 dir;
		struct kernfs_elem_symlink___262 symlink;
		struct kernfs_elem_attr___262 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___262;

struct kernfs_ops___262 {
	int (*open)(struct kernfs_open_file___262 *);
	void (*release)(struct kernfs_open_file___262 *);
	int (*seq_show)(struct seq_file___249 *, void *);
	void * (*seq_start)(struct seq_file___249 *, loff_t *);
	void * (*seq_next)(struct seq_file___249 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___249 *, void *);
	ssize_t (*read)(struct kernfs_open_file___262 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___262 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___262 *, struct poll_table_struct___195 *);
	int (*mmap)(struct kernfs_open_file___262 *, struct vm_area_struct___279 *);
};

struct kernfs_syscall_ops___262 {
	int (*show_options)(struct seq_file___249 *, struct kernfs_root___262 *);
	int (*mkdir)(struct kernfs_node___262 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___262 *);
	int (*rename)(struct kernfs_node___262 *, struct kernfs_node___262 *, const char *);
	int (*show_path)(struct seq_file___249 *, struct kernfs_node___262 *, struct kernfs_root___262 *);
};

struct kernfs_open_file___262 {
	struct kernfs_node___262 *kn;
	struct file___274 *file;
	struct seq_file___249 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___269 *vm_ops;
};

struct sock___70;

struct kobj_ns_type_operations___70 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___70 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___88 *net;
} possible_net_t___83;

struct proto___70;

struct sock_common___70 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___70 *skc_prot;
	possible_net_t___83 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___70 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___84;

struct sk_buff_head___83 {
	struct sk_buff___84 *next;
	struct sk_buff___84 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___70 {
	struct cgroup___201 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___70;

struct socket_wq___71;

struct xfrm_policy___14;

struct dst_entry___70;

struct socket___72;

struct net_device___83;

struct sock_reuseport___21;

struct sock___70 {
	struct sock_common___70 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___83 sk_error_queue;
	struct sk_buff___84 *sk_rx_skb_cache;
	struct sk_buff_head___83 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___84 *head;
		struct sk_buff___84 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___70 *sk_filter;
	union {
		struct socket_wq___71 *sk_wq;
		struct socket_wq___71 *sk_wq_raw;
	};
	struct xfrm_policy___14 *sk_policy[2];
	struct dst_entry___70 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___70 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___84 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___84 *sk_tx_skb_cache;
	struct sk_buff_head___83 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___279 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___70 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___251 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___72 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___70 sk_cgrp_data;
	struct mem_cgroup___139 *sk_memcg;
	void (*sk_state_change)(struct sock___70 *);
	void (*sk_data_ready)(struct sock___70 *);
	void (*sk_write_space)(struct sock___70 *);
	void (*sk_error_report)(struct sock___70 *);
	int (*sk_backlog_rcv)(struct sock___70 *, struct sk_buff___84 *);
	struct sk_buff___84 * (*sk_validate_xmit_skb)(struct sock___70 *, struct net_device___83 *, struct sk_buff___84 *);
	void (*sk_destruct)(struct sock___70 *);
	struct sock_reuseport___21 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___262;

struct attribute_group___262 {
	const char *name;
	umode_t (*is_visible)(struct kobject___262 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___262 *, struct bin_attribute___262 *, int);
	struct attribute **attrs;
	struct bin_attribute___262 **bin_attrs;
};

struct bin_attribute___262 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___274 * (*f_mapping)();
	ssize_t (*read)(struct file___274 *, struct kobject___262 *, struct bin_attribute___262 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___274 *, struct kobject___262 *, struct bin_attribute___262 *, char *, loff_t, size_t);
	int (*mmap)(struct file___274 *, struct kobject___262 *, struct bin_attribute___262 *, struct vm_area_struct___279 *);
};

struct sysfs_ops___262 {
	ssize_t (*show)(struct kobject___262 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___262 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___262;

struct kset___262 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___262 kobj;
	const struct kset_uevent_ops___262 *uevent_ops;
};

struct kobj_type___262 {
	void (*release)(struct kobject___262 *);
	const struct sysfs_ops___262 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___262 **default_groups;
	const struct kobj_ns_type_operations___70 * (*child_ns_type)(struct kobject___262 *);
	const void * (*namespace)(struct kobject___262 *);
	void (*get_ownership)(struct kobject___262 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___262 {
	int (* const filter)(struct kset___262 *, struct kobject___262 *);
	const char * (* const name)(struct kset___262 *, struct kobject___262 *);
	int (* const uevent)(struct kset___262 *, struct kobject___262 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___258 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___258 *);
	int (*get)(char *, const struct kernel_param___258 *);
	void (*free)(void *);
};

struct kparam_array___258;

struct kernel_param___258 {
	const char *name;
	struct module___258 *mod;
	const struct kernel_param_ops___258 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___258 *arr;
	};
};

struct kparam_array___258 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___258 *ops;
	void *elem;
};

struct module_attribute___258 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___258 *, struct module_kobject___259 *, char *);
	ssize_t (*store)(struct module_attribute___258 *, struct module_kobject___259 *, const char *, size_t);
	void (*setup)(struct module___258 *, const char *);
	int (*test)(struct module___258 *);
	void (*free)(struct module___258 *);
};

struct ip_ra_chain___43;

struct fib_rules_ops___70;

struct fqdir___88;

struct fib_notifier_ops___70;

struct netns_ipv4___88 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___43 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___70 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___70 *fibnl;
	struct sock___70 **icmp_sk;
	struct sock___70 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___70 **tcp_sk;
	struct fqdir___88 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___70 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___70 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___70 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___70;

struct dst_ops___88 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___88 *);
	struct dst_entry___70 * (*check)(struct dst_entry___70 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___70 *);
	unsigned int (*mtu)(const struct dst_entry___70 *);
	u32 * (*cow_metrics)(struct dst_entry___70 *, long unsigned int);
	void (*destroy)(struct dst_entry___70 *);
	void (*ifdown)(struct dst_entry___70 *, struct net_device___83 *, int);
	struct dst_entry___70 * (*negative_advice)(struct dst_entry___70 *);
	void (*link_failure)(struct sk_buff___84 *);
	void (*update_pmtu)(struct dst_entry___70 *, struct sock___70 *, struct sk_buff___84 *, u32, bool);
	void (*redirect)(struct dst_entry___70 *, struct sock___70 *, struct sk_buff___84 *);
	int (*local_out)(struct net___88 *, struct sock___70 *, struct sk_buff___84 *);
	struct neighbour___70 * (*neigh_lookup)(const struct dst_entry___70 *, struct sk_buff___84 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___70 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___19;

struct rt6_info___19;

struct fib6_table___19;

struct netns_ipv6___88 {
	struct dst_ops___88 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___88 *fqdir;
	struct fib6_info___19 *fib6_null_entry;
	struct rt6_info___19 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___19 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___19 *ip6_prohibit_entry;
	struct rt6_info___19 *ip6_blk_hole_entry;
	struct fib6_table___19 *fib6_local_tbl;
	struct fib_rules_ops___70 *fib6_rules_ops;
	struct sock___70 **icmp_sk;
	struct sock___70 *ndisc_sk;
	struct sock___70 *tcp_sk;
	struct sock___70 *igmp_sk;
	struct sock___70 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___70 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___70 *notifier_ops;
	struct fib_notifier_ops___70 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___88 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___88 *fqdir;
};

struct netns_sctp___70 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___70 *ctl_sock;
	struct sock___70 *udp4_sock;
	struct sock___70 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___77;

struct netns_bpf___77 {
	struct bpf_prog_array___77 *run_array[2];
	struct bpf_prog___77 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___88 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___70 *nlsk;
	struct sock___70 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___88 xfrm4_dst_ops;
	struct dst_ops___88 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___88 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___70 *rtnl;
	struct sock___70 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___83 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___88 ipv4;
	struct netns_ipv6___88 ipv6;
	struct netns_ieee802154_lowpan___88 ieee802154_lowpan;
	struct netns_sctp___70 sctp;
	struct netns_nf___11 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___83 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___77 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___88 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___70 *crypto_nlsk;
	struct sock___70 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___201 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___201 *root_cset;
};

struct msghdr___72 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___194 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___274 *msg_iocb;
};

struct seq_operations___249 {
	void * (*start)(struct seq_file___249 *, loff_t *);
	void (*stop)(struct seq_file___249 *, void *);
	void * (*next)(struct seq_file___249 *, void *, loff_t *);
	int (*show)(struct seq_file___249 *, void *);
};

struct bpf_iter_aux_info___86;

typedef int (*bpf_iter_init_seq_priv_t___85)(void *, struct bpf_iter_aux_info___86 *);

struct bpf_map___86;

struct bpf_iter_aux_info___86 {
	struct bpf_map___86 *map;
};

struct bpf_iter_seq_info___85 {
	const struct seq_operations___249 *seq_ops;
	bpf_iter_init_seq_priv_t___85 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___86;

struct bpf_map_ops___85 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___86 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___86 *, struct file___274 *);
	void (*map_free)(struct bpf_map___86 *);
	int (*map_get_next_key)(struct bpf_map___86 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___86 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___86 *, void *);
	int (*map_lookup_batch)(struct bpf_map___86 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___86 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___86 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___86 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___86 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___86 *, void *);
	int (*map_update_elem)(struct bpf_map___86 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___86 *, void *);
	int (*map_push_elem)(struct bpf_map___86 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___86 *, void *);
	int (*map_peek_elem)(struct bpf_map___86 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___86 *, struct file___274 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___86 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___86 *, void *, struct seq_file___249 *);
	int (*map_check_btf)(const struct bpf_map___86 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___86 *, struct bpf_prog_aux___86 *);
	void (*map_poke_untrack)(struct bpf_map___86 *, struct bpf_prog_aux___86 *);
	void (*map_poke_run)(struct bpf_map___86 *, u32, struct bpf_prog___77 *, struct bpf_prog___77 *);
	int (*map_direct_value_addr)(const struct bpf_map___86 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___86 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___86 *, struct vm_area_struct___279 *);
	__poll_t (*map_poll)(struct bpf_map___86 *, struct file___274 *, struct poll_table_struct___195 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___86 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___86 *, const struct bpf_map___86 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___86 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___85 *iter_seq_info;
};

struct bpf_map___86 {
	const struct bpf_map_ops___85 *ops;
	struct bpf_map___86 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___139 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___85;

struct bpf_jit_poke_descriptor___85;

struct bpf_prog_ops___77;

struct btf_mod_pair___85;

struct bpf_prog_offload___83;

struct bpf_prog_aux___86 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___77 *dst_prog;
	struct bpf_trampoline___85 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___77 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___85 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___77 *ops;
	struct bpf_map___86 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___85 *used_btfs;
	struct bpf_prog___77 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___86 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___83 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___77 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___86 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___83;

struct bpf_map_dev_ops___83 {
	int (*map_get_next_key)(struct bpf_offloaded_map___83 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___83 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___83 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___83 *, void *);
};

struct bpf_offloaded_map___83 {
	struct bpf_map___86 map;
	struct net_device___83 *netdev;
	const struct bpf_map_dev_ops___83 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___83(struct sk_buff___84 **);

struct bpf_xdp_entity___77 {
	struct bpf_prog___77 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___83;

struct net_device_ops___83;

struct l3mdev_ops___70;

struct ndisc_ops___52;

struct xfrmdev_ops___83;

struct header_ops___83;

struct in_device___11;

struct inet6_dev___52;

struct netdev_rx_queue___83;

struct mini_Qdisc___77;

struct netdev_queue___83;

struct Qdisc___77;

struct rtnl_link_ops___77;

struct dcbnl_rtnl_ops___83;

struct udp_tunnel_nic_info___2;

struct net_device___83 {
	char name[16];
	struct netdev_name_node___83 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___83 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___70 *l3mdev_ops;
	const struct ndisc_ops___52 *ndisc_ops;
	const struct xfrmdev_ops___83 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___83 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___262 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___11 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___52 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___83 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___77 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___83 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___77 *miniq_ingress;
	struct netdev_queue___83 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___83 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___77 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___77 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___83 = 0,
		NETREG_REGISTERED___83 = 1,
		NETREG_UNREGISTERING___83 = 2,
		NETREG_UNREGISTERED___83 = 3,
		NETREG_RELEASED___83 = 4,
		NETREG_DUMMY___83 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___83 = 0,
		RTNL_LINK_INITIALIZING___83 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___83 *);
	struct netpoll_info *npinfo;
	possible_net_t___83 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___255 dev;
	const struct attribute_group___262 *sysfs_groups[4];
	const struct attribute_group___262 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___77 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___83 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info___2 *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___77 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___14 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___77 *);
};

struct bpf_prog_ops___77 {
	int (*test_run)(struct bpf_prog___77 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___83 {
	struct bpf_prog___77 *prog;
	struct net_device___83 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___85 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___77 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___258 *mod;
};

struct bpf_jit_poke_descriptor___85 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___86 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___85 {
	struct btf *btf;
	struct module___258 *module;
};

struct bpf_prog_array_item___77 {
	struct bpf_prog___77 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___77 {
	struct callback_head rcu;
	struct bpf_prog_array_item___77 items[0];
};

typedef int (*bpf_iter_attach_target_t___6)(struct bpf_prog___77 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___86 *);

typedef void (*bpf_iter_detach_target_t___6)(struct bpf_iter_aux_info___86 *);

typedef void (*bpf_iter_show_fdinfo_t___6)(const struct bpf_iter_aux_info___86 *, struct seq_file___249 *);

typedef int (*bpf_iter_fill_link_info_t___6)(const struct bpf_iter_aux_info___86 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___14 * (*bpf_iter_get_func_proto_t___7)(enum bpf_func_id, const struct bpf_prog___77 *);

struct bpf_iter_reg___6 {
	const char *target;
	bpf_iter_attach_target_t___6 attach_target;
	bpf_iter_detach_target_t___6 detach_target;
	bpf_iter_show_fdinfo_t___6 show_fdinfo;
	bpf_iter_fill_link_info_t___6 fill_link_info;
	bpf_iter_get_func_proto_t___7 get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___85 *seq_info;
};

struct bpf_iter_meta___7 {
	union {
		struct seq_file___249 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct sk_buff___84 {
	union {
		struct {
			struct sk_buff___84 *next;
			struct sk_buff___84 *prev;
			union {
				struct net_device___83 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___70 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___84 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct cftype___201;

struct cgroup_subsys___201 {
	struct cgroup_subsys_state___201 * (*css_alloc)(struct cgroup_subsys_state___201 *);
	int (*css_online)(struct cgroup_subsys_state___201 *);
	void (*css_offline)(struct cgroup_subsys_state___201 *);
	void (*css_released)(struct cgroup_subsys_state___201 *);
	void (*css_free)(struct cgroup_subsys_state___201 *);
	void (*css_reset)(struct cgroup_subsys_state___201 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___201 *, int);
	int (*css_extra_stat_show)(struct seq_file___249 *, struct cgroup_subsys_state___201 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___281 *, struct css_set___201 *);
	void (*cancel_fork)(struct task_struct___281 *, struct css_set___201 *);
	void (*fork)(struct task_struct___281 *);
	void (*exit)(struct task_struct___281 *);
	void (*release)(struct task_struct___281 *);
	void (*bind)(struct cgroup_subsys_state___201 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___201 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___201 *dfl_cftypes;
	struct cftype___201 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___201 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___201 *updated_children;
	struct cgroup___201 *updated_next;
};

struct cgroup_root___201 {
	struct kernfs_root___262 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___201 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___201 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___201 *ss;
	struct list_head node;
	struct kernfs_ops___262 *kf_ops;
	int (*open)(struct kernfs_open_file___262 *);
	void (*release)(struct kernfs_open_file___262 *);
	u64 (*read_u64)(struct cgroup_subsys_state___201 *, struct cftype___201 *);
	s64 (*read_s64)(struct cgroup_subsys_state___201 *, struct cftype___201 *);
	int (*seq_show)(struct seq_file___249 *, void *);
	void * (*seq_start)(struct seq_file___249 *, loff_t *);
	void * (*seq_next)(struct seq_file___249 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___249 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___201 *, struct cftype___201 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___201 *, struct cftype___201 *, s64);
	ssize_t (*write)(struct kernfs_open_file___262 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___262 *, struct poll_table_struct___195 *);
};

struct dev_pm_ops___255 {
	int (*prepare)(struct device___255 *);
	void (*complete)(struct device___255 *);
	int (*suspend)(struct device___255 *);
	int (*resume)(struct device___255 *);
	int (*freeze)(struct device___255 *);
	int (*thaw)(struct device___255 *);
	int (*poweroff)(struct device___255 *);
	int (*restore)(struct device___255 *);
	int (*suspend_late)(struct device___255 *);
	int (*resume_early)(struct device___255 *);
	int (*freeze_late)(struct device___255 *);
	int (*thaw_early)(struct device___255 *);
	int (*poweroff_late)(struct device___255 *);
	int (*restore_early)(struct device___255 *);
	int (*suspend_noirq)(struct device___255 *);
	int (*resume_noirq)(struct device___255 *);
	int (*freeze_noirq)(struct device___255 *);
	int (*thaw_noirq)(struct device___255 *);
	int (*poweroff_noirq)(struct device___255 *);
	int (*restore_noirq)(struct device___255 *);
	int (*runtime_suspend)(struct device___255 *);
	int (*runtime_resume)(struct device___255 *);
	int (*runtime_idle)(struct device___255 *);
};

struct wakeup_source___255 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___255 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___255 {
	struct dev_pm_ops___255 ops;
	int (*start)(struct device___255 *);
	void (*detach)(struct device___255 *, bool);
	int (*activate)(struct device___255 *);
	void (*sync)(struct device___255 *);
	void (*dismiss)(struct device___255 *);
};

struct bus_type___255 {
	const char *name;
	const char *dev_name;
	struct device___255 *dev_root;
	const struct attribute_group___262 **bus_groups;
	const struct attribute_group___262 **dev_groups;
	const struct attribute_group___262 **drv_groups;
	int (*match)(struct device___255 *, struct device_driver___255 *);
	int (*uevent)(struct device___255 *, struct kobj_uevent_env *);
	int (*probe)(struct device___255 *);
	void (*sync_state)(struct device___255 *);
	void (*remove)(struct device___255 *);
	void (*shutdown)(struct device___255 *);
	int (*online)(struct device___255 *);
	int (*offline)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	int (*num_vf)(struct device___255 *);
	int (*dma_configure)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___255 {
	const char *name;
	struct bus_type___255 *bus;
	struct module___258 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___255 *);
	void (*sync_state)(struct device___255 *);
	int (*remove)(struct device___255 *);
	void (*shutdown)(struct device___255 *);
	int (*suspend)(struct device___255 *, pm_message_t);
	int (*resume)(struct device___255 *);
	const struct attribute_group___262 **groups;
	const struct attribute_group___262 **dev_groups;
	const struct dev_pm_ops___255 *pm;
	void (*coredump)(struct device___255 *);
	struct driver_private *p;
};

struct device_type___255 {
	const char *name;
	const struct attribute_group___262 **groups;
	int (*uevent)(struct device___255 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___255 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___255 *);
	const struct dev_pm_ops___255 *pm;
};

struct class___255 {
	const char *name;
	struct module___258 *owner;
	const struct attribute_group___262 **class_groups;
	const struct attribute_group___262 **dev_groups;
	struct kobject___262 *dev_kobj;
	int (*dev_uevent)(struct device___255 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___255 *, umode_t *);
	void (*class_release)(struct class___255 *);
	void (*dev_release)(struct device___255 *);
	int (*shutdown_pre)(struct device___255 *);
	const struct kobj_ns_type_operations___70 *ns_type;
	const void * (*namespace)(struct device___255 *);
	void (*get_ownership)(struct device___255 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___255 *pm;
	struct subsys_private *p;
};

struct block_device_operations___165;

struct gendisk___168 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___168 *part0;
	const struct block_device_operations___165 *fops;
	struct request_queue___165 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___151 *bdi;
	struct kobject___262 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___262 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___165 {
	struct bio___165 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___191 *bip_vec;
	struct bio_vec___191 bip_inline_vecs[0];
};

struct blkcg___153;

struct blkg_policy_data___153;

struct blkcg_gq___153 {
	struct request_queue___165 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___153 *blkcg;
	struct blkcg_gq___153 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___153 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___165 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___165(struct request___165 *);

typedef void integrity_complete_fn___165(struct request___165 *, unsigned int);

struct blk_integrity_profile___165 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___165 *prepare_fn;
	integrity_complete_fn___165 *complete_fn;
	const char *name;
};

struct block_device_operations___165 {
	blk_qc_t (*submit_bio)(struct bio___165 *);
	int (*open)(struct block_device___168 *, fmode_t);
	void (*release)(struct gendisk___168 *, fmode_t);
	int (*rw_page)(struct block_device___168 *, sector_t, struct page___279 *, unsigned int);
	int (*ioctl)(struct block_device___168 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___168 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___168 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___168 *);
	int (*getgeo)(struct block_device___168 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___168 *, bool);
	void (*swap_slot_free_notify)(struct block_device___168 *, long unsigned int);
	int (*report_zones)(struct gendisk___168 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___168 *, umode_t *);
	struct module___258 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___168 *, sector_t *);
};

typedef void rq_end_io_fn___165(struct request___165 *, blk_status_t);

struct request___165 {
	struct request_queue___165 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___160 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___165 *bio;
	struct bio___165 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___191 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___165 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___165 *saved_end_io;
		} flush;
	};
	struct gendisk___168 *rq_disk;
	struct block_device___168 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___165 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___160 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___165 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___262 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___274 *debugfs_dir;
	struct dentry___274 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___165;

struct elevator_mq_ops___165 {
	int (*init_sched)(struct request_queue___165 *, struct elevator_type___165 *);
	void (*exit_sched)(struct elevator_queue___165 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___160 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___160 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___160 *);
	bool (*allow_merge)(struct request_queue___165 *, struct request___165 *, struct bio___165 *);
	bool (*bio_merge)(struct request_queue___165 *, struct bio___165 *, unsigned int);
	int (*request_merge)(struct request_queue___165 *, struct request___165 **, struct bio___165 *);
	void (*request_merged)(struct request_queue___165 *, struct request___165 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___165 *, struct request___165 *, struct request___165 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___165 *);
	void (*finish_request)(struct request___165 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___160 *, struct list_head *, bool);
	struct request___165 * (*dispatch_request)(struct blk_mq_hw_ctx___160 *);
	bool (*has_work)(struct blk_mq_hw_ctx___160 *);
	void (*completed_request)(struct request___165 *, u64);
	void (*requeue_request)(struct request___165 *);
	struct request___165 * (*former_request)(struct request_queue___165 *, struct request___165 *);
	struct request___165 * (*next_request)(struct request_queue___165 *, struct request___165 *);
	void (*init_icq)(struct io_cq___165 *);
	void (*exit_icq)(struct io_cq___165 *);
};

struct elv_fs_entry___165;

struct elevator_type___165 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___165 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___165 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___258 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___165 {
	struct elevator_type___165 *type;
	void *elevator_data;
	struct kobject___262 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___165 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___165 *, char *);
	ssize_t (*store)(struct elevator_queue___165 *, const char *, size_t);
};

struct blk_mq_queue_data___160;

struct blk_mq_ops___160 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___160 *, const struct blk_mq_queue_data___160 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___160 *);
	int (*get_budget)(struct request_queue___165 *);
	void (*put_budget)(struct request_queue___165 *, int);
	void (*set_rq_budget_token)(struct request___165 *, int);
	int (*get_rq_budget_token)(struct request___165 *);
	enum blk_eh_timer_return (*timeout)(struct request___165 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___160 *);
	void (*complete)(struct request___165 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___160 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___160 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___160 *, struct request___165 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___160 *, struct request___165 *, unsigned int);
	void (*initialize_rq_fn)(struct request___165 *);
	void (*cleanup_rq)(struct request___165 *);
	bool (*busy)(struct request_queue___165 *);
	int (*map_queues)(struct blk_mq_tag_set___160 *);
	void (*show_rq)(struct seq_file___249 *, struct request___165 *);
};

struct blk_mq_tag_set___160 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___160 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___160 {
	struct request___165 *rq;
	bool last;
};

struct blkcg_policy_data___153;

struct blkcg___153 {
	struct cgroup_subsys_state___201 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___153 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___153 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___153 {
	struct blkcg___153 *blkcg;
	int plid;
};

struct blkg_policy_data___153 {
	struct blkcg_gq___153 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___139 {
	struct mem_cgroup___139 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___139 {
	struct lruvec___147 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___139 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___139 *memcg;
};

struct obj_cgroup___139 {
	struct percpu_ref refcnt;
	struct mem_cgroup___139 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct socket_wq___71 {
	wait_queue_head_t wait;
	struct fasync_struct___274 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___71;

struct socket___72 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___274 *file;
	struct sock___70 *sk;
	const struct proto_ops___71 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___71 wq;
};

typedef int (*sk_read_actor_t___70)(read_descriptor_t *, struct sk_buff___84 *, unsigned int, size_t);

struct proto_ops___71 {
	int family;
	struct module___258 *owner;
	int (*release)(struct socket___72 *);
	int (*bind)(struct socket___72 *, struct sockaddr *, int);
	int (*connect)(struct socket___72 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___72 *, struct socket___72 *);
	int (*accept)(struct socket___72 *, struct socket___72 *, int, bool);
	int (*getname)(struct socket___72 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___274 *, struct socket___72 *, struct poll_table_struct___195 *);
	int (*ioctl)(struct socket___72 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___72 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___72 *, void *, bool, bool);
	int (*listen)(struct socket___72 *, int);
	int (*shutdown)(struct socket___72 *, int);
	int (*setsockopt)(struct socket___72 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___72 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___249 *, struct socket___72 *);
	int (*sendmsg)(struct socket___72 *, struct msghdr___72 *, size_t);
	int (*recvmsg)(struct socket___72 *, struct msghdr___72 *, size_t, int);
	int (*mmap)(struct file___274 *, struct socket___72 *, struct vm_area_struct___279 *);
	ssize_t (*sendpage)(struct socket___72 *, struct page___279 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___72 *, loff_t *, struct pipe_inode_info___115 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___70 *, int);
	int (*peek_len)(struct socket___72 *);
	int (*read_sock)(struct sock___70 *, read_descriptor_t *, sk_read_actor_t___70);
	int (*sendpage_locked)(struct sock___70 *, struct page___279 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___70 *, struct msghdr___72 *, size_t);
	int (*set_rcvlowat)(struct sock___70 *, int);
};

struct pipe_buf_operations___115;

struct pipe_buffer___115 {
	struct page___279 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___115 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___115 {
	int (*confirm)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
	void (*release)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
	bool (*try_steal)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
	bool (*get)(struct pipe_inode_info___115 *, struct pipe_buffer___115 *);
};

typedef struct bio_vec___191 skb_frag_t___31;

struct skb_shared_info___29 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___84 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___31 frags[17];
};

struct ip_mc_list___3 {
	struct in_device___11 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___3 *next;
		struct ip_mc_list___3 *next_rcu;
	};
	struct ip_mc_list___3 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___11;

struct neigh_parms___70;

struct in_device___11 {
	struct net_device___83 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___11 *ifa_list;
	struct ip_mc_list___3 *mc_list;
	struct ip_mc_list___3 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___3 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___70 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct inet_frags___88;

struct fqdir___88 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___88 *f;
	struct net___88 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___88;

struct inet_frags___88 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___88 *, const void *);
	void (*destructor)(struct inet_frag_queue___88 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___88 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___84 *fragments_tail;
	struct sk_buff___84 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___88 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___43 {
	struct ip_ra_chain___43 *next;
	struct sock___70 *sk;
	union {
		void (*destructor)(struct sock___70 *);
		struct sock___70 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___70;

struct fib_lookup_arg___70;

struct fib_rules_ops___70 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___70 *, struct flowi *, int, struct fib_lookup_arg___70 *);
	bool (*suppress)(struct fib_rule___70 *, int, struct fib_lookup_arg___70 *);
	int (*match)(struct fib_rule___70 *, struct flowi *, int);
	int (*configure)(struct fib_rule___70 *, struct sk_buff___84 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___70 *);
	int (*compare)(struct fib_rule___70 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___70 *, struct sk_buff___84 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___70 *);
	void (*flush_cache)(struct fib_rules_ops___70 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___258 *owner;
	struct net___88 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___70 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___88 *);
	int (*fib_dump)(struct net___88 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___258 *owner;
	struct callback_head rcu;
};

struct xfrm_state___14;

struct lwtunnel_state___46;

struct dst_entry___70 {
	struct net_device___83 *dev;
	struct dst_ops___88 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___14 *xfrm;
	int (*input)(struct sk_buff___84 *);
	int (*output)(struct net___88 *, struct sock___70 *, struct sk_buff___84 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___46 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___70;

struct neigh_ops___70;

struct neighbour___70 {
	struct neighbour___70 *next;
	struct neigh_table___70 *tbl;
	struct neigh_parms___70 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___83 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___70 *, struct sk_buff___84 *);
	const struct neigh_ops___70 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___83 *dev;
	u8 primary_key[0];
};

struct rtable___20;

struct fnhe_hash_bucket___19;

struct fib_nh_common___19 {
	struct net_device___83 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___46 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___20 **nhc_pcpu_rth_output;
	struct rtable___20 *nhc_rth_input;
	struct fnhe_hash_bucket___19 *nhc_exceptions;
};

struct fib6_nh___19 {
	struct fib_nh_common___19 nh_common;
	long unsigned int last_probe;
	struct rt6_info___19 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___19;

struct nexthop___10;

struct fib6_info___19 {
	struct fib6_table___19 *fib6_table;
	struct fib6_info___19 *fib6_next;
	struct fib6_node___19 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___10 *nh;
	struct fib6_nh___19 fib6_nh[0];
};

struct rt6_info___19 {
	struct dst_entry___70 dst;
	struct fib6_info___19 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___52 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___19 {
	struct fib6_node___19 *parent;
	struct fib6_node___19 *left;
	struct fib6_node___19 *right;
	struct fib6_node___19 *subtree;
	struct fib6_info___19 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___19 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___19 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___19 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct seq_net_private___8 {
	struct net___88 *net;
};

struct pernet_operations___24 {
	struct list_head list;
	int (*init)(struct net___88 *);
	void (*pre_exit)(struct net___88 *);
	void (*exit)(struct net___88 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___83 {
	int (*ieee_getets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___83 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___83 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___83 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___83 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___83 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___83 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___83 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___83 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___83 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___83 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___83 *);
	u8 (*setstate)(struct net_device___83 *, u8);
	void (*getpermhwaddr)(struct net_device___83 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___83 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___83 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___83 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___83 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___83 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___83 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___83 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___83 *, int, u8 *);
	void (*setpfccfg)(struct net_device___83 *, int, u8);
	void (*getpfccfg)(struct net_device___83 *, int, u8 *);
	u8 (*setall)(struct net_device___83 *);
	u8 (*getcap)(struct net_device___83 *, int, u8 *);
	int (*getnumtcs)(struct net_device___83 *, int, u8 *);
	int (*setnumtcs)(struct net_device___83 *, int, u8);
	u8 (*getpfcstate)(struct net_device___83 *);
	void (*setpfcstate)(struct net_device___83 *, u8);
	void (*getbcncfg)(struct net_device___83 *, int, u32 *);
	void (*setbcncfg)(struct net_device___83 *, int, u32);
	void (*getbcnrp)(struct net_device___83 *, int, u8 *);
	void (*setbcnrp)(struct net_device___83 *, int, u8);
	int (*setapp)(struct net_device___83 *, u8, u16, u8);
	int (*getapp)(struct net_device___83 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___83 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___83 *, int, u8);
	u8 (*getdcbx)(struct net_device___83 *);
	u8 (*setdcbx)(struct net_device___83 *, u8);
	int (*peer_getappinfo)(struct net_device___83 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___83 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___83 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___83 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___83 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___83 *, struct dcbnl_buffer *);
};

struct xdp_rxq_info___83 {
	struct net_device___83 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___83 {
	struct net_device___83 *dev;
};

struct xdp_buff___83 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___83 *rxq;
	struct xdp_txq_info___83 *txq;
	u32 frame_sz;
};

struct xdp_frame___83 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___83 *dev_rx;
};

struct netlink_callback___83 {
	struct sk_buff___84 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___84 *, struct netlink_callback___83 *);
	int (*done)(struct netlink_callback___83 *);
	void *data;
	struct module___258 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___83 {
	int (*create)(struct sk_buff___84 *, struct net_device___83 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___84 *, unsigned char *);
	int (*cache)(const struct neighbour___70 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___83 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___84 *);
};

struct netdev_queue___83 {
	struct net_device___83 *dev;
	struct Qdisc___77 *qdisc;
	struct Qdisc___77 *qdisc_sleeping;
	struct kobject___262 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___83 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___77 {
	struct sk_buff___84 *head;
	struct sk_buff___84 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___77;

struct Qdisc___77 {
	int (*enqueue)(struct sk_buff___84 *, struct Qdisc___77 *, struct sk_buff___84 **);
	struct sk_buff___84 * (*dequeue)(struct Qdisc___77 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___77 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___83 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___83 gso_skb;
	struct qdisc_skb_head___77 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___77 *next_sched;
	struct sk_buff_head___83 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___83 {
	struct xdp_rxq_info___83 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___262 kobj;
	struct net_device___83 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___83 {
	enum net_device_path_type type;
	const struct net_device___83 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___83 = 0,
				DEV_PATH_BR_VLAN_TAG___83 = 1,
				DEV_PATH_BR_VLAN_UNTAG___83 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___83 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___83 {
	const struct net_device___83 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___83 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___77 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___83 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___83 {
	int (*xdo_dev_state_add)(struct xfrm_state___14 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___14 *);
	void (*xdo_dev_state_free)(struct xfrm_state___14 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___84 *, struct xfrm_state___14 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___14 *);
};

struct xfrm_state_offload___14 {
	struct net_device___83 *dev;
	struct net_device___83 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___14;

struct xfrm_type_offload___14;

struct xfrm_state___14 {
	possible_net_t___83 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___70 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___14 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___14 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___279 xfrag;
	const struct xfrm_type___14 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___14 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___83 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___83 *dev;
	const char *name;
};

struct net_device_ops___83 {
	int (*ndo_init)(struct net_device___83 *);
	void (*ndo_uninit)(struct net_device___83 *);
	int (*ndo_open)(struct net_device___83 *);
	int (*ndo_stop)(struct net_device___83 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___84 *, struct net_device___83 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___84 *, struct net_device___83 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___83 *, struct sk_buff___84 *, struct net_device___83 *);
	void (*ndo_change_rx_flags)(struct net_device___83 *, int);
	void (*ndo_set_rx_mode)(struct net_device___83 *);
	int (*ndo_set_mac_address)(struct net_device___83 *, void *);
	int (*ndo_validate_addr)(struct net_device___83 *);
	int (*ndo_do_ioctl)(struct net_device___83 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___83 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___83 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___83 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___83 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___83 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___83 *, int);
	int (*ndo_neigh_setup)(struct net_device___83 *, struct neigh_parms___70 *);
	void (*ndo_tx_timeout)(struct net_device___83 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___83 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___83 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___83 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___83 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___83 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___83 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___83 *);
	int (*ndo_netpoll_setup)(struct net_device___83 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___83 *);
	int (*ndo_set_vf_mac)(struct net_device___83 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___83 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___83 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___83 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___83 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___83 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___83 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___83 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___83 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___83 *, int, struct sk_buff___84 *);
	int (*ndo_get_vf_guid)(struct net_device___83 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___83 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___83 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___83 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___83 *);
	int (*ndo_fcoe_disable)(struct net_device___83 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___83 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___83 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___83 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___83 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___83 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___83 *, const struct sk_buff___84 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___83 *, struct net_device___83 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___83 *, struct net_device___83 *);
	struct net_device___83 * (*ndo_get_xmit_slave)(struct net_device___83 *, struct sk_buff___84 *, bool);
	struct net_device___83 * (*ndo_sk_get_lower_dev)(struct net_device___83 *, struct sock___70 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___83 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___83 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___83 *, struct neighbour___70 *);
	void (*ndo_neigh_destroy)(struct net_device___83 *, struct neighbour___70 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___84 *, struct netlink_callback___83 *, struct net_device___83 *, struct net_device___83 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___84 *, struct nlattr **, struct net_device___83 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___83 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___84 *, u32, u32, struct net_device___83 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___83 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___83 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___83 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___83 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___83 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___83 *, struct net_device___83 *);
	void (*ndo_dfwd_del_station)(struct net_device___83 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___83 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___83 *);
	int (*ndo_change_proto_down)(struct net_device___83 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___83 *, struct sk_buff___84 *);
	void (*ndo_set_rx_headroom)(struct net_device___83 *, int);
	int (*ndo_bpf)(struct net_device___83 *, struct netdev_bpf___83 *);
	int (*ndo_xdp_xmit)(struct net_device___83 *, int, struct xdp_frame___83 **, u32);
	struct net_device___83 * (*ndo_xdp_get_xmit_slave)(struct net_device___83 *, struct xdp_buff___83 *);
	int (*ndo_xsk_wakeup)(struct net_device___83 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___83 *);
	int (*ndo_tunnel_ctl)(struct net_device___83 *, struct ip_tunnel_parm *, int);
	struct net_device___83 * (*ndo_get_peer_dev)(struct net_device___83 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___83 *, struct net_device_path___83 *);
};

struct neigh_parms___70 {
	possible_net_t___83 net;
	struct net_device___83 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___70 *);
	struct neigh_table___70 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___70 {
	u32 (*l3mdev_fib_table)(const struct net_device___83 *);
	struct sk_buff___84 * (*l3mdev_l3_rcv)(struct net_device___83 *, struct sk_buff___84 *, u16);
	struct sk_buff___84 * (*l3mdev_l3_out)(struct net_device___83 *, struct sock___70 *, struct sk_buff___84 *, u16);
	struct dst_entry___70 * (*l3mdev_link_scope_lookup)(const struct net_device___83 *, struct flowi6 *);
};

struct ndisc_ops___52 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___83 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___83 *, struct neighbour___70 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___83 *, u8, struct neighbour___70 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___83 *, struct sk_buff___84 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___88 *, struct net_device___83 *, const struct prefix_info *, struct inet6_dev___52 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___52;

struct ifacaddr6___19;

struct inet6_dev___52 {
	struct net_device___83 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___52 *mc_list;
	struct ifmcaddr6___52 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___83 mc_query_queue;
	struct sk_buff_head___83 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___19 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___70 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___77;

struct tcf_block___77;

struct mini_Qdisc___77 {
	struct tcf_proto___77 *filter_list;
	struct tcf_block___77 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___77 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___83 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___83 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___88 *, struct net_device___83 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___83 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___83 *, struct list_head *);
	size_t (*get_size)(const struct net_device___83 *);
	int (*fill_info)(struct sk_buff___84 *, const struct net_device___83 *);
	size_t (*get_xstats_size)(const struct net_device___83 *);
	int (*fill_xstats)(struct sk_buff___84 *, const struct net_device___83 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___83 *, struct net_device___83 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___83 *, const struct net_device___83 *);
	int (*fill_slave_info)(struct sk_buff___84 *, const struct net_device___83 *, const struct net_device___83 *);
	struct net___88 * (*get_link_net)(const struct net_device___83 *);
	size_t (*get_linkxstats_size)(const struct net_device___83 *, int);
	int (*fill_linkxstats)(struct sk_buff___84 *, const struct net_device___83 *, int *, int);
};

struct udp_tunnel_nic_info___2 {
	int (*set_port)(struct net_device___83 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	int (*unset_port)(struct net_device___83 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	int (*sync_table)(struct net_device___83 *, unsigned int);
	struct udp_tunnel_nic_shared *shared;
	unsigned int flags;
	struct udp_tunnel_nic_table_info tables[4];
};

struct in_ifaddr___11 {
	struct hlist_node hash;
	struct in_ifaddr___11 *ifa_next;
	struct in_device___11 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct gnet_dump___77 {
	spinlock_t *lock;
	struct sk_buff___84 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___6 {
	struct nlmsghdr *nlh;
	struct net___88 *nl_net;
	u32 portid;
	u8 skip_notify;
	u8 skip_notify_kernel;
	long: 56;
	long: 64;
	long: 64;
};

struct Qdisc_class_ops___77;

struct Qdisc_ops___77 {
	struct Qdisc_ops___77 *next;
	const struct Qdisc_class_ops___77 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___84 *, struct Qdisc___77 *, struct sk_buff___84 **);
	struct sk_buff___84 * (*dequeue)(struct Qdisc___77 *);
	struct sk_buff___84 * (*peek)(struct Qdisc___77 *);
	int (*init)(struct Qdisc___77 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___77 *);
	void (*destroy)(struct Qdisc___77 *);
	int (*change)(struct Qdisc___77 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___77 *);
	int (*change_tx_queue_len)(struct Qdisc___77 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___77 *, unsigned int);
	int (*dump)(struct Qdisc___77 *, struct sk_buff___84 *);
	int (*dump_stats)(struct Qdisc___77 *, struct gnet_dump___77 *);
	void (*ingress_block_set)(struct Qdisc___77 *, u32);
	void (*egress_block_set)(struct Qdisc___77 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___77 *);
	u32 (*egress_block_get)(struct Qdisc___77 *);
	struct module___258 *owner;
};

struct Qdisc_class_ops___77 {
	unsigned int flags;
	struct netdev_queue___83 * (*select_queue)(struct Qdisc___77 *, struct tcmsg *);
	int (*graft)(struct Qdisc___77 *, long unsigned int, struct Qdisc___77 *, struct Qdisc___77 **, struct netlink_ext_ack *);
	struct Qdisc___77 * (*leaf)(struct Qdisc___77 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___77 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___77 *, u32);
	int (*change)(struct Qdisc___77 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___77 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___77 *, struct qdisc_walker *);
	struct tcf_block___77 * (*tcf_block)(struct Qdisc___77 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___77 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___77 *, long unsigned int);
	int (*dump)(struct Qdisc___77 *, long unsigned int, struct sk_buff___84 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___77 *, long unsigned int, struct gnet_dump___77 *);
};

struct tcf_chain___77;

struct tcf_block___77 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___88 *net;
	struct Qdisc___77 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___77 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___77;

struct tcf_proto_ops___77;

struct tcf_proto___77 {
	struct tcf_proto___77 *next;
	void *root;
	int (*classify)(struct sk_buff___84 *, const struct tcf_proto___77 *, struct tcf_result___77 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___77 *ops;
	struct tcf_chain___77 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___77 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___77 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___77 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___84 *, const struct tcf_proto___77 *, struct tcf_result___77 *);
	int (*init)(struct tcf_proto___77 *);
	void (*destroy)(struct tcf_proto___77 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___77 *, u32);
	void (*put)(struct tcf_proto___77 *, void *);
	int (*change)(struct net___88 *, struct sk_buff___84 *, struct tcf_proto___77 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___77 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___77 *);
	void (*walk)(struct tcf_proto___77 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___77 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___77 *, void *);
	void (*hw_del)(struct tcf_proto___77 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___88 *, struct tcf_chain___77 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___88 *, struct tcf_proto___77 *, void *, struct sk_buff___84 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___88 *, struct tcf_proto___77 *, void *, struct sk_buff___84 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___84 *, struct net___88 *, void *);
	struct module___258 *owner;
	int flags;
};

struct tcf_chain___77 {
	struct mutex filter_chain_lock;
	struct tcf_proto___77 *filter_chain;
	struct list_head list;
	struct tcf_block___77 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___77 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___70 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___77 *prog;
};

struct bpf_sk_lookup_kern___4 {
	u16 family;
	u16 protocol;
	__be16 sport;
	u16 dport;
	struct {
		__be32 saddr;
		__be32 daddr;
	} v4;
	struct {
		const struct in6_addr *saddr;
		const struct in6_addr *daddr;
	} v6;
	struct sock___70 *selected_sk;
	bool no_reuseport;
};

typedef struct poll_table_struct___195 poll_table___50;

struct pneigh_entry___70;

struct neigh_hash_table___70;

struct neigh_table___70 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___83 *, __u32 *);
	bool (*key_eq)(const struct neighbour___70 *, const void *);
	int (*constructor)(struct neighbour___70 *);
	int (*pconstructor)(struct pneigh_entry___70 *);
	void (*pdestructor)(struct pneigh_entry___70 *);
	void (*proxy_redo)(struct sk_buff___84 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___83 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___70 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___83 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___70 *nht;
	struct pneigh_entry___70 **phash_buckets;
};

struct neigh_ops___70 {
	int family;
	void (*solicit)(struct neighbour___70 *, struct sk_buff___84 *);
	void (*error_report)(struct neighbour___70 *, struct sk_buff___84 *);
	int (*output)(struct neighbour___70 *, struct sk_buff___84 *);
	int (*connected_output)(struct neighbour___70 *, struct sk_buff___84 *);
};

struct pneigh_entry___70 {
	struct pneigh_entry___70 *next;
	possible_net_t___83 net;
	struct net_device___83 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___70 {
	struct neighbour___70 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___46 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___88 *, struct sock___70 *, struct sk_buff___84 *);
	int (*orig_input)(struct sk_buff___84 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___70 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___70 *ctarget;
	struct net___88 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___70 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___70 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___55;

struct timewait_sock_ops___54;

struct proto___70 {
	void (*close)(struct sock___70 *, long int);
	int (*pre_connect)(struct sock___70 *, struct sockaddr *, int);
	int (*connect)(struct sock___70 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___70 *, int);
	struct sock___70 * (*accept)(struct sock___70 *, int, int *, bool);
	int (*ioctl)(struct sock___70 *, int, long unsigned int);
	int (*init)(struct sock___70 *);
	void (*destroy)(struct sock___70 *);
	void (*shutdown)(struct sock___70 *, int);
	int (*setsockopt)(struct sock___70 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___70 *, int, int, char *, int *);
	void (*keepalive)(struct sock___70 *, int);
	int (*compat_ioctl)(struct sock___70 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___70 *, struct msghdr___72 *, size_t);
	int (*recvmsg)(struct sock___70 *, struct msghdr___72 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___70 *, struct page___279 *, int, size_t, int);
	int (*bind)(struct sock___70 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___70 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___70 *, struct sk_buff___84 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___70 *);
	int (*hash)(struct sock___70 *);
	void (*unhash)(struct sock___70 *);
	void (*rehash)(struct sock___70 *);
	int (*get_port)(struct sock___70 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___70 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___70 *, int);
	bool (*sock_is_readable)(struct sock___70 *);
	void (*enter_memory_pressure)(struct sock___70 *);
	void (*leave_memory_pressure)(struct sock___70 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___55 *rsk_prot;
	struct timewait_sock_ops___54 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___258 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___70 *, int);
};

struct xfrm_policy_queue___14 {
	struct sk_buff_head___83 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___14 {
	possible_net_t___83 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___14 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___21 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___77 *prog;
	struct sock___70 *socks[0];
};

struct request_sock___56;

struct request_sock_ops___55 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___70 *, struct request_sock___56 *);
	void (*send_ack)(const struct sock___70 *, struct sk_buff___84 *, struct request_sock___56 *);
	void (*send_reset)(const struct sock___70 *, struct sk_buff___84 *);
	void (*destructor)(struct request_sock___56 *);
	void (*syn_ack_timeout)(const struct request_sock___56 *);
};

struct timewait_sock_ops___54 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___70 *, struct sock___70 *, void *);
	void (*twsk_destructor)(struct sock___70 *);
};

struct request_sock___56 {
	struct sock_common___70 __req_common;
	struct request_sock___56 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___55 *rsk_ops;
	struct sock___70 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___13 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___70 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___13 {
	struct inet_cork___13 base;
	struct flowi fl;
};

struct ipv6_pinfo___13;

struct inet_sock___13 {
	struct sock___70 sk;
	struct ipv6_pinfo___13 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___13 cork;
};

struct ipv6_fl_socklist___13;

struct ipv6_pinfo___13 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___13 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___84 *pktoptions;
	struct sk_buff___84 *rxpmtu;
	struct inet6_cork cork;
};

struct udp_sock___2 {
	struct inet_sock___13 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	unsigned char encap_enabled: 1;
	unsigned char gro_enabled: 1;
	unsigned char accept_udp_l4: 1;
	unsigned char accept_udp_fraglist: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___70 *, struct sk_buff___84 *);
	int (*encap_err_lookup)(struct sock___70 *, struct sk_buff___84 *);
	void (*encap_destroy)(struct sock___70 *);
	struct sk_buff___84 * (*gro_receive)(struct sock___70 *, struct list_head *, struct sk_buff___84 *);
	int (*gro_complete)(struct sock___70 *, struct sk_buff___84 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___83 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip6_flowlabel___13;

struct ipv6_fl_socklist___13 {
	struct ipv6_fl_socklist___13 *next;
	struct ip6_flowlabel___13 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___52 {
	struct in6_addr mca_addr;
	struct inet6_dev___52 *idev;
	struct ifmcaddr6___52 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___19 {
	struct in6_addr aca_addr;
	struct fib6_info___19 *aca_rt;
	struct ifacaddr6___19 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result___5;

struct fib6_config___6;

struct ipv6_stub___6 {
	int (*ipv6_sock_mc_join)(struct sock___70 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___70 *, int, const struct in6_addr *);
	struct dst_entry___70 * (*ipv6_dst_lookup_flow)(struct net___88 *, const struct sock___70 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___84 *);
	struct fib6_table___19 * (*fib6_get_table)(struct net___88 *, u32);
	int (*fib6_lookup)(struct net___88 *, int, struct flowi6 *, struct fib6_result___5 *, int);
	int (*fib6_table_lookup)(struct net___88 *, struct fib6_table___19 *, int, struct flowi6 *, struct fib6_result___5 *, int);
	void (*fib6_select_path)(const struct net___88 *, struct fib6_result___5 *, struct flowi6 *, int, bool, const struct sk_buff___84 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___5 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___88 *, struct fib6_nh___19 *, struct fib6_config___6 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___19 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___19 *);
	void (*fib6_update_sernum)(struct net___88 *, struct fib6_info___19 *);
	int (*ip6_del_rt)(struct net___88 *, struct fib6_info___19 *, bool);
	void (*fib6_rt_update)(struct net___88 *, struct fib6_info___19 *, struct nl_info___6 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___83 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___84 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___70 *, struct sk_buff___84 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___84 *, int, __be32, int);
	struct neigh_table___70 *nd_tbl;
	int (*ipv6_fragment)(struct net___88 *, struct sock___70 *, struct sk_buff___84 *, int (*)(struct net___88 *, struct sock___70 *, struct sk_buff___84 *));
	struct net_device___83 * (*ipv6_dev_find)(struct net___88 *, const struct in6_addr *, struct net_device___83 *);
};

struct fib6_result___5 {
	struct fib6_nh___19 *nh;
	struct fib6_info___19 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___19 *rt6;
};

struct fib6_config___6 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___6 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct ip6_flowlabel___13 {
	struct ip6_flowlabel___13 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___251 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___88 *fl_net;
};

struct fib_nh_exception___19 {
	struct fib_nh_exception___19 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___20 *fnhe_rth_input;
	struct rtable___20 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___20 {
	struct dst_entry___70 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___19 {
	struct fib_nh_exception___19 *chain;
};

struct fib_info___10;

struct fib_nh___10 {
	struct fib_nh_common___19 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___10 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___10 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___88 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___10 *nh;
	struct callback_head rcu;
	struct fib_nh___10 fib_nh[0];
};

struct nh_info___10;

struct nh_group___10;

struct nexthop___10 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___88 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___10 *nh_info;
		struct nh_group___10 *nh_grp;
	};
};

struct nh_info___10 {
	struct hlist_node dev_hash;
	struct nexthop___10 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___19 fib_nhc;
		struct fib_nh___10 fib_nh;
		struct fib6_nh___19 fib6_nh;
	};
};

struct nh_grp_entry___10;

struct nh_res_bucket___10 {
	struct nh_grp_entry___10 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___10 {
	struct nexthop___10 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___10 *nh_parent;
};

struct nh_res_table___10 {
	struct net___88 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___10 nh_buckets[0];
};

struct nh_group___10 {
	struct nh_group___10 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___10 *res_table;
	struct nh_grp_entry___10 nh_entries[0];
};

struct ip_tunnel_encap {
	u16 type;
	u16 flags;
	__be16 sport;
	__be16 dport;
};

struct ip_tunnel_encap_ops {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___84 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
	int (*err_handler)(struct sk_buff___84 *, u32);
};

struct xfrm_type___14 {
	struct module___258 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___14 *);
	void (*destructor)(struct xfrm_state___14 *);
	int (*input)(struct xfrm_state___14 *, struct sk_buff___84 *);
	int (*output)(struct xfrm_state___14 *, struct sk_buff___84 *);
	int (*reject)(struct xfrm_state___14 *, struct sk_buff___84 *, const struct flowi *);
};

struct xfrm_type_offload___14 {
	struct module___258 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___14 *, struct sk_buff___84 *);
	int (*input_tail)(struct xfrm_state___14 *, struct sk_buff___84 *);
	int (*xmit)(struct xfrm_state___14 *, struct sk_buff___84 *, netdev_features_t);
};

struct udp_skb_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	__u16 cscov;
	__u8 partial_cov;
};

struct udp_dev_scratch {
	u32 _tsize_state;
	u16 len;
	bool is_linear;
	bool csum_unnecessary;
};

struct udp_seq_afinfo {
	sa_family_t family;
	struct udp_table *udp_table;
};

struct udp_iter_state {
	struct seq_net_private___8 p;
	int bucket;
	struct udp_seq_afinfo *bpf_seq_afinfo;
};

struct bpf_iter__udp {
	union {
		struct bpf_iter_meta___7 *meta;
	};
	union {
		struct udp_sock___2 *udp_sk;
	};
	uid_t uid;
	int: 32;
	int bucket;
};

struct inet_cork___14 {
	unsigned int flags;
	__be32 addr;
	struct ip_options___2 *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___70 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___14 {
	struct inet_cork___14 base;
	struct flowi fl;
};

struct inet_sock___14 {
	struct sock___70 sk;
	struct ipv6_pinfo___13 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu___2 *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___14 cork;
};

struct udp_sock___3 {
	struct inet_sock___14 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	unsigned char encap_enabled: 1;
	unsigned char gro_enabled: 1;
	unsigned char accept_udp_l4: 1;
	unsigned char accept_udp_fraglist: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___70 *, struct sk_buff___84 *);
	int (*encap_err_lookup)(struct sock___70 *, struct sk_buff___84 *);
	void (*encap_destroy)(struct sock___70 *);
	struct sk_buff___84 * (*gro_receive)(struct sock___70 *, struct list_head *, struct sk_buff___84 *);
	int (*gro_complete)(struct sock___70 *, struct sk_buff___84 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___83 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet_protosw {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___70 *prot;
	const struct proto_ops___71 *ops;
	unsigned char flags;
};

typedef struct sk_buff___84 * (*gro_receive_t)(struct list_head *, struct sk_buff___84 *);

typedef struct sk_buff___84 * (*gro_receive_sk_t)(struct sock___70 *, struct list_head *, struct sk_buff___84 *);

typedef struct sock___70 * (*udp_lookup_t)(const struct sk_buff___84 *, __be16, __be16);

struct dentry___275;

struct super_block___275;

struct module___259;

struct file_system_type___275 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___275 * (*mount)(struct file_system_type___275 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___275 *);
	struct module___259 *owner;
	struct file_system_type___275 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___275;

struct kiocb___275;

struct iov_iter___195;

struct poll_table_struct___196;

struct vm_area_struct___280;

struct inode___275;

struct file_lock___275;

struct page___280;

struct pipe_inode_info___116;

struct seq_file___250;

struct file_operations___276 {
	struct module___259 *owner;
	loff_t (*llseek)(struct file___275 *, loff_t, int);
	ssize_t (*read)(struct file___275 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___275 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___275 *, struct iov_iter___195 *);
	ssize_t (*write_iter)(struct kiocb___275 *, struct iov_iter___195 *);
	int (*iopoll)(struct kiocb___275 *, bool);
	int (*iterate)(struct file___275 *, struct dir_context *);
	int (*iterate_shared)(struct file___275 *, struct dir_context *);
	__poll_t (*poll)(struct file___275 *, struct poll_table_struct___196 *);
	long int (*unlocked_ioctl)(struct file___275 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___275 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___275 *, struct vm_area_struct___280 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___275 *, struct file___275 *);
	int (*flush)(struct file___275 *, fl_owner_t);
	int (*release)(struct inode___275 *, struct file___275 *);
	int (*fsync)(struct file___275 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___275 *, int);
	int (*lock)(struct file___275 *, int, struct file_lock___275 *);
	ssize_t (*sendpage)(struct file___275 *, struct page___280 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___275 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___275 *, long unsigned int);
	int (*flock)(struct file___275 *, int, struct file_lock___275 *);
	ssize_t (*splice_write)(struct pipe_inode_info___116 *, struct file___275 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___275 *, loff_t *, struct pipe_inode_info___116 *, size_t, unsigned int);
	int (*setlease)(struct file___275 *, long int, struct file_lock___275 **, void **);
	long int (*fallocate)(struct file___275 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___250 *, struct file___275 *);
	ssize_t (*copy_file_range)(struct file___275 *, loff_t, struct file___275 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___275 *, loff_t, struct file___275 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___275 *, loff_t, loff_t, int);
};

struct vmacache___280 {
	u64 seqnum;
	struct vm_area_struct___280 *vmas[4];
};

struct page_frag___280 {
	struct page___280 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___281;

struct pid___252;

struct nsproxy___261;

struct signal_struct___276;

struct bio_list___166;

struct backing_dev_info___152;

struct io_context___166;

struct css_set___202;

struct mem_cgroup___140;

struct request_queue___166;

struct vm_struct___258;

struct task_struct___282 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___282 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___281 *mm;
	struct mm_struct___281 *active_mm;
	struct vmacache___280 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___282 *real_parent;
	struct task_struct___282 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___282 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___252 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___261 *nsproxy;
	struct signal_struct___276 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___282 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___166 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___152 *backing_dev_info;
	struct io_context___166 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___202 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___116 *splice_pipe;
	struct page_frag___280 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___140 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___140 *active_memcg;
	struct request_queue___166 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___282 *oom_reaper_list;
	struct vm_struct___258 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___263;

struct kobj_type___263;

struct kernfs_node___263;

struct kobject___263 {
	const char *name;
	struct list_head entry;
	struct kobject___263 *parent;
	struct kset___263 *kset;
	struct kobj_type___263 *ktype;
	struct kernfs_node___263 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___260 {
	struct kobject___263 kobj;
	struct module___259 *mod;
	struct kobject___263 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___259 {
	struct module___259 *mod;
	struct latch_tree_node node;
};

struct module_layout___259 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___259 mtn;
};

struct module_attribute___259;

struct kernel_param___259;

struct module___259 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___260 mkobj;
	struct module_attribute___259 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___263 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___259 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___259 core_layout;
	struct module_layout___259 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___252;

struct upid___252 {
	int nr;
	struct pid_namespace___252 *ns;
};

struct pid_namespace___252 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___282 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___252 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___252 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___252 numbers[1];
};

typedef struct page___280 *pgtable_t___280;

struct address_space___275;

struct page_pool___104;

struct dev_pagemap___270;

struct page___280 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___275 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___104 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___280 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___280 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___281 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___270 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___270;

struct vm_area_struct___280 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___280 *vm_next;
	struct vm_area_struct___280 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___281 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___270 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___275 *vm_file;
	struct file___275 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___276 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___282 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___282 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___252 *pids[4];
	struct pid___252 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___281 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___280;

struct mm_struct___281 {
	struct {
		struct vm_area_struct___280 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___275 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___280 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___282 *owner;
		struct user_namespace___26 *user_ns;
		struct file___275 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___89;

struct cgroup_namespace___202;

struct nsproxy___261 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___252 *pid_ns_for_children;
	struct net___89 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___202 *cgroup_ns;
};

struct bio___166;

struct bio_list___166 {
	struct bio___166 *head;
	struct bio___166 *tail;
};

struct cgroup_subsys_state___202;

struct bdi_writeback___152 {
	struct backing_dev_info___152 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___202 *memcg_css;
	struct cgroup_subsys_state___202 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___256;

struct backing_dev_info___152 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___152 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___256 *dev;
	char dev_name[64];
	struct device___256 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___275 *debug_dir;
};

struct io_cq___166;

struct io_context___166 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___166 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___202;

struct css_set___202 {
	struct cgroup_subsys_state___202 *subsys[14];
	refcount_t refcount;
	struct css_set___202 *dom_cset;
	struct cgroup___202 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___202 *mg_src_cgrp;
	struct cgroup___202 *mg_dst_cgrp;
	struct css_set___202 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___275;

struct pipe_buffer___116;

struct pipe_inode_info___116 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___280 *tmp_page;
	struct fasync_struct___275 *fasync_readers;
	struct fasync_struct___275 *fasync_writers;
	struct pipe_buffer___116 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___202;

struct cgroup_subsys_state___202 {
	struct cgroup___202 *cgroup;
	struct cgroup_subsys___202 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___202 *parent;
};

struct cgroup_file___202 {
	struct kernfs_node___263 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___140;

struct mem_cgroup_per_node___140;

struct mem_cgroup___140 {
	struct cgroup_subsys_state___202 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___202 events_file;
	struct cgroup_file___202 events_local_file;
	struct cgroup_file___202 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___140 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___282 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___140 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___166;

struct blk_integrity___166 {
	const struct blk_integrity_profile___166 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___166 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___166 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___166;

struct elevator_queue___166;

struct blk_mq_ops___161;

struct blk_mq_hw_ctx___161;

struct gendisk___169;

struct blkcg_gq___154;

struct blk_mq_tag_set___161;

struct request_queue___166 {
	struct request___166 *last_merge;
	struct elevator_queue___166 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___161 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___161 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___169 *disk;
	struct kobject___263 kobj;
	struct kobject___263 *mq_kobj;
	struct blk_integrity___166 integrity;
	struct device___256 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___154 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___161 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___166 bio_split;
	struct dentry___275 *debugfs_dir;
	struct dentry___275 *sched_debugfs_dir;
	struct dentry___275 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___258 {
	struct vm_struct___258 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___280 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___275;

struct address_space___275 {
	struct inode___275 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___275 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___104 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___256 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___104 {
	u32 count;
	struct page___280 *cache[128];
};

struct page_pool___104 {
	struct page_pool_params___104 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___280 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___104 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___270;

struct dev_pagemap___270 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___270 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___275;

struct path___275 {
	struct vfsmount___275 *mnt;
	struct dentry___275 *dentry;
};

struct fown_struct___252 {
	rwlock_t lock;
	struct pid___252 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___275 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___275 f_path;
	struct inode___275 *f_inode;
	const struct file_operations___276 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___252 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___275 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___270;

struct vm_operations_struct___270 {
	void (*open)(struct vm_area_struct___280 *);
	void (*close)(struct vm_area_struct___280 *);
	int (*may_split)(struct vm_area_struct___280 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___280 *);
	int (*mprotect)(struct vm_area_struct___280 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___270 *);
	vm_fault_t (*huge_fault)(struct vm_fault___270 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___270 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___280 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___270 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___270 *);
	int (*access)(struct vm_area_struct___280 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___280 *);
	int (*set_policy)(struct vm_area_struct___280 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___280 *, long unsigned int);
	struct page___280 * (*find_special_page)(struct vm_area_struct___280 *, long unsigned int);
};

struct core_thread___280 {
	struct task_struct___282 *task;
	struct core_thread___280 *next;
};

struct core_state___280 {
	atomic_t nr_threads;
	struct core_thread___280 dumper;
	struct completion startup;
};

struct vm_fault___270 {
	const struct {
		struct vm_area_struct___280 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___280 *cow_page;
	struct page___280 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___280 prealloc_pte;
};

struct pglist_data___148;

struct lruvec___148 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___148 *pgdat;
};

struct zone___148 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___148 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___148 {
	struct zone___148 *zone;
	int zone_idx;
};

struct zonelist___148 {
	struct zoneref___148 _zonerefs[321];
};

struct pglist_data___148 {
	struct zone___148 node_zones[5];
	struct zonelist___148 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___282 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___282 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___148 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___275;

struct dentry___275 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___275 *d_parent;
	struct qstr d_name;
	struct inode___275 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___275 *d_op;
	struct super_block___275 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___275;

struct inode___275 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___275 *i_op;
	struct super_block___275 *i_sb;
	struct address_space___275 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___152 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___276 *i_fop;
		void (*free_inode)(struct inode___275 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___275 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___116 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___275 {
	int (*d_revalidate)(struct dentry___275 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___275 *, unsigned int);
	int (*d_hash)(const struct dentry___275 *, struct qstr *);
	int (*d_compare)(const struct dentry___275 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___275 *);
	int (*d_init)(struct dentry___275 *);
	void (*d_release)(struct dentry___275 *);
	void (*d_prune)(struct dentry___275 *);
	void (*d_iput)(struct dentry___275 *, struct inode___275 *);
	char * (*d_dname)(struct dentry___275 *, char *, int);
	struct vfsmount___275 * (*d_automount)(struct path___275 *);
	int (*d_manage)(const struct path___275 *, bool);
	struct dentry___275 * (*d_real)(struct dentry___275 *, const struct inode___275 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___275;

struct mem_dqinfo___275 {
	struct quota_format_type___275 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___275;

struct quota_info___275 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___275 *files[3];
	struct mem_dqinfo___275 info[3];
	const struct quota_format_ops___275 *ops[3];
};

struct rcuwait___276 {
	struct task_struct___282 *task;
};

struct percpu_rw_semaphore___276 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___276 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___275 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___276 rw_sem[3];
};

struct shrink_control___140;

struct shrinker___140 {
	long unsigned int (*count_objects)(struct shrinker___140 *, struct shrink_control___140 *);
	long unsigned int (*scan_objects)(struct shrinker___140 *, struct shrink_control___140 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___275;

struct dquot_operations___275;

struct quotactl_ops___275;

struct block_device___169;

struct super_block___275 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___275 *s_type;
	const struct super_operations___275 *s_op;
	const struct dquot_operations___275 *dq_op;
	const struct quotactl_ops___275 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___275 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___169 *s_bdev;
	struct backing_dev_info___152 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___275 s_dquot;
	struct sb_writers___275 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___275 *s_d_op;
	int cleancache_poolid;
	struct shrinker___140 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___275 {
	struct dentry___275 *mnt_root;
	struct super_block___275 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___140 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___140 *memcg;
};

struct psi_group___202 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___282 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___78;

struct cgroup_bpf___78 {
	struct bpf_prog_array___78 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___78 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___202;

struct cgroup_rstat_cpu___202;

struct cgroup___202 {
	struct cgroup_subsys_state___202 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___263 *kn;
	struct cgroup_file___202 procs_file;
	struct cgroup_file___202 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___202 *subsys[14];
	struct cgroup_root___202 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___202 *dom_cgrp;
	struct cgroup___202 *old_dom_cgrp;
	struct cgroup_rstat_cpu___202 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___202 psi;
	struct cgroup_bpf___78 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___166 {
	struct request_queue___166 *q;
	struct io_context___166 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___275 {
	struct file___275 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___275 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___275 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___275 *ia_file;
};

struct dquot___275 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___275 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___275 {
	int qf_fmt_id;
	const struct quota_format_ops___275 *qf_ops;
	struct module___259 *qf_owner;
	struct quota_format_type___275 *qf_next;
};

struct quota_format_ops___275 {
	int (*check_quota_file)(struct super_block___275 *, int);
	int (*read_file_info)(struct super_block___275 *, int);
	int (*write_file_info)(struct super_block___275 *, int);
	int (*free_file_info)(struct super_block___275 *, int);
	int (*read_dqblk)(struct dquot___275 *);
	int (*commit_dqblk)(struct dquot___275 *);
	int (*release_dqblk)(struct dquot___275 *);
	int (*get_next_id)(struct super_block___275 *, struct kqid *);
};

struct dquot_operations___275 {
	int (*write_dquot)(struct dquot___275 *);
	struct dquot___275 * (*alloc_dquot)(struct super_block___275 *, int);
	void (*destroy_dquot)(struct dquot___275 *);
	int (*acquire_dquot)(struct dquot___275 *);
	int (*release_dquot)(struct dquot___275 *);
	int (*mark_dirty)(struct dquot___275 *);
	int (*write_info)(struct super_block___275 *, int);
	qsize_t * (*get_reserved_space)(struct inode___275 *);
	int (*get_projid)(struct inode___275 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___275 *, qsize_t *);
	int (*get_next_id)(struct super_block___275 *, struct kqid *);
};

struct quotactl_ops___275 {
	int (*quota_on)(struct super_block___275 *, int, int, const struct path___275 *);
	int (*quota_off)(struct super_block___275 *, int);
	int (*quota_enable)(struct super_block___275 *, unsigned int);
	int (*quota_disable)(struct super_block___275 *, unsigned int);
	int (*quota_sync)(struct super_block___275 *, int);
	int (*set_info)(struct super_block___275 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___275 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___275 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___275 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___275 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___275 *, unsigned int);
};

struct writeback_control___152;

struct address_space_operations___275 {
	int (*writepage)(struct page___280 *, struct writeback_control___152 *);
	int (*readpage)(struct file___275 *, struct page___280 *);
	int (*writepages)(struct address_space___275 *, struct writeback_control___152 *);
	int (*set_page_dirty)(struct page___280 *);
	int (*readpages)(struct file___275 *, struct address_space___275 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___275 *, struct address_space___275 *, loff_t, unsigned int, unsigned int, struct page___280 **, void **);
	int (*write_end)(struct file___275 *, struct address_space___275 *, loff_t, unsigned int, unsigned int, struct page___280 *, void *);
	sector_t (*bmap)(struct address_space___275 *, sector_t);
	void (*invalidatepage)(struct page___280 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___280 *, gfp_t);
	void (*freepage)(struct page___280 *);
	ssize_t (*direct_IO)(struct kiocb___275 *, struct iov_iter___195 *);
	int (*migratepage)(struct address_space___275 *, struct page___280 *, struct page___280 *, enum migrate_mode);
	bool (*isolate_page)(struct page___280 *, isolate_mode_t);
	void (*putback_page)(struct page___280 *);
	int (*launder_page)(struct page___280 *);
	int (*is_partially_uptodate)(struct page___280 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___280 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___275 *, struct page___280 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___275 *, sector_t *);
	void (*swap_deactivate)(struct file___275 *);
};

struct writeback_control___152 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___152 *wb;
	struct inode___275 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___192;

struct iov_iter___195 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___192 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___116 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___275 {
	struct dentry___275 * (*lookup)(struct inode___275 *, struct dentry___275 *, unsigned int);
	const char * (*get_link)(struct dentry___275 *, struct inode___275 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___275 *, int);
	struct posix_acl * (*get_acl)(struct inode___275 *, int, bool);
	int (*readlink)(struct dentry___275 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___275 *, struct dentry___275 *, umode_t, bool);
	int (*link)(struct dentry___275 *, struct inode___275 *, struct dentry___275 *);
	int (*unlink)(struct inode___275 *, struct dentry___275 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___275 *, struct dentry___275 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___275 *, struct dentry___275 *, umode_t);
	int (*rmdir)(struct inode___275 *, struct dentry___275 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___275 *, struct dentry___275 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___275 *, struct dentry___275 *, struct inode___275 *, struct dentry___275 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___275 *, struct iattr___275 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___275 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___275 *, char *, size_t);
	int (*fiemap)(struct inode___275 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___275 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___275 *, struct dentry___275 *, struct file___275 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___275 *, struct dentry___275 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___275 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___275 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___275 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___275 {
	void (*fl_copy_lock)(struct file_lock___275 *, struct file_lock___275 *);
	void (*fl_release_private)(struct file_lock___275 *);
};

struct lock_manager_operations___275;

struct file_lock___275 {
	struct file_lock___275 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___275 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___275 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___275 *fl_ops;
	const struct lock_manager_operations___275 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___275 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___275 *);
	int (*lm_grant)(struct file_lock___275 *, int);
	bool (*lm_break)(struct file_lock___275 *);
	int (*lm_change)(struct file_lock___275 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___275 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___275 *);
};

struct fasync_struct___275 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___275 *fa_next;
	struct file___275 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___275 {
	struct inode___275 * (*alloc_inode)(struct super_block___275 *);
	void (*destroy_inode)(struct inode___275 *);
	void (*free_inode)(struct inode___275 *);
	void (*dirty_inode)(struct inode___275 *, int);
	int (*write_inode)(struct inode___275 *, struct writeback_control___152 *);
	int (*drop_inode)(struct inode___275 *);
	void (*evict_inode)(struct inode___275 *);
	void (*put_super)(struct super_block___275 *);
	int (*sync_fs)(struct super_block___275 *, int);
	int (*freeze_super)(struct super_block___275 *);
	int (*freeze_fs)(struct super_block___275 *);
	int (*thaw_super)(struct super_block___275 *);
	int (*unfreeze_fs)(struct super_block___275 *);
	int (*statfs)(struct dentry___275 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___275 *, int *, char *);
	void (*umount_begin)(struct super_block___275 *);
	int (*show_options)(struct seq_file___250 *, struct dentry___275 *);
	int (*show_devname)(struct seq_file___250 *, struct dentry___275 *);
	int (*show_path)(struct seq_file___250 *, struct dentry___275 *);
	int (*show_stats)(struct seq_file___250 *, struct dentry___275 *);
	ssize_t (*quota_read)(struct super_block___275 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___275 *, int, const char *, size_t, loff_t);
	struct dquot___275 ** (*get_dquots)(struct inode___275 *);
	long int (*nr_cached_objects)(struct super_block___275 *, struct shrink_control___140 *);
	long int (*free_cached_objects)(struct super_block___275 *, struct shrink_control___140 *);
	struct file___275 * (*real_loop)(struct file___275 *);
};

struct wakeup_source___256;

struct dev_pm_info___256 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___256 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___256 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___256;

struct bus_type___256;

struct device_driver___256;

struct dev_pm_domain___256;

struct fwnode_handle___252;

struct class___256;

struct attribute_group___263;

struct device___256 {
	struct kobject___263 kobj;
	struct device___256 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___256 *type;
	struct bus_type___256 *bus;
	struct device_driver___256 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___256 power;
	struct dev_pm_domain___256 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___252 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___256 *class;
	const struct attribute_group___263 **groups;
	void (*release)(struct device___256 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___169 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___275 *bd_inode;
	struct super_block___275 *bd_super;
	void *bd_claiming;
	struct device___256 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___263 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___169 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___275 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___204)(struct file___275 *, wait_queue_head_t *, struct poll_table_struct___196 *);

struct poll_table_struct___196 {
	poll_queue_proc___204 _qproc;
	__poll_t _key;
};

struct seq_operations___250;

struct seq_file___250 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___250 *op;
	int poll_event;
	const struct file___275 *file;
	void *private;
};

typedef void bio_end_io_t___166(struct bio___166 *);

struct bio_vec___192 {
	struct page___280 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___166;

struct bio___166 {
	struct bio___166 *bi_next;
	struct block_device___169 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___166 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___154 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___166 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___192 *bi_io_vec;
	struct bio_set___166 *bi_pool;
	struct bio_vec___192 bi_inline_vecs[0];
};

struct kernfs_root___263;

struct kernfs_elem_dir___263 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___263 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___263;

struct kernfs_root___263 {
	struct kernfs_node___263 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___263 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___263 {
	struct kernfs_node___263 *target_kn;
};

struct kernfs_ops___263;

struct kernfs_elem_attr___263 {
	const struct kernfs_ops___263 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___263 *notify_next;
};

struct kernfs_node___263 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___263 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___263 dir;
		struct kernfs_elem_symlink___263 symlink;
		struct kernfs_elem_attr___263 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___263;

struct kernfs_ops___263 {
	int (*open)(struct kernfs_open_file___263 *);
	void (*release)(struct kernfs_open_file___263 *);
	int (*seq_show)(struct seq_file___250 *, void *);
	void * (*seq_start)(struct seq_file___250 *, loff_t *);
	void * (*seq_next)(struct seq_file___250 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___250 *, void *);
	ssize_t (*read)(struct kernfs_open_file___263 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___263 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___263 *, struct poll_table_struct___196 *);
	int (*mmap)(struct kernfs_open_file___263 *, struct vm_area_struct___280 *);
};

struct kernfs_syscall_ops___263 {
	int (*show_options)(struct seq_file___250 *, struct kernfs_root___263 *);
	int (*mkdir)(struct kernfs_node___263 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___263 *);
	int (*rename)(struct kernfs_node___263 *, struct kernfs_node___263 *, const char *);
	int (*show_path)(struct seq_file___250 *, struct kernfs_node___263 *, struct kernfs_root___263 *);
};

struct kernfs_open_file___263 {
	struct kernfs_node___263 *kn;
	struct file___275 *file;
	struct seq_file___250 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___270 *vm_ops;
};

struct sock___71;

struct kobj_ns_type_operations___71 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___71 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___89 *net;
} possible_net_t___84;

struct proto___71;

struct sock_common___71 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___71 *skc_prot;
	possible_net_t___84 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___71 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___85;

struct sk_buff_head___84 {
	struct sk_buff___85 *next;
	struct sk_buff___85 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___71 {
	struct cgroup___202 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___71;

struct socket_wq___72;

struct dst_entry___71;

struct socket___73;

struct net_device___84;

struct sock_reuseport___22;

struct sock___71 {
	struct sock_common___71 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___84 sk_error_queue;
	struct sk_buff___85 *sk_rx_skb_cache;
	struct sk_buff_head___84 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___85 *head;
		struct sk_buff___85 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___71 *sk_filter;
	union {
		struct socket_wq___72 *sk_wq;
		struct socket_wq___72 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___71 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___71 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___85 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___85 *sk_tx_skb_cache;
	struct sk_buff_head___84 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___280 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___71 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___252 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___73 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___71 sk_cgrp_data;
	struct mem_cgroup___140 *sk_memcg;
	void (*sk_state_change)(struct sock___71 *);
	void (*sk_data_ready)(struct sock___71 *);
	void (*sk_write_space)(struct sock___71 *);
	void (*sk_error_report)(struct sock___71 *);
	int (*sk_backlog_rcv)(struct sock___71 *, struct sk_buff___85 *);
	struct sk_buff___85 * (*sk_validate_xmit_skb)(struct sock___71 *, struct net_device___84 *, struct sk_buff___85 *);
	void (*sk_destruct)(struct sock___71 *);
	struct sock_reuseport___22 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___263;

struct attribute_group___263 {
	const char *name;
	umode_t (*is_visible)(struct kobject___263 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___263 *, struct bin_attribute___263 *, int);
	struct attribute **attrs;
	struct bin_attribute___263 **bin_attrs;
};

struct bin_attribute___263 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___275 * (*f_mapping)();
	ssize_t (*read)(struct file___275 *, struct kobject___263 *, struct bin_attribute___263 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___275 *, struct kobject___263 *, struct bin_attribute___263 *, char *, loff_t, size_t);
	int (*mmap)(struct file___275 *, struct kobject___263 *, struct bin_attribute___263 *, struct vm_area_struct___280 *);
};

struct sysfs_ops___263 {
	ssize_t (*show)(struct kobject___263 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___263 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___263;

struct kset___263 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___263 kobj;
	const struct kset_uevent_ops___263 *uevent_ops;
};

struct kobj_type___263 {
	void (*release)(struct kobject___263 *);
	const struct sysfs_ops___263 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___263 **default_groups;
	const struct kobj_ns_type_operations___71 * (*child_ns_type)(struct kobject___263 *);
	const void * (*namespace)(struct kobject___263 *);
	void (*get_ownership)(struct kobject___263 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___263 {
	int (* const filter)(struct kset___263 *, struct kobject___263 *);
	const char * (* const name)(struct kset___263 *, struct kobject___263 *);
	int (* const uevent)(struct kset___263 *, struct kobject___263 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___259 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___259 *);
	int (*get)(char *, const struct kernel_param___259 *);
	void (*free)(void *);
};

struct kparam_array___259;

struct kernel_param___259 {
	const char *name;
	struct module___259 *mod;
	const struct kernel_param_ops___259 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___259 *arr;
	};
};

struct kparam_array___259 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___259 *ops;
	void *elem;
};

struct module_attribute___259 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___259 *, struct module_kobject___260 *, char *);
	ssize_t (*store)(struct module_attribute___259 *, struct module_kobject___260 *, const char *, size_t);
	void (*setup)(struct module___259 *, const char *);
	int (*test)(struct module___259 *);
	void (*free)(struct module___259 *);
};

struct msghdr___73 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___195 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___275 *msg_iocb;
};

struct dev_pagemap_ops___270 {
	void (*page_free)(struct page___280 *);
	void (*kill)(struct dev_pagemap___270 *);
	void (*cleanup)(struct dev_pagemap___270 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___270 *);
};

struct sk_buff___85 {
	union {
		struct {
			struct sk_buff___85 *next;
			struct sk_buff___85 *prev;
			union {
				struct net_device___84 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___71 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___85 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___89;

struct fqdir___89 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___89 *f;
	struct net___89 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___89;

struct inet_frags___89 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___89 *, const void *);
	void (*destructor)(struct inet_frag_queue___89 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___44;

struct fib_rules_ops___71;

struct tcp_congestion_ops___20;

struct fib_notifier_ops___71;

struct netns_ipv4___89 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___44 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___71 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___71 *fibnl;
	struct sock___71 **icmp_sk;
	struct sock___71 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___71 **tcp_sk;
	struct fqdir___89 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___20 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___71 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___71 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___71 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___71;

struct dst_ops___89 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___89 *);
	struct dst_entry___71 * (*check)(struct dst_entry___71 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___71 *);
	unsigned int (*mtu)(const struct dst_entry___71 *);
	u32 * (*cow_metrics)(struct dst_entry___71 *, long unsigned int);
	void (*destroy)(struct dst_entry___71 *);
	void (*ifdown)(struct dst_entry___71 *, struct net_device___84 *, int);
	struct dst_entry___71 * (*negative_advice)(struct dst_entry___71 *);
	void (*link_failure)(struct sk_buff___85 *);
	void (*update_pmtu)(struct dst_entry___71 *, struct sock___71 *, struct sk_buff___85 *, u32, bool);
	void (*redirect)(struct dst_entry___71 *, struct sock___71 *, struct sk_buff___85 *);
	int (*local_out)(struct net___89 *, struct sock___71 *, struct sk_buff___85 *);
	struct neighbour___71 * (*neigh_lookup)(const struct dst_entry___71 *, struct sk_buff___85 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___71 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___20;

struct rt6_info___20;

struct fib6_table___20;

struct netns_ipv6___89 {
	struct dst_ops___89 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___89 *fqdir;
	struct fib6_info___20 *fib6_null_entry;
	struct rt6_info___20 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___20 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___20 *ip6_prohibit_entry;
	struct rt6_info___20 *ip6_blk_hole_entry;
	struct fib6_table___20 *fib6_local_tbl;
	struct fib_rules_ops___71 *fib6_rules_ops;
	struct sock___71 **icmp_sk;
	struct sock___71 *ndisc_sk;
	struct sock___71 *tcp_sk;
	struct sock___71 *igmp_sk;
	struct sock___71 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___71 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___71 *notifier_ops;
	struct fib_notifier_ops___71 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___89 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___89 *fqdir;
};

struct netns_sctp___71 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___71 *ctl_sock;
	struct sock___71 *udp4_sock;
	struct sock___71 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___12;

struct netns_nf___12 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___12 *hooks_ipv4[5];
	struct nf_hook_entries___12 *hooks_ipv6[5];
	struct nf_hook_entries___12 *hooks_arp[3];
	struct nf_hook_entries___12 *hooks_bridge[5];
	struct nf_hook_entries___12 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___78;

struct netns_bpf___78 {
	struct bpf_prog_array___78 *run_array[2];
	struct bpf_prog___78 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___89 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___71 *nlsk;
	struct sock___71 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___89 xfrm4_dst_ops;
	struct dst_ops___89 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___89 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___71 *rtnl;
	struct sock___71 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___84 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___89 ipv4;
	struct netns_ipv6___89 ipv6;
	struct netns_ieee802154_lowpan___89 ieee802154_lowpan;
	struct netns_sctp___71 sctp;
	struct netns_nf___12 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___84 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___78 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___89 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___71 *crypto_nlsk;
	struct sock___71 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___89 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___85 *fragments_tail;
	struct sk_buff___85 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___89 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___44 {
	struct ip_ra_chain___44 *next;
	struct sock___71 *sk;
	union {
		void (*destructor)(struct sock___71 *);
		struct sock___71 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___71;

struct fib_lookup_arg___71;

struct fib_rules_ops___71 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___71 *, struct flowi *, int, struct fib_lookup_arg___71 *);
	bool (*suppress)(struct fib_rule___71 *, int, struct fib_lookup_arg___71 *);
	int (*match)(struct fib_rule___71 *, struct flowi *, int);
	int (*configure)(struct fib_rule___71 *, struct sk_buff___85 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___71 *);
	int (*compare)(struct fib_rule___71 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___71 *, struct sk_buff___85 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___71 *);
	void (*flush_cache)(struct fib_rules_ops___71 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___259 *owner;
	struct net___89 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___20 {
	u32 (*ssthresh)(struct sock___71 *);
	void (*cong_avoid)(struct sock___71 *, u32, u32);
	void (*set_state)(struct sock___71 *, u8);
	void (*cwnd_event)(struct sock___71 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___71 *, u32);
	void (*pkts_acked)(struct sock___71 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___71 *);
	void (*cong_control)(struct sock___71 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___71 *);
	u32 (*sndbuf_expand)(struct sock___71 *);
	size_t (*get_info)(struct sock___71 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___259 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___71 *);
	void (*release)(struct sock___71 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___71 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___89 *);
	int (*fib_dump)(struct net___89 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___259 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___47;

struct dst_entry___71 {
	struct net_device___84 *dev;
	struct dst_ops___89 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___85 *);
	int (*output)(struct net___89 *, struct sock___71 *, struct sk_buff___85 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___47 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___84(struct sk_buff___85 **);

struct bpf_xdp_entity___78 {
	struct bpf_prog___78 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___84;

struct net_device_ops___84;

struct l3mdev_ops___71;

struct ndisc_ops___53;

struct xfrmdev_ops___84;

struct header_ops___84;

struct in_device___12;

struct inet6_dev___53;

struct netdev_rx_queue___84;

struct mini_Qdisc___78;

struct netdev_queue___84;

struct Qdisc___78;

struct rtnl_link_ops___78;

struct dcbnl_rtnl_ops___84;

struct net_device___84 {
	char name[16];
	struct netdev_name_node___84 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___84 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___71 *l3mdev_ops;
	const struct ndisc_ops___53 *ndisc_ops;
	const struct xfrmdev_ops___84 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___84 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___263 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___12 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___53 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___84 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___78 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___84 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___78 *miniq_ingress;
	struct netdev_queue___84 *ingress_queue;
	struct nf_hook_entries___12 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___84 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___78 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___78 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___84 = 0,
		NETREG_REGISTERED___84 = 1,
		NETREG_UNREGISTERING___84 = 2,
		NETREG_UNREGISTERED___84 = 3,
		NETREG_RELEASED___84 = 4,
		NETREG_DUMMY___84 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___84 = 0,
		RTNL_LINK_INITIALIZING___84 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___84 *);
	struct netpoll_info *npinfo;
	possible_net_t___84 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___256 dev;
	const struct attribute_group___263 *sysfs_groups[4];
	const struct attribute_group___263 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___78 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___84 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___78 xdp_state[3];
	long: 64;
};

struct neigh_table___71;

struct neigh_parms___71;

struct neigh_ops___71;

struct neighbour___71 {
	struct neighbour___71 *next;
	struct neigh_table___71 *tbl;
	struct neigh_parms___71 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___84 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___71 *, struct sk_buff___85 *);
	const struct neigh_ops___71 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___84 *dev;
	u8 primary_key[0];
};

struct rtable___21;

struct fnhe_hash_bucket___20;

struct fib_nh_common___20 {
	struct net_device___84 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___47 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___21 **nhc_pcpu_rth_output;
	struct rtable___21 *nhc_rth_input;
	struct fnhe_hash_bucket___20 *nhc_exceptions;
};

struct fib6_nh___20 {
	struct fib_nh_common___20 nh_common;
	long unsigned int last_probe;
	struct rt6_info___20 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___20;

struct nexthop___11;

struct fib6_info___20 {
	struct fib6_table___20 *fib6_table;
	struct fib6_info___20 *fib6_next;
	struct fib6_node___20 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___11 *nh;
	struct fib6_nh___20 fib6_nh[0];
};

struct rt6_info___20 {
	struct dst_entry___71 dst;
	struct fib6_info___20 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___53 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___20 {
	struct fib6_node___20 *parent;
	struct fib6_node___20 *left;
	struct fib6_node___20 *right;
	struct fib6_node___20 *subtree;
	struct fib6_info___20 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___20 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___20 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___20 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___12;

typedef unsigned int nf_hookfn___14(void *, struct sk_buff___85 *, const struct nf_hook_state___12 *);

struct nf_hook_entry___12 {
	nf_hookfn___14 *hook;
	void *priv;
};

struct nf_hook_entries___12 {
	u16 num_hook_entries;
	struct nf_hook_entry___12 hooks[0];
};

struct bpf_prog_array_item___78 {
	struct bpf_prog___78 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___78 {
	struct callback_head rcu;
	struct bpf_prog_array_item___78 items[0];
};

struct bpf_prog_aux___87;

struct bpf_prog___78 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___87 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___252;

struct fwnode_handle___252 {
	struct fwnode_handle___252 *secondary;
	const struct fwnode_operations___252 *ops;
	struct device___256 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___252;

struct fwnode_endpoint___252;

struct fwnode_operations___252 {
	struct fwnode_handle___252 * (*get)(struct fwnode_handle___252 *);
	void (*put)(struct fwnode_handle___252 *);
	bool (*device_is_available)(const struct fwnode_handle___252 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___252 *, const struct device___256 *);
	bool (*property_present)(const struct fwnode_handle___252 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___252 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___252 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___252 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*get_parent)(const struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*get_next_child_node)(const struct fwnode_handle___252 *, struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*get_named_child_node)(const struct fwnode_handle___252 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___252 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___252 *);
	struct fwnode_handle___252 * (*graph_get_next_endpoint)(const struct fwnode_handle___252 *, struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*graph_get_remote_endpoint)(const struct fwnode_handle___252 *);
	struct fwnode_handle___252 * (*graph_get_port_parent)(struct fwnode_handle___252 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___252 *, struct fwnode_endpoint___252 *);
	int (*add_links)(struct fwnode_handle___252 *);
};

struct fwnode_endpoint___252 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___252 *local_fwnode;
};

struct fwnode_reference_args___252 {
	struct fwnode_handle___252 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___202 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___202 *root_cset;
};

struct socket_wq___72 {
	wait_queue_head_t wait;
	struct fasync_struct___275 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___72;

struct socket___73 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___275 *file;
	struct sock___71 *sk;
	const struct proto_ops___72 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___72 wq;
};

typedef int (*sk_read_actor_t___71)(read_descriptor_t *, struct sk_buff___85 *, unsigned int, size_t);

struct proto_ops___72 {
	int family;
	struct module___259 *owner;
	int (*release)(struct socket___73 *);
	int (*bind)(struct socket___73 *, struct sockaddr *, int);
	int (*connect)(struct socket___73 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___73 *, struct socket___73 *);
	int (*accept)(struct socket___73 *, struct socket___73 *, int, bool);
	int (*getname)(struct socket___73 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___275 *, struct socket___73 *, struct poll_table_struct___196 *);
	int (*ioctl)(struct socket___73 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___73 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___73 *, void *, bool, bool);
	int (*listen)(struct socket___73 *, int);
	int (*shutdown)(struct socket___73 *, int);
	int (*setsockopt)(struct socket___73 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___73 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___250 *, struct socket___73 *);
	int (*sendmsg)(struct socket___73 *, struct msghdr___73 *, size_t);
	int (*recvmsg)(struct socket___73 *, struct msghdr___73 *, size_t, int);
	int (*mmap)(struct file___275 *, struct socket___73 *, struct vm_area_struct___280 *);
	ssize_t (*sendpage)(struct socket___73 *, struct page___280 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___73 *, loff_t *, struct pipe_inode_info___116 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___71 *, int);
	int (*peek_len)(struct socket___73 *);
	int (*read_sock)(struct sock___71 *, read_descriptor_t *, sk_read_actor_t___71);
	int (*sendpage_locked)(struct sock___71 *, struct page___280 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___71 *, struct msghdr___73 *, size_t);
	int (*set_rcvlowat)(struct sock___71 *, int);
};

struct dev_pm_ops___256 {
	int (*prepare)(struct device___256 *);
	void (*complete)(struct device___256 *);
	int (*suspend)(struct device___256 *);
	int (*resume)(struct device___256 *);
	int (*freeze)(struct device___256 *);
	int (*thaw)(struct device___256 *);
	int (*poweroff)(struct device___256 *);
	int (*restore)(struct device___256 *);
	int (*suspend_late)(struct device___256 *);
	int (*resume_early)(struct device___256 *);
	int (*freeze_late)(struct device___256 *);
	int (*thaw_early)(struct device___256 *);
	int (*poweroff_late)(struct device___256 *);
	int (*restore_early)(struct device___256 *);
	int (*suspend_noirq)(struct device___256 *);
	int (*resume_noirq)(struct device___256 *);
	int (*freeze_noirq)(struct device___256 *);
	int (*thaw_noirq)(struct device___256 *);
	int (*poweroff_noirq)(struct device___256 *);
	int (*restore_noirq)(struct device___256 *);
	int (*runtime_suspend)(struct device___256 *);
	int (*runtime_resume)(struct device___256 *);
	int (*runtime_idle)(struct device___256 *);
};

struct wakeup_source___256 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___256 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___256 {
	struct dev_pm_ops___256 ops;
	int (*start)(struct device___256 *);
	void (*detach)(struct device___256 *, bool);
	int (*activate)(struct device___256 *);
	void (*sync)(struct device___256 *);
	void (*dismiss)(struct device___256 *);
};

struct bus_type___256 {
	const char *name;
	const char *dev_name;
	struct device___256 *dev_root;
	const struct attribute_group___263 **bus_groups;
	const struct attribute_group___263 **dev_groups;
	const struct attribute_group___263 **drv_groups;
	int (*match)(struct device___256 *, struct device_driver___256 *);
	int (*uevent)(struct device___256 *, struct kobj_uevent_env *);
	int (*probe)(struct device___256 *);
	void (*sync_state)(struct device___256 *);
	void (*remove)(struct device___256 *);
	void (*shutdown)(struct device___256 *);
	int (*online)(struct device___256 *);
	int (*offline)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	int (*num_vf)(struct device___256 *);
	int (*dma_configure)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___256 {
	const char *name;
	struct bus_type___256 *bus;
	struct module___259 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___256 *);
	void (*sync_state)(struct device___256 *);
	int (*remove)(struct device___256 *);
	void (*shutdown)(struct device___256 *);
	int (*suspend)(struct device___256 *, pm_message_t);
	int (*resume)(struct device___256 *);
	const struct attribute_group___263 **groups;
	const struct attribute_group___263 **dev_groups;
	const struct dev_pm_ops___256 *pm;
	void (*coredump)(struct device___256 *);
	struct driver_private *p;
};

struct device_type___256 {
	const char *name;
	const struct attribute_group___263 **groups;
	int (*uevent)(struct device___256 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___256 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___256 *);
	const struct dev_pm_ops___256 *pm;
};

struct class___256 {
	const char *name;
	struct module___259 *owner;
	const struct attribute_group___263 **class_groups;
	const struct attribute_group___263 **dev_groups;
	struct kobject___263 *dev_kobj;
	int (*dev_uevent)(struct device___256 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___256 *, umode_t *);
	void (*class_release)(struct class___256 *);
	void (*dev_release)(struct device___256 *);
	int (*shutdown_pre)(struct device___256 *);
	const struct kobj_ns_type_operations___71 *ns_type;
	const void * (*namespace)(struct device___256 *);
	void (*get_ownership)(struct device___256 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___256 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___116;

struct pipe_buffer___116 {
	struct page___280 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___116 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___116 {
	int (*confirm)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
	void (*release)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
	bool (*try_steal)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
	bool (*get)(struct pipe_inode_info___116 *, struct pipe_buffer___116 *);
};

struct seq_operations___250 {
	void * (*start)(struct seq_file___250 *, loff_t *);
	void (*stop)(struct seq_file___250 *, void *);
	void * (*next)(struct seq_file___250 *, void *, loff_t *);
	int (*show)(struct seq_file___250 *, void *);
};

struct seq_net_private___9 {
	struct net___89 *net;
};

struct pernet_operations___25 {
	struct list_head list;
	int (*init)(struct net___89 *);
	void (*pre_exit)(struct net___89 *);
	void (*exit)(struct net___89 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___84 {
	int (*ieee_getets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___84 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___84 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___84 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___84 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___84 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___84 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___84 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___84 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___84 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___84 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___84 *);
	u8 (*setstate)(struct net_device___84 *, u8);
	void (*getpermhwaddr)(struct net_device___84 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___84 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___84 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___84 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___84 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___84 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___84 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___84 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___84 *, int, u8 *);
	void (*setpfccfg)(struct net_device___84 *, int, u8);
	void (*getpfccfg)(struct net_device___84 *, int, u8 *);
	u8 (*setall)(struct net_device___84 *);
	u8 (*getcap)(struct net_device___84 *, int, u8 *);
	int (*getnumtcs)(struct net_device___84 *, int, u8 *);
	int (*setnumtcs)(struct net_device___84 *, int, u8);
	u8 (*getpfcstate)(struct net_device___84 *);
	void (*setpfcstate)(struct net_device___84 *, u8);
	void (*getbcncfg)(struct net_device___84 *, int, u32 *);
	void (*setbcncfg)(struct net_device___84 *, int, u32);
	void (*getbcnrp)(struct net_device___84 *, int, u8 *);
	void (*setbcnrp)(struct net_device___84 *, int, u8);
	int (*setapp)(struct net_device___84 *, u8, u16, u8);
	int (*getapp)(struct net_device___84 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___84 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___84 *, int, u8);
	u8 (*getdcbx)(struct net_device___84 *);
	u8 (*setdcbx)(struct net_device___84 *, u8);
	int (*peer_getappinfo)(struct net_device___84 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___84 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___84 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___84 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___84 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___84 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___87;

typedef int (*bpf_iter_init_seq_priv_t___86)(void *, struct bpf_iter_aux_info___87 *);

struct bpf_map___87;

struct bpf_iter_aux_info___87 {
	struct bpf_map___87 *map;
};

struct bpf_iter_seq_info___86 {
	const struct seq_operations___250 *seq_ops;
	bpf_iter_init_seq_priv_t___86 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___86 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___87 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___87 *, struct file___275 *);
	void (*map_free)(struct bpf_map___87 *);
	int (*map_get_next_key)(struct bpf_map___87 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___87 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___87 *, void *);
	int (*map_lookup_batch)(struct bpf_map___87 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___87 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___87 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___87 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___87 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___87 *, void *);
	int (*map_update_elem)(struct bpf_map___87 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___87 *, void *);
	int (*map_push_elem)(struct bpf_map___87 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___87 *, void *);
	int (*map_peek_elem)(struct bpf_map___87 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___87 *, struct file___275 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___87 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___87 *, void *, struct seq_file___250 *);
	int (*map_check_btf)(const struct bpf_map___87 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___87 *, struct bpf_prog_aux___87 *);
	void (*map_poke_untrack)(struct bpf_map___87 *, struct bpf_prog_aux___87 *);
	void (*map_poke_run)(struct bpf_map___87 *, u32, struct bpf_prog___78 *, struct bpf_prog___78 *);
	int (*map_direct_value_addr)(const struct bpf_map___87 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___87 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___87 *, struct vm_area_struct___280 *);
	__poll_t (*map_poll)(struct bpf_map___87 *, struct file___275 *, struct poll_table_struct___196 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___87 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___87 *, const struct bpf_map___87 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___87 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___86 *iter_seq_info;
};

struct bpf_map___87 {
	const struct bpf_map_ops___86 *ops;
	struct bpf_map___87 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___140 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___86;

struct bpf_jit_poke_descriptor___86;

struct bpf_prog_ops___78;

struct btf_mod_pair___86;

struct bpf_prog_offload___84;

struct bpf_prog_aux___87 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___78 *dst_prog;
	struct bpf_trampoline___86 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___78 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___86 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___78 *ops;
	struct bpf_map___87 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___86 *used_btfs;
	struct bpf_prog___78 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___87 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___84 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___84;

struct bpf_map_dev_ops___84 {
	int (*map_get_next_key)(struct bpf_offloaded_map___84 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___84 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___84 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___84 *, void *);
};

struct bpf_offloaded_map___84 {
	struct bpf_map___87 map;
	struct net_device___84 *netdev;
	const struct bpf_map_dev_ops___84 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___78 {
	int (*test_run)(struct bpf_prog___78 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___84 {
	struct bpf_prog___78 *prog;
	struct net_device___84 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___86 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___78 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___259 *mod;
};

struct bpf_jit_poke_descriptor___86 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___87 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___86 {
	struct btf *btf;
	struct module___259 *module;
};

struct cftype___202;

struct cgroup_subsys___202 {
	struct cgroup_subsys_state___202 * (*css_alloc)(struct cgroup_subsys_state___202 *);
	int (*css_online)(struct cgroup_subsys_state___202 *);
	void (*css_offline)(struct cgroup_subsys_state___202 *);
	void (*css_released)(struct cgroup_subsys_state___202 *);
	void (*css_free)(struct cgroup_subsys_state___202 *);
	void (*css_reset)(struct cgroup_subsys_state___202 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___202 *, int);
	int (*css_extra_stat_show)(struct seq_file___250 *, struct cgroup_subsys_state___202 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___282 *, struct css_set___202 *);
	void (*cancel_fork)(struct task_struct___282 *, struct css_set___202 *);
	void (*fork)(struct task_struct___282 *);
	void (*exit)(struct task_struct___282 *);
	void (*release)(struct task_struct___282 *);
	void (*bind)(struct cgroup_subsys_state___202 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___202 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___202 *dfl_cftypes;
	struct cftype___202 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___202 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___202 *updated_children;
	struct cgroup___202 *updated_next;
};

struct cgroup_root___202 {
	struct kernfs_root___263 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___202 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___202 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___202 *ss;
	struct list_head node;
	struct kernfs_ops___263 *kf_ops;
	int (*open)(struct kernfs_open_file___263 *);
	void (*release)(struct kernfs_open_file___263 *);
	u64 (*read_u64)(struct cgroup_subsys_state___202 *, struct cftype___202 *);
	s64 (*read_s64)(struct cgroup_subsys_state___202 *, struct cftype___202 *);
	int (*seq_show)(struct seq_file___250 *, void *);
	void * (*seq_start)(struct seq_file___250 *, loff_t *);
	void * (*seq_next)(struct seq_file___250 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___250 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___202 *, struct cftype___202 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___202 *, struct cftype___202 *, s64);
	ssize_t (*write)(struct kernfs_open_file___263 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___263 *, struct poll_table_struct___196 *);
};

struct xdp_rxq_info___84 {
	struct net_device___84 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___84 {
	struct net_device___84 *dev;
};

struct xdp_buff___84 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___84 *rxq;
	struct xdp_txq_info___84 *txq;
	u32 frame_sz;
};

struct xdp_frame___84 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___84 *dev_rx;
};

struct netlink_callback___84 {
	struct sk_buff___85 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___85 *, struct netlink_callback___84 *);
	int (*done)(struct netlink_callback___84 *);
	void *data;
	struct module___259 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___84 {
	int (*create)(struct sk_buff___85 *, struct net_device___84 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___85 *, unsigned char *);
	int (*cache)(const struct neighbour___71 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___84 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___85 *);
};

struct netdev_queue___84 {
	struct net_device___84 *dev;
	struct Qdisc___78 *qdisc;
	struct Qdisc___78 *qdisc_sleeping;
	struct kobject___263 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___84 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___78 {
	struct sk_buff___85 *head;
	struct sk_buff___85 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___78;

struct Qdisc___78 {
	int (*enqueue)(struct sk_buff___85 *, struct Qdisc___78 *, struct sk_buff___85 **);
	struct sk_buff___85 * (*dequeue)(struct Qdisc___78 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___78 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___84 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___84 gso_skb;
	struct qdisc_skb_head___78 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___78 *next_sched;
	struct sk_buff_head___84 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___84 {
	struct xdp_rxq_info___84 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___263 kobj;
	struct net_device___84 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___84 {
	enum net_device_path_type type;
	const struct net_device___84 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___84 = 0,
				DEV_PATH_BR_VLAN_TAG___84 = 1,
				DEV_PATH_BR_VLAN_UNTAG___84 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___84 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___84 {
	const struct net_device___84 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___84 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___78 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___84 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___84 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___85 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___84 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___84 *dev;
	const char *name;
};

struct net_device_ops___84 {
	int (*ndo_init)(struct net_device___84 *);
	void (*ndo_uninit)(struct net_device___84 *);
	int (*ndo_open)(struct net_device___84 *);
	int (*ndo_stop)(struct net_device___84 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___85 *, struct net_device___84 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___85 *, struct net_device___84 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___84 *, struct sk_buff___85 *, struct net_device___84 *);
	void (*ndo_change_rx_flags)(struct net_device___84 *, int);
	void (*ndo_set_rx_mode)(struct net_device___84 *);
	int (*ndo_set_mac_address)(struct net_device___84 *, void *);
	int (*ndo_validate_addr)(struct net_device___84 *);
	int (*ndo_do_ioctl)(struct net_device___84 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___84 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___84 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___84 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___84 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___84 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___84 *, int);
	int (*ndo_neigh_setup)(struct net_device___84 *, struct neigh_parms___71 *);
	void (*ndo_tx_timeout)(struct net_device___84 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___84 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___84 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___84 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___84 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___84 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___84 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___84 *);
	int (*ndo_netpoll_setup)(struct net_device___84 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___84 *);
	int (*ndo_set_vf_mac)(struct net_device___84 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___84 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___84 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___84 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___84 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___84 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___84 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___84 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___84 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___84 *, int, struct sk_buff___85 *);
	int (*ndo_get_vf_guid)(struct net_device___84 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___84 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___84 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___84 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___84 *);
	int (*ndo_fcoe_disable)(struct net_device___84 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___84 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___84 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___84 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___84 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___84 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___84 *, const struct sk_buff___85 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___84 *, struct net_device___84 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___84 *, struct net_device___84 *);
	struct net_device___84 * (*ndo_get_xmit_slave)(struct net_device___84 *, struct sk_buff___85 *, bool);
	struct net_device___84 * (*ndo_sk_get_lower_dev)(struct net_device___84 *, struct sock___71 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___84 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___84 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___84 *, struct neighbour___71 *);
	void (*ndo_neigh_destroy)(struct net_device___84 *, struct neighbour___71 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___85 *, struct netlink_callback___84 *, struct net_device___84 *, struct net_device___84 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___85 *, struct nlattr **, struct net_device___84 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___84 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___85 *, u32, u32, struct net_device___84 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___84 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___84 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___84 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___84 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___84 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___84 *, struct net_device___84 *);
	void (*ndo_dfwd_del_station)(struct net_device___84 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___84 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___84 *);
	int (*ndo_change_proto_down)(struct net_device___84 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___84 *, struct sk_buff___85 *);
	void (*ndo_set_rx_headroom)(struct net_device___84 *, int);
	int (*ndo_bpf)(struct net_device___84 *, struct netdev_bpf___84 *);
	int (*ndo_xdp_xmit)(struct net_device___84 *, int, struct xdp_frame___84 **, u32);
	struct net_device___84 * (*ndo_xdp_get_xmit_slave)(struct net_device___84 *, struct xdp_buff___84 *);
	int (*ndo_xsk_wakeup)(struct net_device___84 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___84 *);
	int (*ndo_tunnel_ctl)(struct net_device___84 *, struct ip_tunnel_parm *, int);
	struct net_device___84 * (*ndo_get_peer_dev)(struct net_device___84 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___84 *, struct net_device_path___84 *);
};

struct neigh_parms___71 {
	possible_net_t___84 net;
	struct net_device___84 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___71 *);
	struct neigh_table___71 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___71 {
	u32 (*l3mdev_fib_table)(const struct net_device___84 *);
	struct sk_buff___85 * (*l3mdev_l3_rcv)(struct net_device___84 *, struct sk_buff___85 *, u16);
	struct sk_buff___85 * (*l3mdev_l3_out)(struct net_device___84 *, struct sock___71 *, struct sk_buff___85 *, u16);
	struct dst_entry___71 * (*l3mdev_link_scope_lookup)(const struct net_device___84 *, struct flowi6 *);
};

struct ndisc_ops___53 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___84 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___84 *, struct neighbour___71 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___84 *, u8, struct neighbour___71 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___84 *, struct sk_buff___85 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___89 *, struct net_device___84 *, const struct prefix_info *, struct inet6_dev___53 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___12;

struct in_device___12 {
	struct net_device___84 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___12 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___71 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___53;

struct ifacaddr6___20;

struct inet6_dev___53 {
	struct net_device___84 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___53 *mc_list;
	struct ifmcaddr6___53 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___84 mc_query_queue;
	struct sk_buff_head___84 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___20 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___71 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___78;

struct tcf_block___78;

struct mini_Qdisc___78 {
	struct tcf_proto___78 *filter_list;
	struct tcf_block___78 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___78 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___84 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___84 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___89 *, struct net_device___84 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___84 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___84 *, struct list_head *);
	size_t (*get_size)(const struct net_device___84 *);
	int (*fill_info)(struct sk_buff___85 *, const struct net_device___84 *);
	size_t (*get_xstats_size)(const struct net_device___84 *);
	int (*fill_xstats)(struct sk_buff___85 *, const struct net_device___84 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___84 *, struct net_device___84 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___84 *, const struct net_device___84 *);
	int (*fill_slave_info)(struct sk_buff___85 *, const struct net_device___84 *, const struct net_device___84 *);
	struct net___89 * (*get_link_net)(const struct net_device___84 *);
	size_t (*get_linkxstats_size)(const struct net_device___84 *, int);
	int (*fill_linkxstats)(struct sk_buff___85 *, const struct net_device___84 *, int *, int);
};

struct packet_type___5 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___84 *dev;
	int (*func)(struct sk_buff___85 *, struct net_device___84 *, struct packet_type___5 *, struct net_device___84 *);
	void (*list_func)(struct list_head *, struct packet_type___5 *, struct net_device___84 *);
	bool (*id_match)(struct packet_type___5 *, struct sock___71 *);
	struct net___89 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct netdev_notifier_info___14 {
	struct net_device___84 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_change_info___2 {
	struct netdev_notifier_info___14 info;
	unsigned int flags_changed;
};

struct in_ifaddr___12 {
	struct hlist_node hash;
	struct in_ifaddr___12 *ifa_next;
	struct in_device___12 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct arpreq {
	struct sockaddr arp_pa;
	struct sockaddr arp_ha;
	int arp_flags;
	struct sockaddr arp_netmask;
	char arp_dev[16];
};

struct block_device_operations___166;

struct gendisk___169 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___169 *part0;
	const struct block_device_operations___166 *fops;
	struct request_queue___166 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___152 *bdi;
	struct kobject___263 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___263 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___166 {
	struct bio___166 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___192 *bip_vec;
	struct bio_vec___192 bip_inline_vecs[0];
};

struct blkcg___154;

struct blkg_policy_data___154;

struct blkcg_gq___154 {
	struct request_queue___166 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___154 *blkcg;
	struct blkcg_gq___154 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___154 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___166 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___166(struct request___166 *);

typedef void integrity_complete_fn___166(struct request___166 *, unsigned int);

struct blk_integrity_profile___166 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___166 *prepare_fn;
	integrity_complete_fn___166 *complete_fn;
	const char *name;
};

struct block_device_operations___166 {
	blk_qc_t (*submit_bio)(struct bio___166 *);
	int (*open)(struct block_device___169 *, fmode_t);
	void (*release)(struct gendisk___169 *, fmode_t);
	int (*rw_page)(struct block_device___169 *, sector_t, struct page___280 *, unsigned int);
	int (*ioctl)(struct block_device___169 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___169 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___169 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___169 *);
	int (*getgeo)(struct block_device___169 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___169 *, bool);
	void (*swap_slot_free_notify)(struct block_device___169 *, long unsigned int);
	int (*report_zones)(struct gendisk___169 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___169 *, umode_t *);
	struct module___259 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___169 *, sector_t *);
};

typedef void rq_end_io_fn___166(struct request___166 *, blk_status_t);

struct request___166 {
	struct request_queue___166 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___161 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___166 *bio;
	struct bio___166 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___192 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___166 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___166 *saved_end_io;
		} flush;
	};
	struct gendisk___169 *rq_disk;
	struct block_device___169 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___166 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___161 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___166 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___263 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___275 *debugfs_dir;
	struct dentry___275 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___166;

struct elevator_mq_ops___166 {
	int (*init_sched)(struct request_queue___166 *, struct elevator_type___166 *);
	void (*exit_sched)(struct elevator_queue___166 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___161 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___161 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___161 *);
	bool (*allow_merge)(struct request_queue___166 *, struct request___166 *, struct bio___166 *);
	bool (*bio_merge)(struct request_queue___166 *, struct bio___166 *, unsigned int);
	int (*request_merge)(struct request_queue___166 *, struct request___166 **, struct bio___166 *);
	void (*request_merged)(struct request_queue___166 *, struct request___166 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___166 *, struct request___166 *, struct request___166 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___166 *);
	void (*finish_request)(struct request___166 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___161 *, struct list_head *, bool);
	struct request___166 * (*dispatch_request)(struct blk_mq_hw_ctx___161 *);
	bool (*has_work)(struct blk_mq_hw_ctx___161 *);
	void (*completed_request)(struct request___166 *, u64);
	void (*requeue_request)(struct request___166 *);
	struct request___166 * (*former_request)(struct request_queue___166 *, struct request___166 *);
	struct request___166 * (*next_request)(struct request_queue___166 *, struct request___166 *);
	void (*init_icq)(struct io_cq___166 *);
	void (*exit_icq)(struct io_cq___166 *);
};

struct elv_fs_entry___166;

struct elevator_type___166 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___166 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___166 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___259 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___166 {
	struct elevator_type___166 *type;
	void *elevator_data;
	struct kobject___263 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___166 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___166 *, char *);
	ssize_t (*store)(struct elevator_queue___166 *, const char *, size_t);
};

struct blk_mq_queue_data___161;

struct blk_mq_ops___161 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___161 *, const struct blk_mq_queue_data___161 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___161 *);
	int (*get_budget)(struct request_queue___166 *);
	void (*put_budget)(struct request_queue___166 *, int);
	void (*set_rq_budget_token)(struct request___166 *, int);
	int (*get_rq_budget_token)(struct request___166 *);
	enum blk_eh_timer_return (*timeout)(struct request___166 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___161 *);
	void (*complete)(struct request___166 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___161 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___161 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___161 *, struct request___166 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___161 *, struct request___166 *, unsigned int);
	void (*initialize_rq_fn)(struct request___166 *);
	void (*cleanup_rq)(struct request___166 *);
	bool (*busy)(struct request_queue___166 *);
	int (*map_queues)(struct blk_mq_tag_set___161 *);
	void (*show_rq)(struct seq_file___250 *, struct request___166 *);
};

struct blk_mq_tag_set___161 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___161 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___161 {
	struct request___166 *rq;
	bool last;
};

struct blkcg_policy_data___154;

struct blkcg___154 {
	struct cgroup_subsys_state___202 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___154 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___154 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___154 {
	struct blkcg___154 *blkcg;
	int plid;
};

struct blkg_policy_data___154 {
	struct blkcg_gq___154 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___140 {
	struct mem_cgroup___140 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___140 {
	struct lruvec___148 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___140 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___140 *memcg;
};

struct obj_cgroup___140 {
	struct percpu_ref refcnt;
	struct mem_cgroup___140 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___78 {
	spinlock_t *lock;
	struct sk_buff___85 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___78;

struct Qdisc_ops___78 {
	struct Qdisc_ops___78 *next;
	const struct Qdisc_class_ops___78 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___85 *, struct Qdisc___78 *, struct sk_buff___85 **);
	struct sk_buff___85 * (*dequeue)(struct Qdisc___78 *);
	struct sk_buff___85 * (*peek)(struct Qdisc___78 *);
	int (*init)(struct Qdisc___78 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___78 *);
	void (*destroy)(struct Qdisc___78 *);
	int (*change)(struct Qdisc___78 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___78 *);
	int (*change_tx_queue_len)(struct Qdisc___78 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___78 *, unsigned int);
	int (*dump)(struct Qdisc___78 *, struct sk_buff___85 *);
	int (*dump_stats)(struct Qdisc___78 *, struct gnet_dump___78 *);
	void (*ingress_block_set)(struct Qdisc___78 *, u32);
	void (*egress_block_set)(struct Qdisc___78 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___78 *);
	u32 (*egress_block_get)(struct Qdisc___78 *);
	struct module___259 *owner;
};

struct Qdisc_class_ops___78 {
	unsigned int flags;
	struct netdev_queue___84 * (*select_queue)(struct Qdisc___78 *, struct tcmsg *);
	int (*graft)(struct Qdisc___78 *, long unsigned int, struct Qdisc___78 *, struct Qdisc___78 **, struct netlink_ext_ack *);
	struct Qdisc___78 * (*leaf)(struct Qdisc___78 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___78 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___78 *, u32);
	int (*change)(struct Qdisc___78 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___78 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___78 *, struct qdisc_walker *);
	struct tcf_block___78 * (*tcf_block)(struct Qdisc___78 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___78 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___78 *, long unsigned int);
	int (*dump)(struct Qdisc___78 *, long unsigned int, struct sk_buff___85 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___78 *, long unsigned int, struct gnet_dump___78 *);
};

struct tcf_chain___78;

struct tcf_block___78 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___89 *net;
	struct Qdisc___78 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___78 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___78;

struct tcf_proto_ops___78;

struct tcf_proto___78 {
	struct tcf_proto___78 *next;
	void *root;
	int (*classify)(struct sk_buff___85 *, const struct tcf_proto___78 *, struct tcf_result___78 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___78 *ops;
	struct tcf_chain___78 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___78 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___78 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___78 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___85 *, const struct tcf_proto___78 *, struct tcf_result___78 *);
	int (*init)(struct tcf_proto___78 *);
	void (*destroy)(struct tcf_proto___78 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___78 *, u32);
	void (*put)(struct tcf_proto___78 *, void *);
	int (*change)(struct net___89 *, struct sk_buff___85 *, struct tcf_proto___78 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___78 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___78 *);
	void (*walk)(struct tcf_proto___78 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___78 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___78 *, void *);
	void (*hw_del)(struct tcf_proto___78 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___89 *, struct tcf_chain___78 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___89 *, struct tcf_proto___78 *, void *, struct sk_buff___85 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___89 *, struct tcf_proto___78 *, void *, struct sk_buff___85 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___85 *, struct net___89 *, void *);
	struct module___259 *owner;
	int flags;
};

struct tcf_chain___78 {
	struct mutex filter_chain_lock;
	struct tcf_proto___78 *filter_chain;
	struct list_head list;
	struct tcf_block___78 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___78 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___71 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___78 *prog;
};

struct pneigh_entry___71;

struct neigh_hash_table___71;

struct neigh_table___71 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___84 *, __u32 *);
	bool (*key_eq)(const struct neighbour___71 *, const void *);
	int (*constructor)(struct neighbour___71 *);
	int (*pconstructor)(struct pneigh_entry___71 *);
	void (*pdestructor)(struct pneigh_entry___71 *);
	void (*proxy_redo)(struct sk_buff___85 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___84 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___71 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___84 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___71 *nht;
	struct pneigh_entry___71 **phash_buckets;
};

struct neigh_ops___71 {
	int family;
	void (*solicit)(struct neighbour___71 *, struct sk_buff___85 *);
	void (*error_report)(struct neighbour___71 *, struct sk_buff___85 *);
	int (*output)(struct neighbour___71 *, struct sk_buff___85 *);
	int (*connected_output)(struct neighbour___71 *, struct sk_buff___85 *);
};

struct pneigh_entry___71 {
	struct pneigh_entry___71 *next;
	possible_net_t___84 net;
	struct net_device___84 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___71 {
	struct neighbour___71 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct neigh_seq_state___2 {
	struct seq_net_private___9 p;
	struct neigh_table___71 *tbl;
	struct neigh_hash_table___71 *nht;
	void * (*neigh_sub_iter)(struct neigh_seq_state___2 *, struct neighbour___71 *, loff_t *);
	unsigned int bucket;
	unsigned int flags;
};

struct lwtunnel_state___47 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___89 *, struct sock___71 *, struct sk_buff___85 *);
	int (*orig_input)(struct sk_buff___85 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___71 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___71 *ctarget;
	struct net___89 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___71 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___71 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___56;

struct timewait_sock_ops___55;

struct proto___71 {
	void (*close)(struct sock___71 *, long int);
	int (*pre_connect)(struct sock___71 *, struct sockaddr *, int);
	int (*connect)(struct sock___71 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___71 *, int);
	struct sock___71 * (*accept)(struct sock___71 *, int, int *, bool);
	int (*ioctl)(struct sock___71 *, int, long unsigned int);
	int (*init)(struct sock___71 *);
	void (*destroy)(struct sock___71 *);
	void (*shutdown)(struct sock___71 *, int);
	int (*setsockopt)(struct sock___71 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___71 *, int, int, char *, int *);
	void (*keepalive)(struct sock___71 *, int);
	int (*compat_ioctl)(struct sock___71 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___71 *, struct msghdr___73 *, size_t);
	int (*recvmsg)(struct sock___71 *, struct msghdr___73 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___71 *, struct page___280 *, int, size_t, int);
	int (*bind)(struct sock___71 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___71 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___71 *, struct sk_buff___85 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___71 *);
	int (*hash)(struct sock___71 *);
	void (*unhash)(struct sock___71 *);
	void (*rehash)(struct sock___71 *);
	int (*get_port)(struct sock___71 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___71 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___71 *, int);
	bool (*sock_is_readable)(struct sock___71 *);
	void (*enter_memory_pressure)(struct sock___71 *);
	void (*leave_memory_pressure)(struct sock___71 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___56 *rsk_prot;
	struct timewait_sock_ops___55 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___259 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___71 *, int);
};

struct sock_reuseport___22 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___78 *prog;
	struct sock___71 *socks[0];
};

struct request_sock___57;

struct request_sock_ops___56 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___71 *, struct request_sock___57 *);
	void (*send_ack)(const struct sock___71 *, struct sk_buff___85 *, struct request_sock___57 *);
	void (*send_reset)(const struct sock___71 *, struct sk_buff___85 *);
	void (*destructor)(struct request_sock___57 *);
	void (*syn_ack_timeout)(const struct request_sock___57 *);
};

struct timewait_sock_ops___55 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___71 *, struct sock___71 *, void *);
	void (*twsk_destructor)(struct sock___71 *);
};

struct request_sock___57 {
	struct sock_common___71 __req_common;
	struct request_sock___57 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___56 *rsk_ops;
	struct sock___71 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___53 {
	struct in6_addr mca_addr;
	struct inet6_dev___53 *idev;
	struct ifmcaddr6___53 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___20 {
	struct in6_addr aca_addr;
	struct fib6_info___20 *aca_rt;
	struct ifacaddr6___20 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___20 {
	struct fib_nh_exception___20 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___21 *fnhe_rth_input;
	struct rtable___21 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___21 {
	struct dst_entry___71 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___20 {
	struct fib_nh_exception___20 *chain;
};

struct fib_info___11;

struct fib_nh___11 {
	struct fib_nh_common___20 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___11 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___11 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___89 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___11 *nh;
	struct callback_head rcu;
	struct fib_nh___11 fib_nh[0];
};

struct nh_info___11;

struct nh_group___11;

struct nexthop___11 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___89 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___11 *nh_info;
		struct nh_group___11 *nh_grp;
	};
};

typedef struct {
	char ax25_call[7];
} ax25_address;

struct nh_info___11 {
	struct hlist_node dev_hash;
	struct nexthop___11 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___20 fib_nhc;
		struct fib_nh___11 fib_nh;
		struct fib6_nh___20 fib6_nh;
	};
};

struct nh_grp_entry___11;

struct nh_res_bucket___11 {
	struct nh_grp_entry___11 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___11 {
	struct nexthop___11 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___11 *nh_parent;
};

struct nh_res_table___11 {
	struct net___89 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___11 nh_buckets[0];
};

struct nh_group___11 {
	struct nh_group___11 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___11 *res_table;
	struct nh_grp_entry___11 nh_entries[0];
};

struct hw_port_info___7 {
	struct net_device___84 *lower_dev;
	u32 port_id;
};

struct metadata_dst___8 {
	struct dst_entry___71 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___7 port_info;
	} u;
};

struct nf_hook_state___12 {
	u8 hook;
	u8 pf;
	struct net_device___84 *in;
	struct net_device___84 *out;
	struct sock___71 *sk;
	struct net___89 *net;
	int (*okfn)(struct net___89 *, struct sock___71 *, struct sk_buff___85 *);
};

struct dentry___276;

struct super_block___276;

struct module___260;

struct file_system_type___276 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___276 * (*mount)(struct file_system_type___276 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___276 *);
	struct module___260 *owner;
	struct file_system_type___276 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___276;

struct kiocb___276;

struct iov_iter___196;

struct poll_table_struct___197;

struct vm_area_struct___281;

struct inode___276;

struct file_lock___276;

struct page___281;

struct pipe_inode_info___117;

struct seq_file___251;

struct file_operations___277 {
	struct module___260 *owner;
	loff_t (*llseek)(struct file___276 *, loff_t, int);
	ssize_t (*read)(struct file___276 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___276 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___276 *, struct iov_iter___196 *);
	ssize_t (*write_iter)(struct kiocb___276 *, struct iov_iter___196 *);
	int (*iopoll)(struct kiocb___276 *, bool);
	int (*iterate)(struct file___276 *, struct dir_context *);
	int (*iterate_shared)(struct file___276 *, struct dir_context *);
	__poll_t (*poll)(struct file___276 *, struct poll_table_struct___197 *);
	long int (*unlocked_ioctl)(struct file___276 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___276 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___276 *, struct vm_area_struct___281 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___276 *, struct file___276 *);
	int (*flush)(struct file___276 *, fl_owner_t);
	int (*release)(struct inode___276 *, struct file___276 *);
	int (*fsync)(struct file___276 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___276 *, int);
	int (*lock)(struct file___276 *, int, struct file_lock___276 *);
	ssize_t (*sendpage)(struct file___276 *, struct page___281 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___276 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___276 *, long unsigned int);
	int (*flock)(struct file___276 *, int, struct file_lock___276 *);
	ssize_t (*splice_write)(struct pipe_inode_info___117 *, struct file___276 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___276 *, loff_t *, struct pipe_inode_info___117 *, size_t, unsigned int);
	int (*setlease)(struct file___276 *, long int, struct file_lock___276 **, void **);
	long int (*fallocate)(struct file___276 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___251 *, struct file___276 *);
	ssize_t (*copy_file_range)(struct file___276 *, loff_t, struct file___276 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___276 *, loff_t, struct file___276 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___276 *, loff_t, loff_t, int);
};

struct vmacache___281 {
	u64 seqnum;
	struct vm_area_struct___281 *vmas[4];
};

struct page_frag___281 {
	struct page___281 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___282;

struct pid___253;

struct nsproxy___262;

struct signal_struct___277;

struct bio_list___167;

struct backing_dev_info___153;

struct io_context___167;

struct css_set___203;

struct mem_cgroup___141;

struct request_queue___167;

struct vm_struct___259;

struct task_struct___283 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___283 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___282 *mm;
	struct mm_struct___282 *active_mm;
	struct vmacache___281 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___283 *real_parent;
	struct task_struct___283 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___283 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___253 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___262 *nsproxy;
	struct signal_struct___277 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___283 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___167 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___153 *backing_dev_info;
	struct io_context___167 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___203 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___117 *splice_pipe;
	struct page_frag___281 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___141 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___141 *active_memcg;
	struct request_queue___167 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___283 *oom_reaper_list;
	struct vm_struct___259 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___264;

struct kobj_type___264;

struct kernfs_node___264;

struct kobject___264 {
	const char *name;
	struct list_head entry;
	struct kobject___264 *parent;
	struct kset___264 *kset;
	struct kobj_type___264 *ktype;
	struct kernfs_node___264 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___261 {
	struct kobject___264 kobj;
	struct module___260 *mod;
	struct kobject___264 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___260 {
	struct module___260 *mod;
	struct latch_tree_node node;
};

struct module_layout___260 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___260 mtn;
};

struct module_attribute___260;

struct kernel_param___260;

struct module___260 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___261 mkobj;
	struct module_attribute___260 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___264 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___260 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___260 core_layout;
	struct module_layout___260 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___253;

struct upid___253 {
	int nr;
	struct pid_namespace___253 *ns;
};

struct pid_namespace___253 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___283 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___253 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___253 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___253 numbers[1];
};

typedef struct page___281 *pgtable_t___281;

struct address_space___276;

struct page_pool___105;

struct dev_pagemap___271;

struct page___281 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___276 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___105 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___281 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___281 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___282 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___271 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___271;

struct vm_area_struct___281 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___281 *vm_next;
	struct vm_area_struct___281 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___282 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___271 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___276 *vm_file;
	struct file___276 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___277 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___283 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___283 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___253 *pids[4];
	struct pid___253 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___282 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___281;

struct mm_struct___282 {
	struct {
		struct vm_area_struct___281 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___276 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___281 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___283 *owner;
		struct user_namespace___26 *user_ns;
		struct file___276 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___90;

struct cgroup_namespace___203;

struct nsproxy___262 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___253 *pid_ns_for_children;
	struct net___90 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___203 *cgroup_ns;
};

struct bio___167;

struct bio_list___167 {
	struct bio___167 *head;
	struct bio___167 *tail;
};

struct cgroup_subsys_state___203;

struct bdi_writeback___153 {
	struct backing_dev_info___153 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___203 *memcg_css;
	struct cgroup_subsys_state___203 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___257;

struct backing_dev_info___153 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___153 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___257 *dev;
	char dev_name[64];
	struct device___257 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___276 *debug_dir;
};

struct io_cq___167;

struct io_context___167 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___167 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___203;

struct css_set___203 {
	struct cgroup_subsys_state___203 *subsys[14];
	refcount_t refcount;
	struct css_set___203 *dom_cset;
	struct cgroup___203 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___203 *mg_src_cgrp;
	struct cgroup___203 *mg_dst_cgrp;
	struct css_set___203 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___276;

struct pipe_buffer___117;

struct pipe_inode_info___117 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___281 *tmp_page;
	struct fasync_struct___276 *fasync_readers;
	struct fasync_struct___276 *fasync_writers;
	struct pipe_buffer___117 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___203;

struct cgroup_subsys_state___203 {
	struct cgroup___203 *cgroup;
	struct cgroup_subsys___203 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___203 *parent;
};

struct cgroup_file___203 {
	struct kernfs_node___264 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___141;

struct mem_cgroup_per_node___141;

struct mem_cgroup___141 {
	struct cgroup_subsys_state___203 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___203 events_file;
	struct cgroup_file___203 events_local_file;
	struct cgroup_file___203 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___141 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___283 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___141 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___167;

struct blk_integrity___167 {
	const struct blk_integrity_profile___167 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___167 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___167 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___167;

struct elevator_queue___167;

struct blk_mq_ops___162;

struct blk_mq_hw_ctx___162;

struct gendisk___170;

struct blkcg_gq___155;

struct blk_mq_tag_set___162;

struct request_queue___167 {
	struct request___167 *last_merge;
	struct elevator_queue___167 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___162 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___162 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___170 *disk;
	struct kobject___264 kobj;
	struct kobject___264 *mq_kobj;
	struct blk_integrity___167 integrity;
	struct device___257 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___155 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___162 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___167 bio_split;
	struct dentry___276 *debugfs_dir;
	struct dentry___276 *sched_debugfs_dir;
	struct dentry___276 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___259 {
	struct vm_struct___259 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___281 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___276;

struct address_space___276 {
	struct inode___276 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___276 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___105 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___257 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___105 {
	u32 count;
	struct page___281 *cache[128];
};

struct page_pool___105 {
	struct page_pool_params___105 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___281 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___105 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___271;

struct dev_pagemap___271 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___271 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___276;

struct path___276 {
	struct vfsmount___276 *mnt;
	struct dentry___276 *dentry;
};

struct fown_struct___253 {
	rwlock_t lock;
	struct pid___253 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___276 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___276 f_path;
	struct inode___276 *f_inode;
	const struct file_operations___277 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___253 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___276 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___271;

struct vm_operations_struct___271 {
	void (*open)(struct vm_area_struct___281 *);
	void (*close)(struct vm_area_struct___281 *);
	int (*may_split)(struct vm_area_struct___281 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___281 *);
	int (*mprotect)(struct vm_area_struct___281 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___271 *);
	vm_fault_t (*huge_fault)(struct vm_fault___271 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___271 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___281 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___271 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___271 *);
	int (*access)(struct vm_area_struct___281 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___281 *);
	int (*set_policy)(struct vm_area_struct___281 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___281 *, long unsigned int);
	struct page___281 * (*find_special_page)(struct vm_area_struct___281 *, long unsigned int);
};

struct core_thread___281 {
	struct task_struct___283 *task;
	struct core_thread___281 *next;
};

struct core_state___281 {
	atomic_t nr_threads;
	struct core_thread___281 dumper;
	struct completion startup;
};

struct vm_fault___271 {
	const struct {
		struct vm_area_struct___281 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___281 *cow_page;
	struct page___281 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___281 prealloc_pte;
};

struct pglist_data___149;

struct lruvec___149 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___149 *pgdat;
};

struct zone___149 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___149 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___149 {
	struct zone___149 *zone;
	int zone_idx;
};

struct zonelist___149 {
	struct zoneref___149 _zonerefs[321];
};

struct pglist_data___149 {
	struct zone___149 node_zones[5];
	struct zonelist___149 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___283 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___283 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___149 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___276;

struct dentry___276 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___276 *d_parent;
	struct qstr d_name;
	struct inode___276 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___276 *d_op;
	struct super_block___276 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___276;

struct inode___276 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___276 *i_op;
	struct super_block___276 *i_sb;
	struct address_space___276 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___153 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___277 *i_fop;
		void (*free_inode)(struct inode___276 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___276 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___117 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___276 {
	int (*d_revalidate)(struct dentry___276 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___276 *, unsigned int);
	int (*d_hash)(const struct dentry___276 *, struct qstr *);
	int (*d_compare)(const struct dentry___276 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___276 *);
	int (*d_init)(struct dentry___276 *);
	void (*d_release)(struct dentry___276 *);
	void (*d_prune)(struct dentry___276 *);
	void (*d_iput)(struct dentry___276 *, struct inode___276 *);
	char * (*d_dname)(struct dentry___276 *, char *, int);
	struct vfsmount___276 * (*d_automount)(struct path___276 *);
	int (*d_manage)(const struct path___276 *, bool);
	struct dentry___276 * (*d_real)(struct dentry___276 *, const struct inode___276 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___276;

struct mem_dqinfo___276 {
	struct quota_format_type___276 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___276;

struct quota_info___276 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___276 *files[3];
	struct mem_dqinfo___276 info[3];
	const struct quota_format_ops___276 *ops[3];
};

struct rcuwait___277 {
	struct task_struct___283 *task;
};

struct percpu_rw_semaphore___277 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___277 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___276 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___277 rw_sem[3];
};

struct shrink_control___141;

struct shrinker___141 {
	long unsigned int (*count_objects)(struct shrinker___141 *, struct shrink_control___141 *);
	long unsigned int (*scan_objects)(struct shrinker___141 *, struct shrink_control___141 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___276;

struct dquot_operations___276;

struct quotactl_ops___276;

struct block_device___170;

struct super_block___276 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___276 *s_type;
	const struct super_operations___276 *s_op;
	const struct dquot_operations___276 *dq_op;
	const struct quotactl_ops___276 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___276 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___170 *s_bdev;
	struct backing_dev_info___153 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___276 s_dquot;
	struct sb_writers___276 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___276 *s_d_op;
	int cleancache_poolid;
	struct shrinker___141 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___276 {
	struct dentry___276 *mnt_root;
	struct super_block___276 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___141 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___141 *memcg;
};

struct psi_group___203 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___283 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___79;

struct cgroup_bpf___79 {
	struct bpf_prog_array___79 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___79 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___203;

struct cgroup_rstat_cpu___203;

struct cgroup___203 {
	struct cgroup_subsys_state___203 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___264 *kn;
	struct cgroup_file___203 procs_file;
	struct cgroup_file___203 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___203 *subsys[14];
	struct cgroup_root___203 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___203 *dom_cgrp;
	struct cgroup___203 *old_dom_cgrp;
	struct cgroup_rstat_cpu___203 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___203 psi;
	struct cgroup_bpf___79 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___167 {
	struct request_queue___167 *q;
	struct io_context___167 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___276 {
	struct file___276 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___276 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___276 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___276 *ia_file;
};

struct dquot___276 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___276 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___276 {
	int qf_fmt_id;
	const struct quota_format_ops___276 *qf_ops;
	struct module___260 *qf_owner;
	struct quota_format_type___276 *qf_next;
};

struct quota_format_ops___276 {
	int (*check_quota_file)(struct super_block___276 *, int);
	int (*read_file_info)(struct super_block___276 *, int);
	int (*write_file_info)(struct super_block___276 *, int);
	int (*free_file_info)(struct super_block___276 *, int);
	int (*read_dqblk)(struct dquot___276 *);
	int (*commit_dqblk)(struct dquot___276 *);
	int (*release_dqblk)(struct dquot___276 *);
	int (*get_next_id)(struct super_block___276 *, struct kqid *);
};

struct dquot_operations___276 {
	int (*write_dquot)(struct dquot___276 *);
	struct dquot___276 * (*alloc_dquot)(struct super_block___276 *, int);
	void (*destroy_dquot)(struct dquot___276 *);
	int (*acquire_dquot)(struct dquot___276 *);
	int (*release_dquot)(struct dquot___276 *);
	int (*mark_dirty)(struct dquot___276 *);
	int (*write_info)(struct super_block___276 *, int);
	qsize_t * (*get_reserved_space)(struct inode___276 *);
	int (*get_projid)(struct inode___276 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___276 *, qsize_t *);
	int (*get_next_id)(struct super_block___276 *, struct kqid *);
};

struct quotactl_ops___276 {
	int (*quota_on)(struct super_block___276 *, int, int, const struct path___276 *);
	int (*quota_off)(struct super_block___276 *, int);
	int (*quota_enable)(struct super_block___276 *, unsigned int);
	int (*quota_disable)(struct super_block___276 *, unsigned int);
	int (*quota_sync)(struct super_block___276 *, int);
	int (*set_info)(struct super_block___276 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___276 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___276 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___276 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___276 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___276 *, unsigned int);
};

struct writeback_control___153;

struct address_space_operations___276 {
	int (*writepage)(struct page___281 *, struct writeback_control___153 *);
	int (*readpage)(struct file___276 *, struct page___281 *);
	int (*writepages)(struct address_space___276 *, struct writeback_control___153 *);
	int (*set_page_dirty)(struct page___281 *);
	int (*readpages)(struct file___276 *, struct address_space___276 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___276 *, struct address_space___276 *, loff_t, unsigned int, unsigned int, struct page___281 **, void **);
	int (*write_end)(struct file___276 *, struct address_space___276 *, loff_t, unsigned int, unsigned int, struct page___281 *, void *);
	sector_t (*bmap)(struct address_space___276 *, sector_t);
	void (*invalidatepage)(struct page___281 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___281 *, gfp_t);
	void (*freepage)(struct page___281 *);
	ssize_t (*direct_IO)(struct kiocb___276 *, struct iov_iter___196 *);
	int (*migratepage)(struct address_space___276 *, struct page___281 *, struct page___281 *, enum migrate_mode);
	bool (*isolate_page)(struct page___281 *, isolate_mode_t);
	void (*putback_page)(struct page___281 *);
	int (*launder_page)(struct page___281 *);
	int (*is_partially_uptodate)(struct page___281 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___281 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___276 *, struct page___281 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___276 *, sector_t *);
	void (*swap_deactivate)(struct file___276 *);
};

struct writeback_control___153 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___153 *wb;
	struct inode___276 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___193;

struct iov_iter___196 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___193 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___117 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___276 {
	struct dentry___276 * (*lookup)(struct inode___276 *, struct dentry___276 *, unsigned int);
	const char * (*get_link)(struct dentry___276 *, struct inode___276 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___276 *, int);
	struct posix_acl * (*get_acl)(struct inode___276 *, int, bool);
	int (*readlink)(struct dentry___276 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___276 *, struct dentry___276 *, umode_t, bool);
	int (*link)(struct dentry___276 *, struct inode___276 *, struct dentry___276 *);
	int (*unlink)(struct inode___276 *, struct dentry___276 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___276 *, struct dentry___276 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___276 *, struct dentry___276 *, umode_t);
	int (*rmdir)(struct inode___276 *, struct dentry___276 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___276 *, struct dentry___276 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___276 *, struct dentry___276 *, struct inode___276 *, struct dentry___276 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___276 *, struct iattr___276 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___276 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___276 *, char *, size_t);
	int (*fiemap)(struct inode___276 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___276 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___276 *, struct dentry___276 *, struct file___276 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___276 *, struct dentry___276 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___276 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___276 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___276 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___276 {
	void (*fl_copy_lock)(struct file_lock___276 *, struct file_lock___276 *);
	void (*fl_release_private)(struct file_lock___276 *);
};

struct lock_manager_operations___276;

struct file_lock___276 {
	struct file_lock___276 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___276 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___276 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___276 *fl_ops;
	const struct lock_manager_operations___276 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___276 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___276 *);
	int (*lm_grant)(struct file_lock___276 *, int);
	bool (*lm_break)(struct file_lock___276 *);
	int (*lm_change)(struct file_lock___276 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___276 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___276 *);
};

struct fasync_struct___276 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___276 *fa_next;
	struct file___276 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___276 {
	struct inode___276 * (*alloc_inode)(struct super_block___276 *);
	void (*destroy_inode)(struct inode___276 *);
	void (*free_inode)(struct inode___276 *);
	void (*dirty_inode)(struct inode___276 *, int);
	int (*write_inode)(struct inode___276 *, struct writeback_control___153 *);
	int (*drop_inode)(struct inode___276 *);
	void (*evict_inode)(struct inode___276 *);
	void (*put_super)(struct super_block___276 *);
	int (*sync_fs)(struct super_block___276 *, int);
	int (*freeze_super)(struct super_block___276 *);
	int (*freeze_fs)(struct super_block___276 *);
	int (*thaw_super)(struct super_block___276 *);
	int (*unfreeze_fs)(struct super_block___276 *);
	int (*statfs)(struct dentry___276 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___276 *, int *, char *);
	void (*umount_begin)(struct super_block___276 *);
	int (*show_options)(struct seq_file___251 *, struct dentry___276 *);
	int (*show_devname)(struct seq_file___251 *, struct dentry___276 *);
	int (*show_path)(struct seq_file___251 *, struct dentry___276 *);
	int (*show_stats)(struct seq_file___251 *, struct dentry___276 *);
	ssize_t (*quota_read)(struct super_block___276 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___276 *, int, const char *, size_t, loff_t);
	struct dquot___276 ** (*get_dquots)(struct inode___276 *);
	long int (*nr_cached_objects)(struct super_block___276 *, struct shrink_control___141 *);
	long int (*free_cached_objects)(struct super_block___276 *, struct shrink_control___141 *);
	struct file___276 * (*real_loop)(struct file___276 *);
};

struct wakeup_source___257;

struct dev_pm_info___257 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___257 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___257 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___257;

struct bus_type___257;

struct device_driver___257;

struct dev_pm_domain___257;

struct fwnode_handle___253;

struct class___257;

struct attribute_group___264;

struct device___257 {
	struct kobject___264 kobj;
	struct device___257 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___257 *type;
	struct bus_type___257 *bus;
	struct device_driver___257 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___257 power;
	struct dev_pm_domain___257 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___253 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___257 *class;
	const struct attribute_group___264 **groups;
	void (*release)(struct device___257 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___170 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___276 *bd_inode;
	struct super_block___276 *bd_super;
	void *bd_claiming;
	struct device___257 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___264 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___170 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___276 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___205)(struct file___276 *, wait_queue_head_t *, struct poll_table_struct___197 *);

struct poll_table_struct___197 {
	poll_queue_proc___205 _qproc;
	__poll_t _key;
};

struct seq_operations___251;

struct seq_file___251 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___251 *op;
	int poll_event;
	const struct file___276 *file;
	void *private;
};

typedef void bio_end_io_t___167(struct bio___167 *);

struct bio_vec___193 {
	struct page___281 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___167;

struct bio___167 {
	struct bio___167 *bi_next;
	struct block_device___170 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___167 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___155 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___167 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___193 *bi_io_vec;
	struct bio_set___167 *bi_pool;
	struct bio_vec___193 bi_inline_vecs[0];
};

struct kernfs_root___264;

struct kernfs_elem_dir___264 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___264 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___264;

struct kernfs_root___264 {
	struct kernfs_node___264 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___264 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___264 {
	struct kernfs_node___264 *target_kn;
};

struct kernfs_ops___264;

struct kernfs_elem_attr___264 {
	const struct kernfs_ops___264 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___264 *notify_next;
};

struct kernfs_node___264 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___264 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___264 dir;
		struct kernfs_elem_symlink___264 symlink;
		struct kernfs_elem_attr___264 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___264;

struct kernfs_ops___264 {
	int (*open)(struct kernfs_open_file___264 *);
	void (*release)(struct kernfs_open_file___264 *);
	int (*seq_show)(struct seq_file___251 *, void *);
	void * (*seq_start)(struct seq_file___251 *, loff_t *);
	void * (*seq_next)(struct seq_file___251 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___251 *, void *);
	ssize_t (*read)(struct kernfs_open_file___264 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___264 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___264 *, struct poll_table_struct___197 *);
	int (*mmap)(struct kernfs_open_file___264 *, struct vm_area_struct___281 *);
};

struct kernfs_syscall_ops___264 {
	int (*show_options)(struct seq_file___251 *, struct kernfs_root___264 *);
	int (*mkdir)(struct kernfs_node___264 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___264 *);
	int (*rename)(struct kernfs_node___264 *, struct kernfs_node___264 *, const char *);
	int (*show_path)(struct seq_file___251 *, struct kernfs_node___264 *, struct kernfs_root___264 *);
};

struct kernfs_open_file___264 {
	struct kernfs_node___264 *kn;
	struct file___276 *file;
	struct seq_file___251 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___271 *vm_ops;
};

struct sock___72;

struct kobj_ns_type_operations___72 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___72 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___90 *net;
} possible_net_t___85;

struct proto___72;

struct sock_common___72 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___72 *skc_prot;
	possible_net_t___85 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___72 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___86;

struct sk_buff_head___85 {
	struct sk_buff___86 *next;
	struct sk_buff___86 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___72 {
	struct cgroup___203 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___72;

struct socket_wq___73;

struct xfrm_policy___15;

struct dst_entry___72;

struct socket___74;

struct net_device___85;

struct sock_reuseport___23;

struct sock___72 {
	struct sock_common___72 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___85 sk_error_queue;
	struct sk_buff___86 *sk_rx_skb_cache;
	struct sk_buff_head___85 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___86 *head;
		struct sk_buff___86 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___72 *sk_filter;
	union {
		struct socket_wq___73 *sk_wq;
		struct socket_wq___73 *sk_wq_raw;
	};
	struct xfrm_policy___15 *sk_policy[2];
	struct dst_entry___72 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___72 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___86 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___86 *sk_tx_skb_cache;
	struct sk_buff_head___85 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___281 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___72 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___253 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___74 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___72 sk_cgrp_data;
	struct mem_cgroup___141 *sk_memcg;
	void (*sk_state_change)(struct sock___72 *);
	void (*sk_data_ready)(struct sock___72 *);
	void (*sk_write_space)(struct sock___72 *);
	void (*sk_error_report)(struct sock___72 *);
	int (*sk_backlog_rcv)(struct sock___72 *, struct sk_buff___86 *);
	struct sk_buff___86 * (*sk_validate_xmit_skb)(struct sock___72 *, struct net_device___85 *, struct sk_buff___86 *);
	void (*sk_destruct)(struct sock___72 *);
	struct sock_reuseport___23 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___264;

struct attribute_group___264 {
	const char *name;
	umode_t (*is_visible)(struct kobject___264 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___264 *, struct bin_attribute___264 *, int);
	struct attribute **attrs;
	struct bin_attribute___264 **bin_attrs;
};

struct bin_attribute___264 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___276 * (*f_mapping)();
	ssize_t (*read)(struct file___276 *, struct kobject___264 *, struct bin_attribute___264 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___276 *, struct kobject___264 *, struct bin_attribute___264 *, char *, loff_t, size_t);
	int (*mmap)(struct file___276 *, struct kobject___264 *, struct bin_attribute___264 *, struct vm_area_struct___281 *);
};

struct sysfs_ops___264 {
	ssize_t (*show)(struct kobject___264 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___264 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___264;

struct kset___264 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___264 kobj;
	const struct kset_uevent_ops___264 *uevent_ops;
};

struct kobj_type___264 {
	void (*release)(struct kobject___264 *);
	const struct sysfs_ops___264 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___264 **default_groups;
	const struct kobj_ns_type_operations___72 * (*child_ns_type)(struct kobject___264 *);
	const void * (*namespace)(struct kobject___264 *);
	void (*get_ownership)(struct kobject___264 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___264 {
	int (* const filter)(struct kset___264 *, struct kobject___264 *);
	const char * (* const name)(struct kset___264 *, struct kobject___264 *);
	int (* const uevent)(struct kset___264 *, struct kobject___264 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___260 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___260 *);
	int (*get)(char *, const struct kernel_param___260 *);
	void (*free)(void *);
};

struct kparam_array___260;

struct kernel_param___260 {
	const char *name;
	struct module___260 *mod;
	const struct kernel_param_ops___260 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___260 *arr;
	};
};

struct kparam_array___260 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___260 *ops;
	void *elem;
};

struct module_attribute___260 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___260 *, struct module_kobject___261 *, char *);
	ssize_t (*store)(struct module_attribute___260 *, struct module_kobject___261 *, const char *, size_t);
	void (*setup)(struct module___260 *, const char *);
	int (*test)(struct module___260 *);
	void (*free)(struct module___260 *);
};

struct msghdr___74 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___196 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___276 *msg_iocb;
};

struct sk_buff___86 {
	union {
		struct {
			struct sk_buff___86 *next;
			struct sk_buff___86 *prev;
			union {
				struct net_device___85 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___72 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___86 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___90;

struct fqdir___90 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___90 *f;
	struct net___90 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___90;

struct inet_frags___90 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___90 *, const void *);
	void (*destructor)(struct inet_frag_queue___90 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___45;

struct fib_rules_ops___72;

struct tcp_congestion_ops___21;

struct fib_notifier_ops___72;

struct netns_ipv4___90 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___45 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___72 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___72 *fibnl;
	struct sock___72 **icmp_sk;
	struct sock___72 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___72 **tcp_sk;
	struct fqdir___90 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___21 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___72 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___72 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___72 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___72;

struct dst_ops___90 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___90 *);
	struct dst_entry___72 * (*check)(struct dst_entry___72 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___72 *);
	unsigned int (*mtu)(const struct dst_entry___72 *);
	u32 * (*cow_metrics)(struct dst_entry___72 *, long unsigned int);
	void (*destroy)(struct dst_entry___72 *);
	void (*ifdown)(struct dst_entry___72 *, struct net_device___85 *, int);
	struct dst_entry___72 * (*negative_advice)(struct dst_entry___72 *);
	void (*link_failure)(struct sk_buff___86 *);
	void (*update_pmtu)(struct dst_entry___72 *, struct sock___72 *, struct sk_buff___86 *, u32, bool);
	void (*redirect)(struct dst_entry___72 *, struct sock___72 *, struct sk_buff___86 *);
	int (*local_out)(struct net___90 *, struct sock___72 *, struct sk_buff___86 *);
	struct neighbour___72 * (*neigh_lookup)(const struct dst_entry___72 *, struct sk_buff___86 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___72 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___21;

struct rt6_info___21;

struct fib6_table___21;

struct netns_ipv6___90 {
	struct dst_ops___90 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___90 *fqdir;
	struct fib6_info___21 *fib6_null_entry;
	struct rt6_info___21 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___21 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___21 *ip6_prohibit_entry;
	struct rt6_info___21 *ip6_blk_hole_entry;
	struct fib6_table___21 *fib6_local_tbl;
	struct fib_rules_ops___72 *fib6_rules_ops;
	struct sock___72 **icmp_sk;
	struct sock___72 *ndisc_sk;
	struct sock___72 *tcp_sk;
	struct sock___72 *igmp_sk;
	struct sock___72 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___72 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___72 *notifier_ops;
	struct fib_notifier_ops___72 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___90 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___90 *fqdir;
};

struct netns_sctp___72 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___72 *ctl_sock;
	struct sock___72 *udp4_sock;
	struct sock___72 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___13;

struct netns_nf___13 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___13 *hooks_ipv4[5];
	struct nf_hook_entries___13 *hooks_ipv6[5];
	struct nf_hook_entries___13 *hooks_arp[3];
	struct nf_hook_entries___13 *hooks_bridge[5];
	struct nf_hook_entries___13 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___79;

struct netns_bpf___79 {
	struct bpf_prog_array___79 *run_array[2];
	struct bpf_prog___79 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___90 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___72 *nlsk;
	struct sock___72 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___90 xfrm4_dst_ops;
	struct dst_ops___90 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___90 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___72 *rtnl;
	struct sock___72 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___85 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___90 ipv4;
	struct netns_ipv6___90 ipv6;
	struct netns_ieee802154_lowpan___90 ieee802154_lowpan;
	struct netns_sctp___72 sctp;
	struct netns_nf___13 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___85 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___79 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___90 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___72 *crypto_nlsk;
	struct sock___72 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___90 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___86 *fragments_tail;
	struct sk_buff___86 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___90 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___45 {
	struct ip_ra_chain___45 *next;
	struct sock___72 *sk;
	union {
		void (*destructor)(struct sock___72 *);
		struct sock___72 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___72;

struct fib_lookup_arg___72;

struct fib_rules_ops___72 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___72 *, struct flowi *, int, struct fib_lookup_arg___72 *);
	bool (*suppress)(struct fib_rule___72 *, int, struct fib_lookup_arg___72 *);
	int (*match)(struct fib_rule___72 *, struct flowi *, int);
	int (*configure)(struct fib_rule___72 *, struct sk_buff___86 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___72 *);
	int (*compare)(struct fib_rule___72 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___72 *, struct sk_buff___86 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___72 *);
	void (*flush_cache)(struct fib_rules_ops___72 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___260 *owner;
	struct net___90 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___21 {
	u32 (*ssthresh)(struct sock___72 *);
	void (*cong_avoid)(struct sock___72 *, u32, u32);
	void (*set_state)(struct sock___72 *, u8);
	void (*cwnd_event)(struct sock___72 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___72 *, u32);
	void (*pkts_acked)(struct sock___72 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___72 *);
	void (*cong_control)(struct sock___72 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___72 *);
	u32 (*sndbuf_expand)(struct sock___72 *);
	size_t (*get_info)(struct sock___72 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___260 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___72 *);
	void (*release)(struct sock___72 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___72 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___90 *);
	int (*fib_dump)(struct net___90 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___260 *owner;
	struct callback_head rcu;
};

struct xfrm_state___15;

struct lwtunnel_state___48;

struct dst_entry___72 {
	struct net_device___85 *dev;
	struct dst_ops___90 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___15 *xfrm;
	int (*input)(struct sk_buff___86 *);
	int (*output)(struct net___90 *, struct sock___72 *, struct sk_buff___86 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___48 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___85(struct sk_buff___86 **);

struct bpf_xdp_entity___79 {
	struct bpf_prog___79 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___85;

struct net_device_ops___85;

struct l3mdev_ops___72;

struct ndisc_ops___54;

struct xfrmdev_ops___85;

struct header_ops___85;

struct in_device___13;

struct inet6_dev___54;

struct netdev_rx_queue___85;

struct mini_Qdisc___79;

struct netdev_queue___85;

struct Qdisc___79;

struct rtnl_link_ops___79;

struct dcbnl_rtnl_ops___85;

struct net_device___85 {
	char name[16];
	struct netdev_name_node___85 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___85 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___72 *l3mdev_ops;
	const struct ndisc_ops___54 *ndisc_ops;
	const struct xfrmdev_ops___85 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___85 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___264 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___13 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___54 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___85 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___79 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___85 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___79 *miniq_ingress;
	struct netdev_queue___85 *ingress_queue;
	struct nf_hook_entries___13 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___85 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___79 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___79 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___85 = 0,
		NETREG_REGISTERED___85 = 1,
		NETREG_UNREGISTERING___85 = 2,
		NETREG_UNREGISTERED___85 = 3,
		NETREG_RELEASED___85 = 4,
		NETREG_DUMMY___85 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___85 = 0,
		RTNL_LINK_INITIALIZING___85 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___85 *);
	struct netpoll_info *npinfo;
	possible_net_t___85 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___257 dev;
	const struct attribute_group___264 *sysfs_groups[4];
	const struct attribute_group___264 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___79 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___85 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___79 xdp_state[3];
	long: 64;
};

struct neigh_table___72;

struct neigh_parms___72;

struct neigh_ops___72;

struct neighbour___72 {
	struct neighbour___72 *next;
	struct neigh_table___72 *tbl;
	struct neigh_parms___72 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___85 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___72 *, struct sk_buff___86 *);
	const struct neigh_ops___72 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___85 *dev;
	u8 primary_key[0];
};

struct rtable___22;

struct fnhe_hash_bucket___21;

struct fib_nh_common___21 {
	struct net_device___85 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___48 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___22 **nhc_pcpu_rth_output;
	struct rtable___22 *nhc_rth_input;
	struct fnhe_hash_bucket___21 *nhc_exceptions;
};

struct fib6_nh___21 {
	struct fib_nh_common___21 nh_common;
	long unsigned int last_probe;
	struct rt6_info___21 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___21;

struct nexthop___12;

struct fib6_info___21 {
	struct fib6_table___21 *fib6_table;
	struct fib6_info___21 *fib6_next;
	struct fib6_node___21 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___12 *nh;
	struct fib6_nh___21 fib6_nh[0];
};

struct rt6_info___21 {
	struct dst_entry___72 dst;
	struct fib6_info___21 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___54 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___21 {
	struct fib6_node___21 *parent;
	struct fib6_node___21 *left;
	struct fib6_node___21 *right;
	struct fib6_node___21 *subtree;
	struct fib6_info___21 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___21 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___21 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___21 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___13;

typedef unsigned int nf_hookfn___15(void *, struct sk_buff___86 *, const struct nf_hook_state___13 *);

struct nf_hook_entry___13 {
	nf_hookfn___15 *hook;
	void *priv;
};

struct nf_hook_entries___13 {
	u16 num_hook_entries;
	struct nf_hook_entry___13 hooks[0];
};

enum ip_conntrack_status {
	IPS_EXPECTED_BIT = 0,
	IPS_EXPECTED = 1,
	IPS_SEEN_REPLY_BIT = 1,
	IPS_SEEN_REPLY = 2,
	IPS_ASSURED_BIT = 2,
	IPS_ASSURED = 4,
	IPS_CONFIRMED_BIT = 3,
	IPS_CONFIRMED = 8,
	IPS_SRC_NAT_BIT = 4,
	IPS_SRC_NAT = 16,
	IPS_DST_NAT_BIT = 5,
	IPS_DST_NAT = 32,
	IPS_NAT_MASK = 48,
	IPS_SEQ_ADJUST_BIT = 6,
	IPS_SEQ_ADJUST = 64,
	IPS_SRC_NAT_DONE_BIT = 7,
	IPS_SRC_NAT_DONE = 128,
	IPS_DST_NAT_DONE_BIT = 8,
	IPS_DST_NAT_DONE = 256,
	IPS_NAT_DONE_MASK = 384,
	IPS_DYING_BIT = 9,
	IPS_DYING = 512,
	IPS_FIXED_TIMEOUT_BIT = 10,
	IPS_FIXED_TIMEOUT = 1024,
	IPS_TEMPLATE_BIT = 11,
	IPS_TEMPLATE = 2048,
	IPS_UNTRACKED_BIT = 12,
	IPS_UNTRACKED = 4096,
	IPS_NAT_CLASH_BIT = 12,
	IPS_NAT_CLASH = 4096,
	IPS_HELPER_BIT = 13,
	IPS_HELPER = 8192,
	IPS_OFFLOAD_BIT = 14,
	IPS_OFFLOAD = 16384,
	IPS_HW_OFFLOAD_BIT = 15,
	IPS_HW_OFFLOAD = 32768,
	IPS_UNCHANGEABLE_MASK = 56313,
	__IPS_MAX_BIT = 16,
};

struct bpf_prog_array_item___79 {
	struct bpf_prog___79 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___79 {
	struct callback_head rcu;
	struct bpf_prog_array_item___79 items[0];
};

struct bpf_prog_aux___88;

struct bpf_prog___79 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___88 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___271 {
	void (*page_free)(struct page___281 *);
	void (*kill)(struct dev_pagemap___271 *);
	void (*cleanup)(struct dev_pagemap___271 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___271 *);
};

struct fwnode_operations___253;

struct fwnode_handle___253 {
	struct fwnode_handle___253 *secondary;
	const struct fwnode_operations___253 *ops;
	struct device___257 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___253;

struct fwnode_endpoint___253;

struct fwnode_operations___253 {
	struct fwnode_handle___253 * (*get)(struct fwnode_handle___253 *);
	void (*put)(struct fwnode_handle___253 *);
	bool (*device_is_available)(const struct fwnode_handle___253 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___253 *, const struct device___257 *);
	bool (*property_present)(const struct fwnode_handle___253 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___253 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___253 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___253 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*get_parent)(const struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*get_next_child_node)(const struct fwnode_handle___253 *, struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*get_named_child_node)(const struct fwnode_handle___253 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___253 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___253 *);
	struct fwnode_handle___253 * (*graph_get_next_endpoint)(const struct fwnode_handle___253 *, struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*graph_get_remote_endpoint)(const struct fwnode_handle___253 *);
	struct fwnode_handle___253 * (*graph_get_port_parent)(struct fwnode_handle___253 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___253 *, struct fwnode_endpoint___253 *);
	int (*add_links)(struct fwnode_handle___253 *);
};

struct fwnode_endpoint___253 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___253 *local_fwnode;
};

struct fwnode_reference_args___253 {
	struct fwnode_handle___253 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___203 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___203 *root_cset;
};

struct socket_wq___73 {
	wait_queue_head_t wait;
	struct fasync_struct___276 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___73;

struct socket___74 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___276 *file;
	struct sock___72 *sk;
	const struct proto_ops___73 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___73 wq;
};

typedef int (*sk_read_actor_t___72)(read_descriptor_t *, struct sk_buff___86 *, unsigned int, size_t);

struct proto_ops___73 {
	int family;
	struct module___260 *owner;
	int (*release)(struct socket___74 *);
	int (*bind)(struct socket___74 *, struct sockaddr *, int);
	int (*connect)(struct socket___74 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___74 *, struct socket___74 *);
	int (*accept)(struct socket___74 *, struct socket___74 *, int, bool);
	int (*getname)(struct socket___74 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___276 *, struct socket___74 *, struct poll_table_struct___197 *);
	int (*ioctl)(struct socket___74 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___74 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___74 *, void *, bool, bool);
	int (*listen)(struct socket___74 *, int);
	int (*shutdown)(struct socket___74 *, int);
	int (*setsockopt)(struct socket___74 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___74 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___251 *, struct socket___74 *);
	int (*sendmsg)(struct socket___74 *, struct msghdr___74 *, size_t);
	int (*recvmsg)(struct socket___74 *, struct msghdr___74 *, size_t, int);
	int (*mmap)(struct file___276 *, struct socket___74 *, struct vm_area_struct___281 *);
	ssize_t (*sendpage)(struct socket___74 *, struct page___281 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___74 *, loff_t *, struct pipe_inode_info___117 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___72 *, int);
	int (*peek_len)(struct socket___74 *);
	int (*read_sock)(struct sock___72 *, read_descriptor_t *, sk_read_actor_t___72);
	int (*sendpage_locked)(struct sock___72 *, struct page___281 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___72 *, struct msghdr___74 *, size_t);
	int (*set_rcvlowat)(struct sock___72 *, int);
};

struct dev_pm_ops___257 {
	int (*prepare)(struct device___257 *);
	void (*complete)(struct device___257 *);
	int (*suspend)(struct device___257 *);
	int (*resume)(struct device___257 *);
	int (*freeze)(struct device___257 *);
	int (*thaw)(struct device___257 *);
	int (*poweroff)(struct device___257 *);
	int (*restore)(struct device___257 *);
	int (*suspend_late)(struct device___257 *);
	int (*resume_early)(struct device___257 *);
	int (*freeze_late)(struct device___257 *);
	int (*thaw_early)(struct device___257 *);
	int (*poweroff_late)(struct device___257 *);
	int (*restore_early)(struct device___257 *);
	int (*suspend_noirq)(struct device___257 *);
	int (*resume_noirq)(struct device___257 *);
	int (*freeze_noirq)(struct device___257 *);
	int (*thaw_noirq)(struct device___257 *);
	int (*poweroff_noirq)(struct device___257 *);
	int (*restore_noirq)(struct device___257 *);
	int (*runtime_suspend)(struct device___257 *);
	int (*runtime_resume)(struct device___257 *);
	int (*runtime_idle)(struct device___257 *);
};

struct wakeup_source___257 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___257 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___257 {
	struct dev_pm_ops___257 ops;
	int (*start)(struct device___257 *);
	void (*detach)(struct device___257 *, bool);
	int (*activate)(struct device___257 *);
	void (*sync)(struct device___257 *);
	void (*dismiss)(struct device___257 *);
};

struct bus_type___257 {
	const char *name;
	const char *dev_name;
	struct device___257 *dev_root;
	const struct attribute_group___264 **bus_groups;
	const struct attribute_group___264 **dev_groups;
	const struct attribute_group___264 **drv_groups;
	int (*match)(struct device___257 *, struct device_driver___257 *);
	int (*uevent)(struct device___257 *, struct kobj_uevent_env *);
	int (*probe)(struct device___257 *);
	void (*sync_state)(struct device___257 *);
	void (*remove)(struct device___257 *);
	void (*shutdown)(struct device___257 *);
	int (*online)(struct device___257 *);
	int (*offline)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	int (*num_vf)(struct device___257 *);
	int (*dma_configure)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___257 {
	const char *name;
	struct bus_type___257 *bus;
	struct module___260 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___257 *);
	void (*sync_state)(struct device___257 *);
	int (*remove)(struct device___257 *);
	void (*shutdown)(struct device___257 *);
	int (*suspend)(struct device___257 *, pm_message_t);
	int (*resume)(struct device___257 *);
	const struct attribute_group___264 **groups;
	const struct attribute_group___264 **dev_groups;
	const struct dev_pm_ops___257 *pm;
	void (*coredump)(struct device___257 *);
	struct driver_private *p;
};

struct device_type___257 {
	const char *name;
	const struct attribute_group___264 **groups;
	int (*uevent)(struct device___257 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___257 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___257 *);
	const struct dev_pm_ops___257 *pm;
};

struct class___257 {
	const char *name;
	struct module___260 *owner;
	const struct attribute_group___264 **class_groups;
	const struct attribute_group___264 **dev_groups;
	struct kobject___264 *dev_kobj;
	int (*dev_uevent)(struct device___257 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___257 *, umode_t *);
	void (*class_release)(struct class___257 *);
	void (*dev_release)(struct device___257 *);
	int (*shutdown_pre)(struct device___257 *);
	const struct kobj_ns_type_operations___72 *ns_type;
	const void * (*namespace)(struct device___257 *);
	void (*get_ownership)(struct device___257 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___257 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___117;

struct pipe_buffer___117 {
	struct page___281 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___117 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___117 {
	int (*confirm)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
	void (*release)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
	bool (*try_steal)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
	bool (*get)(struct pipe_inode_info___117 *, struct pipe_buffer___117 *);
};

struct seq_operations___251 {
	void * (*start)(struct seq_file___251 *, loff_t *);
	void (*stop)(struct seq_file___251 *, void *);
	void * (*next)(struct seq_file___251 *, void *, loff_t *);
	int (*show)(struct seq_file___251 *, void *);
};

struct pernet_operations___26 {
	struct list_head list;
	int (*init)(struct net___90 *);
	void (*pre_exit)(struct net___90 *);
	void (*exit)(struct net___90 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___85 {
	int (*ieee_getets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___85 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___85 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___85 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___85 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___85 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___85 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___85 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___85 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___85 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___85 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___85 *);
	u8 (*setstate)(struct net_device___85 *, u8);
	void (*getpermhwaddr)(struct net_device___85 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___85 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___85 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___85 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___85 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___85 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___85 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___85 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___85 *, int, u8 *);
	void (*setpfccfg)(struct net_device___85 *, int, u8);
	void (*getpfccfg)(struct net_device___85 *, int, u8 *);
	u8 (*setall)(struct net_device___85 *);
	u8 (*getcap)(struct net_device___85 *, int, u8 *);
	int (*getnumtcs)(struct net_device___85 *, int, u8 *);
	int (*setnumtcs)(struct net_device___85 *, int, u8);
	u8 (*getpfcstate)(struct net_device___85 *);
	void (*setpfcstate)(struct net_device___85 *, u8);
	void (*getbcncfg)(struct net_device___85 *, int, u32 *);
	void (*setbcncfg)(struct net_device___85 *, int, u32);
	void (*getbcnrp)(struct net_device___85 *, int, u8 *);
	void (*setbcnrp)(struct net_device___85 *, int, u8);
	int (*setapp)(struct net_device___85 *, u8, u16, u8);
	int (*getapp)(struct net_device___85 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___85 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___85 *, int, u8);
	u8 (*getdcbx)(struct net_device___85 *);
	u8 (*setdcbx)(struct net_device___85 *, u8);
	int (*peer_getappinfo)(struct net_device___85 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___85 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___85 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___85 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___85 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___85 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___88;

typedef int (*bpf_iter_init_seq_priv_t___87)(void *, struct bpf_iter_aux_info___88 *);

struct bpf_map___88;

struct bpf_iter_aux_info___88 {
	struct bpf_map___88 *map;
};

struct bpf_iter_seq_info___87 {
	const struct seq_operations___251 *seq_ops;
	bpf_iter_init_seq_priv_t___87 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___87 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___88 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___88 *, struct file___276 *);
	void (*map_free)(struct bpf_map___88 *);
	int (*map_get_next_key)(struct bpf_map___88 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___88 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___88 *, void *);
	int (*map_lookup_batch)(struct bpf_map___88 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___88 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___88 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___88 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___88 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___88 *, void *);
	int (*map_update_elem)(struct bpf_map___88 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___88 *, void *);
	int (*map_push_elem)(struct bpf_map___88 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___88 *, void *);
	int (*map_peek_elem)(struct bpf_map___88 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___88 *, struct file___276 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___88 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___88 *, void *, struct seq_file___251 *);
	int (*map_check_btf)(const struct bpf_map___88 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___88 *, struct bpf_prog_aux___88 *);
	void (*map_poke_untrack)(struct bpf_map___88 *, struct bpf_prog_aux___88 *);
	void (*map_poke_run)(struct bpf_map___88 *, u32, struct bpf_prog___79 *, struct bpf_prog___79 *);
	int (*map_direct_value_addr)(const struct bpf_map___88 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___88 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___88 *, struct vm_area_struct___281 *);
	__poll_t (*map_poll)(struct bpf_map___88 *, struct file___276 *, struct poll_table_struct___197 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___88 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___88 *, const struct bpf_map___88 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___88 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___87 *iter_seq_info;
};

struct bpf_map___88 {
	const struct bpf_map_ops___87 *ops;
	struct bpf_map___88 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___141 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___87;

struct bpf_jit_poke_descriptor___87;

struct bpf_prog_ops___79;

struct btf_mod_pair___87;

struct bpf_prog_offload___85;

struct bpf_prog_aux___88 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___79 *dst_prog;
	struct bpf_trampoline___87 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___79 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___87 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___79 *ops;
	struct bpf_map___88 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___87 *used_btfs;
	struct bpf_prog___79 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___88 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___85 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___85;

struct bpf_map_dev_ops___85 {
	int (*map_get_next_key)(struct bpf_offloaded_map___85 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___85 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___85 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___85 *, void *);
};

struct bpf_offloaded_map___85 {
	struct bpf_map___88 map;
	struct net_device___85 *netdev;
	const struct bpf_map_dev_ops___85 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___79 {
	int (*test_run)(struct bpf_prog___79 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___85 {
	struct bpf_prog___79 *prog;
	struct net_device___85 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___87 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___79 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___260 *mod;
};

struct bpf_jit_poke_descriptor___87 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___88 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___87 {
	struct btf *btf;
	struct module___260 *module;
};

struct cftype___203;

struct cgroup_subsys___203 {
	struct cgroup_subsys_state___203 * (*css_alloc)(struct cgroup_subsys_state___203 *);
	int (*css_online)(struct cgroup_subsys_state___203 *);
	void (*css_offline)(struct cgroup_subsys_state___203 *);
	void (*css_released)(struct cgroup_subsys_state___203 *);
	void (*css_free)(struct cgroup_subsys_state___203 *);
	void (*css_reset)(struct cgroup_subsys_state___203 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___203 *, int);
	int (*css_extra_stat_show)(struct seq_file___251 *, struct cgroup_subsys_state___203 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___283 *, struct css_set___203 *);
	void (*cancel_fork)(struct task_struct___283 *, struct css_set___203 *);
	void (*fork)(struct task_struct___283 *);
	void (*exit)(struct task_struct___283 *);
	void (*release)(struct task_struct___283 *);
	void (*bind)(struct cgroup_subsys_state___203 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___203 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___203 *dfl_cftypes;
	struct cftype___203 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___203 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___203 *updated_children;
	struct cgroup___203 *updated_next;
};

struct cgroup_root___203 {
	struct kernfs_root___264 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___203 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___203 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___203 *ss;
	struct list_head node;
	struct kernfs_ops___264 *kf_ops;
	int (*open)(struct kernfs_open_file___264 *);
	void (*release)(struct kernfs_open_file___264 *);
	u64 (*read_u64)(struct cgroup_subsys_state___203 *, struct cftype___203 *);
	s64 (*read_s64)(struct cgroup_subsys_state___203 *, struct cftype___203 *);
	int (*seq_show)(struct seq_file___251 *, void *);
	void * (*seq_start)(struct seq_file___251 *, loff_t *);
	void * (*seq_next)(struct seq_file___251 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___251 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___203 *, struct cftype___203 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___203 *, struct cftype___203 *, s64);
	ssize_t (*write)(struct kernfs_open_file___264 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___264 *, struct poll_table_struct___197 *);
};

struct xdp_rxq_info___85 {
	struct net_device___85 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___85 {
	struct net_device___85 *dev;
};

struct xdp_buff___85 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___85 *rxq;
	struct xdp_txq_info___85 *txq;
	u32 frame_sz;
};

struct xdp_frame___85 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___85 *dev_rx;
};

struct netlink_callback___85 {
	struct sk_buff___86 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___86 *, struct netlink_callback___85 *);
	int (*done)(struct netlink_callback___85 *);
	void *data;
	struct module___260 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___85 {
	int (*create)(struct sk_buff___86 *, struct net_device___85 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___86 *, unsigned char *);
	int (*cache)(const struct neighbour___72 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___85 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___86 *);
};

struct netdev_queue___85 {
	struct net_device___85 *dev;
	struct Qdisc___79 *qdisc;
	struct Qdisc___79 *qdisc_sleeping;
	struct kobject___264 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___85 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___79 {
	struct sk_buff___86 *head;
	struct sk_buff___86 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___79;

struct Qdisc___79 {
	int (*enqueue)(struct sk_buff___86 *, struct Qdisc___79 *, struct sk_buff___86 **);
	struct sk_buff___86 * (*dequeue)(struct Qdisc___79 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___79 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___85 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___85 gso_skb;
	struct qdisc_skb_head___79 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___79 *next_sched;
	struct sk_buff_head___85 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___85 {
	struct xdp_rxq_info___85 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___264 kobj;
	struct net_device___85 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___85 {
	enum net_device_path_type type;
	const struct net_device___85 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___85 = 0,
				DEV_PATH_BR_VLAN_TAG___85 = 1,
				DEV_PATH_BR_VLAN_UNTAG___85 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___85 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___85 {
	const struct net_device___85 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___85 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___79 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___85 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___85 {
	int (*xdo_dev_state_add)(struct xfrm_state___15 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___15 *);
	void (*xdo_dev_state_free)(struct xfrm_state___15 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___86 *, struct xfrm_state___15 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___15 *);
};

struct xfrm_state_offload___15 {
	struct net_device___85 *dev;
	struct net_device___85 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___15;

struct xfrm_type_offload___15;

struct xfrm_state___15 {
	possible_net_t___85 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___72 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___15 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___15 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___281 xfrag;
	const struct xfrm_type___15 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___15 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___85 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___85 *dev;
	const char *name;
};

struct net_device_ops___85 {
	int (*ndo_init)(struct net_device___85 *);
	void (*ndo_uninit)(struct net_device___85 *);
	int (*ndo_open)(struct net_device___85 *);
	int (*ndo_stop)(struct net_device___85 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___86 *, struct net_device___85 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___86 *, struct net_device___85 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___85 *, struct sk_buff___86 *, struct net_device___85 *);
	void (*ndo_change_rx_flags)(struct net_device___85 *, int);
	void (*ndo_set_rx_mode)(struct net_device___85 *);
	int (*ndo_set_mac_address)(struct net_device___85 *, void *);
	int (*ndo_validate_addr)(struct net_device___85 *);
	int (*ndo_do_ioctl)(struct net_device___85 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___85 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___85 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___85 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___85 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___85 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___85 *, int);
	int (*ndo_neigh_setup)(struct net_device___85 *, struct neigh_parms___72 *);
	void (*ndo_tx_timeout)(struct net_device___85 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___85 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___85 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___85 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___85 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___85 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___85 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___85 *);
	int (*ndo_netpoll_setup)(struct net_device___85 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___85 *);
	int (*ndo_set_vf_mac)(struct net_device___85 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___85 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___85 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___85 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___85 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___85 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___85 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___85 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___85 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___85 *, int, struct sk_buff___86 *);
	int (*ndo_get_vf_guid)(struct net_device___85 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___85 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___85 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___85 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___85 *);
	int (*ndo_fcoe_disable)(struct net_device___85 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___85 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___85 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___85 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___85 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___85 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___85 *, const struct sk_buff___86 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___85 *, struct net_device___85 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___85 *, struct net_device___85 *);
	struct net_device___85 * (*ndo_get_xmit_slave)(struct net_device___85 *, struct sk_buff___86 *, bool);
	struct net_device___85 * (*ndo_sk_get_lower_dev)(struct net_device___85 *, struct sock___72 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___85 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___85 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___85 *, struct neighbour___72 *);
	void (*ndo_neigh_destroy)(struct net_device___85 *, struct neighbour___72 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___86 *, struct netlink_callback___85 *, struct net_device___85 *, struct net_device___85 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___86 *, struct nlattr **, struct net_device___85 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___85 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___86 *, u32, u32, struct net_device___85 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___85 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___85 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___85 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___85 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___85 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___85 *, struct net_device___85 *);
	void (*ndo_dfwd_del_station)(struct net_device___85 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___85 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___85 *);
	int (*ndo_change_proto_down)(struct net_device___85 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___85 *, struct sk_buff___86 *);
	void (*ndo_set_rx_headroom)(struct net_device___85 *, int);
	int (*ndo_bpf)(struct net_device___85 *, struct netdev_bpf___85 *);
	int (*ndo_xdp_xmit)(struct net_device___85 *, int, struct xdp_frame___85 **, u32);
	struct net_device___85 * (*ndo_xdp_get_xmit_slave)(struct net_device___85 *, struct xdp_buff___85 *);
	int (*ndo_xsk_wakeup)(struct net_device___85 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___85 *);
	int (*ndo_tunnel_ctl)(struct net_device___85 *, struct ip_tunnel_parm *, int);
	struct net_device___85 * (*ndo_get_peer_dev)(struct net_device___85 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___85 *, struct net_device_path___85 *);
};

struct neigh_parms___72 {
	possible_net_t___85 net;
	struct net_device___85 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___72 *);
	struct neigh_table___72 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___72 {
	u32 (*l3mdev_fib_table)(const struct net_device___85 *);
	struct sk_buff___86 * (*l3mdev_l3_rcv)(struct net_device___85 *, struct sk_buff___86 *, u16);
	struct sk_buff___86 * (*l3mdev_l3_out)(struct net_device___85 *, struct sock___72 *, struct sk_buff___86 *, u16);
	struct dst_entry___72 * (*l3mdev_link_scope_lookup)(const struct net_device___85 *, struct flowi6 *);
};

struct ndisc_ops___54 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___85 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___85 *, struct neighbour___72 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___85 *, u8, struct neighbour___72 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___85 *, struct sk_buff___86 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___90 *, struct net_device___85 *, const struct prefix_info *, struct inet6_dev___54 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___13;

struct in_device___13 {
	struct net_device___85 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___13 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___72 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___54;

struct ifacaddr6___21;

struct inet6_dev___54 {
	struct net_device___85 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___54 *mc_list;
	struct ifmcaddr6___54 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___85 mc_query_queue;
	struct sk_buff_head___85 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___21 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___72 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___79;

struct tcf_block___79;

struct mini_Qdisc___79 {
	struct tcf_proto___79 *filter_list;
	struct tcf_block___79 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___79 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___85 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___85 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___90 *, struct net_device___85 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___85 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___85 *, struct list_head *);
	size_t (*get_size)(const struct net_device___85 *);
	int (*fill_info)(struct sk_buff___86 *, const struct net_device___85 *);
	size_t (*get_xstats_size)(const struct net_device___85 *);
	int (*fill_xstats)(struct sk_buff___86 *, const struct net_device___85 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___85 *, struct net_device___85 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___85 *, const struct net_device___85 *);
	int (*fill_slave_info)(struct sk_buff___86 *, const struct net_device___85 *, const struct net_device___85 *);
	struct net___90 * (*get_link_net)(const struct net_device___85 *);
	size_t (*get_linkxstats_size)(const struct net_device___85 *, int);
	int (*fill_linkxstats)(struct sk_buff___86 *, const struct net_device___85 *, int *, int);
};

struct in_ifaddr___13 {
	struct hlist_node hash;
	struct in_ifaddr___13 *ifa_next;
	struct in_device___13 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct nf_hook_state___13 {
	u8 hook;
	u8 pf;
	struct net_device___85 *in;
	struct net_device___85 *out;
	struct sock___72 *sk;
	struct net___90 *net;
	int (*okfn)(struct net___90 *, struct sock___72 *, struct sk_buff___86 *);
};

struct nf_ct_ext___2;

struct nf_conn___4 {
	struct nf_conntrack ct_general;
	spinlock_t lock;
	u32 timeout;
	struct nf_conntrack_zone zone;
	struct nf_conntrack_tuple_hash tuplehash[2];
	long unsigned int status;
	u16 cpu;
	possible_net_t___85 ct_net;
	struct hlist_node nat_bysource;
	struct {	} __nfct_init_offset;
	struct nf_conn___4 *master;
	u_int32_t mark;
	u_int32_t secmark;
	struct nf_ct_ext___2 *ext;
	union nf_conntrack_proto proto;
};

struct block_device_operations___167;

struct gendisk___170 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___170 *part0;
	const struct block_device_operations___167 *fops;
	struct request_queue___167 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___153 *bdi;
	struct kobject___264 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___264 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___167 {
	struct bio___167 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___193 *bip_vec;
	struct bio_vec___193 bip_inline_vecs[0];
};

struct blkcg___155;

struct blkg_policy_data___155;

struct blkcg_gq___155 {
	struct request_queue___167 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___155 *blkcg;
	struct blkcg_gq___155 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___155 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___167 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___167(struct request___167 *);

typedef void integrity_complete_fn___167(struct request___167 *, unsigned int);

struct blk_integrity_profile___167 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___167 *prepare_fn;
	integrity_complete_fn___167 *complete_fn;
	const char *name;
};

struct block_device_operations___167 {
	blk_qc_t (*submit_bio)(struct bio___167 *);
	int (*open)(struct block_device___170 *, fmode_t);
	void (*release)(struct gendisk___170 *, fmode_t);
	int (*rw_page)(struct block_device___170 *, sector_t, struct page___281 *, unsigned int);
	int (*ioctl)(struct block_device___170 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___170 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___170 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___170 *);
	int (*getgeo)(struct block_device___170 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___170 *, bool);
	void (*swap_slot_free_notify)(struct block_device___170 *, long unsigned int);
	int (*report_zones)(struct gendisk___170 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___170 *, umode_t *);
	struct module___260 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___170 *, sector_t *);
};

typedef void rq_end_io_fn___167(struct request___167 *, blk_status_t);

struct request___167 {
	struct request_queue___167 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___162 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___167 *bio;
	struct bio___167 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___193 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___167 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___167 *saved_end_io;
		} flush;
	};
	struct gendisk___170 *rq_disk;
	struct block_device___170 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___167 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___162 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___167 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___264 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___276 *debugfs_dir;
	struct dentry___276 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___167;

struct elevator_mq_ops___167 {
	int (*init_sched)(struct request_queue___167 *, struct elevator_type___167 *);
	void (*exit_sched)(struct elevator_queue___167 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___162 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___162 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___162 *);
	bool (*allow_merge)(struct request_queue___167 *, struct request___167 *, struct bio___167 *);
	bool (*bio_merge)(struct request_queue___167 *, struct bio___167 *, unsigned int);
	int (*request_merge)(struct request_queue___167 *, struct request___167 **, struct bio___167 *);
	void (*request_merged)(struct request_queue___167 *, struct request___167 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___167 *, struct request___167 *, struct request___167 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___167 *);
	void (*finish_request)(struct request___167 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___162 *, struct list_head *, bool);
	struct request___167 * (*dispatch_request)(struct blk_mq_hw_ctx___162 *);
	bool (*has_work)(struct blk_mq_hw_ctx___162 *);
	void (*completed_request)(struct request___167 *, u64);
	void (*requeue_request)(struct request___167 *);
	struct request___167 * (*former_request)(struct request_queue___167 *, struct request___167 *);
	struct request___167 * (*next_request)(struct request_queue___167 *, struct request___167 *);
	void (*init_icq)(struct io_cq___167 *);
	void (*exit_icq)(struct io_cq___167 *);
};

struct elv_fs_entry___167;

struct elevator_type___167 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___167 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___167 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___260 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___167 {
	struct elevator_type___167 *type;
	void *elevator_data;
	struct kobject___264 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___167 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___167 *, char *);
	ssize_t (*store)(struct elevator_queue___167 *, const char *, size_t);
};

struct blk_mq_queue_data___162;

struct blk_mq_ops___162 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___162 *, const struct blk_mq_queue_data___162 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___162 *);
	int (*get_budget)(struct request_queue___167 *);
	void (*put_budget)(struct request_queue___167 *, int);
	void (*set_rq_budget_token)(struct request___167 *, int);
	int (*get_rq_budget_token)(struct request___167 *);
	enum blk_eh_timer_return (*timeout)(struct request___167 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___162 *);
	void (*complete)(struct request___167 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___162 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___162 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___162 *, struct request___167 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___162 *, struct request___167 *, unsigned int);
	void (*initialize_rq_fn)(struct request___167 *);
	void (*cleanup_rq)(struct request___167 *);
	bool (*busy)(struct request_queue___167 *);
	int (*map_queues)(struct blk_mq_tag_set___162 *);
	void (*show_rq)(struct seq_file___251 *, struct request___167 *);
};

struct blk_mq_tag_set___162 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___162 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___162 {
	struct request___167 *rq;
	bool last;
};

struct blkcg_policy_data___155;

struct blkcg___155 {
	struct cgroup_subsys_state___203 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___155 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___155 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___155 {
	struct blkcg___155 *blkcg;
	int plid;
};

struct blkg_policy_data___155 {
	struct blkcg_gq___155 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___141 {
	struct mem_cgroup___141 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___141 {
	struct lruvec___149 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___141 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___141 *memcg;
};

struct obj_cgroup___141 {
	struct percpu_ref refcnt;
	struct mem_cgroup___141 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___79 {
	spinlock_t *lock;
	struct sk_buff___86 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___7 {
	struct nlmsghdr *nlh;
	struct net___90 *nl_net;
	u32 portid;
	u8 skip_notify;
	u8 skip_notify_kernel;
	long: 56;
	long: 64;
	long: 64;
};

struct Qdisc_class_ops___79;

struct Qdisc_ops___79 {
	struct Qdisc_ops___79 *next;
	const struct Qdisc_class_ops___79 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___86 *, struct Qdisc___79 *, struct sk_buff___86 **);
	struct sk_buff___86 * (*dequeue)(struct Qdisc___79 *);
	struct sk_buff___86 * (*peek)(struct Qdisc___79 *);
	int (*init)(struct Qdisc___79 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___79 *);
	void (*destroy)(struct Qdisc___79 *);
	int (*change)(struct Qdisc___79 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___79 *);
	int (*change_tx_queue_len)(struct Qdisc___79 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___79 *, unsigned int);
	int (*dump)(struct Qdisc___79 *, struct sk_buff___86 *);
	int (*dump_stats)(struct Qdisc___79 *, struct gnet_dump___79 *);
	void (*ingress_block_set)(struct Qdisc___79 *, u32);
	void (*egress_block_set)(struct Qdisc___79 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___79 *);
	u32 (*egress_block_get)(struct Qdisc___79 *);
	struct module___260 *owner;
};

struct Qdisc_class_ops___79 {
	unsigned int flags;
	struct netdev_queue___85 * (*select_queue)(struct Qdisc___79 *, struct tcmsg *);
	int (*graft)(struct Qdisc___79 *, long unsigned int, struct Qdisc___79 *, struct Qdisc___79 **, struct netlink_ext_ack *);
	struct Qdisc___79 * (*leaf)(struct Qdisc___79 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___79 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___79 *, u32);
	int (*change)(struct Qdisc___79 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___79 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___79 *, struct qdisc_walker *);
	struct tcf_block___79 * (*tcf_block)(struct Qdisc___79 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___79 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___79 *, long unsigned int);
	int (*dump)(struct Qdisc___79 *, long unsigned int, struct sk_buff___86 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___79 *, long unsigned int, struct gnet_dump___79 *);
};

struct tcf_chain___79;

struct tcf_block___79 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___90 *net;
	struct Qdisc___79 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___79 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___79;

struct tcf_proto_ops___79;

struct tcf_proto___79 {
	struct tcf_proto___79 *next;
	void *root;
	int (*classify)(struct sk_buff___86 *, const struct tcf_proto___79 *, struct tcf_result___79 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___79 *ops;
	struct tcf_chain___79 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___79 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___79 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___79 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___86 *, const struct tcf_proto___79 *, struct tcf_result___79 *);
	int (*init)(struct tcf_proto___79 *);
	void (*destroy)(struct tcf_proto___79 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___79 *, u32);
	void (*put)(struct tcf_proto___79 *, void *);
	int (*change)(struct net___90 *, struct sk_buff___86 *, struct tcf_proto___79 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___79 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___79 *);
	void (*walk)(struct tcf_proto___79 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___79 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___79 *, void *);
	void (*hw_del)(struct tcf_proto___79 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___90 *, struct tcf_chain___79 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___90 *, struct tcf_proto___79 *, void *, struct sk_buff___86 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___90 *, struct tcf_proto___79 *, void *, struct sk_buff___86 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___86 *, struct net___90 *, void *);
	struct module___260 *owner;
	int flags;
};

struct tcf_chain___79 {
	struct mutex filter_chain_lock;
	struct tcf_proto___79 *filter_chain;
	struct list_head list;
	struct tcf_block___79 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___79 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___72 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___79 *prog;
};

struct pneigh_entry___72;

struct neigh_hash_table___72;

struct neigh_table___72 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___85 *, __u32 *);
	bool (*key_eq)(const struct neighbour___72 *, const void *);
	int (*constructor)(struct neighbour___72 *);
	int (*pconstructor)(struct pneigh_entry___72 *);
	void (*pdestructor)(struct pneigh_entry___72 *);
	void (*proxy_redo)(struct sk_buff___86 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___85 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___72 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___85 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___72 *nht;
	struct pneigh_entry___72 **phash_buckets;
};

struct neigh_ops___72 {
	int family;
	void (*solicit)(struct neighbour___72 *, struct sk_buff___86 *);
	void (*error_report)(struct neighbour___72 *, struct sk_buff___86 *);
	int (*output)(struct neighbour___72 *, struct sk_buff___86 *);
	int (*connected_output)(struct neighbour___72 *, struct sk_buff___86 *);
};

struct pneigh_entry___72 {
	struct pneigh_entry___72 *next;
	possible_net_t___85 net;
	struct net_device___85 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___72 {
	struct neighbour___72 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___48 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___90 *, struct sock___72 *, struct sk_buff___86 *);
	int (*orig_input)(struct sk_buff___86 *);
	struct callback_head rcu;
	__u8 data[0];
};

enum {
	XFRM_LOOKUP_ICMP = 1,
	XFRM_LOOKUP_QUEUE = 2,
	XFRM_LOOKUP_KEEP_DST_REF = 4,
};

struct fib_rule___72 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___72 *ctarget;
	struct net___90 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___72 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___72 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___57;

struct timewait_sock_ops___56;

struct proto___72 {
	void (*close)(struct sock___72 *, long int);
	int (*pre_connect)(struct sock___72 *, struct sockaddr *, int);
	int (*connect)(struct sock___72 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___72 *, int);
	struct sock___72 * (*accept)(struct sock___72 *, int, int *, bool);
	int (*ioctl)(struct sock___72 *, int, long unsigned int);
	int (*init)(struct sock___72 *);
	void (*destroy)(struct sock___72 *);
	void (*shutdown)(struct sock___72 *, int);
	int (*setsockopt)(struct sock___72 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___72 *, int, int, char *, int *);
	void (*keepalive)(struct sock___72 *, int);
	int (*compat_ioctl)(struct sock___72 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___72 *, struct msghdr___74 *, size_t);
	int (*recvmsg)(struct sock___72 *, struct msghdr___74 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___72 *, struct page___281 *, int, size_t, int);
	int (*bind)(struct sock___72 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___72 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___72 *, struct sk_buff___86 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___72 *);
	int (*hash)(struct sock___72 *);
	void (*unhash)(struct sock___72 *);
	void (*rehash)(struct sock___72 *);
	int (*get_port)(struct sock___72 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___72 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___72 *, int);
	bool (*sock_is_readable)(struct sock___72 *);
	void (*enter_memory_pressure)(struct sock___72 *);
	void (*leave_memory_pressure)(struct sock___72 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___57 *rsk_prot;
	struct timewait_sock_ops___56 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___260 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___72 *, int);
};

struct xfrm_policy_queue___15 {
	struct sk_buff_head___85 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___15 {
	possible_net_t___85 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___15 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___23 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___79 *prog;
	struct sock___72 *socks[0];
};

struct request_sock___58;

struct request_sock_ops___57 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___72 *, struct request_sock___58 *);
	void (*send_ack)(const struct sock___72 *, struct sk_buff___86 *, struct request_sock___58 *);
	void (*send_reset)(const struct sock___72 *, struct sk_buff___86 *);
	void (*destructor)(struct request_sock___58 *);
	void (*syn_ack_timeout)(const struct request_sock___58 *);
};

struct timewait_sock_ops___56 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___72 *, struct sock___72 *, void *);
	void (*twsk_destructor)(struct sock___72 *);
};

struct request_sock___58 {
	struct sock_common___72 __req_common;
	struct request_sock___58 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___57 *rsk_ops;
	struct sock___72 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___15 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___72 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___15 {
	struct inet_cork___15 base;
	struct flowi fl;
};

struct ipv6_pinfo___14;

struct inet_sock___15 {
	struct sock___72 sk;
	struct ipv6_pinfo___14 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___15 cork;
};

struct ipv6_fl_socklist___14;

struct ipv6_pinfo___14 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___14 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___86 *pktoptions;
	struct sk_buff___86 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___14;

struct ipv6_fl_socklist___14 {
	struct ipv6_fl_socklist___14 *next;
	struct ip6_flowlabel___14 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___54 {
	struct in6_addr mca_addr;
	struct inet6_dev___54 *idev;
	struct ifmcaddr6___54 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___21 {
	struct in6_addr aca_addr;
	struct fib6_info___21 *aca_rt;
	struct ifacaddr6___21 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result___6;

struct fib6_config___7;

struct ipv6_stub___7 {
	int (*ipv6_sock_mc_join)(struct sock___72 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___72 *, int, const struct in6_addr *);
	struct dst_entry___72 * (*ipv6_dst_lookup_flow)(struct net___90 *, const struct sock___72 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___86 *);
	struct fib6_table___21 * (*fib6_get_table)(struct net___90 *, u32);
	int (*fib6_lookup)(struct net___90 *, int, struct flowi6 *, struct fib6_result___6 *, int);
	int (*fib6_table_lookup)(struct net___90 *, struct fib6_table___21 *, int, struct flowi6 *, struct fib6_result___6 *, int);
	void (*fib6_select_path)(const struct net___90 *, struct fib6_result___6 *, struct flowi6 *, int, bool, const struct sk_buff___86 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___6 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___90 *, struct fib6_nh___21 *, struct fib6_config___7 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___21 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___21 *);
	void (*fib6_update_sernum)(struct net___90 *, struct fib6_info___21 *);
	int (*ip6_del_rt)(struct net___90 *, struct fib6_info___21 *, bool);
	void (*fib6_rt_update)(struct net___90 *, struct fib6_info___21 *, struct nl_info___7 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___85 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___86 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___72 *, struct sk_buff___86 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___86 *, int, __be32, int);
	struct neigh_table___72 *nd_tbl;
	int (*ipv6_fragment)(struct net___90 *, struct sock___72 *, struct sk_buff___86 *, int (*)(struct net___90 *, struct sock___72 *, struct sk_buff___86 *));
	struct net_device___85 * (*ipv6_dev_find)(struct net___90 *, const struct in6_addr *, struct net_device___85 *);
};

struct fib6_result___6 {
	struct fib6_nh___21 *nh;
	struct fib6_info___21 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___21 *rt6;
};

struct fib6_config___7 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___7 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct ip6_flowlabel___14 {
	struct ip6_flowlabel___14 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___253 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___90 *fl_net;
};

struct fib_nh_exception___21 {
	struct fib_nh_exception___21 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___22 *fnhe_rth_input;
	struct rtable___22 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___22 {
	struct dst_entry___72 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___21 {
	struct fib_nh_exception___21 *chain;
};

struct fib_info___12;

struct fib_nh___12 {
	struct fib_nh_common___21 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___12 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___12 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___90 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___12 *nh;
	struct callback_head rcu;
	struct fib_nh___12 fib_nh[0];
};

struct nh_info___12;

struct nh_group___12;

struct nexthop___12 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___90 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___12 *nh_info;
		struct nh_group___12 *nh_grp;
	};
};

struct net_protocol___4 {
	int (*early_demux)(struct sk_buff___86 *);
	int (*early_demux_handler)(struct sk_buff___86 *);
	int (*handler)(struct sk_buff___86 *);
	int (*err_handler)(struct sk_buff___86 *, u32);
	unsigned int no_policy: 1;
	unsigned int icmp_strict_tag_validation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct icmp_ext_hdr {
	__u8 reserved1: 4;
	__u8 version: 4;
	__u8 reserved2;
	__sum16 checksum;
};

struct icmp_extobj_hdr {
	__be16 length;
	__u8 class_num;
	__u8 class_type;
};

struct icmp_ext_echo_ctype3_hdr {
	__be16 afi;
	__u8 addrlen;
	__u8 reserved;
};

struct icmp_ext_echo_iio {
	struct icmp_extobj_hdr extobj_hdr;
	union {
		char name[16];
		__be32 ifindex;
		struct {
			struct icmp_ext_echo_ctype3_hdr ctype3_hdr;
			union {
				__be32 ipv4_addr;
				struct in6_addr ipv6_addr;
			} ip_addr;
		} addr;
	} ident;
};

struct xfrm_type___15 {
	struct module___260 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___15 *);
	void (*destructor)(struct xfrm_state___15 *);
	int (*input)(struct xfrm_state___15 *, struct sk_buff___86 *);
	int (*output)(struct xfrm_state___15 *, struct sk_buff___86 *);
	int (*reject)(struct xfrm_state___15 *, struct sk_buff___86 *, const struct flowi *);
};

struct xfrm_type_offload___15 {
	struct module___260 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___15 *, struct sk_buff___86 *);
	int (*input_tail)(struct xfrm_state___15 *, struct sk_buff___86 *);
	int (*xmit)(struct xfrm_state___15 *, struct sk_buff___86 *, netdev_features_t);
};

struct sec_path___6 {
	int len;
	int olen;
	struct xfrm_state___15 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct icmp_bxm {
	struct sk_buff___86 *skb;
	int offset;
	int data_len;
	struct {
		struct icmphdr icmph;
		__be32 times[3];
	} data;
	int head_len;
	struct ip_options_data replyopts;
};

struct icmp_control {
	bool (*handler)(struct sk_buff___86 *);
	short int error;
};

struct nh_info___12 {
	struct hlist_node dev_hash;
	struct nexthop___12 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___21 fib_nhc;
		struct fib_nh___12 fib_nh;
		struct fib6_nh___21 fib6_nh;
	};
};

struct nh_grp_entry___12;

struct nh_res_bucket___12 {
	struct nh_grp_entry___12 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___12 {
	struct nexthop___12 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___12 *nh_parent;
};

struct nh_res_table___12 {
	struct net___90 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___12 nh_buckets[0];
};

struct nh_group___12 {
	struct nh_group___12 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___12 *res_table;
	struct nh_grp_entry___12 nh_entries[0];
};

struct ifaddrmsg {
	__u8 ifa_family;
	__u8 ifa_prefixlen;
	__u8 ifa_flags;
	__u8 ifa_scope;
	__u32 ifa_index;
};

enum {
	IFA_UNSPEC = 0,
	IFA_ADDRESS = 1,
	IFA_LOCAL = 2,
	IFA_LABEL = 3,
	IFA_BROADCAST = 4,
	IFA_ANYCAST = 5,
	IFA_CACHEINFO = 6,
	IFA_MULTICAST = 7,
	IFA_FLAGS = 8,
	IFA_RT_PRIORITY = 9,
	IFA_TARGET_NETNSID = 10,
	__IFA_MAX = 11,
};

struct ifa_cacheinfo {
	__u32 ifa_prefered;
	__u32 ifa_valid;
	__u32 cstamp;
	__u32 tstamp;
};

enum {
	IFLA_INET_UNSPEC = 0,
	IFLA_INET_CONF = 1,
	__IFLA_INET_MAX = 2,
};

struct in_validator_info {
	__be32 ivi_addr;
	struct in_device___13 *ivi_dev;
	struct netlink_ext_ack *extack;
};

struct netconfmsg {
	__u8 ncm_family;
};

enum {
	NETCONFA_UNSPEC = 0,
	NETCONFA_IFINDEX = 1,
	NETCONFA_FORWARDING = 2,
	NETCONFA_RP_FILTER = 3,
	NETCONFA_MC_FORWARDING = 4,
	NETCONFA_PROXY_NEIGH = 5,
	NETCONFA_IGNORE_ROUTES_WITH_LINKDOWN = 6,
	NETCONFA_INPUT = 7,
	NETCONFA_BC_FORWARDING = 8,
	__NETCONFA_MAX = 9,
};

typedef int (*rtnl_doit_func___9)(struct sk_buff___86 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___9)(struct sk_buff___86 *, struct netlink_callback___85 *);

struct rtnl_af_ops___2 {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___86 *, const struct net_device___85 *, u32);
	size_t (*get_link_af_size)(const struct net_device___85 *, u32);
	int (*validate_link_af)(const struct net_device___85 *, const struct nlattr *, struct netlink_ext_ack *);
	int (*set_link_af)(struct net_device___85 *, const struct nlattr *, struct netlink_ext_ack *);
	int (*fill_stats_af)(struct sk_buff___86 *, const struct net_device___85 *);
	size_t (*get_stats_af_size)(const struct net_device___85 *);
};

struct inet_fill_args {
	u32 portid;
	u32 seq;
	int event;
	unsigned int flags;
	int netnsid;
	int ifindex;
};

struct devinet_sysctl_table {
	struct ctl_table_header *sysctl_header;
	struct ctl_table devinet_vars[33];
};

struct dentry___277;

struct super_block___277;

struct module___261;

struct file_system_type___277 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___277 * (*mount)(struct file_system_type___277 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___277 *);
	struct module___261 *owner;
	struct file_system_type___277 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___277;

struct kiocb___277;

struct iov_iter___197;

struct poll_table_struct___198;

struct vm_area_struct___282;

struct inode___277;

struct file_lock___277;

struct page___282;

struct pipe_inode_info___118;

struct seq_file___252;

struct file_operations___278 {
	struct module___261 *owner;
	loff_t (*llseek)(struct file___277 *, loff_t, int);
	ssize_t (*read)(struct file___277 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___277 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___277 *, struct iov_iter___197 *);
	ssize_t (*write_iter)(struct kiocb___277 *, struct iov_iter___197 *);
	int (*iopoll)(struct kiocb___277 *, bool);
	int (*iterate)(struct file___277 *, struct dir_context *);
	int (*iterate_shared)(struct file___277 *, struct dir_context *);
	__poll_t (*poll)(struct file___277 *, struct poll_table_struct___198 *);
	long int (*unlocked_ioctl)(struct file___277 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___277 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___277 *, struct vm_area_struct___282 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___277 *, struct file___277 *);
	int (*flush)(struct file___277 *, fl_owner_t);
	int (*release)(struct inode___277 *, struct file___277 *);
	int (*fsync)(struct file___277 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___277 *, int);
	int (*lock)(struct file___277 *, int, struct file_lock___277 *);
	ssize_t (*sendpage)(struct file___277 *, struct page___282 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___277 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___277 *, long unsigned int);
	int (*flock)(struct file___277 *, int, struct file_lock___277 *);
	ssize_t (*splice_write)(struct pipe_inode_info___118 *, struct file___277 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___277 *, loff_t *, struct pipe_inode_info___118 *, size_t, unsigned int);
	int (*setlease)(struct file___277 *, long int, struct file_lock___277 **, void **);
	long int (*fallocate)(struct file___277 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___252 *, struct file___277 *);
	ssize_t (*copy_file_range)(struct file___277 *, loff_t, struct file___277 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___277 *, loff_t, struct file___277 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___277 *, loff_t, loff_t, int);
};

struct bio_vec___194 {
	struct page___282 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___277;

struct pipe_buffer___118;

struct pipe_inode_info___118 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___282 *tmp_page;
	struct fasync_struct___277 *fasync_readers;
	struct fasync_struct___277 *fasync_writers;
	struct pipe_buffer___118 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___197 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___194 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___118 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___75 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___197 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___277 *msg_iocb;
};

struct kiocb___277 {
	struct file___277 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___277 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct vmacache___282 {
	u64 seqnum;
	struct vm_area_struct___282 *vmas[4];
};

struct page_frag___282 {
	struct page___282 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___283;

struct pid___254;

struct nsproxy___263;

struct signal_struct___278;

struct bio_list___168;

struct backing_dev_info___154;

struct io_context___168;

struct css_set___204;

struct mem_cgroup___142;

struct request_queue___168;

struct vm_struct___260;

struct task_struct___284 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___284 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___283 *mm;
	struct mm_struct___283 *active_mm;
	struct vmacache___282 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___284 *real_parent;
	struct task_struct___284 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___284 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___254 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___263 *nsproxy;
	struct signal_struct___278 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___284 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___168 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___154 *backing_dev_info;
	struct io_context___168 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___204 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___118 *splice_pipe;
	struct page_frag___282 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___142 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___142 *active_memcg;
	struct request_queue___168 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___284 *oom_reaper_list;
	struct vm_struct___260 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___265;

struct kobj_type___265;

struct kernfs_node___265;

struct kobject___265 {
	const char *name;
	struct list_head entry;
	struct kobject___265 *parent;
	struct kset___265 *kset;
	struct kobj_type___265 *ktype;
	struct kernfs_node___265 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___262 {
	struct kobject___265 kobj;
	struct module___261 *mod;
	struct kobject___265 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___261 {
	struct module___261 *mod;
	struct latch_tree_node node;
};

struct module_layout___261 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___261 mtn;
};

struct module_attribute___261;

struct kernel_param___261;

struct module___261 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___262 mkobj;
	struct module_attribute___261 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___265 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___261 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___261 core_layout;
	struct module_layout___261 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___282 *pgtable_t___282;

struct address_space___277;

struct page_pool___106;

struct dev_pagemap___272;

struct page___282 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___277 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___106 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___282 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___282 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___283 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___272 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___272;

struct vm_area_struct___282 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___282 *vm_next;
	struct vm_area_struct___282 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___283 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___272 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___277 *vm_file;
	struct file___277 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___282;

struct mm_struct___283 {
	struct {
		struct vm_area_struct___282 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___277 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___282 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___284 *owner;
		struct user_namespace___26 *user_ns;
		struct file___277 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___277;

struct address_space___277 {
	struct inode___277 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___277 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___258;

struct page_pool_params___106 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___258 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___106 {
	u32 count;
	struct page___282 *cache[128];
};

struct page_pool___106 {
	struct page_pool_params___106 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___282 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___106 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___272;

struct dev_pagemap___272 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___272 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___277;

struct path___277 {
	struct vfsmount___277 *mnt;
	struct dentry___277 *dentry;
};

struct fown_struct___254 {
	rwlock_t lock;
	struct pid___254 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___277 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___277 f_path;
	struct inode___277 *f_inode;
	const struct file_operations___278 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___254 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___277 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___272;

struct vm_operations_struct___272 {
	void (*open)(struct vm_area_struct___282 *);
	void (*close)(struct vm_area_struct___282 *);
	int (*may_split)(struct vm_area_struct___282 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___282 *);
	int (*mprotect)(struct vm_area_struct___282 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___272 *);
	vm_fault_t (*huge_fault)(struct vm_fault___272 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___272 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___282 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___272 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___272 *);
	int (*access)(struct vm_area_struct___282 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___282 *);
	int (*set_policy)(struct vm_area_struct___282 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___282 *, long unsigned int);
	struct page___282 * (*find_special_page)(struct vm_area_struct___282 *, long unsigned int);
};

struct core_thread___282 {
	struct task_struct___284 *task;
	struct core_thread___282 *next;
};

struct core_state___282 {
	atomic_t nr_threads;
	struct core_thread___282 dumper;
	struct completion startup;
};

struct vm_fault___272 {
	const struct {
		struct vm_area_struct___282 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___282 *cow_page;
	struct page___282 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___282 prealloc_pte;
};

struct pglist_data___150;

struct lruvec___150 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___150 *pgdat;
};

struct zone___150 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___150 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___150 {
	struct zone___150 *zone;
	int zone_idx;
};

struct zonelist___150 {
	struct zoneref___150 _zonerefs[321];
};

struct pglist_data___150 {
	struct zone___150 node_zones[5];
	struct zonelist___150 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___284 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___284 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___150 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___254;

struct upid___254 {
	int nr;
	struct pid_namespace___254 *ns;
};

struct pid_namespace___254 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___284 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___254 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___254 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___254 numbers[1];
};

struct signal_struct___278 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___284 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___284 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___254 *pids[4];
	struct pid___254 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___283 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___91;

struct cgroup_namespace___204;

struct nsproxy___263 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___254 *pid_ns_for_children;
	struct net___91 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___204 *cgroup_ns;
};

struct bio___168;

struct bio_list___168 {
	struct bio___168 *head;
	struct bio___168 *tail;
};

struct cgroup_subsys_state___204;

struct bdi_writeback___154 {
	struct backing_dev_info___154 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___204 *memcg_css;
	struct cgroup_subsys_state___204 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___154 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___154 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___258 *dev;
	char dev_name[64];
	struct device___258 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___277 *debug_dir;
};

struct io_cq___168;

struct io_context___168 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___168 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___204;

struct css_set___204 {
	struct cgroup_subsys_state___204 *subsys[14];
	refcount_t refcount;
	struct css_set___204 *dom_cset;
	struct cgroup___204 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___204 *mg_src_cgrp;
	struct cgroup___204 *mg_dst_cgrp;
	struct css_set___204 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___204;

struct cgroup_subsys_state___204 {
	struct cgroup___204 *cgroup;
	struct cgroup_subsys___204 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___204 *parent;
};

struct cgroup_file___204 {
	struct kernfs_node___265 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___142;

struct mem_cgroup_per_node___142;

struct mem_cgroup___142 {
	struct cgroup_subsys_state___204 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___204 events_file;
	struct cgroup_file___204 events_local_file;
	struct cgroup_file___204 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___142 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___284 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___142 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___168;

struct blk_integrity___168 {
	const struct blk_integrity_profile___168 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___168 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___168 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___168;

struct elevator_queue___168;

struct blk_mq_ops___163;

struct blk_mq_hw_ctx___163;

struct gendisk___171;

struct blkcg_gq___156;

struct blk_mq_tag_set___163;

struct request_queue___168 {
	struct request___168 *last_merge;
	struct elevator_queue___168 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___163 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___163 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___171 *disk;
	struct kobject___265 kobj;
	struct kobject___265 *mq_kobj;
	struct blk_integrity___168 integrity;
	struct device___258 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___156 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___163 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___168 bio_split;
	struct dentry___277 *debugfs_dir;
	struct dentry___277 *sched_debugfs_dir;
	struct dentry___277 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___260 {
	struct vm_struct___260 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___282 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___277;

struct dentry___277 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___277 *d_parent;
	struct qstr d_name;
	struct inode___277 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___277 *d_op;
	struct super_block___277 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___277;

struct inode___277 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___277 *i_op;
	struct super_block___277 *i_sb;
	struct address_space___277 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___154 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___278 *i_fop;
		void (*free_inode)(struct inode___277 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___277 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___118 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___277 {
	int (*d_revalidate)(struct dentry___277 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___277 *, unsigned int);
	int (*d_hash)(const struct dentry___277 *, struct qstr *);
	int (*d_compare)(const struct dentry___277 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___277 *);
	int (*d_init)(struct dentry___277 *);
	void (*d_release)(struct dentry___277 *);
	void (*d_prune)(struct dentry___277 *);
	void (*d_iput)(struct dentry___277 *, struct inode___277 *);
	char * (*d_dname)(struct dentry___277 *, char *, int);
	struct vfsmount___277 * (*d_automount)(struct path___277 *);
	int (*d_manage)(const struct path___277 *, bool);
	struct dentry___277 * (*d_real)(struct dentry___277 *, const struct inode___277 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___277;

struct mem_dqinfo___277 {
	struct quota_format_type___277 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___277;

struct quota_info___277 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___277 *files[3];
	struct mem_dqinfo___277 info[3];
	const struct quota_format_ops___277 *ops[3];
};

struct rcuwait___278 {
	struct task_struct___284 *task;
};

struct percpu_rw_semaphore___278 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___278 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___277 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___278 rw_sem[3];
};

struct shrink_control___142;

struct shrinker___142 {
	long unsigned int (*count_objects)(struct shrinker___142 *, struct shrink_control___142 *);
	long unsigned int (*scan_objects)(struct shrinker___142 *, struct shrink_control___142 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___277;

struct dquot_operations___277;

struct quotactl_ops___277;

struct block_device___171;

struct super_block___277 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___277 *s_type;
	const struct super_operations___277 *s_op;
	const struct dquot_operations___277 *dq_op;
	const struct quotactl_ops___277 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___277 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___171 *s_bdev;
	struct backing_dev_info___154 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___277 s_dquot;
	struct sb_writers___277 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___277 *s_d_op;
	int cleancache_poolid;
	struct shrinker___142 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___277 {
	struct dentry___277 *mnt_root;
	struct super_block___277 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___142 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___142 *memcg;
};

struct psi_group___204 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___284 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___80;

struct cgroup_bpf___80 {
	struct bpf_prog_array___80 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___80 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___204;

struct cgroup_rstat_cpu___204;

struct cgroup___204 {
	struct cgroup_subsys_state___204 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___265 *kn;
	struct cgroup_file___204 procs_file;
	struct cgroup_file___204 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___204 *subsys[14];
	struct cgroup_root___204 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___204 *dom_cgrp;
	struct cgroup___204 *old_dom_cgrp;
	struct cgroup_rstat_cpu___204 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___204 psi;
	struct cgroup_bpf___80 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___168 {
	struct request_queue___168 *q;
	struct io_context___168 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___277 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___277 *ia_file;
};

struct dquot___277 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___277 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___277 {
	int qf_fmt_id;
	const struct quota_format_ops___277 *qf_ops;
	struct module___261 *qf_owner;
	struct quota_format_type___277 *qf_next;
};

struct quota_format_ops___277 {
	int (*check_quota_file)(struct super_block___277 *, int);
	int (*read_file_info)(struct super_block___277 *, int);
	int (*write_file_info)(struct super_block___277 *, int);
	int (*free_file_info)(struct super_block___277 *, int);
	int (*read_dqblk)(struct dquot___277 *);
	int (*commit_dqblk)(struct dquot___277 *);
	int (*release_dqblk)(struct dquot___277 *);
	int (*get_next_id)(struct super_block___277 *, struct kqid *);
};

struct dquot_operations___277 {
	int (*write_dquot)(struct dquot___277 *);
	struct dquot___277 * (*alloc_dquot)(struct super_block___277 *, int);
	void (*destroy_dquot)(struct dquot___277 *);
	int (*acquire_dquot)(struct dquot___277 *);
	int (*release_dquot)(struct dquot___277 *);
	int (*mark_dirty)(struct dquot___277 *);
	int (*write_info)(struct super_block___277 *, int);
	qsize_t * (*get_reserved_space)(struct inode___277 *);
	int (*get_projid)(struct inode___277 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___277 *, qsize_t *);
	int (*get_next_id)(struct super_block___277 *, struct kqid *);
};

struct quotactl_ops___277 {
	int (*quota_on)(struct super_block___277 *, int, int, const struct path___277 *);
	int (*quota_off)(struct super_block___277 *, int);
	int (*quota_enable)(struct super_block___277 *, unsigned int);
	int (*quota_disable)(struct super_block___277 *, unsigned int);
	int (*quota_sync)(struct super_block___277 *, int);
	int (*set_info)(struct super_block___277 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___277 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___277 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___277 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___277 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___277 *, unsigned int);
};

struct writeback_control___154;

struct address_space_operations___277 {
	int (*writepage)(struct page___282 *, struct writeback_control___154 *);
	int (*readpage)(struct file___277 *, struct page___282 *);
	int (*writepages)(struct address_space___277 *, struct writeback_control___154 *);
	int (*set_page_dirty)(struct page___282 *);
	int (*readpages)(struct file___277 *, struct address_space___277 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___277 *, struct address_space___277 *, loff_t, unsigned int, unsigned int, struct page___282 **, void **);
	int (*write_end)(struct file___277 *, struct address_space___277 *, loff_t, unsigned int, unsigned int, struct page___282 *, void *);
	sector_t (*bmap)(struct address_space___277 *, sector_t);
	void (*invalidatepage)(struct page___282 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___282 *, gfp_t);
	void (*freepage)(struct page___282 *);
	ssize_t (*direct_IO)(struct kiocb___277 *, struct iov_iter___197 *);
	int (*migratepage)(struct address_space___277 *, struct page___282 *, struct page___282 *, enum migrate_mode);
	bool (*isolate_page)(struct page___282 *, isolate_mode_t);
	void (*putback_page)(struct page___282 *);
	int (*launder_page)(struct page___282 *);
	int (*is_partially_uptodate)(struct page___282 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___282 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___277 *, struct page___282 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___277 *, sector_t *);
	void (*swap_deactivate)(struct file___277 *);
};

struct writeback_control___154 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___154 *wb;
	struct inode___277 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___277 {
	struct dentry___277 * (*lookup)(struct inode___277 *, struct dentry___277 *, unsigned int);
	const char * (*get_link)(struct dentry___277 *, struct inode___277 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___277 *, int);
	struct posix_acl * (*get_acl)(struct inode___277 *, int, bool);
	int (*readlink)(struct dentry___277 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___277 *, struct dentry___277 *, umode_t, bool);
	int (*link)(struct dentry___277 *, struct inode___277 *, struct dentry___277 *);
	int (*unlink)(struct inode___277 *, struct dentry___277 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___277 *, struct dentry___277 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___277 *, struct dentry___277 *, umode_t);
	int (*rmdir)(struct inode___277 *, struct dentry___277 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___277 *, struct dentry___277 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___277 *, struct dentry___277 *, struct inode___277 *, struct dentry___277 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___277 *, struct iattr___277 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___277 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___277 *, char *, size_t);
	int (*fiemap)(struct inode___277 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___277 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___277 *, struct dentry___277 *, struct file___277 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___277 *, struct dentry___277 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___277 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___277 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___277 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___277 {
	void (*fl_copy_lock)(struct file_lock___277 *, struct file_lock___277 *);
	void (*fl_release_private)(struct file_lock___277 *);
};

struct lock_manager_operations___277;

struct file_lock___277 {
	struct file_lock___277 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___277 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___277 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___277 *fl_ops;
	const struct lock_manager_operations___277 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___277 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___277 *);
	int (*lm_grant)(struct file_lock___277 *, int);
	bool (*lm_break)(struct file_lock___277 *);
	int (*lm_change)(struct file_lock___277 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___277 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___277 *);
};

struct fasync_struct___277 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___277 *fa_next;
	struct file___277 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___277 {
	struct inode___277 * (*alloc_inode)(struct super_block___277 *);
	void (*destroy_inode)(struct inode___277 *);
	void (*free_inode)(struct inode___277 *);
	void (*dirty_inode)(struct inode___277 *, int);
	int (*write_inode)(struct inode___277 *, struct writeback_control___154 *);
	int (*drop_inode)(struct inode___277 *);
	void (*evict_inode)(struct inode___277 *);
	void (*put_super)(struct super_block___277 *);
	int (*sync_fs)(struct super_block___277 *, int);
	int (*freeze_super)(struct super_block___277 *);
	int (*freeze_fs)(struct super_block___277 *);
	int (*thaw_super)(struct super_block___277 *);
	int (*unfreeze_fs)(struct super_block___277 *);
	int (*statfs)(struct dentry___277 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___277 *, int *, char *);
	void (*umount_begin)(struct super_block___277 *);
	int (*show_options)(struct seq_file___252 *, struct dentry___277 *);
	int (*show_devname)(struct seq_file___252 *, struct dentry___277 *);
	int (*show_path)(struct seq_file___252 *, struct dentry___277 *);
	int (*show_stats)(struct seq_file___252 *, struct dentry___277 *);
	ssize_t (*quota_read)(struct super_block___277 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___277 *, int, const char *, size_t, loff_t);
	struct dquot___277 ** (*get_dquots)(struct inode___277 *);
	long int (*nr_cached_objects)(struct super_block___277 *, struct shrink_control___142 *);
	long int (*free_cached_objects)(struct super_block___277 *, struct shrink_control___142 *);
	struct file___277 * (*real_loop)(struct file___277 *);
};

struct wakeup_source___258;

struct dev_pm_info___258 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___258 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___258 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___258;

struct bus_type___258;

struct device_driver___258;

struct dev_pm_domain___258;

struct fwnode_handle___254;

struct class___258;

struct attribute_group___265;

struct device___258 {
	struct kobject___265 kobj;
	struct device___258 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___258 *type;
	struct bus_type___258 *bus;
	struct device_driver___258 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___258 power;
	struct dev_pm_domain___258 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___254 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___258 *class;
	const struct attribute_group___265 **groups;
	void (*release)(struct device___258 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___171 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___277 *bd_inode;
	struct super_block___277 *bd_super;
	void *bd_claiming;
	struct device___258 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___265 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___171 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___277 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___206)(struct file___277 *, wait_queue_head_t *, struct poll_table_struct___198 *);

struct poll_table_struct___198 {
	poll_queue_proc___206 _qproc;
	__poll_t _key;
};

struct seq_operations___252;

struct seq_file___252 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___252 *op;
	int poll_event;
	const struct file___277 *file;
	void *private;
};

typedef void bio_end_io_t___168(struct bio___168 *);

struct bio_integrity_payload___168;

struct bio___168 {
	struct bio___168 *bi_next;
	struct block_device___171 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___168 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___156 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___168 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___194 *bi_io_vec;
	struct bio_set___168 *bi_pool;
	struct bio_vec___194 bi_inline_vecs[0];
};

struct dev_pagemap_ops___272 {
	void (*page_free)(struct page___282 *);
	void (*kill)(struct dev_pagemap___272 *);
	void (*cleanup)(struct dev_pagemap___272 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___272 *);
};

struct socket_wq___74 {
	wait_queue_head_t wait;
	struct fasync_struct___277 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___73;

struct proto_ops___74;

struct socket___75 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___277 *file;
	struct sock___73 *sk;
	const struct proto_ops___74 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___74 wq;
};

typedef struct {
	struct net___91 *net;
} possible_net_t___86;

struct proto___73;

struct sock_common___73 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___73 *skc_prot;
	possible_net_t___86 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___73 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___87;

struct sk_buff_head___86 {
	struct sk_buff___87 *next;
	struct sk_buff___87 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___73 {
	struct cgroup___204 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___73;

struct xfrm_policy___16;

struct dst_entry___73;

struct net_device___86;

struct sock_reuseport___24;

struct sock___73 {
	struct sock_common___73 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___86 sk_error_queue;
	struct sk_buff___87 *sk_rx_skb_cache;
	struct sk_buff_head___86 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___87 *head;
		struct sk_buff___87 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___73 *sk_filter;
	union {
		struct socket_wq___74 *sk_wq;
		struct socket_wq___74 *sk_wq_raw;
	};
	struct xfrm_policy___16 *sk_policy[2];
	struct dst_entry___73 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___73 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___87 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___87 *sk_tx_skb_cache;
	struct sk_buff_head___86 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___282 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___73 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___254 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___75 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___73 sk_cgrp_data;
	struct mem_cgroup___142 *sk_memcg;
	void (*sk_state_change)(struct sock___73 *);
	void (*sk_data_ready)(struct sock___73 *);
	void (*sk_write_space)(struct sock___73 *);
	void (*sk_error_report)(struct sock___73 *);
	int (*sk_backlog_rcv)(struct sock___73 *, struct sk_buff___87 *);
	struct sk_buff___87 * (*sk_validate_xmit_skb)(struct sock___73 *, struct net_device___86 *, struct sk_buff___87 *);
	void (*sk_destruct)(struct sock___73 *);
	struct sock_reuseport___24 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___73)(read_descriptor_t *, struct sk_buff___87 *, unsigned int, size_t);

struct proto_ops___74 {
	int family;
	struct module___261 *owner;
	int (*release)(struct socket___75 *);
	int (*bind)(struct socket___75 *, struct sockaddr *, int);
	int (*connect)(struct socket___75 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___75 *, struct socket___75 *);
	int (*accept)(struct socket___75 *, struct socket___75 *, int, bool);
	int (*getname)(struct socket___75 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___277 *, struct socket___75 *, struct poll_table_struct___198 *);
	int (*ioctl)(struct socket___75 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___75 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___75 *, void *, bool, bool);
	int (*listen)(struct socket___75 *, int);
	int (*shutdown)(struct socket___75 *, int);
	int (*setsockopt)(struct socket___75 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___75 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___252 *, struct socket___75 *);
	int (*sendmsg)(struct socket___75 *, struct msghdr___75 *, size_t);
	int (*recvmsg)(struct socket___75 *, struct msghdr___75 *, size_t, int);
	int (*mmap)(struct file___277 *, struct socket___75 *, struct vm_area_struct___282 *);
	ssize_t (*sendpage)(struct socket___75 *, struct page___282 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___75 *, loff_t *, struct pipe_inode_info___118 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___73 *, int);
	int (*peek_len)(struct socket___75 *);
	int (*read_sock)(struct sock___73 *, read_descriptor_t *, sk_read_actor_t___73);
	int (*sendpage_locked)(struct sock___73 *, struct page___282 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___73 *, struct msghdr___75 *, size_t);
	int (*set_rcvlowat)(struct sock___73 *, int);
};

struct sk_buff___87 {
	union {
		struct {
			struct sk_buff___87 *next;
			struct sk_buff___87 *prev;
			union {
				struct net_device___86 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___73 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___87 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct net_proto_family___3 {
	int family;
	int (*create)(struct net___91 *, struct socket___75 *, int, int);
	struct module___261 *owner;
};

struct ip_ra_chain___46;

struct fib_rules_ops___73;

struct fqdir___91;

struct tcp_congestion_ops___22;

struct fib_notifier_ops___73;

struct netns_ipv4___91 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___46 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___73 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___73 *fibnl;
	struct sock___73 **icmp_sk;
	struct sock___73 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___73 **tcp_sk;
	struct fqdir___91 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___22 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___73 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___73 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___73 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___73;

struct dst_ops___91 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___91 *);
	struct dst_entry___73 * (*check)(struct dst_entry___73 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___73 *);
	unsigned int (*mtu)(const struct dst_entry___73 *);
	u32 * (*cow_metrics)(struct dst_entry___73 *, long unsigned int);
	void (*destroy)(struct dst_entry___73 *);
	void (*ifdown)(struct dst_entry___73 *, struct net_device___86 *, int);
	struct dst_entry___73 * (*negative_advice)(struct dst_entry___73 *);
	void (*link_failure)(struct sk_buff___87 *);
	void (*update_pmtu)(struct dst_entry___73 *, struct sock___73 *, struct sk_buff___87 *, u32, bool);
	void (*redirect)(struct dst_entry___73 *, struct sock___73 *, struct sk_buff___87 *);
	int (*local_out)(struct net___91 *, struct sock___73 *, struct sk_buff___87 *);
	struct neighbour___73 * (*neigh_lookup)(const struct dst_entry___73 *, struct sk_buff___87 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___73 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___22;

struct rt6_info___22;

struct fib6_table___22;

struct netns_ipv6___91 {
	struct dst_ops___91 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___91 *fqdir;
	struct fib6_info___22 *fib6_null_entry;
	struct rt6_info___22 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___22 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___22 *ip6_prohibit_entry;
	struct rt6_info___22 *ip6_blk_hole_entry;
	struct fib6_table___22 *fib6_local_tbl;
	struct fib_rules_ops___73 *fib6_rules_ops;
	struct sock___73 **icmp_sk;
	struct sock___73 *ndisc_sk;
	struct sock___73 *tcp_sk;
	struct sock___73 *igmp_sk;
	struct sock___73 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___73 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___73 *notifier_ops;
	struct fib_notifier_ops___73 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___91 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___91 *fqdir;
};

struct netns_sctp___73 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___73 *ctl_sock;
	struct sock___73 *udp4_sock;
	struct sock___73 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___14;

struct netns_nf___14 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___14 *hooks_ipv4[5];
	struct nf_hook_entries___14 *hooks_ipv6[5];
	struct nf_hook_entries___14 *hooks_arp[3];
	struct nf_hook_entries___14 *hooks_bridge[5];
	struct nf_hook_entries___14 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___80;

struct netns_bpf___80 {
	struct bpf_prog_array___80 *run_array[2];
	struct bpf_prog___80 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___91 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___73 *nlsk;
	struct sock___73 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___91 xfrm4_dst_ops;
	struct dst_ops___91 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___91 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___73 *rtnl;
	struct sock___73 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___86 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___91 ipv4;
	struct netns_ipv6___91 ipv6;
	struct netns_ieee802154_lowpan___91 ieee802154_lowpan;
	struct netns_sctp___73 sctp;
	struct netns_nf___14 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___86 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___80 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___91 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___73 *crypto_nlsk;
	struct sock___73 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct fwnode_operations___254;

struct fwnode_handle___254 {
	struct fwnode_handle___254 *secondary;
	const struct fwnode_operations___254 *ops;
	struct device___258 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___254;

struct fwnode_endpoint___254;

struct fwnode_operations___254 {
	struct fwnode_handle___254 * (*get)(struct fwnode_handle___254 *);
	void (*put)(struct fwnode_handle___254 *);
	bool (*device_is_available)(const struct fwnode_handle___254 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___254 *, const struct device___258 *);
	bool (*property_present)(const struct fwnode_handle___254 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___254 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___254 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___254 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*get_parent)(const struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*get_next_child_node)(const struct fwnode_handle___254 *, struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*get_named_child_node)(const struct fwnode_handle___254 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___254 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___254 *);
	struct fwnode_handle___254 * (*graph_get_next_endpoint)(const struct fwnode_handle___254 *, struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*graph_get_remote_endpoint)(const struct fwnode_handle___254 *);
	struct fwnode_handle___254 * (*graph_get_port_parent)(struct fwnode_handle___254 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___254 *, struct fwnode_endpoint___254 *);
	int (*add_links)(struct fwnode_handle___254 *);
};

struct fwnode_endpoint___254 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___254 *local_fwnode;
};

struct fwnode_reference_args___254 {
	struct fwnode_handle___254 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___265;

struct kernfs_elem_dir___265 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___265 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___265;

struct kernfs_root___265 {
	struct kernfs_node___265 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___265 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___265 {
	struct kernfs_node___265 *target_kn;
};

struct kernfs_ops___265;

struct kernfs_elem_attr___265 {
	const struct kernfs_ops___265 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___265 *notify_next;
};

struct kernfs_node___265 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___265 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___265 dir;
		struct kernfs_elem_symlink___265 symlink;
		struct kernfs_elem_attr___265 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___265;

struct kernfs_ops___265 {
	int (*open)(struct kernfs_open_file___265 *);
	void (*release)(struct kernfs_open_file___265 *);
	int (*seq_show)(struct seq_file___252 *, void *);
	void * (*seq_start)(struct seq_file___252 *, loff_t *);
	void * (*seq_next)(struct seq_file___252 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___252 *, void *);
	ssize_t (*read)(struct kernfs_open_file___265 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___265 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___265 *, struct poll_table_struct___198 *);
	int (*mmap)(struct kernfs_open_file___265 *, struct vm_area_struct___282 *);
};

struct kernfs_syscall_ops___265 {
	int (*show_options)(struct seq_file___252 *, struct kernfs_root___265 *);
	int (*mkdir)(struct kernfs_node___265 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___265 *);
	int (*rename)(struct kernfs_node___265 *, struct kernfs_node___265 *, const char *);
	int (*show_path)(struct seq_file___252 *, struct kernfs_node___265 *, struct kernfs_root___265 *);
};

struct kernfs_open_file___265 {
	struct kernfs_node___265 *kn;
	struct file___277 *file;
	struct seq_file___252 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___272 *vm_ops;
};

struct kobj_ns_type_operations___73 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___73 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___265;

struct attribute_group___265 {
	const char *name;
	umode_t (*is_visible)(struct kobject___265 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___265 *, struct bin_attribute___265 *, int);
	struct attribute **attrs;
	struct bin_attribute___265 **bin_attrs;
};

struct bin_attribute___265 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___277 * (*f_mapping)();
	ssize_t (*read)(struct file___277 *, struct kobject___265 *, struct bin_attribute___265 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___277 *, struct kobject___265 *, struct bin_attribute___265 *, char *, loff_t, size_t);
	int (*mmap)(struct file___277 *, struct kobject___265 *, struct bin_attribute___265 *, struct vm_area_struct___282 *);
};

struct sysfs_ops___265 {
	ssize_t (*show)(struct kobject___265 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___265 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___265;

struct kset___265 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___265 kobj;
	const struct kset_uevent_ops___265 *uevent_ops;
};

struct kobj_type___265 {
	void (*release)(struct kobject___265 *);
	const struct sysfs_ops___265 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___265 **default_groups;
	const struct kobj_ns_type_operations___73 * (*child_ns_type)(struct kobject___265 *);
	const void * (*namespace)(struct kobject___265 *);
	void (*get_ownership)(struct kobject___265 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___265 {
	int (* const filter)(struct kset___265 *, struct kobject___265 *);
	const char * (* const name)(struct kset___265 *, struct kobject___265 *);
	int (* const uevent)(struct kset___265 *, struct kobject___265 *, struct kobj_uevent_env *);
};

typedef struct poll_table_struct___198 poll_table___51;

struct kernel_param_ops___261 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___261 *);
	int (*get)(char *, const struct kernel_param___261 *);
	void (*free)(void *);
};

struct kparam_array___261;

struct kernel_param___261 {
	const char *name;
	struct module___261 *mod;
	const struct kernel_param_ops___261 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___261 *arr;
	};
};

struct kparam_array___261 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___261 *ops;
	void *elem;
};

struct module_attribute___261 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___261 *, struct module_kobject___262 *, char *);
	ssize_t (*store)(struct module_attribute___261 *, struct module_kobject___262 *, const char *, size_t);
	void (*setup)(struct module___261 *, const char *);
	int (*test)(struct module___261 *);
	void (*free)(struct module___261 *);
};

struct cgroup_namespace___204 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___204 *root_cset;
};

struct dev_pm_ops___258 {
	int (*prepare)(struct device___258 *);
	void (*complete)(struct device___258 *);
	int (*suspend)(struct device___258 *);
	int (*resume)(struct device___258 *);
	int (*freeze)(struct device___258 *);
	int (*thaw)(struct device___258 *);
	int (*poweroff)(struct device___258 *);
	int (*restore)(struct device___258 *);
	int (*suspend_late)(struct device___258 *);
	int (*resume_early)(struct device___258 *);
	int (*freeze_late)(struct device___258 *);
	int (*thaw_early)(struct device___258 *);
	int (*poweroff_late)(struct device___258 *);
	int (*restore_early)(struct device___258 *);
	int (*suspend_noirq)(struct device___258 *);
	int (*resume_noirq)(struct device___258 *);
	int (*freeze_noirq)(struct device___258 *);
	int (*thaw_noirq)(struct device___258 *);
	int (*poweroff_noirq)(struct device___258 *);
	int (*restore_noirq)(struct device___258 *);
	int (*runtime_suspend)(struct device___258 *);
	int (*runtime_resume)(struct device___258 *);
	int (*runtime_idle)(struct device___258 *);
};

struct wakeup_source___258 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___258 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___258 {
	struct dev_pm_ops___258 ops;
	int (*start)(struct device___258 *);
	void (*detach)(struct device___258 *, bool);
	int (*activate)(struct device___258 *);
	void (*sync)(struct device___258 *);
	void (*dismiss)(struct device___258 *);
};

struct bus_type___258 {
	const char *name;
	const char *dev_name;
	struct device___258 *dev_root;
	const struct attribute_group___265 **bus_groups;
	const struct attribute_group___265 **dev_groups;
	const struct attribute_group___265 **drv_groups;
	int (*match)(struct device___258 *, struct device_driver___258 *);
	int (*uevent)(struct device___258 *, struct kobj_uevent_env *);
	int (*probe)(struct device___258 *);
	void (*sync_state)(struct device___258 *);
	void (*remove)(struct device___258 *);
	void (*shutdown)(struct device___258 *);
	int (*online)(struct device___258 *);
	int (*offline)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	int (*num_vf)(struct device___258 *);
	int (*dma_configure)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___258 {
	const char *name;
	struct bus_type___258 *bus;
	struct module___261 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___258 *);
	void (*sync_state)(struct device___258 *);
	int (*remove)(struct device___258 *);
	void (*shutdown)(struct device___258 *);
	int (*suspend)(struct device___258 *, pm_message_t);
	int (*resume)(struct device___258 *);
	const struct attribute_group___265 **groups;
	const struct attribute_group___265 **dev_groups;
	const struct dev_pm_ops___258 *pm;
	void (*coredump)(struct device___258 *);
	struct driver_private *p;
};

struct device_type___258 {
	const char *name;
	const struct attribute_group___265 **groups;
	int (*uevent)(struct device___258 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___258 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___258 *);
	const struct dev_pm_ops___258 *pm;
};

struct class___258 {
	const char *name;
	struct module___261 *owner;
	const struct attribute_group___265 **class_groups;
	const struct attribute_group___265 **dev_groups;
	struct kobject___265 *dev_kobj;
	int (*dev_uevent)(struct device___258 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___258 *, umode_t *);
	void (*class_release)(struct class___258 *);
	void (*dev_release)(struct device___258 *);
	int (*shutdown_pre)(struct device___258 *);
	const struct kobj_ns_type_operations___73 *ns_type;
	const void * (*namespace)(struct device___258 *);
	void (*get_ownership)(struct device___258 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___258 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___118;

struct pipe_buffer___118 {
	struct page___282 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___118 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___118 {
	int (*confirm)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
	void (*release)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
	bool (*try_steal)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
	bool (*get)(struct pipe_inode_info___118 *, struct pipe_buffer___118 *);
};

typedef rx_handler_result_t rx_handler_func_t___86(struct sk_buff___87 **);

struct bpf_xdp_entity___80 {
	struct bpf_prog___80 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___86;

struct net_device_ops___86;

struct l3mdev_ops___73;

struct ndisc_ops___55;

struct xfrmdev_ops___86;

struct header_ops___86;

struct in_device___14;

struct inet6_dev___55;

struct netdev_rx_queue___86;

struct mini_Qdisc___80;

struct netdev_queue___86;

struct Qdisc___80;

struct rtnl_link_ops___80;

struct dcbnl_rtnl_ops___86;

struct net_device___86 {
	char name[16];
	struct netdev_name_node___86 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___86 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___73 *l3mdev_ops;
	const struct ndisc_ops___55 *ndisc_ops;
	const struct xfrmdev_ops___86 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___86 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___265 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___14 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___55 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___86 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___80 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___86 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___80 *miniq_ingress;
	struct netdev_queue___86 *ingress_queue;
	struct nf_hook_entries___14 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___86 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___80 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___80 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___86 = 0,
		NETREG_REGISTERED___86 = 1,
		NETREG_UNREGISTERING___86 = 2,
		NETREG_UNREGISTERED___86 = 3,
		NETREG_RELEASED___86 = 4,
		NETREG_DUMMY___86 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___86 = 0,
		RTNL_LINK_INITIALIZING___86 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___86 *);
	struct netpoll_info *npinfo;
	possible_net_t___86 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___258 dev;
	const struct attribute_group___265 *sysfs_groups[4];
	const struct attribute_group___265 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___80 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___86 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___80 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___194 skb_frag_t___32;

struct ubuf_info___11 {
	void (*callback)(struct sk_buff___87 *, struct ubuf_info___11 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___30 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___87 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___32 frags[17];
};

struct inet_frags___91;

struct fqdir___91 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___91 *f;
	struct net___91 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___91;

struct inet_frags___91 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___91 *, const void *);
	void (*destructor)(struct inet_frag_queue___91 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___91 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___87 *fragments_tail;
	struct sk_buff___87 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___91 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___46 {
	struct ip_ra_chain___46 *next;
	struct sock___73 *sk;
	union {
		void (*destructor)(struct sock___73 *);
		struct sock___73 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___73;

struct fib_lookup_arg___73;

struct fib_rules_ops___73 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___73 *, struct flowi *, int, struct fib_lookup_arg___73 *);
	bool (*suppress)(struct fib_rule___73 *, int, struct fib_lookup_arg___73 *);
	int (*match)(struct fib_rule___73 *, struct flowi *, int);
	int (*configure)(struct fib_rule___73 *, struct sk_buff___87 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___73 *);
	int (*compare)(struct fib_rule___73 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___73 *, struct sk_buff___87 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___73 *);
	void (*flush_cache)(struct fib_rules_ops___73 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___261 *owner;
	struct net___91 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___22 {
	u32 (*ssthresh)(struct sock___73 *);
	void (*cong_avoid)(struct sock___73 *, u32, u32);
	void (*set_state)(struct sock___73 *, u8);
	void (*cwnd_event)(struct sock___73 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___73 *, u32);
	void (*pkts_acked)(struct sock___73 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___73 *);
	void (*cong_control)(struct sock___73 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___73 *);
	u32 (*sndbuf_expand)(struct sock___73 *);
	size_t (*get_info)(struct sock___73 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___261 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___73 *);
	void (*release)(struct sock___73 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___73 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___91 *);
	int (*fib_dump)(struct net___91 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___261 *owner;
	struct callback_head rcu;
};

struct xfrm_state___16;

struct lwtunnel_state___49;

struct dst_entry___73 {
	struct net_device___86 *dev;
	struct dst_ops___91 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___16 *xfrm;
	int (*input)(struct sk_buff___87 *);
	int (*output)(struct net___91 *, struct sock___73 *, struct sk_buff___87 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___49 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___73;

struct neigh_parms___73;

struct neigh_ops___73;

struct neighbour___73 {
	struct neighbour___73 *next;
	struct neigh_table___73 *tbl;
	struct neigh_parms___73 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___86 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___73 *, struct sk_buff___87 *);
	const struct neigh_ops___73 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___86 *dev;
	u8 primary_key[0];
};

struct rtable___23;

struct fnhe_hash_bucket___22;

struct fib_nh_common___22 {
	struct net_device___86 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___49 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___23 **nhc_pcpu_rth_output;
	struct rtable___23 *nhc_rth_input;
	struct fnhe_hash_bucket___22 *nhc_exceptions;
};

struct fib6_nh___22 {
	struct fib_nh_common___22 nh_common;
	long unsigned int last_probe;
	struct rt6_info___22 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___22;

struct nexthop___13;

struct fib6_info___22 {
	struct fib6_table___22 *fib6_table;
	struct fib6_info___22 *fib6_next;
	struct fib6_node___22 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___13 *nh;
	struct fib6_nh___22 fib6_nh[0];
};

struct rt6_info___22 {
	struct dst_entry___73 dst;
	struct fib6_info___22 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___55 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___22 {
	struct fib6_node___22 *parent;
	struct fib6_node___22 *left;
	struct fib6_node___22 *right;
	struct fib6_node___22 *subtree;
	struct fib6_info___22 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___22 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___22 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___22 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___14;

typedef unsigned int nf_hookfn___16(void *, struct sk_buff___87 *, const struct nf_hook_state___14 *);

struct nf_hook_entry___14 {
	nf_hookfn___16 *hook;
	void *priv;
};

struct nf_hook_entries___14 {
	u16 num_hook_entries;
	struct nf_hook_entry___14 hooks[0];
};

struct bpf_prog_array_item___80 {
	struct bpf_prog___80 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___80 {
	struct callback_head rcu;
	struct bpf_prog_array_item___80 items[0];
};

struct bpf_prog_aux___89;

struct bpf_prog___80 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___89 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___252 {
	void * (*start)(struct seq_file___252 *, loff_t *);
	void (*stop)(struct seq_file___252 *, void *);
	void * (*next)(struct seq_file___252 *, void *, loff_t *);
	int (*show)(struct seq_file___252 *, void *);
};

struct pernet_operations___27 {
	struct list_head list;
	int (*init)(struct net___91 *);
	void (*pre_exit)(struct net___91 *);
	void (*exit)(struct net___91 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___86 {
	int (*ieee_getets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___86 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___86 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___86 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___86 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___86 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___86 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___86 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___86 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___86 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___86 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___86 *);
	u8 (*setstate)(struct net_device___86 *, u8);
	void (*getpermhwaddr)(struct net_device___86 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___86 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___86 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___86 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___86 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___86 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___86 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___86 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___86 *, int, u8 *);
	void (*setpfccfg)(struct net_device___86 *, int, u8);
	void (*getpfccfg)(struct net_device___86 *, int, u8 *);
	u8 (*setall)(struct net_device___86 *);
	u8 (*getcap)(struct net_device___86 *, int, u8 *);
	int (*getnumtcs)(struct net_device___86 *, int, u8 *);
	int (*setnumtcs)(struct net_device___86 *, int, u8);
	u8 (*getpfcstate)(struct net_device___86 *);
	void (*setpfcstate)(struct net_device___86 *, u8);
	void (*getbcncfg)(struct net_device___86 *, int, u32 *);
	void (*setbcncfg)(struct net_device___86 *, int, u32);
	void (*getbcnrp)(struct net_device___86 *, int, u8 *);
	void (*setbcnrp)(struct net_device___86 *, int, u8);
	int (*setapp)(struct net_device___86 *, u8, u16, u8);
	int (*getapp)(struct net_device___86 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___86 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___86 *, int, u8);
	u8 (*getdcbx)(struct net_device___86 *);
	u8 (*setdcbx)(struct net_device___86 *, u8);
	int (*peer_getappinfo)(struct net_device___86 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___86 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___86 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___86 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___86 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___86 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___89;

typedef int (*bpf_iter_init_seq_priv_t___88)(void *, struct bpf_iter_aux_info___89 *);

struct bpf_map___89;

struct bpf_iter_aux_info___89 {
	struct bpf_map___89 *map;
};

struct bpf_iter_seq_info___88 {
	const struct seq_operations___252 *seq_ops;
	bpf_iter_init_seq_priv_t___88 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___88 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___89 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___89 *, struct file___277 *);
	void (*map_free)(struct bpf_map___89 *);
	int (*map_get_next_key)(struct bpf_map___89 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___89 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___89 *, void *);
	int (*map_lookup_batch)(struct bpf_map___89 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___89 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___89 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___89 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___89 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___89 *, void *);
	int (*map_update_elem)(struct bpf_map___89 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___89 *, void *);
	int (*map_push_elem)(struct bpf_map___89 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___89 *, void *);
	int (*map_peek_elem)(struct bpf_map___89 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___89 *, struct file___277 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___89 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___89 *, void *, struct seq_file___252 *);
	int (*map_check_btf)(const struct bpf_map___89 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___89 *, struct bpf_prog_aux___89 *);
	void (*map_poke_untrack)(struct bpf_map___89 *, struct bpf_prog_aux___89 *);
	void (*map_poke_run)(struct bpf_map___89 *, u32, struct bpf_prog___80 *, struct bpf_prog___80 *);
	int (*map_direct_value_addr)(const struct bpf_map___89 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___89 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___89 *, struct vm_area_struct___282 *);
	__poll_t (*map_poll)(struct bpf_map___89 *, struct file___277 *, struct poll_table_struct___198 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___89 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___89 *, const struct bpf_map___89 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___89 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___88 *iter_seq_info;
};

struct bpf_map___89 {
	const struct bpf_map_ops___88 *ops;
	struct bpf_map___89 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___142 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___88;

struct bpf_jit_poke_descriptor___88;

struct bpf_prog_ops___80;

struct btf_mod_pair___88;

struct bpf_prog_offload___86;

struct bpf_prog_aux___89 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___80 *dst_prog;
	struct bpf_trampoline___88 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___80 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___88 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___80 *ops;
	struct bpf_map___89 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___88 *used_btfs;
	struct bpf_prog___80 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___89 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___86 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___86;

struct bpf_map_dev_ops___86 {
	int (*map_get_next_key)(struct bpf_offloaded_map___86 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___86 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___86 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___86 *, void *);
};

struct bpf_offloaded_map___86 {
	struct bpf_map___89 map;
	struct net_device___86 *netdev;
	const struct bpf_map_dev_ops___86 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___80 {
	int (*test_run)(struct bpf_prog___80 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___86 {
	struct bpf_prog___80 *prog;
	struct net_device___86 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___88 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___80 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___261 *mod;
};

struct bpf_jit_poke_descriptor___88 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___89 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___88 {
	struct btf *btf;
	struct module___261 *module;
};

struct cftype___204;

struct cgroup_subsys___204 {
	struct cgroup_subsys_state___204 * (*css_alloc)(struct cgroup_subsys_state___204 *);
	int (*css_online)(struct cgroup_subsys_state___204 *);
	void (*css_offline)(struct cgroup_subsys_state___204 *);
	void (*css_released)(struct cgroup_subsys_state___204 *);
	void (*css_free)(struct cgroup_subsys_state___204 *);
	void (*css_reset)(struct cgroup_subsys_state___204 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___204 *, int);
	int (*css_extra_stat_show)(struct seq_file___252 *, struct cgroup_subsys_state___204 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___284 *, struct css_set___204 *);
	void (*cancel_fork)(struct task_struct___284 *, struct css_set___204 *);
	void (*fork)(struct task_struct___284 *);
	void (*exit)(struct task_struct___284 *);
	void (*release)(struct task_struct___284 *);
	void (*bind)(struct cgroup_subsys_state___204 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___204 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___204 *dfl_cftypes;
	struct cftype___204 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___204 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___204 *updated_children;
	struct cgroup___204 *updated_next;
};

struct cgroup_root___204 {
	struct kernfs_root___265 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___204 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___204 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___204 *ss;
	struct list_head node;
	struct kernfs_ops___265 *kf_ops;
	int (*open)(struct kernfs_open_file___265 *);
	void (*release)(struct kernfs_open_file___265 *);
	u64 (*read_u64)(struct cgroup_subsys_state___204 *, struct cftype___204 *);
	s64 (*read_s64)(struct cgroup_subsys_state___204 *, struct cftype___204 *);
	int (*seq_show)(struct seq_file___252 *, void *);
	void * (*seq_start)(struct seq_file___252 *, loff_t *);
	void * (*seq_next)(struct seq_file___252 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___252 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___204 *, struct cftype___204 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___204 *, struct cftype___204 *, s64);
	ssize_t (*write)(struct kernfs_open_file___265 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___265 *, struct poll_table_struct___198 *);
};

struct xdp_rxq_info___86 {
	struct net_device___86 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___86 {
	struct net_device___86 *dev;
};

struct xdp_buff___86 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___86 *rxq;
	struct xdp_txq_info___86 *txq;
	u32 frame_sz;
};

struct xdp_frame___86 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___86 *dev_rx;
};

struct netlink_callback___86 {
	struct sk_buff___87 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___87 *, struct netlink_callback___86 *);
	int (*done)(struct netlink_callback___86 *);
	void *data;
	struct module___261 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___86 {
	int (*create)(struct sk_buff___87 *, struct net_device___86 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___87 *, unsigned char *);
	int (*cache)(const struct neighbour___73 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___86 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___87 *);
};

struct netdev_queue___86 {
	struct net_device___86 *dev;
	struct Qdisc___80 *qdisc;
	struct Qdisc___80 *qdisc_sleeping;
	struct kobject___265 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___86 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___80 {
	struct sk_buff___87 *head;
	struct sk_buff___87 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___80;

struct Qdisc___80 {
	int (*enqueue)(struct sk_buff___87 *, struct Qdisc___80 *, struct sk_buff___87 **);
	struct sk_buff___87 * (*dequeue)(struct Qdisc___80 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___80 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___86 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___86 gso_skb;
	struct qdisc_skb_head___80 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___80 *next_sched;
	struct sk_buff_head___86 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___86 {
	struct xdp_rxq_info___86 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___265 kobj;
	struct net_device___86 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___86 {
	enum net_device_path_type type;
	const struct net_device___86 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___86 = 0,
				DEV_PATH_BR_VLAN_TAG___86 = 1,
				DEV_PATH_BR_VLAN_UNTAG___86 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___86 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___86 {
	const struct net_device___86 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___86 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___80 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___86 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___86 {
	int (*xdo_dev_state_add)(struct xfrm_state___16 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___16 *);
	void (*xdo_dev_state_free)(struct xfrm_state___16 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___87 *, struct xfrm_state___16 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___16 *);
};

struct xfrm_state_offload___16 {
	struct net_device___86 *dev;
	struct net_device___86 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___16;

struct xfrm_type_offload___16;

struct xfrm_state___16 {
	possible_net_t___86 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___73 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___16 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___16 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___282 xfrag;
	const struct xfrm_type___16 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___16 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___86 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___86 *dev;
	const char *name;
};

struct net_device_ops___86 {
	int (*ndo_init)(struct net_device___86 *);
	void (*ndo_uninit)(struct net_device___86 *);
	int (*ndo_open)(struct net_device___86 *);
	int (*ndo_stop)(struct net_device___86 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___87 *, struct net_device___86 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___87 *, struct net_device___86 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___86 *, struct sk_buff___87 *, struct net_device___86 *);
	void (*ndo_change_rx_flags)(struct net_device___86 *, int);
	void (*ndo_set_rx_mode)(struct net_device___86 *);
	int (*ndo_set_mac_address)(struct net_device___86 *, void *);
	int (*ndo_validate_addr)(struct net_device___86 *);
	int (*ndo_do_ioctl)(struct net_device___86 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___86 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___86 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___86 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___86 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___86 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___86 *, int);
	int (*ndo_neigh_setup)(struct net_device___86 *, struct neigh_parms___73 *);
	void (*ndo_tx_timeout)(struct net_device___86 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___86 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___86 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___86 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___86 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___86 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___86 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___86 *);
	int (*ndo_netpoll_setup)(struct net_device___86 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___86 *);
	int (*ndo_set_vf_mac)(struct net_device___86 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___86 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___86 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___86 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___86 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___86 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___86 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___86 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___86 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___86 *, int, struct sk_buff___87 *);
	int (*ndo_get_vf_guid)(struct net_device___86 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___86 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___86 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___86 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___86 *);
	int (*ndo_fcoe_disable)(struct net_device___86 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___86 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___86 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___86 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___86 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___86 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___86 *, const struct sk_buff___87 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___86 *, struct net_device___86 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___86 *, struct net_device___86 *);
	struct net_device___86 * (*ndo_get_xmit_slave)(struct net_device___86 *, struct sk_buff___87 *, bool);
	struct net_device___86 * (*ndo_sk_get_lower_dev)(struct net_device___86 *, struct sock___73 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___86 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___86 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___86 *, struct neighbour___73 *);
	void (*ndo_neigh_destroy)(struct net_device___86 *, struct neighbour___73 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___87 *, struct netlink_callback___86 *, struct net_device___86 *, struct net_device___86 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___87 *, struct nlattr **, struct net_device___86 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___86 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___87 *, u32, u32, struct net_device___86 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___86 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___86 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___86 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___86 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___86 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___86 *, struct net_device___86 *);
	void (*ndo_dfwd_del_station)(struct net_device___86 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___86 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___86 *);
	int (*ndo_change_proto_down)(struct net_device___86 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___86 *, struct sk_buff___87 *);
	void (*ndo_set_rx_headroom)(struct net_device___86 *, int);
	int (*ndo_bpf)(struct net_device___86 *, struct netdev_bpf___86 *);
	int (*ndo_xdp_xmit)(struct net_device___86 *, int, struct xdp_frame___86 **, u32);
	struct net_device___86 * (*ndo_xdp_get_xmit_slave)(struct net_device___86 *, struct xdp_buff___86 *);
	int (*ndo_xsk_wakeup)(struct net_device___86 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___86 *);
	int (*ndo_tunnel_ctl)(struct net_device___86 *, struct ip_tunnel_parm *, int);
	struct net_device___86 * (*ndo_get_peer_dev)(struct net_device___86 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___86 *, struct net_device_path___86 *);
};

struct neigh_parms___73 {
	possible_net_t___86 net;
	struct net_device___86 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___73 *);
	struct neigh_table___73 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___73 {
	u32 (*l3mdev_fib_table)(const struct net_device___86 *);
	struct sk_buff___87 * (*l3mdev_l3_rcv)(struct net_device___86 *, struct sk_buff___87 *, u16);
	struct sk_buff___87 * (*l3mdev_l3_out)(struct net_device___86 *, struct sock___73 *, struct sk_buff___87 *, u16);
	struct dst_entry___73 * (*l3mdev_link_scope_lookup)(const struct net_device___86 *, struct flowi6 *);
};

struct ndisc_ops___55 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___86 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___86 *, struct neighbour___73 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___86 *, u8, struct neighbour___73 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___86 *, struct sk_buff___87 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___91 *, struct net_device___86 *, const struct prefix_info *, struct inet6_dev___55 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___14;

struct ip_mc_list___4;

struct in_device___14 {
	struct net_device___86 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___14 *ifa_list;
	struct ip_mc_list___4 *mc_list;
	struct ip_mc_list___4 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___4 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___73 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___55;

struct ifacaddr6___22;

struct inet6_dev___55 {
	struct net_device___86 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___55 *mc_list;
	struct ifmcaddr6___55 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___86 mc_query_queue;
	struct sk_buff_head___86 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___22 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___73 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___80;

struct tcf_block___80;

struct mini_Qdisc___80 {
	struct tcf_proto___80 *filter_list;
	struct tcf_block___80 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___80 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___86 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___86 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___91 *, struct net_device___86 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___86 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___86 *, struct list_head *);
	size_t (*get_size)(const struct net_device___86 *);
	int (*fill_info)(struct sk_buff___87 *, const struct net_device___86 *);
	size_t (*get_xstats_size)(const struct net_device___86 *);
	int (*fill_xstats)(struct sk_buff___87 *, const struct net_device___86 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___86 *, struct net_device___86 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___86 *, const struct net_device___86 *);
	int (*fill_slave_info)(struct sk_buff___87 *, const struct net_device___86 *, const struct net_device___86 *);
	struct net___91 * (*get_link_net)(const struct net_device___86 *);
	size_t (*get_linkxstats_size)(const struct net_device___86 *, int);
	int (*fill_linkxstats)(struct sk_buff___87 *, const struct net_device___86 *, int *, int);
};

struct napi_gro_cb___5 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___87 *last;
};

struct packet_type___6 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___86 *dev;
	int (*func)(struct sk_buff___87 *, struct net_device___86 *, struct packet_type___6 *, struct net_device___86 *);
	void (*list_func)(struct list_head *, struct packet_type___6 *, struct net_device___86 *);
	bool (*id_match)(struct packet_type___6 *, struct sock___73 *);
	struct net___91 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct offload_callbacks___4 {
	struct sk_buff___87 * (*gso_segment)(struct sk_buff___87 *, netdev_features_t);
	struct sk_buff___87 * (*gro_receive)(struct list_head *, struct sk_buff___87 *);
	int (*gro_complete)(struct sk_buff___87 *, int);
};

struct packet_offload___3 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___4 callbacks;
	struct list_head list;
};

struct nf_hook_state___14 {
	u8 hook;
	u8 pf;
	struct net_device___86 *in;
	struct net_device___86 *out;
	struct sock___73 *sk;
	struct net___91 *net;
	int (*okfn)(struct net___91 *, struct sock___73 *, struct sk_buff___87 *);
};

struct ip_mc_list___4 {
	struct in_device___14 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___4 *next;
		struct ip_mc_list___4 *next_rcu;
	};
	struct ip_mc_list___4 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___14 {
	struct hlist_node hash;
	struct in_ifaddr___14 *ifa_next;
	struct in_device___14 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct block_device_operations___168;

struct gendisk___171 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___171 *part0;
	const struct block_device_operations___168 *fops;
	struct request_queue___168 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___154 *bdi;
	struct kobject___265 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___265 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___168 {
	struct bio___168 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___194 *bip_vec;
	struct bio_vec___194 bip_inline_vecs[0];
};

struct blkcg___156;

struct blkg_policy_data___156;

struct blkcg_gq___156 {
	struct request_queue___168 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___156 *blkcg;
	struct blkcg_gq___156 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___156 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___168 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___168(struct request___168 *);

typedef void integrity_complete_fn___168(struct request___168 *, unsigned int);

struct blk_integrity_profile___168 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___168 *prepare_fn;
	integrity_complete_fn___168 *complete_fn;
	const char *name;
};

struct block_device_operations___168 {
	blk_qc_t (*submit_bio)(struct bio___168 *);
	int (*open)(struct block_device___171 *, fmode_t);
	void (*release)(struct gendisk___171 *, fmode_t);
	int (*rw_page)(struct block_device___171 *, sector_t, struct page___282 *, unsigned int);
	int (*ioctl)(struct block_device___171 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___171 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___171 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___171 *);
	int (*getgeo)(struct block_device___171 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___171 *, bool);
	void (*swap_slot_free_notify)(struct block_device___171 *, long unsigned int);
	int (*report_zones)(struct gendisk___171 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___171 *, umode_t *);
	struct module___261 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___171 *, sector_t *);
};

typedef void rq_end_io_fn___168(struct request___168 *, blk_status_t);

struct request___168 {
	struct request_queue___168 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___163 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___168 *bio;
	struct bio___168 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___194 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___168 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___168 *saved_end_io;
		} flush;
	};
	struct gendisk___171 *rq_disk;
	struct block_device___171 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___168 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___163 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___168 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___265 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___277 *debugfs_dir;
	struct dentry___277 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___168;

struct elevator_mq_ops___168 {
	int (*init_sched)(struct request_queue___168 *, struct elevator_type___168 *);
	void (*exit_sched)(struct elevator_queue___168 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___163 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___163 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___163 *);
	bool (*allow_merge)(struct request_queue___168 *, struct request___168 *, struct bio___168 *);
	bool (*bio_merge)(struct request_queue___168 *, struct bio___168 *, unsigned int);
	int (*request_merge)(struct request_queue___168 *, struct request___168 **, struct bio___168 *);
	void (*request_merged)(struct request_queue___168 *, struct request___168 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___168 *, struct request___168 *, struct request___168 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___168 *);
	void (*finish_request)(struct request___168 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___163 *, struct list_head *, bool);
	struct request___168 * (*dispatch_request)(struct blk_mq_hw_ctx___163 *);
	bool (*has_work)(struct blk_mq_hw_ctx___163 *);
	void (*completed_request)(struct request___168 *, u64);
	void (*requeue_request)(struct request___168 *);
	struct request___168 * (*former_request)(struct request_queue___168 *, struct request___168 *);
	struct request___168 * (*next_request)(struct request_queue___168 *, struct request___168 *);
	void (*init_icq)(struct io_cq___168 *);
	void (*exit_icq)(struct io_cq___168 *);
};

struct elv_fs_entry___168;

struct elevator_type___168 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___168 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___168 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___261 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___168 {
	struct elevator_type___168 *type;
	void *elevator_data;
	struct kobject___265 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___168 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___168 *, char *);
	ssize_t (*store)(struct elevator_queue___168 *, const char *, size_t);
};

struct blk_mq_queue_data___163;

struct blk_mq_ops___163 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___163 *, const struct blk_mq_queue_data___163 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___163 *);
	int (*get_budget)(struct request_queue___168 *);
	void (*put_budget)(struct request_queue___168 *, int);
	void (*set_rq_budget_token)(struct request___168 *, int);
	int (*get_rq_budget_token)(struct request___168 *);
	enum blk_eh_timer_return (*timeout)(struct request___168 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___163 *);
	void (*complete)(struct request___168 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___163 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___163 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___163 *, struct request___168 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___163 *, struct request___168 *, unsigned int);
	void (*initialize_rq_fn)(struct request___168 *);
	void (*cleanup_rq)(struct request___168 *);
	bool (*busy)(struct request_queue___168 *);
	int (*map_queues)(struct blk_mq_tag_set___163 *);
	void (*show_rq)(struct seq_file___252 *, struct request___168 *);
};

struct blk_mq_tag_set___163 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___163 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___163 {
	struct request___168 *rq;
	bool last;
};

struct blkcg_policy_data___156;

struct blkcg___156 {
	struct cgroup_subsys_state___204 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___156 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___156 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___156 {
	struct blkcg___156 *blkcg;
	int plid;
};

struct blkg_policy_data___156 {
	struct blkcg_gq___156 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___142 {
	struct mem_cgroup___142 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___142 {
	struct lruvec___150 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___142 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___142 *memcg;
};

struct obj_cgroup___142 {
	struct percpu_ref refcnt;
	struct mem_cgroup___142 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___80 {
	spinlock_t *lock;
	struct sk_buff___87 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___80;

struct Qdisc_ops___80 {
	struct Qdisc_ops___80 *next;
	const struct Qdisc_class_ops___80 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___87 *, struct Qdisc___80 *, struct sk_buff___87 **);
	struct sk_buff___87 * (*dequeue)(struct Qdisc___80 *);
	struct sk_buff___87 * (*peek)(struct Qdisc___80 *);
	int (*init)(struct Qdisc___80 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___80 *);
	void (*destroy)(struct Qdisc___80 *);
	int (*change)(struct Qdisc___80 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___80 *);
	int (*change_tx_queue_len)(struct Qdisc___80 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___80 *, unsigned int);
	int (*dump)(struct Qdisc___80 *, struct sk_buff___87 *);
	int (*dump_stats)(struct Qdisc___80 *, struct gnet_dump___80 *);
	void (*ingress_block_set)(struct Qdisc___80 *, u32);
	void (*egress_block_set)(struct Qdisc___80 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___80 *);
	u32 (*egress_block_get)(struct Qdisc___80 *);
	struct module___261 *owner;
};

struct Qdisc_class_ops___80 {
	unsigned int flags;
	struct netdev_queue___86 * (*select_queue)(struct Qdisc___80 *, struct tcmsg *);
	int (*graft)(struct Qdisc___80 *, long unsigned int, struct Qdisc___80 *, struct Qdisc___80 **, struct netlink_ext_ack *);
	struct Qdisc___80 * (*leaf)(struct Qdisc___80 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___80 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___80 *, u32);
	int (*change)(struct Qdisc___80 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___80 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___80 *, struct qdisc_walker *);
	struct tcf_block___80 * (*tcf_block)(struct Qdisc___80 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___80 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___80 *, long unsigned int);
	int (*dump)(struct Qdisc___80 *, long unsigned int, struct sk_buff___87 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___80 *, long unsigned int, struct gnet_dump___80 *);
};

struct tcf_chain___80;

struct tcf_block___80 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___91 *net;
	struct Qdisc___80 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___80 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___80;

struct tcf_proto_ops___80;

struct tcf_proto___80 {
	struct tcf_proto___80 *next;
	void *root;
	int (*classify)(struct sk_buff___87 *, const struct tcf_proto___80 *, struct tcf_result___80 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___80 *ops;
	struct tcf_chain___80 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___80 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___80 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___80 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___87 *, const struct tcf_proto___80 *, struct tcf_result___80 *);
	int (*init)(struct tcf_proto___80 *);
	void (*destroy)(struct tcf_proto___80 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___80 *, u32);
	void (*put)(struct tcf_proto___80 *, void *);
	int (*change)(struct net___91 *, struct sk_buff___87 *, struct tcf_proto___80 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___80 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___80 *);
	void (*walk)(struct tcf_proto___80 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___80 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___80 *, void *);
	void (*hw_del)(struct tcf_proto___80 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___91 *, struct tcf_chain___80 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___91 *, struct tcf_proto___80 *, void *, struct sk_buff___87 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___91 *, struct tcf_proto___80 *, void *, struct sk_buff___87 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___87 *, struct net___91 *, void *);
	struct module___261 *owner;
	int flags;
};

struct tcf_chain___80 {
	struct mutex filter_chain_lock;
	struct tcf_proto___80 *filter_chain;
	struct list_head list;
	struct tcf_block___80 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___80 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___73 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___80 *prog;
};

struct bpf_sock_ops_kern___8 {
	struct sock___73 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___87 *syn_skb;
	struct sk_buff___87 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct pneigh_entry___73;

struct neigh_hash_table___73;

struct neigh_table___73 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___86 *, __u32 *);
	bool (*key_eq)(const struct neighbour___73 *, const void *);
	int (*constructor)(struct neighbour___73 *);
	int (*pconstructor)(struct pneigh_entry___73 *);
	void (*pdestructor)(struct pneigh_entry___73 *);
	void (*proxy_redo)(struct sk_buff___87 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___86 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___73 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___86 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___73 *nht;
	struct pneigh_entry___73 **phash_buckets;
};

struct neigh_ops___73 {
	int family;
	void (*solicit)(struct neighbour___73 *, struct sk_buff___87 *);
	void (*error_report)(struct neighbour___73 *, struct sk_buff___87 *);
	int (*output)(struct neighbour___73 *, struct sk_buff___87 *);
	int (*connected_output)(struct neighbour___73 *, struct sk_buff___87 *);
};

struct pneigh_entry___73 {
	struct pneigh_entry___73 *next;
	possible_net_t___86 net;
	struct net_device___86 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___73 {
	struct neighbour___73 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___49 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___91 *, struct sock___73 *, struct sk_buff___87 *);
	int (*orig_input)(struct sk_buff___87 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___73 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___73 *ctarget;
	struct net___91 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___73 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___73 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___58;

struct timewait_sock_ops___57;

struct proto___73 {
	void (*close)(struct sock___73 *, long int);
	int (*pre_connect)(struct sock___73 *, struct sockaddr *, int);
	int (*connect)(struct sock___73 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___73 *, int);
	struct sock___73 * (*accept)(struct sock___73 *, int, int *, bool);
	int (*ioctl)(struct sock___73 *, int, long unsigned int);
	int (*init)(struct sock___73 *);
	void (*destroy)(struct sock___73 *);
	void (*shutdown)(struct sock___73 *, int);
	int (*setsockopt)(struct sock___73 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___73 *, int, int, char *, int *);
	void (*keepalive)(struct sock___73 *, int);
	int (*compat_ioctl)(struct sock___73 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___73 *, struct msghdr___75 *, size_t);
	int (*recvmsg)(struct sock___73 *, struct msghdr___75 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___73 *, struct page___282 *, int, size_t, int);
	int (*bind)(struct sock___73 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___73 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___73 *, struct sk_buff___87 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___73 *);
	int (*hash)(struct sock___73 *);
	void (*unhash)(struct sock___73 *);
	void (*rehash)(struct sock___73 *);
	int (*get_port)(struct sock___73 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___73 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___73 *, int);
	bool (*sock_is_readable)(struct sock___73 *);
	void (*enter_memory_pressure)(struct sock___73 *);
	void (*leave_memory_pressure)(struct sock___73 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___58 *rsk_prot;
	struct timewait_sock_ops___57 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___261 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___73 *, int);
};

struct xfrm_policy_queue___16 {
	struct sk_buff_head___86 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___16 {
	possible_net_t___86 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___16 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___24 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___80 *prog;
	struct sock___73 *socks[0];
};

struct request_sock___59;

struct request_sock_ops___58 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___73 *, struct request_sock___59 *);
	void (*send_ack)(const struct sock___73 *, struct sk_buff___87 *, struct request_sock___59 *);
	void (*send_reset)(const struct sock___73 *, struct sk_buff___87 *);
	void (*destructor)(struct request_sock___59 *);
	void (*syn_ack_timeout)(const struct request_sock___59 *);
};

struct timewait_sock_ops___57 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___73 *, struct sock___73 *, void *);
	void (*twsk_destructor)(struct sock___73 *);
};

struct socket_alloc___5 {
	struct socket___75 socket;
	struct inode___277 vfs_inode;
	long: 64;
};

struct request_sock___59 {
	struct sock_common___73 __req_common;
	struct request_sock___59 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___58 *rsk_ops;
	struct sock___73 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___8 {
	struct request_sock___59 *rskq_rst_head;
	struct request_sock___59 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___8 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___59 *rskq_accept_head;
	struct request_sock___59 *rskq_accept_tail;
	struct fastopen_queue___8 fastopenq;
};

struct inet_cork___16 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___73 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___16 {
	struct inet_cork___16 base;
	struct flowi fl;
};

struct ipv6_pinfo___15;

struct inet_sock___16 {
	struct sock___73 sk;
	struct ipv6_pinfo___15 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___16 cork;
};

struct ipv6_fl_socklist___15;

struct ipv6_pinfo___15 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___15 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___87 *pktoptions;
	struct sk_buff___87 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___8 {
	int (*queue_xmit)(struct sock___73 *, struct sk_buff___87 *, struct flowi *);
	void (*send_check)(struct sock___73 *, struct sk_buff___87 *);
	int (*rebuild_header)(struct sock___73 *);
	void (*sk_rx_dst_set)(struct sock___73 *, const struct sk_buff___87 *);
	int (*conn_request)(struct sock___73 *, struct sk_buff___87 *);
	struct sock___73 * (*syn_recv_sock)(const struct sock___73 *, struct sk_buff___87 *, struct request_sock___59 *, struct dst_entry___73 *, struct request_sock___59 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___73 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___73 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___73 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___73 *);
};

struct inet_bind_bucket___8;

struct tcp_ulp_ops___8;

struct inet_connection_sock___8 {
	struct inet_sock___16 icsk_inet;
	struct request_sock_queue___8 icsk_accept_queue;
	struct inet_bind_bucket___8 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___22 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___8 *icsk_af_ops;
	const struct tcp_ulp_ops___8 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___73 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___73 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___8 {
	possible_net_t___86 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___8 {
	struct list_head list;
	int (*init)(struct sock___73 *);
	void (*update)(struct sock___73 *, struct proto___73 *, void (*)(struct sock___73 *));
	void (*release)(struct sock___73 *);
	int (*get_info)(const struct sock___73 *, struct sk_buff___87 *);
	size_t (*get_info_size)(const struct sock___73 *);
	void (*clone)(const struct request_sock___59 *, struct sock___73 *, const gfp_t);
	char name[16];
	struct module___261 *owner;
};

struct tcp_sock_af_ops___9;

struct tcp_fastopen_request___9;

struct tcp_sock___9 {
	struct inet_connection_sock___8 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___87 *lost_skb_hint;
	struct sk_buff___87 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___87 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___87 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___9 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___9 *fastopen_req;
	struct request_sock___59 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___9 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___73 *, const struct sock___73 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___73 *, const struct sk_buff___87 *);
	int (*md5_parse)(struct sock___73 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___9 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___75 *data;
	size_t size;
	int copied;
	struct ubuf_info___11 *uarg;
};

struct ip6_flowlabel___15;

struct ipv6_fl_socklist___15 {
	struct ipv6_fl_socklist___15 *next;
	struct ip6_flowlabel___15 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___55 {
	struct in6_addr mca_addr;
	struct inet6_dev___55 *idev;
	struct ifmcaddr6___55 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___22 {
	struct in6_addr aca_addr;
	struct fib6_info___22 *aca_rt;
	struct ifacaddr6___22 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___15 {
	struct ip6_flowlabel___15 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___254 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___91 *fl_net;
};

struct fib_nh_exception___22 {
	struct fib_nh_exception___22 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___23 *fnhe_rth_input;
	struct rtable___23 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___23 {
	struct dst_entry___73 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___22 {
	struct fib_nh_exception___22 *chain;
};

struct fib_info___13;

struct fib_nh___13 {
	struct fib_nh_common___22 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___13 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___13 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___91 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___13 *nh;
	struct callback_head rcu;
	struct fib_nh___13 fib_nh[0];
};

struct nh_info___13;

struct nh_group___13;

struct nexthop___13 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___91 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___13 *nh_info;
		struct nh_group___13 *nh_grp;
	};
};

struct rtentry {
	long unsigned int rt_pad1;
	struct sockaddr rt_dst;
	struct sockaddr rt_gateway;
	struct sockaddr rt_genmask;
	short unsigned int rt_flags;
	short int rt_pad2;
	long unsigned int rt_pad3;
	void *rt_pad4;
	short int rt_metric;
	char *rt_dev;
	long unsigned int rt_mtu;
	long unsigned int rt_window;
	short unsigned int rt_irtt;
};

struct net_protocol___5 {
	int (*early_demux)(struct sk_buff___87 *);
	int (*early_demux_handler)(struct sk_buff___87 *);
	int (*handler)(struct sk_buff___87 *);
	int (*err_handler)(struct sk_buff___87 *, u32);
	unsigned int no_policy: 1;
	unsigned int icmp_strict_tag_validation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_offload___3 {
	struct offload_callbacks___4 callbacks;
	unsigned int flags;
};

struct inet_protosw___2 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___73 *prot;
	const struct proto_ops___74 *ops;
	unsigned char flags;
};

struct pingv6_ops {
	int (*ipv6_recv_error)(struct sock___73 *, struct msghdr___75 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___73 *, struct msghdr___75 *, struct sk_buff___87 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___73 *, struct msghdr___75 *, struct sk_buff___87 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___73 *, struct sk_buff___87 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___91 *, const struct in6_addr *, const struct net_device___86 *, int);
};

struct nh_info___13 {
	struct hlist_node dev_hash;
	struct nexthop___13 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___22 fib_nhc;
		struct fib_nh___13 fib_nh;
		struct fib6_nh___22 fib6_nh;
	};
};

struct nh_grp_entry___13;

struct nh_res_bucket___13 {
	struct nh_grp_entry___13 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___13 {
	struct nexthop___13 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___13 *nh_parent;
};

struct nh_res_table___13 {
	struct net___91 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___13 nh_buckets[0];
};

struct nh_group___13 {
	struct nh_group___13 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___13 *res_table;
	struct nh_grp_entry___13 nh_entries[0];
};

struct xfrm_type___16 {
	struct module___261 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___16 *);
	void (*destructor)(struct xfrm_state___16 *);
	int (*input)(struct xfrm_state___16 *, struct sk_buff___87 *);
	int (*output)(struct xfrm_state___16 *, struct sk_buff___87 *);
	int (*reject)(struct xfrm_state___16 *, struct sk_buff___87 *, const struct flowi *);
};

struct xfrm_type_offload___16 {
	struct module___261 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___16 *, struct sk_buff___87 *);
	int (*input_tail)(struct xfrm_state___16 *, struct sk_buff___87 *);
	int (*xmit)(struct xfrm_state___16 *, struct sk_buff___87 *, netdev_features_t);
};

struct compat_rtentry {
	u32 rt_pad1;
	struct sockaddr rt_dst;
	struct sockaddr rt_gateway;
	struct sockaddr rt_genmask;
	short unsigned int rt_flags;
	short int rt_pad2;
	u32 rt_pad3;
	unsigned char rt_tos;
	unsigned char rt_class;
	short int rt_pad4;
	short int rt_metric;
	compat_uptr_t rt_dev;
	u32 rt_mtu;
	u32 rt_window;
	short unsigned int rt_irtt;
};

struct dentry___278;

struct super_block___278;

struct module___262;

struct file_system_type___278 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___278 * (*mount)(struct file_system_type___278 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___278 *);
	struct module___262 *owner;
	struct file_system_type___278 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___278;

struct kiocb___278;

struct iov_iter___198;

struct poll_table_struct___199;

struct vm_area_struct___283;

struct inode___278;

struct file_lock___278;

struct page___283;

struct pipe_inode_info___119;

struct seq_file___253;

struct file_operations___279 {
	struct module___262 *owner;
	loff_t (*llseek)(struct file___278 *, loff_t, int);
	ssize_t (*read)(struct file___278 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___278 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___278 *, struct iov_iter___198 *);
	ssize_t (*write_iter)(struct kiocb___278 *, struct iov_iter___198 *);
	int (*iopoll)(struct kiocb___278 *, bool);
	int (*iterate)(struct file___278 *, struct dir_context *);
	int (*iterate_shared)(struct file___278 *, struct dir_context *);
	__poll_t (*poll)(struct file___278 *, struct poll_table_struct___199 *);
	long int (*unlocked_ioctl)(struct file___278 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___278 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___278 *, struct vm_area_struct___283 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___278 *, struct file___278 *);
	int (*flush)(struct file___278 *, fl_owner_t);
	int (*release)(struct inode___278 *, struct file___278 *);
	int (*fsync)(struct file___278 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___278 *, int);
	int (*lock)(struct file___278 *, int, struct file_lock___278 *);
	ssize_t (*sendpage)(struct file___278 *, struct page___283 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___278 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___278 *, long unsigned int);
	int (*flock)(struct file___278 *, int, struct file_lock___278 *);
	ssize_t (*splice_write)(struct pipe_inode_info___119 *, struct file___278 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___278 *, loff_t *, struct pipe_inode_info___119 *, size_t, unsigned int);
	int (*setlease)(struct file___278 *, long int, struct file_lock___278 **, void **);
	long int (*fallocate)(struct file___278 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___253 *, struct file___278 *);
	ssize_t (*copy_file_range)(struct file___278 *, loff_t, struct file___278 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___278 *, loff_t, struct file___278 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___278 *, loff_t, loff_t, int);
};

struct vmacache___283 {
	u64 seqnum;
	struct vm_area_struct___283 *vmas[4];
};

struct page_frag___283 {
	struct page___283 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___284;

struct pid___255;

struct nsproxy___264;

struct signal_struct___279;

struct bio_list___169;

struct backing_dev_info___155;

struct io_context___169;

struct css_set___205;

struct mem_cgroup___143;

struct request_queue___169;

struct vm_struct___261;

struct task_struct___285 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___285 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___284 *mm;
	struct mm_struct___284 *active_mm;
	struct vmacache___283 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___285 *real_parent;
	struct task_struct___285 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___285 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___255 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___264 *nsproxy;
	struct signal_struct___279 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___285 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___169 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___155 *backing_dev_info;
	struct io_context___169 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___205 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___119 *splice_pipe;
	struct page_frag___283 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___143 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___143 *active_memcg;
	struct request_queue___169 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___285 *oom_reaper_list;
	struct vm_struct___261 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___266;

struct kobj_type___266;

struct kernfs_node___266;

struct kobject___266 {
	const char *name;
	struct list_head entry;
	struct kobject___266 *parent;
	struct kset___266 *kset;
	struct kobj_type___266 *ktype;
	struct kernfs_node___266 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___263 {
	struct kobject___266 kobj;
	struct module___262 *mod;
	struct kobject___266 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___262 {
	struct module___262 *mod;
	struct latch_tree_node node;
};

struct module_layout___262 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___262 mtn;
};

struct module_attribute___262;

struct kernel_param___262;

struct module___262 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___263 mkobj;
	struct module_attribute___262 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___266 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___262 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___262 core_layout;
	struct module_layout___262 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___255;

struct upid___255 {
	int nr;
	struct pid_namespace___255 *ns;
};

struct pid_namespace___255 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___285 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___255 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___255 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___255 numbers[1];
};

typedef struct page___283 *pgtable_t___283;

struct address_space___278;

struct page_pool___107;

struct dev_pagemap___273;

struct page___283 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___278 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___107 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___283 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___283 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___284 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___273 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___273;

struct vm_area_struct___283 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___283 *vm_next;
	struct vm_area_struct___283 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___284 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___273 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___278 *vm_file;
	struct file___278 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___279 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___285 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___285 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___255 *pids[4];
	struct pid___255 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___284 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___283;

struct mm_struct___284 {
	struct {
		struct vm_area_struct___283 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___278 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___283 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___285 *owner;
		struct user_namespace___26 *user_ns;
		struct file___278 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___92;

struct cgroup_namespace___205;

struct nsproxy___264 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___255 *pid_ns_for_children;
	struct net___92 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___205 *cgroup_ns;
};

struct bio___169;

struct bio_list___169 {
	struct bio___169 *head;
	struct bio___169 *tail;
};

struct cgroup_subsys_state___205;

struct bdi_writeback___155 {
	struct backing_dev_info___155 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___205 *memcg_css;
	struct cgroup_subsys_state___205 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___259;

struct backing_dev_info___155 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___155 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___259 *dev;
	char dev_name[64];
	struct device___259 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___278 *debug_dir;
};

struct io_cq___169;

struct io_context___169 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___169 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___205;

struct css_set___205 {
	struct cgroup_subsys_state___205 *subsys[14];
	refcount_t refcount;
	struct css_set___205 *dom_cset;
	struct cgroup___205 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___205 *mg_src_cgrp;
	struct cgroup___205 *mg_dst_cgrp;
	struct css_set___205 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___278;

struct pipe_buffer___119;

struct pipe_inode_info___119 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___283 *tmp_page;
	struct fasync_struct___278 *fasync_readers;
	struct fasync_struct___278 *fasync_writers;
	struct pipe_buffer___119 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___205;

struct cgroup_subsys_state___205 {
	struct cgroup___205 *cgroup;
	struct cgroup_subsys___205 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___205 *parent;
};

struct cgroup_file___205 {
	struct kernfs_node___266 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___143;

struct mem_cgroup_per_node___143;

struct mem_cgroup___143 {
	struct cgroup_subsys_state___205 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___205 events_file;
	struct cgroup_file___205 events_local_file;
	struct cgroup_file___205 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___143 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___285 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___143 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___169;

struct blk_integrity___169 {
	const struct blk_integrity_profile___169 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___169 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___169 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___169;

struct elevator_queue___169;

struct blk_mq_ops___164;

struct blk_mq_hw_ctx___164;

struct gendisk___172;

struct blkcg_gq___157;

struct blk_mq_tag_set___164;

struct request_queue___169 {
	struct request___169 *last_merge;
	struct elevator_queue___169 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___164 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___164 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___172 *disk;
	struct kobject___266 kobj;
	struct kobject___266 *mq_kobj;
	struct blk_integrity___169 integrity;
	struct device___259 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___157 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___164 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___169 bio_split;
	struct dentry___278 *debugfs_dir;
	struct dentry___278 *sched_debugfs_dir;
	struct dentry___278 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___261 {
	struct vm_struct___261 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___283 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___278;

struct address_space___278 {
	struct inode___278 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___278 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___107 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___259 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___107 {
	u32 count;
	struct page___283 *cache[128];
};

struct page_pool___107 {
	struct page_pool_params___107 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___283 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___107 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___273;

struct dev_pagemap___273 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___273 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___278;

struct path___278 {
	struct vfsmount___278 *mnt;
	struct dentry___278 *dentry;
};

struct fown_struct___255 {
	rwlock_t lock;
	struct pid___255 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___278 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___278 f_path;
	struct inode___278 *f_inode;
	const struct file_operations___279 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___255 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___278 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___273;

struct vm_operations_struct___273 {
	void (*open)(struct vm_area_struct___283 *);
	void (*close)(struct vm_area_struct___283 *);
	int (*may_split)(struct vm_area_struct___283 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___283 *);
	int (*mprotect)(struct vm_area_struct___283 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___273 *);
	vm_fault_t (*huge_fault)(struct vm_fault___273 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___273 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___283 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___273 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___273 *);
	int (*access)(struct vm_area_struct___283 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___283 *);
	int (*set_policy)(struct vm_area_struct___283 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___283 *, long unsigned int);
	struct page___283 * (*find_special_page)(struct vm_area_struct___283 *, long unsigned int);
};

struct core_thread___283 {
	struct task_struct___285 *task;
	struct core_thread___283 *next;
};

struct core_state___283 {
	atomic_t nr_threads;
	struct core_thread___283 dumper;
	struct completion startup;
};

struct vm_fault___273 {
	const struct {
		struct vm_area_struct___283 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___283 *cow_page;
	struct page___283 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___283 prealloc_pte;
};

struct pglist_data___151;

struct lruvec___151 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___151 *pgdat;
};

struct zone___151 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___151 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___151 {
	struct zone___151 *zone;
	int zone_idx;
};

struct zonelist___151 {
	struct zoneref___151 _zonerefs[321];
};

struct pglist_data___151 {
	struct zone___151 node_zones[5];
	struct zonelist___151 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___285 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___285 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___151 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___278;

struct dentry___278 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___278 *d_parent;
	struct qstr d_name;
	struct inode___278 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___278 *d_op;
	struct super_block___278 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___278;

struct inode___278 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___278 *i_op;
	struct super_block___278 *i_sb;
	struct address_space___278 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___155 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___279 *i_fop;
		void (*free_inode)(struct inode___278 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___278 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___119 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___278 {
	int (*d_revalidate)(struct dentry___278 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___278 *, unsigned int);
	int (*d_hash)(const struct dentry___278 *, struct qstr *);
	int (*d_compare)(const struct dentry___278 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___278 *);
	int (*d_init)(struct dentry___278 *);
	void (*d_release)(struct dentry___278 *);
	void (*d_prune)(struct dentry___278 *);
	void (*d_iput)(struct dentry___278 *, struct inode___278 *);
	char * (*d_dname)(struct dentry___278 *, char *, int);
	struct vfsmount___278 * (*d_automount)(struct path___278 *);
	int (*d_manage)(const struct path___278 *, bool);
	struct dentry___278 * (*d_real)(struct dentry___278 *, const struct inode___278 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___278;

struct mem_dqinfo___278 {
	struct quota_format_type___278 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___278;

struct quota_info___278 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___278 *files[3];
	struct mem_dqinfo___278 info[3];
	const struct quota_format_ops___278 *ops[3];
};

struct rcuwait___279 {
	struct task_struct___285 *task;
};

struct percpu_rw_semaphore___279 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___279 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___278 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___279 rw_sem[3];
};

struct shrink_control___143;

struct shrinker___143 {
	long unsigned int (*count_objects)(struct shrinker___143 *, struct shrink_control___143 *);
	long unsigned int (*scan_objects)(struct shrinker___143 *, struct shrink_control___143 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___278;

struct dquot_operations___278;

struct quotactl_ops___278;

struct block_device___172;

struct super_block___278 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___278 *s_type;
	const struct super_operations___278 *s_op;
	const struct dquot_operations___278 *dq_op;
	const struct quotactl_ops___278 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___278 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___172 *s_bdev;
	struct backing_dev_info___155 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___278 s_dquot;
	struct sb_writers___278 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___278 *s_d_op;
	int cleancache_poolid;
	struct shrinker___143 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___278 {
	struct dentry___278 *mnt_root;
	struct super_block___278 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___143 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___143 *memcg;
};

struct psi_group___205 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___285 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___81;

struct cgroup_bpf___81 {
	struct bpf_prog_array___81 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___81 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___205;

struct cgroup_rstat_cpu___205;

struct cgroup___205 {
	struct cgroup_subsys_state___205 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___266 *kn;
	struct cgroup_file___205 procs_file;
	struct cgroup_file___205 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___205 *subsys[14];
	struct cgroup_root___205 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___205 *dom_cgrp;
	struct cgroup___205 *old_dom_cgrp;
	struct cgroup_rstat_cpu___205 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___205 psi;
	struct cgroup_bpf___81 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___169 {
	struct request_queue___169 *q;
	struct io_context___169 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___278 {
	struct file___278 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___278 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___278 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___278 *ia_file;
};

struct dquot___278 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___278 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___278 {
	int qf_fmt_id;
	const struct quota_format_ops___278 *qf_ops;
	struct module___262 *qf_owner;
	struct quota_format_type___278 *qf_next;
};

struct quota_format_ops___278 {
	int (*check_quota_file)(struct super_block___278 *, int);
	int (*read_file_info)(struct super_block___278 *, int);
	int (*write_file_info)(struct super_block___278 *, int);
	int (*free_file_info)(struct super_block___278 *, int);
	int (*read_dqblk)(struct dquot___278 *);
	int (*commit_dqblk)(struct dquot___278 *);
	int (*release_dqblk)(struct dquot___278 *);
	int (*get_next_id)(struct super_block___278 *, struct kqid *);
};

struct dquot_operations___278 {
	int (*write_dquot)(struct dquot___278 *);
	struct dquot___278 * (*alloc_dquot)(struct super_block___278 *, int);
	void (*destroy_dquot)(struct dquot___278 *);
	int (*acquire_dquot)(struct dquot___278 *);
	int (*release_dquot)(struct dquot___278 *);
	int (*mark_dirty)(struct dquot___278 *);
	int (*write_info)(struct super_block___278 *, int);
	qsize_t * (*get_reserved_space)(struct inode___278 *);
	int (*get_projid)(struct inode___278 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___278 *, qsize_t *);
	int (*get_next_id)(struct super_block___278 *, struct kqid *);
};

struct quotactl_ops___278 {
	int (*quota_on)(struct super_block___278 *, int, int, const struct path___278 *);
	int (*quota_off)(struct super_block___278 *, int);
	int (*quota_enable)(struct super_block___278 *, unsigned int);
	int (*quota_disable)(struct super_block___278 *, unsigned int);
	int (*quota_sync)(struct super_block___278 *, int);
	int (*set_info)(struct super_block___278 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___278 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___278 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___278 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___278 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___278 *, unsigned int);
};

struct writeback_control___155;

struct address_space_operations___278 {
	int (*writepage)(struct page___283 *, struct writeback_control___155 *);
	int (*readpage)(struct file___278 *, struct page___283 *);
	int (*writepages)(struct address_space___278 *, struct writeback_control___155 *);
	int (*set_page_dirty)(struct page___283 *);
	int (*readpages)(struct file___278 *, struct address_space___278 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___278 *, struct address_space___278 *, loff_t, unsigned int, unsigned int, struct page___283 **, void **);
	int (*write_end)(struct file___278 *, struct address_space___278 *, loff_t, unsigned int, unsigned int, struct page___283 *, void *);
	sector_t (*bmap)(struct address_space___278 *, sector_t);
	void (*invalidatepage)(struct page___283 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___283 *, gfp_t);
	void (*freepage)(struct page___283 *);
	ssize_t (*direct_IO)(struct kiocb___278 *, struct iov_iter___198 *);
	int (*migratepage)(struct address_space___278 *, struct page___283 *, struct page___283 *, enum migrate_mode);
	bool (*isolate_page)(struct page___283 *, isolate_mode_t);
	void (*putback_page)(struct page___283 *);
	int (*launder_page)(struct page___283 *);
	int (*is_partially_uptodate)(struct page___283 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___283 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___278 *, struct page___283 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___278 *, sector_t *);
	void (*swap_deactivate)(struct file___278 *);
};

struct writeback_control___155 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___155 *wb;
	struct inode___278 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___195;

struct iov_iter___198 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___195 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___119 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___278 {
	struct dentry___278 * (*lookup)(struct inode___278 *, struct dentry___278 *, unsigned int);
	const char * (*get_link)(struct dentry___278 *, struct inode___278 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___278 *, int);
	struct posix_acl * (*get_acl)(struct inode___278 *, int, bool);
	int (*readlink)(struct dentry___278 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___278 *, struct dentry___278 *, umode_t, bool);
	int (*link)(struct dentry___278 *, struct inode___278 *, struct dentry___278 *);
	int (*unlink)(struct inode___278 *, struct dentry___278 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___278 *, struct dentry___278 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___278 *, struct dentry___278 *, umode_t);
	int (*rmdir)(struct inode___278 *, struct dentry___278 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___278 *, struct dentry___278 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___278 *, struct dentry___278 *, struct inode___278 *, struct dentry___278 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___278 *, struct iattr___278 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___278 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___278 *, char *, size_t);
	int (*fiemap)(struct inode___278 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___278 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___278 *, struct dentry___278 *, struct file___278 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___278 *, struct dentry___278 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___278 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___278 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___278 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___278 {
	void (*fl_copy_lock)(struct file_lock___278 *, struct file_lock___278 *);
	void (*fl_release_private)(struct file_lock___278 *);
};

struct lock_manager_operations___278;

struct file_lock___278 {
	struct file_lock___278 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___278 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___278 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___278 *fl_ops;
	const struct lock_manager_operations___278 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___278 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___278 *);
	int (*lm_grant)(struct file_lock___278 *, int);
	bool (*lm_break)(struct file_lock___278 *);
	int (*lm_change)(struct file_lock___278 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___278 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___278 *);
};

struct fasync_struct___278 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___278 *fa_next;
	struct file___278 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___278 {
	struct inode___278 * (*alloc_inode)(struct super_block___278 *);
	void (*destroy_inode)(struct inode___278 *);
	void (*free_inode)(struct inode___278 *);
	void (*dirty_inode)(struct inode___278 *, int);
	int (*write_inode)(struct inode___278 *, struct writeback_control___155 *);
	int (*drop_inode)(struct inode___278 *);
	void (*evict_inode)(struct inode___278 *);
	void (*put_super)(struct super_block___278 *);
	int (*sync_fs)(struct super_block___278 *, int);
	int (*freeze_super)(struct super_block___278 *);
	int (*freeze_fs)(struct super_block___278 *);
	int (*thaw_super)(struct super_block___278 *);
	int (*unfreeze_fs)(struct super_block___278 *);
	int (*statfs)(struct dentry___278 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___278 *, int *, char *);
	void (*umount_begin)(struct super_block___278 *);
	int (*show_options)(struct seq_file___253 *, struct dentry___278 *);
	int (*show_devname)(struct seq_file___253 *, struct dentry___278 *);
	int (*show_path)(struct seq_file___253 *, struct dentry___278 *);
	int (*show_stats)(struct seq_file___253 *, struct dentry___278 *);
	ssize_t (*quota_read)(struct super_block___278 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___278 *, int, const char *, size_t, loff_t);
	struct dquot___278 ** (*get_dquots)(struct inode___278 *);
	long int (*nr_cached_objects)(struct super_block___278 *, struct shrink_control___143 *);
	long int (*free_cached_objects)(struct super_block___278 *, struct shrink_control___143 *);
	struct file___278 * (*real_loop)(struct file___278 *);
};

struct wakeup_source___259;

struct dev_pm_info___259 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___259 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___259 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___259;

struct bus_type___259;

struct device_driver___259;

struct dev_pm_domain___259;

struct fwnode_handle___255;

struct class___259;

struct attribute_group___266;

struct device___259 {
	struct kobject___266 kobj;
	struct device___259 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___259 *type;
	struct bus_type___259 *bus;
	struct device_driver___259 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___259 power;
	struct dev_pm_domain___259 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___255 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___259 *class;
	const struct attribute_group___266 **groups;
	void (*release)(struct device___259 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___172 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___278 *bd_inode;
	struct super_block___278 *bd_super;
	void *bd_claiming;
	struct device___259 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___266 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___172 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___278 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___207)(struct file___278 *, wait_queue_head_t *, struct poll_table_struct___199 *);

struct poll_table_struct___199 {
	poll_queue_proc___207 _qproc;
	__poll_t _key;
};

struct seq_operations___253;

struct seq_file___253 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___253 *op;
	int poll_event;
	const struct file___278 *file;
	void *private;
};

typedef void bio_end_io_t___169(struct bio___169 *);

struct bio_vec___195 {
	struct page___283 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___169;

struct bio___169 {
	struct bio___169 *bi_next;
	struct block_device___172 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___169 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___157 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___169 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___195 *bi_io_vec;
	struct bio_set___169 *bi_pool;
	struct bio_vec___195 bi_inline_vecs[0];
};

struct kernfs_root___266;

struct kernfs_elem_dir___266 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___266 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___266;

struct kernfs_root___266 {
	struct kernfs_node___266 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___266 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___266 {
	struct kernfs_node___266 *target_kn;
};

struct kernfs_ops___266;

struct kernfs_elem_attr___266 {
	const struct kernfs_ops___266 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___266 *notify_next;
};

struct kernfs_node___266 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___266 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___266 dir;
		struct kernfs_elem_symlink___266 symlink;
		struct kernfs_elem_attr___266 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___266;

struct kernfs_ops___266 {
	int (*open)(struct kernfs_open_file___266 *);
	void (*release)(struct kernfs_open_file___266 *);
	int (*seq_show)(struct seq_file___253 *, void *);
	void * (*seq_start)(struct seq_file___253 *, loff_t *);
	void * (*seq_next)(struct seq_file___253 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___253 *, void *);
	ssize_t (*read)(struct kernfs_open_file___266 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___266 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___266 *, struct poll_table_struct___199 *);
	int (*mmap)(struct kernfs_open_file___266 *, struct vm_area_struct___283 *);
};

struct kernfs_syscall_ops___266 {
	int (*show_options)(struct seq_file___253 *, struct kernfs_root___266 *);
	int (*mkdir)(struct kernfs_node___266 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___266 *);
	int (*rename)(struct kernfs_node___266 *, struct kernfs_node___266 *, const char *);
	int (*show_path)(struct seq_file___253 *, struct kernfs_node___266 *, struct kernfs_root___266 *);
};

struct kernfs_open_file___266 {
	struct kernfs_node___266 *kn;
	struct file___278 *file;
	struct seq_file___253 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___273 *vm_ops;
};

struct sock___74;

struct kobj_ns_type_operations___74 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___74 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___92 *net;
} possible_net_t___87;

struct proto___74;

struct sock_common___74 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___74 *skc_prot;
	possible_net_t___87 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___74 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___88;

struct sk_buff_head___87 {
	struct sk_buff___88 *next;
	struct sk_buff___88 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___74 {
	struct cgroup___205 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___74;

struct socket_wq___75;

struct dst_entry___74;

struct socket___76;

struct net_device___87;

struct sock___74 {
	struct sock_common___74 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___87 sk_error_queue;
	struct sk_buff___88 *sk_rx_skb_cache;
	struct sk_buff_head___87 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___88 *head;
		struct sk_buff___88 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___74 *sk_filter;
	union {
		struct socket_wq___75 *sk_wq;
		struct socket_wq___75 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___74 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___74 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___88 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___88 *sk_tx_skb_cache;
	struct sk_buff_head___87 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___283 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___74 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___255 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___76 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___74 sk_cgrp_data;
	struct mem_cgroup___143 *sk_memcg;
	void (*sk_state_change)(struct sock___74 *);
	void (*sk_data_ready)(struct sock___74 *);
	void (*sk_write_space)(struct sock___74 *);
	void (*sk_error_report)(struct sock___74 *);
	int (*sk_backlog_rcv)(struct sock___74 *, struct sk_buff___88 *);
	struct sk_buff___88 * (*sk_validate_xmit_skb)(struct sock___74 *, struct net_device___87 *, struct sk_buff___88 *);
	void (*sk_destruct)(struct sock___74 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___266;

struct attribute_group___266 {
	const char *name;
	umode_t (*is_visible)(struct kobject___266 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___266 *, struct bin_attribute___266 *, int);
	struct attribute **attrs;
	struct bin_attribute___266 **bin_attrs;
};

struct bin_attribute___266 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___278 * (*f_mapping)();
	ssize_t (*read)(struct file___278 *, struct kobject___266 *, struct bin_attribute___266 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___278 *, struct kobject___266 *, struct bin_attribute___266 *, char *, loff_t, size_t);
	int (*mmap)(struct file___278 *, struct kobject___266 *, struct bin_attribute___266 *, struct vm_area_struct___283 *);
};

struct sysfs_ops___266 {
	ssize_t (*show)(struct kobject___266 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___266 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___266;

struct kset___266 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___266 kobj;
	const struct kset_uevent_ops___266 *uevent_ops;
};

struct kobj_type___266 {
	void (*release)(struct kobject___266 *);
	const struct sysfs_ops___266 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___266 **default_groups;
	const struct kobj_ns_type_operations___74 * (*child_ns_type)(struct kobject___266 *);
	const void * (*namespace)(struct kobject___266 *);
	void (*get_ownership)(struct kobject___266 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___266 {
	int (* const filter)(struct kset___266 *, struct kobject___266 *);
	const char * (* const name)(struct kset___266 *, struct kobject___266 *);
	int (* const uevent)(struct kset___266 *, struct kobject___266 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___262 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___262 *);
	int (*get)(char *, const struct kernel_param___262 *);
	void (*free)(void *);
};

struct kparam_array___262;

struct kernel_param___262 {
	const char *name;
	struct module___262 *mod;
	const struct kernel_param_ops___262 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___262 *arr;
	};
};

struct kparam_array___262 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___262 *ops;
	void *elem;
};

struct module_attribute___262 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___262 *, struct module_kobject___263 *, char *);
	ssize_t (*store)(struct module_attribute___262 *, struct module_kobject___263 *, const char *, size_t);
	void (*setup)(struct module___262 *, const char *);
	int (*test)(struct module___262 *);
	void (*free)(struct module___262 *);
};

struct msghdr___76 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___198 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___278 *msg_iocb;
};

struct sk_buff___88 {
	union {
		struct {
			struct sk_buff___88 *next;
			struct sk_buff___88 *prev;
			union {
				struct net_device___87 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___74 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___88 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___92;

struct fqdir___92 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___92 *f;
	struct net___92 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___92;

struct inet_frags___92 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___92 *, const void *);
	void (*destructor)(struct inet_frag_queue___92 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___47;

struct fib_rules_ops___74;

struct fib_notifier_ops___74;

struct netns_ipv4___92 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___47 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___74 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___74 *fibnl;
	struct sock___74 **icmp_sk;
	struct sock___74 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___74 **tcp_sk;
	struct fqdir___92 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___74 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___74 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___74 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___74;

struct dst_ops___92 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___92 *);
	struct dst_entry___74 * (*check)(struct dst_entry___74 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___74 *);
	unsigned int (*mtu)(const struct dst_entry___74 *);
	u32 * (*cow_metrics)(struct dst_entry___74 *, long unsigned int);
	void (*destroy)(struct dst_entry___74 *);
	void (*ifdown)(struct dst_entry___74 *, struct net_device___87 *, int);
	struct dst_entry___74 * (*negative_advice)(struct dst_entry___74 *);
	void (*link_failure)(struct sk_buff___88 *);
	void (*update_pmtu)(struct dst_entry___74 *, struct sock___74 *, struct sk_buff___88 *, u32, bool);
	void (*redirect)(struct dst_entry___74 *, struct sock___74 *, struct sk_buff___88 *);
	int (*local_out)(struct net___92 *, struct sock___74 *, struct sk_buff___88 *);
	struct neighbour___74 * (*neigh_lookup)(const struct dst_entry___74 *, struct sk_buff___88 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___74 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___92 {
	struct dst_ops___92 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___92 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___74 *fib6_rules_ops;
	struct sock___74 **icmp_sk;
	struct sock___74 *ndisc_sk;
	struct sock___74 *tcp_sk;
	struct sock___74 *igmp_sk;
	struct sock___74 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___74 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___74 *notifier_ops;
	struct fib_notifier_ops___74 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___92 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___92 *fqdir;
};

struct netns_sctp___74 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___74 *ctl_sock;
	struct sock___74 *udp4_sock;
	struct sock___74 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___15;

struct netns_nf___15 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___15 *hooks_ipv4[5];
	struct nf_hook_entries___15 *hooks_ipv6[5];
	struct nf_hook_entries___15 *hooks_arp[3];
	struct nf_hook_entries___15 *hooks_bridge[5];
	struct nf_hook_entries___15 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___81;

struct netns_bpf___81 {
	struct bpf_prog_array___81 *run_array[2];
	struct bpf_prog___81 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___92 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___74 *nlsk;
	struct sock___74 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___92 xfrm4_dst_ops;
	struct dst_ops___92 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___92 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___74 *rtnl;
	struct sock___74 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___87 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___92 ipv4;
	struct netns_ipv6___92 ipv6;
	struct netns_ieee802154_lowpan___92 ieee802154_lowpan;
	struct netns_sctp___74 sctp;
	struct netns_nf___15 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___87 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___81 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___92 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___74 *crypto_nlsk;
	struct sock___74 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___92 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___88 *fragments_tail;
	struct sk_buff___88 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___92 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___47 {
	struct ip_ra_chain___47 *next;
	struct sock___74 *sk;
	union {
		void (*destructor)(struct sock___74 *);
		struct sock___74 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___74;

struct fib_lookup_arg___74;

struct fib_rules_ops___74 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___74 *, struct flowi *, int, struct fib_lookup_arg___74 *);
	bool (*suppress)(struct fib_rule___74 *, int, struct fib_lookup_arg___74 *);
	int (*match)(struct fib_rule___74 *, struct flowi *, int);
	int (*configure)(struct fib_rule___74 *, struct sk_buff___88 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___74 *);
	int (*compare)(struct fib_rule___74 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___74 *, struct sk_buff___88 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___74 *);
	void (*flush_cache)(struct fib_rules_ops___74 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___262 *owner;
	struct net___92 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___74 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___92 *);
	int (*fib_dump)(struct net___92 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___262 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___50;

struct dst_entry___74 {
	struct net_device___87 *dev;
	struct dst_ops___92 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___88 *);
	int (*output)(struct net___92 *, struct sock___74 *, struct sk_buff___88 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___50 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___87(struct sk_buff___88 **);

struct bpf_xdp_entity___81 {
	struct bpf_prog___81 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___87;

struct net_device_ops___87;

struct l3mdev_ops___74;

struct ndisc_ops___56;

struct xfrmdev_ops___87;

struct header_ops___87;

struct in_device___15;

struct inet6_dev___56;

struct netdev_rx_queue___87;

struct mini_Qdisc___81;

struct netdev_queue___87;

struct Qdisc___81;

struct rtnl_link_ops___81;

struct dcbnl_rtnl_ops___87;

struct net_device___87 {
	char name[16];
	struct netdev_name_node___87 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___87 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___74 *l3mdev_ops;
	const struct ndisc_ops___56 *ndisc_ops;
	const struct xfrmdev_ops___87 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___87 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___266 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___15 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___56 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___87 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___81 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___87 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___81 *miniq_ingress;
	struct netdev_queue___87 *ingress_queue;
	struct nf_hook_entries___15 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___87 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___81 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___81 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___87 = 0,
		NETREG_REGISTERED___87 = 1,
		NETREG_UNREGISTERING___87 = 2,
		NETREG_UNREGISTERED___87 = 3,
		NETREG_RELEASED___87 = 4,
		NETREG_DUMMY___87 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___87 = 0,
		RTNL_LINK_INITIALIZING___87 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___87 *);
	struct netpoll_info *npinfo;
	possible_net_t___87 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___259 dev;
	const struct attribute_group___266 *sysfs_groups[4];
	const struct attribute_group___266 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___81 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___87 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___81 xdp_state[3];
	long: 64;
};

struct neigh_table___74;

struct neigh_parms___74;

struct neigh_ops___74;

struct neighbour___74 {
	struct neighbour___74 *next;
	struct neigh_table___74 *tbl;
	struct neigh_parms___74 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___87 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___74 *, struct sk_buff___88 *);
	const struct neigh_ops___74 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___87 *dev;
	u8 primary_key[0];
};

struct nf_hook_state___15;

typedef unsigned int nf_hookfn___17(void *, struct sk_buff___88 *, const struct nf_hook_state___15 *);

struct nf_hook_entry___15 {
	nf_hookfn___17 *hook;
	void *priv;
};

struct nf_hook_entries___15 {
	u16 num_hook_entries;
	struct nf_hook_entry___15 hooks[0];
};

struct bpf_prog_array_item___81 {
	struct bpf_prog___81 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___81 {
	struct callback_head rcu;
	struct bpf_prog_array_item___81 items[0];
};

struct bpf_prog_aux___90;

struct bpf_prog___81 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___90 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dev_pagemap_ops___273 {
	void (*page_free)(struct page___283 *);
	void (*kill)(struct dev_pagemap___273 *);
	void (*cleanup)(struct dev_pagemap___273 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___273 *);
};

struct fwnode_operations___255;

struct fwnode_handle___255 {
	struct fwnode_handle___255 *secondary;
	const struct fwnode_operations___255 *ops;
	struct device___259 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___255;

struct fwnode_endpoint___255;

struct fwnode_operations___255 {
	struct fwnode_handle___255 * (*get)(struct fwnode_handle___255 *);
	void (*put)(struct fwnode_handle___255 *);
	bool (*device_is_available)(const struct fwnode_handle___255 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___255 *, const struct device___259 *);
	bool (*property_present)(const struct fwnode_handle___255 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___255 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___255 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___255 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*get_parent)(const struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*get_next_child_node)(const struct fwnode_handle___255 *, struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*get_named_child_node)(const struct fwnode_handle___255 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___255 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___255 *);
	struct fwnode_handle___255 * (*graph_get_next_endpoint)(const struct fwnode_handle___255 *, struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*graph_get_remote_endpoint)(const struct fwnode_handle___255 *);
	struct fwnode_handle___255 * (*graph_get_port_parent)(struct fwnode_handle___255 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___255 *, struct fwnode_endpoint___255 *);
	int (*add_links)(struct fwnode_handle___255 *);
};

struct fwnode_endpoint___255 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___255 *local_fwnode;
};

struct fwnode_reference_args___255 {
	struct fwnode_handle___255 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___205 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___205 *root_cset;
};

struct socket_wq___75 {
	wait_queue_head_t wait;
	struct fasync_struct___278 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___75;

struct socket___76 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___278 *file;
	struct sock___74 *sk;
	const struct proto_ops___75 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___75 wq;
};

typedef int (*sk_read_actor_t___74)(read_descriptor_t *, struct sk_buff___88 *, unsigned int, size_t);

struct proto_ops___75 {
	int family;
	struct module___262 *owner;
	int (*release)(struct socket___76 *);
	int (*bind)(struct socket___76 *, struct sockaddr *, int);
	int (*connect)(struct socket___76 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___76 *, struct socket___76 *);
	int (*accept)(struct socket___76 *, struct socket___76 *, int, bool);
	int (*getname)(struct socket___76 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___278 *, struct socket___76 *, struct poll_table_struct___199 *);
	int (*ioctl)(struct socket___76 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___76 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___76 *, void *, bool, bool);
	int (*listen)(struct socket___76 *, int);
	int (*shutdown)(struct socket___76 *, int);
	int (*setsockopt)(struct socket___76 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___76 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___253 *, struct socket___76 *);
	int (*sendmsg)(struct socket___76 *, struct msghdr___76 *, size_t);
	int (*recvmsg)(struct socket___76 *, struct msghdr___76 *, size_t, int);
	int (*mmap)(struct file___278 *, struct socket___76 *, struct vm_area_struct___283 *);
	ssize_t (*sendpage)(struct socket___76 *, struct page___283 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___76 *, loff_t *, struct pipe_inode_info___119 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___74 *, int);
	int (*peek_len)(struct socket___76 *);
	int (*read_sock)(struct sock___74 *, read_descriptor_t *, sk_read_actor_t___74);
	int (*sendpage_locked)(struct sock___74 *, struct page___283 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___74 *, struct msghdr___76 *, size_t);
	int (*set_rcvlowat)(struct sock___74 *, int);
};

struct dev_pm_ops___259 {
	int (*prepare)(struct device___259 *);
	void (*complete)(struct device___259 *);
	int (*suspend)(struct device___259 *);
	int (*resume)(struct device___259 *);
	int (*freeze)(struct device___259 *);
	int (*thaw)(struct device___259 *);
	int (*poweroff)(struct device___259 *);
	int (*restore)(struct device___259 *);
	int (*suspend_late)(struct device___259 *);
	int (*resume_early)(struct device___259 *);
	int (*freeze_late)(struct device___259 *);
	int (*thaw_early)(struct device___259 *);
	int (*poweroff_late)(struct device___259 *);
	int (*restore_early)(struct device___259 *);
	int (*suspend_noirq)(struct device___259 *);
	int (*resume_noirq)(struct device___259 *);
	int (*freeze_noirq)(struct device___259 *);
	int (*thaw_noirq)(struct device___259 *);
	int (*poweroff_noirq)(struct device___259 *);
	int (*restore_noirq)(struct device___259 *);
	int (*runtime_suspend)(struct device___259 *);
	int (*runtime_resume)(struct device___259 *);
	int (*runtime_idle)(struct device___259 *);
};

struct wakeup_source___259 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___259 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___259 {
	struct dev_pm_ops___259 ops;
	int (*start)(struct device___259 *);
	void (*detach)(struct device___259 *, bool);
	int (*activate)(struct device___259 *);
	void (*sync)(struct device___259 *);
	void (*dismiss)(struct device___259 *);
};

struct bus_type___259 {
	const char *name;
	const char *dev_name;
	struct device___259 *dev_root;
	const struct attribute_group___266 **bus_groups;
	const struct attribute_group___266 **dev_groups;
	const struct attribute_group___266 **drv_groups;
	int (*match)(struct device___259 *, struct device_driver___259 *);
	int (*uevent)(struct device___259 *, struct kobj_uevent_env *);
	int (*probe)(struct device___259 *);
	void (*sync_state)(struct device___259 *);
	void (*remove)(struct device___259 *);
	void (*shutdown)(struct device___259 *);
	int (*online)(struct device___259 *);
	int (*offline)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	int (*num_vf)(struct device___259 *);
	int (*dma_configure)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___259 {
	const char *name;
	struct bus_type___259 *bus;
	struct module___262 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___259 *);
	void (*sync_state)(struct device___259 *);
	int (*remove)(struct device___259 *);
	void (*shutdown)(struct device___259 *);
	int (*suspend)(struct device___259 *, pm_message_t);
	int (*resume)(struct device___259 *);
	const struct attribute_group___266 **groups;
	const struct attribute_group___266 **dev_groups;
	const struct dev_pm_ops___259 *pm;
	void (*coredump)(struct device___259 *);
	struct driver_private *p;
};

struct device_type___259 {
	const char *name;
	const struct attribute_group___266 **groups;
	int (*uevent)(struct device___259 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___259 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___259 *);
	const struct dev_pm_ops___259 *pm;
};

struct class___259 {
	const char *name;
	struct module___262 *owner;
	const struct attribute_group___266 **class_groups;
	const struct attribute_group___266 **dev_groups;
	struct kobject___266 *dev_kobj;
	int (*dev_uevent)(struct device___259 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___259 *, umode_t *);
	void (*class_release)(struct class___259 *);
	void (*dev_release)(struct device___259 *);
	int (*shutdown_pre)(struct device___259 *);
	const struct kobj_ns_type_operations___74 *ns_type;
	const void * (*namespace)(struct device___259 *);
	void (*get_ownership)(struct device___259 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___259 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___119;

struct pipe_buffer___119 {
	struct page___283 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___119 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___119 {
	int (*confirm)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
	void (*release)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
	bool (*try_steal)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
	bool (*get)(struct pipe_inode_info___119 *, struct pipe_buffer___119 *);
};

struct seq_operations___253 {
	void * (*start)(struct seq_file___253 *, loff_t *);
	void (*stop)(struct seq_file___253 *, void *);
	void * (*next)(struct seq_file___253 *, void *, loff_t *);
	int (*show)(struct seq_file___253 *, void *);
};

struct seq_net_private___10 {
	struct net___92 *net;
};

struct pernet_operations___28 {
	struct list_head list;
	int (*init)(struct net___92 *);
	void (*pre_exit)(struct net___92 *);
	void (*exit)(struct net___92 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___87 {
	int (*ieee_getets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___87 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___87 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___87 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___87 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___87 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___87 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___87 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___87 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___87 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___87 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___87 *);
	u8 (*setstate)(struct net_device___87 *, u8);
	void (*getpermhwaddr)(struct net_device___87 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___87 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___87 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___87 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___87 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___87 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___87 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___87 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___87 *, int, u8 *);
	void (*setpfccfg)(struct net_device___87 *, int, u8);
	void (*getpfccfg)(struct net_device___87 *, int, u8 *);
	u8 (*setall)(struct net_device___87 *);
	u8 (*getcap)(struct net_device___87 *, int, u8 *);
	int (*getnumtcs)(struct net_device___87 *, int, u8 *);
	int (*setnumtcs)(struct net_device___87 *, int, u8);
	u8 (*getpfcstate)(struct net_device___87 *);
	void (*setpfcstate)(struct net_device___87 *, u8);
	void (*getbcncfg)(struct net_device___87 *, int, u32 *);
	void (*setbcncfg)(struct net_device___87 *, int, u32);
	void (*getbcnrp)(struct net_device___87 *, int, u8 *);
	void (*setbcnrp)(struct net_device___87 *, int, u8);
	int (*setapp)(struct net_device___87 *, u8, u16, u8);
	int (*getapp)(struct net_device___87 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___87 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___87 *, int, u8);
	u8 (*getdcbx)(struct net_device___87 *);
	u8 (*setdcbx)(struct net_device___87 *, u8);
	int (*peer_getappinfo)(struct net_device___87 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___87 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___87 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___87 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___87 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___87 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___90;

typedef int (*bpf_iter_init_seq_priv_t___89)(void *, struct bpf_iter_aux_info___90 *);

struct bpf_map___90;

struct bpf_iter_aux_info___90 {
	struct bpf_map___90 *map;
};

struct bpf_iter_seq_info___89 {
	const struct seq_operations___253 *seq_ops;
	bpf_iter_init_seq_priv_t___89 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___89 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___90 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___90 *, struct file___278 *);
	void (*map_free)(struct bpf_map___90 *);
	int (*map_get_next_key)(struct bpf_map___90 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___90 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___90 *, void *);
	int (*map_lookup_batch)(struct bpf_map___90 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___90 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___90 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___90 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___90 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___90 *, void *);
	int (*map_update_elem)(struct bpf_map___90 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___90 *, void *);
	int (*map_push_elem)(struct bpf_map___90 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___90 *, void *);
	int (*map_peek_elem)(struct bpf_map___90 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___90 *, struct file___278 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___90 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___90 *, void *, struct seq_file___253 *);
	int (*map_check_btf)(const struct bpf_map___90 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___90 *, struct bpf_prog_aux___90 *);
	void (*map_poke_untrack)(struct bpf_map___90 *, struct bpf_prog_aux___90 *);
	void (*map_poke_run)(struct bpf_map___90 *, u32, struct bpf_prog___81 *, struct bpf_prog___81 *);
	int (*map_direct_value_addr)(const struct bpf_map___90 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___90 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___90 *, struct vm_area_struct___283 *);
	__poll_t (*map_poll)(struct bpf_map___90 *, struct file___278 *, struct poll_table_struct___199 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___90 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___90 *, const struct bpf_map___90 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___90 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___89 *iter_seq_info;
};

struct bpf_map___90 {
	const struct bpf_map_ops___89 *ops;
	struct bpf_map___90 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___143 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___89;

struct bpf_jit_poke_descriptor___89;

struct bpf_prog_ops___81;

struct btf_mod_pair___89;

struct bpf_prog_offload___87;

struct bpf_prog_aux___90 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___81 *dst_prog;
	struct bpf_trampoline___89 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___81 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___89 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___81 *ops;
	struct bpf_map___90 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___89 *used_btfs;
	struct bpf_prog___81 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___90 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___87 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___87;

struct bpf_map_dev_ops___87 {
	int (*map_get_next_key)(struct bpf_offloaded_map___87 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___87 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___87 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___87 *, void *);
};

struct bpf_offloaded_map___87 {
	struct bpf_map___90 map;
	struct net_device___87 *netdev;
	const struct bpf_map_dev_ops___87 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___81 {
	int (*test_run)(struct bpf_prog___81 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___87 {
	struct bpf_prog___81 *prog;
	struct net_device___87 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___89 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___81 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___262 *mod;
};

struct bpf_jit_poke_descriptor___89 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___90 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___89 {
	struct btf *btf;
	struct module___262 *module;
};

struct cftype___205;

struct cgroup_subsys___205 {
	struct cgroup_subsys_state___205 * (*css_alloc)(struct cgroup_subsys_state___205 *);
	int (*css_online)(struct cgroup_subsys_state___205 *);
	void (*css_offline)(struct cgroup_subsys_state___205 *);
	void (*css_released)(struct cgroup_subsys_state___205 *);
	void (*css_free)(struct cgroup_subsys_state___205 *);
	void (*css_reset)(struct cgroup_subsys_state___205 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___205 *, int);
	int (*css_extra_stat_show)(struct seq_file___253 *, struct cgroup_subsys_state___205 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___285 *, struct css_set___205 *);
	void (*cancel_fork)(struct task_struct___285 *, struct css_set___205 *);
	void (*fork)(struct task_struct___285 *);
	void (*exit)(struct task_struct___285 *);
	void (*release)(struct task_struct___285 *);
	void (*bind)(struct cgroup_subsys_state___205 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___205 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___205 *dfl_cftypes;
	struct cftype___205 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___205 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___205 *updated_children;
	struct cgroup___205 *updated_next;
};

struct cgroup_root___205 {
	struct kernfs_root___266 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___205 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___205 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___205 *ss;
	struct list_head node;
	struct kernfs_ops___266 *kf_ops;
	int (*open)(struct kernfs_open_file___266 *);
	void (*release)(struct kernfs_open_file___266 *);
	u64 (*read_u64)(struct cgroup_subsys_state___205 *, struct cftype___205 *);
	s64 (*read_s64)(struct cgroup_subsys_state___205 *, struct cftype___205 *);
	int (*seq_show)(struct seq_file___253 *, void *);
	void * (*seq_start)(struct seq_file___253 *, loff_t *);
	void * (*seq_next)(struct seq_file___253 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___253 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___205 *, struct cftype___205 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___205 *, struct cftype___205 *, s64);
	ssize_t (*write)(struct kernfs_open_file___266 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___266 *, struct poll_table_struct___199 *);
};

struct xdp_rxq_info___87 {
	struct net_device___87 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___87 {
	struct net_device___87 *dev;
};

struct xdp_buff___87 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___87 *rxq;
	struct xdp_txq_info___87 *txq;
	u32 frame_sz;
};

struct xdp_frame___87 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___87 *dev_rx;
};

struct netlink_callback___87 {
	struct sk_buff___88 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___88 *, struct netlink_callback___87 *);
	int (*done)(struct netlink_callback___87 *);
	void *data;
	struct module___262 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___87 {
	int (*create)(struct sk_buff___88 *, struct net_device___87 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___88 *, unsigned char *);
	int (*cache)(const struct neighbour___74 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___87 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___88 *);
};

struct netdev_queue___87 {
	struct net_device___87 *dev;
	struct Qdisc___81 *qdisc;
	struct Qdisc___81 *qdisc_sleeping;
	struct kobject___266 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___87 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___81 {
	struct sk_buff___88 *head;
	struct sk_buff___88 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___81;

struct Qdisc___81 {
	int (*enqueue)(struct sk_buff___88 *, struct Qdisc___81 *, struct sk_buff___88 **);
	struct sk_buff___88 * (*dequeue)(struct Qdisc___81 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___81 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___87 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___87 gso_skb;
	struct qdisc_skb_head___81 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___81 *next_sched;
	struct sk_buff_head___87 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___87 {
	struct xdp_rxq_info___87 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___266 kobj;
	struct net_device___87 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___87 {
	enum net_device_path_type type;
	const struct net_device___87 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___87 = 0,
				DEV_PATH_BR_VLAN_TAG___87 = 1,
				DEV_PATH_BR_VLAN_UNTAG___87 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___87 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___87 {
	const struct net_device___87 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___87 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___81 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___87 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___87 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___88 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___87 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___87 *dev;
	const char *name;
};

struct net_device_ops___87 {
	int (*ndo_init)(struct net_device___87 *);
	void (*ndo_uninit)(struct net_device___87 *);
	int (*ndo_open)(struct net_device___87 *);
	int (*ndo_stop)(struct net_device___87 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___88 *, struct net_device___87 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___88 *, struct net_device___87 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___87 *, struct sk_buff___88 *, struct net_device___87 *);
	void (*ndo_change_rx_flags)(struct net_device___87 *, int);
	void (*ndo_set_rx_mode)(struct net_device___87 *);
	int (*ndo_set_mac_address)(struct net_device___87 *, void *);
	int (*ndo_validate_addr)(struct net_device___87 *);
	int (*ndo_do_ioctl)(struct net_device___87 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___87 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___87 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___87 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___87 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___87 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___87 *, int);
	int (*ndo_neigh_setup)(struct net_device___87 *, struct neigh_parms___74 *);
	void (*ndo_tx_timeout)(struct net_device___87 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___87 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___87 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___87 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___87 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___87 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___87 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___87 *);
	int (*ndo_netpoll_setup)(struct net_device___87 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___87 *);
	int (*ndo_set_vf_mac)(struct net_device___87 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___87 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___87 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___87 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___87 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___87 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___87 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___87 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___87 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___87 *, int, struct sk_buff___88 *);
	int (*ndo_get_vf_guid)(struct net_device___87 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___87 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___87 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___87 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___87 *);
	int (*ndo_fcoe_disable)(struct net_device___87 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___87 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___87 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___87 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___87 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___87 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___87 *, const struct sk_buff___88 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___87 *, struct net_device___87 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___87 *, struct net_device___87 *);
	struct net_device___87 * (*ndo_get_xmit_slave)(struct net_device___87 *, struct sk_buff___88 *, bool);
	struct net_device___87 * (*ndo_sk_get_lower_dev)(struct net_device___87 *, struct sock___74 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___87 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___87 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___87 *, struct neighbour___74 *);
	void (*ndo_neigh_destroy)(struct net_device___87 *, struct neighbour___74 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___88 *, struct netlink_callback___87 *, struct net_device___87 *, struct net_device___87 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___88 *, struct nlattr **, struct net_device___87 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___87 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___88 *, u32, u32, struct net_device___87 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___87 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___87 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___87 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___87 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___87 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___87 *, struct net_device___87 *);
	void (*ndo_dfwd_del_station)(struct net_device___87 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___87 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___87 *);
	int (*ndo_change_proto_down)(struct net_device___87 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___87 *, struct sk_buff___88 *);
	void (*ndo_set_rx_headroom)(struct net_device___87 *, int);
	int (*ndo_bpf)(struct net_device___87 *, struct netdev_bpf___87 *);
	int (*ndo_xdp_xmit)(struct net_device___87 *, int, struct xdp_frame___87 **, u32);
	struct net_device___87 * (*ndo_xdp_get_xmit_slave)(struct net_device___87 *, struct xdp_buff___87 *);
	int (*ndo_xsk_wakeup)(struct net_device___87 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___87 *);
	int (*ndo_tunnel_ctl)(struct net_device___87 *, struct ip_tunnel_parm *, int);
	struct net_device___87 * (*ndo_get_peer_dev)(struct net_device___87 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___87 *, struct net_device_path___87 *);
};

struct neigh_parms___74 {
	possible_net_t___87 net;
	struct net_device___87 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___74 *);
	struct neigh_table___74 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___74 {
	u32 (*l3mdev_fib_table)(const struct net_device___87 *);
	struct sk_buff___88 * (*l3mdev_l3_rcv)(struct net_device___87 *, struct sk_buff___88 *, u16);
	struct sk_buff___88 * (*l3mdev_l3_out)(struct net_device___87 *, struct sock___74 *, struct sk_buff___88 *, u16);
	struct dst_entry___74 * (*l3mdev_link_scope_lookup)(const struct net_device___87 *, struct flowi6 *);
};

struct ndisc_ops___56 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___87 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___87 *, struct neighbour___74 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___87 *, u8, struct neighbour___74 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___87 *, struct sk_buff___88 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___92 *, struct net_device___87 *, const struct prefix_info *, struct inet6_dev___56 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___15;

struct ip_mc_list___5;

struct in_device___15 {
	struct net_device___87 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___15 *ifa_list;
	struct ip_mc_list___5 *mc_list;
	struct ip_mc_list___5 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___5 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___74 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___56;

struct inet6_dev___56 {
	struct net_device___87 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___56 *mc_list;
	struct ifmcaddr6___56 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___87 mc_query_queue;
	struct sk_buff_head___87 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___22 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___74 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___81;

struct tcf_block___81;

struct mini_Qdisc___81 {
	struct tcf_proto___81 *filter_list;
	struct tcf_block___81 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___81 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___87 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___87 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___92 *, struct net_device___87 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___87 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___87 *, struct list_head *);
	size_t (*get_size)(const struct net_device___87 *);
	int (*fill_info)(struct sk_buff___88 *, const struct net_device___87 *);
	size_t (*get_xstats_size)(const struct net_device___87 *);
	int (*fill_xstats)(struct sk_buff___88 *, const struct net_device___87 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___87 *, struct net_device___87 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___87 *, const struct net_device___87 *);
	int (*fill_slave_info)(struct sk_buff___88 *, const struct net_device___87 *, const struct net_device___87 *);
	struct net___92 * (*get_link_net)(const struct net_device___87 *);
	size_t (*get_linkxstats_size)(const struct net_device___87 *, int);
	int (*fill_linkxstats)(struct sk_buff___88 *, const struct net_device___87 *, int *, int);
};

struct netdev_notifier_info___15 {
	struct net_device___87 *dev;
	struct netlink_ext_ack *extack;
};

struct in_ifaddr___15 {
	struct hlist_node hash;
	struct in_ifaddr___15 *ifa_next;
	struct in_device___15 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_mc_list___5 {
	struct in_device___15 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___5 *next;
		struct ip_mc_list___5 *next_rcu;
	};
	struct ip_mc_list___5 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct igmphdr {
	__u8 type;
	__u8 code;
	__sum16 csum;
	__be32 group;
};

struct igmpv3_grec {
	__u8 grec_type;
	__u8 grec_auxwords;
	__be16 grec_nsrcs;
	__be32 grec_mca;
	__be32 grec_src[0];
};

struct igmpv3_report {
	__u8 type;
	__u8 resv1;
	__sum16 csum;
	__be16 resv2;
	__be16 ngrec;
	struct igmpv3_grec grec[0];
};

struct igmpv3_query {
	__u8 type;
	__u8 code;
	__sum16 csum;
	__be32 group;
	__u8 qrv: 3;
	__u8 suppress: 1;
	__u8 resv: 4;
	long: 4;
	long: 64;
	__u8 qqic;
	__be16 nsrcs;
	__be32 srcs[0];
};

struct pneigh_entry___74;

struct neigh_hash_table___74;

struct neigh_table___74 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___87 *, __u32 *);
	bool (*key_eq)(const struct neighbour___74 *, const void *);
	int (*constructor)(struct neighbour___74 *);
	int (*pconstructor)(struct pneigh_entry___74 *);
	void (*pdestructor)(struct pneigh_entry___74 *);
	void (*proxy_redo)(struct sk_buff___88 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___87 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___74 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___87 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___74 *nht;
	struct pneigh_entry___74 **phash_buckets;
};

struct neigh_ops___74 {
	int family;
	void (*solicit)(struct neighbour___74 *, struct sk_buff___88 *);
	void (*error_report)(struct neighbour___74 *, struct sk_buff___88 *);
	int (*output)(struct neighbour___74 *, struct sk_buff___88 *);
	int (*connected_output)(struct neighbour___74 *, struct sk_buff___88 *);
};

struct pneigh_entry___74 {
	struct pneigh_entry___74 *next;
	possible_net_t___87 net;
	struct net_device___87 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___74 {
	struct neighbour___74 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct block_device_operations___169;

struct gendisk___172 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___172 *part0;
	const struct block_device_operations___169 *fops;
	struct request_queue___169 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___155 *bdi;
	struct kobject___266 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___266 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___169 {
	struct bio___169 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___195 *bip_vec;
	struct bio_vec___195 bip_inline_vecs[0];
};

struct blkcg___157;

struct blkg_policy_data___157;

struct blkcg_gq___157 {
	struct request_queue___169 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___157 *blkcg;
	struct blkcg_gq___157 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___157 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___169 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___169(struct request___169 *);

typedef void integrity_complete_fn___169(struct request___169 *, unsigned int);

struct blk_integrity_profile___169 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___169 *prepare_fn;
	integrity_complete_fn___169 *complete_fn;
	const char *name;
};

struct block_device_operations___169 {
	blk_qc_t (*submit_bio)(struct bio___169 *);
	int (*open)(struct block_device___172 *, fmode_t);
	void (*release)(struct gendisk___172 *, fmode_t);
	int (*rw_page)(struct block_device___172 *, sector_t, struct page___283 *, unsigned int);
	int (*ioctl)(struct block_device___172 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___172 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___172 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___172 *);
	int (*getgeo)(struct block_device___172 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___172 *, bool);
	void (*swap_slot_free_notify)(struct block_device___172 *, long unsigned int);
	int (*report_zones)(struct gendisk___172 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___172 *, umode_t *);
	struct module___262 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___172 *, sector_t *);
};

typedef void rq_end_io_fn___169(struct request___169 *, blk_status_t);

struct request___169 {
	struct request_queue___169 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___164 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___169 *bio;
	struct bio___169 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___195 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___169 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___169 *saved_end_io;
		} flush;
	};
	struct gendisk___172 *rq_disk;
	struct block_device___172 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___169 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___164 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___169 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___266 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___278 *debugfs_dir;
	struct dentry___278 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___169;

struct elevator_mq_ops___169 {
	int (*init_sched)(struct request_queue___169 *, struct elevator_type___169 *);
	void (*exit_sched)(struct elevator_queue___169 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___164 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___164 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___164 *);
	bool (*allow_merge)(struct request_queue___169 *, struct request___169 *, struct bio___169 *);
	bool (*bio_merge)(struct request_queue___169 *, struct bio___169 *, unsigned int);
	int (*request_merge)(struct request_queue___169 *, struct request___169 **, struct bio___169 *);
	void (*request_merged)(struct request_queue___169 *, struct request___169 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___169 *, struct request___169 *, struct request___169 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___169 *);
	void (*finish_request)(struct request___169 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___164 *, struct list_head *, bool);
	struct request___169 * (*dispatch_request)(struct blk_mq_hw_ctx___164 *);
	bool (*has_work)(struct blk_mq_hw_ctx___164 *);
	void (*completed_request)(struct request___169 *, u64);
	void (*requeue_request)(struct request___169 *);
	struct request___169 * (*former_request)(struct request_queue___169 *, struct request___169 *);
	struct request___169 * (*next_request)(struct request_queue___169 *, struct request___169 *);
	void (*init_icq)(struct io_cq___169 *);
	void (*exit_icq)(struct io_cq___169 *);
};

struct elv_fs_entry___169;

struct elevator_type___169 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___169 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___169 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___262 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___169 {
	struct elevator_type___169 *type;
	void *elevator_data;
	struct kobject___266 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___169 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___169 *, char *);
	ssize_t (*store)(struct elevator_queue___169 *, const char *, size_t);
};

struct blk_mq_queue_data___164;

struct blk_mq_ops___164 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___164 *, const struct blk_mq_queue_data___164 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___164 *);
	int (*get_budget)(struct request_queue___169 *);
	void (*put_budget)(struct request_queue___169 *, int);
	void (*set_rq_budget_token)(struct request___169 *, int);
	int (*get_rq_budget_token)(struct request___169 *);
	enum blk_eh_timer_return (*timeout)(struct request___169 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___164 *);
	void (*complete)(struct request___169 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___164 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___164 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___164 *, struct request___169 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___164 *, struct request___169 *, unsigned int);
	void (*initialize_rq_fn)(struct request___169 *);
	void (*cleanup_rq)(struct request___169 *);
	bool (*busy)(struct request_queue___169 *);
	int (*map_queues)(struct blk_mq_tag_set___164 *);
	void (*show_rq)(struct seq_file___253 *, struct request___169 *);
};

struct blk_mq_tag_set___164 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___164 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___164 {
	struct request___169 *rq;
	bool last;
};

struct blkcg_policy_data___157;

struct blkcg___157 {
	struct cgroup_subsys_state___205 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___157 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___157 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___157 {
	struct blkcg___157 *blkcg;
	int plid;
};

struct blkg_policy_data___157 {
	struct blkcg_gq___157 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___143 {
	struct mem_cgroup___143 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___143 {
	struct lruvec___151 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___143 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___143 *memcg;
};

struct obj_cgroup___143 {
	struct percpu_ref refcnt;
	struct mem_cgroup___143 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___81 {
	spinlock_t *lock;
	struct sk_buff___88 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___81;

struct Qdisc_ops___81 {
	struct Qdisc_ops___81 *next;
	const struct Qdisc_class_ops___81 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___88 *, struct Qdisc___81 *, struct sk_buff___88 **);
	struct sk_buff___88 * (*dequeue)(struct Qdisc___81 *);
	struct sk_buff___88 * (*peek)(struct Qdisc___81 *);
	int (*init)(struct Qdisc___81 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___81 *);
	void (*destroy)(struct Qdisc___81 *);
	int (*change)(struct Qdisc___81 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___81 *);
	int (*change_tx_queue_len)(struct Qdisc___81 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___81 *, unsigned int);
	int (*dump)(struct Qdisc___81 *, struct sk_buff___88 *);
	int (*dump_stats)(struct Qdisc___81 *, struct gnet_dump___81 *);
	void (*ingress_block_set)(struct Qdisc___81 *, u32);
	void (*egress_block_set)(struct Qdisc___81 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___81 *);
	u32 (*egress_block_get)(struct Qdisc___81 *);
	struct module___262 *owner;
};

struct Qdisc_class_ops___81 {
	unsigned int flags;
	struct netdev_queue___87 * (*select_queue)(struct Qdisc___81 *, struct tcmsg *);
	int (*graft)(struct Qdisc___81 *, long unsigned int, struct Qdisc___81 *, struct Qdisc___81 **, struct netlink_ext_ack *);
	struct Qdisc___81 * (*leaf)(struct Qdisc___81 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___81 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___81 *, u32);
	int (*change)(struct Qdisc___81 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___81 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___81 *, struct qdisc_walker *);
	struct tcf_block___81 * (*tcf_block)(struct Qdisc___81 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___81 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___81 *, long unsigned int);
	int (*dump)(struct Qdisc___81 *, long unsigned int, struct sk_buff___88 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___81 *, long unsigned int, struct gnet_dump___81 *);
};

struct tcf_chain___81;

struct tcf_block___81 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___92 *net;
	struct Qdisc___81 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___81 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___81;

struct tcf_proto_ops___81;

struct tcf_proto___81 {
	struct tcf_proto___81 *next;
	void *root;
	int (*classify)(struct sk_buff___88 *, const struct tcf_proto___81 *, struct tcf_result___81 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___81 *ops;
	struct tcf_chain___81 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___81 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___81 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___81 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___88 *, const struct tcf_proto___81 *, struct tcf_result___81 *);
	int (*init)(struct tcf_proto___81 *);
	void (*destroy)(struct tcf_proto___81 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___81 *, u32);
	void (*put)(struct tcf_proto___81 *, void *);
	int (*change)(struct net___92 *, struct sk_buff___88 *, struct tcf_proto___81 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___81 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___81 *);
	void (*walk)(struct tcf_proto___81 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___81 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___81 *, void *);
	void (*hw_del)(struct tcf_proto___81 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___92 *, struct tcf_chain___81 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___92 *, struct tcf_proto___81 *, void *, struct sk_buff___88 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___92 *, struct tcf_proto___81 *, void *, struct sk_buff___88 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___88 *, struct net___92 *, void *);
	struct module___262 *owner;
	int flags;
};

struct tcf_chain___81 {
	struct mutex filter_chain_lock;
	struct tcf_proto___81 *filter_chain;
	struct list_head list;
	struct tcf_block___81 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___81 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___74 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___81 *prog;
};

struct lwtunnel_state___50 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___92 *, struct sock___74 *, struct sk_buff___88 *);
	int (*orig_input)(struct sk_buff___88 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___74 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___74 *ctarget;
	struct net___92 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___74 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___74 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___59;

struct timewait_sock_ops___58;

struct proto___74 {
	void (*close)(struct sock___74 *, long int);
	int (*pre_connect)(struct sock___74 *, struct sockaddr *, int);
	int (*connect)(struct sock___74 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___74 *, int);
	struct sock___74 * (*accept)(struct sock___74 *, int, int *, bool);
	int (*ioctl)(struct sock___74 *, int, long unsigned int);
	int (*init)(struct sock___74 *);
	void (*destroy)(struct sock___74 *);
	void (*shutdown)(struct sock___74 *, int);
	int (*setsockopt)(struct sock___74 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___74 *, int, int, char *, int *);
	void (*keepalive)(struct sock___74 *, int);
	int (*compat_ioctl)(struct sock___74 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___74 *, struct msghdr___76 *, size_t);
	int (*recvmsg)(struct sock___74 *, struct msghdr___76 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___74 *, struct page___283 *, int, size_t, int);
	int (*bind)(struct sock___74 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___74 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___74 *, struct sk_buff___88 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___74 *);
	int (*hash)(struct sock___74 *);
	void (*unhash)(struct sock___74 *);
	void (*rehash)(struct sock___74 *);
	int (*get_port)(struct sock___74 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___74 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___74 *, int);
	bool (*sock_is_readable)(struct sock___74 *);
	void (*enter_memory_pressure)(struct sock___74 *);
	void (*leave_memory_pressure)(struct sock___74 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___59 *rsk_prot;
	struct timewait_sock_ops___58 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___262 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___74 *, int);
};

struct request_sock___60;

struct request_sock_ops___59 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___74 *, struct request_sock___60 *);
	void (*send_ack)(const struct sock___74 *, struct sk_buff___88 *, struct request_sock___60 *);
	void (*send_reset)(const struct sock___74 *, struct sk_buff___88 *);
	void (*destructor)(struct request_sock___60 *);
	void (*syn_ack_timeout)(const struct request_sock___60 *);
};

struct timewait_sock_ops___58 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___74 *, struct sock___74 *, void *);
	void (*twsk_destructor)(struct sock___74 *);
};

struct request_sock___60 {
	struct sock_common___74 __req_common;
	struct request_sock___60 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___59 *rsk_ops;
	struct sock___74 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___17 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___74 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___17 {
	struct inet_cork___17 base;
	struct flowi fl;
};

struct ipv6_pinfo___16;

struct inet_sock___17 {
	struct sock___74 sk;
	struct ipv6_pinfo___16 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___17 cork;
};

struct ipv6_fl_socklist___16;

struct ipv6_pinfo___16 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___16 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___88 *pktoptions;
	struct sk_buff___88 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___16;

struct ipv6_fl_socklist___16 {
	struct ipv6_fl_socklist___16 *next;
	struct ip6_flowlabel___16 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___56 {
	struct in6_addr mca_addr;
	struct inet6_dev___56 *idev;
	struct ifmcaddr6___56 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___16 {
	struct ip6_flowlabel___16 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___255 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___92 *fl_net;
};

struct rtable___24 {
	struct dst_entry___74 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct nf_hook_state___15 {
	u8 hook;
	u8 pf;
	struct net_device___87 *in;
	struct net_device___87 *out;
	struct sock___74 *sk;
	struct net___92 *net;
	int (*okfn)(struct net___92 *, struct sock___74 *, struct sk_buff___88 *);
};

struct igmp_mc_iter_state {
	struct seq_net_private___10 p;
	struct net_device___87 *dev;
	struct in_device___15 *in_dev;
};

struct igmp_mcf_iter_state {
	struct seq_net_private___10 p;
	struct net_device___87 *dev;
	struct in_device___15 *idev;
	struct ip_mc_list___5 *im;
};

struct dentry___279;

struct super_block___279;

struct module___263;

struct file_system_type___279 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___279 * (*mount)(struct file_system_type___279 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___279 *);
	struct module___263 *owner;
	struct file_system_type___279 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___279;

struct kiocb___279;

struct iov_iter___199;

struct poll_table_struct___200;

struct vm_area_struct___284;

struct inode___279;

struct file_lock___279;

struct page___284;

struct pipe_inode_info___120;

struct seq_file___254;

struct file_operations___280 {
	struct module___263 *owner;
	loff_t (*llseek)(struct file___279 *, loff_t, int);
	ssize_t (*read)(struct file___279 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___279 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___279 *, struct iov_iter___199 *);
	ssize_t (*write_iter)(struct kiocb___279 *, struct iov_iter___199 *);
	int (*iopoll)(struct kiocb___279 *, bool);
	int (*iterate)(struct file___279 *, struct dir_context *);
	int (*iterate_shared)(struct file___279 *, struct dir_context *);
	__poll_t (*poll)(struct file___279 *, struct poll_table_struct___200 *);
	long int (*unlocked_ioctl)(struct file___279 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___279 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___279 *, struct vm_area_struct___284 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___279 *, struct file___279 *);
	int (*flush)(struct file___279 *, fl_owner_t);
	int (*release)(struct inode___279 *, struct file___279 *);
	int (*fsync)(struct file___279 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___279 *, int);
	int (*lock)(struct file___279 *, int, struct file_lock___279 *);
	ssize_t (*sendpage)(struct file___279 *, struct page___284 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___279 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___279 *, long unsigned int);
	int (*flock)(struct file___279 *, int, struct file_lock___279 *);
	ssize_t (*splice_write)(struct pipe_inode_info___120 *, struct file___279 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___279 *, loff_t *, struct pipe_inode_info___120 *, size_t, unsigned int);
	int (*setlease)(struct file___279 *, long int, struct file_lock___279 **, void **);
	long int (*fallocate)(struct file___279 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___254 *, struct file___279 *);
	ssize_t (*copy_file_range)(struct file___279 *, loff_t, struct file___279 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___279 *, loff_t, struct file___279 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___279 *, loff_t, loff_t, int);
};

struct vmacache___284 {
	u64 seqnum;
	struct vm_area_struct___284 *vmas[4];
};

struct page_frag___284 {
	struct page___284 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___285;

struct pid___256;

struct nsproxy___265;

struct signal_struct___280;

struct bio_list___170;

struct backing_dev_info___156;

struct io_context___170;

struct css_set___206;

struct mem_cgroup___144;

struct request_queue___170;

struct vm_struct___262;

struct task_struct___286 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___286 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___285 *mm;
	struct mm_struct___285 *active_mm;
	struct vmacache___284 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___286 *real_parent;
	struct task_struct___286 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___286 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___256 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___265 *nsproxy;
	struct signal_struct___280 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___286 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___170 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___156 *backing_dev_info;
	struct io_context___170 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___206 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___120 *splice_pipe;
	struct page_frag___284 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___144 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___144 *active_memcg;
	struct request_queue___170 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___286 *oom_reaper_list;
	struct vm_struct___262 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___267;

struct kobj_type___267;

struct kernfs_node___267;

struct kobject___267 {
	const char *name;
	struct list_head entry;
	struct kobject___267 *parent;
	struct kset___267 *kset;
	struct kobj_type___267 *ktype;
	struct kernfs_node___267 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___264 {
	struct kobject___267 kobj;
	struct module___263 *mod;
	struct kobject___267 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___263 {
	struct module___263 *mod;
	struct latch_tree_node node;
};

struct module_layout___263 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___263 mtn;
};

struct module_attribute___263;

struct kernel_param___263;

struct module___263 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___264 mkobj;
	struct module_attribute___263 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___267 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___263 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___263 core_layout;
	struct module_layout___263 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___256;

struct upid___256 {
	int nr;
	struct pid_namespace___256 *ns;
};

struct pid_namespace___256 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___286 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___256 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___256 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___256 numbers[1];
};

typedef struct page___284 *pgtable_t___284;

struct address_space___279;

struct page_pool___108;

struct dev_pagemap___274;

struct page___284 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___279 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___108 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___284 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___284 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___285 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___274 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___274;

struct vm_area_struct___284 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___284 *vm_next;
	struct vm_area_struct___284 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___285 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___274 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___279 *vm_file;
	struct file___279 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___280 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___286 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___286 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___256 *pids[4];
	struct pid___256 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___285 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___284;

struct mm_struct___285 {
	struct {
		struct vm_area_struct___284 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___279 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___284 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___286 *owner;
		struct user_namespace___26 *user_ns;
		struct file___279 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___93;

struct cgroup_namespace___206;

struct nsproxy___265 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___256 *pid_ns_for_children;
	struct net___93 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___206 *cgroup_ns;
};

struct bio___170;

struct bio_list___170 {
	struct bio___170 *head;
	struct bio___170 *tail;
};

struct cgroup_subsys_state___206;

struct bdi_writeback___156 {
	struct backing_dev_info___156 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___206 *memcg_css;
	struct cgroup_subsys_state___206 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___260;

struct backing_dev_info___156 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___156 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___260 *dev;
	char dev_name[64];
	struct device___260 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___279 *debug_dir;
};

struct io_cq___170;

struct io_context___170 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___170 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___206;

struct css_set___206 {
	struct cgroup_subsys_state___206 *subsys[14];
	refcount_t refcount;
	struct css_set___206 *dom_cset;
	struct cgroup___206 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___206 *mg_src_cgrp;
	struct cgroup___206 *mg_dst_cgrp;
	struct css_set___206 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___279;

struct pipe_buffer___120;

struct pipe_inode_info___120 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___284 *tmp_page;
	struct fasync_struct___279 *fasync_readers;
	struct fasync_struct___279 *fasync_writers;
	struct pipe_buffer___120 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___206;

struct cgroup_subsys_state___206 {
	struct cgroup___206 *cgroup;
	struct cgroup_subsys___206 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___206 *parent;
};

struct cgroup_file___206 {
	struct kernfs_node___267 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___144;

struct mem_cgroup_per_node___144;

struct mem_cgroup___144 {
	struct cgroup_subsys_state___206 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___206 events_file;
	struct cgroup_file___206 events_local_file;
	struct cgroup_file___206 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___144 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___286 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___144 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___170;

struct blk_integrity___170 {
	const struct blk_integrity_profile___170 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___170 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___170 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___170;

struct elevator_queue___170;

struct blk_mq_ops___165;

struct blk_mq_hw_ctx___165;

struct gendisk___173;

struct blkcg_gq___158;

struct blk_mq_tag_set___165;

struct request_queue___170 {
	struct request___170 *last_merge;
	struct elevator_queue___170 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___165 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___165 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___173 *disk;
	struct kobject___267 kobj;
	struct kobject___267 *mq_kobj;
	struct blk_integrity___170 integrity;
	struct device___260 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___158 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___165 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___170 bio_split;
	struct dentry___279 *debugfs_dir;
	struct dentry___279 *sched_debugfs_dir;
	struct dentry___279 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___262 {
	struct vm_struct___262 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___284 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___279;

struct address_space___279 {
	struct inode___279 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___279 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___108 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___260 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___108 {
	u32 count;
	struct page___284 *cache[128];
};

struct page_pool___108 {
	struct page_pool_params___108 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___284 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___108 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___274;

struct dev_pagemap___274 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___274 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___279;

struct path___279 {
	struct vfsmount___279 *mnt;
	struct dentry___279 *dentry;
};

struct fown_struct___256 {
	rwlock_t lock;
	struct pid___256 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___279 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___279 f_path;
	struct inode___279 *f_inode;
	const struct file_operations___280 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___256 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___279 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___274;

struct vm_operations_struct___274 {
	void (*open)(struct vm_area_struct___284 *);
	void (*close)(struct vm_area_struct___284 *);
	int (*may_split)(struct vm_area_struct___284 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___284 *);
	int (*mprotect)(struct vm_area_struct___284 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___274 *);
	vm_fault_t (*huge_fault)(struct vm_fault___274 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___274 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___284 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___274 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___274 *);
	int (*access)(struct vm_area_struct___284 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___284 *);
	int (*set_policy)(struct vm_area_struct___284 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___284 *, long unsigned int);
	struct page___284 * (*find_special_page)(struct vm_area_struct___284 *, long unsigned int);
};

struct core_thread___284 {
	struct task_struct___286 *task;
	struct core_thread___284 *next;
};

struct core_state___284 {
	atomic_t nr_threads;
	struct core_thread___284 dumper;
	struct completion startup;
};

struct vm_fault___274 {
	const struct {
		struct vm_area_struct___284 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___284 *cow_page;
	struct page___284 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___284 prealloc_pte;
};

struct pglist_data___152;

struct lruvec___152 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___152 *pgdat;
};

struct zone___152 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___152 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___152 {
	struct zone___152 *zone;
	int zone_idx;
};

struct zonelist___152 {
	struct zoneref___152 _zonerefs[321];
};

struct pglist_data___152 {
	struct zone___152 node_zones[5];
	struct zonelist___152 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___286 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___286 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___152 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___279;

struct dentry___279 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___279 *d_parent;
	struct qstr d_name;
	struct inode___279 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___279 *d_op;
	struct super_block___279 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___279;

struct inode___279 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___279 *i_op;
	struct super_block___279 *i_sb;
	struct address_space___279 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___156 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___280 *i_fop;
		void (*free_inode)(struct inode___279 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___279 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___120 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___279 {
	int (*d_revalidate)(struct dentry___279 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___279 *, unsigned int);
	int (*d_hash)(const struct dentry___279 *, struct qstr *);
	int (*d_compare)(const struct dentry___279 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___279 *);
	int (*d_init)(struct dentry___279 *);
	void (*d_release)(struct dentry___279 *);
	void (*d_prune)(struct dentry___279 *);
	void (*d_iput)(struct dentry___279 *, struct inode___279 *);
	char * (*d_dname)(struct dentry___279 *, char *, int);
	struct vfsmount___279 * (*d_automount)(struct path___279 *);
	int (*d_manage)(const struct path___279 *, bool);
	struct dentry___279 * (*d_real)(struct dentry___279 *, const struct inode___279 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___279;

struct mem_dqinfo___279 {
	struct quota_format_type___279 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___279;

struct quota_info___279 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___279 *files[3];
	struct mem_dqinfo___279 info[3];
	const struct quota_format_ops___279 *ops[3];
};

struct rcuwait___280 {
	struct task_struct___286 *task;
};

struct percpu_rw_semaphore___280 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___280 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___279 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___280 rw_sem[3];
};

struct shrink_control___144;

struct shrinker___144 {
	long unsigned int (*count_objects)(struct shrinker___144 *, struct shrink_control___144 *);
	long unsigned int (*scan_objects)(struct shrinker___144 *, struct shrink_control___144 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___279;

struct dquot_operations___279;

struct quotactl_ops___279;

struct block_device___173;

struct super_block___279 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___279 *s_type;
	const struct super_operations___279 *s_op;
	const struct dquot_operations___279 *dq_op;
	const struct quotactl_ops___279 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___279 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___173 *s_bdev;
	struct backing_dev_info___156 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___279 s_dquot;
	struct sb_writers___279 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___279 *s_d_op;
	int cleancache_poolid;
	struct shrinker___144 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___279 {
	struct dentry___279 *mnt_root;
	struct super_block___279 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___144 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___144 *memcg;
};

struct psi_group___206 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___286 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___82;

struct cgroup_bpf___82 {
	struct bpf_prog_array___82 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___82 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___206;

struct cgroup_rstat_cpu___206;

struct cgroup___206 {
	struct cgroup_subsys_state___206 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___267 *kn;
	struct cgroup_file___206 procs_file;
	struct cgroup_file___206 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___206 *subsys[14];
	struct cgroup_root___206 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___206 *dom_cgrp;
	struct cgroup___206 *old_dom_cgrp;
	struct cgroup_rstat_cpu___206 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___206 psi;
	struct cgroup_bpf___82 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___170 {
	struct request_queue___170 *q;
	struct io_context___170 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___279 {
	struct file___279 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___279 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___279 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___279 *ia_file;
};

struct dquot___279 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___279 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___279 {
	int qf_fmt_id;
	const struct quota_format_ops___279 *qf_ops;
	struct module___263 *qf_owner;
	struct quota_format_type___279 *qf_next;
};

struct quota_format_ops___279 {
	int (*check_quota_file)(struct super_block___279 *, int);
	int (*read_file_info)(struct super_block___279 *, int);
	int (*write_file_info)(struct super_block___279 *, int);
	int (*free_file_info)(struct super_block___279 *, int);
	int (*read_dqblk)(struct dquot___279 *);
	int (*commit_dqblk)(struct dquot___279 *);
	int (*release_dqblk)(struct dquot___279 *);
	int (*get_next_id)(struct super_block___279 *, struct kqid *);
};

struct dquot_operations___279 {
	int (*write_dquot)(struct dquot___279 *);
	struct dquot___279 * (*alloc_dquot)(struct super_block___279 *, int);
	void (*destroy_dquot)(struct dquot___279 *);
	int (*acquire_dquot)(struct dquot___279 *);
	int (*release_dquot)(struct dquot___279 *);
	int (*mark_dirty)(struct dquot___279 *);
	int (*write_info)(struct super_block___279 *, int);
	qsize_t * (*get_reserved_space)(struct inode___279 *);
	int (*get_projid)(struct inode___279 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___279 *, qsize_t *);
	int (*get_next_id)(struct super_block___279 *, struct kqid *);
};

struct quotactl_ops___279 {
	int (*quota_on)(struct super_block___279 *, int, int, const struct path___279 *);
	int (*quota_off)(struct super_block___279 *, int);
	int (*quota_enable)(struct super_block___279 *, unsigned int);
	int (*quota_disable)(struct super_block___279 *, unsigned int);
	int (*quota_sync)(struct super_block___279 *, int);
	int (*set_info)(struct super_block___279 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___279 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___279 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___279 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___279 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___279 *, unsigned int);
};

struct writeback_control___156;

struct address_space_operations___279 {
	int (*writepage)(struct page___284 *, struct writeback_control___156 *);
	int (*readpage)(struct file___279 *, struct page___284 *);
	int (*writepages)(struct address_space___279 *, struct writeback_control___156 *);
	int (*set_page_dirty)(struct page___284 *);
	int (*readpages)(struct file___279 *, struct address_space___279 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___279 *, struct address_space___279 *, loff_t, unsigned int, unsigned int, struct page___284 **, void **);
	int (*write_end)(struct file___279 *, struct address_space___279 *, loff_t, unsigned int, unsigned int, struct page___284 *, void *);
	sector_t (*bmap)(struct address_space___279 *, sector_t);
	void (*invalidatepage)(struct page___284 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___284 *, gfp_t);
	void (*freepage)(struct page___284 *);
	ssize_t (*direct_IO)(struct kiocb___279 *, struct iov_iter___199 *);
	int (*migratepage)(struct address_space___279 *, struct page___284 *, struct page___284 *, enum migrate_mode);
	bool (*isolate_page)(struct page___284 *, isolate_mode_t);
	void (*putback_page)(struct page___284 *);
	int (*launder_page)(struct page___284 *);
	int (*is_partially_uptodate)(struct page___284 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___284 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___279 *, struct page___284 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___279 *, sector_t *);
	void (*swap_deactivate)(struct file___279 *);
};

struct writeback_control___156 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___156 *wb;
	struct inode___279 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___196;

struct iov_iter___199 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___196 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___120 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___279 {
	struct dentry___279 * (*lookup)(struct inode___279 *, struct dentry___279 *, unsigned int);
	const char * (*get_link)(struct dentry___279 *, struct inode___279 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___279 *, int);
	struct posix_acl * (*get_acl)(struct inode___279 *, int, bool);
	int (*readlink)(struct dentry___279 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___279 *, struct dentry___279 *, umode_t, bool);
	int (*link)(struct dentry___279 *, struct inode___279 *, struct dentry___279 *);
	int (*unlink)(struct inode___279 *, struct dentry___279 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___279 *, struct dentry___279 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___279 *, struct dentry___279 *, umode_t);
	int (*rmdir)(struct inode___279 *, struct dentry___279 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___279 *, struct dentry___279 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___279 *, struct dentry___279 *, struct inode___279 *, struct dentry___279 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___279 *, struct iattr___279 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___279 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___279 *, char *, size_t);
	int (*fiemap)(struct inode___279 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___279 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___279 *, struct dentry___279 *, struct file___279 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___279 *, struct dentry___279 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___279 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___279 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___279 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___279 {
	void (*fl_copy_lock)(struct file_lock___279 *, struct file_lock___279 *);
	void (*fl_release_private)(struct file_lock___279 *);
};

struct lock_manager_operations___279;

struct file_lock___279 {
	struct file_lock___279 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___279 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___279 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___279 *fl_ops;
	const struct lock_manager_operations___279 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___279 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___279 *);
	int (*lm_grant)(struct file_lock___279 *, int);
	bool (*lm_break)(struct file_lock___279 *);
	int (*lm_change)(struct file_lock___279 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___279 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___279 *);
};

struct fasync_struct___279 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___279 *fa_next;
	struct file___279 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___279 {
	struct inode___279 * (*alloc_inode)(struct super_block___279 *);
	void (*destroy_inode)(struct inode___279 *);
	void (*free_inode)(struct inode___279 *);
	void (*dirty_inode)(struct inode___279 *, int);
	int (*write_inode)(struct inode___279 *, struct writeback_control___156 *);
	int (*drop_inode)(struct inode___279 *);
	void (*evict_inode)(struct inode___279 *);
	void (*put_super)(struct super_block___279 *);
	int (*sync_fs)(struct super_block___279 *, int);
	int (*freeze_super)(struct super_block___279 *);
	int (*freeze_fs)(struct super_block___279 *);
	int (*thaw_super)(struct super_block___279 *);
	int (*unfreeze_fs)(struct super_block___279 *);
	int (*statfs)(struct dentry___279 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___279 *, int *, char *);
	void (*umount_begin)(struct super_block___279 *);
	int (*show_options)(struct seq_file___254 *, struct dentry___279 *);
	int (*show_devname)(struct seq_file___254 *, struct dentry___279 *);
	int (*show_path)(struct seq_file___254 *, struct dentry___279 *);
	int (*show_stats)(struct seq_file___254 *, struct dentry___279 *);
	ssize_t (*quota_read)(struct super_block___279 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___279 *, int, const char *, size_t, loff_t);
	struct dquot___279 ** (*get_dquots)(struct inode___279 *);
	long int (*nr_cached_objects)(struct super_block___279 *, struct shrink_control___144 *);
	long int (*free_cached_objects)(struct super_block___279 *, struct shrink_control___144 *);
	struct file___279 * (*real_loop)(struct file___279 *);
};

struct wakeup_source___260;

struct dev_pm_info___260 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___260 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___260 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___260;

struct bus_type___260;

struct device_driver___260;

struct dev_pm_domain___260;

struct fwnode_handle___256;

struct class___260;

struct attribute_group___267;

struct device___260 {
	struct kobject___267 kobj;
	struct device___260 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___260 *type;
	struct bus_type___260 *bus;
	struct device_driver___260 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___260 power;
	struct dev_pm_domain___260 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___256 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___260 *class;
	const struct attribute_group___267 **groups;
	void (*release)(struct device___260 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___173 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___279 *bd_inode;
	struct super_block___279 *bd_super;
	void *bd_claiming;
	struct device___260 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___267 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___173 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___279 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___208)(struct file___279 *, wait_queue_head_t *, struct poll_table_struct___200 *);

struct poll_table_struct___200 {
	poll_queue_proc___208 _qproc;
	__poll_t _key;
};

struct seq_operations___254;

struct seq_file___254 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___254 *op;
	int poll_event;
	const struct file___279 *file;
	void *private;
};

typedef void bio_end_io_t___170(struct bio___170 *);

struct bio_vec___196 {
	struct page___284 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___170;

struct bio___170 {
	struct bio___170 *bi_next;
	struct block_device___173 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___170 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___158 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___170 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___196 *bi_io_vec;
	struct bio_set___170 *bi_pool;
	struct bio_vec___196 bi_inline_vecs[0];
};

struct kernfs_root___267;

struct kernfs_elem_dir___267 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___267 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___267;

struct kernfs_root___267 {
	struct kernfs_node___267 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___267 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___267 {
	struct kernfs_node___267 *target_kn;
};

struct kernfs_ops___267;

struct kernfs_elem_attr___267 {
	const struct kernfs_ops___267 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___267 *notify_next;
};

struct kernfs_node___267 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___267 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___267 dir;
		struct kernfs_elem_symlink___267 symlink;
		struct kernfs_elem_attr___267 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___267;

struct kernfs_ops___267 {
	int (*open)(struct kernfs_open_file___267 *);
	void (*release)(struct kernfs_open_file___267 *);
	int (*seq_show)(struct seq_file___254 *, void *);
	void * (*seq_start)(struct seq_file___254 *, loff_t *);
	void * (*seq_next)(struct seq_file___254 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___254 *, void *);
	ssize_t (*read)(struct kernfs_open_file___267 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___267 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___267 *, struct poll_table_struct___200 *);
	int (*mmap)(struct kernfs_open_file___267 *, struct vm_area_struct___284 *);
};

struct kernfs_syscall_ops___267 {
	int (*show_options)(struct seq_file___254 *, struct kernfs_root___267 *);
	int (*mkdir)(struct kernfs_node___267 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___267 *);
	int (*rename)(struct kernfs_node___267 *, struct kernfs_node___267 *, const char *);
	int (*show_path)(struct seq_file___254 *, struct kernfs_node___267 *, struct kernfs_root___267 *);
};

struct kernfs_open_file___267 {
	struct kernfs_node___267 *kn;
	struct file___279 *file;
	struct seq_file___254 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___274 *vm_ops;
};

struct sock___75;

struct kobj_ns_type_operations___75 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___75 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___93 *net;
} possible_net_t___88;

struct proto___75;

struct sock_common___75 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___75 *skc_prot;
	possible_net_t___88 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___75 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___89;

struct sk_buff_head___88 {
	struct sk_buff___89 *next;
	struct sk_buff___89 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___75 {
	struct cgroup___206 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___75;

struct socket_wq___76;

struct xfrm_policy___17;

struct dst_entry___75;

struct socket___77;

struct net_device___88;

struct sock_reuseport___25;

struct sock___75 {
	struct sock_common___75 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___88 sk_error_queue;
	struct sk_buff___89 *sk_rx_skb_cache;
	struct sk_buff_head___88 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___89 *head;
		struct sk_buff___89 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___75 *sk_filter;
	union {
		struct socket_wq___76 *sk_wq;
		struct socket_wq___76 *sk_wq_raw;
	};
	struct xfrm_policy___17 *sk_policy[2];
	struct dst_entry___75 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___75 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___89 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___89 *sk_tx_skb_cache;
	struct sk_buff_head___88 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___284 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___75 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___256 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___77 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___75 sk_cgrp_data;
	struct mem_cgroup___144 *sk_memcg;
	void (*sk_state_change)(struct sock___75 *);
	void (*sk_data_ready)(struct sock___75 *);
	void (*sk_write_space)(struct sock___75 *);
	void (*sk_error_report)(struct sock___75 *);
	int (*sk_backlog_rcv)(struct sock___75 *, struct sk_buff___89 *);
	struct sk_buff___89 * (*sk_validate_xmit_skb)(struct sock___75 *, struct net_device___88 *, struct sk_buff___89 *);
	void (*sk_destruct)(struct sock___75 *);
	struct sock_reuseport___25 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___267;

struct attribute_group___267 {
	const char *name;
	umode_t (*is_visible)(struct kobject___267 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___267 *, struct bin_attribute___267 *, int);
	struct attribute **attrs;
	struct bin_attribute___267 **bin_attrs;
};

struct bin_attribute___267 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___279 * (*f_mapping)();
	ssize_t (*read)(struct file___279 *, struct kobject___267 *, struct bin_attribute___267 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___279 *, struct kobject___267 *, struct bin_attribute___267 *, char *, loff_t, size_t);
	int (*mmap)(struct file___279 *, struct kobject___267 *, struct bin_attribute___267 *, struct vm_area_struct___284 *);
};

struct sysfs_ops___267 {
	ssize_t (*show)(struct kobject___267 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___267 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___267;

struct kset___267 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___267 kobj;
	const struct kset_uevent_ops___267 *uevent_ops;
};

struct kobj_type___267 {
	void (*release)(struct kobject___267 *);
	const struct sysfs_ops___267 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___267 **default_groups;
	const struct kobj_ns_type_operations___75 * (*child_ns_type)(struct kobject___267 *);
	const void * (*namespace)(struct kobject___267 *);
	void (*get_ownership)(struct kobject___267 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___267 {
	int (* const filter)(struct kset___267 *, struct kobject___267 *);
	const char * (* const name)(struct kset___267 *, struct kobject___267 *);
	int (* const uevent)(struct kset___267 *, struct kobject___267 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___263 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___263 *);
	int (*get)(char *, const struct kernel_param___263 *);
	void (*free)(void *);
};

struct kparam_array___263;

struct kernel_param___263 {
	const char *name;
	struct module___263 *mod;
	const struct kernel_param_ops___263 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___263 *arr;
	};
};

struct kparam_array___263 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___263 *ops;
	void *elem;
};

struct module_attribute___263 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___263 *, struct module_kobject___264 *, char *);
	ssize_t (*store)(struct module_attribute___263 *, struct module_kobject___264 *, const char *, size_t);
	void (*setup)(struct module___263 *, const char *);
	int (*test)(struct module___263 *);
	void (*free)(struct module___263 *);
};

struct dev_pagemap_ops___274 {
	void (*page_free)(struct page___284 *);
	void (*kill)(struct dev_pagemap___274 *);
	void (*cleanup)(struct dev_pagemap___274 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___274 *);
};

struct msghdr___77 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___199 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___279 *msg_iocb;
};

struct sk_buff___89 {
	union {
		struct {
			struct sk_buff___89 *next;
			struct sk_buff___89 *prev;
			union {
				struct net_device___88 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___75 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___89 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___93;

struct fqdir___93 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___93 *f;
	struct net___93 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___93;

struct inet_frags___93 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___93 *, const void *);
	void (*destructor)(struct inet_frag_queue___93 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___48;

struct fib_rules_ops___75;

struct tcp_congestion_ops___23;

struct fib_notifier_ops___75;

struct netns_ipv4___93 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___48 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___75 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___75 *fibnl;
	struct sock___75 **icmp_sk;
	struct sock___75 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___75 **tcp_sk;
	struct fqdir___93 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___23 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___75 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___75 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___75 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___75;

struct dst_ops___93 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___93 *);
	struct dst_entry___75 * (*check)(struct dst_entry___75 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___75 *);
	unsigned int (*mtu)(const struct dst_entry___75 *);
	u32 * (*cow_metrics)(struct dst_entry___75 *, long unsigned int);
	void (*destroy)(struct dst_entry___75 *);
	void (*ifdown)(struct dst_entry___75 *, struct net_device___88 *, int);
	struct dst_entry___75 * (*negative_advice)(struct dst_entry___75 *);
	void (*link_failure)(struct sk_buff___89 *);
	void (*update_pmtu)(struct dst_entry___75 *, struct sock___75 *, struct sk_buff___89 *, u32, bool);
	void (*redirect)(struct dst_entry___75 *, struct sock___75 *, struct sk_buff___89 *);
	int (*local_out)(struct net___93 *, struct sock___75 *, struct sk_buff___89 *);
	struct neighbour___75 * (*neigh_lookup)(const struct dst_entry___75 *, struct sk_buff___89 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___75 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___23;

struct rt6_info___23;

struct fib6_table___23;

struct netns_ipv6___93 {
	struct dst_ops___93 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___93 *fqdir;
	struct fib6_info___23 *fib6_null_entry;
	struct rt6_info___23 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___23 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___23 *ip6_prohibit_entry;
	struct rt6_info___23 *ip6_blk_hole_entry;
	struct fib6_table___23 *fib6_local_tbl;
	struct fib_rules_ops___75 *fib6_rules_ops;
	struct sock___75 **icmp_sk;
	struct sock___75 *ndisc_sk;
	struct sock___75 *tcp_sk;
	struct sock___75 *igmp_sk;
	struct sock___75 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___75 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___75 *notifier_ops;
	struct fib_notifier_ops___75 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___93 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___93 *fqdir;
};

struct netns_sctp___75 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___75 *ctl_sock;
	struct sock___75 *udp4_sock;
	struct sock___75 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___82;

struct netns_bpf___82 {
	struct bpf_prog_array___82 *run_array[2];
	struct bpf_prog___82 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___93 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___75 *nlsk;
	struct sock___75 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___93 xfrm4_dst_ops;
	struct dst_ops___93 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___93 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___75 *rtnl;
	struct sock___75 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___88 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___93 ipv4;
	struct netns_ipv6___93 ipv6;
	struct netns_ieee802154_lowpan___93 ieee802154_lowpan;
	struct netns_sctp___75 sctp;
	struct netns_nf___15 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___88 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___82 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___93 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___75 *crypto_nlsk;
	struct sock___75 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___93 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___89 *fragments_tail;
	struct sk_buff___89 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___93 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___48 {
	struct ip_ra_chain___48 *next;
	struct sock___75 *sk;
	union {
		void (*destructor)(struct sock___75 *);
		struct sock___75 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___75;

struct fib_lookup_arg___75;

struct fib_rules_ops___75 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___75 *, struct flowi *, int, struct fib_lookup_arg___75 *);
	bool (*suppress)(struct fib_rule___75 *, int, struct fib_lookup_arg___75 *);
	int (*match)(struct fib_rule___75 *, struct flowi *, int);
	int (*configure)(struct fib_rule___75 *, struct sk_buff___89 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___75 *);
	int (*compare)(struct fib_rule___75 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___75 *, struct sk_buff___89 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___75 *);
	void (*flush_cache)(struct fib_rules_ops___75 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___263 *owner;
	struct net___93 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___23 {
	u32 (*ssthresh)(struct sock___75 *);
	void (*cong_avoid)(struct sock___75 *, u32, u32);
	void (*set_state)(struct sock___75 *, u8);
	void (*cwnd_event)(struct sock___75 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___75 *, u32);
	void (*pkts_acked)(struct sock___75 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___75 *);
	void (*cong_control)(struct sock___75 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___75 *);
	u32 (*sndbuf_expand)(struct sock___75 *);
	size_t (*get_info)(struct sock___75 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___263 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___75 *);
	void (*release)(struct sock___75 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___75 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___93 *);
	int (*fib_dump)(struct net___93 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___263 *owner;
	struct callback_head rcu;
};

struct xfrm_state___17;

struct lwtunnel_state___51;

struct dst_entry___75 {
	struct net_device___88 *dev;
	struct dst_ops___93 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___17 *xfrm;
	int (*input)(struct sk_buff___89 *);
	int (*output)(struct net___93 *, struct sock___75 *, struct sk_buff___89 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___51 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___88(struct sk_buff___89 **);

struct bpf_xdp_entity___82 {
	struct bpf_prog___82 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___88;

struct net_device_ops___88;

struct l3mdev_ops___75;

struct ndisc_ops___57;

struct xfrmdev_ops___88;

struct header_ops___88;

struct in_device___16;

struct inet6_dev___57;

struct netdev_rx_queue___88;

struct mini_Qdisc___82;

struct netdev_queue___88;

struct Qdisc___82;

struct rtnl_link_ops___82;

struct dcbnl_rtnl_ops___88;

struct net_device___88 {
	char name[16];
	struct netdev_name_node___88 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___88 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___75 *l3mdev_ops;
	const struct ndisc_ops___57 *ndisc_ops;
	const struct xfrmdev_ops___88 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___88 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___267 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___16 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___57 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___88 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___82 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___88 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___82 *miniq_ingress;
	struct netdev_queue___88 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___88 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___82 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___82 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___88 = 0,
		NETREG_REGISTERED___88 = 1,
		NETREG_UNREGISTERING___88 = 2,
		NETREG_UNREGISTERED___88 = 3,
		NETREG_RELEASED___88 = 4,
		NETREG_DUMMY___88 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___88 = 0,
		RTNL_LINK_INITIALIZING___88 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___88 *);
	struct netpoll_info *npinfo;
	possible_net_t___88 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___260 dev;
	const struct attribute_group___267 *sysfs_groups[4];
	const struct attribute_group___267 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___82 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___88 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___82 xdp_state[3];
	long: 64;
};

struct neigh_table___75;

struct neigh_parms___75;

struct neigh_ops___75;

struct neighbour___75 {
	struct neighbour___75 *next;
	struct neigh_table___75 *tbl;
	struct neigh_parms___75 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___88 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___75 *, struct sk_buff___89 *);
	const struct neigh_ops___75 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___88 *dev;
	u8 primary_key[0];
};

struct rtable___25;

struct fnhe_hash_bucket___23;

struct fib_nh_common___23 {
	struct net_device___88 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___51 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___25 **nhc_pcpu_rth_output;
	struct rtable___25 *nhc_rth_input;
	struct fnhe_hash_bucket___23 *nhc_exceptions;
};

struct fib6_nh___23 {
	struct fib_nh_common___23 nh_common;
	long unsigned int last_probe;
	struct rt6_info___23 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___23;

struct nexthop___14;

struct fib6_info___23 {
	struct fib6_table___23 *fib6_table;
	struct fib6_info___23 *fib6_next;
	struct fib6_node___23 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___14 *nh;
	struct fib6_nh___23 fib6_nh[0];
};

struct rt6_info___23 {
	struct dst_entry___75 dst;
	struct fib6_info___23 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___57 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___23 {
	struct fib6_node___23 *parent;
	struct fib6_node___23 *left;
	struct fib6_node___23 *right;
	struct fib6_node___23 *subtree;
	struct fib6_info___23 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___23 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___23 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___23 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___82 {
	struct bpf_prog___82 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___82 {
	struct callback_head rcu;
	struct bpf_prog_array_item___82 items[0];
};

struct bpf_prog_aux___91;

struct bpf_prog___82 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___91 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___256;

struct fwnode_handle___256 {
	struct fwnode_handle___256 *secondary;
	const struct fwnode_operations___256 *ops;
	struct device___260 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___256;

struct fwnode_endpoint___256;

struct fwnode_operations___256 {
	struct fwnode_handle___256 * (*get)(struct fwnode_handle___256 *);
	void (*put)(struct fwnode_handle___256 *);
	bool (*device_is_available)(const struct fwnode_handle___256 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___256 *, const struct device___260 *);
	bool (*property_present)(const struct fwnode_handle___256 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___256 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___256 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___256 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*get_parent)(const struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*get_next_child_node)(const struct fwnode_handle___256 *, struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*get_named_child_node)(const struct fwnode_handle___256 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___256 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___256 *);
	struct fwnode_handle___256 * (*graph_get_next_endpoint)(const struct fwnode_handle___256 *, struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*graph_get_remote_endpoint)(const struct fwnode_handle___256 *);
	struct fwnode_handle___256 * (*graph_get_port_parent)(struct fwnode_handle___256 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___256 *, struct fwnode_endpoint___256 *);
	int (*add_links)(struct fwnode_handle___256 *);
};

struct fwnode_endpoint___256 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___256 *local_fwnode;
};

struct fwnode_reference_args___256 {
	struct fwnode_handle___256 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___206 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___206 *root_cset;
};

struct socket_wq___76 {
	wait_queue_head_t wait;
	struct fasync_struct___279 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___76;

struct socket___77 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___279 *file;
	struct sock___75 *sk;
	const struct proto_ops___76 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___76 wq;
};

typedef int (*sk_read_actor_t___75)(read_descriptor_t *, struct sk_buff___89 *, unsigned int, size_t);

struct proto_ops___76 {
	int family;
	struct module___263 *owner;
	int (*release)(struct socket___77 *);
	int (*bind)(struct socket___77 *, struct sockaddr *, int);
	int (*connect)(struct socket___77 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___77 *, struct socket___77 *);
	int (*accept)(struct socket___77 *, struct socket___77 *, int, bool);
	int (*getname)(struct socket___77 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___279 *, struct socket___77 *, struct poll_table_struct___200 *);
	int (*ioctl)(struct socket___77 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___77 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___77 *, void *, bool, bool);
	int (*listen)(struct socket___77 *, int);
	int (*shutdown)(struct socket___77 *, int);
	int (*setsockopt)(struct socket___77 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___77 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___254 *, struct socket___77 *);
	int (*sendmsg)(struct socket___77 *, struct msghdr___77 *, size_t);
	int (*recvmsg)(struct socket___77 *, struct msghdr___77 *, size_t, int);
	int (*mmap)(struct file___279 *, struct socket___77 *, struct vm_area_struct___284 *);
	ssize_t (*sendpage)(struct socket___77 *, struct page___284 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___77 *, loff_t *, struct pipe_inode_info___120 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___75 *, int);
	int (*peek_len)(struct socket___77 *);
	int (*read_sock)(struct sock___75 *, read_descriptor_t *, sk_read_actor_t___75);
	int (*sendpage_locked)(struct sock___75 *, struct page___284 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___75 *, struct msghdr___77 *, size_t);
	int (*set_rcvlowat)(struct sock___75 *, int);
};

struct dev_pm_ops___260 {
	int (*prepare)(struct device___260 *);
	void (*complete)(struct device___260 *);
	int (*suspend)(struct device___260 *);
	int (*resume)(struct device___260 *);
	int (*freeze)(struct device___260 *);
	int (*thaw)(struct device___260 *);
	int (*poweroff)(struct device___260 *);
	int (*restore)(struct device___260 *);
	int (*suspend_late)(struct device___260 *);
	int (*resume_early)(struct device___260 *);
	int (*freeze_late)(struct device___260 *);
	int (*thaw_early)(struct device___260 *);
	int (*poweroff_late)(struct device___260 *);
	int (*restore_early)(struct device___260 *);
	int (*suspend_noirq)(struct device___260 *);
	int (*resume_noirq)(struct device___260 *);
	int (*freeze_noirq)(struct device___260 *);
	int (*thaw_noirq)(struct device___260 *);
	int (*poweroff_noirq)(struct device___260 *);
	int (*restore_noirq)(struct device___260 *);
	int (*runtime_suspend)(struct device___260 *);
	int (*runtime_resume)(struct device___260 *);
	int (*runtime_idle)(struct device___260 *);
};

struct wakeup_source___260 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___260 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___260 {
	struct dev_pm_ops___260 ops;
	int (*start)(struct device___260 *);
	void (*detach)(struct device___260 *, bool);
	int (*activate)(struct device___260 *);
	void (*sync)(struct device___260 *);
	void (*dismiss)(struct device___260 *);
};

struct bus_type___260 {
	const char *name;
	const char *dev_name;
	struct device___260 *dev_root;
	const struct attribute_group___267 **bus_groups;
	const struct attribute_group___267 **dev_groups;
	const struct attribute_group___267 **drv_groups;
	int (*match)(struct device___260 *, struct device_driver___260 *);
	int (*uevent)(struct device___260 *, struct kobj_uevent_env *);
	int (*probe)(struct device___260 *);
	void (*sync_state)(struct device___260 *);
	void (*remove)(struct device___260 *);
	void (*shutdown)(struct device___260 *);
	int (*online)(struct device___260 *);
	int (*offline)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	int (*num_vf)(struct device___260 *);
	int (*dma_configure)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___260 {
	const char *name;
	struct bus_type___260 *bus;
	struct module___263 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___260 *);
	void (*sync_state)(struct device___260 *);
	int (*remove)(struct device___260 *);
	void (*shutdown)(struct device___260 *);
	int (*suspend)(struct device___260 *, pm_message_t);
	int (*resume)(struct device___260 *);
	const struct attribute_group___267 **groups;
	const struct attribute_group___267 **dev_groups;
	const struct dev_pm_ops___260 *pm;
	void (*coredump)(struct device___260 *);
	struct driver_private *p;
};

struct device_type___260 {
	const char *name;
	const struct attribute_group___267 **groups;
	int (*uevent)(struct device___260 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___260 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___260 *);
	const struct dev_pm_ops___260 *pm;
};

struct class___260 {
	const char *name;
	struct module___263 *owner;
	const struct attribute_group___267 **class_groups;
	const struct attribute_group___267 **dev_groups;
	struct kobject___267 *dev_kobj;
	int (*dev_uevent)(struct device___260 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___260 *, umode_t *);
	void (*class_release)(struct class___260 *);
	void (*dev_release)(struct device___260 *);
	int (*shutdown_pre)(struct device___260 *);
	const struct kobj_ns_type_operations___75 *ns_type;
	const void * (*namespace)(struct device___260 *);
	void (*get_ownership)(struct device___260 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___260 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___120;

struct pipe_buffer___120 {
	struct page___284 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___120 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___120 {
	int (*confirm)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
	void (*release)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
	bool (*try_steal)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
	bool (*get)(struct pipe_inode_info___120 *, struct pipe_buffer___120 *);
};

struct seq_operations___254 {
	void * (*start)(struct seq_file___254 *, loff_t *);
	void (*stop)(struct seq_file___254 *, void *);
	void * (*next)(struct seq_file___254 *, void *, loff_t *);
	int (*show)(struct seq_file___254 *, void *);
};

struct pernet_operations___29 {
	struct list_head list;
	int (*init)(struct net___93 *);
	void (*pre_exit)(struct net___93 *);
	void (*exit)(struct net___93 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___88 {
	int (*ieee_getets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___88 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___88 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___88 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___88 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___88 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___88 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___88 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___88 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___88 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___88 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___88 *);
	u8 (*setstate)(struct net_device___88 *, u8);
	void (*getpermhwaddr)(struct net_device___88 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___88 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___88 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___88 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___88 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___88 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___88 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___88 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___88 *, int, u8 *);
	void (*setpfccfg)(struct net_device___88 *, int, u8);
	void (*getpfccfg)(struct net_device___88 *, int, u8 *);
	u8 (*setall)(struct net_device___88 *);
	u8 (*getcap)(struct net_device___88 *, int, u8 *);
	int (*getnumtcs)(struct net_device___88 *, int, u8 *);
	int (*setnumtcs)(struct net_device___88 *, int, u8);
	u8 (*getpfcstate)(struct net_device___88 *);
	void (*setpfcstate)(struct net_device___88 *, u8);
	void (*getbcncfg)(struct net_device___88 *, int, u32 *);
	void (*setbcncfg)(struct net_device___88 *, int, u32);
	void (*getbcnrp)(struct net_device___88 *, int, u8 *);
	void (*setbcnrp)(struct net_device___88 *, int, u8);
	int (*setapp)(struct net_device___88 *, u8, u16, u8);
	int (*getapp)(struct net_device___88 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___88 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___88 *, int, u8);
	u8 (*getdcbx)(struct net_device___88 *);
	u8 (*setdcbx)(struct net_device___88 *, u8);
	int (*peer_getappinfo)(struct net_device___88 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___88 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___88 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___88 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___88 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___88 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___91;

typedef int (*bpf_iter_init_seq_priv_t___90)(void *, struct bpf_iter_aux_info___91 *);

struct bpf_map___91;

struct bpf_iter_aux_info___91 {
	struct bpf_map___91 *map;
};

struct bpf_iter_seq_info___90 {
	const struct seq_operations___254 *seq_ops;
	bpf_iter_init_seq_priv_t___90 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___90 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___91 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___91 *, struct file___279 *);
	void (*map_free)(struct bpf_map___91 *);
	int (*map_get_next_key)(struct bpf_map___91 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___91 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___91 *, void *);
	int (*map_lookup_batch)(struct bpf_map___91 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___91 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___91 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___91 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___91 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___91 *, void *);
	int (*map_update_elem)(struct bpf_map___91 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___91 *, void *);
	int (*map_push_elem)(struct bpf_map___91 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___91 *, void *);
	int (*map_peek_elem)(struct bpf_map___91 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___91 *, struct file___279 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___91 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___91 *, void *, struct seq_file___254 *);
	int (*map_check_btf)(const struct bpf_map___91 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___91 *, struct bpf_prog_aux___91 *);
	void (*map_poke_untrack)(struct bpf_map___91 *, struct bpf_prog_aux___91 *);
	void (*map_poke_run)(struct bpf_map___91 *, u32, struct bpf_prog___82 *, struct bpf_prog___82 *);
	int (*map_direct_value_addr)(const struct bpf_map___91 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___91 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___91 *, struct vm_area_struct___284 *);
	__poll_t (*map_poll)(struct bpf_map___91 *, struct file___279 *, struct poll_table_struct___200 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___91 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___91 *, const struct bpf_map___91 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___91 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___90 *iter_seq_info;
};

struct bpf_map___91 {
	const struct bpf_map_ops___90 *ops;
	struct bpf_map___91 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___144 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___90;

struct bpf_jit_poke_descriptor___90;

struct bpf_prog_ops___82;

struct btf_mod_pair___90;

struct bpf_prog_offload___88;

struct bpf_prog_aux___91 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___82 *dst_prog;
	struct bpf_trampoline___90 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___82 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___90 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___82 *ops;
	struct bpf_map___91 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___90 *used_btfs;
	struct bpf_prog___82 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___91 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___88 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___88;

struct bpf_map_dev_ops___88 {
	int (*map_get_next_key)(struct bpf_offloaded_map___88 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___88 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___88 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___88 *, void *);
};

struct bpf_offloaded_map___88 {
	struct bpf_map___91 map;
	struct net_device___88 *netdev;
	const struct bpf_map_dev_ops___88 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___82 {
	int (*test_run)(struct bpf_prog___82 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___88 {
	struct bpf_prog___82 *prog;
	struct net_device___88 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___90 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___82 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___263 *mod;
};

struct bpf_jit_poke_descriptor___90 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___91 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___90 {
	struct btf *btf;
	struct module___263 *module;
};

struct cftype___206;

struct cgroup_subsys___206 {
	struct cgroup_subsys_state___206 * (*css_alloc)(struct cgroup_subsys_state___206 *);
	int (*css_online)(struct cgroup_subsys_state___206 *);
	void (*css_offline)(struct cgroup_subsys_state___206 *);
	void (*css_released)(struct cgroup_subsys_state___206 *);
	void (*css_free)(struct cgroup_subsys_state___206 *);
	void (*css_reset)(struct cgroup_subsys_state___206 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___206 *, int);
	int (*css_extra_stat_show)(struct seq_file___254 *, struct cgroup_subsys_state___206 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___286 *, struct css_set___206 *);
	void (*cancel_fork)(struct task_struct___286 *, struct css_set___206 *);
	void (*fork)(struct task_struct___286 *);
	void (*exit)(struct task_struct___286 *);
	void (*release)(struct task_struct___286 *);
	void (*bind)(struct cgroup_subsys_state___206 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___206 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___206 *dfl_cftypes;
	struct cftype___206 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___206 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___206 *updated_children;
	struct cgroup___206 *updated_next;
};

struct cgroup_root___206 {
	struct kernfs_root___267 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___206 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___206 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___206 *ss;
	struct list_head node;
	struct kernfs_ops___267 *kf_ops;
	int (*open)(struct kernfs_open_file___267 *);
	void (*release)(struct kernfs_open_file___267 *);
	u64 (*read_u64)(struct cgroup_subsys_state___206 *, struct cftype___206 *);
	s64 (*read_s64)(struct cgroup_subsys_state___206 *, struct cftype___206 *);
	int (*seq_show)(struct seq_file___254 *, void *);
	void * (*seq_start)(struct seq_file___254 *, loff_t *);
	void * (*seq_next)(struct seq_file___254 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___254 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___206 *, struct cftype___206 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___206 *, struct cftype___206 *, s64);
	ssize_t (*write)(struct kernfs_open_file___267 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___267 *, struct poll_table_struct___200 *);
};

struct xdp_rxq_info___88 {
	struct net_device___88 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___88 {
	struct net_device___88 *dev;
};

struct xdp_buff___88 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___88 *rxq;
	struct xdp_txq_info___88 *txq;
	u32 frame_sz;
};

struct xdp_frame___88 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___88 *dev_rx;
};

struct netlink_skb_parms___17 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___75 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_kernel_cfg___6 {
	unsigned int groups;
	unsigned int flags;
	void (*input)(struct sk_buff___89 *);
	struct mutex *cb_mutex;
	int (*bind)(struct net___93 *, int);
	void (*unbind)(struct net___93 *, int);
	bool (*compare)(struct net___93 *, struct sock___75 *);
};

struct netlink_callback___88 {
	struct sk_buff___89 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___89 *, struct netlink_callback___88 *);
	int (*done)(struct netlink_callback___88 *);
	void *data;
	struct module___263 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___88 {
	int (*create)(struct sk_buff___89 *, struct net_device___88 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___89 *, unsigned char *);
	int (*cache)(const struct neighbour___75 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___88 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___89 *);
};

struct netdev_queue___88 {
	struct net_device___88 *dev;
	struct Qdisc___82 *qdisc;
	struct Qdisc___82 *qdisc_sleeping;
	struct kobject___267 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___88 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___82 {
	struct sk_buff___89 *head;
	struct sk_buff___89 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___82;

struct Qdisc___82 {
	int (*enqueue)(struct sk_buff___89 *, struct Qdisc___82 *, struct sk_buff___89 **);
	struct sk_buff___89 * (*dequeue)(struct Qdisc___82 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___82 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___88 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___88 gso_skb;
	struct qdisc_skb_head___82 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___82 *next_sched;
	struct sk_buff_head___88 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___88 {
	struct xdp_rxq_info___88 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___267 kobj;
	struct net_device___88 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___88 {
	enum net_device_path_type type;
	const struct net_device___88 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___88 = 0,
				DEV_PATH_BR_VLAN_TAG___88 = 1,
				DEV_PATH_BR_VLAN_UNTAG___88 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___88 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___88 {
	const struct net_device___88 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___88 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___82 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___88 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___88 {
	int (*xdo_dev_state_add)(struct xfrm_state___17 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___17 *);
	void (*xdo_dev_state_free)(struct xfrm_state___17 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___89 *, struct xfrm_state___17 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___17 *);
};

struct xfrm_state_offload___17 {
	struct net_device___88 *dev;
	struct net_device___88 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___17;

struct xfrm_type_offload___17;

struct xfrm_state___17 {
	possible_net_t___88 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	long: 64;
	long: 64;
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___75 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___17 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___17 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___284 xfrag;
	const struct xfrm_type___17 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___17 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___88 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___88 *dev;
	const char *name;
};

struct net_device_ops___88 {
	int (*ndo_init)(struct net_device___88 *);
	void (*ndo_uninit)(struct net_device___88 *);
	int (*ndo_open)(struct net_device___88 *);
	int (*ndo_stop)(struct net_device___88 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___89 *, struct net_device___88 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___89 *, struct net_device___88 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___88 *, struct sk_buff___89 *, struct net_device___88 *);
	void (*ndo_change_rx_flags)(struct net_device___88 *, int);
	void (*ndo_set_rx_mode)(struct net_device___88 *);
	int (*ndo_set_mac_address)(struct net_device___88 *, void *);
	int (*ndo_validate_addr)(struct net_device___88 *);
	int (*ndo_do_ioctl)(struct net_device___88 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___88 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___88 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___88 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___88 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___88 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___88 *, int);
	int (*ndo_neigh_setup)(struct net_device___88 *, struct neigh_parms___75 *);
	void (*ndo_tx_timeout)(struct net_device___88 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___88 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___88 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___88 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___88 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___88 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___88 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___88 *);
	int (*ndo_netpoll_setup)(struct net_device___88 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___88 *);
	int (*ndo_set_vf_mac)(struct net_device___88 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___88 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___88 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___88 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___88 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___88 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___88 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___88 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___88 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___88 *, int, struct sk_buff___89 *);
	int (*ndo_get_vf_guid)(struct net_device___88 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___88 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___88 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___88 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___88 *);
	int (*ndo_fcoe_disable)(struct net_device___88 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___88 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___88 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___88 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___88 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___88 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___88 *, const struct sk_buff___89 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___88 *, struct net_device___88 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___88 *, struct net_device___88 *);
	struct net_device___88 * (*ndo_get_xmit_slave)(struct net_device___88 *, struct sk_buff___89 *, bool);
	struct net_device___88 * (*ndo_sk_get_lower_dev)(struct net_device___88 *, struct sock___75 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___88 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___88 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___88 *, struct neighbour___75 *);
	void (*ndo_neigh_destroy)(struct net_device___88 *, struct neighbour___75 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___89 *, struct netlink_callback___88 *, struct net_device___88 *, struct net_device___88 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___89 *, struct nlattr **, struct net_device___88 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___88 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___89 *, u32, u32, struct net_device___88 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___88 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___88 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___88 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___88 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___88 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___88 *, struct net_device___88 *);
	void (*ndo_dfwd_del_station)(struct net_device___88 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___88 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___88 *);
	int (*ndo_change_proto_down)(struct net_device___88 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___88 *, struct sk_buff___89 *);
	void (*ndo_set_rx_headroom)(struct net_device___88 *, int);
	int (*ndo_bpf)(struct net_device___88 *, struct netdev_bpf___88 *);
	int (*ndo_xdp_xmit)(struct net_device___88 *, int, struct xdp_frame___88 **, u32);
	struct net_device___88 * (*ndo_xdp_get_xmit_slave)(struct net_device___88 *, struct xdp_buff___88 *);
	int (*ndo_xsk_wakeup)(struct net_device___88 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___88 *);
	int (*ndo_tunnel_ctl)(struct net_device___88 *, struct ip_tunnel_parm *, int);
	struct net_device___88 * (*ndo_get_peer_dev)(struct net_device___88 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___88 *, struct net_device_path___88 *);
};

struct neigh_parms___75 {
	possible_net_t___88 net;
	struct net_device___88 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___75 *);
	struct neigh_table___75 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___75 {
	u32 (*l3mdev_fib_table)(const struct net_device___88 *);
	struct sk_buff___89 * (*l3mdev_l3_rcv)(struct net_device___88 *, struct sk_buff___89 *, u16);
	struct sk_buff___89 * (*l3mdev_l3_out)(struct net_device___88 *, struct sock___75 *, struct sk_buff___89 *, u16);
	struct dst_entry___75 * (*l3mdev_link_scope_lookup)(const struct net_device___88 *, struct flowi6 *);
};

struct ndisc_ops___57 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___88 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___88 *, struct neighbour___75 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___88 *, u8, struct neighbour___75 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___88 *, struct sk_buff___89 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___93 *, struct net_device___88 *, const struct prefix_info *, struct inet6_dev___57 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___16;

struct in_device___16 {
	struct net_device___88 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___16 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___75 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___57;

struct ifacaddr6___23;

struct inet6_dev___57 {
	struct net_device___88 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___57 *mc_list;
	struct ifmcaddr6___57 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___88 mc_query_queue;
	struct sk_buff_head___88 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___23 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___75 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___82;

struct tcf_block___82;

struct mini_Qdisc___82 {
	struct tcf_proto___82 *filter_list;
	struct tcf_block___82 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___82 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___88 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___88 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___93 *, struct net_device___88 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___88 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___88 *, struct list_head *);
	size_t (*get_size)(const struct net_device___88 *);
	int (*fill_info)(struct sk_buff___89 *, const struct net_device___88 *);
	size_t (*get_xstats_size)(const struct net_device___88 *);
	int (*fill_xstats)(struct sk_buff___89 *, const struct net_device___88 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___88 *, struct net_device___88 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___88 *, const struct net_device___88 *);
	int (*fill_slave_info)(struct sk_buff___89 *, const struct net_device___88 *, const struct net_device___88 *);
	struct net___93 * (*get_link_net)(const struct net_device___88 *);
	size_t (*get_linkxstats_size)(const struct net_device___88 *, int);
	int (*fill_linkxstats)(struct sk_buff___89 *, const struct net_device___88 *, int *, int);
};

struct netdev_notifier_info___16 {
	struct net_device___88 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_info_ext___2 {
	struct netdev_notifier_info___16 info;
	union {
		u32 mtu;
	} ext;
};

struct netdev_notifier_changeupper_info___6 {
	struct netdev_notifier_info___16 info;
	struct net_device___88 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct in_ifaddr___16 {
	struct hlist_node hash;
	struct in_ifaddr___16 *ifa_next;
	struct in_device___16 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct block_device_operations___170;

struct gendisk___173 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___173 *part0;
	const struct block_device_operations___170 *fops;
	struct request_queue___170 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___156 *bdi;
	struct kobject___267 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___267 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___170 {
	struct bio___170 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___196 *bip_vec;
	struct bio_vec___196 bip_inline_vecs[0];
};

struct blkcg___158;

struct blkg_policy_data___158;

struct blkcg_gq___158 {
	struct request_queue___170 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___158 *blkcg;
	struct blkcg_gq___158 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___158 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___170 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___170(struct request___170 *);

typedef void integrity_complete_fn___170(struct request___170 *, unsigned int);

struct blk_integrity_profile___170 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___170 *prepare_fn;
	integrity_complete_fn___170 *complete_fn;
	const char *name;
};

struct block_device_operations___170 {
	blk_qc_t (*submit_bio)(struct bio___170 *);
	int (*open)(struct block_device___173 *, fmode_t);
	void (*release)(struct gendisk___173 *, fmode_t);
	int (*rw_page)(struct block_device___173 *, sector_t, struct page___284 *, unsigned int);
	int (*ioctl)(struct block_device___173 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___173 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___173 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___173 *);
	int (*getgeo)(struct block_device___173 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___173 *, bool);
	void (*swap_slot_free_notify)(struct block_device___173 *, long unsigned int);
	int (*report_zones)(struct gendisk___173 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___173 *, umode_t *);
	struct module___263 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___173 *, sector_t *);
};

typedef void rq_end_io_fn___170(struct request___170 *, blk_status_t);

struct request___170 {
	struct request_queue___170 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___165 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___170 *bio;
	struct bio___170 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___196 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___170 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___170 *saved_end_io;
		} flush;
	};
	struct gendisk___173 *rq_disk;
	struct block_device___173 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___170 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___165 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___170 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___267 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___279 *debugfs_dir;
	struct dentry___279 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___170;

struct elevator_mq_ops___170 {
	int (*init_sched)(struct request_queue___170 *, struct elevator_type___170 *);
	void (*exit_sched)(struct elevator_queue___170 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___165 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___165 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___165 *);
	bool (*allow_merge)(struct request_queue___170 *, struct request___170 *, struct bio___170 *);
	bool (*bio_merge)(struct request_queue___170 *, struct bio___170 *, unsigned int);
	int (*request_merge)(struct request_queue___170 *, struct request___170 **, struct bio___170 *);
	void (*request_merged)(struct request_queue___170 *, struct request___170 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___170 *, struct request___170 *, struct request___170 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___170 *);
	void (*finish_request)(struct request___170 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___165 *, struct list_head *, bool);
	struct request___170 * (*dispatch_request)(struct blk_mq_hw_ctx___165 *);
	bool (*has_work)(struct blk_mq_hw_ctx___165 *);
	void (*completed_request)(struct request___170 *, u64);
	void (*requeue_request)(struct request___170 *);
	struct request___170 * (*former_request)(struct request_queue___170 *, struct request___170 *);
	struct request___170 * (*next_request)(struct request_queue___170 *, struct request___170 *);
	void (*init_icq)(struct io_cq___170 *);
	void (*exit_icq)(struct io_cq___170 *);
};

struct elv_fs_entry___170;

struct elevator_type___170 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___170 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___170 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___263 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___170 {
	struct elevator_type___170 *type;
	void *elevator_data;
	struct kobject___267 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___170 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___170 *, char *);
	ssize_t (*store)(struct elevator_queue___170 *, const char *, size_t);
};

struct blk_mq_queue_data___165;

struct blk_mq_ops___165 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___165 *, const struct blk_mq_queue_data___165 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___165 *);
	int (*get_budget)(struct request_queue___170 *);
	void (*put_budget)(struct request_queue___170 *, int);
	void (*set_rq_budget_token)(struct request___170 *, int);
	int (*get_rq_budget_token)(struct request___170 *);
	enum blk_eh_timer_return (*timeout)(struct request___170 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___165 *);
	void (*complete)(struct request___170 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___165 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___165 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___165 *, struct request___170 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___165 *, struct request___170 *, unsigned int);
	void (*initialize_rq_fn)(struct request___170 *);
	void (*cleanup_rq)(struct request___170 *);
	bool (*busy)(struct request_queue___170 *);
	int (*map_queues)(struct blk_mq_tag_set___165 *);
	void (*show_rq)(struct seq_file___254 *, struct request___170 *);
};

struct blk_mq_tag_set___165 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___165 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___165 {
	struct request___170 *rq;
	bool last;
};

struct blkcg_policy_data___158;

struct blkcg___158 {
	struct cgroup_subsys_state___206 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___158 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___158 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___158 {
	struct blkcg___158 *blkcg;
	int plid;
};

struct blkg_policy_data___158 {
	struct blkcg_gq___158 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___144 {
	struct mem_cgroup___144 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___144 {
	struct lruvec___152 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___144 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___144 *memcg;
};

struct obj_cgroup___144 {
	struct percpu_ref refcnt;
	struct mem_cgroup___144 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___82 {
	spinlock_t *lock;
	struct sk_buff___89 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___8 {
	struct nlmsghdr *nlh;
	struct net___93 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

typedef int (*rtnl_doit_func___10)(struct sk_buff___89 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___10)(struct sk_buff___89 *, struct netlink_callback___88 *);

struct Qdisc_class_ops___82;

struct Qdisc_ops___82 {
	struct Qdisc_ops___82 *next;
	const struct Qdisc_class_ops___82 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___89 *, struct Qdisc___82 *, struct sk_buff___89 **);
	struct sk_buff___89 * (*dequeue)(struct Qdisc___82 *);
	struct sk_buff___89 * (*peek)(struct Qdisc___82 *);
	int (*init)(struct Qdisc___82 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___82 *);
	void (*destroy)(struct Qdisc___82 *);
	int (*change)(struct Qdisc___82 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___82 *);
	int (*change_tx_queue_len)(struct Qdisc___82 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___82 *, unsigned int);
	int (*dump)(struct Qdisc___82 *, struct sk_buff___89 *);
	int (*dump_stats)(struct Qdisc___82 *, struct gnet_dump___82 *);
	void (*ingress_block_set)(struct Qdisc___82 *, u32);
	void (*egress_block_set)(struct Qdisc___82 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___82 *);
	u32 (*egress_block_get)(struct Qdisc___82 *);
	struct module___263 *owner;
};

struct Qdisc_class_ops___82 {
	unsigned int flags;
	struct netdev_queue___88 * (*select_queue)(struct Qdisc___82 *, struct tcmsg *);
	int (*graft)(struct Qdisc___82 *, long unsigned int, struct Qdisc___82 *, struct Qdisc___82 **, struct netlink_ext_ack *);
	struct Qdisc___82 * (*leaf)(struct Qdisc___82 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___82 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___82 *, u32);
	int (*change)(struct Qdisc___82 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___82 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___82 *, struct qdisc_walker *);
	struct tcf_block___82 * (*tcf_block)(struct Qdisc___82 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___82 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___82 *, long unsigned int);
	int (*dump)(struct Qdisc___82 *, long unsigned int, struct sk_buff___89 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___82 *, long unsigned int, struct gnet_dump___82 *);
};

struct tcf_chain___82;

struct tcf_block___82 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___93 *net;
	struct Qdisc___82 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___82 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___82;

struct tcf_proto_ops___82;

struct tcf_proto___82 {
	struct tcf_proto___82 *next;
	void *root;
	int (*classify)(struct sk_buff___89 *, const struct tcf_proto___82 *, struct tcf_result___82 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___82 *ops;
	struct tcf_chain___82 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___82 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___82 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___82 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___89 *, const struct tcf_proto___82 *, struct tcf_result___82 *);
	int (*init)(struct tcf_proto___82 *);
	void (*destroy)(struct tcf_proto___82 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___82 *, u32);
	void (*put)(struct tcf_proto___82 *, void *);
	int (*change)(struct net___93 *, struct sk_buff___89 *, struct tcf_proto___82 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___82 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___82 *);
	void (*walk)(struct tcf_proto___82 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___82 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___82 *, void *);
	void (*hw_del)(struct tcf_proto___82 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___93 *, struct tcf_chain___82 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___93 *, struct tcf_proto___82 *, void *, struct sk_buff___89 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___93 *, struct tcf_proto___82 *, void *, struct sk_buff___89 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___89 *, struct net___93 *, void *);
	struct module___263 *owner;
	int flags;
};

struct tcf_chain___82 {
	struct mutex filter_chain_lock;
	struct tcf_proto___82 *filter_chain;
	struct list_head list;
	struct tcf_block___82 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___82 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___75 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___82 *prog;
};

struct pneigh_entry___75;

struct neigh_hash_table___75;

struct neigh_table___75 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___88 *, __u32 *);
	bool (*key_eq)(const struct neighbour___75 *, const void *);
	int (*constructor)(struct neighbour___75 *);
	int (*pconstructor)(struct pneigh_entry___75 *);
	void (*pdestructor)(struct pneigh_entry___75 *);
	void (*proxy_redo)(struct sk_buff___89 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___88 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___75 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___88 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___75 *nht;
	struct pneigh_entry___75 **phash_buckets;
};

struct neigh_ops___75 {
	int family;
	void (*solicit)(struct neighbour___75 *, struct sk_buff___89 *);
	void (*error_report)(struct neighbour___75 *, struct sk_buff___89 *);
	int (*output)(struct neighbour___75 *, struct sk_buff___89 *);
	int (*connected_output)(struct neighbour___75 *, struct sk_buff___89 *);
};

struct pneigh_entry___75 {
	struct pneigh_entry___75 *next;
	possible_net_t___88 net;
	struct net_device___88 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___75 {
	struct neighbour___75 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___51 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___93 *, struct sock___75 *, struct sk_buff___89 *);
	int (*orig_input)(struct sk_buff___89 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___75 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___75 *ctarget;
	struct net___93 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___75 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___75 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___60;

struct timewait_sock_ops___59;

struct proto___75 {
	void (*close)(struct sock___75 *, long int);
	int (*pre_connect)(struct sock___75 *, struct sockaddr *, int);
	int (*connect)(struct sock___75 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___75 *, int);
	struct sock___75 * (*accept)(struct sock___75 *, int, int *, bool);
	int (*ioctl)(struct sock___75 *, int, long unsigned int);
	int (*init)(struct sock___75 *);
	void (*destroy)(struct sock___75 *);
	void (*shutdown)(struct sock___75 *, int);
	int (*setsockopt)(struct sock___75 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___75 *, int, int, char *, int *);
	void (*keepalive)(struct sock___75 *, int);
	int (*compat_ioctl)(struct sock___75 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___75 *, struct msghdr___77 *, size_t);
	int (*recvmsg)(struct sock___75 *, struct msghdr___77 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___75 *, struct page___284 *, int, size_t, int);
	int (*bind)(struct sock___75 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___75 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___75 *, struct sk_buff___89 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___75 *);
	int (*hash)(struct sock___75 *);
	void (*unhash)(struct sock___75 *);
	void (*rehash)(struct sock___75 *);
	int (*get_port)(struct sock___75 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___75 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___75 *, int);
	bool (*sock_is_readable)(struct sock___75 *);
	void (*enter_memory_pressure)(struct sock___75 *);
	void (*leave_memory_pressure)(struct sock___75 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___60 *rsk_prot;
	struct timewait_sock_ops___59 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___263 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___75 *, int);
};

struct xfrm_policy_queue___17 {
	struct sk_buff_head___88 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___17 {
	possible_net_t___88 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___17 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___25 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___82 *prog;
	struct sock___75 *socks[0];
};

struct request_sock___61;

struct request_sock_ops___60 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___75 *, struct request_sock___61 *);
	void (*send_ack)(const struct sock___75 *, struct sk_buff___89 *, struct request_sock___61 *);
	void (*send_reset)(const struct sock___75 *, struct sk_buff___89 *);
	void (*destructor)(struct request_sock___61 *);
	void (*syn_ack_timeout)(const struct request_sock___61 *);
};

struct timewait_sock_ops___59 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___75 *, struct sock___75 *, void *);
	void (*twsk_destructor)(struct sock___75 *);
};

struct request_sock___61 {
	struct sock_common___75 __req_common;
	struct request_sock___61 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___60 *rsk_ops;
	struct sock___75 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___57 {
	struct in6_addr mca_addr;
	struct inet6_dev___57 *idev;
	struct ifmcaddr6___57 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___23 {
	struct in6_addr aca_addr;
	struct fib6_info___23 *aca_rt;
	struct ifacaddr6___23 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_config {
	u8 fc_dst_len;
	u8 fc_tos;
	u8 fc_protocol;
	u8 fc_scope;
	u8 fc_type;
	u8 fc_gw_family;
	u32 fc_table;
	__be32 fc_dst;
	union {
		__be32 fc_gw4;
		struct in6_addr fc_gw6;
	};
	int fc_oif;
	u32 fc_flags;
	u32 fc_priority;
	__be32 fc_prefsrc;
	u32 fc_nh_id;
	struct nlattr *fc_mx;
	struct rtnexthop *fc_mp;
	int fc_mx_len;
	int fc_mp_len;
	u32 fc_flow;
	u32 fc_nlflags;
	struct nl_info___8 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
};

struct fib_nh_exception___23 {
	struct fib_nh_exception___23 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___25 *fnhe_rth_input;
	struct rtable___25 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___25 {
	struct dst_entry___75 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___23 {
	struct fib_nh_exception___23 *chain;
};

struct fib_info___14;

struct fib_nh___14 {
	struct fib_nh_common___23 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___14 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___14 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___93 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___14 *nh;
	struct callback_head rcu;
	struct fib_nh___14 fib_nh[0];
};

struct nh_info___14;

struct nh_group___14;

struct nexthop___14 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___93 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___14 *nh_info;
		struct nh_group___14 *nh_grp;
	};
};

struct fib_result___3 {
	__be32 prefix;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	u32 tclassid;
	struct fib_nh_common___23 *nhc;
	struct fib_info___14 *fi;
	struct fib_table *table;
	struct hlist_head *fa_head;
};

struct fib_result_nl {
	__be32 fl_addr;
	u32 fl_mark;
	unsigned char fl_tos;
	unsigned char fl_scope;
	unsigned char tb_id_in;
	unsigned char tb_id;
	unsigned char prefixlen;
	unsigned char nh_sel;
	unsigned char type;
	unsigned char scope;
	int err;
};

struct fib_dump_filter {
	u32 table_id;
	bool filter_set;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___88 *dev;
};

struct nh_info___14 {
	struct hlist_node dev_hash;
	struct nexthop___14 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___23 fib_nhc;
		struct fib_nh___14 fib_nh;
		struct fib6_nh___23 fib6_nh;
	};
};

struct nh_grp_entry___14;

struct nh_res_bucket___14 {
	struct nh_grp_entry___14 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___14 {
	struct nexthop___14 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___14 *nh_parent;
};

struct nh_res_table___14 {
	struct net___93 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___14 nh_buckets[0];
};

struct nh_group___14 {
	struct nh_group___14 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___14 *res_table;
	struct nh_grp_entry___14 nh_entries[0];
};

struct xfrm_type___17 {
	struct module___263 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___17 *);
	void (*destructor)(struct xfrm_state___17 *);
	int (*input)(struct xfrm_state___17 *, struct sk_buff___89 *);
	int (*output)(struct xfrm_state___17 *, struct sk_buff___89 *);
	int (*reject)(struct xfrm_state___17 *, struct sk_buff___89 *, const struct flowi *);
};

struct xfrm_type_offload___17 {
	struct module___263 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___17 *, struct sk_buff___89 *);
	int (*input_tail)(struct xfrm_state___17 *, struct sk_buff___89 *);
	int (*xmit)(struct xfrm_state___17 *, struct sk_buff___89 *, netdev_features_t);
};

struct fib_config___2 {
	u8 fc_dst_len;
	u8 fc_tos;
	u8 fc_protocol;
	u8 fc_scope;
	u8 fc_type;
	u8 fc_gw_family;
	u32 fc_table;
	__be32 fc_dst;
	union {
		__be32 fc_gw4;
		struct in6_addr fc_gw6;
	};
	int fc_oif;
	u32 fc_flags;
	u32 fc_priority;
	__be32 fc_prefsrc;
	u32 fc_nh_id;
	struct nlattr *fc_mx;
	struct rtnexthop *fc_mp;
	int fc_mx_len;
	int fc_mp_len;
	u32 fc_flow;
	u32 fc_nlflags;
	struct nl_info fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
};

struct fib_rt_info___2 {
	struct fib_info___12 *fi;
	u32 tb_id;
	__be32 dst;
	int dst_len;
	u8 tos;
	u8 type;
	u8 offload: 1;
	u8 trap: 1;
	u8 offload_failed: 1;
	u8 unused: 5;
	long: 59;
	long: 64;
	long: 64;
};

struct fib_nh_notifier_info {
	struct fib_notifier_info info;
	struct fib_nh___12 *fib_nh;
};

struct fib_alias___2 {
	struct hlist_node fa_list;
	struct fib_info___12 *fa_info;
	u8 fa_tos;
	u8 fa_type;
	u8 fa_state;
	u8 fa_slen;
	u32 tb_id;
	s16 fa_default;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	struct callback_head rcu;
};

struct seq_net_private___11 {
	struct net___90 *net;
};

struct netlink_skb_parms___18 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___72 *sk;
	bool nsid_is_set;
	int nsid;
};

struct fib_entry_notifier_info {
	struct fib_notifier_info info;
	u32 dst;
	int dst_len;
	struct fib_info___12 *fi;
	u8 tos;
	u8 type;
	u32 tb_id;
};

struct fib_dump_filter___2 {
	u32 table_id;
	bool filter_set;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___85 *dev;
};

typedef unsigned int t_key;

struct key_vector {
	t_key key;
	unsigned char pos;
	unsigned char bits;
	unsigned char slen;
	union {
		struct hlist_head leaf;
		struct key_vector *tnode[0];
	};
};

struct tnode {
	struct callback_head rcu;
	t_key empty_children;
	t_key full_children;
	struct key_vector *parent;
	struct key_vector kv[1];
};

struct trie_use_stats {
	unsigned int gets;
	unsigned int backtrack;
	unsigned int semantic_match_passed;
	unsigned int semantic_match_miss;
	unsigned int null_node_hit;
	unsigned int resize_node_skipped;
};

struct trie_stat {
	unsigned int totdepth;
	unsigned int maxdepth;
	unsigned int tnodes;
	unsigned int leaves;
	unsigned int nullpointers;
	unsigned int prefixes;
	unsigned int nodesizes[32];
};

struct trie {
	struct key_vector kv[1];
	struct trie_use_stats *stats;
};

struct fib_trie_iter {
	struct seq_net_private___11 p;
	struct fib_table *tb;
	struct key_vector *tnode;
	unsigned int index;
	unsigned int depth;
};

struct fib_route_iter {
	struct seq_net_private___11 p;
	struct fib_table *main_tb;
	struct key_vector *tnode;
	loff_t pos;
	t_key key;
};

struct ipfrag_skb_cb {
	union {
		struct inet_skb_parm___2 h4;
		struct inet6_skb_parm h6;
	};
	struct sk_buff___76 *next_frag;
	int frag_run_len;
};

struct icmpv6_echo {
	__be16 identifier;
	__be16 sequence;
};

struct icmpv6_nd_advt {
	__u32 reserved: 5;
	__u32 override: 1;
	__u32 solicited: 1;
	__u32 router: 1;
	__u32 reserved2: 24;
};

struct icmpv6_nd_ra {
	__u8 hop_limit;
	__u8 reserved: 3;
	__u8 router_pref: 2;
	__u8 home_agent: 1;
	__u8 other: 1;
	__u8 managed: 1;
	__be16 rt_lifetime;
};

struct icmp6hdr {
	__u8 icmp6_type;
	__u8 icmp6_code;
	__sum16 icmp6_cksum;
	union {
		__be32 un_data32[1];
		__be16 un_data16[2];
		__u8 un_data8[4];
		struct icmpv6_echo u_echo;
		struct icmpv6_nd_advt u_nd_advt;
		struct icmpv6_nd_ra u_nd_ra;
	} icmp6_dataun;
};

typedef struct bio_vec___196 skb_frag_t___33;

struct pingv6_ops___2 {
	int (*ipv6_recv_error)(struct sock___75 *, struct msghdr___77 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___75 *, struct msghdr___77 *, struct sk_buff___89 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___75 *, struct msghdr___77 *, struct sk_buff___89 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___75 *, struct sk_buff___89 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___93 *, const struct in6_addr *, const struct net_device___88 *, int);
};

struct ping_iter_state {
	struct seq_net_private___10 p;
	int bucket;
	sa_family_t family;
};

struct pingfakehdr {
	struct icmphdr___2 icmph;
	struct msghdr___77 *msg;
	sa_family_t family;
	__wsum wcheck;
};

struct ping_table {
	struct hlist_nulls_head hash[64];
	rwlock_t lock;
};

struct dentry___280;

struct super_block___280;

struct module___264;

struct file_system_type___280 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___280 * (*mount)(struct file_system_type___280 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___280 *);
	struct module___264 *owner;
	struct file_system_type___280 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___280;

struct kiocb___280;

struct iov_iter___200;

struct poll_table_struct___201;

struct vm_area_struct___285;

struct inode___280;

struct file_lock___280;

struct page___285;

struct pipe_inode_info___121;

struct seq_file___255;

struct file_operations___281 {
	struct module___264 *owner;
	loff_t (*llseek)(struct file___280 *, loff_t, int);
	ssize_t (*read)(struct file___280 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___280 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___280 *, struct iov_iter___200 *);
	ssize_t (*write_iter)(struct kiocb___280 *, struct iov_iter___200 *);
	int (*iopoll)(struct kiocb___280 *, bool);
	int (*iterate)(struct file___280 *, struct dir_context *);
	int (*iterate_shared)(struct file___280 *, struct dir_context *);
	__poll_t (*poll)(struct file___280 *, struct poll_table_struct___201 *);
	long int (*unlocked_ioctl)(struct file___280 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___280 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___280 *, struct vm_area_struct___285 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___280 *, struct file___280 *);
	int (*flush)(struct file___280 *, fl_owner_t);
	int (*release)(struct inode___280 *, struct file___280 *);
	int (*fsync)(struct file___280 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___280 *, int);
	int (*lock)(struct file___280 *, int, struct file_lock___280 *);
	ssize_t (*sendpage)(struct file___280 *, struct page___285 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___280 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___280 *, long unsigned int);
	int (*flock)(struct file___280 *, int, struct file_lock___280 *);
	ssize_t (*splice_write)(struct pipe_inode_info___121 *, struct file___280 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___280 *, loff_t *, struct pipe_inode_info___121 *, size_t, unsigned int);
	int (*setlease)(struct file___280 *, long int, struct file_lock___280 **, void **);
	long int (*fallocate)(struct file___280 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___255 *, struct file___280 *);
	ssize_t (*copy_file_range)(struct file___280 *, loff_t, struct file___280 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___280 *, loff_t, struct file___280 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___280 *, loff_t, loff_t, int);
};

struct vmacache___285 {
	u64 seqnum;
	struct vm_area_struct___285 *vmas[4];
};

struct page_frag___285 {
	struct page___285 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___286;

struct pid___257;

struct nsproxy___266;

struct signal_struct___281;

struct bio_list___171;

struct backing_dev_info___157;

struct io_context___171;

struct css_set___207;

struct mem_cgroup___145;

struct request_queue___171;

struct vm_struct___263;

struct task_struct___287 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___287 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___286 *mm;
	struct mm_struct___286 *active_mm;
	struct vmacache___285 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___287 *real_parent;
	struct task_struct___287 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___287 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___257 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___266 *nsproxy;
	struct signal_struct___281 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___287 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___171 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___157 *backing_dev_info;
	struct io_context___171 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___207 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___121 *splice_pipe;
	struct page_frag___285 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___145 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___145 *active_memcg;
	struct request_queue___171 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___287 *oom_reaper_list;
	struct vm_struct___263 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___268;

struct kobj_type___268;

struct kernfs_node___268;

struct kobject___268 {
	const char *name;
	struct list_head entry;
	struct kobject___268 *parent;
	struct kset___268 *kset;
	struct kobj_type___268 *ktype;
	struct kernfs_node___268 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___265 {
	struct kobject___268 kobj;
	struct module___264 *mod;
	struct kobject___268 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___264 {
	struct module___264 *mod;
	struct latch_tree_node node;
};

struct module_layout___264 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___264 mtn;
};

struct module_attribute___264;

struct kernel_param___264;

struct module___264 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___265 mkobj;
	struct module_attribute___264 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___268 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___264 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___264 core_layout;
	struct module_layout___264 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___280;

struct dentry___280 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___280 *d_parent;
	struct qstr d_name;
	struct inode___280 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___280 *d_op;
	struct super_block___280 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___280;

struct address_space___280 {
	struct inode___280 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___280 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___280;

struct bdi_writeback___157;

struct inode___280 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___280 *i_op;
	struct super_block___280 *i_sb;
	struct address_space___280 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___157 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___281 *i_fop;
		void (*free_inode)(struct inode___280 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___280 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___121 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___280;

struct path___280;

struct dentry_operations___280 {
	int (*d_revalidate)(struct dentry___280 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___280 *, unsigned int);
	int (*d_hash)(const struct dentry___280 *, struct qstr *);
	int (*d_compare)(const struct dentry___280 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___280 *);
	int (*d_init)(struct dentry___280 *);
	void (*d_release)(struct dentry___280 *);
	void (*d_prune)(struct dentry___280 *);
	void (*d_iput)(struct dentry___280 *, struct inode___280 *);
	char * (*d_dname)(struct dentry___280 *, char *, int);
	struct vfsmount___280 * (*d_automount)(struct path___280 *);
	int (*d_manage)(const struct path___280 *, bool);
	struct dentry___280 * (*d_real)(struct dentry___280 *, const struct inode___280 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___280;

struct mem_dqinfo___280 {
	struct quota_format_type___280 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___280;

struct quota_info___280 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___280 *files[3];
	struct mem_dqinfo___280 info[3];
	const struct quota_format_ops___280 *ops[3];
};

struct rcuwait___281 {
	struct task_struct___287 *task;
};

struct percpu_rw_semaphore___281 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___281 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___280 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___281 rw_sem[3];
};

struct shrink_control___145;

struct shrinker___145 {
	long unsigned int (*count_objects)(struct shrinker___145 *, struct shrink_control___145 *);
	long unsigned int (*scan_objects)(struct shrinker___145 *, struct shrink_control___145 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___280;

struct dquot_operations___280;

struct quotactl_ops___280;

struct block_device___174;

struct super_block___280 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___280 *s_type;
	const struct super_operations___280 *s_op;
	const struct dquot_operations___280 *dq_op;
	const struct quotactl_ops___280 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___280 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___174 *s_bdev;
	struct backing_dev_info___157 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___280 s_dquot;
	struct sb_writers___280 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___280 *s_d_op;
	int cleancache_poolid;
	struct shrinker___145 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___280 {
	struct dentry___280 *mnt_root;
	struct super_block___280 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___280 {
	struct vfsmount___280 *mnt;
	struct dentry___280 *dentry;
};

struct pid_namespace___257;

struct upid___257 {
	int nr;
	struct pid_namespace___257 *ns;
};

struct pid_namespace___257 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___287 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___257 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___257 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___257 numbers[1];
};

typedef struct page___285 *pgtable_t___285;

struct page_pool___109;

struct dev_pagemap___275;

struct page___285 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___280 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___109 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___285 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___285 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___286 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___275 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___275;

struct vm_area_struct___285 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___285 *vm_next;
	struct vm_area_struct___285 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___286 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___275 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___280 *vm_file;
	struct file___280 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___281 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___287 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___287 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___257 *pids[4];
	struct pid___257 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___286 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___285;

struct mm_struct___286 {
	struct {
		struct vm_area_struct___285 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___280 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___285 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___287 *owner;
		struct user_namespace___26 *user_ns;
		struct file___280 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___94;

struct cgroup_namespace___207;

struct nsproxy___266 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___257 *pid_ns_for_children;
	struct net___94 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___207 *cgroup_ns;
};

struct bio___171;

struct bio_list___171 {
	struct bio___171 *head;
	struct bio___171 *tail;
};

struct cgroup_subsys_state___207;

struct bdi_writeback___157 {
	struct backing_dev_info___157 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___207 *memcg_css;
	struct cgroup_subsys_state___207 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___261;

struct backing_dev_info___157 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___157 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___261 *dev;
	char dev_name[64];
	struct device___261 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___280 *debug_dir;
};

struct io_cq___171;

struct io_context___171 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___171 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___207;

struct css_set___207 {
	struct cgroup_subsys_state___207 *subsys[14];
	refcount_t refcount;
	struct css_set___207 *dom_cset;
	struct cgroup___207 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___207 *mg_src_cgrp;
	struct cgroup___207 *mg_dst_cgrp;
	struct css_set___207 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___280;

struct pipe_buffer___121;

struct pipe_inode_info___121 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___285 *tmp_page;
	struct fasync_struct___280 *fasync_readers;
	struct fasync_struct___280 *fasync_writers;
	struct pipe_buffer___121 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___207;

struct cgroup_subsys_state___207 {
	struct cgroup___207 *cgroup;
	struct cgroup_subsys___207 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___207 *parent;
};

struct cgroup_file___207 {
	struct kernfs_node___268 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___145;

struct mem_cgroup_per_node___145;

struct mem_cgroup___145 {
	struct cgroup_subsys_state___207 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___207 events_file;
	struct cgroup_file___207 events_local_file;
	struct cgroup_file___207 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___145 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___287 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___145 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___171;

struct blk_integrity___171 {
	const struct blk_integrity_profile___171 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___171 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___171 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___171;

struct elevator_queue___171;

struct blk_mq_ops___166;

struct blk_mq_hw_ctx___166;

struct gendisk___174;

struct blkcg_gq___159;

struct blk_mq_tag_set___166;

struct request_queue___171 {
	struct request___171 *last_merge;
	struct elevator_queue___171 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___166 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___166 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___174 *disk;
	struct kobject___268 kobj;
	struct kobject___268 *mq_kobj;
	struct blk_integrity___171 integrity;
	struct device___261 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___159 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___166 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___171 bio_split;
	struct dentry___280 *debugfs_dir;
	struct dentry___280 *sched_debugfs_dir;
	struct dentry___280 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___263 {
	struct vm_struct___263 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___285 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___145 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___145 *memcg;
};

struct page_pool_params___109 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___261 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___109 {
	u32 count;
	struct page___285 *cache[128];
};

struct page_pool___109 {
	struct page_pool_params___109 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___285 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___109 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___275;

struct dev_pagemap___275 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___275 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___257 {
	rwlock_t lock;
	struct pid___257 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___280 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___280 f_path;
	struct inode___280 *f_inode;
	const struct file_operations___281 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___257 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___280 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___275;

struct vm_operations_struct___275 {
	void (*open)(struct vm_area_struct___285 *);
	void (*close)(struct vm_area_struct___285 *);
	int (*may_split)(struct vm_area_struct___285 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___285 *);
	int (*mprotect)(struct vm_area_struct___285 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___275 *);
	vm_fault_t (*huge_fault)(struct vm_fault___275 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___275 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___285 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___275 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___275 *);
	int (*access)(struct vm_area_struct___285 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___285 *);
	int (*set_policy)(struct vm_area_struct___285 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___285 *, long unsigned int);
	struct page___285 * (*find_special_page)(struct vm_area_struct___285 *, long unsigned int);
};

struct core_thread___285 {
	struct task_struct___287 *task;
	struct core_thread___285 *next;
};

struct core_state___285 {
	atomic_t nr_threads;
	struct core_thread___285 dumper;
	struct completion startup;
};

struct vm_fault___275 {
	const struct {
		struct vm_area_struct___285 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___285 *cow_page;
	struct page___285 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___285 prealloc_pte;
};

struct pglist_data___153;

struct lruvec___153 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___153 *pgdat;
};

struct zone___153 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___153 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___153 {
	struct zone___153 *zone;
	int zone_idx;
};

struct zonelist___153 {
	struct zoneref___153 _zonerefs[321];
};

struct pglist_data___153 {
	struct zone___153 node_zones[5];
	struct zonelist___153 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___287 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___287 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___153 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___207 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___287 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___83;

struct cgroup_bpf___83 {
	struct bpf_prog_array___83 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___83 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___207;

struct cgroup_rstat_cpu___207;

struct cgroup___207 {
	struct cgroup_subsys_state___207 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___268 *kn;
	struct cgroup_file___207 procs_file;
	struct cgroup_file___207 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___207 *subsys[14];
	struct cgroup_root___207 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___207 *dom_cgrp;
	struct cgroup___207 *old_dom_cgrp;
	struct cgroup_rstat_cpu___207 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___207 psi;
	struct cgroup_bpf___83 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___171 {
	struct request_queue___171 *q;
	struct io_context___171 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___280 {
	struct file___280 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___280 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___280 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___280 *ia_file;
};

struct dquot___280 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___280 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___280 {
	int qf_fmt_id;
	const struct quota_format_ops___280 *qf_ops;
	struct module___264 *qf_owner;
	struct quota_format_type___280 *qf_next;
};

struct quota_format_ops___280 {
	int (*check_quota_file)(struct super_block___280 *, int);
	int (*read_file_info)(struct super_block___280 *, int);
	int (*write_file_info)(struct super_block___280 *, int);
	int (*free_file_info)(struct super_block___280 *, int);
	int (*read_dqblk)(struct dquot___280 *);
	int (*commit_dqblk)(struct dquot___280 *);
	int (*release_dqblk)(struct dquot___280 *);
	int (*get_next_id)(struct super_block___280 *, struct kqid *);
};

struct dquot_operations___280 {
	int (*write_dquot)(struct dquot___280 *);
	struct dquot___280 * (*alloc_dquot)(struct super_block___280 *, int);
	void (*destroy_dquot)(struct dquot___280 *);
	int (*acquire_dquot)(struct dquot___280 *);
	int (*release_dquot)(struct dquot___280 *);
	int (*mark_dirty)(struct dquot___280 *);
	int (*write_info)(struct super_block___280 *, int);
	qsize_t * (*get_reserved_space)(struct inode___280 *);
	int (*get_projid)(struct inode___280 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___280 *, qsize_t *);
	int (*get_next_id)(struct super_block___280 *, struct kqid *);
};

struct quotactl_ops___280 {
	int (*quota_on)(struct super_block___280 *, int, int, const struct path___280 *);
	int (*quota_off)(struct super_block___280 *, int);
	int (*quota_enable)(struct super_block___280 *, unsigned int);
	int (*quota_disable)(struct super_block___280 *, unsigned int);
	int (*quota_sync)(struct super_block___280 *, int);
	int (*set_info)(struct super_block___280 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___280 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___280 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___280 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___280 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___280 *, unsigned int);
};

struct writeback_control___157;

struct address_space_operations___280 {
	int (*writepage)(struct page___285 *, struct writeback_control___157 *);
	int (*readpage)(struct file___280 *, struct page___285 *);
	int (*writepages)(struct address_space___280 *, struct writeback_control___157 *);
	int (*set_page_dirty)(struct page___285 *);
	int (*readpages)(struct file___280 *, struct address_space___280 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___280 *, struct address_space___280 *, loff_t, unsigned int, unsigned int, struct page___285 **, void **);
	int (*write_end)(struct file___280 *, struct address_space___280 *, loff_t, unsigned int, unsigned int, struct page___285 *, void *);
	sector_t (*bmap)(struct address_space___280 *, sector_t);
	void (*invalidatepage)(struct page___285 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___285 *, gfp_t);
	void (*freepage)(struct page___285 *);
	ssize_t (*direct_IO)(struct kiocb___280 *, struct iov_iter___200 *);
	int (*migratepage)(struct address_space___280 *, struct page___285 *, struct page___285 *, enum migrate_mode);
	bool (*isolate_page)(struct page___285 *, isolate_mode_t);
	void (*putback_page)(struct page___285 *);
	int (*launder_page)(struct page___285 *);
	int (*is_partially_uptodate)(struct page___285 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___285 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___280 *, struct page___285 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___280 *, sector_t *);
	void (*swap_deactivate)(struct file___280 *);
};

struct writeback_control___157 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___157 *wb;
	struct inode___280 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___197;

struct iov_iter___200 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___197 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___121 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___280 {
	struct dentry___280 * (*lookup)(struct inode___280 *, struct dentry___280 *, unsigned int);
	const char * (*get_link)(struct dentry___280 *, struct inode___280 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___280 *, int);
	struct posix_acl * (*get_acl)(struct inode___280 *, int, bool);
	int (*readlink)(struct dentry___280 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___280 *, struct dentry___280 *, umode_t, bool);
	int (*link)(struct dentry___280 *, struct inode___280 *, struct dentry___280 *);
	int (*unlink)(struct inode___280 *, struct dentry___280 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___280 *, struct dentry___280 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___280 *, struct dentry___280 *, umode_t);
	int (*rmdir)(struct inode___280 *, struct dentry___280 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___280 *, struct dentry___280 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___280 *, struct dentry___280 *, struct inode___280 *, struct dentry___280 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___280 *, struct iattr___280 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___280 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___280 *, char *, size_t);
	int (*fiemap)(struct inode___280 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___280 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___280 *, struct dentry___280 *, struct file___280 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___280 *, struct dentry___280 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___280 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___280 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___280 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___280 {
	void (*fl_copy_lock)(struct file_lock___280 *, struct file_lock___280 *);
	void (*fl_release_private)(struct file_lock___280 *);
};

struct lock_manager_operations___280;

struct file_lock___280 {
	struct file_lock___280 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___280 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___280 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___280 *fl_ops;
	const struct lock_manager_operations___280 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___280 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___280 *);
	int (*lm_grant)(struct file_lock___280 *, int);
	bool (*lm_break)(struct file_lock___280 *);
	int (*lm_change)(struct file_lock___280 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___280 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___280 *);
};

struct fasync_struct___280 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___280 *fa_next;
	struct file___280 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___280 {
	struct inode___280 * (*alloc_inode)(struct super_block___280 *);
	void (*destroy_inode)(struct inode___280 *);
	void (*free_inode)(struct inode___280 *);
	void (*dirty_inode)(struct inode___280 *, int);
	int (*write_inode)(struct inode___280 *, struct writeback_control___157 *);
	int (*drop_inode)(struct inode___280 *);
	void (*evict_inode)(struct inode___280 *);
	void (*put_super)(struct super_block___280 *);
	int (*sync_fs)(struct super_block___280 *, int);
	int (*freeze_super)(struct super_block___280 *);
	int (*freeze_fs)(struct super_block___280 *);
	int (*thaw_super)(struct super_block___280 *);
	int (*unfreeze_fs)(struct super_block___280 *);
	int (*statfs)(struct dentry___280 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___280 *, int *, char *);
	void (*umount_begin)(struct super_block___280 *);
	int (*show_options)(struct seq_file___255 *, struct dentry___280 *);
	int (*show_devname)(struct seq_file___255 *, struct dentry___280 *);
	int (*show_path)(struct seq_file___255 *, struct dentry___280 *);
	int (*show_stats)(struct seq_file___255 *, struct dentry___280 *);
	ssize_t (*quota_read)(struct super_block___280 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___280 *, int, const char *, size_t, loff_t);
	struct dquot___280 ** (*get_dquots)(struct inode___280 *);
	long int (*nr_cached_objects)(struct super_block___280 *, struct shrink_control___145 *);
	long int (*free_cached_objects)(struct super_block___280 *, struct shrink_control___145 *);
	struct file___280 * (*real_loop)(struct file___280 *);
};

struct wakeup_source___261;

struct dev_pm_info___261 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___261 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___261 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___261;

struct bus_type___261;

struct device_driver___261;

struct dev_pm_domain___261;

struct fwnode_handle___257;

struct class___261;

struct attribute_group___268;

struct device___261 {
	struct kobject___268 kobj;
	struct device___261 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___261 *type;
	struct bus_type___261 *bus;
	struct device_driver___261 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___261 power;
	struct dev_pm_domain___261 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___257 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___261 *class;
	const struct attribute_group___268 **groups;
	void (*release)(struct device___261 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___174 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___280 *bd_inode;
	struct super_block___280 *bd_super;
	void *bd_claiming;
	struct device___261 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___268 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___174 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___280 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___209)(struct file___280 *, wait_queue_head_t *, struct poll_table_struct___201 *);

struct poll_table_struct___201 {
	poll_queue_proc___209 _qproc;
	__poll_t _key;
};

struct seq_operations___255;

struct seq_file___255 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___255 *op;
	int poll_event;
	const struct file___280 *file;
	void *private;
};

typedef void bio_end_io_t___171(struct bio___171 *);

struct bio_vec___197 {
	struct page___285 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___171;

struct bio___171 {
	struct bio___171 *bi_next;
	struct block_device___174 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___171 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___159 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___171 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___197 *bi_io_vec;
	struct bio_set___171 *bi_pool;
	struct bio_vec___197 bi_inline_vecs[0];
};

struct dev_pagemap_ops___275 {
	void (*page_free)(struct page___285 *);
	void (*kill)(struct dev_pagemap___275 *);
	void (*cleanup)(struct dev_pagemap___275 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___275 *);
};

struct fwnode_operations___257;

struct fwnode_handle___257 {
	struct fwnode_handle___257 *secondary;
	const struct fwnode_operations___257 *ops;
	struct device___261 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___257;

struct fwnode_endpoint___257;

struct fwnode_operations___257 {
	struct fwnode_handle___257 * (*get)(struct fwnode_handle___257 *);
	void (*put)(struct fwnode_handle___257 *);
	bool (*device_is_available)(const struct fwnode_handle___257 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___257 *, const struct device___261 *);
	bool (*property_present)(const struct fwnode_handle___257 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___257 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___257 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___257 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*get_parent)(const struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*get_next_child_node)(const struct fwnode_handle___257 *, struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*get_named_child_node)(const struct fwnode_handle___257 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___257 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___257 *);
	struct fwnode_handle___257 * (*graph_get_next_endpoint)(const struct fwnode_handle___257 *, struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*graph_get_remote_endpoint)(const struct fwnode_handle___257 *);
	struct fwnode_handle___257 * (*graph_get_port_parent)(struct fwnode_handle___257 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___257 *, struct fwnode_endpoint___257 *);
	int (*add_links)(struct fwnode_handle___257 *);
};

struct fwnode_endpoint___257 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___257 *local_fwnode;
};

struct fwnode_reference_args___257 {
	struct fwnode_handle___257 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___268;

struct kernfs_elem_dir___268 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___268 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___268;

struct kernfs_root___268 {
	struct kernfs_node___268 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___268 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___268 {
	struct kernfs_node___268 *target_kn;
};

struct kernfs_ops___268;

struct kernfs_elem_attr___268 {
	const struct kernfs_ops___268 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___268 *notify_next;
};

struct kernfs_node___268 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___268 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___268 dir;
		struct kernfs_elem_symlink___268 symlink;
		struct kernfs_elem_attr___268 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___268;

struct kernfs_ops___268 {
	int (*open)(struct kernfs_open_file___268 *);
	void (*release)(struct kernfs_open_file___268 *);
	int (*seq_show)(struct seq_file___255 *, void *);
	void * (*seq_start)(struct seq_file___255 *, loff_t *);
	void * (*seq_next)(struct seq_file___255 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___255 *, void *);
	ssize_t (*read)(struct kernfs_open_file___268 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___268 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___268 *, struct poll_table_struct___201 *);
	int (*mmap)(struct kernfs_open_file___268 *, struct vm_area_struct___285 *);
};

struct kernfs_syscall_ops___268 {
	int (*show_options)(struct seq_file___255 *, struct kernfs_root___268 *);
	int (*mkdir)(struct kernfs_node___268 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___268 *);
	int (*rename)(struct kernfs_node___268 *, struct kernfs_node___268 *, const char *);
	int (*show_path)(struct seq_file___255 *, struct kernfs_node___268 *, struct kernfs_root___268 *);
};

struct kernfs_open_file___268 {
	struct kernfs_node___268 *kn;
	struct file___280 *file;
	struct seq_file___255 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___275 *vm_ops;
};

struct sock___76;

struct kobj_ns_type_operations___76 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___76 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___94 *net;
} possible_net_t___89;

struct proto___76;

struct sock_common___76 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___76 *skc_prot;
	possible_net_t___89 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___76 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___90;

struct sk_buff_head___89 {
	struct sk_buff___90 *next;
	struct sk_buff___90 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___76 {
	struct cgroup___207 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___76;

struct socket_wq___77;

struct xfrm_policy___18;

struct dst_entry___76;

struct socket___78;

struct net_device___89;

struct sock___76 {
	struct sock_common___76 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___89 sk_error_queue;
	struct sk_buff___90 *sk_rx_skb_cache;
	struct sk_buff_head___89 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___90 *head;
		struct sk_buff___90 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___76 *sk_filter;
	union {
		struct socket_wq___77 *sk_wq;
		struct socket_wq___77 *sk_wq_raw;
	};
	struct xfrm_policy___18 *sk_policy[2];
	struct dst_entry___76 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___76 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___90 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___90 *sk_tx_skb_cache;
	struct sk_buff_head___89 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___285 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___76 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___257 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___78 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___76 sk_cgrp_data;
	struct mem_cgroup___145 *sk_memcg;
	void (*sk_state_change)(struct sock___76 *);
	void (*sk_data_ready)(struct sock___76 *);
	void (*sk_write_space)(struct sock___76 *);
	void (*sk_error_report)(struct sock___76 *);
	int (*sk_backlog_rcv)(struct sock___76 *, struct sk_buff___90 *);
	struct sk_buff___90 * (*sk_validate_xmit_skb)(struct sock___76 *, struct net_device___89 *, struct sk_buff___90 *);
	void (*sk_destruct)(struct sock___76 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___268;

struct attribute_group___268 {
	const char *name;
	umode_t (*is_visible)(struct kobject___268 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___268 *, struct bin_attribute___268 *, int);
	struct attribute **attrs;
	struct bin_attribute___268 **bin_attrs;
};

struct bin_attribute___268 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___280 * (*f_mapping)();
	ssize_t (*read)(struct file___280 *, struct kobject___268 *, struct bin_attribute___268 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___280 *, struct kobject___268 *, struct bin_attribute___268 *, char *, loff_t, size_t);
	int (*mmap)(struct file___280 *, struct kobject___268 *, struct bin_attribute___268 *, struct vm_area_struct___285 *);
};

struct sysfs_ops___268 {
	ssize_t (*show)(struct kobject___268 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___268 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___268;

struct kset___268 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___268 kobj;
	const struct kset_uevent_ops___268 *uevent_ops;
};

struct kobj_type___268 {
	void (*release)(struct kobject___268 *);
	const struct sysfs_ops___268 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___268 **default_groups;
	const struct kobj_ns_type_operations___76 * (*child_ns_type)(struct kobject___268 *);
	const void * (*namespace)(struct kobject___268 *);
	void (*get_ownership)(struct kobject___268 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___268 {
	int (* const filter)(struct kset___268 *, struct kobject___268 *);
	const char * (* const name)(struct kset___268 *, struct kobject___268 *);
	int (* const uevent)(struct kset___268 *, struct kobject___268 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___264 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___264 *);
	int (*get)(char *, const struct kernel_param___264 *);
	void (*free)(void *);
};

struct kparam_array___264;

struct kernel_param___264 {
	const char *name;
	struct module___264 *mod;
	const struct kernel_param_ops___264 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___264 *arr;
	};
};

struct kparam_array___264 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___264 *ops;
	void *elem;
};

struct module_attribute___264 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___264 *, struct module_kobject___265 *, char *);
	ssize_t (*store)(struct module_attribute___264 *, struct module_kobject___265 *, const char *, size_t);
	void (*setup)(struct module___264 *, const char *);
	int (*test)(struct module___264 *);
	void (*free)(struct module___264 *);
};

struct ip_ra_chain___49;

struct fib_rules_ops___76;

struct fqdir___94;

struct fib_notifier_ops___76;

struct netns_ipv4___94 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___49 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___76 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___76 *fibnl;
	struct sock___76 **icmp_sk;
	struct sock___76 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___76 **tcp_sk;
	struct fqdir___94 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___76 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___76 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___76 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___76;

struct dst_ops___94 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___94 *);
	struct dst_entry___76 * (*check)(struct dst_entry___76 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___76 *);
	unsigned int (*mtu)(const struct dst_entry___76 *);
	u32 * (*cow_metrics)(struct dst_entry___76 *, long unsigned int);
	void (*destroy)(struct dst_entry___76 *);
	void (*ifdown)(struct dst_entry___76 *, struct net_device___89 *, int);
	struct dst_entry___76 * (*negative_advice)(struct dst_entry___76 *);
	void (*link_failure)(struct sk_buff___90 *);
	void (*update_pmtu)(struct dst_entry___76 *, struct sock___76 *, struct sk_buff___90 *, u32, bool);
	void (*redirect)(struct dst_entry___76 *, struct sock___76 *, struct sk_buff___90 *);
	int (*local_out)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
	struct neighbour___76 * (*neigh_lookup)(const struct dst_entry___76 *, struct sk_buff___90 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___76 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___24;

struct rt6_info___24;

struct fib6_table___24;

struct netns_ipv6___94 {
	struct dst_ops___94 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___94 *fqdir;
	struct fib6_info___24 *fib6_null_entry;
	struct rt6_info___24 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___24 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___24 *ip6_prohibit_entry;
	struct rt6_info___24 *ip6_blk_hole_entry;
	struct fib6_table___24 *fib6_local_tbl;
	struct fib_rules_ops___76 *fib6_rules_ops;
	struct sock___76 **icmp_sk;
	struct sock___76 *ndisc_sk;
	struct sock___76 *tcp_sk;
	struct sock___76 *igmp_sk;
	struct sock___76 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___76 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___76 *notifier_ops;
	struct fib_notifier_ops___76 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___94 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___94 *fqdir;
};

struct netns_sctp___76 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___76 *ctl_sock;
	struct sock___76 *udp4_sock;
	struct sock___76 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___16;

struct netns_nf___16 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___16 *hooks_ipv4[5];
	struct nf_hook_entries___16 *hooks_ipv6[5];
	struct nf_hook_entries___16 *hooks_arp[3];
	struct nf_hook_entries___16 *hooks_bridge[5];
	struct nf_hook_entries___16 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___83;

struct netns_bpf___83 {
	struct bpf_prog_array___83 *run_array[2];
	struct bpf_prog___83 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___94 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___76 *nlsk;
	struct sock___76 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___94 xfrm4_dst_ops;
	struct dst_ops___94 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___94 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___76 *rtnl;
	struct sock___76 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___89 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___94 ipv4;
	struct netns_ipv6___94 ipv6;
	struct netns_ieee802154_lowpan___94 ieee802154_lowpan;
	struct netns_sctp___76 sctp;
	struct netns_nf___16 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___89 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___83 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___94 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___76 *crypto_nlsk;
	struct sock___76 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___207 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___207 *root_cset;
};

struct msghdr___78 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___200 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___280 *msg_iocb;
};

struct socket_wq___77 {
	wait_queue_head_t wait;
	struct fasync_struct___280 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___77;

struct socket___78 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___280 *file;
	struct sock___76 *sk;
	const struct proto_ops___77 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___77 wq;
};

typedef int (*sk_read_actor_t___76)(read_descriptor_t *, struct sk_buff___90 *, unsigned int, size_t);

struct proto_ops___77 {
	int family;
	struct module___264 *owner;
	int (*release)(struct socket___78 *);
	int (*bind)(struct socket___78 *, struct sockaddr *, int);
	int (*connect)(struct socket___78 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___78 *, struct socket___78 *);
	int (*accept)(struct socket___78 *, struct socket___78 *, int, bool);
	int (*getname)(struct socket___78 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___280 *, struct socket___78 *, struct poll_table_struct___201 *);
	int (*ioctl)(struct socket___78 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___78 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___78 *, void *, bool, bool);
	int (*listen)(struct socket___78 *, int);
	int (*shutdown)(struct socket___78 *, int);
	int (*setsockopt)(struct socket___78 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___78 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___255 *, struct socket___78 *);
	int (*sendmsg)(struct socket___78 *, struct msghdr___78 *, size_t);
	int (*recvmsg)(struct socket___78 *, struct msghdr___78 *, size_t, int);
	int (*mmap)(struct file___280 *, struct socket___78 *, struct vm_area_struct___285 *);
	ssize_t (*sendpage)(struct socket___78 *, struct page___285 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___78 *, loff_t *, struct pipe_inode_info___121 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___76 *, int);
	int (*peek_len)(struct socket___78 *);
	int (*read_sock)(struct sock___76 *, read_descriptor_t *, sk_read_actor_t___76);
	int (*sendpage_locked)(struct sock___76 *, struct page___285 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___76 *, struct msghdr___78 *, size_t);
	int (*set_rcvlowat)(struct sock___76 *, int);
};

struct sk_buff___90 {
	union {
		struct {
			struct sk_buff___90 *next;
			struct sk_buff___90 *prev;
			union {
				struct net_device___89 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___76 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___90 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___261 {
	int (*prepare)(struct device___261 *);
	void (*complete)(struct device___261 *);
	int (*suspend)(struct device___261 *);
	int (*resume)(struct device___261 *);
	int (*freeze)(struct device___261 *);
	int (*thaw)(struct device___261 *);
	int (*poweroff)(struct device___261 *);
	int (*restore)(struct device___261 *);
	int (*suspend_late)(struct device___261 *);
	int (*resume_early)(struct device___261 *);
	int (*freeze_late)(struct device___261 *);
	int (*thaw_early)(struct device___261 *);
	int (*poweroff_late)(struct device___261 *);
	int (*restore_early)(struct device___261 *);
	int (*suspend_noirq)(struct device___261 *);
	int (*resume_noirq)(struct device___261 *);
	int (*freeze_noirq)(struct device___261 *);
	int (*thaw_noirq)(struct device___261 *);
	int (*poweroff_noirq)(struct device___261 *);
	int (*restore_noirq)(struct device___261 *);
	int (*runtime_suspend)(struct device___261 *);
	int (*runtime_resume)(struct device___261 *);
	int (*runtime_idle)(struct device___261 *);
};

struct wakeup_source___261 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___261 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___261 {
	struct dev_pm_ops___261 ops;
	int (*start)(struct device___261 *);
	void (*detach)(struct device___261 *, bool);
	int (*activate)(struct device___261 *);
	void (*sync)(struct device___261 *);
	void (*dismiss)(struct device___261 *);
};

struct bus_type___261 {
	const char *name;
	const char *dev_name;
	struct device___261 *dev_root;
	const struct attribute_group___268 **bus_groups;
	const struct attribute_group___268 **dev_groups;
	const struct attribute_group___268 **drv_groups;
	int (*match)(struct device___261 *, struct device_driver___261 *);
	int (*uevent)(struct device___261 *, struct kobj_uevent_env *);
	int (*probe)(struct device___261 *);
	void (*sync_state)(struct device___261 *);
	void (*remove)(struct device___261 *);
	void (*shutdown)(struct device___261 *);
	int (*online)(struct device___261 *);
	int (*offline)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	int (*num_vf)(struct device___261 *);
	int (*dma_configure)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___261 {
	const char *name;
	struct bus_type___261 *bus;
	struct module___264 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___261 *);
	void (*sync_state)(struct device___261 *);
	int (*remove)(struct device___261 *);
	void (*shutdown)(struct device___261 *);
	int (*suspend)(struct device___261 *, pm_message_t);
	int (*resume)(struct device___261 *);
	const struct attribute_group___268 **groups;
	const struct attribute_group___268 **dev_groups;
	const struct dev_pm_ops___261 *pm;
	void (*coredump)(struct device___261 *);
	struct driver_private *p;
};

struct device_type___261 {
	const char *name;
	const struct attribute_group___268 **groups;
	int (*uevent)(struct device___261 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___261 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___261 *);
	const struct dev_pm_ops___261 *pm;
};

struct class___261 {
	const char *name;
	struct module___264 *owner;
	const struct attribute_group___268 **class_groups;
	const struct attribute_group___268 **dev_groups;
	struct kobject___268 *dev_kobj;
	int (*dev_uevent)(struct device___261 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___261 *, umode_t *);
	void (*class_release)(struct class___261 *);
	void (*dev_release)(struct device___261 *);
	int (*shutdown_pre)(struct device___261 *);
	const struct kobj_ns_type_operations___76 *ns_type;
	const void * (*namespace)(struct device___261 *);
	void (*get_ownership)(struct device___261 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___261 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___121;

struct pipe_buffer___121 {
	struct page___285 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___121 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___121 {
	int (*confirm)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
	void (*release)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
	bool (*try_steal)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
	bool (*get)(struct pipe_inode_info___121 *, struct pipe_buffer___121 *);
};

typedef rx_handler_result_t rx_handler_func_t___89(struct sk_buff___90 **);

struct bpf_xdp_entity___83 {
	struct bpf_prog___83 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___89;

struct net_device_ops___89;

struct l3mdev_ops___76;

struct ndisc_ops___58;

struct xfrmdev_ops___89;

struct header_ops___89;

struct in_device___17;

struct inet6_dev___58;

struct netdev_rx_queue___89;

struct mini_Qdisc___83;

struct netdev_queue___89;

struct Qdisc___83;

struct rtnl_link_ops___83;

struct dcbnl_rtnl_ops___89;

struct udp_tunnel_nic_info___3;

struct net_device___89 {
	char name[16];
	struct netdev_name_node___89 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___89 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___76 *l3mdev_ops;
	const struct ndisc_ops___58 *ndisc_ops;
	const struct xfrmdev_ops___89 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___89 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___268 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___17 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___58 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___89 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___83 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___89 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___83 *miniq_ingress;
	struct netdev_queue___89 *ingress_queue;
	struct nf_hook_entries___16 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___89 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___83 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___83 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___89 = 0,
		NETREG_REGISTERED___89 = 1,
		NETREG_UNREGISTERING___89 = 2,
		NETREG_UNREGISTERED___89 = 3,
		NETREG_RELEASED___89 = 4,
		NETREG_DUMMY___89 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___89 = 0,
		RTNL_LINK_INITIALIZING___89 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___89 *);
	struct netpoll_info *npinfo;
	possible_net_t___89 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___261 dev;
	const struct attribute_group___268 *sysfs_groups[4];
	const struct attribute_group___268 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___83 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___89 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info___3 *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___83 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___197 skb_frag_t___34;

struct skb_shared_info___31 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___90 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___34 frags[17];
};

struct inet_frags___94;

struct fqdir___94 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___94 *f;
	struct net___94 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___94;

struct inet_frags___94 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___94 *, const void *);
	void (*destructor)(struct inet_frag_queue___94 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___94 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___90 *fragments_tail;
	struct sk_buff___90 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___94 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___49 {
	struct ip_ra_chain___49 *next;
	struct sock___76 *sk;
	union {
		void (*destructor)(struct sock___76 *);
		struct sock___76 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___76;

struct fib_lookup_arg___76;

struct fib_rules_ops___76 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___76 *, struct flowi *, int, struct fib_lookup_arg___76 *);
	bool (*suppress)(struct fib_rule___76 *, int, struct fib_lookup_arg___76 *);
	int (*match)(struct fib_rule___76 *, struct flowi *, int);
	int (*configure)(struct fib_rule___76 *, struct sk_buff___90 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___76 *);
	int (*compare)(struct fib_rule___76 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___76 *, struct sk_buff___90 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___76 *);
	void (*flush_cache)(struct fib_rules_ops___76 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___264 *owner;
	struct net___94 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___76 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___94 *);
	int (*fib_dump)(struct net___94 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___264 *owner;
	struct callback_head rcu;
};

struct xfrm_state___18;

struct lwtunnel_state___52;

struct dst_entry___76 {
	struct net_device___89 *dev;
	struct dst_ops___94 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___18 *xfrm;
	int (*input)(struct sk_buff___90 *);
	int (*output)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___52 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___76;

struct neigh_parms___76;

struct neigh_ops___76;

struct neighbour___76 {
	struct neighbour___76 *next;
	struct neigh_table___76 *tbl;
	struct neigh_parms___76 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___89 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___76 *, struct sk_buff___90 *);
	const struct neigh_ops___76 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___89 *dev;
	u8 primary_key[0];
};

struct rtable___26;

struct fnhe_hash_bucket___24;

struct fib_nh_common___24 {
	struct net_device___89 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___52 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___26 **nhc_pcpu_rth_output;
	struct rtable___26 *nhc_rth_input;
	struct fnhe_hash_bucket___24 *nhc_exceptions;
};

struct fib6_nh___24 {
	struct fib_nh_common___24 nh_common;
	long unsigned int last_probe;
	struct rt6_info___24 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___24;

struct nexthop___15;

struct fib6_info___24 {
	struct fib6_table___24 *fib6_table;
	struct fib6_info___24 *fib6_next;
	struct fib6_node___24 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___15 *nh;
	struct fib6_nh___24 fib6_nh[0];
};

struct rt6_info___24 {
	struct dst_entry___76 dst;
	struct fib6_info___24 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___58 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___24 {
	struct fib6_node___24 *parent;
	struct fib6_node___24 *left;
	struct fib6_node___24 *right;
	struct fib6_node___24 *subtree;
	struct fib6_info___24 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___24 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___24 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___24 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___16;

typedef unsigned int nf_hookfn___18(void *, struct sk_buff___90 *, const struct nf_hook_state___16 *);

struct nf_hook_entry___16 {
	nf_hookfn___18 *hook;
	void *priv;
};

struct nf_hook_entries___16 {
	u16 num_hook_entries;
	struct nf_hook_entry___16 hooks[0];
};

struct bpf_prog_array_item___83 {
	struct bpf_prog___83 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___83 {
	struct callback_head rcu;
	struct bpf_prog_array_item___83 items[0];
};

struct bpf_prog_aux___92;

struct bpf_prog___83 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___92 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___255 {
	void * (*start)(struct seq_file___255 *, loff_t *);
	void (*stop)(struct seq_file___255 *, void *);
	void * (*next)(struct seq_file___255 *, void *, loff_t *);
	int (*show)(struct seq_file___255 *, void *);
};

struct dcbnl_rtnl_ops___89 {
	int (*ieee_getets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___89 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___89 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___89 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___89 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___89 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___89 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___89 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___89 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___89 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___89 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___89 *);
	u8 (*setstate)(struct net_device___89 *, u8);
	void (*getpermhwaddr)(struct net_device___89 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___89 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___89 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___89 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___89 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___89 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___89 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___89 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___89 *, int, u8 *);
	void (*setpfccfg)(struct net_device___89 *, int, u8);
	void (*getpfccfg)(struct net_device___89 *, int, u8 *);
	u8 (*setall)(struct net_device___89 *);
	u8 (*getcap)(struct net_device___89 *, int, u8 *);
	int (*getnumtcs)(struct net_device___89 *, int, u8 *);
	int (*setnumtcs)(struct net_device___89 *, int, u8);
	u8 (*getpfcstate)(struct net_device___89 *);
	void (*setpfcstate)(struct net_device___89 *, u8);
	void (*getbcncfg)(struct net_device___89 *, int, u32 *);
	void (*setbcncfg)(struct net_device___89 *, int, u32);
	void (*getbcnrp)(struct net_device___89 *, int, u8 *);
	void (*setbcnrp)(struct net_device___89 *, int, u8);
	int (*setapp)(struct net_device___89 *, u8, u16, u8);
	int (*getapp)(struct net_device___89 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___89 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___89 *, int, u8);
	u8 (*getdcbx)(struct net_device___89 *);
	u8 (*setdcbx)(struct net_device___89 *, u8);
	int (*peer_getappinfo)(struct net_device___89 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___89 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___89 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___89 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___89 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___89 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___92;

typedef int (*bpf_iter_init_seq_priv_t___91)(void *, struct bpf_iter_aux_info___92 *);

struct bpf_map___92;

struct bpf_iter_aux_info___92 {
	struct bpf_map___92 *map;
};

struct bpf_iter_seq_info___91 {
	const struct seq_operations___255 *seq_ops;
	bpf_iter_init_seq_priv_t___91 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___91 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___92 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___92 *, struct file___280 *);
	void (*map_free)(struct bpf_map___92 *);
	int (*map_get_next_key)(struct bpf_map___92 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___92 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___92 *, void *);
	int (*map_lookup_batch)(struct bpf_map___92 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___92 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___92 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___92 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___92 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___92 *, void *);
	int (*map_update_elem)(struct bpf_map___92 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___92 *, void *);
	int (*map_push_elem)(struct bpf_map___92 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___92 *, void *);
	int (*map_peek_elem)(struct bpf_map___92 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___92 *, struct file___280 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___92 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___92 *, void *, struct seq_file___255 *);
	int (*map_check_btf)(const struct bpf_map___92 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___92 *, struct bpf_prog_aux___92 *);
	void (*map_poke_untrack)(struct bpf_map___92 *, struct bpf_prog_aux___92 *);
	void (*map_poke_run)(struct bpf_map___92 *, u32, struct bpf_prog___83 *, struct bpf_prog___83 *);
	int (*map_direct_value_addr)(const struct bpf_map___92 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___92 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___92 *, struct vm_area_struct___285 *);
	__poll_t (*map_poll)(struct bpf_map___92 *, struct file___280 *, struct poll_table_struct___201 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___92 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___92 *, const struct bpf_map___92 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___92 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___91 *iter_seq_info;
};

struct bpf_map___92 {
	const struct bpf_map_ops___91 *ops;
	struct bpf_map___92 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___145 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___91;

struct bpf_jit_poke_descriptor___91;

struct bpf_prog_ops___83;

struct btf_mod_pair___91;

struct bpf_prog_offload___89;

struct bpf_prog_aux___92 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___83 *dst_prog;
	struct bpf_trampoline___91 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___83 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___91 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___83 *ops;
	struct bpf_map___92 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___91 *used_btfs;
	struct bpf_prog___83 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___92 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___89 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___89;

struct bpf_map_dev_ops___89 {
	int (*map_get_next_key)(struct bpf_offloaded_map___89 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___89 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___89 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___89 *, void *);
};

struct bpf_offloaded_map___89 {
	struct bpf_map___92 map;
	struct net_device___89 *netdev;
	const struct bpf_map_dev_ops___89 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___83 {
	int (*test_run)(struct bpf_prog___83 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___89 {
	struct bpf_prog___83 *prog;
	struct net_device___89 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___91 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___83 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___264 *mod;
};

struct bpf_jit_poke_descriptor___91 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___92 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___91 {
	struct btf *btf;
	struct module___264 *module;
};

struct cftype___207;

struct cgroup_subsys___207 {
	struct cgroup_subsys_state___207 * (*css_alloc)(struct cgroup_subsys_state___207 *);
	int (*css_online)(struct cgroup_subsys_state___207 *);
	void (*css_offline)(struct cgroup_subsys_state___207 *);
	void (*css_released)(struct cgroup_subsys_state___207 *);
	void (*css_free)(struct cgroup_subsys_state___207 *);
	void (*css_reset)(struct cgroup_subsys_state___207 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___207 *, int);
	int (*css_extra_stat_show)(struct seq_file___255 *, struct cgroup_subsys_state___207 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___287 *, struct css_set___207 *);
	void (*cancel_fork)(struct task_struct___287 *, struct css_set___207 *);
	void (*fork)(struct task_struct___287 *);
	void (*exit)(struct task_struct___287 *);
	void (*release)(struct task_struct___287 *);
	void (*bind)(struct cgroup_subsys_state___207 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___207 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___207 *dfl_cftypes;
	struct cftype___207 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___207 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___207 *updated_children;
	struct cgroup___207 *updated_next;
};

struct cgroup_root___207 {
	struct kernfs_root___268 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___207 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___207 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___207 *ss;
	struct list_head node;
	struct kernfs_ops___268 *kf_ops;
	int (*open)(struct kernfs_open_file___268 *);
	void (*release)(struct kernfs_open_file___268 *);
	u64 (*read_u64)(struct cgroup_subsys_state___207 *, struct cftype___207 *);
	s64 (*read_s64)(struct cgroup_subsys_state___207 *, struct cftype___207 *);
	int (*seq_show)(struct seq_file___255 *, void *);
	void * (*seq_start)(struct seq_file___255 *, loff_t *);
	void * (*seq_next)(struct seq_file___255 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___255 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___207 *, struct cftype___207 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___207 *, struct cftype___207 *, s64);
	ssize_t (*write)(struct kernfs_open_file___268 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___268 *, struct poll_table_struct___201 *);
};

struct xdp_rxq_info___89 {
	struct net_device___89 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___89 {
	struct net_device___89 *dev;
};

struct xdp_buff___89 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___89 *rxq;
	struct xdp_txq_info___89 *txq;
	u32 frame_sz;
};

struct xdp_frame___89 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___89 *dev_rx;
};

struct netlink_callback___89 {
	struct sk_buff___90 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___90 *, struct netlink_callback___89 *);
	int (*done)(struct netlink_callback___89 *);
	void *data;
	struct module___264 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___89 {
	int (*create)(struct sk_buff___90 *, struct net_device___89 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___90 *, unsigned char *);
	int (*cache)(const struct neighbour___76 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___89 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___90 *);
};

struct netdev_queue___89 {
	struct net_device___89 *dev;
	struct Qdisc___83 *qdisc;
	struct Qdisc___83 *qdisc_sleeping;
	struct kobject___268 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___89 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___83 {
	struct sk_buff___90 *head;
	struct sk_buff___90 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___83;

struct Qdisc___83 {
	int (*enqueue)(struct sk_buff___90 *, struct Qdisc___83 *, struct sk_buff___90 **);
	struct sk_buff___90 * (*dequeue)(struct Qdisc___83 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___83 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___89 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___89 gso_skb;
	struct qdisc_skb_head___83 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___83 *next_sched;
	struct sk_buff_head___89 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___89 {
	struct xdp_rxq_info___89 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___268 kobj;
	struct net_device___89 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___89 {
	enum net_device_path_type type;
	const struct net_device___89 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___89 = 0,
				DEV_PATH_BR_VLAN_TAG___89 = 1,
				DEV_PATH_BR_VLAN_UNTAG___89 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___89 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___89 {
	const struct net_device___89 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___89 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___83 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___89 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___89 {
	int (*xdo_dev_state_add)(struct xfrm_state___18 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___18 *);
	void (*xdo_dev_state_free)(struct xfrm_state___18 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___90 *, struct xfrm_state___18 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___18 *);
};

struct xfrm_state_offload___18 {
	struct net_device___89 *dev;
	struct net_device___89 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___18;

struct xfrm_type_offload___18;

struct xfrm_state___18 {
	possible_net_t___89 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___76 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___18 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___18 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___285 xfrag;
	const struct xfrm_type___18 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___18 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___89 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___89 *dev;
	const char *name;
};

struct net_device_ops___89 {
	int (*ndo_init)(struct net_device___89 *);
	void (*ndo_uninit)(struct net_device___89 *);
	int (*ndo_open)(struct net_device___89 *);
	int (*ndo_stop)(struct net_device___89 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___90 *, struct net_device___89 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___90 *, struct net_device___89 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___89 *, struct sk_buff___90 *, struct net_device___89 *);
	void (*ndo_change_rx_flags)(struct net_device___89 *, int);
	void (*ndo_set_rx_mode)(struct net_device___89 *);
	int (*ndo_set_mac_address)(struct net_device___89 *, void *);
	int (*ndo_validate_addr)(struct net_device___89 *);
	int (*ndo_do_ioctl)(struct net_device___89 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___89 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___89 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___89 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___89 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___89 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___89 *, int);
	int (*ndo_neigh_setup)(struct net_device___89 *, struct neigh_parms___76 *);
	void (*ndo_tx_timeout)(struct net_device___89 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___89 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___89 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___89 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___89 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___89 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___89 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___89 *);
	int (*ndo_netpoll_setup)(struct net_device___89 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___89 *);
	int (*ndo_set_vf_mac)(struct net_device___89 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___89 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___89 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___89 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___89 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___89 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___89 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___89 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___89 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___89 *, int, struct sk_buff___90 *);
	int (*ndo_get_vf_guid)(struct net_device___89 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___89 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___89 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___89 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___89 *);
	int (*ndo_fcoe_disable)(struct net_device___89 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___89 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___89 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___89 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___89 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___89 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___89 *, const struct sk_buff___90 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___89 *, struct net_device___89 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___89 *, struct net_device___89 *);
	struct net_device___89 * (*ndo_get_xmit_slave)(struct net_device___89 *, struct sk_buff___90 *, bool);
	struct net_device___89 * (*ndo_sk_get_lower_dev)(struct net_device___89 *, struct sock___76 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___89 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___89 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___89 *, struct neighbour___76 *);
	void (*ndo_neigh_destroy)(struct net_device___89 *, struct neighbour___76 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___90 *, struct netlink_callback___89 *, struct net_device___89 *, struct net_device___89 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___90 *, struct nlattr **, struct net_device___89 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___89 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___90 *, u32, u32, struct net_device___89 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___89 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___89 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___89 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___89 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___89 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___89 *, struct net_device___89 *);
	void (*ndo_dfwd_del_station)(struct net_device___89 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___89 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___89 *);
	int (*ndo_change_proto_down)(struct net_device___89 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___89 *, struct sk_buff___90 *);
	void (*ndo_set_rx_headroom)(struct net_device___89 *, int);
	int (*ndo_bpf)(struct net_device___89 *, struct netdev_bpf___89 *);
	int (*ndo_xdp_xmit)(struct net_device___89 *, int, struct xdp_frame___89 **, u32);
	struct net_device___89 * (*ndo_xdp_get_xmit_slave)(struct net_device___89 *, struct xdp_buff___89 *);
	int (*ndo_xsk_wakeup)(struct net_device___89 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___89 *);
	int (*ndo_tunnel_ctl)(struct net_device___89 *, struct ip_tunnel_parm *, int);
	struct net_device___89 * (*ndo_get_peer_dev)(struct net_device___89 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___89 *, struct net_device_path___89 *);
};

struct neigh_parms___76 {
	possible_net_t___89 net;
	struct net_device___89 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___76 *);
	struct neigh_table___76 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___76 {
	u32 (*l3mdev_fib_table)(const struct net_device___89 *);
	struct sk_buff___90 * (*l3mdev_l3_rcv)(struct net_device___89 *, struct sk_buff___90 *, u16);
	struct sk_buff___90 * (*l3mdev_l3_out)(struct net_device___89 *, struct sock___76 *, struct sk_buff___90 *, u16);
	struct dst_entry___76 * (*l3mdev_link_scope_lookup)(const struct net_device___89 *, struct flowi6 *);
};

struct ndisc_ops___58 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___89 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___89 *, struct neighbour___76 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___89 *, u8, struct neighbour___76 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___89 *, struct sk_buff___90 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___94 *, struct net_device___89 *, const struct prefix_info *, struct inet6_dev___58 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___17;

struct in_device___17 {
	struct net_device___89 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___17 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___76 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___58;

struct ifacaddr6___24;

struct inet6_dev___58 {
	struct net_device___89 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___58 *mc_list;
	struct ifmcaddr6___58 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___89 mc_query_queue;
	struct sk_buff_head___89 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___24 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___76 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___83;

struct tcf_block___83;

struct mini_Qdisc___83 {
	struct tcf_proto___83 *filter_list;
	struct tcf_block___83 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___83 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___89 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___89 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___94 *, struct net_device___89 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___89 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___89 *, struct list_head *);
	size_t (*get_size)(const struct net_device___89 *);
	int (*fill_info)(struct sk_buff___90 *, const struct net_device___89 *);
	size_t (*get_xstats_size)(const struct net_device___89 *);
	int (*fill_xstats)(struct sk_buff___90 *, const struct net_device___89 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___89 *, struct net_device___89 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___89 *, const struct net_device___89 *);
	int (*fill_slave_info)(struct sk_buff___90 *, const struct net_device___89 *, const struct net_device___89 *);
	struct net___94 * (*get_link_net)(const struct net_device___89 *);
	size_t (*get_linkxstats_size)(const struct net_device___89 *, int);
	int (*fill_linkxstats)(struct sk_buff___90 *, const struct net_device___89 *, int *, int);
};

struct udp_tunnel_nic_info___3 {
	int (*set_port)(struct net_device___89 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	int (*unset_port)(struct net_device___89 *, unsigned int, unsigned int, struct udp_tunnel_info *);
	int (*sync_table)(struct net_device___89 *, unsigned int);
	struct udp_tunnel_nic_shared *shared;
	unsigned int flags;
	struct udp_tunnel_nic_table_info tables[4];
};

struct in_ifaddr___17 {
	struct hlist_node hash;
	struct in_ifaddr___17 *ifa_next;
	struct in_device___17 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct nf_hook_state___16 {
	u8 hook;
	u8 pf;
	struct net_device___89 *in;
	struct net_device___89 *out;
	struct sock___76 *sk;
	struct net___94 *net;
	int (*okfn)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
};

struct block_device_operations___171;

struct gendisk___174 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___174 *part0;
	const struct block_device_operations___171 *fops;
	struct request_queue___171 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___157 *bdi;
	struct kobject___268 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___268 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___171 {
	struct bio___171 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___197 *bip_vec;
	struct bio_vec___197 bip_inline_vecs[0];
};

struct blkcg___159;

struct blkg_policy_data___159;

struct blkcg_gq___159 {
	struct request_queue___171 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___159 *blkcg;
	struct blkcg_gq___159 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___159 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___171 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___171(struct request___171 *);

typedef void integrity_complete_fn___171(struct request___171 *, unsigned int);

struct blk_integrity_profile___171 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___171 *prepare_fn;
	integrity_complete_fn___171 *complete_fn;
	const char *name;
};

struct block_device_operations___171 {
	blk_qc_t (*submit_bio)(struct bio___171 *);
	int (*open)(struct block_device___174 *, fmode_t);
	void (*release)(struct gendisk___174 *, fmode_t);
	int (*rw_page)(struct block_device___174 *, sector_t, struct page___285 *, unsigned int);
	int (*ioctl)(struct block_device___174 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___174 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___174 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___174 *);
	int (*getgeo)(struct block_device___174 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___174 *, bool);
	void (*swap_slot_free_notify)(struct block_device___174 *, long unsigned int);
	int (*report_zones)(struct gendisk___174 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___174 *, umode_t *);
	struct module___264 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___174 *, sector_t *);
};

typedef void rq_end_io_fn___171(struct request___171 *, blk_status_t);

struct request___171 {
	struct request_queue___171 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___166 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___171 *bio;
	struct bio___171 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___197 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___171 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___171 *saved_end_io;
		} flush;
	};
	struct gendisk___174 *rq_disk;
	struct block_device___174 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___171 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___166 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___171 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___268 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___280 *debugfs_dir;
	struct dentry___280 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___171;

struct elevator_mq_ops___171 {
	int (*init_sched)(struct request_queue___171 *, struct elevator_type___171 *);
	void (*exit_sched)(struct elevator_queue___171 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___166 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___166 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___166 *);
	bool (*allow_merge)(struct request_queue___171 *, struct request___171 *, struct bio___171 *);
	bool (*bio_merge)(struct request_queue___171 *, struct bio___171 *, unsigned int);
	int (*request_merge)(struct request_queue___171 *, struct request___171 **, struct bio___171 *);
	void (*request_merged)(struct request_queue___171 *, struct request___171 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___171 *, struct request___171 *, struct request___171 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___171 *);
	void (*finish_request)(struct request___171 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___166 *, struct list_head *, bool);
	struct request___171 * (*dispatch_request)(struct blk_mq_hw_ctx___166 *);
	bool (*has_work)(struct blk_mq_hw_ctx___166 *);
	void (*completed_request)(struct request___171 *, u64);
	void (*requeue_request)(struct request___171 *);
	struct request___171 * (*former_request)(struct request_queue___171 *, struct request___171 *);
	struct request___171 * (*next_request)(struct request_queue___171 *, struct request___171 *);
	void (*init_icq)(struct io_cq___171 *);
	void (*exit_icq)(struct io_cq___171 *);
};

struct elv_fs_entry___171;

struct elevator_type___171 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___171 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___171 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___264 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___171 {
	struct elevator_type___171 *type;
	void *elevator_data;
	struct kobject___268 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___171 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___171 *, char *);
	ssize_t (*store)(struct elevator_queue___171 *, const char *, size_t);
};

struct blk_mq_queue_data___166;

struct blk_mq_ops___166 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___166 *, const struct blk_mq_queue_data___166 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___166 *);
	int (*get_budget)(struct request_queue___171 *);
	void (*put_budget)(struct request_queue___171 *, int);
	void (*set_rq_budget_token)(struct request___171 *, int);
	int (*get_rq_budget_token)(struct request___171 *);
	enum blk_eh_timer_return (*timeout)(struct request___171 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___166 *);
	void (*complete)(struct request___171 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___166 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___166 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___166 *, struct request___171 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___166 *, struct request___171 *, unsigned int);
	void (*initialize_rq_fn)(struct request___171 *);
	void (*cleanup_rq)(struct request___171 *);
	bool (*busy)(struct request_queue___171 *);
	int (*map_queues)(struct blk_mq_tag_set___166 *);
	void (*show_rq)(struct seq_file___255 *, struct request___171 *);
};

struct blk_mq_tag_set___166 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___166 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___166 {
	struct request___171 *rq;
	bool last;
};

struct blkcg_policy_data___159;

struct blkcg___159 {
	struct cgroup_subsys_state___207 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___159 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___159 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___159 {
	struct blkcg___159 *blkcg;
	int plid;
};

struct blkg_policy_data___159 {
	struct blkcg_gq___159 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___145 {
	struct mem_cgroup___145 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___145 {
	struct lruvec___153 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___145 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___145 *memcg;
};

struct obj_cgroup___145 {
	struct percpu_ref refcnt;
	struct mem_cgroup___145 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___83 {
	spinlock_t *lock;
	struct sk_buff___90 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___83;

struct Qdisc_ops___83 {
	struct Qdisc_ops___83 *next;
	const struct Qdisc_class_ops___83 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___90 *, struct Qdisc___83 *, struct sk_buff___90 **);
	struct sk_buff___90 * (*dequeue)(struct Qdisc___83 *);
	struct sk_buff___90 * (*peek)(struct Qdisc___83 *);
	int (*init)(struct Qdisc___83 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___83 *);
	void (*destroy)(struct Qdisc___83 *);
	int (*change)(struct Qdisc___83 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___83 *);
	int (*change_tx_queue_len)(struct Qdisc___83 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___83 *, unsigned int);
	int (*dump)(struct Qdisc___83 *, struct sk_buff___90 *);
	int (*dump_stats)(struct Qdisc___83 *, struct gnet_dump___83 *);
	void (*ingress_block_set)(struct Qdisc___83 *, u32);
	void (*egress_block_set)(struct Qdisc___83 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___83 *);
	u32 (*egress_block_get)(struct Qdisc___83 *);
	struct module___264 *owner;
};

struct Qdisc_class_ops___83 {
	unsigned int flags;
	struct netdev_queue___89 * (*select_queue)(struct Qdisc___83 *, struct tcmsg *);
	int (*graft)(struct Qdisc___83 *, long unsigned int, struct Qdisc___83 *, struct Qdisc___83 **, struct netlink_ext_ack *);
	struct Qdisc___83 * (*leaf)(struct Qdisc___83 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___83 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___83 *, u32);
	int (*change)(struct Qdisc___83 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___83 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___83 *, struct qdisc_walker *);
	struct tcf_block___83 * (*tcf_block)(struct Qdisc___83 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___83 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___83 *, long unsigned int);
	int (*dump)(struct Qdisc___83 *, long unsigned int, struct sk_buff___90 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___83 *, long unsigned int, struct gnet_dump___83 *);
};

struct tcf_chain___83;

struct tcf_block___83 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___94 *net;
	struct Qdisc___83 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___83 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___83;

struct tcf_proto_ops___83;

struct tcf_proto___83 {
	struct tcf_proto___83 *next;
	void *root;
	int (*classify)(struct sk_buff___90 *, const struct tcf_proto___83 *, struct tcf_result___83 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___83 *ops;
	struct tcf_chain___83 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___83 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___83 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___83 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___90 *, const struct tcf_proto___83 *, struct tcf_result___83 *);
	int (*init)(struct tcf_proto___83 *);
	void (*destroy)(struct tcf_proto___83 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___83 *, u32);
	void (*put)(struct tcf_proto___83 *, void *);
	int (*change)(struct net___94 *, struct sk_buff___90 *, struct tcf_proto___83 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___83 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___83 *);
	void (*walk)(struct tcf_proto___83 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___83 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___83 *, void *);
	void (*hw_del)(struct tcf_proto___83 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___94 *, struct tcf_chain___83 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___94 *, struct tcf_proto___83 *, void *, struct sk_buff___90 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___94 *, struct tcf_proto___83 *, void *, struct sk_buff___90 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___90 *, struct net___94 *, void *);
	struct module___264 *owner;
	int flags;
};

struct tcf_chain___83 {
	struct mutex filter_chain_lock;
	struct tcf_proto___83 *filter_chain;
	struct list_head list;
	struct tcf_block___83 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___83 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___76 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___83 *prog;
};

struct pneigh_entry___76;

struct neigh_hash_table___76;

struct neigh_table___76 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___89 *, __u32 *);
	bool (*key_eq)(const struct neighbour___76 *, const void *);
	int (*constructor)(struct neighbour___76 *);
	int (*pconstructor)(struct pneigh_entry___76 *);
	void (*pdestructor)(struct pneigh_entry___76 *);
	void (*proxy_redo)(struct sk_buff___90 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___89 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___76 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___89 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___76 *nht;
	struct pneigh_entry___76 **phash_buckets;
};

struct neigh_ops___76 {
	int family;
	void (*solicit)(struct neighbour___76 *, struct sk_buff___90 *);
	void (*error_report)(struct neighbour___76 *, struct sk_buff___90 *);
	int (*output)(struct neighbour___76 *, struct sk_buff___90 *);
	int (*connected_output)(struct neighbour___76 *, struct sk_buff___90 *);
};

struct pneigh_entry___76 {
	struct pneigh_entry___76 *next;
	possible_net_t___89 net;
	struct net_device___89 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___76 {
	struct neighbour___76 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___52 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
	int (*orig_input)(struct sk_buff___90 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___76 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___76 *ctarget;
	struct net___94 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___76 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___76 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___61;

struct timewait_sock_ops___60;

struct proto___76 {
	void (*close)(struct sock___76 *, long int);
	int (*pre_connect)(struct sock___76 *, struct sockaddr *, int);
	int (*connect)(struct sock___76 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___76 *, int);
	struct sock___76 * (*accept)(struct sock___76 *, int, int *, bool);
	int (*ioctl)(struct sock___76 *, int, long unsigned int);
	int (*init)(struct sock___76 *);
	void (*destroy)(struct sock___76 *);
	void (*shutdown)(struct sock___76 *, int);
	int (*setsockopt)(struct sock___76 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___76 *, int, int, char *, int *);
	void (*keepalive)(struct sock___76 *, int);
	int (*compat_ioctl)(struct sock___76 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___76 *, struct msghdr___78 *, size_t);
	int (*recvmsg)(struct sock___76 *, struct msghdr___78 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___76 *, struct page___285 *, int, size_t, int);
	int (*bind)(struct sock___76 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___76 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___76 *, struct sk_buff___90 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___76 *);
	int (*hash)(struct sock___76 *);
	void (*unhash)(struct sock___76 *);
	void (*rehash)(struct sock___76 *);
	int (*get_port)(struct sock___76 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___76 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___76 *, int);
	bool (*sock_is_readable)(struct sock___76 *);
	void (*enter_memory_pressure)(struct sock___76 *);
	void (*leave_memory_pressure)(struct sock___76 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___61 *rsk_prot;
	struct timewait_sock_ops___60 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___264 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___76 *, int);
};

struct xfrm_policy_queue___18 {
	struct sk_buff_head___89 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___18 {
	possible_net_t___89 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___18 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct request_sock___62;

struct request_sock_ops___61 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___76 *, struct request_sock___62 *);
	void (*send_ack)(const struct sock___76 *, struct sk_buff___90 *, struct request_sock___62 *);
	void (*send_reset)(const struct sock___76 *, struct sk_buff___90 *);
	void (*destructor)(struct request_sock___62 *);
	void (*syn_ack_timeout)(const struct request_sock___62 *);
};

struct timewait_sock_ops___60 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___76 *, struct sock___76 *, void *);
	void (*twsk_destructor)(struct sock___76 *);
};

struct request_sock___62 {
	struct sock_common___76 __req_common;
	struct request_sock___62 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___61 *rsk_ops;
	struct sock___76 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___58 {
	struct in6_addr mca_addr;
	struct inet6_dev___58 *idev;
	struct ifmcaddr6___58 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___24 {
	struct in6_addr aca_addr;
	struct fib6_info___24 *aca_rt;
	struct ifacaddr6___24 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___24 {
	struct fib_nh_exception___24 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___26 *fnhe_rth_input;
	struct rtable___26 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___26 {
	struct dst_entry___76 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___24 {
	struct fib_nh_exception___24 *chain;
};

struct fib_info___15;

struct fib_nh___15 {
	struct fib_nh_common___24 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___15 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___15 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___94 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___15 *nh;
	struct callback_head rcu;
	struct fib_nh___15 fib_nh[0];
};

struct nh_info___15;

struct nh_group___15;

struct nexthop___15 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___94 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___15 *nh_info;
		struct nh_group___15 *nh_grp;
	};
};

enum lwtunnel_ip_t {
	LWTUNNEL_IP_UNSPEC = 0,
	LWTUNNEL_IP_ID = 1,
	LWTUNNEL_IP_DST = 2,
	LWTUNNEL_IP_SRC = 3,
	LWTUNNEL_IP_TTL = 4,
	LWTUNNEL_IP_TOS = 5,
	LWTUNNEL_IP_FLAGS = 6,
	LWTUNNEL_IP_PAD = 7,
	LWTUNNEL_IP_OPTS = 8,
	__LWTUNNEL_IP_MAX = 9,
};

enum lwtunnel_ip6_t {
	LWTUNNEL_IP6_UNSPEC = 0,
	LWTUNNEL_IP6_ID = 1,
	LWTUNNEL_IP6_DST = 2,
	LWTUNNEL_IP6_SRC = 3,
	LWTUNNEL_IP6_HOPLIMIT = 4,
	LWTUNNEL_IP6_TC = 5,
	LWTUNNEL_IP6_FLAGS = 6,
	LWTUNNEL_IP6_PAD = 7,
	LWTUNNEL_IP6_OPTS = 8,
	__LWTUNNEL_IP6_MAX = 9,
};

enum {
	LWTUNNEL_IP_OPTS_UNSPEC = 0,
	LWTUNNEL_IP_OPTS_GENEVE = 1,
	LWTUNNEL_IP_OPTS_VXLAN = 2,
	LWTUNNEL_IP_OPTS_ERSPAN = 3,
	__LWTUNNEL_IP_OPTS_MAX = 4,
};

enum {
	LWTUNNEL_IP_OPT_GENEVE_UNSPEC = 0,
	LWTUNNEL_IP_OPT_GENEVE_CLASS = 1,
	LWTUNNEL_IP_OPT_GENEVE_TYPE = 2,
	LWTUNNEL_IP_OPT_GENEVE_DATA = 3,
	__LWTUNNEL_IP_OPT_GENEVE_MAX = 4,
};

enum {
	LWTUNNEL_IP_OPT_VXLAN_UNSPEC = 0,
	LWTUNNEL_IP_OPT_VXLAN_GBP = 1,
	__LWTUNNEL_IP_OPT_VXLAN_MAX = 2,
};

enum {
	LWTUNNEL_IP_OPT_ERSPAN_UNSPEC = 0,
	LWTUNNEL_IP_OPT_ERSPAN_VER = 1,
	LWTUNNEL_IP_OPT_ERSPAN_INDEX = 2,
	LWTUNNEL_IP_OPT_ERSPAN_DIR = 3,
	LWTUNNEL_IP_OPT_ERSPAN_HWID = 4,
	__LWTUNNEL_IP_OPT_ERSPAN_MAX = 5,
};

struct lwtunnel_encap_ops___3 {
	int (*build_state)(struct net___94 *, struct nlattr *, unsigned int, const void *, struct lwtunnel_state___52 **, struct netlink_ext_ack *);
	void (*destroy_state)(struct lwtunnel_state___52 *);
	int (*output)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
	int (*input)(struct sk_buff___90 *);
	int (*fill_encap)(struct sk_buff___90 *, struct lwtunnel_state___52 *);
	int (*get_encap_size)(struct lwtunnel_state___52 *);
	int (*cmp_encap)(struct lwtunnel_state___52 *, struct lwtunnel_state___52 *);
	int (*xmit)(struct sk_buff___90 *);
	struct module___264 *owner;
};

struct nh_info___15 {
	struct hlist_node dev_hash;
	struct nexthop___15 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___24 fib_nhc;
		struct fib_nh___15 fib_nh;
		struct fib6_nh___24 fib6_nh;
	};
};

struct nh_grp_entry___15;

struct nh_res_bucket___15 {
	struct nh_grp_entry___15 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___15 {
	struct nexthop___15 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___15 *nh_parent;
};

struct nh_res_table___15 {
	struct net___94 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___15 nh_buckets[0];
};

struct nh_group___15 {
	struct nh_group___15 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___15 *res_table;
	struct nh_grp_entry___15 nh_entries[0];
};

struct ip_tunnel_encap_ops___2 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___90 *, struct ip_tunnel_encap *, u8 *, struct flowi4 *);
	int (*err_handler)(struct sk_buff___90 *, u32);
};

struct ip6_tnl_encap_ops {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___90 *, struct ip_tunnel_encap *, u8 *, struct flowi6 *);
	int (*err_handler)(struct sk_buff___90 *, struct inet6_skb_parm *, u8, u8, int, __be32);
};

struct xfrm_type___18 {
	struct module___264 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___18 *);
	void (*destructor)(struct xfrm_state___18 *);
	int (*input)(struct xfrm_state___18 *, struct sk_buff___90 *);
	int (*output)(struct xfrm_state___18 *, struct sk_buff___90 *);
	int (*reject)(struct xfrm_state___18 *, struct sk_buff___90 *, const struct flowi *);
};

struct xfrm_type_offload___18 {
	struct module___264 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___18 *, struct sk_buff___90 *);
	int (*input_tail)(struct xfrm_state___18 *, struct sk_buff___90 *);
	int (*xmit)(struct xfrm_state___18 *, struct sk_buff___90 *, netdev_features_t);
};

struct hw_port_info___8 {
	struct net_device___89 *lower_dev;
	u32 port_id;
};

struct metadata_dst___9 {
	struct dst_entry___76 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___8 port_info;
	} u;
};

struct geneve_opt {
	__be16 opt_class;
	u8 type;
	u8 length: 5;
	u8 r3: 1;
	u8 r2: 1;
	u8 r1: 1;
	int: 31;
	u8 opt_data[0];
};

struct vxlan_metadata {
	u32 gbp;
};

struct erspan_md2 {
	__be32 timestamp;
	__be16 sgt;
	__u8 hwid_upper: 2;
	__u8 ft: 5;
	__u8 p: 1;
	__u8 o: 1;
	__u8 gra: 2;
	__u8 dir: 1;
	__u8 hwid: 4;
	long: 60;
};

struct erspan_metadata {
	int version;
	union {
		__be32 index;
		struct erspan_md2 md2;
	} u;
};

typedef struct bio_vec___193 skb_frag_t___35;

typedef struct sk_buff___86 * (*gro_receive_t___2)(struct list_head *, struct sk_buff___86 *);

struct dentry___281;

struct super_block___281;

struct module___265;

struct file_system_type___281 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___281 * (*mount)(struct file_system_type___281 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___281 *);
	struct module___265 *owner;
	struct file_system_type___281 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___281;

struct kiocb___281;

struct iov_iter___201;

struct poll_table_struct___202;

struct vm_area_struct___286;

struct inode___281;

struct file_lock___281;

struct page___286;

struct pipe_inode_info___122;

struct seq_file___256;

struct file_operations___282 {
	struct module___265 *owner;
	loff_t (*llseek)(struct file___281 *, loff_t, int);
	ssize_t (*read)(struct file___281 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___281 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___281 *, struct iov_iter___201 *);
	ssize_t (*write_iter)(struct kiocb___281 *, struct iov_iter___201 *);
	int (*iopoll)(struct kiocb___281 *, bool);
	int (*iterate)(struct file___281 *, struct dir_context *);
	int (*iterate_shared)(struct file___281 *, struct dir_context *);
	__poll_t (*poll)(struct file___281 *, struct poll_table_struct___202 *);
	long int (*unlocked_ioctl)(struct file___281 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___281 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___281 *, struct vm_area_struct___286 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___281 *, struct file___281 *);
	int (*flush)(struct file___281 *, fl_owner_t);
	int (*release)(struct inode___281 *, struct file___281 *);
	int (*fsync)(struct file___281 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___281 *, int);
	int (*lock)(struct file___281 *, int, struct file_lock___281 *);
	ssize_t (*sendpage)(struct file___281 *, struct page___286 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___281 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___281 *, long unsigned int);
	int (*flock)(struct file___281 *, int, struct file_lock___281 *);
	ssize_t (*splice_write)(struct pipe_inode_info___122 *, struct file___281 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___281 *, loff_t *, struct pipe_inode_info___122 *, size_t, unsigned int);
	int (*setlease)(struct file___281 *, long int, struct file_lock___281 **, void **);
	long int (*fallocate)(struct file___281 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___256 *, struct file___281 *);
	ssize_t (*copy_file_range)(struct file___281 *, loff_t, struct file___281 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___281 *, loff_t, struct file___281 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___281 *, loff_t, loff_t, int);
};

struct vmacache___286 {
	u64 seqnum;
	struct vm_area_struct___286 *vmas[4];
};

struct page_frag___286 {
	struct page___286 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___287;

struct pid___258;

struct nsproxy___267;

struct signal_struct___282;

struct bio_list___172;

struct backing_dev_info___158;

struct io_context___172;

struct css_set___208;

struct mem_cgroup___146;

struct request_queue___172;

struct vm_struct___264;

struct task_struct___288 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___288 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___287 *mm;
	struct mm_struct___287 *active_mm;
	struct vmacache___286 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___288 *real_parent;
	struct task_struct___288 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___288 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___258 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___267 *nsproxy;
	struct signal_struct___282 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___288 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___172 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___158 *backing_dev_info;
	struct io_context___172 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___208 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___122 *splice_pipe;
	struct page_frag___286 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___146 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___146 *active_memcg;
	struct request_queue___172 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___288 *oom_reaper_list;
	struct vm_struct___264 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___269;

struct kobj_type___269;

struct kernfs_node___269;

struct kobject___269 {
	const char *name;
	struct list_head entry;
	struct kobject___269 *parent;
	struct kset___269 *kset;
	struct kobj_type___269 *ktype;
	struct kernfs_node___269 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___266 {
	struct kobject___269 kobj;
	struct module___265 *mod;
	struct kobject___269 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___265 {
	struct module___265 *mod;
	struct latch_tree_node node;
};

struct module_layout___265 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___265 mtn;
};

struct module_attribute___265;

struct kernel_param___265;

struct module___265 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___266 mkobj;
	struct module_attribute___265 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___269 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___265 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___265 core_layout;
	struct module_layout___265 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___281;

struct dentry___281 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___281 *d_parent;
	struct qstr d_name;
	struct inode___281 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___281 *d_op;
	struct super_block___281 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___281;

struct address_space___281 {
	struct inode___281 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___281 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___281;

struct bdi_writeback___158;

struct inode___281 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___281 *i_op;
	struct super_block___281 *i_sb;
	struct address_space___281 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___158 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___282 *i_fop;
		void (*free_inode)(struct inode___281 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___281 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___122 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___281;

struct path___281;

struct dentry_operations___281 {
	int (*d_revalidate)(struct dentry___281 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___281 *, unsigned int);
	int (*d_hash)(const struct dentry___281 *, struct qstr *);
	int (*d_compare)(const struct dentry___281 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___281 *);
	int (*d_init)(struct dentry___281 *);
	void (*d_release)(struct dentry___281 *);
	void (*d_prune)(struct dentry___281 *);
	void (*d_iput)(struct dentry___281 *, struct inode___281 *);
	char * (*d_dname)(struct dentry___281 *, char *, int);
	struct vfsmount___281 * (*d_automount)(struct path___281 *);
	int (*d_manage)(const struct path___281 *, bool);
	struct dentry___281 * (*d_real)(struct dentry___281 *, const struct inode___281 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___281;

struct mem_dqinfo___281 {
	struct quota_format_type___281 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___281;

struct quota_info___281 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___281 *files[3];
	struct mem_dqinfo___281 info[3];
	const struct quota_format_ops___281 *ops[3];
};

struct rcuwait___282 {
	struct task_struct___288 *task;
};

struct percpu_rw_semaphore___282 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___282 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___281 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___282 rw_sem[3];
};

struct shrink_control___146;

struct shrinker___146 {
	long unsigned int (*count_objects)(struct shrinker___146 *, struct shrink_control___146 *);
	long unsigned int (*scan_objects)(struct shrinker___146 *, struct shrink_control___146 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___281;

struct dquot_operations___281;

struct quotactl_ops___281;

struct block_device___175;

struct super_block___281 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___281 *s_type;
	const struct super_operations___281 *s_op;
	const struct dquot_operations___281 *dq_op;
	const struct quotactl_ops___281 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___281 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___175 *s_bdev;
	struct backing_dev_info___158 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___281 s_dquot;
	struct sb_writers___281 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___281 *s_d_op;
	int cleancache_poolid;
	struct shrinker___146 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___281 {
	struct dentry___281 *mnt_root;
	struct super_block___281 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___281 {
	struct vfsmount___281 *mnt;
	struct dentry___281 *dentry;
};

struct pid_namespace___258;

struct upid___258 {
	int nr;
	struct pid_namespace___258 *ns;
};

struct pid_namespace___258 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___288 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___258 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___258 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___258 numbers[1];
};

typedef struct page___286 *pgtable_t___286;

struct page_pool___110;

struct dev_pagemap___276;

struct page___286 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___281 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___110 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___286 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___286 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___287 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___276 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___276;

struct vm_area_struct___286 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___286 *vm_next;
	struct vm_area_struct___286 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___287 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___276 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___281 *vm_file;
	struct file___281 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___282 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___288 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___288 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___258 *pids[4];
	struct pid___258 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___287 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___286;

struct mm_struct___287 {
	struct {
		struct vm_area_struct___286 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___281 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___286 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___288 *owner;
		struct user_namespace___26 *user_ns;
		struct file___281 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___95;

struct cgroup_namespace___208;

struct nsproxy___267 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___258 *pid_ns_for_children;
	struct net___95 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___208 *cgroup_ns;
};

struct bio___172;

struct bio_list___172 {
	struct bio___172 *head;
	struct bio___172 *tail;
};

struct cgroup_subsys_state___208;

struct bdi_writeback___158 {
	struct backing_dev_info___158 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___208 *memcg_css;
	struct cgroup_subsys_state___208 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___262;

struct backing_dev_info___158 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___158 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___262 *dev;
	char dev_name[64];
	struct device___262 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___281 *debug_dir;
};

struct io_cq___172;

struct io_context___172 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___172 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___208;

struct css_set___208 {
	struct cgroup_subsys_state___208 *subsys[14];
	refcount_t refcount;
	struct css_set___208 *dom_cset;
	struct cgroup___208 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___208 *mg_src_cgrp;
	struct cgroup___208 *mg_dst_cgrp;
	struct css_set___208 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___281;

struct pipe_buffer___122;

struct pipe_inode_info___122 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___286 *tmp_page;
	struct fasync_struct___281 *fasync_readers;
	struct fasync_struct___281 *fasync_writers;
	struct pipe_buffer___122 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___208;

struct cgroup_subsys_state___208 {
	struct cgroup___208 *cgroup;
	struct cgroup_subsys___208 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___208 *parent;
};

struct cgroup_file___208 {
	struct kernfs_node___269 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___146;

struct mem_cgroup_per_node___146;

struct mem_cgroup___146 {
	struct cgroup_subsys_state___208 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___208 events_file;
	struct cgroup_file___208 events_local_file;
	struct cgroup_file___208 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___146 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___288 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___146 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___172;

struct blk_integrity___172 {
	const struct blk_integrity_profile___172 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___172 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___172 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___172;

struct elevator_queue___172;

struct blk_mq_ops___167;

struct blk_mq_hw_ctx___167;

struct gendisk___175;

struct blkcg_gq___160;

struct blk_mq_tag_set___167;

struct request_queue___172 {
	struct request___172 *last_merge;
	struct elevator_queue___172 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___167 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___167 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___175 *disk;
	struct kobject___269 kobj;
	struct kobject___269 *mq_kobj;
	struct blk_integrity___172 integrity;
	struct device___262 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___160 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___167 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___172 bio_split;
	struct dentry___281 *debugfs_dir;
	struct dentry___281 *sched_debugfs_dir;
	struct dentry___281 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___264 {
	struct vm_struct___264 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___286 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___146 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___146 *memcg;
};

struct page_pool_params___110 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___262 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___110 {
	u32 count;
	struct page___286 *cache[128];
};

struct page_pool___110 {
	struct page_pool_params___110 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___286 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___110 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___276;

struct dev_pagemap___276 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___276 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___258 {
	rwlock_t lock;
	struct pid___258 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___281 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___281 f_path;
	struct inode___281 *f_inode;
	const struct file_operations___282 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___258 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___281 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___276;

struct vm_operations_struct___276 {
	void (*open)(struct vm_area_struct___286 *);
	void (*close)(struct vm_area_struct___286 *);
	int (*may_split)(struct vm_area_struct___286 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___286 *);
	int (*mprotect)(struct vm_area_struct___286 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___276 *);
	vm_fault_t (*huge_fault)(struct vm_fault___276 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___276 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___286 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___276 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___276 *);
	int (*access)(struct vm_area_struct___286 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___286 *);
	int (*set_policy)(struct vm_area_struct___286 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___286 *, long unsigned int);
	struct page___286 * (*find_special_page)(struct vm_area_struct___286 *, long unsigned int);
};

struct core_thread___286 {
	struct task_struct___288 *task;
	struct core_thread___286 *next;
};

struct core_state___286 {
	atomic_t nr_threads;
	struct core_thread___286 dumper;
	struct completion startup;
};

struct vm_fault___276 {
	const struct {
		struct vm_area_struct___286 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___286 *cow_page;
	struct page___286 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___286 prealloc_pte;
};

struct pglist_data___154;

struct lruvec___154 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___154 *pgdat;
};

struct zone___154 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___154 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___154 {
	struct zone___154 *zone;
	int zone_idx;
};

struct zonelist___154 {
	struct zoneref___154 _zonerefs[321];
};

struct pglist_data___154 {
	struct zone___154 node_zones[5];
	struct zonelist___154 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___288 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___288 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___154 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___208 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___288 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___84;

struct cgroup_bpf___84 {
	struct bpf_prog_array___84 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___84 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___208;

struct cgroup_rstat_cpu___208;

struct cgroup___208 {
	struct cgroup_subsys_state___208 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___269 *kn;
	struct cgroup_file___208 procs_file;
	struct cgroup_file___208 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___208 *subsys[14];
	struct cgroup_root___208 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___208 *dom_cgrp;
	struct cgroup___208 *old_dom_cgrp;
	struct cgroup_rstat_cpu___208 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___208 psi;
	struct cgroup_bpf___84 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___172 {
	struct request_queue___172 *q;
	struct io_context___172 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___281 {
	struct file___281 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___281 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___116 *ki_waitq;
	};
};

struct iattr___281 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___281 *ia_file;
};

struct dquot___281 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___281 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___281 {
	int qf_fmt_id;
	const struct quota_format_ops___281 *qf_ops;
	struct module___265 *qf_owner;
	struct quota_format_type___281 *qf_next;
};

struct quota_format_ops___281 {
	int (*check_quota_file)(struct super_block___281 *, int);
	int (*read_file_info)(struct super_block___281 *, int);
	int (*write_file_info)(struct super_block___281 *, int);
	int (*free_file_info)(struct super_block___281 *, int);
	int (*read_dqblk)(struct dquot___281 *);
	int (*commit_dqblk)(struct dquot___281 *);
	int (*release_dqblk)(struct dquot___281 *);
	int (*get_next_id)(struct super_block___281 *, struct kqid *);
};

struct dquot_operations___281 {
	int (*write_dquot)(struct dquot___281 *);
	struct dquot___281 * (*alloc_dquot)(struct super_block___281 *, int);
	void (*destroy_dquot)(struct dquot___281 *);
	int (*acquire_dquot)(struct dquot___281 *);
	int (*release_dquot)(struct dquot___281 *);
	int (*mark_dirty)(struct dquot___281 *);
	int (*write_info)(struct super_block___281 *, int);
	qsize_t * (*get_reserved_space)(struct inode___281 *);
	int (*get_projid)(struct inode___281 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___281 *, qsize_t *);
	int (*get_next_id)(struct super_block___281 *, struct kqid *);
};

struct quotactl_ops___281 {
	int (*quota_on)(struct super_block___281 *, int, int, const struct path___281 *);
	int (*quota_off)(struct super_block___281 *, int);
	int (*quota_enable)(struct super_block___281 *, unsigned int);
	int (*quota_disable)(struct super_block___281 *, unsigned int);
	int (*quota_sync)(struct super_block___281 *, int);
	int (*set_info)(struct super_block___281 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___281 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___281 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___281 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___281 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___281 *, unsigned int);
};

struct writeback_control___158;

struct address_space_operations___281 {
	int (*writepage)(struct page___286 *, struct writeback_control___158 *);
	int (*readpage)(struct file___281 *, struct page___286 *);
	int (*writepages)(struct address_space___281 *, struct writeback_control___158 *);
	int (*set_page_dirty)(struct page___286 *);
	int (*readpages)(struct file___281 *, struct address_space___281 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___281 *, struct address_space___281 *, loff_t, unsigned int, unsigned int, struct page___286 **, void **);
	int (*write_end)(struct file___281 *, struct address_space___281 *, loff_t, unsigned int, unsigned int, struct page___286 *, void *);
	sector_t (*bmap)(struct address_space___281 *, sector_t);
	void (*invalidatepage)(struct page___286 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___286 *, gfp_t);
	void (*freepage)(struct page___286 *);
	ssize_t (*direct_IO)(struct kiocb___281 *, struct iov_iter___201 *);
	int (*migratepage)(struct address_space___281 *, struct page___286 *, struct page___286 *, enum migrate_mode);
	bool (*isolate_page)(struct page___286 *, isolate_mode_t);
	void (*putback_page)(struct page___286 *);
	int (*launder_page)(struct page___286 *);
	int (*is_partially_uptodate)(struct page___286 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___286 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___281 *, struct page___286 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___281 *, sector_t *);
	void (*swap_deactivate)(struct file___281 *);
};

struct writeback_control___158 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___158 *wb;
	struct inode___281 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___198;

struct iov_iter___201 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___198 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___122 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___281 {
	struct dentry___281 * (*lookup)(struct inode___281 *, struct dentry___281 *, unsigned int);
	const char * (*get_link)(struct dentry___281 *, struct inode___281 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___281 *, int);
	struct posix_acl * (*get_acl)(struct inode___281 *, int, bool);
	int (*readlink)(struct dentry___281 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___281 *, struct dentry___281 *, umode_t, bool);
	int (*link)(struct dentry___281 *, struct inode___281 *, struct dentry___281 *);
	int (*unlink)(struct inode___281 *, struct dentry___281 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___281 *, struct dentry___281 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___281 *, struct dentry___281 *, umode_t);
	int (*rmdir)(struct inode___281 *, struct dentry___281 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___281 *, struct dentry___281 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___281 *, struct dentry___281 *, struct inode___281 *, struct dentry___281 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___281 *, struct iattr___281 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___281 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___281 *, char *, size_t);
	int (*fiemap)(struct inode___281 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___281 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___281 *, struct dentry___281 *, struct file___281 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___281 *, struct dentry___281 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___281 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___281 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___281 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___281 {
	void (*fl_copy_lock)(struct file_lock___281 *, struct file_lock___281 *);
	void (*fl_release_private)(struct file_lock___281 *);
};

struct lock_manager_operations___281;

struct file_lock___281 {
	struct file_lock___281 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___281 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___281 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___281 *fl_ops;
	const struct lock_manager_operations___281 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___281 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___281 *);
	int (*lm_grant)(struct file_lock___281 *, int);
	bool (*lm_break)(struct file_lock___281 *);
	int (*lm_change)(struct file_lock___281 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___281 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___281 *);
};

struct fasync_struct___281 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___281 *fa_next;
	struct file___281 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___281 {
	struct inode___281 * (*alloc_inode)(struct super_block___281 *);
	void (*destroy_inode)(struct inode___281 *);
	void (*free_inode)(struct inode___281 *);
	void (*dirty_inode)(struct inode___281 *, int);
	int (*write_inode)(struct inode___281 *, struct writeback_control___158 *);
	int (*drop_inode)(struct inode___281 *);
	void (*evict_inode)(struct inode___281 *);
	void (*put_super)(struct super_block___281 *);
	int (*sync_fs)(struct super_block___281 *, int);
	int (*freeze_super)(struct super_block___281 *);
	int (*freeze_fs)(struct super_block___281 *);
	int (*thaw_super)(struct super_block___281 *);
	int (*unfreeze_fs)(struct super_block___281 *);
	int (*statfs)(struct dentry___281 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___281 *, int *, char *);
	void (*umount_begin)(struct super_block___281 *);
	int (*show_options)(struct seq_file___256 *, struct dentry___281 *);
	int (*show_devname)(struct seq_file___256 *, struct dentry___281 *);
	int (*show_path)(struct seq_file___256 *, struct dentry___281 *);
	int (*show_stats)(struct seq_file___256 *, struct dentry___281 *);
	ssize_t (*quota_read)(struct super_block___281 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___281 *, int, const char *, size_t, loff_t);
	struct dquot___281 ** (*get_dquots)(struct inode___281 *);
	long int (*nr_cached_objects)(struct super_block___281 *, struct shrink_control___146 *);
	long int (*free_cached_objects)(struct super_block___281 *, struct shrink_control___146 *);
	struct file___281 * (*real_loop)(struct file___281 *);
};

struct wakeup_source___262;

struct dev_pm_info___262 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___262 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___262 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___262;

struct bus_type___262;

struct device_driver___262;

struct dev_pm_domain___262;

struct fwnode_handle___258;

struct class___262;

struct attribute_group___269;

struct device___262 {
	struct kobject___269 kobj;
	struct device___262 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___262 *type;
	struct bus_type___262 *bus;
	struct device_driver___262 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___262 power;
	struct dev_pm_domain___262 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___258 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___262 *class;
	const struct attribute_group___269 **groups;
	void (*release)(struct device___262 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___175 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___281 *bd_inode;
	struct super_block___281 *bd_super;
	void *bd_claiming;
	struct device___262 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___269 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___175 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___281 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___210)(struct file___281 *, wait_queue_head_t *, struct poll_table_struct___202 *);

struct poll_table_struct___202 {
	poll_queue_proc___210 _qproc;
	__poll_t _key;
};

struct seq_operations___256;

struct seq_file___256 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___256 *op;
	int poll_event;
	const struct file___281 *file;
	void *private;
};

typedef void bio_end_io_t___172(struct bio___172 *);

struct bio_vec___198 {
	struct page___286 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___172;

struct bio___172 {
	struct bio___172 *bi_next;
	struct block_device___175 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___172 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___160 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___172 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___198 *bi_io_vec;
	struct bio_set___172 *bi_pool;
	struct bio_vec___198 bi_inline_vecs[0];
};

struct dev_pagemap_ops___276 {
	void (*page_free)(struct page___286 *);
	void (*kill)(struct dev_pagemap___276 *);
	void (*cleanup)(struct dev_pagemap___276 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___276 *);
};

struct fwnode_operations___258;

struct fwnode_handle___258 {
	struct fwnode_handle___258 *secondary;
	const struct fwnode_operations___258 *ops;
	struct device___262 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___258;

struct fwnode_endpoint___258;

struct fwnode_operations___258 {
	struct fwnode_handle___258 * (*get)(struct fwnode_handle___258 *);
	void (*put)(struct fwnode_handle___258 *);
	bool (*device_is_available)(const struct fwnode_handle___258 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___258 *, const struct device___262 *);
	bool (*property_present)(const struct fwnode_handle___258 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___258 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___258 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___258 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*get_parent)(const struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*get_next_child_node)(const struct fwnode_handle___258 *, struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*get_named_child_node)(const struct fwnode_handle___258 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___258 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___258 *);
	struct fwnode_handle___258 * (*graph_get_next_endpoint)(const struct fwnode_handle___258 *, struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*graph_get_remote_endpoint)(const struct fwnode_handle___258 *);
	struct fwnode_handle___258 * (*graph_get_port_parent)(struct fwnode_handle___258 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___258 *, struct fwnode_endpoint___258 *);
	int (*add_links)(struct fwnode_handle___258 *);
};

struct fwnode_endpoint___258 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___258 *local_fwnode;
};

struct fwnode_reference_args___258 {
	struct fwnode_handle___258 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___269;

struct kernfs_elem_dir___269 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___269 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___269;

struct kernfs_root___269 {
	struct kernfs_node___269 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___269 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___269 {
	struct kernfs_node___269 *target_kn;
};

struct kernfs_ops___269;

struct kernfs_elem_attr___269 {
	const struct kernfs_ops___269 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___269 *notify_next;
};

struct kernfs_node___269 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___269 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___269 dir;
		struct kernfs_elem_symlink___269 symlink;
		struct kernfs_elem_attr___269 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___269;

struct kernfs_ops___269 {
	int (*open)(struct kernfs_open_file___269 *);
	void (*release)(struct kernfs_open_file___269 *);
	int (*seq_show)(struct seq_file___256 *, void *);
	void * (*seq_start)(struct seq_file___256 *, loff_t *);
	void * (*seq_next)(struct seq_file___256 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___256 *, void *);
	ssize_t (*read)(struct kernfs_open_file___269 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___269 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___269 *, struct poll_table_struct___202 *);
	int (*mmap)(struct kernfs_open_file___269 *, struct vm_area_struct___286 *);
};

struct kernfs_syscall_ops___269 {
	int (*show_options)(struct seq_file___256 *, struct kernfs_root___269 *);
	int (*mkdir)(struct kernfs_node___269 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___269 *);
	int (*rename)(struct kernfs_node___269 *, struct kernfs_node___269 *, const char *);
	int (*show_path)(struct seq_file___256 *, struct kernfs_node___269 *, struct kernfs_root___269 *);
};

struct kernfs_open_file___269 {
	struct kernfs_node___269 *kn;
	struct file___281 *file;
	struct seq_file___256 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___276 *vm_ops;
};

struct sock___77;

struct kobj_ns_type_operations___77 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___77 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___95 *net;
} possible_net_t___90;

struct proto___77;

struct sock_common___77 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___77 *skc_prot;
	possible_net_t___90 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___77 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___91;

struct sk_buff_head___90 {
	struct sk_buff___91 *next;
	struct sk_buff___91 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___77 {
	struct cgroup___208 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___77;

struct socket_wq___78;

struct dst_entry___77;

struct socket___79;

struct net_device___90;

struct sock_reuseport___26;

struct sock___77 {
	struct sock_common___77 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___90 sk_error_queue;
	struct sk_buff___91 *sk_rx_skb_cache;
	struct sk_buff_head___90 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___91 *head;
		struct sk_buff___91 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___77 *sk_filter;
	union {
		struct socket_wq___78 *sk_wq;
		struct socket_wq___78 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___77 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___77 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___91 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___91 *sk_tx_skb_cache;
	struct sk_buff_head___90 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___286 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___77 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___258 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___79 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___77 sk_cgrp_data;
	struct mem_cgroup___146 *sk_memcg;
	void (*sk_state_change)(struct sock___77 *);
	void (*sk_data_ready)(struct sock___77 *);
	void (*sk_write_space)(struct sock___77 *);
	void (*sk_error_report)(struct sock___77 *);
	int (*sk_backlog_rcv)(struct sock___77 *, struct sk_buff___91 *);
	struct sk_buff___91 * (*sk_validate_xmit_skb)(struct sock___77 *, struct net_device___90 *, struct sk_buff___91 *);
	void (*sk_destruct)(struct sock___77 *);
	struct sock_reuseport___26 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___269;

struct attribute_group___269 {
	const char *name;
	umode_t (*is_visible)(struct kobject___269 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___269 *, struct bin_attribute___269 *, int);
	struct attribute **attrs;
	struct bin_attribute___269 **bin_attrs;
};

struct bin_attribute___269 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___281 * (*f_mapping)();
	ssize_t (*read)(struct file___281 *, struct kobject___269 *, struct bin_attribute___269 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___281 *, struct kobject___269 *, struct bin_attribute___269 *, char *, loff_t, size_t);
	int (*mmap)(struct file___281 *, struct kobject___269 *, struct bin_attribute___269 *, struct vm_area_struct___286 *);
};

struct sysfs_ops___269 {
	ssize_t (*show)(struct kobject___269 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___269 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___269;

struct kset___269 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___269 kobj;
	const struct kset_uevent_ops___269 *uevent_ops;
};

struct kobj_type___269 {
	void (*release)(struct kobject___269 *);
	const struct sysfs_ops___269 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___269 **default_groups;
	const struct kobj_ns_type_operations___77 * (*child_ns_type)(struct kobject___269 *);
	const void * (*namespace)(struct kobject___269 *);
	void (*get_ownership)(struct kobject___269 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___269 {
	int (* const filter)(struct kset___269 *, struct kobject___269 *);
	const char * (* const name)(struct kset___269 *, struct kobject___269 *);
	int (* const uevent)(struct kset___269 *, struct kobject___269 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___265 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___265 *);
	int (*get)(char *, const struct kernel_param___265 *);
	void (*free)(void *);
};

struct kparam_array___265;

struct kernel_param___265 {
	const char *name;
	struct module___265 *mod;
	const struct kernel_param_ops___265 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___265 *arr;
	};
};

struct kparam_array___265 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___265 *ops;
	void *elem;
};

struct module_attribute___265 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___265 *, struct module_kobject___266 *, char *);
	ssize_t (*store)(struct module_attribute___265 *, struct module_kobject___266 *, const char *, size_t);
	void (*setup)(struct module___265 *, const char *);
	int (*test)(struct module___265 *);
	void (*free)(struct module___265 *);
};

struct ip_ra_chain___50;

struct fib_rules_ops___77;

struct fqdir___95;

struct tcp_congestion_ops___24;

struct fib_notifier_ops___77;

struct netns_ipv4___95 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___50 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___77 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___77 *fibnl;
	struct sock___77 **icmp_sk;
	struct sock___77 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___77 **tcp_sk;
	struct fqdir___95 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___24 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___77 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___77 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___77 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___77;

struct dst_ops___95 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___95 *);
	struct dst_entry___77 * (*check)(struct dst_entry___77 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___77 *);
	unsigned int (*mtu)(const struct dst_entry___77 *);
	u32 * (*cow_metrics)(struct dst_entry___77 *, long unsigned int);
	void (*destroy)(struct dst_entry___77 *);
	void (*ifdown)(struct dst_entry___77 *, struct net_device___90 *, int);
	struct dst_entry___77 * (*negative_advice)(struct dst_entry___77 *);
	void (*link_failure)(struct sk_buff___91 *);
	void (*update_pmtu)(struct dst_entry___77 *, struct sock___77 *, struct sk_buff___91 *, u32, bool);
	void (*redirect)(struct dst_entry___77 *, struct sock___77 *, struct sk_buff___91 *);
	int (*local_out)(struct net___95 *, struct sock___77 *, struct sk_buff___91 *);
	struct neighbour___77 * (*neigh_lookup)(const struct dst_entry___77 *, struct sk_buff___91 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___77 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___95 {
	struct dst_ops___95 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___95 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___77 *fib6_rules_ops;
	struct sock___77 **icmp_sk;
	struct sock___77 *ndisc_sk;
	struct sock___77 *tcp_sk;
	struct sock___77 *igmp_sk;
	struct sock___77 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___77 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___77 *notifier_ops;
	struct fib_notifier_ops___77 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___95 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___95 *fqdir;
};

struct netns_sctp___77 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___77 *ctl_sock;
	struct sock___77 *udp4_sock;
	struct sock___77 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___84;

struct netns_bpf___84 {
	struct bpf_prog_array___84 *run_array[2];
	struct bpf_prog___84 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___95 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___77 *nlsk;
	struct sock___77 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___95 xfrm4_dst_ops;
	struct dst_ops___95 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___95 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___77 *rtnl;
	struct sock___77 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___90 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___95 ipv4;
	struct netns_ipv6___95 ipv6;
	struct netns_ieee802154_lowpan___95 ieee802154_lowpan;
	struct netns_sctp___77 sctp;
	struct netns_nf___16 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___90 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___84 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___95 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___77 *crypto_nlsk;
	struct sock___77 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___208 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___208 *root_cset;
};

struct msghdr___79 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___201 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___281 *msg_iocb;
};

struct socket_wq___78 {
	wait_queue_head_t wait;
	struct fasync_struct___281 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___78;

struct socket___79 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___281 *file;
	struct sock___77 *sk;
	const struct proto_ops___78 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___78 wq;
};

typedef int (*sk_read_actor_t___77)(read_descriptor_t *, struct sk_buff___91 *, unsigned int, size_t);

struct proto_ops___78 {
	int family;
	struct module___265 *owner;
	int (*release)(struct socket___79 *);
	int (*bind)(struct socket___79 *, struct sockaddr *, int);
	int (*connect)(struct socket___79 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___79 *, struct socket___79 *);
	int (*accept)(struct socket___79 *, struct socket___79 *, int, bool);
	int (*getname)(struct socket___79 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___281 *, struct socket___79 *, struct poll_table_struct___202 *);
	int (*ioctl)(struct socket___79 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___79 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___79 *, void *, bool, bool);
	int (*listen)(struct socket___79 *, int);
	int (*shutdown)(struct socket___79 *, int);
	int (*setsockopt)(struct socket___79 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___79 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___256 *, struct socket___79 *);
	int (*sendmsg)(struct socket___79 *, struct msghdr___79 *, size_t);
	int (*recvmsg)(struct socket___79 *, struct msghdr___79 *, size_t, int);
	int (*mmap)(struct file___281 *, struct socket___79 *, struct vm_area_struct___286 *);
	ssize_t (*sendpage)(struct socket___79 *, struct page___286 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___79 *, loff_t *, struct pipe_inode_info___122 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___77 *, int);
	int (*peek_len)(struct socket___79 *);
	int (*read_sock)(struct sock___77 *, read_descriptor_t *, sk_read_actor_t___77);
	int (*sendpage_locked)(struct sock___77 *, struct page___286 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___77 *, struct msghdr___79 *, size_t);
	int (*set_rcvlowat)(struct sock___77 *, int);
};

struct sk_buff___91 {
	union {
		struct {
			struct sk_buff___91 *next;
			struct sk_buff___91 *prev;
			union {
				struct net_device___90 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___77 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___91 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___262 {
	int (*prepare)(struct device___262 *);
	void (*complete)(struct device___262 *);
	int (*suspend)(struct device___262 *);
	int (*resume)(struct device___262 *);
	int (*freeze)(struct device___262 *);
	int (*thaw)(struct device___262 *);
	int (*poweroff)(struct device___262 *);
	int (*restore)(struct device___262 *);
	int (*suspend_late)(struct device___262 *);
	int (*resume_early)(struct device___262 *);
	int (*freeze_late)(struct device___262 *);
	int (*thaw_early)(struct device___262 *);
	int (*poweroff_late)(struct device___262 *);
	int (*restore_early)(struct device___262 *);
	int (*suspend_noirq)(struct device___262 *);
	int (*resume_noirq)(struct device___262 *);
	int (*freeze_noirq)(struct device___262 *);
	int (*thaw_noirq)(struct device___262 *);
	int (*poweroff_noirq)(struct device___262 *);
	int (*restore_noirq)(struct device___262 *);
	int (*runtime_suspend)(struct device___262 *);
	int (*runtime_resume)(struct device___262 *);
	int (*runtime_idle)(struct device___262 *);
};

struct wakeup_source___262 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___262 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___262 {
	struct dev_pm_ops___262 ops;
	int (*start)(struct device___262 *);
	void (*detach)(struct device___262 *, bool);
	int (*activate)(struct device___262 *);
	void (*sync)(struct device___262 *);
	void (*dismiss)(struct device___262 *);
};

struct bus_type___262 {
	const char *name;
	const char *dev_name;
	struct device___262 *dev_root;
	const struct attribute_group___269 **bus_groups;
	const struct attribute_group___269 **dev_groups;
	const struct attribute_group___269 **drv_groups;
	int (*match)(struct device___262 *, struct device_driver___262 *);
	int (*uevent)(struct device___262 *, struct kobj_uevent_env *);
	int (*probe)(struct device___262 *);
	void (*sync_state)(struct device___262 *);
	void (*remove)(struct device___262 *);
	void (*shutdown)(struct device___262 *);
	int (*online)(struct device___262 *);
	int (*offline)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	int (*num_vf)(struct device___262 *);
	int (*dma_configure)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___262 {
	const char *name;
	struct bus_type___262 *bus;
	struct module___265 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___262 *);
	void (*sync_state)(struct device___262 *);
	int (*remove)(struct device___262 *);
	void (*shutdown)(struct device___262 *);
	int (*suspend)(struct device___262 *, pm_message_t);
	int (*resume)(struct device___262 *);
	const struct attribute_group___269 **groups;
	const struct attribute_group___269 **dev_groups;
	const struct dev_pm_ops___262 *pm;
	void (*coredump)(struct device___262 *);
	struct driver_private *p;
};

struct device_type___262 {
	const char *name;
	const struct attribute_group___269 **groups;
	int (*uevent)(struct device___262 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___262 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___262 *);
	const struct dev_pm_ops___262 *pm;
};

struct class___262 {
	const char *name;
	struct module___265 *owner;
	const struct attribute_group___269 **class_groups;
	const struct attribute_group___269 **dev_groups;
	struct kobject___269 *dev_kobj;
	int (*dev_uevent)(struct device___262 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___262 *, umode_t *);
	void (*class_release)(struct class___262 *);
	void (*dev_release)(struct device___262 *);
	int (*shutdown_pre)(struct device___262 *);
	const struct kobj_ns_type_operations___77 *ns_type;
	const void * (*namespace)(struct device___262 *);
	void (*get_ownership)(struct device___262 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___262 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___122;

struct pipe_buffer___122 {
	struct page___286 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___122 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___122 {
	int (*confirm)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
	void (*release)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
	bool (*try_steal)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
	bool (*get)(struct pipe_inode_info___122 *, struct pipe_buffer___122 *);
};

typedef rx_handler_result_t rx_handler_func_t___90(struct sk_buff___91 **);

struct bpf_xdp_entity___84 {
	struct bpf_prog___84 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___90;

struct net_device_ops___90;

struct l3mdev_ops___77;

struct ndisc_ops___59;

struct xfrmdev_ops___90;

struct header_ops___90;

struct inet6_dev___59;

struct netdev_rx_queue___90;

struct mini_Qdisc___84;

struct netdev_queue___90;

struct Qdisc___84;

struct rtnl_link_ops___84;

struct dcbnl_rtnl_ops___90;

struct net_device___90 {
	char name[16];
	struct netdev_name_node___90 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___90 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___77 *l3mdev_ops;
	const struct ndisc_ops___59 *ndisc_ops;
	const struct xfrmdev_ops___90 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___90 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___269 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___59 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___90 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___84 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___90 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___84 *miniq_ingress;
	struct netdev_queue___90 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___90 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___84 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___84 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___90 = 0,
		NETREG_REGISTERED___90 = 1,
		NETREG_UNREGISTERING___90 = 2,
		NETREG_UNREGISTERED___90 = 3,
		NETREG_RELEASED___90 = 4,
		NETREG_DUMMY___90 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___90 = 0,
		RTNL_LINK_INITIALIZING___90 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___90 *);
	struct netpoll_info *npinfo;
	possible_net_t___90 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___262 dev;
	const struct attribute_group___269 *sysfs_groups[4];
	const struct attribute_group___269 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___84 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___90 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___84 xdp_state[3];
	long: 64;
};

struct netlink_callback___90 {
	struct sk_buff___91 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___91 *, struct netlink_callback___90 *);
	int (*done)(struct netlink_callback___90 *);
	void *data;
	struct module___265 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct inet_frags___95;

struct fqdir___95 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___95 *f;
	struct net___95 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___95;

struct inet_frags___95 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___95 *, const void *);
	void (*destructor)(struct inet_frag_queue___95 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___95 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___91 *fragments_tail;
	struct sk_buff___91 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___95 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___50 {
	struct ip_ra_chain___50 *next;
	struct sock___77 *sk;
	union {
		void (*destructor)(struct sock___77 *);
		struct sock___77 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___77;

struct fib_lookup_arg___77;

struct fib_rules_ops___77 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___77 *, struct flowi *, int, struct fib_lookup_arg___77 *);
	bool (*suppress)(struct fib_rule___77 *, int, struct fib_lookup_arg___77 *);
	int (*match)(struct fib_rule___77 *, struct flowi *, int);
	int (*configure)(struct fib_rule___77 *, struct sk_buff___91 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___77 *);
	int (*compare)(struct fib_rule___77 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___77 *, struct sk_buff___91 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___77 *);
	void (*flush_cache)(struct fib_rules_ops___77 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___265 *owner;
	struct net___95 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___24 {
	u32 (*ssthresh)(struct sock___77 *);
	void (*cong_avoid)(struct sock___77 *, u32, u32);
	void (*set_state)(struct sock___77 *, u8);
	void (*cwnd_event)(struct sock___77 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___77 *, u32);
	void (*pkts_acked)(struct sock___77 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___77 *);
	void (*cong_control)(struct sock___77 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___77 *);
	u32 (*sndbuf_expand)(struct sock___77 *);
	size_t (*get_info)(struct sock___77 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___265 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___77 *);
	void (*release)(struct sock___77 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___77 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___95 *);
	int (*fib_dump)(struct net___95 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___265 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___53;

struct dst_entry___77 {
	struct net_device___90 *dev;
	struct dst_ops___95 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___91 *);
	int (*output)(struct net___95 *, struct sock___77 *, struct sk_buff___91 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___53 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___77;

struct neigh_parms___77;

struct neigh_ops___77;

struct neighbour___77 {
	struct neighbour___77 *next;
	struct neigh_table___77 *tbl;
	struct neigh_parms___77 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___90 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___77 *, struct sk_buff___91 *);
	const struct neigh_ops___77 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___90 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___84 {
	struct bpf_prog___84 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___84 {
	struct callback_head rcu;
	struct bpf_prog_array_item___84 items[0];
};

struct bpf_prog_aux___93;

struct bpf_prog___84 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___93 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___256 {
	void * (*start)(struct seq_file___256 *, loff_t *);
	void (*stop)(struct seq_file___256 *, void *);
	void * (*next)(struct seq_file___256 *, void *, loff_t *);
	int (*show)(struct seq_file___256 *, void *);
};

struct dcbnl_rtnl_ops___90 {
	int (*ieee_getets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___90 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___90 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___90 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___90 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___90 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___90 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___90 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___90 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___90 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___90 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___90 *);
	u8 (*setstate)(struct net_device___90 *, u8);
	void (*getpermhwaddr)(struct net_device___90 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___90 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___90 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___90 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___90 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___90 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___90 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___90 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___90 *, int, u8 *);
	void (*setpfccfg)(struct net_device___90 *, int, u8);
	void (*getpfccfg)(struct net_device___90 *, int, u8 *);
	u8 (*setall)(struct net_device___90 *);
	u8 (*getcap)(struct net_device___90 *, int, u8 *);
	int (*getnumtcs)(struct net_device___90 *, int, u8 *);
	int (*setnumtcs)(struct net_device___90 *, int, u8);
	u8 (*getpfcstate)(struct net_device___90 *);
	void (*setpfcstate)(struct net_device___90 *, u8);
	void (*getbcncfg)(struct net_device___90 *, int, u32 *);
	void (*setbcncfg)(struct net_device___90 *, int, u32);
	void (*getbcnrp)(struct net_device___90 *, int, u8 *);
	void (*setbcnrp)(struct net_device___90 *, int, u8);
	int (*setapp)(struct net_device___90 *, u8, u16, u8);
	int (*getapp)(struct net_device___90 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___90 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___90 *, int, u8);
	u8 (*getdcbx)(struct net_device___90 *);
	u8 (*setdcbx)(struct net_device___90 *, u8);
	int (*peer_getappinfo)(struct net_device___90 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___90 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___90 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___90 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___90 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___90 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___93;

typedef int (*bpf_iter_init_seq_priv_t___92)(void *, struct bpf_iter_aux_info___93 *);

struct bpf_map___93;

struct bpf_iter_aux_info___93 {
	struct bpf_map___93 *map;
};

struct bpf_iter_seq_info___92 {
	const struct seq_operations___256 *seq_ops;
	bpf_iter_init_seq_priv_t___92 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___92 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___93 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___93 *, struct file___281 *);
	void (*map_free)(struct bpf_map___93 *);
	int (*map_get_next_key)(struct bpf_map___93 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___93 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___93 *, void *);
	int (*map_lookup_batch)(struct bpf_map___93 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___93 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___93 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___93 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___93 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___93 *, void *);
	int (*map_update_elem)(struct bpf_map___93 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___93 *, void *);
	int (*map_push_elem)(struct bpf_map___93 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___93 *, void *);
	int (*map_peek_elem)(struct bpf_map___93 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___93 *, struct file___281 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___93 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___93 *, void *, struct seq_file___256 *);
	int (*map_check_btf)(const struct bpf_map___93 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___93 *, struct bpf_prog_aux___93 *);
	void (*map_poke_untrack)(struct bpf_map___93 *, struct bpf_prog_aux___93 *);
	void (*map_poke_run)(struct bpf_map___93 *, u32, struct bpf_prog___84 *, struct bpf_prog___84 *);
	int (*map_direct_value_addr)(const struct bpf_map___93 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___93 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___93 *, struct vm_area_struct___286 *);
	__poll_t (*map_poll)(struct bpf_map___93 *, struct file___281 *, struct poll_table_struct___202 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___93 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___93 *, const struct bpf_map___93 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___93 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___92 *iter_seq_info;
};

struct bpf_map___93 {
	const struct bpf_map_ops___92 *ops;
	struct bpf_map___93 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___146 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___92;

struct bpf_jit_poke_descriptor___92;

struct bpf_prog_ops___84;

struct btf_mod_pair___92;

struct bpf_prog_offload___90;

struct bpf_prog_aux___93 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___84 *dst_prog;
	struct bpf_trampoline___92 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___84 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___92 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___84 *ops;
	struct bpf_map___93 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___92 *used_btfs;
	struct bpf_prog___84 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___93 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___90 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___90;

struct bpf_map_dev_ops___90 {
	int (*map_get_next_key)(struct bpf_offloaded_map___90 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___90 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___90 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___90 *, void *);
};

struct bpf_offloaded_map___90 {
	struct bpf_map___93 map;
	struct net_device___90 *netdev;
	const struct bpf_map_dev_ops___90 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___84 {
	int (*test_run)(struct bpf_prog___84 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___90 {
	struct bpf_prog___84 *prog;
	struct net_device___90 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___92 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___84 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___265 *mod;
};

struct bpf_jit_poke_descriptor___92 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___93 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___92 {
	struct btf *btf;
	struct module___265 *module;
};

struct cftype___208;

struct cgroup_subsys___208 {
	struct cgroup_subsys_state___208 * (*css_alloc)(struct cgroup_subsys_state___208 *);
	int (*css_online)(struct cgroup_subsys_state___208 *);
	void (*css_offline)(struct cgroup_subsys_state___208 *);
	void (*css_released)(struct cgroup_subsys_state___208 *);
	void (*css_free)(struct cgroup_subsys_state___208 *);
	void (*css_reset)(struct cgroup_subsys_state___208 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___208 *, int);
	int (*css_extra_stat_show)(struct seq_file___256 *, struct cgroup_subsys_state___208 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___288 *, struct css_set___208 *);
	void (*cancel_fork)(struct task_struct___288 *, struct css_set___208 *);
	void (*fork)(struct task_struct___288 *);
	void (*exit)(struct task_struct___288 *);
	void (*release)(struct task_struct___288 *);
	void (*bind)(struct cgroup_subsys_state___208 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___208 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___208 *dfl_cftypes;
	struct cftype___208 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___208 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___208 *updated_children;
	struct cgroup___208 *updated_next;
};

struct cgroup_root___208 {
	struct kernfs_root___269 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___208 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___208 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___208 *ss;
	struct list_head node;
	struct kernfs_ops___269 *kf_ops;
	int (*open)(struct kernfs_open_file___269 *);
	void (*release)(struct kernfs_open_file___269 *);
	u64 (*read_u64)(struct cgroup_subsys_state___208 *, struct cftype___208 *);
	s64 (*read_s64)(struct cgroup_subsys_state___208 *, struct cftype___208 *);
	int (*seq_show)(struct seq_file___256 *, void *);
	void * (*seq_start)(struct seq_file___256 *, loff_t *);
	void * (*seq_next)(struct seq_file___256 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___256 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___208 *, struct cftype___208 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___208 *, struct cftype___208 *, s64);
	ssize_t (*write)(struct kernfs_open_file___269 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___269 *, struct poll_table_struct___202 *);
};

struct xdp_rxq_info___90 {
	struct net_device___90 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___90 {
	struct net_device___90 *dev;
};

struct xdp_buff___90 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___90 *rxq;
	struct xdp_txq_info___90 *txq;
	u32 frame_sz;
};

struct xdp_frame___90 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___90 *dev_rx;
};

struct header_ops___90 {
	int (*create)(struct sk_buff___91 *, struct net_device___90 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___91 *, unsigned char *);
	int (*cache)(const struct neighbour___77 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___90 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___91 *);
};

struct netdev_queue___90 {
	struct net_device___90 *dev;
	struct Qdisc___84 *qdisc;
	struct Qdisc___84 *qdisc_sleeping;
	struct kobject___269 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___90 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___84 {
	struct sk_buff___91 *head;
	struct sk_buff___91 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___84;

struct Qdisc___84 {
	int (*enqueue)(struct sk_buff___91 *, struct Qdisc___84 *, struct sk_buff___91 **);
	struct sk_buff___91 * (*dequeue)(struct Qdisc___84 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___84 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___90 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___90 gso_skb;
	struct qdisc_skb_head___84 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___84 *next_sched;
	struct sk_buff_head___90 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___90 {
	struct xdp_rxq_info___90 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___269 kobj;
	struct net_device___90 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___90 {
	enum net_device_path_type type;
	const struct net_device___90 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___90 = 0,
				DEV_PATH_BR_VLAN_TAG___90 = 1,
				DEV_PATH_BR_VLAN_UNTAG___90 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___90 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___90 {
	const struct net_device___90 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___90 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___84 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___90 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___90 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___91 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___90 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___90 *dev;
	const char *name;
};

struct net_device_ops___90 {
	int (*ndo_init)(struct net_device___90 *);
	void (*ndo_uninit)(struct net_device___90 *);
	int (*ndo_open)(struct net_device___90 *);
	int (*ndo_stop)(struct net_device___90 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___91 *, struct net_device___90 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___91 *, struct net_device___90 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___90 *, struct sk_buff___91 *, struct net_device___90 *);
	void (*ndo_change_rx_flags)(struct net_device___90 *, int);
	void (*ndo_set_rx_mode)(struct net_device___90 *);
	int (*ndo_set_mac_address)(struct net_device___90 *, void *);
	int (*ndo_validate_addr)(struct net_device___90 *);
	int (*ndo_do_ioctl)(struct net_device___90 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___90 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___90 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___90 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___90 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___90 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___90 *, int);
	int (*ndo_neigh_setup)(struct net_device___90 *, struct neigh_parms___77 *);
	void (*ndo_tx_timeout)(struct net_device___90 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___90 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___90 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___90 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___90 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___90 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___90 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___90 *);
	int (*ndo_netpoll_setup)(struct net_device___90 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___90 *);
	int (*ndo_set_vf_mac)(struct net_device___90 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___90 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___90 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___90 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___90 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___90 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___90 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___90 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___90 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___90 *, int, struct sk_buff___91 *);
	int (*ndo_get_vf_guid)(struct net_device___90 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___90 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___90 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___90 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___90 *);
	int (*ndo_fcoe_disable)(struct net_device___90 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___90 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___90 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___90 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___90 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___90 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___90 *, const struct sk_buff___91 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___90 *, struct net_device___90 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___90 *, struct net_device___90 *);
	struct net_device___90 * (*ndo_get_xmit_slave)(struct net_device___90 *, struct sk_buff___91 *, bool);
	struct net_device___90 * (*ndo_sk_get_lower_dev)(struct net_device___90 *, struct sock___77 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___90 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___90 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___90 *, struct neighbour___77 *);
	void (*ndo_neigh_destroy)(struct net_device___90 *, struct neighbour___77 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___91 *, struct netlink_callback___90 *, struct net_device___90 *, struct net_device___90 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___91 *, struct nlattr **, struct net_device___90 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___90 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___91 *, u32, u32, struct net_device___90 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___90 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___90 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___90 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___90 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___90 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___90 *, struct net_device___90 *);
	void (*ndo_dfwd_del_station)(struct net_device___90 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___90 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___90 *);
	int (*ndo_change_proto_down)(struct net_device___90 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___90 *, struct sk_buff___91 *);
	void (*ndo_set_rx_headroom)(struct net_device___90 *, int);
	int (*ndo_bpf)(struct net_device___90 *, struct netdev_bpf___90 *);
	int (*ndo_xdp_xmit)(struct net_device___90 *, int, struct xdp_frame___90 **, u32);
	struct net_device___90 * (*ndo_xdp_get_xmit_slave)(struct net_device___90 *, struct xdp_buff___90 *);
	int (*ndo_xsk_wakeup)(struct net_device___90 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___90 *);
	int (*ndo_tunnel_ctl)(struct net_device___90 *, struct ip_tunnel_parm *, int);
	struct net_device___90 * (*ndo_get_peer_dev)(struct net_device___90 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___90 *, struct net_device_path___90 *);
};

struct neigh_parms___77 {
	possible_net_t___90 net;
	struct net_device___90 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___77 *);
	struct neigh_table___77 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___77 {
	u32 (*l3mdev_fib_table)(const struct net_device___90 *);
	struct sk_buff___91 * (*l3mdev_l3_rcv)(struct net_device___90 *, struct sk_buff___91 *, u16);
	struct sk_buff___91 * (*l3mdev_l3_out)(struct net_device___90 *, struct sock___77 *, struct sk_buff___91 *, u16);
	struct dst_entry___77 * (*l3mdev_link_scope_lookup)(const struct net_device___90 *, struct flowi6 *);
};

struct ndisc_ops___59 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___90 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___90 *, struct neighbour___77 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___90 *, u8, struct neighbour___77 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___90 *, struct sk_buff___91 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___95 *, struct net_device___90 *, const struct prefix_info *, struct inet6_dev___59 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___59;

struct inet6_dev___59 {
	struct net_device___90 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___59 *mc_list;
	struct ifmcaddr6___59 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___90 mc_query_queue;
	struct sk_buff_head___90 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___24 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___77 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___84;

struct tcf_block___84;

struct mini_Qdisc___84 {
	struct tcf_proto___84 *filter_list;
	struct tcf_block___84 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___84 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___90 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___90 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___95 *, struct net_device___90 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___90 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___90 *, struct list_head *);
	size_t (*get_size)(const struct net_device___90 *);
	int (*fill_info)(struct sk_buff___91 *, const struct net_device___90 *);
	size_t (*get_xstats_size)(const struct net_device___90 *);
	int (*fill_xstats)(struct sk_buff___91 *, const struct net_device___90 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___90 *, struct net_device___90 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___90 *, const struct net_device___90 *);
	int (*fill_slave_info)(struct sk_buff___91 *, const struct net_device___90 *, const struct net_device___90 *);
	struct net___95 * (*get_link_net)(const struct net_device___90 *);
	size_t (*get_linkxstats_size)(const struct net_device___90 *, int);
	int (*fill_linkxstats)(struct sk_buff___91 *, const struct net_device___90 *, int *, int);
};

struct block_device_operations___172;

struct gendisk___175 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___175 *part0;
	const struct block_device_operations___172 *fops;
	struct request_queue___172 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___158 *bdi;
	struct kobject___269 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___269 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___172 {
	struct bio___172 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___198 *bip_vec;
	struct bio_vec___198 bip_inline_vecs[0];
};

struct blkcg___160;

struct blkg_policy_data___160;

struct blkcg_gq___160 {
	struct request_queue___172 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___160 *blkcg;
	struct blkcg_gq___160 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___160 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___172 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___172(struct request___172 *);

typedef void integrity_complete_fn___172(struct request___172 *, unsigned int);

struct blk_integrity_profile___172 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___172 *prepare_fn;
	integrity_complete_fn___172 *complete_fn;
	const char *name;
};

struct block_device_operations___172 {
	blk_qc_t (*submit_bio)(struct bio___172 *);
	int (*open)(struct block_device___175 *, fmode_t);
	void (*release)(struct gendisk___175 *, fmode_t);
	int (*rw_page)(struct block_device___175 *, sector_t, struct page___286 *, unsigned int);
	int (*ioctl)(struct block_device___175 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___175 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___175 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___175 *);
	int (*getgeo)(struct block_device___175 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___175 *, bool);
	void (*swap_slot_free_notify)(struct block_device___175 *, long unsigned int);
	int (*report_zones)(struct gendisk___175 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___175 *, umode_t *);
	struct module___265 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___175 *, sector_t *);
};

typedef void rq_end_io_fn___172(struct request___172 *, blk_status_t);

struct request___172 {
	struct request_queue___172 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___167 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___172 *bio;
	struct bio___172 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___198 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___172 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___172 *saved_end_io;
		} flush;
	};
	struct gendisk___175 *rq_disk;
	struct block_device___175 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___172 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___167 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___172 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___269 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___281 *debugfs_dir;
	struct dentry___281 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___172;

struct elevator_mq_ops___172 {
	int (*init_sched)(struct request_queue___172 *, struct elevator_type___172 *);
	void (*exit_sched)(struct elevator_queue___172 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___167 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___167 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___167 *);
	bool (*allow_merge)(struct request_queue___172 *, struct request___172 *, struct bio___172 *);
	bool (*bio_merge)(struct request_queue___172 *, struct bio___172 *, unsigned int);
	int (*request_merge)(struct request_queue___172 *, struct request___172 **, struct bio___172 *);
	void (*request_merged)(struct request_queue___172 *, struct request___172 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___172 *, struct request___172 *, struct request___172 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___172 *);
	void (*finish_request)(struct request___172 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___167 *, struct list_head *, bool);
	struct request___172 * (*dispatch_request)(struct blk_mq_hw_ctx___167 *);
	bool (*has_work)(struct blk_mq_hw_ctx___167 *);
	void (*completed_request)(struct request___172 *, u64);
	void (*requeue_request)(struct request___172 *);
	struct request___172 * (*former_request)(struct request_queue___172 *, struct request___172 *);
	struct request___172 * (*next_request)(struct request_queue___172 *, struct request___172 *);
	void (*init_icq)(struct io_cq___172 *);
	void (*exit_icq)(struct io_cq___172 *);
};

struct elv_fs_entry___172;

struct elevator_type___172 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___172 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___172 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___265 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___172 {
	struct elevator_type___172 *type;
	void *elevator_data;
	struct kobject___269 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___172 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___172 *, char *);
	ssize_t (*store)(struct elevator_queue___172 *, const char *, size_t);
};

struct blk_mq_queue_data___167;

struct blk_mq_ops___167 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___167 *, const struct blk_mq_queue_data___167 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___167 *);
	int (*get_budget)(struct request_queue___172 *);
	void (*put_budget)(struct request_queue___172 *, int);
	void (*set_rq_budget_token)(struct request___172 *, int);
	int (*get_rq_budget_token)(struct request___172 *);
	enum blk_eh_timer_return (*timeout)(struct request___172 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___167 *);
	void (*complete)(struct request___172 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___167 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___167 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___167 *, struct request___172 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___167 *, struct request___172 *, unsigned int);
	void (*initialize_rq_fn)(struct request___172 *);
	void (*cleanup_rq)(struct request___172 *);
	bool (*busy)(struct request_queue___172 *);
	int (*map_queues)(struct blk_mq_tag_set___167 *);
	void (*show_rq)(struct seq_file___256 *, struct request___172 *);
};

struct blk_mq_tag_set___167 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___167 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___167 {
	struct request___172 *rq;
	bool last;
};

struct blkcg_policy_data___160;

struct blkcg___160 {
	struct cgroup_subsys_state___208 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___160 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___160 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___160 {
	struct blkcg___160 *blkcg;
	int plid;
};

struct blkg_policy_data___160 {
	struct blkcg_gq___160 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___146 {
	struct mem_cgroup___146 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___146 {
	struct lruvec___154 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___146 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___146 *memcg;
};

struct obj_cgroup___146 {
	struct percpu_ref refcnt;
	struct mem_cgroup___146 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___84 {
	spinlock_t *lock;
	struct sk_buff___91 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___84;

struct Qdisc_ops___84 {
	struct Qdisc_ops___84 *next;
	const struct Qdisc_class_ops___84 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___91 *, struct Qdisc___84 *, struct sk_buff___91 **);
	struct sk_buff___91 * (*dequeue)(struct Qdisc___84 *);
	struct sk_buff___91 * (*peek)(struct Qdisc___84 *);
	int (*init)(struct Qdisc___84 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___84 *);
	void (*destroy)(struct Qdisc___84 *);
	int (*change)(struct Qdisc___84 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___84 *);
	int (*change_tx_queue_len)(struct Qdisc___84 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___84 *, unsigned int);
	int (*dump)(struct Qdisc___84 *, struct sk_buff___91 *);
	int (*dump_stats)(struct Qdisc___84 *, struct gnet_dump___84 *);
	void (*ingress_block_set)(struct Qdisc___84 *, u32);
	void (*egress_block_set)(struct Qdisc___84 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___84 *);
	u32 (*egress_block_get)(struct Qdisc___84 *);
	struct module___265 *owner;
};

struct Qdisc_class_ops___84 {
	unsigned int flags;
	struct netdev_queue___90 * (*select_queue)(struct Qdisc___84 *, struct tcmsg *);
	int (*graft)(struct Qdisc___84 *, long unsigned int, struct Qdisc___84 *, struct Qdisc___84 **, struct netlink_ext_ack *);
	struct Qdisc___84 * (*leaf)(struct Qdisc___84 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___84 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___84 *, u32);
	int (*change)(struct Qdisc___84 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___84 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___84 *, struct qdisc_walker *);
	struct tcf_block___84 * (*tcf_block)(struct Qdisc___84 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___84 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___84 *, long unsigned int);
	int (*dump)(struct Qdisc___84 *, long unsigned int, struct sk_buff___91 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___84 *, long unsigned int, struct gnet_dump___84 *);
};

struct tcf_chain___84;

struct tcf_block___84 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___95 *net;
	struct Qdisc___84 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___84 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___84;

struct tcf_proto_ops___84;

struct tcf_proto___84 {
	struct tcf_proto___84 *next;
	void *root;
	int (*classify)(struct sk_buff___91 *, const struct tcf_proto___84 *, struct tcf_result___84 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___84 *ops;
	struct tcf_chain___84 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___84 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___84 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___84 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___91 *, const struct tcf_proto___84 *, struct tcf_result___84 *);
	int (*init)(struct tcf_proto___84 *);
	void (*destroy)(struct tcf_proto___84 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___84 *, u32);
	void (*put)(struct tcf_proto___84 *, void *);
	int (*change)(struct net___95 *, struct sk_buff___91 *, struct tcf_proto___84 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___84 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___84 *);
	void (*walk)(struct tcf_proto___84 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___84 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___84 *, void *);
	void (*hw_del)(struct tcf_proto___84 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___95 *, struct tcf_chain___84 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___95 *, struct tcf_proto___84 *, void *, struct sk_buff___91 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___95 *, struct tcf_proto___84 *, void *, struct sk_buff___91 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___91 *, struct net___95 *, void *);
	struct module___265 *owner;
	int flags;
};

struct tcf_chain___84 {
	struct mutex filter_chain_lock;
	struct tcf_proto___84 *filter_chain;
	struct list_head list;
	struct tcf_block___84 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___84 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___77 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___84 *prog;
};

struct pneigh_entry___77;

struct neigh_hash_table___77;

struct neigh_table___77 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___90 *, __u32 *);
	bool (*key_eq)(const struct neighbour___77 *, const void *);
	int (*constructor)(struct neighbour___77 *);
	int (*pconstructor)(struct pneigh_entry___77 *);
	void (*pdestructor)(struct pneigh_entry___77 *);
	void (*proxy_redo)(struct sk_buff___91 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___90 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___77 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___90 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___77 *nht;
	struct pneigh_entry___77 **phash_buckets;
};

struct neigh_ops___77 {
	int family;
	void (*solicit)(struct neighbour___77 *, struct sk_buff___91 *);
	void (*error_report)(struct neighbour___77 *, struct sk_buff___91 *);
	int (*output)(struct neighbour___77 *, struct sk_buff___91 *);
	int (*connected_output)(struct neighbour___77 *, struct sk_buff___91 *);
};

struct pneigh_entry___77 {
	struct pneigh_entry___77 *next;
	possible_net_t___90 net;
	struct net_device___90 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___77 {
	struct neighbour___77 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___53 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___95 *, struct sock___77 *, struct sk_buff___91 *);
	int (*orig_input)(struct sk_buff___91 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___77 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___77 *ctarget;
	struct net___95 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___77 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___77 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___62;

struct timewait_sock_ops___61;

struct proto___77 {
	void (*close)(struct sock___77 *, long int);
	int (*pre_connect)(struct sock___77 *, struct sockaddr *, int);
	int (*connect)(struct sock___77 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___77 *, int);
	struct sock___77 * (*accept)(struct sock___77 *, int, int *, bool);
	int (*ioctl)(struct sock___77 *, int, long unsigned int);
	int (*init)(struct sock___77 *);
	void (*destroy)(struct sock___77 *);
	void (*shutdown)(struct sock___77 *, int);
	int (*setsockopt)(struct sock___77 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___77 *, int, int, char *, int *);
	void (*keepalive)(struct sock___77 *, int);
	int (*compat_ioctl)(struct sock___77 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___77 *, struct msghdr___79 *, size_t);
	int (*recvmsg)(struct sock___77 *, struct msghdr___79 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___77 *, struct page___286 *, int, size_t, int);
	int (*bind)(struct sock___77 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___77 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___77 *, struct sk_buff___91 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___77 *);
	int (*hash)(struct sock___77 *);
	void (*unhash)(struct sock___77 *);
	void (*rehash)(struct sock___77 *);
	int (*get_port)(struct sock___77 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___77 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___77 *, int);
	bool (*sock_is_readable)(struct sock___77 *);
	void (*enter_memory_pressure)(struct sock___77 *);
	void (*leave_memory_pressure)(struct sock___77 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___62 *rsk_prot;
	struct timewait_sock_ops___61 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___265 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___77 *, int);
};

struct sock_reuseport___26 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___84 *prog;
	struct sock___77 *socks[0];
};

struct request_sock___63;

struct request_sock_ops___62 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___77 *, struct request_sock___63 *);
	void (*send_ack)(const struct sock___77 *, struct sk_buff___91 *, struct request_sock___63 *);
	void (*send_reset)(const struct sock___77 *, struct sk_buff___91 *);
	void (*destructor)(struct request_sock___63 *);
	void (*syn_ack_timeout)(const struct request_sock___63 *);
};

struct timewait_sock_ops___61 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___77 *, struct sock___77 *, void *);
	void (*twsk_destructor)(struct sock___77 *);
};

struct request_sock___63 {
	struct sock_common___77 __req_common;
	struct request_sock___63 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___62 *rsk_ops;
	struct sock___77 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___59 {
	struct in6_addr mca_addr;
	struct inet6_dev___59 *idev;
	struct ifmcaddr6___59 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct nhmsg {
	unsigned char nh_family;
	unsigned char nh_scope;
	unsigned char nh_protocol;
	unsigned char resvd;
	unsigned int nh_flags;
};

struct nexthop_grp {
	__u32 id;
	__u8 weight;
	__u8 resvd1;
	__u16 resvd2;
};

enum {
	NEXTHOP_GRP_TYPE_MPATH = 0,
	NEXTHOP_GRP_TYPE_RES = 1,
	__NEXTHOP_GRP_TYPE_MAX = 2,
};

enum {
	NHA_UNSPEC = 0,
	NHA_ID = 1,
	NHA_GROUP = 2,
	NHA_GROUP_TYPE = 3,
	NHA_BLACKHOLE = 4,
	NHA_OIF = 5,
	NHA_GATEWAY = 6,
	NHA_ENCAP_TYPE = 7,
	NHA_ENCAP = 8,
	NHA_GROUPS = 9,
	NHA_MASTER = 10,
	NHA_FDB = 11,
	NHA_RES_GROUP = 12,
	NHA_RES_BUCKET = 13,
	__NHA_MAX = 14,
};

enum {
	NHA_RES_GROUP_UNSPEC = 0,
	NHA_RES_GROUP_PAD = 0,
	NHA_RES_GROUP_BUCKETS = 1,
	NHA_RES_GROUP_IDLE_TIMER = 2,
	NHA_RES_GROUP_UNBALANCED_TIMER = 3,
	NHA_RES_GROUP_UNBALANCED_TIME = 4,
	__NHA_RES_GROUP_MAX = 5,
};

enum {
	NHA_RES_BUCKET_UNSPEC = 0,
	NHA_RES_BUCKET_PAD = 0,
	NHA_RES_BUCKET_INDEX = 1,
	NHA_RES_BUCKET_IDLE_TIME = 2,
	NHA_RES_BUCKET_NH_ID = 3,
	__NHA_RES_BUCKET_MAX = 4,
};

struct nh_config {
	u32 nh_id;
	u8 nh_family;
	u8 nh_protocol;
	u8 nh_blackhole;
	u8 nh_fdb;
	u32 nh_flags;
	int nh_ifindex;
	struct net_device___85 *dev;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} gw;
	struct nlattr *nh_grp;
	u16 nh_grp_type;
	u16 nh_grp_res_num_buckets;
	long unsigned int nh_grp_res_idle_timer;
	long unsigned int nh_grp_res_unbalanced_timer;
	bool nh_grp_res_has_num_buckets;
	bool nh_grp_res_has_idle_timer;
	bool nh_grp_res_has_unbalanced_timer;
	struct nlattr *nh_encap;
	u16 nh_encap_type;
	u32 nlflags;
	struct nl_info___3 nlinfo;
};

enum nexthop_event_type {
	NEXTHOP_EVENT_DEL = 0,
	NEXTHOP_EVENT_REPLACE = 1,
	NEXTHOP_EVENT_RES_TABLE_PRE_REPLACE = 2,
	NEXTHOP_EVENT_BUCKET_REPLACE = 3,
};

enum nh_notifier_info_type {
	NH_NOTIFIER_INFO_TYPE_SINGLE = 0,
	NH_NOTIFIER_INFO_TYPE_GRP = 1,
	NH_NOTIFIER_INFO_TYPE_RES_TABLE = 2,
	NH_NOTIFIER_INFO_TYPE_RES_BUCKET = 3,
};

struct nh_notifier_single_info {
	struct net_device___85 *dev;
	u8 gw_family;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	};
	u8 is_reject: 1;
	u8 is_fdb: 1;
	u8 has_encap: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
};

struct nh_notifier_grp_entry_info {
	u8 weight;
	u32 id;
	struct nh_notifier_single_info nh;
};

struct nh_notifier_grp_info {
	u16 num_nh;
	bool is_fdb;
	struct nh_notifier_grp_entry_info nh_entries[0];
};

struct nh_notifier_res_bucket_info {
	u16 bucket_index;
	unsigned int idle_timer_ms;
	bool force;
	struct nh_notifier_single_info old_nh;
	struct nh_notifier_single_info new_nh;
};

struct nh_notifier_res_table_info {
	u16 num_nh_buckets;
	struct nh_notifier_single_info nhs[0];
};

struct nh_notifier_info {
	struct net___90 *net;
	struct netlink_ext_ack *extack;
	u32 id;
	enum nh_notifier_info_type type;
	union {
		struct nh_notifier_single_info *nh;
		struct nh_notifier_grp_info *nh_grp;
		struct nh_notifier_res_table_info *nh_res_table;
		struct nh_notifier_res_bucket_info *nh_res_bucket;
	};
};

struct nh_dump_filter {
	u32 nh_id;
	int dev_idx;
	int master_idx;
	bool group_filter;
	bool fdb_filter;
	u32 res_bucket_nh_id;
};

struct rtm_dump_nh_ctx {
	u32 idx;
};

struct rtm_dump_res_bucket_ctx {
	struct rtm_dump_nh_ctx nh;
	u16 bucket_index;
	u32 done_nh_idx;
};

struct rtm_dump_nexthop_bucket_data {
	struct rtm_dump_res_bucket_ctx *ctx;
	struct nh_dump_filter filter;
};

struct umd_info___3 {
	const char *driver_name;
	struct file___108 *pipe_to_umh;
	struct file___108 *pipe_from_umh;
	struct path___108 wd;
	struct pid___96 *tgid;
};

struct bpfilter_umh_ops {
	struct umd_info___3 info;
	struct mutex lock;
	int (*sockopt)(struct sock *, int, sockptr_t, unsigned int, bool);
	int (*start)();
};

struct dentry___282;

struct super_block___282;

struct module___266;

struct file_system_type___282 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___282 * (*mount)(struct file_system_type___282 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___282 *);
	struct module___266 *owner;
	struct file_system_type___282 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___282;

struct kiocb___282;

struct iov_iter___202;

struct poll_table_struct___203;

struct vm_area_struct___287;

struct inode___282;

struct file_lock___282;

struct page___287;

struct pipe_inode_info___123;

struct seq_file___257;

struct file_operations___283 {
	struct module___266 *owner;
	loff_t (*llseek)(struct file___282 *, loff_t, int);
	ssize_t (*read)(struct file___282 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___282 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___282 *, struct iov_iter___202 *);
	ssize_t (*write_iter)(struct kiocb___282 *, struct iov_iter___202 *);
	int (*iopoll)(struct kiocb___282 *, bool);
	int (*iterate)(struct file___282 *, struct dir_context *);
	int (*iterate_shared)(struct file___282 *, struct dir_context *);
	__poll_t (*poll)(struct file___282 *, struct poll_table_struct___203 *);
	long int (*unlocked_ioctl)(struct file___282 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___282 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___282 *, struct vm_area_struct___287 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___282 *, struct file___282 *);
	int (*flush)(struct file___282 *, fl_owner_t);
	int (*release)(struct inode___282 *, struct file___282 *);
	int (*fsync)(struct file___282 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___282 *, int);
	int (*lock)(struct file___282 *, int, struct file_lock___282 *);
	ssize_t (*sendpage)(struct file___282 *, struct page___287 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___282 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___282 *, long unsigned int);
	int (*flock)(struct file___282 *, int, struct file_lock___282 *);
	ssize_t (*splice_write)(struct pipe_inode_info___123 *, struct file___282 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___282 *, loff_t *, struct pipe_inode_info___123 *, size_t, unsigned int);
	int (*setlease)(struct file___282 *, long int, struct file_lock___282 **, void **);
	long int (*fallocate)(struct file___282 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___257 *, struct file___282 *);
	ssize_t (*copy_file_range)(struct file___282 *, loff_t, struct file___282 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___282 *, loff_t, struct file___282 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___282 *, loff_t, loff_t, int);
};

struct vmacache___287 {
	u64 seqnum;
	struct vm_area_struct___287 *vmas[4];
};

struct page_frag___287 {
	struct page___287 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___288;

struct pid___259;

struct nsproxy___268;

struct signal_struct___283;

struct bio_list___173;

struct backing_dev_info___159;

struct io_context___173;

struct css_set___209;

struct mem_cgroup___147;

struct request_queue___173;

struct vm_struct___265;

struct task_struct___289 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___289 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___288 *mm;
	struct mm_struct___288 *active_mm;
	struct vmacache___287 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___289 *real_parent;
	struct task_struct___289 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___289 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___259 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___268 *nsproxy;
	struct signal_struct___283 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___289 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___173 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___159 *backing_dev_info;
	struct io_context___173 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___209 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___123 *splice_pipe;
	struct page_frag___287 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___147 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___147 *active_memcg;
	struct request_queue___173 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___289 *oom_reaper_list;
	struct vm_struct___265 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___270;

struct kobj_type___270;

struct kernfs_node___270;

struct kobject___270 {
	const char *name;
	struct list_head entry;
	struct kobject___270 *parent;
	struct kset___270 *kset;
	struct kobj_type___270 *ktype;
	struct kernfs_node___270 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___267 {
	struct kobject___270 kobj;
	struct module___266 *mod;
	struct kobject___270 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___266 {
	struct module___266 *mod;
	struct latch_tree_node node;
};

struct module_layout___266 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___266 mtn;
};

struct module_attribute___266;

struct kernel_param___266;

struct module___266 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___267 mkobj;
	struct module_attribute___266 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___270 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___266 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___266 core_layout;
	struct module_layout___266 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___287 *pgtable_t___287;

struct address_space___282;

struct page_pool___111;

struct dev_pagemap___277;

struct page___287 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___282 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___111 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___287 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___287 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___288 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___277 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___277;

struct vm_area_struct___287 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___287 *vm_next;
	struct vm_area_struct___287 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___288 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___277 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___282 *vm_file;
	struct file___282 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___287;

struct mm_struct___288 {
	struct {
		struct vm_area_struct___287 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___282 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___287 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___289 *owner;
		struct user_namespace___26 *user_ns;
		struct file___282 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___282;

struct address_space___282 {
	struct inode___282 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___282 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___263;

struct page_pool_params___111 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___263 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___111 {
	u32 count;
	struct page___287 *cache[128];
};

struct page_pool___111 {
	struct page_pool_params___111 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___287 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___111 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___277;

struct dev_pagemap___277 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___277 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___282;

struct path___282 {
	struct vfsmount___282 *mnt;
	struct dentry___282 *dentry;
};

struct fown_struct___259 {
	rwlock_t lock;
	struct pid___259 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___282 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___282 f_path;
	struct inode___282 *f_inode;
	const struct file_operations___283 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___259 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___282 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___277;

struct vm_operations_struct___277 {
	void (*open)(struct vm_area_struct___287 *);
	void (*close)(struct vm_area_struct___287 *);
	int (*may_split)(struct vm_area_struct___287 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___287 *);
	int (*mprotect)(struct vm_area_struct___287 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___277 *);
	vm_fault_t (*huge_fault)(struct vm_fault___277 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___277 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___287 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___277 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___277 *);
	int (*access)(struct vm_area_struct___287 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___287 *);
	int (*set_policy)(struct vm_area_struct___287 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___287 *, long unsigned int);
	struct page___287 * (*find_special_page)(struct vm_area_struct___287 *, long unsigned int);
};

struct core_thread___287 {
	struct task_struct___289 *task;
	struct core_thread___287 *next;
};

struct core_state___287 {
	atomic_t nr_threads;
	struct core_thread___287 dumper;
	struct completion startup;
};

struct vm_fault___277 {
	const struct {
		struct vm_area_struct___287 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___287 *cow_page;
	struct page___287 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___287 prealloc_pte;
};

struct pglist_data___155;

struct lruvec___155 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___155 *pgdat;
};

struct zone___155 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___155 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___155 {
	struct zone___155 *zone;
	int zone_idx;
};

struct zonelist___155 {
	struct zoneref___155 _zonerefs[321];
};

struct pglist_data___155 {
	struct zone___155 node_zones[5];
	struct zonelist___155 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___289 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___289 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___155 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___147 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___147 *memcg;
};

struct cgroup___209;

struct cgroup_subsys___209;

struct cgroup_subsys_state___209 {
	struct cgroup___209 *cgroup;
	struct cgroup_subsys___209 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___209 *parent;
};

struct cgroup_file___209 {
	struct kernfs_node___270 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___147;

struct mem_cgroup_per_node___147;

struct mem_cgroup___147 {
	struct cgroup_subsys_state___209 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___209 events_file;
	struct cgroup_file___209 events_local_file;
	struct cgroup_file___209 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___147 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___289 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___147 *nodeinfo[0];
	long: 64;
};

struct shrinker___147 {
	long unsigned int (*count_objects)(struct shrinker___147 *, struct shrink_control___147 *);
	long unsigned int (*scan_objects)(struct shrinker___147 *, struct shrink_control___147 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___277 {
	void (*page_free)(struct page___287 *);
	void (*kill)(struct dev_pagemap___277 *);
	void (*cleanup)(struct dev_pagemap___277 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___277 *);
};

struct pid_namespace___259;

struct upid___259 {
	int nr;
	struct pid_namespace___259 *ns;
};

struct pid_namespace___259 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___289 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___259 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___259 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___259 numbers[1];
};

struct signal_struct___283 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___289 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___289 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___259 *pids[4];
	struct pid___259 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___288 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___96;

struct cgroup_namespace___209;

struct nsproxy___268 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___259 *pid_ns_for_children;
	struct net___96 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___209 *cgroup_ns;
};

struct bio___173;

struct bio_list___173 {
	struct bio___173 *head;
	struct bio___173 *tail;
};

struct bdi_writeback___159 {
	struct backing_dev_info___159 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___209 *memcg_css;
	struct cgroup_subsys_state___209 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___159 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___159 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___263 *dev;
	char dev_name[64];
	struct device___263 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___282 *debug_dir;
};

struct io_cq___173;

struct io_context___173 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___173 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___209 {
	struct cgroup_subsys_state___209 *subsys[14];
	refcount_t refcount;
	struct css_set___209 *dom_cset;
	struct cgroup___209 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___209 *mg_src_cgrp;
	struct cgroup___209 *mg_dst_cgrp;
	struct css_set___209 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___282;

struct pipe_buffer___123;

struct pipe_inode_info___123 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___287 *tmp_page;
	struct fasync_struct___282 *fasync_readers;
	struct fasync_struct___282 *fasync_writers;
	struct pipe_buffer___123 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct blk_integrity_profile___173;

struct blk_integrity___173 {
	const struct blk_integrity_profile___173 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___173 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___173 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___173;

struct elevator_queue___173;

struct blk_mq_ops___168;

struct blk_mq_hw_ctx___168;

struct gendisk___176;

struct blkcg_gq___161;

struct blk_mq_tag_set___168;

struct request_queue___173 {
	struct request___173 *last_merge;
	struct elevator_queue___173 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___168 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___168 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___176 *disk;
	struct kobject___270 kobj;
	struct kobject___270 *mq_kobj;
	struct blk_integrity___173 integrity;
	struct device___263 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___161 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___168 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___173 bio_split;
	struct dentry___282 *debugfs_dir;
	struct dentry___282 *sched_debugfs_dir;
	struct dentry___282 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___265 {
	struct vm_struct___265 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___287 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___282;

struct dentry___282 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___282 *d_parent;
	struct qstr d_name;
	struct inode___282 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___282 *d_op;
	struct super_block___282 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___282;

struct inode___282 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___282 *i_op;
	struct super_block___282 *i_sb;
	struct address_space___282 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___159 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___283 *i_fop;
		void (*free_inode)(struct inode___282 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___282 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___123 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___282 {
	int (*d_revalidate)(struct dentry___282 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___282 *, unsigned int);
	int (*d_hash)(const struct dentry___282 *, struct qstr *);
	int (*d_compare)(const struct dentry___282 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___282 *);
	int (*d_init)(struct dentry___282 *);
	void (*d_release)(struct dentry___282 *);
	void (*d_prune)(struct dentry___282 *);
	void (*d_iput)(struct dentry___282 *, struct inode___282 *);
	char * (*d_dname)(struct dentry___282 *, char *, int);
	struct vfsmount___282 * (*d_automount)(struct path___282 *);
	int (*d_manage)(const struct path___282 *, bool);
	struct dentry___282 * (*d_real)(struct dentry___282 *, const struct inode___282 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___282;

struct mem_dqinfo___282 {
	struct quota_format_type___282 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___282;

struct quota_info___282 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___282 *files[3];
	struct mem_dqinfo___282 info[3];
	const struct quota_format_ops___282 *ops[3];
};

struct rcuwait___283 {
	struct task_struct___289 *task;
};

struct percpu_rw_semaphore___283 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___283 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___282 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___283 rw_sem[3];
};

struct super_operations___282;

struct dquot_operations___282;

struct quotactl_ops___282;

struct block_device___176;

struct super_block___282 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___282 *s_type;
	const struct super_operations___282 *s_op;
	const struct dquot_operations___282 *dq_op;
	const struct quotactl_ops___282 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___282 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___176 *s_bdev;
	struct backing_dev_info___159 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___282 s_dquot;
	struct sb_writers___282 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___282 *s_d_op;
	int cleancache_poolid;
	struct shrinker___147 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___282 {
	struct dentry___282 *mnt_root;
	struct super_block___282 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___209 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___289 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___85;

struct cgroup_bpf___85 {
	struct bpf_prog_array___85 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___85 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___209;

struct cgroup_rstat_cpu___209;

struct cgroup___209 {
	struct cgroup_subsys_state___209 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___270 *kn;
	struct cgroup_file___209 procs_file;
	struct cgroup_file___209 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___209 *subsys[14];
	struct cgroup_root___209 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___209 *dom_cgrp;
	struct cgroup___209 *old_dom_cgrp;
	struct cgroup_rstat_cpu___209 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___209 psi;
	struct cgroup_bpf___85 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___173 {
	struct request_queue___173 *q;
	struct io_context___173 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct wait_page_queue___117;

struct kiocb___282 {
	struct file___282 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___282 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___282 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___282 *ia_file;
};

struct dquot___282 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___282 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___282 {
	int qf_fmt_id;
	const struct quota_format_ops___282 *qf_ops;
	struct module___266 *qf_owner;
	struct quota_format_type___282 *qf_next;
};

struct quota_format_ops___282 {
	int (*check_quota_file)(struct super_block___282 *, int);
	int (*read_file_info)(struct super_block___282 *, int);
	int (*write_file_info)(struct super_block___282 *, int);
	int (*free_file_info)(struct super_block___282 *, int);
	int (*read_dqblk)(struct dquot___282 *);
	int (*commit_dqblk)(struct dquot___282 *);
	int (*release_dqblk)(struct dquot___282 *);
	int (*get_next_id)(struct super_block___282 *, struct kqid *);
};

struct dquot_operations___282 {
	int (*write_dquot)(struct dquot___282 *);
	struct dquot___282 * (*alloc_dquot)(struct super_block___282 *, int);
	void (*destroy_dquot)(struct dquot___282 *);
	int (*acquire_dquot)(struct dquot___282 *);
	int (*release_dquot)(struct dquot___282 *);
	int (*mark_dirty)(struct dquot___282 *);
	int (*write_info)(struct super_block___282 *, int);
	qsize_t * (*get_reserved_space)(struct inode___282 *);
	int (*get_projid)(struct inode___282 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___282 *, qsize_t *);
	int (*get_next_id)(struct super_block___282 *, struct kqid *);
};

struct quotactl_ops___282 {
	int (*quota_on)(struct super_block___282 *, int, int, const struct path___282 *);
	int (*quota_off)(struct super_block___282 *, int);
	int (*quota_enable)(struct super_block___282 *, unsigned int);
	int (*quota_disable)(struct super_block___282 *, unsigned int);
	int (*quota_sync)(struct super_block___282 *, int);
	int (*set_info)(struct super_block___282 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___282 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___282 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___282 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___282 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___282 *, unsigned int);
};

struct wait_page_queue___117 {
	struct page___287 *page;
	int bit_nr;
	wait_queue_entry_t wait;
};

struct writeback_control___159;

struct readahead_control___117;

struct swap_info_struct___70;

struct address_space_operations___282 {
	int (*writepage)(struct page___287 *, struct writeback_control___159 *);
	int (*readpage)(struct file___282 *, struct page___287 *);
	int (*writepages)(struct address_space___282 *, struct writeback_control___159 *);
	int (*set_page_dirty)(struct page___287 *);
	int (*readpages)(struct file___282 *, struct address_space___282 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___117 *);
	int (*write_begin)(struct file___282 *, struct address_space___282 *, loff_t, unsigned int, unsigned int, struct page___287 **, void **);
	int (*write_end)(struct file___282 *, struct address_space___282 *, loff_t, unsigned int, unsigned int, struct page___287 *, void *);
	sector_t (*bmap)(struct address_space___282 *, sector_t);
	void (*invalidatepage)(struct page___287 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___287 *, gfp_t);
	void (*freepage)(struct page___287 *);
	ssize_t (*direct_IO)(struct kiocb___282 *, struct iov_iter___202 *);
	int (*migratepage)(struct address_space___282 *, struct page___287 *, struct page___287 *, enum migrate_mode);
	bool (*isolate_page)(struct page___287 *, isolate_mode_t);
	void (*putback_page)(struct page___287 *);
	int (*launder_page)(struct page___287 *);
	int (*is_partially_uptodate)(struct page___287 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___287 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___282 *, struct page___287 *);
	int (*swap_activate)(struct swap_info_struct___70 *, struct file___282 *, sector_t *);
	void (*swap_deactivate)(struct file___282 *);
};

struct writeback_control___159 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___159 *wb;
	struct inode___282 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct readahead_control___117 {
	struct file___282 *file;
	struct address_space___282 *mapping;
	struct file_ra_state *ra;
	long unsigned int _index;
	unsigned int _nr_pages;
	unsigned int _batch_count;
};

struct bio_vec___199;

struct iov_iter___202 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___199 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___123 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct swap_info_struct___70 {
	struct percpu_ref users;
	long unsigned int flags;
	short int prio;
	struct plist_node list;
	signed char type;
	unsigned int max;
	unsigned char *swap_map;
	struct swap_cluster_info *cluster_info;
	struct swap_cluster_list free_clusters;
	unsigned int lowest_bit;
	unsigned int highest_bit;
	unsigned int pages;
	unsigned int inuse_pages;
	unsigned int cluster_next;
	unsigned int cluster_nr;
	unsigned int *cluster_next_cpu;
	struct percpu_cluster *percpu_cluster;
	struct rb_root swap_extent_root;
	struct block_device___176 *bdev;
	struct file___282 *swap_file;
	unsigned int old_block_size;
	struct completion comp;
	long unsigned int *frontswap_map;
	atomic_t frontswap_pages;
	spinlock_t lock;
	spinlock_t cont_lock;
	struct work_struct discard_work;
	struct swap_cluster_list discard_clusters;
	struct plist_node avail_lists[0];
};

struct inode_operations___282 {
	struct dentry___282 * (*lookup)(struct inode___282 *, struct dentry___282 *, unsigned int);
	const char * (*get_link)(struct dentry___282 *, struct inode___282 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___282 *, int);
	struct posix_acl * (*get_acl)(struct inode___282 *, int, bool);
	int (*readlink)(struct dentry___282 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___282 *, struct dentry___282 *, umode_t, bool);
	int (*link)(struct dentry___282 *, struct inode___282 *, struct dentry___282 *);
	int (*unlink)(struct inode___282 *, struct dentry___282 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___282 *, struct dentry___282 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___282 *, struct dentry___282 *, umode_t);
	int (*rmdir)(struct inode___282 *, struct dentry___282 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___282 *, struct dentry___282 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___282 *, struct dentry___282 *, struct inode___282 *, struct dentry___282 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___282 *, struct iattr___282 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___282 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___282 *, char *, size_t);
	int (*fiemap)(struct inode___282 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___282 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___282 *, struct dentry___282 *, struct file___282 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___282 *, struct dentry___282 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___282 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___282 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___282 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___282 {
	void (*fl_copy_lock)(struct file_lock___282 *, struct file_lock___282 *);
	void (*fl_release_private)(struct file_lock___282 *);
};

struct lock_manager_operations___282;

struct file_lock___282 {
	struct file_lock___282 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___282 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___282 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___282 *fl_ops;
	const struct lock_manager_operations___282 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___282 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___282 *);
	int (*lm_grant)(struct file_lock___282 *, int);
	bool (*lm_break)(struct file_lock___282 *);
	int (*lm_change)(struct file_lock___282 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___282 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___282 *);
};

struct fasync_struct___282 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___282 *fa_next;
	struct file___282 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___282 {
	struct inode___282 * (*alloc_inode)(struct super_block___282 *);
	void (*destroy_inode)(struct inode___282 *);
	void (*free_inode)(struct inode___282 *);
	void (*dirty_inode)(struct inode___282 *, int);
	int (*write_inode)(struct inode___282 *, struct writeback_control___159 *);
	int (*drop_inode)(struct inode___282 *);
	void (*evict_inode)(struct inode___282 *);
	void (*put_super)(struct super_block___282 *);
	int (*sync_fs)(struct super_block___282 *, int);
	int (*freeze_super)(struct super_block___282 *);
	int (*freeze_fs)(struct super_block___282 *);
	int (*thaw_super)(struct super_block___282 *);
	int (*unfreeze_fs)(struct super_block___282 *);
	int (*statfs)(struct dentry___282 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___282 *, int *, char *);
	void (*umount_begin)(struct super_block___282 *);
	int (*show_options)(struct seq_file___257 *, struct dentry___282 *);
	int (*show_devname)(struct seq_file___257 *, struct dentry___282 *);
	int (*show_path)(struct seq_file___257 *, struct dentry___282 *);
	int (*show_stats)(struct seq_file___257 *, struct dentry___282 *);
	ssize_t (*quota_read)(struct super_block___282 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___282 *, int, const char *, size_t, loff_t);
	struct dquot___282 ** (*get_dquots)(struct inode___282 *);
	long int (*nr_cached_objects)(struct super_block___282 *, struct shrink_control___147 *);
	long int (*free_cached_objects)(struct super_block___282 *, struct shrink_control___147 *);
	struct file___282 * (*real_loop)(struct file___282 *);
};

struct wakeup_source___263;

struct dev_pm_info___263 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___263 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___263 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___263;

struct bus_type___263;

struct device_driver___263;

struct dev_pm_domain___263;

struct fwnode_handle___259;

struct class___263;

struct attribute_group___270;

struct device___263 {
	struct kobject___270 kobj;
	struct device___263 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___263 *type;
	struct bus_type___263 *bus;
	struct device_driver___263 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___263 power;
	struct dev_pm_domain___263 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___259 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___263 *class;
	const struct attribute_group___270 **groups;
	void (*release)(struct device___263 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___176 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___282 *bd_inode;
	struct super_block___282 *bd_super;
	void *bd_claiming;
	struct device___263 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___270 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___176 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___282 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___211)(struct file___282 *, wait_queue_head_t *, struct poll_table_struct___203 *);

struct poll_table_struct___203 {
	poll_queue_proc___211 _qproc;
	__poll_t _key;
};

struct seq_operations___257;

struct seq_file___257 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___257 *op;
	int poll_event;
	const struct file___282 *file;
	void *private;
};

typedef void bio_end_io_t___173(struct bio___173 *);

struct bio_vec___199 {
	struct page___287 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___173;

struct bio___173 {
	struct bio___173 *bi_next;
	struct block_device___176 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___173 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___161 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___173 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___199 *bi_io_vec;
	struct bio_set___173 *bi_pool;
	struct bio_vec___199 bi_inline_vecs[0];
};

struct kernfs_root___270;

struct kernfs_elem_dir___270 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___270 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___270;

struct kernfs_root___270 {
	struct kernfs_node___270 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___270 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___270 {
	struct kernfs_node___270 *target_kn;
};

struct kernfs_ops___270;

struct kernfs_elem_attr___270 {
	const struct kernfs_ops___270 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___270 *notify_next;
};

struct kernfs_node___270 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___270 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___270 dir;
		struct kernfs_elem_symlink___270 symlink;
		struct kernfs_elem_attr___270 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___270;

struct kernfs_ops___270 {
	int (*open)(struct kernfs_open_file___270 *);
	void (*release)(struct kernfs_open_file___270 *);
	int (*seq_show)(struct seq_file___257 *, void *);
	void * (*seq_start)(struct seq_file___257 *, loff_t *);
	void * (*seq_next)(struct seq_file___257 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___257 *, void *);
	ssize_t (*read)(struct kernfs_open_file___270 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___270 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___270 *, struct poll_table_struct___203 *);
	int (*mmap)(struct kernfs_open_file___270 *, struct vm_area_struct___287 *);
};

struct kernfs_syscall_ops___270 {
	int (*show_options)(struct seq_file___257 *, struct kernfs_root___270 *);
	int (*mkdir)(struct kernfs_node___270 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___270 *);
	int (*rename)(struct kernfs_node___270 *, struct kernfs_node___270 *, const char *);
	int (*show_path)(struct seq_file___257 *, struct kernfs_node___270 *, struct kernfs_root___270 *);
};

struct kernfs_open_file___270 {
	struct kernfs_node___270 *kn;
	struct file___282 *file;
	struct seq_file___257 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___277 *vm_ops;
};

struct sock___78;

struct kobj_ns_type_operations___78 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___78 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___96 *net;
} possible_net_t___91;

struct proto___78;

struct sock_common___78 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___78 *skc_prot;
	possible_net_t___91 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___78 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___92;

struct sk_buff_head___91 {
	struct sk_buff___92 *next;
	struct sk_buff___92 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___78 {
	struct cgroup___209 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___78;

struct socket_wq___79;

struct dst_entry___78;

struct socket___80;

struct net_device___91;

struct sock_reuseport___27;

struct sock___78 {
	struct sock_common___78 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___91 sk_error_queue;
	struct sk_buff___92 *sk_rx_skb_cache;
	struct sk_buff_head___91 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___92 *head;
		struct sk_buff___92 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___78 *sk_filter;
	union {
		struct socket_wq___79 *sk_wq;
		struct socket_wq___79 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___78 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___78 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___92 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___92 *sk_tx_skb_cache;
	struct sk_buff_head___91 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___287 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___78 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___259 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___80 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___78 sk_cgrp_data;
	struct mem_cgroup___147 *sk_memcg;
	void (*sk_state_change)(struct sock___78 *);
	void (*sk_data_ready)(struct sock___78 *);
	void (*sk_write_space)(struct sock___78 *);
	void (*sk_error_report)(struct sock___78 *);
	int (*sk_backlog_rcv)(struct sock___78 *, struct sk_buff___92 *);
	struct sk_buff___92 * (*sk_validate_xmit_skb)(struct sock___78 *, struct net_device___91 *, struct sk_buff___92 *);
	void (*sk_destruct)(struct sock___78 *);
	struct sock_reuseport___27 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___270;

struct attribute_group___270 {
	const char *name;
	umode_t (*is_visible)(struct kobject___270 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___270 *, struct bin_attribute___270 *, int);
	struct attribute **attrs;
	struct bin_attribute___270 **bin_attrs;
};

struct bin_attribute___270 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___282 * (*f_mapping)();
	ssize_t (*read)(struct file___282 *, struct kobject___270 *, struct bin_attribute___270 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___282 *, struct kobject___270 *, struct bin_attribute___270 *, char *, loff_t, size_t);
	int (*mmap)(struct file___282 *, struct kobject___270 *, struct bin_attribute___270 *, struct vm_area_struct___287 *);
};

struct sysfs_ops___270 {
	ssize_t (*show)(struct kobject___270 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___270 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___270;

struct kset___270 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___270 kobj;
	const struct kset_uevent_ops___270 *uevent_ops;
};

struct kobj_type___270 {
	void (*release)(struct kobject___270 *);
	const struct sysfs_ops___270 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___270 **default_groups;
	const struct kobj_ns_type_operations___78 * (*child_ns_type)(struct kobject___270 *);
	const void * (*namespace)(struct kobject___270 *);
	void (*get_ownership)(struct kobject___270 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___270 {
	int (* const filter)(struct kset___270 *, struct kobject___270 *);
	const char * (* const name)(struct kset___270 *, struct kobject___270 *);
	int (* const uevent)(struct kset___270 *, struct kobject___270 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___266 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___266 *);
	int (*get)(char *, const struct kernel_param___266 *);
	void (*free)(void *);
};

struct kparam_array___266;

struct kernel_param___266 {
	const char *name;
	struct module___266 *mod;
	const struct kernel_param_ops___266 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___266 *arr;
	};
};

struct kparam_array___266 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___266 *ops;
	void *elem;
};

struct module_attribute___266 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___266 *, struct module_kobject___267 *, char *);
	ssize_t (*store)(struct module_attribute___266 *, struct module_kobject___267 *, const char *, size_t);
	void (*setup)(struct module___266 *, const char *);
	int (*test)(struct module___266 *);
	void (*free)(struct module___266 *);
};

struct fwnode_operations___259;

struct fwnode_handle___259 {
	struct fwnode_handle___259 *secondary;
	const struct fwnode_operations___259 *ops;
	struct device___263 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___259;

struct fwnode_endpoint___259;

struct fwnode_operations___259 {
	struct fwnode_handle___259 * (*get)(struct fwnode_handle___259 *);
	void (*put)(struct fwnode_handle___259 *);
	bool (*device_is_available)(const struct fwnode_handle___259 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___259 *, const struct device___263 *);
	bool (*property_present)(const struct fwnode_handle___259 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___259 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___259 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___259 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*get_parent)(const struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*get_next_child_node)(const struct fwnode_handle___259 *, struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*get_named_child_node)(const struct fwnode_handle___259 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___259 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___259 *);
	struct fwnode_handle___259 * (*graph_get_next_endpoint)(const struct fwnode_handle___259 *, struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*graph_get_remote_endpoint)(const struct fwnode_handle___259 *);
	struct fwnode_handle___259 * (*graph_get_port_parent)(struct fwnode_handle___259 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___259 *, struct fwnode_endpoint___259 *);
	int (*add_links)(struct fwnode_handle___259 *);
};

struct fwnode_endpoint___259 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___259 *local_fwnode;
};

struct fwnode_reference_args___259 {
	struct fwnode_handle___259 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___51;

struct fib_rules_ops___78;

struct fqdir___96;

struct tcp_congestion_ops___25;

struct fib_notifier_ops___78;

struct netns_ipv4___96 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___51 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___78 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___78 *fibnl;
	struct sock___78 **icmp_sk;
	struct sock___78 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___78 **tcp_sk;
	struct fqdir___96 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___25 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___78 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___78 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___78 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___78;

struct dst_ops___96 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___96 *);
	struct dst_entry___78 * (*check)(struct dst_entry___78 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___78 *);
	unsigned int (*mtu)(const struct dst_entry___78 *);
	u32 * (*cow_metrics)(struct dst_entry___78 *, long unsigned int);
	void (*destroy)(struct dst_entry___78 *);
	void (*ifdown)(struct dst_entry___78 *, struct net_device___91 *, int);
	struct dst_entry___78 * (*negative_advice)(struct dst_entry___78 *);
	void (*link_failure)(struct sk_buff___92 *);
	void (*update_pmtu)(struct dst_entry___78 *, struct sock___78 *, struct sk_buff___92 *, u32, bool);
	void (*redirect)(struct dst_entry___78 *, struct sock___78 *, struct sk_buff___92 *);
	int (*local_out)(struct net___96 *, struct sock___78 *, struct sk_buff___92 *);
	struct neighbour___78 * (*neigh_lookup)(const struct dst_entry___78 *, struct sk_buff___92 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___78 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___96 {
	struct dst_ops___96 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___96 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___78 *fib6_rules_ops;
	struct sock___78 **icmp_sk;
	struct sock___78 *ndisc_sk;
	struct sock___78 *tcp_sk;
	struct sock___78 *igmp_sk;
	struct sock___78 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___78 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___78 *notifier_ops;
	struct fib_notifier_ops___78 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___96 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___96 *fqdir;
};

struct netns_sctp___78 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___78 *ctl_sock;
	struct sock___78 *udp4_sock;
	struct sock___78 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___85;

struct netns_bpf___85 {
	struct bpf_prog_array___85 *run_array[2];
	struct bpf_prog___85 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___96 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___78 *nlsk;
	struct sock___78 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___96 xfrm4_dst_ops;
	struct dst_ops___96 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___96 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___78 *rtnl;
	struct sock___78 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___91 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___96 ipv4;
	struct netns_ipv6___96 ipv6;
	struct netns_ieee802154_lowpan___96 ieee802154_lowpan;
	struct netns_sctp___78 sctp;
	struct netns_nf___16 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___91 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___85 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___96 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___78 *crypto_nlsk;
	struct sock___78 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___209 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___209 *root_cset;
};

struct msghdr___80 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___202 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___282 *msg_iocb;
};

struct socket_wq___79 {
	wait_queue_head_t wait;
	struct fasync_struct___282 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___79;

struct socket___80 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___282 *file;
	struct sock___78 *sk;
	const struct proto_ops___79 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___79 wq;
};

typedef int (*sk_read_actor_t___78)(read_descriptor_t *, struct sk_buff___92 *, unsigned int, size_t);

struct proto_ops___79 {
	int family;
	struct module___266 *owner;
	int (*release)(struct socket___80 *);
	int (*bind)(struct socket___80 *, struct sockaddr *, int);
	int (*connect)(struct socket___80 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___80 *, struct socket___80 *);
	int (*accept)(struct socket___80 *, struct socket___80 *, int, bool);
	int (*getname)(struct socket___80 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___282 *, struct socket___80 *, struct poll_table_struct___203 *);
	int (*ioctl)(struct socket___80 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___80 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___80 *, void *, bool, bool);
	int (*listen)(struct socket___80 *, int);
	int (*shutdown)(struct socket___80 *, int);
	int (*setsockopt)(struct socket___80 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___80 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___257 *, struct socket___80 *);
	int (*sendmsg)(struct socket___80 *, struct msghdr___80 *, size_t);
	int (*recvmsg)(struct socket___80 *, struct msghdr___80 *, size_t, int);
	int (*mmap)(struct file___282 *, struct socket___80 *, struct vm_area_struct___287 *);
	ssize_t (*sendpage)(struct socket___80 *, struct page___287 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___80 *, loff_t *, struct pipe_inode_info___123 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___78 *, int);
	int (*peek_len)(struct socket___80 *);
	int (*read_sock)(struct sock___78 *, read_descriptor_t *, sk_read_actor_t___78);
	int (*sendpage_locked)(struct sock___78 *, struct page___287 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___78 *, struct msghdr___80 *, size_t);
	int (*set_rcvlowat)(struct sock___78 *, int);
};

struct sk_buff___92 {
	union {
		struct {
			struct sk_buff___92 *next;
			struct sk_buff___92 *prev;
			union {
				struct net_device___91 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___78 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___92 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___263 {
	int (*prepare)(struct device___263 *);
	void (*complete)(struct device___263 *);
	int (*suspend)(struct device___263 *);
	int (*resume)(struct device___263 *);
	int (*freeze)(struct device___263 *);
	int (*thaw)(struct device___263 *);
	int (*poweroff)(struct device___263 *);
	int (*restore)(struct device___263 *);
	int (*suspend_late)(struct device___263 *);
	int (*resume_early)(struct device___263 *);
	int (*freeze_late)(struct device___263 *);
	int (*thaw_early)(struct device___263 *);
	int (*poweroff_late)(struct device___263 *);
	int (*restore_early)(struct device___263 *);
	int (*suspend_noirq)(struct device___263 *);
	int (*resume_noirq)(struct device___263 *);
	int (*freeze_noirq)(struct device___263 *);
	int (*thaw_noirq)(struct device___263 *);
	int (*poweroff_noirq)(struct device___263 *);
	int (*restore_noirq)(struct device___263 *);
	int (*runtime_suspend)(struct device___263 *);
	int (*runtime_resume)(struct device___263 *);
	int (*runtime_idle)(struct device___263 *);
};

struct wakeup_source___263 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___263 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___263 {
	struct dev_pm_ops___263 ops;
	int (*start)(struct device___263 *);
	void (*detach)(struct device___263 *, bool);
	int (*activate)(struct device___263 *);
	void (*sync)(struct device___263 *);
	void (*dismiss)(struct device___263 *);
};

struct bus_type___263 {
	const char *name;
	const char *dev_name;
	struct device___263 *dev_root;
	const struct attribute_group___270 **bus_groups;
	const struct attribute_group___270 **dev_groups;
	const struct attribute_group___270 **drv_groups;
	int (*match)(struct device___263 *, struct device_driver___263 *);
	int (*uevent)(struct device___263 *, struct kobj_uevent_env *);
	int (*probe)(struct device___263 *);
	void (*sync_state)(struct device___263 *);
	void (*remove)(struct device___263 *);
	void (*shutdown)(struct device___263 *);
	int (*online)(struct device___263 *);
	int (*offline)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	int (*num_vf)(struct device___263 *);
	int (*dma_configure)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___263 {
	const char *name;
	struct bus_type___263 *bus;
	struct module___266 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___263 *);
	void (*sync_state)(struct device___263 *);
	int (*remove)(struct device___263 *);
	void (*shutdown)(struct device___263 *);
	int (*suspend)(struct device___263 *, pm_message_t);
	int (*resume)(struct device___263 *);
	const struct attribute_group___270 **groups;
	const struct attribute_group___270 **dev_groups;
	const struct dev_pm_ops___263 *pm;
	void (*coredump)(struct device___263 *);
	struct driver_private *p;
};

struct device_type___263 {
	const char *name;
	const struct attribute_group___270 **groups;
	int (*uevent)(struct device___263 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___263 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___263 *);
	const struct dev_pm_ops___263 *pm;
};

struct class___263 {
	const char *name;
	struct module___266 *owner;
	const struct attribute_group___270 **class_groups;
	const struct attribute_group___270 **dev_groups;
	struct kobject___270 *dev_kobj;
	int (*dev_uevent)(struct device___263 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___263 *, umode_t *);
	void (*class_release)(struct class___263 *);
	void (*dev_release)(struct device___263 *);
	int (*shutdown_pre)(struct device___263 *);
	const struct kobj_ns_type_operations___78 *ns_type;
	const void * (*namespace)(struct device___263 *);
	void (*get_ownership)(struct device___263 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___263 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___123;

struct pipe_buffer___123 {
	struct page___287 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___123 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___123 {
	int (*confirm)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
	void (*release)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
	bool (*try_steal)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
	bool (*get)(struct pipe_inode_info___123 *, struct pipe_buffer___123 *);
};

typedef rx_handler_result_t rx_handler_func_t___91(struct sk_buff___92 **);

struct bpf_xdp_entity___85 {
	struct bpf_prog___85 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___91;

struct net_device_ops___91;

struct l3mdev_ops___78;

struct ndisc_ops___60;

struct xfrmdev_ops___91;

struct header_ops___91;

struct in_device___18;

struct inet6_dev___60;

struct netdev_rx_queue___91;

struct mini_Qdisc___85;

struct netdev_queue___91;

struct Qdisc___85;

struct rtnl_link_ops___85;

struct dcbnl_rtnl_ops___91;

struct net_device___91 {
	char name[16];
	struct netdev_name_node___91 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___91 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___78 *l3mdev_ops;
	const struct ndisc_ops___60 *ndisc_ops;
	const struct xfrmdev_ops___91 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___91 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___270 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___18 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___60 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___91 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___85 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___91 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___85 *miniq_ingress;
	struct netdev_queue___91 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___91 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___85 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___85 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___91 = 0,
		NETREG_REGISTERED___91 = 1,
		NETREG_UNREGISTERING___91 = 2,
		NETREG_UNREGISTERED___91 = 3,
		NETREG_RELEASED___91 = 4,
		NETREG_DUMMY___91 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___91 = 0,
		RTNL_LINK_INITIALIZING___91 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___91 *);
	struct netpoll_info *npinfo;
	possible_net_t___91 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___263 dev;
	const struct attribute_group___270 *sysfs_groups[4];
	const struct attribute_group___270 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___85 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___91 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___85 xdp_state[3];
	long: 64;
};

struct ip_mc_list___6 {
	struct in_device___18 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___6 *next;
		struct ip_mc_list___6 *next_rcu;
	};
	struct ip_mc_list___6 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

struct in_ifaddr___18;

struct neigh_parms___78;

struct in_device___18 {
	struct net_device___91 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___18 *ifa_list;
	struct ip_mc_list___6 *mc_list;
	struct ip_mc_list___6 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___6 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___78 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct inet_frags___96;

struct fqdir___96 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___96 *f;
	struct net___96 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___96;

struct inet_frags___96 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___96 *, const void *);
	void (*destructor)(struct inet_frag_queue___96 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___96 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___92 *fragments_tail;
	struct sk_buff___92 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___96 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___51 {
	struct ip_ra_chain___51 *next;
	struct sock___78 *sk;
	union {
		void (*destructor)(struct sock___78 *);
		struct sock___78 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___78;

struct fib_lookup_arg___78;

struct fib_rules_ops___78 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___78 *, struct flowi *, int, struct fib_lookup_arg___78 *);
	bool (*suppress)(struct fib_rule___78 *, int, struct fib_lookup_arg___78 *);
	int (*match)(struct fib_rule___78 *, struct flowi *, int);
	int (*configure)(struct fib_rule___78 *, struct sk_buff___92 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___78 *);
	int (*compare)(struct fib_rule___78 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___78 *, struct sk_buff___92 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___78 *);
	void (*flush_cache)(struct fib_rules_ops___78 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___266 *owner;
	struct net___96 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___25 {
	u32 (*ssthresh)(struct sock___78 *);
	void (*cong_avoid)(struct sock___78 *, u32, u32);
	void (*set_state)(struct sock___78 *, u8);
	void (*cwnd_event)(struct sock___78 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___78 *, u32);
	void (*pkts_acked)(struct sock___78 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___78 *);
	void (*cong_control)(struct sock___78 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___78 *);
	u32 (*sndbuf_expand)(struct sock___78 *);
	size_t (*get_info)(struct sock___78 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___266 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___78 *);
	void (*release)(struct sock___78 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___78 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___96 *);
	int (*fib_dump)(struct net___96 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___266 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___54;

struct dst_entry___78 {
	struct net_device___91 *dev;
	struct dst_ops___96 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___92 *);
	int (*output)(struct net___96 *, struct sock___78 *, struct sk_buff___92 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___54 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___78;

struct neigh_ops___78;

struct neighbour___78 {
	struct neighbour___78 *next;
	struct neigh_table___78 *tbl;
	struct neigh_parms___78 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___91 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___78 *, struct sk_buff___92 *);
	const struct neigh_ops___78 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___91 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___85 {
	struct bpf_prog___85 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___85 {
	struct callback_head rcu;
	struct bpf_prog_array_item___85 items[0];
};

struct bpf_prog_aux___94;

struct bpf_prog___85 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___94 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___257 {
	void * (*start)(struct seq_file___257 *, loff_t *);
	void (*stop)(struct seq_file___257 *, void *);
	void * (*next)(struct seq_file___257 *, void *, loff_t *);
	int (*show)(struct seq_file___257 *, void *);
};

struct pernet_operations___30 {
	struct list_head list;
	int (*init)(struct net___96 *);
	void (*pre_exit)(struct net___96 *);
	void (*exit)(struct net___96 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___91 {
	int (*ieee_getets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___91 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___91 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___91 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___91 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___91 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___91 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___91 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___91 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___91 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___91 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___91 *);
	u8 (*setstate)(struct net_device___91 *, u8);
	void (*getpermhwaddr)(struct net_device___91 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___91 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___91 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___91 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___91 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___91 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___91 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___91 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___91 *, int, u8 *);
	void (*setpfccfg)(struct net_device___91 *, int, u8);
	void (*getpfccfg)(struct net_device___91 *, int, u8 *);
	u8 (*setall)(struct net_device___91 *);
	u8 (*getcap)(struct net_device___91 *, int, u8 *);
	int (*getnumtcs)(struct net_device___91 *, int, u8 *);
	int (*setnumtcs)(struct net_device___91 *, int, u8);
	u8 (*getpfcstate)(struct net_device___91 *);
	void (*setpfcstate)(struct net_device___91 *, u8);
	void (*getbcncfg)(struct net_device___91 *, int, u32 *);
	void (*setbcncfg)(struct net_device___91 *, int, u32);
	void (*getbcnrp)(struct net_device___91 *, int, u8 *);
	void (*setbcnrp)(struct net_device___91 *, int, u8);
	int (*setapp)(struct net_device___91 *, u8, u16, u8);
	int (*getapp)(struct net_device___91 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___91 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___91 *, int, u8);
	u8 (*getdcbx)(struct net_device___91 *);
	u8 (*setdcbx)(struct net_device___91 *, u8);
	int (*peer_getappinfo)(struct net_device___91 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___91 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___91 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___91 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___91 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___91 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___94;

typedef int (*bpf_iter_init_seq_priv_t___93)(void *, struct bpf_iter_aux_info___94 *);

struct bpf_map___94;

struct bpf_iter_aux_info___94 {
	struct bpf_map___94 *map;
};

struct bpf_iter_seq_info___93 {
	const struct seq_operations___257 *seq_ops;
	bpf_iter_init_seq_priv_t___93 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___93 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___94 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___94 *, struct file___282 *);
	void (*map_free)(struct bpf_map___94 *);
	int (*map_get_next_key)(struct bpf_map___94 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___94 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___94 *, void *);
	int (*map_lookup_batch)(struct bpf_map___94 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___94 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___94 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___94 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___94 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___94 *, void *);
	int (*map_update_elem)(struct bpf_map___94 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___94 *, void *);
	int (*map_push_elem)(struct bpf_map___94 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___94 *, void *);
	int (*map_peek_elem)(struct bpf_map___94 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___94 *, struct file___282 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___94 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___94 *, void *, struct seq_file___257 *);
	int (*map_check_btf)(const struct bpf_map___94 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___94 *, struct bpf_prog_aux___94 *);
	void (*map_poke_untrack)(struct bpf_map___94 *, struct bpf_prog_aux___94 *);
	void (*map_poke_run)(struct bpf_map___94 *, u32, struct bpf_prog___85 *, struct bpf_prog___85 *);
	int (*map_direct_value_addr)(const struct bpf_map___94 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___94 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___94 *, struct vm_area_struct___287 *);
	__poll_t (*map_poll)(struct bpf_map___94 *, struct file___282 *, struct poll_table_struct___203 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___94 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___94 *, const struct bpf_map___94 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___94 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___93 *iter_seq_info;
};

struct bpf_map___94 {
	const struct bpf_map_ops___93 *ops;
	struct bpf_map___94 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___147 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___93;

struct bpf_jit_poke_descriptor___93;

struct bpf_prog_ops___85;

struct btf_mod_pair___93;

struct bpf_prog_offload___91;

struct bpf_prog_aux___94 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___85 *dst_prog;
	struct bpf_trampoline___93 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___85 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___93 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___85 *ops;
	struct bpf_map___94 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___93 *used_btfs;
	struct bpf_prog___85 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___94 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___91 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___91;

struct bpf_map_dev_ops___91 {
	int (*map_get_next_key)(struct bpf_offloaded_map___91 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___91 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___91 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___91 *, void *);
};

struct bpf_offloaded_map___91 {
	struct bpf_map___94 map;
	struct net_device___91 *netdev;
	const struct bpf_map_dev_ops___91 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___85 {
	int (*test_run)(struct bpf_prog___85 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___91 {
	struct bpf_prog___85 *prog;
	struct net_device___91 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___93 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___85 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___266 *mod;
};

struct bpf_jit_poke_descriptor___93 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___94 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___93 {
	struct btf *btf;
	struct module___266 *module;
};

struct cftype___209;

struct cgroup_subsys___209 {
	struct cgroup_subsys_state___209 * (*css_alloc)(struct cgroup_subsys_state___209 *);
	int (*css_online)(struct cgroup_subsys_state___209 *);
	void (*css_offline)(struct cgroup_subsys_state___209 *);
	void (*css_released)(struct cgroup_subsys_state___209 *);
	void (*css_free)(struct cgroup_subsys_state___209 *);
	void (*css_reset)(struct cgroup_subsys_state___209 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___209 *, int);
	int (*css_extra_stat_show)(struct seq_file___257 *, struct cgroup_subsys_state___209 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___289 *, struct css_set___209 *);
	void (*cancel_fork)(struct task_struct___289 *, struct css_set___209 *);
	void (*fork)(struct task_struct___289 *);
	void (*exit)(struct task_struct___289 *);
	void (*release)(struct task_struct___289 *);
	void (*bind)(struct cgroup_subsys_state___209 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___209 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___209 *dfl_cftypes;
	struct cftype___209 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___209 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___209 *updated_children;
	struct cgroup___209 *updated_next;
};

struct cgroup_root___209 {
	struct kernfs_root___270 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___209 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___209 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___209 *ss;
	struct list_head node;
	struct kernfs_ops___270 *kf_ops;
	int (*open)(struct kernfs_open_file___270 *);
	void (*release)(struct kernfs_open_file___270 *);
	u64 (*read_u64)(struct cgroup_subsys_state___209 *, struct cftype___209 *);
	s64 (*read_s64)(struct cgroup_subsys_state___209 *, struct cftype___209 *);
	int (*seq_show)(struct seq_file___257 *, void *);
	void * (*seq_start)(struct seq_file___257 *, loff_t *);
	void * (*seq_next)(struct seq_file___257 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___257 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___209 *, struct cftype___209 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___209 *, struct cftype___209 *, s64);
	ssize_t (*write)(struct kernfs_open_file___270 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___270 *, struct poll_table_struct___203 *);
};

struct xdp_rxq_info___91 {
	struct net_device___91 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___91 {
	struct net_device___91 *dev;
};

struct xdp_buff___91 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___91 *rxq;
	struct xdp_txq_info___91 *txq;
	u32 frame_sz;
};

struct xdp_frame___91 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___91 *dev_rx;
};

struct netlink_callback___91 {
	struct sk_buff___92 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___92 *, struct netlink_callback___91 *);
	int (*done)(struct netlink_callback___91 *);
	void *data;
	struct module___266 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___91 {
	int (*create)(struct sk_buff___92 *, struct net_device___91 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___92 *, unsigned char *);
	int (*cache)(const struct neighbour___78 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___91 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___92 *);
};

struct netdev_queue___91 {
	struct net_device___91 *dev;
	struct Qdisc___85 *qdisc;
	struct Qdisc___85 *qdisc_sleeping;
	struct kobject___270 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___91 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___85 {
	struct sk_buff___92 *head;
	struct sk_buff___92 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___85;

struct Qdisc___85 {
	int (*enqueue)(struct sk_buff___92 *, struct Qdisc___85 *, struct sk_buff___92 **);
	struct sk_buff___92 * (*dequeue)(struct Qdisc___85 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___85 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___91 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___91 gso_skb;
	struct qdisc_skb_head___85 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___85 *next_sched;
	struct sk_buff_head___91 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___91 {
	struct xdp_rxq_info___91 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___270 kobj;
	struct net_device___91 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___91 {
	enum net_device_path_type type;
	const struct net_device___91 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___91 = 0,
				DEV_PATH_BR_VLAN_TAG___91 = 1,
				DEV_PATH_BR_VLAN_UNTAG___91 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___91 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___91 {
	const struct net_device___91 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___91 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___85 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___91 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___91 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___92 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___91 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___91 *dev;
	const char *name;
};

struct net_device_ops___91 {
	int (*ndo_init)(struct net_device___91 *);
	void (*ndo_uninit)(struct net_device___91 *);
	int (*ndo_open)(struct net_device___91 *);
	int (*ndo_stop)(struct net_device___91 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___92 *, struct net_device___91 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___92 *, struct net_device___91 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___91 *, struct sk_buff___92 *, struct net_device___91 *);
	void (*ndo_change_rx_flags)(struct net_device___91 *, int);
	void (*ndo_set_rx_mode)(struct net_device___91 *);
	int (*ndo_set_mac_address)(struct net_device___91 *, void *);
	int (*ndo_validate_addr)(struct net_device___91 *);
	int (*ndo_do_ioctl)(struct net_device___91 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___91 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___91 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___91 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___91 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___91 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___91 *, int);
	int (*ndo_neigh_setup)(struct net_device___91 *, struct neigh_parms___78 *);
	void (*ndo_tx_timeout)(struct net_device___91 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___91 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___91 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___91 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___91 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___91 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___91 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___91 *);
	int (*ndo_netpoll_setup)(struct net_device___91 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___91 *);
	int (*ndo_set_vf_mac)(struct net_device___91 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___91 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___91 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___91 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___91 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___91 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___91 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___91 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___91 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___91 *, int, struct sk_buff___92 *);
	int (*ndo_get_vf_guid)(struct net_device___91 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___91 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___91 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___91 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___91 *);
	int (*ndo_fcoe_disable)(struct net_device___91 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___91 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___91 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___91 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___91 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___91 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___91 *, const struct sk_buff___92 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___91 *, struct net_device___91 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___91 *, struct net_device___91 *);
	struct net_device___91 * (*ndo_get_xmit_slave)(struct net_device___91 *, struct sk_buff___92 *, bool);
	struct net_device___91 * (*ndo_sk_get_lower_dev)(struct net_device___91 *, struct sock___78 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___91 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___91 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___91 *, struct neighbour___78 *);
	void (*ndo_neigh_destroy)(struct net_device___91 *, struct neighbour___78 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___92 *, struct netlink_callback___91 *, struct net_device___91 *, struct net_device___91 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___92 *, struct nlattr **, struct net_device___91 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___91 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___92 *, u32, u32, struct net_device___91 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___91 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___91 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___91 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___91 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___91 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___91 *, struct net_device___91 *);
	void (*ndo_dfwd_del_station)(struct net_device___91 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___91 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___91 *);
	int (*ndo_change_proto_down)(struct net_device___91 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___91 *, struct sk_buff___92 *);
	void (*ndo_set_rx_headroom)(struct net_device___91 *, int);
	int (*ndo_bpf)(struct net_device___91 *, struct netdev_bpf___91 *);
	int (*ndo_xdp_xmit)(struct net_device___91 *, int, struct xdp_frame___91 **, u32);
	struct net_device___91 * (*ndo_xdp_get_xmit_slave)(struct net_device___91 *, struct xdp_buff___91 *);
	int (*ndo_xsk_wakeup)(struct net_device___91 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___91 *);
	int (*ndo_tunnel_ctl)(struct net_device___91 *, struct ip_tunnel_parm *, int);
	struct net_device___91 * (*ndo_get_peer_dev)(struct net_device___91 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___91 *, struct net_device_path___91 *);
};

struct neigh_parms___78 {
	possible_net_t___91 net;
	struct net_device___91 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___78 *);
	struct neigh_table___78 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___78 {
	u32 (*l3mdev_fib_table)(const struct net_device___91 *);
	struct sk_buff___92 * (*l3mdev_l3_rcv)(struct net_device___91 *, struct sk_buff___92 *, u16);
	struct sk_buff___92 * (*l3mdev_l3_out)(struct net_device___91 *, struct sock___78 *, struct sk_buff___92 *, u16);
	struct dst_entry___78 * (*l3mdev_link_scope_lookup)(const struct net_device___91 *, struct flowi6 *);
};

struct ndisc_ops___60 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___91 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___91 *, struct neighbour___78 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___91 *, u8, struct neighbour___78 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___91 *, struct sk_buff___92 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___96 *, struct net_device___91 *, const struct prefix_info *, struct inet6_dev___60 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___60;

struct inet6_dev___60 {
	struct net_device___91 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___60 *mc_list;
	struct ifmcaddr6___60 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___91 mc_query_queue;
	struct sk_buff_head___91 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___24 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___78 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___85;

struct tcf_block___85;

struct mini_Qdisc___85 {
	struct tcf_proto___85 *filter_list;
	struct tcf_block___85 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___85 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___91 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___91 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___96 *, struct net_device___91 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___91 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___91 *, struct list_head *);
	size_t (*get_size)(const struct net_device___91 *);
	int (*fill_info)(struct sk_buff___92 *, const struct net_device___91 *);
	size_t (*get_xstats_size)(const struct net_device___91 *);
	int (*fill_xstats)(struct sk_buff___92 *, const struct net_device___91 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___91 *, struct net_device___91 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___91 *, const struct net_device___91 *);
	int (*fill_slave_info)(struct sk_buff___92 *, const struct net_device___91 *, const struct net_device___91 *);
	struct net___96 * (*get_link_net)(const struct net_device___91 *);
	size_t (*get_linkxstats_size)(const struct net_device___91 *, int);
	int (*fill_linkxstats)(struct sk_buff___92 *, const struct net_device___91 *, int *, int);
};

struct in_ifaddr___18 {
	struct hlist_node hash;
	struct in_ifaddr___18 *ifa_next;
	struct in_device___18 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct block_device_operations___173;

struct gendisk___176 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___176 *part0;
	const struct block_device_operations___173 *fops;
	struct request_queue___173 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___159 *bdi;
	struct kobject___270 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___270 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___173 {
	struct bio___173 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___199 *bip_vec;
	struct bio_vec___199 bip_inline_vecs[0];
};

struct blkcg___161;

struct blkg_policy_data___161;

struct blkcg_gq___161 {
	struct request_queue___173 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___161 *blkcg;
	struct blkcg_gq___161 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___161 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___173 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___173(struct request___173 *);

typedef void integrity_complete_fn___173(struct request___173 *, unsigned int);

struct blk_integrity_profile___173 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___173 *prepare_fn;
	integrity_complete_fn___173 *complete_fn;
	const char *name;
};

struct block_device_operations___173 {
	blk_qc_t (*submit_bio)(struct bio___173 *);
	int (*open)(struct block_device___176 *, fmode_t);
	void (*release)(struct gendisk___176 *, fmode_t);
	int (*rw_page)(struct block_device___176 *, sector_t, struct page___287 *, unsigned int);
	int (*ioctl)(struct block_device___176 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___176 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___176 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___176 *);
	int (*getgeo)(struct block_device___176 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___176 *, bool);
	void (*swap_slot_free_notify)(struct block_device___176 *, long unsigned int);
	int (*report_zones)(struct gendisk___176 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___176 *, umode_t *);
	struct module___266 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___176 *, sector_t *);
};

typedef void rq_end_io_fn___173(struct request___173 *, blk_status_t);

struct request___173 {
	struct request_queue___173 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___168 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___173 *bio;
	struct bio___173 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___199 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___173 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___173 *saved_end_io;
		} flush;
	};
	struct gendisk___176 *rq_disk;
	struct block_device___176 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___173 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___168 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___173 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___270 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___282 *debugfs_dir;
	struct dentry___282 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___173;

struct elevator_mq_ops___173 {
	int (*init_sched)(struct request_queue___173 *, struct elevator_type___173 *);
	void (*exit_sched)(struct elevator_queue___173 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___168 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___168 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___168 *);
	bool (*allow_merge)(struct request_queue___173 *, struct request___173 *, struct bio___173 *);
	bool (*bio_merge)(struct request_queue___173 *, struct bio___173 *, unsigned int);
	int (*request_merge)(struct request_queue___173 *, struct request___173 **, struct bio___173 *);
	void (*request_merged)(struct request_queue___173 *, struct request___173 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___173 *, struct request___173 *, struct request___173 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___173 *);
	void (*finish_request)(struct request___173 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___168 *, struct list_head *, bool);
	struct request___173 * (*dispatch_request)(struct blk_mq_hw_ctx___168 *);
	bool (*has_work)(struct blk_mq_hw_ctx___168 *);
	void (*completed_request)(struct request___173 *, u64);
	void (*requeue_request)(struct request___173 *);
	struct request___173 * (*former_request)(struct request_queue___173 *, struct request___173 *);
	struct request___173 * (*next_request)(struct request_queue___173 *, struct request___173 *);
	void (*init_icq)(struct io_cq___173 *);
	void (*exit_icq)(struct io_cq___173 *);
};

struct elv_fs_entry___173;

struct elevator_type___173 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___173 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___173 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___266 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___173 {
	struct elevator_type___173 *type;
	void *elevator_data;
	struct kobject___270 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___173 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___173 *, char *);
	ssize_t (*store)(struct elevator_queue___173 *, const char *, size_t);
};

struct blk_mq_queue_data___168;

struct blk_mq_ops___168 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___168 *, const struct blk_mq_queue_data___168 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___168 *);
	int (*get_budget)(struct request_queue___173 *);
	void (*put_budget)(struct request_queue___173 *, int);
	void (*set_rq_budget_token)(struct request___173 *, int);
	int (*get_rq_budget_token)(struct request___173 *);
	enum blk_eh_timer_return (*timeout)(struct request___173 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___168 *);
	void (*complete)(struct request___173 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___168 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___168 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___168 *, struct request___173 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___168 *, struct request___173 *, unsigned int);
	void (*initialize_rq_fn)(struct request___173 *);
	void (*cleanup_rq)(struct request___173 *);
	bool (*busy)(struct request_queue___173 *);
	int (*map_queues)(struct blk_mq_tag_set___168 *);
	void (*show_rq)(struct seq_file___257 *, struct request___173 *);
};

struct blk_mq_tag_set___168 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___168 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___168 {
	struct request___173 *rq;
	bool last;
};

struct blkcg_policy_data___161;

struct blkcg___161 {
	struct cgroup_subsys_state___209 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___161 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___161 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___161 {
	struct blkcg___161 *blkcg;
	int plid;
};

struct blkg_policy_data___161 {
	struct blkcg_gq___161 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___147 {
	struct mem_cgroup___147 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___147 {
	struct lruvec___155 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___147 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___147 *memcg;
};

struct obj_cgroup___147 {
	struct percpu_ref refcnt;
	struct mem_cgroup___147 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___85 {
	spinlock_t *lock;
	struct sk_buff___92 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___85;

struct Qdisc_ops___85 {
	struct Qdisc_ops___85 *next;
	const struct Qdisc_class_ops___85 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___92 *, struct Qdisc___85 *, struct sk_buff___92 **);
	struct sk_buff___92 * (*dequeue)(struct Qdisc___85 *);
	struct sk_buff___92 * (*peek)(struct Qdisc___85 *);
	int (*init)(struct Qdisc___85 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___85 *);
	void (*destroy)(struct Qdisc___85 *);
	int (*change)(struct Qdisc___85 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___85 *);
	int (*change_tx_queue_len)(struct Qdisc___85 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___85 *, unsigned int);
	int (*dump)(struct Qdisc___85 *, struct sk_buff___92 *);
	int (*dump_stats)(struct Qdisc___85 *, struct gnet_dump___85 *);
	void (*ingress_block_set)(struct Qdisc___85 *, u32);
	void (*egress_block_set)(struct Qdisc___85 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___85 *);
	u32 (*egress_block_get)(struct Qdisc___85 *);
	struct module___266 *owner;
};

struct Qdisc_class_ops___85 {
	unsigned int flags;
	struct netdev_queue___91 * (*select_queue)(struct Qdisc___85 *, struct tcmsg *);
	int (*graft)(struct Qdisc___85 *, long unsigned int, struct Qdisc___85 *, struct Qdisc___85 **, struct netlink_ext_ack *);
	struct Qdisc___85 * (*leaf)(struct Qdisc___85 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___85 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___85 *, u32);
	int (*change)(struct Qdisc___85 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___85 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___85 *, struct qdisc_walker *);
	struct tcf_block___85 * (*tcf_block)(struct Qdisc___85 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___85 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___85 *, long unsigned int);
	int (*dump)(struct Qdisc___85 *, long unsigned int, struct sk_buff___92 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___85 *, long unsigned int, struct gnet_dump___85 *);
};

struct tcf_chain___85;

struct tcf_block___85 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___96 *net;
	struct Qdisc___85 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___85 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___85;

struct tcf_proto_ops___85;

struct tcf_proto___85 {
	struct tcf_proto___85 *next;
	void *root;
	int (*classify)(struct sk_buff___92 *, const struct tcf_proto___85 *, struct tcf_result___85 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___85 *ops;
	struct tcf_chain___85 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___85 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___85 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___85 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___92 *, const struct tcf_proto___85 *, struct tcf_result___85 *);
	int (*init)(struct tcf_proto___85 *);
	void (*destroy)(struct tcf_proto___85 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___85 *, u32);
	void (*put)(struct tcf_proto___85 *, void *);
	int (*change)(struct net___96 *, struct sk_buff___92 *, struct tcf_proto___85 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___85 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___85 *);
	void (*walk)(struct tcf_proto___85 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___85 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___85 *, void *);
	void (*hw_del)(struct tcf_proto___85 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___96 *, struct tcf_chain___85 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___96 *, struct tcf_proto___85 *, void *, struct sk_buff___92 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___96 *, struct tcf_proto___85 *, void *, struct sk_buff___92 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___92 *, struct net___96 *, void *);
	struct module___266 *owner;
	int flags;
};

struct tcf_chain___85 {
	struct mutex filter_chain_lock;
	struct tcf_proto___85 *filter_chain;
	struct list_head list;
	struct tcf_block___85 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___85 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___78 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___85 *prog;
};

struct pneigh_entry___78;

struct neigh_hash_table___78;

struct neigh_table___78 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___91 *, __u32 *);
	bool (*key_eq)(const struct neighbour___78 *, const void *);
	int (*constructor)(struct neighbour___78 *);
	int (*pconstructor)(struct pneigh_entry___78 *);
	void (*pdestructor)(struct pneigh_entry___78 *);
	void (*proxy_redo)(struct sk_buff___92 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___91 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___78 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___91 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___78 *nht;
	struct pneigh_entry___78 **phash_buckets;
};

struct neigh_ops___78 {
	int family;
	void (*solicit)(struct neighbour___78 *, struct sk_buff___92 *);
	void (*error_report)(struct neighbour___78 *, struct sk_buff___92 *);
	int (*output)(struct neighbour___78 *, struct sk_buff___92 *);
	int (*connected_output)(struct neighbour___78 *, struct sk_buff___92 *);
};

struct pneigh_entry___78 {
	struct pneigh_entry___78 *next;
	possible_net_t___91 net;
	struct net_device___91 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___78 {
	struct neighbour___78 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___54 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___96 *, struct sock___78 *, struct sk_buff___92 *);
	int (*orig_input)(struct sk_buff___92 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___78 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___78 *ctarget;
	struct net___96 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___78 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___78 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___63;

struct timewait_sock_ops___62;

struct proto___78 {
	void (*close)(struct sock___78 *, long int);
	int (*pre_connect)(struct sock___78 *, struct sockaddr *, int);
	int (*connect)(struct sock___78 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___78 *, int);
	struct sock___78 * (*accept)(struct sock___78 *, int, int *, bool);
	int (*ioctl)(struct sock___78 *, int, long unsigned int);
	int (*init)(struct sock___78 *);
	void (*destroy)(struct sock___78 *);
	void (*shutdown)(struct sock___78 *, int);
	int (*setsockopt)(struct sock___78 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___78 *, int, int, char *, int *);
	void (*keepalive)(struct sock___78 *, int);
	int (*compat_ioctl)(struct sock___78 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___78 *, struct msghdr___80 *, size_t);
	int (*recvmsg)(struct sock___78 *, struct msghdr___80 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___78 *, struct page___287 *, int, size_t, int);
	int (*bind)(struct sock___78 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___78 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___78 *, struct sk_buff___92 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___78 *);
	int (*hash)(struct sock___78 *);
	void (*unhash)(struct sock___78 *);
	void (*rehash)(struct sock___78 *);
	int (*get_port)(struct sock___78 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___78 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___78 *, int);
	bool (*sock_is_readable)(struct sock___78 *);
	void (*enter_memory_pressure)(struct sock___78 *);
	void (*leave_memory_pressure)(struct sock___78 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___63 *rsk_prot;
	struct timewait_sock_ops___62 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___266 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___78 *, int);
};

struct sock_reuseport___27 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___85 *prog;
	struct sock___78 *socks[0];
};

struct request_sock___64;

struct request_sock_ops___63 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___78 *, struct request_sock___64 *);
	void (*send_ack)(const struct sock___78 *, struct sk_buff___92 *, struct request_sock___64 *);
	void (*send_reset)(const struct sock___78 *, struct sk_buff___92 *);
	void (*destructor)(struct request_sock___64 *);
	void (*syn_ack_timeout)(const struct request_sock___64 *);
};

struct timewait_sock_ops___62 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___78 *, struct sock___78 *, void *);
	void (*twsk_destructor)(struct sock___78 *);
};

struct request_sock___64 {
	struct sock_common___78 __req_common;
	struct request_sock___64 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___63 *rsk_ops;
	struct sock___78 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___9 {
	struct request_sock___64 *rskq_rst_head;
	struct request_sock___64 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___9 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___64 *rskq_accept_head;
	struct request_sock___64 *rskq_accept_tail;
	struct fastopen_queue___9 fastopenq;
};

struct inet_cork___18 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___78 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___18 {
	struct inet_cork___18 base;
	struct flowi fl;
};

struct ipv6_pinfo___17;

struct inet_sock___18 {
	struct sock___78 sk;
	struct ipv6_pinfo___17 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___18 cork;
};

struct ipv6_fl_socklist___17;

struct ipv6_pinfo___17 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___17 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___92 *pktoptions;
	struct sk_buff___92 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___9 {
	int (*queue_xmit)(struct sock___78 *, struct sk_buff___92 *, struct flowi *);
	void (*send_check)(struct sock___78 *, struct sk_buff___92 *);
	int (*rebuild_header)(struct sock___78 *);
	void (*sk_rx_dst_set)(struct sock___78 *, const struct sk_buff___92 *);
	int (*conn_request)(struct sock___78 *, struct sk_buff___92 *);
	struct sock___78 * (*syn_recv_sock)(const struct sock___78 *, struct sk_buff___92 *, struct request_sock___64 *, struct dst_entry___78 *, struct request_sock___64 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___78 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___78 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___78 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___78 *);
};

struct inet_bind_bucket___9;

struct tcp_ulp_ops___9;

struct inet_connection_sock___9 {
	struct inet_sock___18 icsk_inet;
	struct request_sock_queue___9 icsk_accept_queue;
	struct inet_bind_bucket___9 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___25 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___9 *icsk_af_ops;
	const struct tcp_ulp_ops___9 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___78 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___78 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___9 {
	possible_net_t___91 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___9 {
	struct list_head list;
	int (*init)(struct sock___78 *);
	void (*update)(struct sock___78 *, struct proto___78 *, void (*)(struct sock___78 *));
	void (*release)(struct sock___78 *);
	int (*get_info)(const struct sock___78 *, struct sk_buff___92 *);
	size_t (*get_info_size)(const struct sock___78 *);
	void (*clone)(const struct request_sock___64 *, struct sock___78 *, const gfp_t);
	char name[16];
	struct module___266 *owner;
};

struct ip6_flowlabel___17;

struct ipv6_fl_socklist___17 {
	struct ipv6_fl_socklist___17 *next;
	struct ip6_flowlabel___17 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___60 {
	struct in6_addr mca_addr;
	struct inet6_dev___60 *idev;
	struct ifmcaddr6___60 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___17 {
	struct ip6_flowlabel___17 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___259 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___96 *fl_net;
};

struct net_protocol___6 {
	int (*early_demux)(struct sk_buff___92 *);
	int (*early_demux_handler)(struct sk_buff___92 *);
	int (*handler)(struct sk_buff___92 *);
	int (*err_handler)(struct sk_buff___92 *, u32);
	unsigned int no_policy: 1;
	unsigned int icmp_strict_tag_validation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct inet6_protocol {
	void (*early_demux)(struct sk_buff___92 *);
	void (*early_demux_handler)(struct sk_buff___92 *);
	int (*handler)(struct sk_buff___92 *);
	int (*err_handler)(struct sk_buff___92 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct dentry___283;

struct super_block___283;

struct module___267;

struct file_system_type___283 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___283 * (*mount)(struct file_system_type___283 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___283 *);
	struct module___267 *owner;
	struct file_system_type___283 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___283;

struct kiocb___283;

struct iov_iter___203;

struct poll_table_struct___204;

struct vm_area_struct___288;

struct inode___283;

struct file_lock___283;

struct page___288;

struct pipe_inode_info___124;

struct seq_file___258;

struct file_operations___284 {
	struct module___267 *owner;
	loff_t (*llseek)(struct file___283 *, loff_t, int);
	ssize_t (*read)(struct file___283 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___283 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___283 *, struct iov_iter___203 *);
	ssize_t (*write_iter)(struct kiocb___283 *, struct iov_iter___203 *);
	int (*iopoll)(struct kiocb___283 *, bool);
	int (*iterate)(struct file___283 *, struct dir_context *);
	int (*iterate_shared)(struct file___283 *, struct dir_context *);
	__poll_t (*poll)(struct file___283 *, struct poll_table_struct___204 *);
	long int (*unlocked_ioctl)(struct file___283 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___283 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___283 *, struct vm_area_struct___288 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___283 *, struct file___283 *);
	int (*flush)(struct file___283 *, fl_owner_t);
	int (*release)(struct inode___283 *, struct file___283 *);
	int (*fsync)(struct file___283 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___283 *, int);
	int (*lock)(struct file___283 *, int, struct file_lock___283 *);
	ssize_t (*sendpage)(struct file___283 *, struct page___288 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___283 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___283 *, long unsigned int);
	int (*flock)(struct file___283 *, int, struct file_lock___283 *);
	ssize_t (*splice_write)(struct pipe_inode_info___124 *, struct file___283 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___283 *, loff_t *, struct pipe_inode_info___124 *, size_t, unsigned int);
	int (*setlease)(struct file___283 *, long int, struct file_lock___283 **, void **);
	long int (*fallocate)(struct file___283 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___258 *, struct file___283 *);
	ssize_t (*copy_file_range)(struct file___283 *, loff_t, struct file___283 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___283 *, loff_t, struct file___283 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___283 *, loff_t, loff_t, int);
};

struct vmacache___288 {
	u64 seqnum;
	struct vm_area_struct___288 *vmas[4];
};

struct page_frag___288 {
	struct page___288 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___289;

struct pid___260;

struct nsproxy___269;

struct signal_struct___284;

struct bio_list___174;

struct backing_dev_info___160;

struct io_context___174;

struct css_set___210;

struct mem_cgroup___148;

struct request_queue___174;

struct vm_struct___266;

struct task_struct___290 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___290 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___289 *mm;
	struct mm_struct___289 *active_mm;
	struct vmacache___288 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___290 *real_parent;
	struct task_struct___290 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___290 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___260 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___269 *nsproxy;
	struct signal_struct___284 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___290 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___174 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___160 *backing_dev_info;
	struct io_context___174 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___210 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___124 *splice_pipe;
	struct page_frag___288 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___148 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___148 *active_memcg;
	struct request_queue___174 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___290 *oom_reaper_list;
	struct vm_struct___266 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___271;

struct kobj_type___271;

struct kernfs_node___271;

struct kobject___271 {
	const char *name;
	struct list_head entry;
	struct kobject___271 *parent;
	struct kset___271 *kset;
	struct kobj_type___271 *ktype;
	struct kernfs_node___271 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___268 {
	struct kobject___271 kobj;
	struct module___267 *mod;
	struct kobject___271 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___267 {
	struct module___267 *mod;
	struct latch_tree_node node;
};

struct module_layout___267 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___267 mtn;
};

struct module_attribute___267;

struct kernel_param___267;

struct module___267 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___268 mkobj;
	struct module_attribute___267 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___271 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___267 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___267 core_layout;
	struct module_layout___267 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___200 {
	struct page___288 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___283;

struct pipe_buffer___124;

struct pipe_inode_info___124 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___288 *tmp_page;
	struct fasync_struct___283 *fasync_readers;
	struct fasync_struct___283 *fasync_writers;
	struct pipe_buffer___124 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___203 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___200 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___124 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___81 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___203 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___283 *msg_iocb;
};

struct kiocb___283 {
	struct file___283 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___283 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct net_device___92;

struct sock___79;

struct sk_buff___93 {
	union {
		struct {
			struct sk_buff___93 *next;
			struct sk_buff___93 *prev;
			union {
				struct net_device___92 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___79 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___93 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct snmp_mib {
	const char *name;
	int entry;
};

struct inet_frags___97;

struct net___97;

struct fqdir___97 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___97 *f;
	struct net___97 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___97;

struct inet_frags___97 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___97 *, const void *);
	void (*destructor)(struct inet_frag_queue___97 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___52;

struct fib_rules_ops___79;

struct tcp_congestion_ops___26;

struct fib_notifier_ops___79;

struct netns_ipv4___97 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___52 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___79 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___79 *fibnl;
	struct sock___79 **icmp_sk;
	struct sock___79 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___79 **tcp_sk;
	struct fqdir___97 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___26 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___79 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___79 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___79 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___79;

struct neighbour___79;

struct dst_ops___97 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___97 *);
	struct dst_entry___79 * (*check)(struct dst_entry___79 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___79 *);
	unsigned int (*mtu)(const struct dst_entry___79 *);
	u32 * (*cow_metrics)(struct dst_entry___79 *, long unsigned int);
	void (*destroy)(struct dst_entry___79 *);
	void (*ifdown)(struct dst_entry___79 *, struct net_device___92 *, int);
	struct dst_entry___79 * (*negative_advice)(struct dst_entry___79 *);
	void (*link_failure)(struct sk_buff___93 *);
	void (*update_pmtu)(struct dst_entry___79 *, struct sock___79 *, struct sk_buff___93 *, u32, bool);
	void (*redirect)(struct dst_entry___79 *, struct sock___79 *, struct sk_buff___93 *);
	int (*local_out)(struct net___97 *, struct sock___79 *, struct sk_buff___93 *);
	struct neighbour___79 * (*neigh_lookup)(const struct dst_entry___79 *, struct sk_buff___93 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___79 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___97 {
	struct dst_ops___97 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___97 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___79 *fib6_rules_ops;
	struct sock___79 **icmp_sk;
	struct sock___79 *ndisc_sk;
	struct sock___79 *tcp_sk;
	struct sock___79 *igmp_sk;
	struct sock___79 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___79 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___79 *notifier_ops;
	struct fib_notifier_ops___79 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___97 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___97 *fqdir;
};

struct netns_sctp___79 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___79 *ctl_sock;
	struct sock___79 *udp4_sock;
	struct sock___79 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___92 {
	struct sk_buff___93 *next;
	struct sk_buff___93 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___86;

struct bpf_prog___86;

struct netns_bpf___86 {
	struct bpf_prog_array___86 *run_array[2];
	struct bpf_prog___86 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___97 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___79 *nlsk;
	struct sock___79 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___97 xfrm4_dst_ops;
	struct dst_ops___97 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___97 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___79 *rtnl;
	struct sock___79 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___92 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___97 ipv4;
	struct netns_ipv6___97 ipv6;
	struct netns_ieee802154_lowpan___97 ieee802154_lowpan;
	struct netns_sctp___79 sctp;
	struct netns_nf___16 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___92 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___86 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___97 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___79 *crypto_nlsk;
	struct sock___79 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___97 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___93 *fragments_tail;
	struct sk_buff___93 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___97 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___52 {
	struct ip_ra_chain___52 *next;
	struct sock___79 *sk;
	union {
		void (*destructor)(struct sock___79 *);
		struct sock___79 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___79;

struct fib_lookup_arg___79;

struct fib_rules_ops___79 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___79 *, struct flowi *, int, struct fib_lookup_arg___79 *);
	bool (*suppress)(struct fib_rule___79 *, int, struct fib_lookup_arg___79 *);
	int (*match)(struct fib_rule___79 *, struct flowi *, int);
	int (*configure)(struct fib_rule___79 *, struct sk_buff___93 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___79 *);
	int (*compare)(struct fib_rule___79 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___79 *, struct sk_buff___93 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___79 *);
	void (*flush_cache)(struct fib_rules_ops___79 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___267 *owner;
	struct net___97 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___97 *net;
} possible_net_t___92;

struct proto___79;

struct sock_common___79 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___79 *skc_prot;
	possible_net_t___92 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___79 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct cgroup___210;

struct sock_cgroup_data___79 {
	struct cgroup___210 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___79;

struct socket_wq___80;

struct socket___81;

struct sock_reuseport___28;

struct sock___79 {
	struct sock_common___79 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___92 sk_error_queue;
	struct sk_buff___93 *sk_rx_skb_cache;
	struct sk_buff_head___92 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___93 *head;
		struct sk_buff___93 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___79 *sk_filter;
	union {
		struct socket_wq___80 *sk_wq;
		struct socket_wq___80 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___79 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___79 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___93 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___93 *sk_tx_skb_cache;
	struct sk_buff_head___92 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___288 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___79 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___260 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___81 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___79 sk_cgrp_data;
	struct mem_cgroup___148 *sk_memcg;
	void (*sk_state_change)(struct sock___79 *);
	void (*sk_data_ready)(struct sock___79 *);
	void (*sk_write_space)(struct sock___79 *);
	void (*sk_error_report)(struct sock___79 *);
	int (*sk_backlog_rcv)(struct sock___79 *, struct sk_buff___93 *);
	struct sk_buff___93 * (*sk_validate_xmit_skb)(struct sock___79 *, struct net_device___92 *, struct sk_buff___93 *);
	void (*sk_destruct)(struct sock___79 *);
	struct sock_reuseport___28 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct tcp_congestion_ops___26 {
	u32 (*ssthresh)(struct sock___79 *);
	void (*cong_avoid)(struct sock___79 *, u32, u32);
	void (*set_state)(struct sock___79 *, u8);
	void (*cwnd_event)(struct sock___79 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___79 *, u32);
	void (*pkts_acked)(struct sock___79 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___79 *);
	void (*cong_control)(struct sock___79 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___79 *);
	u32 (*sndbuf_expand)(struct sock___79 *);
	size_t (*get_info)(struct sock___79 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___267 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___79 *);
	void (*release)(struct sock___79 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___79 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___97 *);
	int (*fib_dump)(struct net___97 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___267 *owner;
	struct callback_head rcu;
};

typedef struct page___288 *pgtable_t___288;

struct address_space___283;

struct page_pool___112;

struct dev_pagemap___278;

struct page___288 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___283 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___112 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___288 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___288 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___289 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___278 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___278;

struct vm_area_struct___288 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___288 *vm_next;
	struct vm_area_struct___288 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___289 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___278 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___283 *vm_file;
	struct file___283 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___288;

struct mm_struct___289 {
	struct {
		struct vm_area_struct___288 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___283 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___288 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___290 *owner;
		struct user_namespace___26 *user_ns;
		struct file___283 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___283;

struct address_space___283 {
	struct inode___283 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___283 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___264;

struct page_pool_params___112 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___264 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___112 {
	u32 count;
	struct page___288 *cache[128];
};

struct page_pool___112 {
	struct page_pool_params___112 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___288 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___112 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___278;

struct dev_pagemap___278 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___278 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___283;

struct path___283 {
	struct vfsmount___283 *mnt;
	struct dentry___283 *dentry;
};

struct fown_struct___260 {
	rwlock_t lock;
	struct pid___260 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___283 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___283 f_path;
	struct inode___283 *f_inode;
	const struct file_operations___284 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___260 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___283 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___278;

struct vm_operations_struct___278 {
	void (*open)(struct vm_area_struct___288 *);
	void (*close)(struct vm_area_struct___288 *);
	int (*may_split)(struct vm_area_struct___288 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___288 *);
	int (*mprotect)(struct vm_area_struct___288 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___278 *);
	vm_fault_t (*huge_fault)(struct vm_fault___278 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___278 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___288 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___278 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___278 *);
	int (*access)(struct vm_area_struct___288 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___288 *);
	int (*set_policy)(struct vm_area_struct___288 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___288 *, long unsigned int);
	struct page___288 * (*find_special_page)(struct vm_area_struct___288 *, long unsigned int);
};

struct core_thread___288 {
	struct task_struct___290 *task;
	struct core_thread___288 *next;
};

struct core_state___288 {
	atomic_t nr_threads;
	struct core_thread___288 dumper;
	struct completion startup;
};

struct vm_fault___278 {
	const struct {
		struct vm_area_struct___288 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___288 *cow_page;
	struct page___288 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___288 prealloc_pte;
};

struct pglist_data___156;

struct lruvec___156 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___156 *pgdat;
};

struct zone___156 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___156 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___156 {
	struct zone___156 *zone;
	int zone_idx;
};

struct zonelist___156 {
	struct zoneref___156 _zonerefs[321];
};

struct pglist_data___156 {
	struct zone___156 node_zones[5];
	struct zonelist___156 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___290 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___290 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___156 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct lwtunnel_state___55;

struct dst_entry___79 {
	struct net_device___92 *dev;
	struct dst_ops___97 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___93 *);
	int (*output)(struct net___97 *, struct sock___79 *, struct sk_buff___93 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___55 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___92(struct sk_buff___93 **);

struct wakeup_source___264;

struct dev_pm_info___264 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___264 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___264 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___264;

struct bus_type___264;

struct device_driver___264;

struct dev_pm_domain___264;

struct fwnode_handle___260;

struct class___264;

struct attribute_group___271;

struct device___264 {
	struct kobject___271 kobj;
	struct device___264 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___264 *type;
	struct bus_type___264 *bus;
	struct device_driver___264 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___264 power;
	struct dev_pm_domain___264 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___260 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___264 *class;
	const struct attribute_group___271 **groups;
	void (*release)(struct device___264 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___86 {
	struct bpf_prog___86 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___92;

struct net_device_ops___92;

struct l3mdev_ops___79;

struct ndisc_ops___61;

struct xfrmdev_ops___92;

struct header_ops___92;

struct in_device___19;

struct inet6_dev___61;

struct netdev_rx_queue___92;

struct mini_Qdisc___86;

struct netdev_queue___92;

struct Qdisc___86;

struct rtnl_link_ops___86;

struct dcbnl_rtnl_ops___92;

struct net_device___92 {
	char name[16];
	struct netdev_name_node___92 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___92 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___79 *l3mdev_ops;
	const struct ndisc_ops___61 *ndisc_ops;
	const struct xfrmdev_ops___92 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___92 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___271 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___19 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___61 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___92 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___86 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___92 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___86 *miniq_ingress;
	struct netdev_queue___92 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___92 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___86 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___86 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___92 = 0,
		NETREG_REGISTERED___92 = 1,
		NETREG_UNREGISTERING___92 = 2,
		NETREG_UNREGISTERED___92 = 3,
		NETREG_RELEASED___92 = 4,
		NETREG_DUMMY___92 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___92 = 0,
		RTNL_LINK_INITIALIZING___92 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___92 *);
	struct netpoll_info *npinfo;
	possible_net_t___92 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___264 dev;
	const struct attribute_group___271 *sysfs_groups[4];
	const struct attribute_group___271 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___86 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___92 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___86 xdp_state[3];
	long: 64;
};

struct neigh_table___79;

struct neigh_parms___79;

struct neigh_ops___79;

struct neighbour___79 {
	struct neighbour___79 *next;
	struct neigh_table___79 *tbl;
	struct neigh_parms___79 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___92 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___79 *, struct sk_buff___93 *);
	const struct neigh_ops___79 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___92 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___86 {
	struct bpf_prog___86 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___86 {
	struct callback_head rcu;
	struct bpf_prog_array_item___86 items[0];
};

struct bpf_prog_aux___95;

struct bpf_prog___86 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___95 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___283;

struct dentry___283 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___283 *d_parent;
	struct qstr d_name;
	struct inode___283 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___283 *d_op;
	struct super_block___283 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___283;

struct bdi_writeback___160;

struct inode___283 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___283 *i_op;
	struct super_block___283 *i_sb;
	struct address_space___283 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___160 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___284 *i_fop;
		void (*free_inode)(struct inode___283 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___283 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___124 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___283 {
	int (*d_revalidate)(struct dentry___283 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___283 *, unsigned int);
	int (*d_hash)(const struct dentry___283 *, struct qstr *);
	int (*d_compare)(const struct dentry___283 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___283 *);
	int (*d_init)(struct dentry___283 *);
	void (*d_release)(struct dentry___283 *);
	void (*d_prune)(struct dentry___283 *);
	void (*d_iput)(struct dentry___283 *, struct inode___283 *);
	char * (*d_dname)(struct dentry___283 *, char *, int);
	struct vfsmount___283 * (*d_automount)(struct path___283 *);
	int (*d_manage)(const struct path___283 *, bool);
	struct dentry___283 * (*d_real)(struct dentry___283 *, const struct inode___283 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___283;

struct mem_dqinfo___283 {
	struct quota_format_type___283 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___283;

struct quota_info___283 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___283 *files[3];
	struct mem_dqinfo___283 info[3];
	const struct quota_format_ops___283 *ops[3];
};

struct rcuwait___284 {
	struct task_struct___290 *task;
};

struct percpu_rw_semaphore___284 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___284 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___283 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___284 rw_sem[3];
};

struct shrink_control___148;

struct shrinker___148 {
	long unsigned int (*count_objects)(struct shrinker___148 *, struct shrink_control___148 *);
	long unsigned int (*scan_objects)(struct shrinker___148 *, struct shrink_control___148 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___283;

struct dquot_operations___283;

struct quotactl_ops___283;

struct block_device___177;

struct super_block___283 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___283 *s_type;
	const struct super_operations___283 *s_op;
	const struct dquot_operations___283 *dq_op;
	const struct quotactl_ops___283 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___283 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___177 *s_bdev;
	struct backing_dev_info___160 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___283 s_dquot;
	struct sb_writers___283 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___283 *s_d_op;
	int cleancache_poolid;
	struct shrinker___148 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___283 {
	struct dentry___283 *mnt_root;
	struct super_block___283 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct pid_namespace___260;

struct upid___260 {
	int nr;
	struct pid_namespace___260 *ns;
};

struct pid_namespace___260 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___290 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___260 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___260 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___260 numbers[1];
};

struct signal_struct___284 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___290 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___290 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___260 *pids[4];
	struct pid___260 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___289 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___210;

struct nsproxy___269 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___260 *pid_ns_for_children;
	struct net___97 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___210 *cgroup_ns;
};

struct bio___174;

struct bio_list___174 {
	struct bio___174 *head;
	struct bio___174 *tail;
};

struct cgroup_subsys_state___210;

struct bdi_writeback___160 {
	struct backing_dev_info___160 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___210 *memcg_css;
	struct cgroup_subsys_state___210 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___160 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___160 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___264 *dev;
	char dev_name[64];
	struct device___264 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___283 *debug_dir;
};

struct io_cq___174;

struct io_context___174 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___174 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___210 {
	struct cgroup_subsys_state___210 *subsys[14];
	refcount_t refcount;
	struct css_set___210 *dom_cset;
	struct cgroup___210 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___210 *mg_src_cgrp;
	struct cgroup___210 *mg_dst_cgrp;
	struct css_set___210 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___210;

struct cgroup_subsys_state___210 {
	struct cgroup___210 *cgroup;
	struct cgroup_subsys___210 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___210 *parent;
};

struct cgroup_file___210 {
	struct kernfs_node___271 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___148;

struct mem_cgroup_per_node___148;

struct mem_cgroup___148 {
	struct cgroup_subsys_state___210 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___210 events_file;
	struct cgroup_file___210 events_local_file;
	struct cgroup_file___210 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___148 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___290 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___148 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___174;

struct blk_integrity___174 {
	const struct blk_integrity_profile___174 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___174 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___174 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___174;

struct elevator_queue___174;

struct blk_mq_ops___169;

struct blk_mq_hw_ctx___169;

struct gendisk___177;

struct blkcg_gq___162;

struct blk_mq_tag_set___169;

struct request_queue___174 {
	struct request___174 *last_merge;
	struct elevator_queue___174 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___169 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___169 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___177 *disk;
	struct kobject___271 kobj;
	struct kobject___271 *mq_kobj;
	struct blk_integrity___174 integrity;
	struct device___264 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___162 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___169 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___174 bio_split;
	struct dentry___283 *debugfs_dir;
	struct dentry___283 *sched_debugfs_dir;
	struct dentry___283 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___266 {
	struct vm_struct___266 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___288 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___148 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___148 *memcg;
};

struct psi_group___210 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___290 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___86 {
	struct bpf_prog_array___86 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___86 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___210;

struct cgroup_rstat_cpu___210;

struct cgroup___210 {
	struct cgroup_subsys_state___210 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___271 *kn;
	struct cgroup_file___210 procs_file;
	struct cgroup_file___210 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___210 *subsys[14];
	struct cgroup_root___210 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___210 *dom_cgrp;
	struct cgroup___210 *old_dom_cgrp;
	struct cgroup_rstat_cpu___210 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___210 psi;
	struct cgroup_bpf___86 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___174 {
	struct request_queue___174 *q;
	struct io_context___174 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___283 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___283 *ia_file;
};

struct dquot___283 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___283 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___283 {
	int qf_fmt_id;
	const struct quota_format_ops___283 *qf_ops;
	struct module___267 *qf_owner;
	struct quota_format_type___283 *qf_next;
};

struct quota_format_ops___283 {
	int (*check_quota_file)(struct super_block___283 *, int);
	int (*read_file_info)(struct super_block___283 *, int);
	int (*write_file_info)(struct super_block___283 *, int);
	int (*free_file_info)(struct super_block___283 *, int);
	int (*read_dqblk)(struct dquot___283 *);
	int (*commit_dqblk)(struct dquot___283 *);
	int (*release_dqblk)(struct dquot___283 *);
	int (*get_next_id)(struct super_block___283 *, struct kqid *);
};

struct dquot_operations___283 {
	int (*write_dquot)(struct dquot___283 *);
	struct dquot___283 * (*alloc_dquot)(struct super_block___283 *, int);
	void (*destroy_dquot)(struct dquot___283 *);
	int (*acquire_dquot)(struct dquot___283 *);
	int (*release_dquot)(struct dquot___283 *);
	int (*mark_dirty)(struct dquot___283 *);
	int (*write_info)(struct super_block___283 *, int);
	qsize_t * (*get_reserved_space)(struct inode___283 *);
	int (*get_projid)(struct inode___283 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___283 *, qsize_t *);
	int (*get_next_id)(struct super_block___283 *, struct kqid *);
};

struct quotactl_ops___283 {
	int (*quota_on)(struct super_block___283 *, int, int, const struct path___283 *);
	int (*quota_off)(struct super_block___283 *, int);
	int (*quota_enable)(struct super_block___283 *, unsigned int);
	int (*quota_disable)(struct super_block___283 *, unsigned int);
	int (*quota_sync)(struct super_block___283 *, int);
	int (*set_info)(struct super_block___283 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___283 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___283 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___283 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___283 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___283 *, unsigned int);
};

struct writeback_control___160;

struct address_space_operations___283 {
	int (*writepage)(struct page___288 *, struct writeback_control___160 *);
	int (*readpage)(struct file___283 *, struct page___288 *);
	int (*writepages)(struct address_space___283 *, struct writeback_control___160 *);
	int (*set_page_dirty)(struct page___288 *);
	int (*readpages)(struct file___283 *, struct address_space___283 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___283 *, struct address_space___283 *, loff_t, unsigned int, unsigned int, struct page___288 **, void **);
	int (*write_end)(struct file___283 *, struct address_space___283 *, loff_t, unsigned int, unsigned int, struct page___288 *, void *);
	sector_t (*bmap)(struct address_space___283 *, sector_t);
	void (*invalidatepage)(struct page___288 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___288 *, gfp_t);
	void (*freepage)(struct page___288 *);
	ssize_t (*direct_IO)(struct kiocb___283 *, struct iov_iter___203 *);
	int (*migratepage)(struct address_space___283 *, struct page___288 *, struct page___288 *, enum migrate_mode);
	bool (*isolate_page)(struct page___288 *, isolate_mode_t);
	void (*putback_page)(struct page___288 *);
	int (*launder_page)(struct page___288 *);
	int (*is_partially_uptodate)(struct page___288 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___288 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___283 *, struct page___288 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___283 *, sector_t *);
	void (*swap_deactivate)(struct file___283 *);
};

struct writeback_control___160 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___160 *wb;
	struct inode___283 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___283 {
	struct dentry___283 * (*lookup)(struct inode___283 *, struct dentry___283 *, unsigned int);
	const char * (*get_link)(struct dentry___283 *, struct inode___283 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___283 *, int);
	struct posix_acl * (*get_acl)(struct inode___283 *, int, bool);
	int (*readlink)(struct dentry___283 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___283 *, struct dentry___283 *, umode_t, bool);
	int (*link)(struct dentry___283 *, struct inode___283 *, struct dentry___283 *);
	int (*unlink)(struct inode___283 *, struct dentry___283 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___283 *, struct dentry___283 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___283 *, struct dentry___283 *, umode_t);
	int (*rmdir)(struct inode___283 *, struct dentry___283 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___283 *, struct dentry___283 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___283 *, struct dentry___283 *, struct inode___283 *, struct dentry___283 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___283 *, struct iattr___283 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___283 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___283 *, char *, size_t);
	int (*fiemap)(struct inode___283 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___283 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___283 *, struct dentry___283 *, struct file___283 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___283 *, struct dentry___283 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___283 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___283 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___283 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___283 {
	void (*fl_copy_lock)(struct file_lock___283 *, struct file_lock___283 *);
	void (*fl_release_private)(struct file_lock___283 *);
};

struct lock_manager_operations___283;

struct file_lock___283 {
	struct file_lock___283 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___283 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___283 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___283 *fl_ops;
	const struct lock_manager_operations___283 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___283 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___283 *);
	int (*lm_grant)(struct file_lock___283 *, int);
	bool (*lm_break)(struct file_lock___283 *);
	int (*lm_change)(struct file_lock___283 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___283 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___283 *);
};

struct fasync_struct___283 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___283 *fa_next;
	struct file___283 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___283 {
	struct inode___283 * (*alloc_inode)(struct super_block___283 *);
	void (*destroy_inode)(struct inode___283 *);
	void (*free_inode)(struct inode___283 *);
	void (*dirty_inode)(struct inode___283 *, int);
	int (*write_inode)(struct inode___283 *, struct writeback_control___160 *);
	int (*drop_inode)(struct inode___283 *);
	void (*evict_inode)(struct inode___283 *);
	void (*put_super)(struct super_block___283 *);
	int (*sync_fs)(struct super_block___283 *, int);
	int (*freeze_super)(struct super_block___283 *);
	int (*freeze_fs)(struct super_block___283 *);
	int (*thaw_super)(struct super_block___283 *);
	int (*unfreeze_fs)(struct super_block___283 *);
	int (*statfs)(struct dentry___283 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___283 *, int *, char *);
	void (*umount_begin)(struct super_block___283 *);
	int (*show_options)(struct seq_file___258 *, struct dentry___283 *);
	int (*show_devname)(struct seq_file___258 *, struct dentry___283 *);
	int (*show_path)(struct seq_file___258 *, struct dentry___283 *);
	int (*show_stats)(struct seq_file___258 *, struct dentry___283 *);
	ssize_t (*quota_read)(struct super_block___283 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___283 *, int, const char *, size_t, loff_t);
	struct dquot___283 ** (*get_dquots)(struct inode___283 *);
	long int (*nr_cached_objects)(struct super_block___283 *, struct shrink_control___148 *);
	long int (*free_cached_objects)(struct super_block___283 *, struct shrink_control___148 *);
	struct file___283 * (*real_loop)(struct file___283 *);
};

struct block_device___177 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___283 *bd_inode;
	struct super_block___283 *bd_super;
	void *bd_claiming;
	struct device___264 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___271 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___177 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___283 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___212)(struct file___283 *, wait_queue_head_t *, struct poll_table_struct___204 *);

struct poll_table_struct___204 {
	poll_queue_proc___212 _qproc;
	__poll_t _key;
};

struct seq_operations___258;

struct seq_file___258 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___258 *op;
	int poll_event;
	const struct file___283 *file;
	void *private;
};

typedef void bio_end_io_t___174(struct bio___174 *);

struct bio_integrity_payload___174;

struct bio___174 {
	struct bio___174 *bi_next;
	struct block_device___177 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___174 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___162 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___174 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___200 *bi_io_vec;
	struct bio_set___174 *bi_pool;
	struct bio_vec___200 bi_inline_vecs[0];
};

struct dev_pagemap_ops___278 {
	void (*page_free)(struct page___288 *);
	void (*kill)(struct dev_pagemap___278 *);
	void (*cleanup)(struct dev_pagemap___278 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___278 *);
};

struct fwnode_operations___260;

struct fwnode_handle___260 {
	struct fwnode_handle___260 *secondary;
	const struct fwnode_operations___260 *ops;
	struct device___264 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___260;

struct fwnode_endpoint___260;

struct fwnode_operations___260 {
	struct fwnode_handle___260 * (*get)(struct fwnode_handle___260 *);
	void (*put)(struct fwnode_handle___260 *);
	bool (*device_is_available)(const struct fwnode_handle___260 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___260 *, const struct device___264 *);
	bool (*property_present)(const struct fwnode_handle___260 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___260 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___260 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___260 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*get_parent)(const struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*get_next_child_node)(const struct fwnode_handle___260 *, struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*get_named_child_node)(const struct fwnode_handle___260 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___260 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___260 *);
	struct fwnode_handle___260 * (*graph_get_next_endpoint)(const struct fwnode_handle___260 *, struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*graph_get_remote_endpoint)(const struct fwnode_handle___260 *);
	struct fwnode_handle___260 * (*graph_get_port_parent)(struct fwnode_handle___260 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___260 *, struct fwnode_endpoint___260 *);
	int (*add_links)(struct fwnode_handle___260 *);
};

struct fwnode_endpoint___260 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___260 *local_fwnode;
};

struct fwnode_reference_args___260 {
	struct fwnode_handle___260 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___271;

struct kernfs_elem_dir___271 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___271 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___271;

struct kernfs_root___271 {
	struct kernfs_node___271 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___271 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___271 {
	struct kernfs_node___271 *target_kn;
};

struct kernfs_ops___271;

struct kernfs_elem_attr___271 {
	const struct kernfs_ops___271 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___271 *notify_next;
};

struct kernfs_node___271 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___271 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___271 dir;
		struct kernfs_elem_symlink___271 symlink;
		struct kernfs_elem_attr___271 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___271;

struct kernfs_ops___271 {
	int (*open)(struct kernfs_open_file___271 *);
	void (*release)(struct kernfs_open_file___271 *);
	int (*seq_show)(struct seq_file___258 *, void *);
	void * (*seq_start)(struct seq_file___258 *, loff_t *);
	void * (*seq_next)(struct seq_file___258 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___258 *, void *);
	ssize_t (*read)(struct kernfs_open_file___271 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___271 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___271 *, struct poll_table_struct___204 *);
	int (*mmap)(struct kernfs_open_file___271 *, struct vm_area_struct___288 *);
};

struct kernfs_syscall_ops___271 {
	int (*show_options)(struct seq_file___258 *, struct kernfs_root___271 *);
	int (*mkdir)(struct kernfs_node___271 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___271 *);
	int (*rename)(struct kernfs_node___271 *, struct kernfs_node___271 *, const char *);
	int (*show_path)(struct seq_file___258 *, struct kernfs_node___271 *, struct kernfs_root___271 *);
};

struct kernfs_open_file___271 {
	struct kernfs_node___271 *kn;
	struct file___283 *file;
	struct seq_file___258 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___278 *vm_ops;
};

struct kobj_ns_type_operations___79 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___79 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___271;

struct attribute_group___271 {
	const char *name;
	umode_t (*is_visible)(struct kobject___271 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___271 *, struct bin_attribute___271 *, int);
	struct attribute **attrs;
	struct bin_attribute___271 **bin_attrs;
};

struct bin_attribute___271 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___283 * (*f_mapping)();
	ssize_t (*read)(struct file___283 *, struct kobject___271 *, struct bin_attribute___271 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___283 *, struct kobject___271 *, struct bin_attribute___271 *, char *, loff_t, size_t);
	int (*mmap)(struct file___283 *, struct kobject___271 *, struct bin_attribute___271 *, struct vm_area_struct___288 *);
};

struct sysfs_ops___271 {
	ssize_t (*show)(struct kobject___271 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___271 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___271;

struct kset___271 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___271 kobj;
	const struct kset_uevent_ops___271 *uevent_ops;
};

struct kobj_type___271 {
	void (*release)(struct kobject___271 *);
	const struct sysfs_ops___271 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___271 **default_groups;
	const struct kobj_ns_type_operations___79 * (*child_ns_type)(struct kobject___271 *);
	const void * (*namespace)(struct kobject___271 *);
	void (*get_ownership)(struct kobject___271 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___271 {
	int (* const filter)(struct kset___271 *, struct kobject___271 *);
	const char * (* const name)(struct kset___271 *, struct kobject___271 *);
	int (* const uevent)(struct kset___271 *, struct kobject___271 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___267 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___267 *);
	int (*get)(char *, const struct kernel_param___267 *);
	void (*free)(void *);
};

struct kparam_array___267;

struct kernel_param___267 {
	const char *name;
	struct module___267 *mod;
	const struct kernel_param_ops___267 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___267 *arr;
	};
};

struct kparam_array___267 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___267 *ops;
	void *elem;
};

struct module_attribute___267 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___267 *, struct module_kobject___268 *, char *);
	ssize_t (*store)(struct module_attribute___267 *, struct module_kobject___268 *, const char *, size_t);
	void (*setup)(struct module___267 *, const char *);
	int (*test)(struct module___267 *);
	void (*free)(struct module___267 *);
};

struct cgroup_namespace___210 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___210 *root_cset;
};

struct socket_wq___80 {
	wait_queue_head_t wait;
	struct fasync_struct___283 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___80;

struct socket___81 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___283 *file;
	struct sock___79 *sk;
	const struct proto_ops___80 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___80 wq;
};

typedef int (*sk_read_actor_t___79)(read_descriptor_t *, struct sk_buff___93 *, unsigned int, size_t);

struct proto_ops___80 {
	int family;
	struct module___267 *owner;
	int (*release)(struct socket___81 *);
	int (*bind)(struct socket___81 *, struct sockaddr *, int);
	int (*connect)(struct socket___81 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___81 *, struct socket___81 *);
	int (*accept)(struct socket___81 *, struct socket___81 *, int, bool);
	int (*getname)(struct socket___81 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___283 *, struct socket___81 *, struct poll_table_struct___204 *);
	int (*ioctl)(struct socket___81 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___81 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___81 *, void *, bool, bool);
	int (*listen)(struct socket___81 *, int);
	int (*shutdown)(struct socket___81 *, int);
	int (*setsockopt)(struct socket___81 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___81 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___258 *, struct socket___81 *);
	int (*sendmsg)(struct socket___81 *, struct msghdr___81 *, size_t);
	int (*recvmsg)(struct socket___81 *, struct msghdr___81 *, size_t, int);
	int (*mmap)(struct file___283 *, struct socket___81 *, struct vm_area_struct___288 *);
	ssize_t (*sendpage)(struct socket___81 *, struct page___288 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___81 *, loff_t *, struct pipe_inode_info___124 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___79 *, int);
	int (*peek_len)(struct socket___81 *);
	int (*read_sock)(struct sock___79 *, read_descriptor_t *, sk_read_actor_t___79);
	int (*sendpage_locked)(struct sock___79 *, struct page___288 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___79 *, struct msghdr___81 *, size_t);
	int (*set_rcvlowat)(struct sock___79 *, int);
};

struct dev_pm_ops___264 {
	int (*prepare)(struct device___264 *);
	void (*complete)(struct device___264 *);
	int (*suspend)(struct device___264 *);
	int (*resume)(struct device___264 *);
	int (*freeze)(struct device___264 *);
	int (*thaw)(struct device___264 *);
	int (*poweroff)(struct device___264 *);
	int (*restore)(struct device___264 *);
	int (*suspend_late)(struct device___264 *);
	int (*resume_early)(struct device___264 *);
	int (*freeze_late)(struct device___264 *);
	int (*thaw_early)(struct device___264 *);
	int (*poweroff_late)(struct device___264 *);
	int (*restore_early)(struct device___264 *);
	int (*suspend_noirq)(struct device___264 *);
	int (*resume_noirq)(struct device___264 *);
	int (*freeze_noirq)(struct device___264 *);
	int (*thaw_noirq)(struct device___264 *);
	int (*poweroff_noirq)(struct device___264 *);
	int (*restore_noirq)(struct device___264 *);
	int (*runtime_suspend)(struct device___264 *);
	int (*runtime_resume)(struct device___264 *);
	int (*runtime_idle)(struct device___264 *);
};

struct wakeup_source___264 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___264 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___264 {
	struct dev_pm_ops___264 ops;
	int (*start)(struct device___264 *);
	void (*detach)(struct device___264 *, bool);
	int (*activate)(struct device___264 *);
	void (*sync)(struct device___264 *);
	void (*dismiss)(struct device___264 *);
};

struct bus_type___264 {
	const char *name;
	const char *dev_name;
	struct device___264 *dev_root;
	const struct attribute_group___271 **bus_groups;
	const struct attribute_group___271 **dev_groups;
	const struct attribute_group___271 **drv_groups;
	int (*match)(struct device___264 *, struct device_driver___264 *);
	int (*uevent)(struct device___264 *, struct kobj_uevent_env *);
	int (*probe)(struct device___264 *);
	void (*sync_state)(struct device___264 *);
	void (*remove)(struct device___264 *);
	void (*shutdown)(struct device___264 *);
	int (*online)(struct device___264 *);
	int (*offline)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	int (*num_vf)(struct device___264 *);
	int (*dma_configure)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___264 {
	const char *name;
	struct bus_type___264 *bus;
	struct module___267 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___264 *);
	void (*sync_state)(struct device___264 *);
	int (*remove)(struct device___264 *);
	void (*shutdown)(struct device___264 *);
	int (*suspend)(struct device___264 *, pm_message_t);
	int (*resume)(struct device___264 *);
	const struct attribute_group___271 **groups;
	const struct attribute_group___271 **dev_groups;
	const struct dev_pm_ops___264 *pm;
	void (*coredump)(struct device___264 *);
	struct driver_private *p;
};

struct device_type___264 {
	const char *name;
	const struct attribute_group___271 **groups;
	int (*uevent)(struct device___264 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___264 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___264 *);
	const struct dev_pm_ops___264 *pm;
};

struct class___264 {
	const char *name;
	struct module___267 *owner;
	const struct attribute_group___271 **class_groups;
	const struct attribute_group___271 **dev_groups;
	struct kobject___271 *dev_kobj;
	int (*dev_uevent)(struct device___264 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___264 *, umode_t *);
	void (*class_release)(struct class___264 *);
	void (*dev_release)(struct device___264 *);
	int (*shutdown_pre)(struct device___264 *);
	const struct kobj_ns_type_operations___79 *ns_type;
	const void * (*namespace)(struct device___264 *);
	void (*get_ownership)(struct device___264 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___264 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___124;

struct pipe_buffer___124 {
	struct page___288 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___124 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___124 {
	int (*confirm)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
	void (*release)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
	bool (*try_steal)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
	bool (*get)(struct pipe_inode_info___124 *, struct pipe_buffer___124 *);
};

struct seq_operations___258 {
	void * (*start)(struct seq_file___258 *, loff_t *);
	void (*stop)(struct seq_file___258 *, void *);
	void * (*next)(struct seq_file___258 *, void *, loff_t *);
	int (*show)(struct seq_file___258 *, void *);
};

struct pernet_operations___31 {
	struct list_head list;
	int (*init)(struct net___97 *);
	void (*pre_exit)(struct net___97 *);
	void (*exit)(struct net___97 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___92 {
	int (*ieee_getets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___92 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___92 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___92 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___92 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___92 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___92 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___92 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___92 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___92 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___92 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___92 *);
	u8 (*setstate)(struct net_device___92 *, u8);
	void (*getpermhwaddr)(struct net_device___92 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___92 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___92 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___92 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___92 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___92 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___92 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___92 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___92 *, int, u8 *);
	void (*setpfccfg)(struct net_device___92 *, int, u8);
	void (*getpfccfg)(struct net_device___92 *, int, u8 *);
	u8 (*setall)(struct net_device___92 *);
	u8 (*getcap)(struct net_device___92 *, int, u8 *);
	int (*getnumtcs)(struct net_device___92 *, int, u8 *);
	int (*setnumtcs)(struct net_device___92 *, int, u8);
	u8 (*getpfcstate)(struct net_device___92 *);
	void (*setpfcstate)(struct net_device___92 *, u8);
	void (*getbcncfg)(struct net_device___92 *, int, u32 *);
	void (*setbcncfg)(struct net_device___92 *, int, u32);
	void (*getbcnrp)(struct net_device___92 *, int, u8 *);
	void (*setbcnrp)(struct net_device___92 *, int, u8);
	int (*setapp)(struct net_device___92 *, u8, u16, u8);
	int (*getapp)(struct net_device___92 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___92 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___92 *, int, u8);
	u8 (*getdcbx)(struct net_device___92 *);
	u8 (*setdcbx)(struct net_device___92 *, u8);
	int (*peer_getappinfo)(struct net_device___92 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___92 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___92 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___92 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___92 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___92 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___95;

typedef int (*bpf_iter_init_seq_priv_t___94)(void *, struct bpf_iter_aux_info___95 *);

struct bpf_map___95;

struct bpf_iter_aux_info___95 {
	struct bpf_map___95 *map;
};

struct bpf_iter_seq_info___94 {
	const struct seq_operations___258 *seq_ops;
	bpf_iter_init_seq_priv_t___94 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___94 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___95 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___95 *, struct file___283 *);
	void (*map_free)(struct bpf_map___95 *);
	int (*map_get_next_key)(struct bpf_map___95 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___95 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___95 *, void *);
	int (*map_lookup_batch)(struct bpf_map___95 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___95 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___95 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___95 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___95 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___95 *, void *);
	int (*map_update_elem)(struct bpf_map___95 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___95 *, void *);
	int (*map_push_elem)(struct bpf_map___95 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___95 *, void *);
	int (*map_peek_elem)(struct bpf_map___95 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___95 *, struct file___283 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___95 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___95 *, void *, struct seq_file___258 *);
	int (*map_check_btf)(const struct bpf_map___95 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___95 *, struct bpf_prog_aux___95 *);
	void (*map_poke_untrack)(struct bpf_map___95 *, struct bpf_prog_aux___95 *);
	void (*map_poke_run)(struct bpf_map___95 *, u32, struct bpf_prog___86 *, struct bpf_prog___86 *);
	int (*map_direct_value_addr)(const struct bpf_map___95 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___95 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___95 *, struct vm_area_struct___288 *);
	__poll_t (*map_poll)(struct bpf_map___95 *, struct file___283 *, struct poll_table_struct___204 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___95 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___95 *, const struct bpf_map___95 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___95 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___94 *iter_seq_info;
};

struct bpf_map___95 {
	const struct bpf_map_ops___94 *ops;
	struct bpf_map___95 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___148 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___94;

struct bpf_jit_poke_descriptor___94;

struct bpf_prog_ops___86;

struct btf_mod_pair___94;

struct bpf_prog_offload___92;

struct bpf_prog_aux___95 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___86 *dst_prog;
	struct bpf_trampoline___94 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___86 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___94 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___86 *ops;
	struct bpf_map___95 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___94 *used_btfs;
	struct bpf_prog___86 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___95 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___92 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___92;

struct bpf_map_dev_ops___92 {
	int (*map_get_next_key)(struct bpf_offloaded_map___92 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___92 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___92 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___92 *, void *);
};

struct bpf_offloaded_map___92 {
	struct bpf_map___95 map;
	struct net_device___92 *netdev;
	const struct bpf_map_dev_ops___92 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___86 {
	int (*test_run)(struct bpf_prog___86 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___92 {
	struct bpf_prog___86 *prog;
	struct net_device___92 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___94 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___86 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___267 *mod;
};

struct bpf_jit_poke_descriptor___94 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___95 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___94 {
	struct btf *btf;
	struct module___267 *module;
};

struct cftype___210;

struct cgroup_subsys___210 {
	struct cgroup_subsys_state___210 * (*css_alloc)(struct cgroup_subsys_state___210 *);
	int (*css_online)(struct cgroup_subsys_state___210 *);
	void (*css_offline)(struct cgroup_subsys_state___210 *);
	void (*css_released)(struct cgroup_subsys_state___210 *);
	void (*css_free)(struct cgroup_subsys_state___210 *);
	void (*css_reset)(struct cgroup_subsys_state___210 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___210 *, int);
	int (*css_extra_stat_show)(struct seq_file___258 *, struct cgroup_subsys_state___210 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___290 *, struct css_set___210 *);
	void (*cancel_fork)(struct task_struct___290 *, struct css_set___210 *);
	void (*fork)(struct task_struct___290 *);
	void (*exit)(struct task_struct___290 *);
	void (*release)(struct task_struct___290 *);
	void (*bind)(struct cgroup_subsys_state___210 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___210 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___210 *dfl_cftypes;
	struct cftype___210 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___210 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___210 *updated_children;
	struct cgroup___210 *updated_next;
};

struct cgroup_root___210 {
	struct kernfs_root___271 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___210 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___210 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___210 *ss;
	struct list_head node;
	struct kernfs_ops___271 *kf_ops;
	int (*open)(struct kernfs_open_file___271 *);
	void (*release)(struct kernfs_open_file___271 *);
	u64 (*read_u64)(struct cgroup_subsys_state___210 *, struct cftype___210 *);
	s64 (*read_s64)(struct cgroup_subsys_state___210 *, struct cftype___210 *);
	int (*seq_show)(struct seq_file___258 *, void *);
	void * (*seq_start)(struct seq_file___258 *, loff_t *);
	void * (*seq_next)(struct seq_file___258 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___258 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___210 *, struct cftype___210 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___210 *, struct cftype___210 *, s64);
	ssize_t (*write)(struct kernfs_open_file___271 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___271 *, struct poll_table_struct___204 *);
};

struct xdp_rxq_info___92 {
	struct net_device___92 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___92 {
	struct net_device___92 *dev;
};

struct xdp_buff___92 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___92 *rxq;
	struct xdp_txq_info___92 *txq;
	u32 frame_sz;
};

struct xdp_frame___92 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___92 *dev_rx;
};

struct netlink_callback___92 {
	struct sk_buff___93 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___93 *, struct netlink_callback___92 *);
	int (*done)(struct netlink_callback___92 *);
	void *data;
	struct module___267 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___92 {
	int (*create)(struct sk_buff___93 *, struct net_device___92 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___93 *, unsigned char *);
	int (*cache)(const struct neighbour___79 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___92 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___93 *);
};

struct netdev_queue___92 {
	struct net_device___92 *dev;
	struct Qdisc___86 *qdisc;
	struct Qdisc___86 *qdisc_sleeping;
	struct kobject___271 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___92 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___86 {
	struct sk_buff___93 *head;
	struct sk_buff___93 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___86;

struct Qdisc___86 {
	int (*enqueue)(struct sk_buff___93 *, struct Qdisc___86 *, struct sk_buff___93 **);
	struct sk_buff___93 * (*dequeue)(struct Qdisc___86 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___86 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___92 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___92 gso_skb;
	struct qdisc_skb_head___86 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___86 *next_sched;
	struct sk_buff_head___92 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___92 {
	struct xdp_rxq_info___92 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___271 kobj;
	struct net_device___92 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___92 {
	enum net_device_path_type type;
	const struct net_device___92 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___92 = 0,
				DEV_PATH_BR_VLAN_TAG___92 = 1,
				DEV_PATH_BR_VLAN_UNTAG___92 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___92 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___92 {
	const struct net_device___92 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___92 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___86 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___92 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___92 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___93 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___92 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___92 *dev;
	const char *name;
};

struct net_device_ops___92 {
	int (*ndo_init)(struct net_device___92 *);
	void (*ndo_uninit)(struct net_device___92 *);
	int (*ndo_open)(struct net_device___92 *);
	int (*ndo_stop)(struct net_device___92 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___93 *, struct net_device___92 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___93 *, struct net_device___92 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___92 *, struct sk_buff___93 *, struct net_device___92 *);
	void (*ndo_change_rx_flags)(struct net_device___92 *, int);
	void (*ndo_set_rx_mode)(struct net_device___92 *);
	int (*ndo_set_mac_address)(struct net_device___92 *, void *);
	int (*ndo_validate_addr)(struct net_device___92 *);
	int (*ndo_do_ioctl)(struct net_device___92 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___92 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___92 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___92 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___92 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___92 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___92 *, int);
	int (*ndo_neigh_setup)(struct net_device___92 *, struct neigh_parms___79 *);
	void (*ndo_tx_timeout)(struct net_device___92 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___92 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___92 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___92 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___92 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___92 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___92 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___92 *);
	int (*ndo_netpoll_setup)(struct net_device___92 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___92 *);
	int (*ndo_set_vf_mac)(struct net_device___92 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___92 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___92 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___92 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___92 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___92 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___92 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___92 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___92 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___92 *, int, struct sk_buff___93 *);
	int (*ndo_get_vf_guid)(struct net_device___92 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___92 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___92 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___92 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___92 *);
	int (*ndo_fcoe_disable)(struct net_device___92 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___92 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___92 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___92 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___92 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___92 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___92 *, const struct sk_buff___93 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___92 *, struct net_device___92 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___92 *, struct net_device___92 *);
	struct net_device___92 * (*ndo_get_xmit_slave)(struct net_device___92 *, struct sk_buff___93 *, bool);
	struct net_device___92 * (*ndo_sk_get_lower_dev)(struct net_device___92 *, struct sock___79 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___92 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___92 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___92 *, struct neighbour___79 *);
	void (*ndo_neigh_destroy)(struct net_device___92 *, struct neighbour___79 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___93 *, struct netlink_callback___92 *, struct net_device___92 *, struct net_device___92 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___93 *, struct nlattr **, struct net_device___92 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___92 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___93 *, u32, u32, struct net_device___92 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___92 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___92 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___92 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___92 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___92 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___92 *, struct net_device___92 *);
	void (*ndo_dfwd_del_station)(struct net_device___92 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___92 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___92 *);
	int (*ndo_change_proto_down)(struct net_device___92 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___92 *, struct sk_buff___93 *);
	void (*ndo_set_rx_headroom)(struct net_device___92 *, int);
	int (*ndo_bpf)(struct net_device___92 *, struct netdev_bpf___92 *);
	int (*ndo_xdp_xmit)(struct net_device___92 *, int, struct xdp_frame___92 **, u32);
	struct net_device___92 * (*ndo_xdp_get_xmit_slave)(struct net_device___92 *, struct xdp_buff___92 *);
	int (*ndo_xsk_wakeup)(struct net_device___92 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___92 *);
	int (*ndo_tunnel_ctl)(struct net_device___92 *, struct ip_tunnel_parm *, int);
	struct net_device___92 * (*ndo_get_peer_dev)(struct net_device___92 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___92 *, struct net_device_path___92 *);
};

struct neigh_parms___79 {
	possible_net_t___92 net;
	struct net_device___92 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___79 *);
	struct neigh_table___79 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___79 {
	u32 (*l3mdev_fib_table)(const struct net_device___92 *);
	struct sk_buff___93 * (*l3mdev_l3_rcv)(struct net_device___92 *, struct sk_buff___93 *, u16);
	struct sk_buff___93 * (*l3mdev_l3_out)(struct net_device___92 *, struct sock___79 *, struct sk_buff___93 *, u16);
	struct dst_entry___79 * (*l3mdev_link_scope_lookup)(const struct net_device___92 *, struct flowi6 *);
};

struct ndisc_ops___61 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___92 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___92 *, struct neighbour___79 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___92 *, u8, struct neighbour___79 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___92 *, struct sk_buff___93 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___97 *, struct net_device___92 *, const struct prefix_info *, struct inet6_dev___61 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___19;

struct in_device___19 {
	struct net_device___92 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___19 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___79 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___61;

struct inet6_dev___61 {
	struct net_device___92 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___61 *mc_list;
	struct ifmcaddr6___61 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___92 mc_query_queue;
	struct sk_buff_head___92 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___24 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___79 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___86;

struct tcf_block___86;

struct mini_Qdisc___86 {
	struct tcf_proto___86 *filter_list;
	struct tcf_block___86 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___86 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___92 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___92 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___97 *, struct net_device___92 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___92 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___92 *, struct list_head *);
	size_t (*get_size)(const struct net_device___92 *);
	int (*fill_info)(struct sk_buff___93 *, const struct net_device___92 *);
	size_t (*get_xstats_size)(const struct net_device___92 *);
	int (*fill_xstats)(struct sk_buff___93 *, const struct net_device___92 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___92 *, struct net_device___92 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___92 *, const struct net_device___92 *);
	int (*fill_slave_info)(struct sk_buff___93 *, const struct net_device___92 *, const struct net_device___92 *);
	struct net___97 * (*get_link_net)(const struct net_device___92 *);
	size_t (*get_linkxstats_size)(const struct net_device___92 *, int);
	int (*fill_linkxstats)(struct sk_buff___93 *, const struct net_device___92 *, int *, int);
};

struct block_device_operations___174;

struct gendisk___177 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___177 *part0;
	const struct block_device_operations___174 *fops;
	struct request_queue___174 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___160 *bdi;
	struct kobject___271 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___271 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___174 {
	struct bio___174 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___200 *bip_vec;
	struct bio_vec___200 bip_inline_vecs[0];
};

struct blkcg___162;

struct blkg_policy_data___162;

struct blkcg_gq___162 {
	struct request_queue___174 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___162 *blkcg;
	struct blkcg_gq___162 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___162 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___174 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___174(struct request___174 *);

typedef void integrity_complete_fn___174(struct request___174 *, unsigned int);

struct blk_integrity_profile___174 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___174 *prepare_fn;
	integrity_complete_fn___174 *complete_fn;
	const char *name;
};

struct block_device_operations___174 {
	blk_qc_t (*submit_bio)(struct bio___174 *);
	int (*open)(struct block_device___177 *, fmode_t);
	void (*release)(struct gendisk___177 *, fmode_t);
	int (*rw_page)(struct block_device___177 *, sector_t, struct page___288 *, unsigned int);
	int (*ioctl)(struct block_device___177 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___177 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___177 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___177 *);
	int (*getgeo)(struct block_device___177 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___177 *, bool);
	void (*swap_slot_free_notify)(struct block_device___177 *, long unsigned int);
	int (*report_zones)(struct gendisk___177 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___177 *, umode_t *);
	struct module___267 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___177 *, sector_t *);
};

typedef void rq_end_io_fn___174(struct request___174 *, blk_status_t);

struct request___174 {
	struct request_queue___174 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___169 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___174 *bio;
	struct bio___174 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___200 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___174 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___174 *saved_end_io;
		} flush;
	};
	struct gendisk___177 *rq_disk;
	struct block_device___177 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___174 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___169 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___174 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___271 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___283 *debugfs_dir;
	struct dentry___283 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___174;

struct elevator_mq_ops___174 {
	int (*init_sched)(struct request_queue___174 *, struct elevator_type___174 *);
	void (*exit_sched)(struct elevator_queue___174 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___169 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___169 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___169 *);
	bool (*allow_merge)(struct request_queue___174 *, struct request___174 *, struct bio___174 *);
	bool (*bio_merge)(struct request_queue___174 *, struct bio___174 *, unsigned int);
	int (*request_merge)(struct request_queue___174 *, struct request___174 **, struct bio___174 *);
	void (*request_merged)(struct request_queue___174 *, struct request___174 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___174 *, struct request___174 *, struct request___174 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___174 *);
	void (*finish_request)(struct request___174 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___169 *, struct list_head *, bool);
	struct request___174 * (*dispatch_request)(struct blk_mq_hw_ctx___169 *);
	bool (*has_work)(struct blk_mq_hw_ctx___169 *);
	void (*completed_request)(struct request___174 *, u64);
	void (*requeue_request)(struct request___174 *);
	struct request___174 * (*former_request)(struct request_queue___174 *, struct request___174 *);
	struct request___174 * (*next_request)(struct request_queue___174 *, struct request___174 *);
	void (*init_icq)(struct io_cq___174 *);
	void (*exit_icq)(struct io_cq___174 *);
};

struct elv_fs_entry___174;

struct elevator_type___174 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___174 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___174 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___267 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___174 {
	struct elevator_type___174 *type;
	void *elevator_data;
	struct kobject___271 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___174 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___174 *, char *);
	ssize_t (*store)(struct elevator_queue___174 *, const char *, size_t);
};

struct blk_mq_queue_data___169;

struct blk_mq_ops___169 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___169 *, const struct blk_mq_queue_data___169 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___169 *);
	int (*get_budget)(struct request_queue___174 *);
	void (*put_budget)(struct request_queue___174 *, int);
	void (*set_rq_budget_token)(struct request___174 *, int);
	int (*get_rq_budget_token)(struct request___174 *);
	enum blk_eh_timer_return (*timeout)(struct request___174 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___169 *);
	void (*complete)(struct request___174 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___169 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___169 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___169 *, struct request___174 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___169 *, struct request___174 *, unsigned int);
	void (*initialize_rq_fn)(struct request___174 *);
	void (*cleanup_rq)(struct request___174 *);
	bool (*busy)(struct request_queue___174 *);
	int (*map_queues)(struct blk_mq_tag_set___169 *);
	void (*show_rq)(struct seq_file___258 *, struct request___174 *);
};

struct blk_mq_tag_set___169 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___169 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___169 {
	struct request___174 *rq;
	bool last;
};

struct blkcg_policy_data___162;

struct blkcg___162 {
	struct cgroup_subsys_state___210 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___162 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___162 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___162 {
	struct blkcg___162 *blkcg;
	int plid;
};

struct blkg_policy_data___162 {
	struct blkcg_gq___162 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___148 {
	struct mem_cgroup___148 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___148 {
	struct lruvec___156 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___148 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___148 *memcg;
};

struct obj_cgroup___148 {
	struct percpu_ref refcnt;
	struct mem_cgroup___148 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___86 {
	spinlock_t *lock;
	struct sk_buff___93 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___86;

struct Qdisc_ops___86 {
	struct Qdisc_ops___86 *next;
	const struct Qdisc_class_ops___86 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___93 *, struct Qdisc___86 *, struct sk_buff___93 **);
	struct sk_buff___93 * (*dequeue)(struct Qdisc___86 *);
	struct sk_buff___93 * (*peek)(struct Qdisc___86 *);
	int (*init)(struct Qdisc___86 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___86 *);
	void (*destroy)(struct Qdisc___86 *);
	int (*change)(struct Qdisc___86 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___86 *);
	int (*change_tx_queue_len)(struct Qdisc___86 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___86 *, unsigned int);
	int (*dump)(struct Qdisc___86 *, struct sk_buff___93 *);
	int (*dump_stats)(struct Qdisc___86 *, struct gnet_dump___86 *);
	void (*ingress_block_set)(struct Qdisc___86 *, u32);
	void (*egress_block_set)(struct Qdisc___86 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___86 *);
	u32 (*egress_block_get)(struct Qdisc___86 *);
	struct module___267 *owner;
};

struct Qdisc_class_ops___86 {
	unsigned int flags;
	struct netdev_queue___92 * (*select_queue)(struct Qdisc___86 *, struct tcmsg *);
	int (*graft)(struct Qdisc___86 *, long unsigned int, struct Qdisc___86 *, struct Qdisc___86 **, struct netlink_ext_ack *);
	struct Qdisc___86 * (*leaf)(struct Qdisc___86 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___86 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___86 *, u32);
	int (*change)(struct Qdisc___86 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___86 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___86 *, struct qdisc_walker *);
	struct tcf_block___86 * (*tcf_block)(struct Qdisc___86 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___86 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___86 *, long unsigned int);
	int (*dump)(struct Qdisc___86 *, long unsigned int, struct sk_buff___93 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___86 *, long unsigned int, struct gnet_dump___86 *);
};

struct tcf_chain___86;

struct tcf_block___86 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___97 *net;
	struct Qdisc___86 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___86 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___86;

struct tcf_proto_ops___86;

struct tcf_proto___86 {
	struct tcf_proto___86 *next;
	void *root;
	int (*classify)(struct sk_buff___93 *, const struct tcf_proto___86 *, struct tcf_result___86 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___86 *ops;
	struct tcf_chain___86 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___86 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___86 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___86 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___93 *, const struct tcf_proto___86 *, struct tcf_result___86 *);
	int (*init)(struct tcf_proto___86 *);
	void (*destroy)(struct tcf_proto___86 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___86 *, u32);
	void (*put)(struct tcf_proto___86 *, void *);
	int (*change)(struct net___97 *, struct sk_buff___93 *, struct tcf_proto___86 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___86 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___86 *);
	void (*walk)(struct tcf_proto___86 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___86 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___86 *, void *);
	void (*hw_del)(struct tcf_proto___86 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___97 *, struct tcf_chain___86 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___97 *, struct tcf_proto___86 *, void *, struct sk_buff___93 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___97 *, struct tcf_proto___86 *, void *, struct sk_buff___93 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___93 *, struct net___97 *, void *);
	struct module___267 *owner;
	int flags;
};

struct tcf_chain___86 {
	struct mutex filter_chain_lock;
	struct tcf_proto___86 *filter_chain;
	struct list_head list;
	struct tcf_block___86 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___86 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___79 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___86 *prog;
};

struct pneigh_entry___79;

struct neigh_hash_table___79;

struct neigh_table___79 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___92 *, __u32 *);
	bool (*key_eq)(const struct neighbour___79 *, const void *);
	int (*constructor)(struct neighbour___79 *);
	int (*pconstructor)(struct pneigh_entry___79 *);
	void (*pdestructor)(struct pneigh_entry___79 *);
	void (*proxy_redo)(struct sk_buff___93 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___92 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___79 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___92 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___79 *nht;
	struct pneigh_entry___79 **phash_buckets;
};

struct neigh_ops___79 {
	int family;
	void (*solicit)(struct neighbour___79 *, struct sk_buff___93 *);
	void (*error_report)(struct neighbour___79 *, struct sk_buff___93 *);
	int (*output)(struct neighbour___79 *, struct sk_buff___93 *);
	int (*connected_output)(struct neighbour___79 *, struct sk_buff___93 *);
};

struct pneigh_entry___79 {
	struct pneigh_entry___79 *next;
	possible_net_t___92 net;
	struct net_device___92 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___79 {
	struct neighbour___79 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___55 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___97 *, struct sock___79 *, struct sk_buff___93 *);
	int (*orig_input)(struct sk_buff___93 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___79 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___79 *ctarget;
	struct net___97 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___79 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___79 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___64;

struct timewait_sock_ops___63;

struct proto___79 {
	void (*close)(struct sock___79 *, long int);
	int (*pre_connect)(struct sock___79 *, struct sockaddr *, int);
	int (*connect)(struct sock___79 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___79 *, int);
	struct sock___79 * (*accept)(struct sock___79 *, int, int *, bool);
	int (*ioctl)(struct sock___79 *, int, long unsigned int);
	int (*init)(struct sock___79 *);
	void (*destroy)(struct sock___79 *);
	void (*shutdown)(struct sock___79 *, int);
	int (*setsockopt)(struct sock___79 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___79 *, int, int, char *, int *);
	void (*keepalive)(struct sock___79 *, int);
	int (*compat_ioctl)(struct sock___79 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___79 *, struct msghdr___81 *, size_t);
	int (*recvmsg)(struct sock___79 *, struct msghdr___81 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___79 *, struct page___288 *, int, size_t, int);
	int (*bind)(struct sock___79 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___79 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___79 *, struct sk_buff___93 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___79 *);
	int (*hash)(struct sock___79 *);
	void (*unhash)(struct sock___79 *);
	void (*rehash)(struct sock___79 *);
	int (*get_port)(struct sock___79 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___79 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___79 *, int);
	bool (*sock_is_readable)(struct sock___79 *);
	void (*enter_memory_pressure)(struct sock___79 *);
	void (*leave_memory_pressure)(struct sock___79 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___64 *rsk_prot;
	struct timewait_sock_ops___63 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___267 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___79 *, int);
};

struct sock_reuseport___28 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___86 *prog;
	struct sock___79 *socks[0];
};

struct request_sock___65;

struct request_sock_ops___64 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___79 *, struct request_sock___65 *);
	void (*send_ack)(const struct sock___79 *, struct sk_buff___93 *, struct request_sock___65 *);
	void (*send_reset)(const struct sock___79 *, struct sk_buff___93 *);
	void (*destructor)(struct request_sock___65 *);
	void (*syn_ack_timeout)(const struct request_sock___65 *);
};

struct timewait_sock_ops___63 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___79 *, struct sock___79 *, void *);
	void (*twsk_destructor)(struct sock___79 *);
};

struct request_sock___65 {
	struct sock_common___79 __req_common;
	struct request_sock___65 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___64 *rsk_ops;
	struct sock___79 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___61 {
	struct in6_addr mca_addr;
	struct inet6_dev___61 *idev;
	struct ifmcaddr6___61 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct in_ifaddr___19 {
	struct hlist_node hash;
	struct in_ifaddr___19 *ifa_next;
	struct in_device___19 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct fib4_rule {
	struct fib_rule___72 common;
	u8 dst_len;
	u8 src_len;
	u8 tos;
	__be32 src;
	__be32 srcmask;
	__be32 dst;
	__be32 dstmask;
	u32 tclassid;
};

struct dentry___284;

struct super_block___284;

struct module___268;

struct file_system_type___284 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___284 * (*mount)(struct file_system_type___284 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___284 *);
	struct module___268 *owner;
	struct file_system_type___284 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___284;

struct kiocb___284;

struct iov_iter___204;

struct poll_table_struct___205;

struct vm_area_struct___289;

struct inode___284;

struct file_lock___284;

struct page___289;

struct pipe_inode_info___125;

struct seq_file___259;

struct file_operations___285 {
	struct module___268 *owner;
	loff_t (*llseek)(struct file___284 *, loff_t, int);
	ssize_t (*read)(struct file___284 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___284 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___284 *, struct iov_iter___204 *);
	ssize_t (*write_iter)(struct kiocb___284 *, struct iov_iter___204 *);
	int (*iopoll)(struct kiocb___284 *, bool);
	int (*iterate)(struct file___284 *, struct dir_context *);
	int (*iterate_shared)(struct file___284 *, struct dir_context *);
	__poll_t (*poll)(struct file___284 *, struct poll_table_struct___205 *);
	long int (*unlocked_ioctl)(struct file___284 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___284 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___284 *, struct vm_area_struct___289 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___284 *, struct file___284 *);
	int (*flush)(struct file___284 *, fl_owner_t);
	int (*release)(struct inode___284 *, struct file___284 *);
	int (*fsync)(struct file___284 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___284 *, int);
	int (*lock)(struct file___284 *, int, struct file_lock___284 *);
	ssize_t (*sendpage)(struct file___284 *, struct page___289 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___284 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___284 *, long unsigned int);
	int (*flock)(struct file___284 *, int, struct file_lock___284 *);
	ssize_t (*splice_write)(struct pipe_inode_info___125 *, struct file___284 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___284 *, loff_t *, struct pipe_inode_info___125 *, size_t, unsigned int);
	int (*setlease)(struct file___284 *, long int, struct file_lock___284 **, void **);
	long int (*fallocate)(struct file___284 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___259 *, struct file___284 *);
	ssize_t (*copy_file_range)(struct file___284 *, loff_t, struct file___284 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___284 *, loff_t, struct file___284 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___284 *, loff_t, loff_t, int);
};

struct vmacache___289 {
	u64 seqnum;
	struct vm_area_struct___289 *vmas[4];
};

struct page_frag___289 {
	struct page___289 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___290;

struct pid___261;

struct nsproxy___270;

struct signal_struct___285;

struct bio_list___175;

struct backing_dev_info___161;

struct io_context___175;

struct css_set___211;

struct mem_cgroup___149;

struct request_queue___175;

struct vm_struct___267;

struct task_struct___291 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___291 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___290 *mm;
	struct mm_struct___290 *active_mm;
	struct vmacache___289 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___291 *real_parent;
	struct task_struct___291 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___291 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___261 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___270 *nsproxy;
	struct signal_struct___285 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___291 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___175 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___161 *backing_dev_info;
	struct io_context___175 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___211 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___125 *splice_pipe;
	struct page_frag___289 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___149 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___149 *active_memcg;
	struct request_queue___175 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___291 *oom_reaper_list;
	struct vm_struct___267 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___272;

struct kobj_type___272;

struct kernfs_node___272;

struct kobject___272 {
	const char *name;
	struct list_head entry;
	struct kobject___272 *parent;
	struct kset___272 *kset;
	struct kobj_type___272 *ktype;
	struct kernfs_node___272 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___269 {
	struct kobject___272 kobj;
	struct module___268 *mod;
	struct kobject___272 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___268 {
	struct module___268 *mod;
	struct latch_tree_node node;
};

struct module_layout___268 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___268 mtn;
};

struct module_attribute___268;

struct kernel_param___268;

struct module___268 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___269 mkobj;
	struct module_attribute___268 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___272 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___268 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___268 core_layout;
	struct module_layout___268 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___261;

struct upid___261 {
	int nr;
	struct pid_namespace___261 *ns;
};

struct pid_namespace___261 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___291 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___261 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___261 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___261 numbers[1];
};

typedef struct page___289 *pgtable_t___289;

struct address_space___284;

struct page_pool___113;

struct dev_pagemap___279;

struct page___289 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___284 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___113 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___289 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___289 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___290 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___279 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___279;

struct vm_area_struct___289 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___289 *vm_next;
	struct vm_area_struct___289 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___290 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___279 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___284 *vm_file;
	struct file___284 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___285 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___291 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___291 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___261 *pids[4];
	struct pid___261 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___290 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___289;

struct mm_struct___290 {
	struct {
		struct vm_area_struct___289 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___284 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___289 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___291 *owner;
		struct user_namespace___26 *user_ns;
		struct file___284 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___98;

struct cgroup_namespace___211;

struct nsproxy___270 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___261 *pid_ns_for_children;
	struct net___98 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___211 *cgroup_ns;
};

struct bio___175;

struct bio_list___175 {
	struct bio___175 *head;
	struct bio___175 *tail;
};

struct cgroup_subsys_state___211;

struct bdi_writeback___161 {
	struct backing_dev_info___161 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___211 *memcg_css;
	struct cgroup_subsys_state___211 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___265;

struct backing_dev_info___161 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___161 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___265 *dev;
	char dev_name[64];
	struct device___265 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___284 *debug_dir;
};

struct io_cq___175;

struct io_context___175 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___175 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___211;

struct css_set___211 {
	struct cgroup_subsys_state___211 *subsys[14];
	refcount_t refcount;
	struct css_set___211 *dom_cset;
	struct cgroup___211 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___211 *mg_src_cgrp;
	struct cgroup___211 *mg_dst_cgrp;
	struct css_set___211 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___284;

struct pipe_buffer___125;

struct pipe_inode_info___125 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___289 *tmp_page;
	struct fasync_struct___284 *fasync_readers;
	struct fasync_struct___284 *fasync_writers;
	struct pipe_buffer___125 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___211;

struct cgroup_subsys_state___211 {
	struct cgroup___211 *cgroup;
	struct cgroup_subsys___211 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___211 *parent;
};

struct cgroup_file___211 {
	struct kernfs_node___272 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___149;

struct mem_cgroup_per_node___149;

struct mem_cgroup___149 {
	struct cgroup_subsys_state___211 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___211 events_file;
	struct cgroup_file___211 events_local_file;
	struct cgroup_file___211 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___149 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___291 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___149 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___175;

struct blk_integrity___175 {
	const struct blk_integrity_profile___175 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___175 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___175 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___175;

struct elevator_queue___175;

struct blk_mq_ops___170;

struct blk_mq_hw_ctx___170;

struct gendisk___178;

struct blkcg_gq___163;

struct blk_mq_tag_set___170;

struct request_queue___175 {
	struct request___175 *last_merge;
	struct elevator_queue___175 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___170 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___170 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___178 *disk;
	struct kobject___272 kobj;
	struct kobject___272 *mq_kobj;
	struct blk_integrity___175 integrity;
	struct device___265 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___163 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___170 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___175 bio_split;
	struct dentry___284 *debugfs_dir;
	struct dentry___284 *sched_debugfs_dir;
	struct dentry___284 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___267 {
	struct vm_struct___267 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___289 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___284;

struct address_space___284 {
	struct inode___284 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___284 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___113 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___265 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___113 {
	u32 count;
	struct page___289 *cache[128];
};

struct page_pool___113 {
	struct page_pool_params___113 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___289 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___113 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___279;

struct dev_pagemap___279 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___279 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___284;

struct path___284 {
	struct vfsmount___284 *mnt;
	struct dentry___284 *dentry;
};

struct fown_struct___261 {
	rwlock_t lock;
	struct pid___261 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___284 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___284 f_path;
	struct inode___284 *f_inode;
	const struct file_operations___285 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___261 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___284 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___279;

struct vm_operations_struct___279 {
	void (*open)(struct vm_area_struct___289 *);
	void (*close)(struct vm_area_struct___289 *);
	int (*may_split)(struct vm_area_struct___289 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___289 *);
	int (*mprotect)(struct vm_area_struct___289 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___279 *);
	vm_fault_t (*huge_fault)(struct vm_fault___279 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___279 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___289 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___279 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___279 *);
	int (*access)(struct vm_area_struct___289 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___289 *);
	int (*set_policy)(struct vm_area_struct___289 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___289 *, long unsigned int);
	struct page___289 * (*find_special_page)(struct vm_area_struct___289 *, long unsigned int);
};

struct core_thread___289 {
	struct task_struct___291 *task;
	struct core_thread___289 *next;
};

struct core_state___289 {
	atomic_t nr_threads;
	struct core_thread___289 dumper;
	struct completion startup;
};

struct vm_fault___279 {
	const struct {
		struct vm_area_struct___289 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___289 *cow_page;
	struct page___289 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___289 prealloc_pte;
};

struct pglist_data___157;

struct lruvec___157 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___157 *pgdat;
};

struct zone___157 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___157 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___157 {
	struct zone___157 *zone;
	int zone_idx;
};

struct zonelist___157 {
	struct zoneref___157 _zonerefs[321];
};

struct pglist_data___157 {
	struct zone___157 node_zones[5];
	struct zonelist___157 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___291 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___291 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___157 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___149 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___149 *memcg;
};

struct shrinker___149 {
	long unsigned int (*count_objects)(struct shrinker___149 *, struct shrink_control___149 *);
	long unsigned int (*scan_objects)(struct shrinker___149 *, struct shrink_control___149 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___279 {
	void (*page_free)(struct page___289 *);
	void (*kill)(struct dev_pagemap___279 *);
	void (*cleanup)(struct dev_pagemap___279 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___279 *);
};

struct dentry_operations___284;

struct dentry___284 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___284 *d_parent;
	struct qstr d_name;
	struct inode___284 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___284 *d_op;
	struct super_block___284 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___284;

struct inode___284 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___284 *i_op;
	struct super_block___284 *i_sb;
	struct address_space___284 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___161 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___285 *i_fop;
		void (*free_inode)(struct inode___284 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___284 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___125 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___284 {
	int (*d_revalidate)(struct dentry___284 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___284 *, unsigned int);
	int (*d_hash)(const struct dentry___284 *, struct qstr *);
	int (*d_compare)(const struct dentry___284 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___284 *);
	int (*d_init)(struct dentry___284 *);
	void (*d_release)(struct dentry___284 *);
	void (*d_prune)(struct dentry___284 *);
	void (*d_iput)(struct dentry___284 *, struct inode___284 *);
	char * (*d_dname)(struct dentry___284 *, char *, int);
	struct vfsmount___284 * (*d_automount)(struct path___284 *);
	int (*d_manage)(const struct path___284 *, bool);
	struct dentry___284 * (*d_real)(struct dentry___284 *, const struct inode___284 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___284;

struct mem_dqinfo___284 {
	struct quota_format_type___284 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___284;

struct quota_info___284 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___284 *files[3];
	struct mem_dqinfo___284 info[3];
	const struct quota_format_ops___284 *ops[3];
};

struct rcuwait___285 {
	struct task_struct___291 *task;
};

struct percpu_rw_semaphore___285 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___285 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___284 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___285 rw_sem[3];
};

struct super_operations___284;

struct dquot_operations___284;

struct quotactl_ops___284;

struct block_device___178;

struct super_block___284 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___284 *s_type;
	const struct super_operations___284 *s_op;
	const struct dquot_operations___284 *dq_op;
	const struct quotactl_ops___284 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___284 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___178 *s_bdev;
	struct backing_dev_info___161 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___284 s_dquot;
	struct sb_writers___284 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___284 *s_d_op;
	int cleancache_poolid;
	struct shrinker___149 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___284 {
	struct dentry___284 *mnt_root;
	struct super_block___284 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___211 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___291 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___87;

struct cgroup_bpf___87 {
	struct bpf_prog_array___87 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___87 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___211;

struct cgroup_rstat_cpu___211;

struct cgroup___211 {
	struct cgroup_subsys_state___211 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___272 *kn;
	struct cgroup_file___211 procs_file;
	struct cgroup_file___211 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___211 *subsys[14];
	struct cgroup_root___211 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___211 *dom_cgrp;
	struct cgroup___211 *old_dom_cgrp;
	struct cgroup_rstat_cpu___211 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___211 psi;
	struct cgroup_bpf___87 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___175 {
	struct request_queue___175 *q;
	struct io_context___175 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___284 {
	struct file___284 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___284 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___284 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___284 *ia_file;
};

struct dquot___284 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___284 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___284 {
	int qf_fmt_id;
	const struct quota_format_ops___284 *qf_ops;
	struct module___268 *qf_owner;
	struct quota_format_type___284 *qf_next;
};

struct quota_format_ops___284 {
	int (*check_quota_file)(struct super_block___284 *, int);
	int (*read_file_info)(struct super_block___284 *, int);
	int (*write_file_info)(struct super_block___284 *, int);
	int (*free_file_info)(struct super_block___284 *, int);
	int (*read_dqblk)(struct dquot___284 *);
	int (*commit_dqblk)(struct dquot___284 *);
	int (*release_dqblk)(struct dquot___284 *);
	int (*get_next_id)(struct super_block___284 *, struct kqid *);
};

struct dquot_operations___284 {
	int (*write_dquot)(struct dquot___284 *);
	struct dquot___284 * (*alloc_dquot)(struct super_block___284 *, int);
	void (*destroy_dquot)(struct dquot___284 *);
	int (*acquire_dquot)(struct dquot___284 *);
	int (*release_dquot)(struct dquot___284 *);
	int (*mark_dirty)(struct dquot___284 *);
	int (*write_info)(struct super_block___284 *, int);
	qsize_t * (*get_reserved_space)(struct inode___284 *);
	int (*get_projid)(struct inode___284 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___284 *, qsize_t *);
	int (*get_next_id)(struct super_block___284 *, struct kqid *);
};

struct quotactl_ops___284 {
	int (*quota_on)(struct super_block___284 *, int, int, const struct path___284 *);
	int (*quota_off)(struct super_block___284 *, int);
	int (*quota_enable)(struct super_block___284 *, unsigned int);
	int (*quota_disable)(struct super_block___284 *, unsigned int);
	int (*quota_sync)(struct super_block___284 *, int);
	int (*set_info)(struct super_block___284 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___284 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___284 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___284 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___284 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___284 *, unsigned int);
};

struct writeback_control___161;

struct address_space_operations___284 {
	int (*writepage)(struct page___289 *, struct writeback_control___161 *);
	int (*readpage)(struct file___284 *, struct page___289 *);
	int (*writepages)(struct address_space___284 *, struct writeback_control___161 *);
	int (*set_page_dirty)(struct page___289 *);
	int (*readpages)(struct file___284 *, struct address_space___284 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___284 *, struct address_space___284 *, loff_t, unsigned int, unsigned int, struct page___289 **, void **);
	int (*write_end)(struct file___284 *, struct address_space___284 *, loff_t, unsigned int, unsigned int, struct page___289 *, void *);
	sector_t (*bmap)(struct address_space___284 *, sector_t);
	void (*invalidatepage)(struct page___289 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___289 *, gfp_t);
	void (*freepage)(struct page___289 *);
	ssize_t (*direct_IO)(struct kiocb___284 *, struct iov_iter___204 *);
	int (*migratepage)(struct address_space___284 *, struct page___289 *, struct page___289 *, enum migrate_mode);
	bool (*isolate_page)(struct page___289 *, isolate_mode_t);
	void (*putback_page)(struct page___289 *);
	int (*launder_page)(struct page___289 *);
	int (*is_partially_uptodate)(struct page___289 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___289 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___284 *, struct page___289 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___284 *, sector_t *);
	void (*swap_deactivate)(struct file___284 *);
};

struct writeback_control___161 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___161 *wb;
	struct inode___284 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___201;

struct iov_iter___204 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___201 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___125 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___284 {
	struct dentry___284 * (*lookup)(struct inode___284 *, struct dentry___284 *, unsigned int);
	const char * (*get_link)(struct dentry___284 *, struct inode___284 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___284 *, int);
	struct posix_acl * (*get_acl)(struct inode___284 *, int, bool);
	int (*readlink)(struct dentry___284 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___284 *, struct dentry___284 *, umode_t, bool);
	int (*link)(struct dentry___284 *, struct inode___284 *, struct dentry___284 *);
	int (*unlink)(struct inode___284 *, struct dentry___284 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___284 *, struct dentry___284 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___284 *, struct dentry___284 *, umode_t);
	int (*rmdir)(struct inode___284 *, struct dentry___284 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___284 *, struct dentry___284 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___284 *, struct dentry___284 *, struct inode___284 *, struct dentry___284 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___284 *, struct iattr___284 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___284 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___284 *, char *, size_t);
	int (*fiemap)(struct inode___284 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___284 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___284 *, struct dentry___284 *, struct file___284 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___284 *, struct dentry___284 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___284 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___284 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___284 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___284 {
	void (*fl_copy_lock)(struct file_lock___284 *, struct file_lock___284 *);
	void (*fl_release_private)(struct file_lock___284 *);
};

struct lock_manager_operations___284;

struct file_lock___284 {
	struct file_lock___284 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___284 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___284 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___284 *fl_ops;
	const struct lock_manager_operations___284 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___284 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___284 *);
	int (*lm_grant)(struct file_lock___284 *, int);
	bool (*lm_break)(struct file_lock___284 *);
	int (*lm_change)(struct file_lock___284 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___284 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___284 *);
};

struct fasync_struct___284 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___284 *fa_next;
	struct file___284 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___284 {
	struct inode___284 * (*alloc_inode)(struct super_block___284 *);
	void (*destroy_inode)(struct inode___284 *);
	void (*free_inode)(struct inode___284 *);
	void (*dirty_inode)(struct inode___284 *, int);
	int (*write_inode)(struct inode___284 *, struct writeback_control___161 *);
	int (*drop_inode)(struct inode___284 *);
	void (*evict_inode)(struct inode___284 *);
	void (*put_super)(struct super_block___284 *);
	int (*sync_fs)(struct super_block___284 *, int);
	int (*freeze_super)(struct super_block___284 *);
	int (*freeze_fs)(struct super_block___284 *);
	int (*thaw_super)(struct super_block___284 *);
	int (*unfreeze_fs)(struct super_block___284 *);
	int (*statfs)(struct dentry___284 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___284 *, int *, char *);
	void (*umount_begin)(struct super_block___284 *);
	int (*show_options)(struct seq_file___259 *, struct dentry___284 *);
	int (*show_devname)(struct seq_file___259 *, struct dentry___284 *);
	int (*show_path)(struct seq_file___259 *, struct dentry___284 *);
	int (*show_stats)(struct seq_file___259 *, struct dentry___284 *);
	ssize_t (*quota_read)(struct super_block___284 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___284 *, int, const char *, size_t, loff_t);
	struct dquot___284 ** (*get_dquots)(struct inode___284 *);
	long int (*nr_cached_objects)(struct super_block___284 *, struct shrink_control___149 *);
	long int (*free_cached_objects)(struct super_block___284 *, struct shrink_control___149 *);
	struct file___284 * (*real_loop)(struct file___284 *);
};

struct wakeup_source___265;

struct dev_pm_info___265 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___265 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___265 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___265;

struct bus_type___265;

struct device_driver___265;

struct dev_pm_domain___265;

struct fwnode_handle___261;

struct class___265;

struct attribute_group___272;

struct device___265 {
	struct kobject___272 kobj;
	struct device___265 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___265 *type;
	struct bus_type___265 *bus;
	struct device_driver___265 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___265 power;
	struct dev_pm_domain___265 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___261 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___265 *class;
	const struct attribute_group___272 **groups;
	void (*release)(struct device___265 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___178 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___284 *bd_inode;
	struct super_block___284 *bd_super;
	void *bd_claiming;
	struct device___265 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___272 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___178 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___284 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___213)(struct file___284 *, wait_queue_head_t *, struct poll_table_struct___205 *);

struct poll_table_struct___205 {
	poll_queue_proc___213 _qproc;
	__poll_t _key;
};

struct seq_operations___259;

struct seq_file___259 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___259 *op;
	int poll_event;
	const struct file___284 *file;
	void *private;
};

typedef void bio_end_io_t___175(struct bio___175 *);

struct bio_vec___201 {
	struct page___289 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___175;

struct bio___175 {
	struct bio___175 *bi_next;
	struct block_device___178 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___175 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___163 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___175 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___201 *bi_io_vec;
	struct bio_set___175 *bi_pool;
	struct bio_vec___201 bi_inline_vecs[0];
};

struct msghdr___82 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___204 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___284 *msg_iocb;
};

struct net_device___93;

struct sock___80;

struct sk_buff___94 {
	union {
		struct {
			struct sk_buff___94 *next;
			struct sk_buff___94 *prev;
			union {
				struct net_device___93 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___80 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___94 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___98;

struct fqdir___98 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___98 *f;
	struct net___98 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___98;

struct inet_frags___98 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___98 *, const void *);
	void (*destructor)(struct inet_frag_queue___98 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___53;

struct fib_rules_ops___80;

struct fib_notifier_ops___80;

struct netns_ipv4___98 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___53 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___80 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___80 *fibnl;
	struct sock___80 **icmp_sk;
	struct sock___80 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___80 **tcp_sk;
	struct fqdir___98 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___80 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___80 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___80 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___80;

struct neighbour___80;

struct dst_ops___98 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___98 *);
	struct dst_entry___80 * (*check)(struct dst_entry___80 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___80 *);
	unsigned int (*mtu)(const struct dst_entry___80 *);
	u32 * (*cow_metrics)(struct dst_entry___80 *, long unsigned int);
	void (*destroy)(struct dst_entry___80 *);
	void (*ifdown)(struct dst_entry___80 *, struct net_device___93 *, int);
	struct dst_entry___80 * (*negative_advice)(struct dst_entry___80 *);
	void (*link_failure)(struct sk_buff___94 *);
	void (*update_pmtu)(struct dst_entry___80 *, struct sock___80 *, struct sk_buff___94 *, u32, bool);
	void (*redirect)(struct dst_entry___80 *, struct sock___80 *, struct sk_buff___94 *);
	int (*local_out)(struct net___98 *, struct sock___80 *, struct sk_buff___94 *);
	struct neighbour___80 * (*neigh_lookup)(const struct dst_entry___80 *, struct sk_buff___94 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___80 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___25;

struct rt6_info___25;

struct fib6_table___25;

struct netns_ipv6___98 {
	struct dst_ops___98 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___98 *fqdir;
	struct fib6_info___25 *fib6_null_entry;
	struct rt6_info___25 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___25 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___25 *ip6_prohibit_entry;
	struct rt6_info___25 *ip6_blk_hole_entry;
	struct fib6_table___25 *fib6_local_tbl;
	struct fib_rules_ops___80 *fib6_rules_ops;
	struct sock___80 **icmp_sk;
	struct sock___80 *ndisc_sk;
	struct sock___80 *tcp_sk;
	struct sock___80 *igmp_sk;
	struct sock___80 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___80 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___80 *notifier_ops;
	struct fib_notifier_ops___80 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___98 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___98 *fqdir;
};

struct netns_sctp___80 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___80 *ctl_sock;
	struct sock___80 *udp4_sock;
	struct sock___80 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___17;

struct netns_nf___17 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___17 *hooks_ipv4[5];
	struct nf_hook_entries___17 *hooks_ipv6[5];
	struct nf_hook_entries___17 *hooks_arp[3];
	struct nf_hook_entries___17 *hooks_bridge[5];
	struct nf_hook_entries___17 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct sk_buff_head___93 {
	struct sk_buff___94 *next;
	struct sk_buff___94 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___87;

struct netns_bpf___87 {
	struct bpf_prog_array___87 *run_array[2];
	struct bpf_prog___87 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___98 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___80 *nlsk;
	struct sock___80 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___98 xfrm4_dst_ops;
	struct dst_ops___98 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___98 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___80 *rtnl;
	struct sock___80 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___93 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___98 ipv4;
	struct netns_ipv6___98 ipv6;
	struct netns_ieee802154_lowpan___98 ieee802154_lowpan;
	struct netns_sctp___80 sctp;
	struct netns_nf___17 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___93 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___87 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___98 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___80 *crypto_nlsk;
	struct sock___80 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___98 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___94 *fragments_tail;
	struct sk_buff___94 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___98 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___53 {
	struct ip_ra_chain___53 *next;
	struct sock___80 *sk;
	union {
		void (*destructor)(struct sock___80 *);
		struct sock___80 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___80;

struct fib_lookup_arg___80;

struct fib_rules_ops___80 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___80 *, struct flowi *, int, struct fib_lookup_arg___80 *);
	bool (*suppress)(struct fib_rule___80 *, int, struct fib_lookup_arg___80 *);
	int (*match)(struct fib_rule___80 *, struct flowi *, int);
	int (*configure)(struct fib_rule___80 *, struct sk_buff___94 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___80 *);
	int (*compare)(struct fib_rule___80 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___80 *, struct sk_buff___94 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___80 *);
	void (*flush_cache)(struct fib_rules_ops___80 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___268 *owner;
	struct net___98 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___98 *net;
} possible_net_t___93;

struct proto___80;

struct sock_common___80 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___80 *skc_prot;
	possible_net_t___93 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___80 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___80 {
	struct cgroup___211 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___80;

struct socket_wq___81;

struct socket___82;

struct sock___80 {
	struct sock_common___80 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___93 sk_error_queue;
	struct sk_buff___94 *sk_rx_skb_cache;
	struct sk_buff_head___93 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___94 *head;
		struct sk_buff___94 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___80 *sk_filter;
	union {
		struct socket_wq___81 *sk_wq;
		struct socket_wq___81 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___80 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___80 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___94 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___94 *sk_tx_skb_cache;
	struct sk_buff_head___93 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___289 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___80 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___261 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___82 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___80 sk_cgrp_data;
	struct mem_cgroup___149 *sk_memcg;
	void (*sk_state_change)(struct sock___80 *);
	void (*sk_data_ready)(struct sock___80 *);
	void (*sk_write_space)(struct sock___80 *);
	void (*sk_error_report)(struct sock___80 *);
	int (*sk_backlog_rcv)(struct sock___80 *, struct sk_buff___94 *);
	struct sk_buff___94 * (*sk_validate_xmit_skb)(struct sock___80 *, struct net_device___93 *, struct sk_buff___94 *);
	void (*sk_destruct)(struct sock___80 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct fib_notifier_ops___80 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___98 *);
	int (*fib_dump)(struct net___98 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___268 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___56;

struct dst_entry___80 {
	struct net_device___93 *dev;
	struct dst_ops___98 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___94 *);
	int (*output)(struct net___98 *, struct sock___80 *, struct sk_buff___94 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___56 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___93(struct sk_buff___94 **);

struct bpf_xdp_entity___87 {
	struct bpf_prog___87 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___93;

struct net_device_ops___93;

struct l3mdev_ops___80;

struct ndisc_ops___62;

struct xfrmdev_ops___93;

struct header_ops___93;

struct in_device___20;

struct inet6_dev___62;

struct netdev_rx_queue___93;

struct mini_Qdisc___87;

struct netdev_queue___93;

struct Qdisc___87;

struct rtnl_link_ops___87;

struct dcbnl_rtnl_ops___93;

struct net_device___93 {
	char name[16];
	struct netdev_name_node___93 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___93 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___80 *l3mdev_ops;
	const struct ndisc_ops___62 *ndisc_ops;
	const struct xfrmdev_ops___93 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___93 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___272 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___20 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___62 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___93 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___87 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___93 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___87 *miniq_ingress;
	struct netdev_queue___93 *ingress_queue;
	struct nf_hook_entries___17 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___93 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___87 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___87 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___93 = 0,
		NETREG_REGISTERED___93 = 1,
		NETREG_UNREGISTERING___93 = 2,
		NETREG_UNREGISTERED___93 = 3,
		NETREG_RELEASED___93 = 4,
		NETREG_DUMMY___93 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___93 = 0,
		RTNL_LINK_INITIALIZING___93 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___93 *);
	struct netpoll_info *npinfo;
	possible_net_t___93 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___265 dev;
	const struct attribute_group___272 *sysfs_groups[4];
	const struct attribute_group___272 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___87 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___93 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___87 xdp_state[3];
	long: 64;
};

struct neigh_table___80;

struct neigh_parms___80;

struct neigh_ops___80;

struct neighbour___80 {
	struct neighbour___80 *next;
	struct neigh_table___80 *tbl;
	struct neigh_parms___80 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___93 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___80 *, struct sk_buff___94 *);
	const struct neigh_ops___80 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___93 *dev;
	u8 primary_key[0];
};

struct rtable___27;

struct fnhe_hash_bucket___25;

struct fib_nh_common___25 {
	struct net_device___93 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___56 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___27 **nhc_pcpu_rth_output;
	struct rtable___27 *nhc_rth_input;
	struct fnhe_hash_bucket___25 *nhc_exceptions;
};

struct fib6_nh___25 {
	struct fib_nh_common___25 nh_common;
	long unsigned int last_probe;
	struct rt6_info___25 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___25;

struct nexthop___16;

struct fib6_info___25 {
	struct fib6_table___25 *fib6_table;
	struct fib6_info___25 *fib6_next;
	struct fib6_node___25 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___16 *nh;
	struct fib6_nh___25 fib6_nh[0];
};

struct rt6_info___25 {
	struct dst_entry___80 dst;
	struct fib6_info___25 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___62 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___25 {
	struct fib6_node___25 *parent;
	struct fib6_node___25 *left;
	struct fib6_node___25 *right;
	struct fib6_node___25 *subtree;
	struct fib6_info___25 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___25 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___25 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___25 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___17;

typedef unsigned int nf_hookfn___19(void *, struct sk_buff___94 *, const struct nf_hook_state___17 *);

struct nf_hook_entry___17 {
	nf_hookfn___19 *hook;
	void *priv;
};

struct nf_hook_entries___17 {
	u16 num_hook_entries;
	struct nf_hook_entry___17 hooks[0];
};

struct bpf_prog_array_item___87 {
	struct bpf_prog___87 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___87 {
	struct callback_head rcu;
	struct bpf_prog_array_item___87 items[0];
};

struct bpf_prog_aux___96;

struct bpf_prog___87 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___96 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___261;

struct fwnode_handle___261 {
	struct fwnode_handle___261 *secondary;
	const struct fwnode_operations___261 *ops;
	struct device___265 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___261;

struct fwnode_endpoint___261;

struct fwnode_operations___261 {
	struct fwnode_handle___261 * (*get)(struct fwnode_handle___261 *);
	void (*put)(struct fwnode_handle___261 *);
	bool (*device_is_available)(const struct fwnode_handle___261 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___261 *, const struct device___265 *);
	bool (*property_present)(const struct fwnode_handle___261 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___261 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___261 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___261 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*get_parent)(const struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*get_next_child_node)(const struct fwnode_handle___261 *, struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*get_named_child_node)(const struct fwnode_handle___261 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___261 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___261 *);
	struct fwnode_handle___261 * (*graph_get_next_endpoint)(const struct fwnode_handle___261 *, struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*graph_get_remote_endpoint)(const struct fwnode_handle___261 *);
	struct fwnode_handle___261 * (*graph_get_port_parent)(struct fwnode_handle___261 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___261 *, struct fwnode_endpoint___261 *);
	int (*add_links)(struct fwnode_handle___261 *);
};

struct fwnode_endpoint___261 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___261 *local_fwnode;
};

struct fwnode_reference_args___261 {
	struct fwnode_handle___261 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___272;

struct kernfs_elem_dir___272 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___272 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___272;

struct kernfs_root___272 {
	struct kernfs_node___272 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___272 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___272 {
	struct kernfs_node___272 *target_kn;
};

struct kernfs_ops___272;

struct kernfs_elem_attr___272 {
	const struct kernfs_ops___272 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___272 *notify_next;
};

struct kernfs_node___272 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___272 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___272 dir;
		struct kernfs_elem_symlink___272 symlink;
		struct kernfs_elem_attr___272 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___272;

struct kernfs_ops___272 {
	int (*open)(struct kernfs_open_file___272 *);
	void (*release)(struct kernfs_open_file___272 *);
	int (*seq_show)(struct seq_file___259 *, void *);
	void * (*seq_start)(struct seq_file___259 *, loff_t *);
	void * (*seq_next)(struct seq_file___259 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___259 *, void *);
	ssize_t (*read)(struct kernfs_open_file___272 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___272 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___272 *, struct poll_table_struct___205 *);
	int (*mmap)(struct kernfs_open_file___272 *, struct vm_area_struct___289 *);
};

struct kernfs_syscall_ops___272 {
	int (*show_options)(struct seq_file___259 *, struct kernfs_root___272 *);
	int (*mkdir)(struct kernfs_node___272 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___272 *);
	int (*rename)(struct kernfs_node___272 *, struct kernfs_node___272 *, const char *);
	int (*show_path)(struct seq_file___259 *, struct kernfs_node___272 *, struct kernfs_root___272 *);
};

struct kernfs_open_file___272 {
	struct kernfs_node___272 *kn;
	struct file___284 *file;
	struct seq_file___259 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___279 *vm_ops;
};

struct kobj_ns_type_operations___80 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___80 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___272;

struct attribute_group___272 {
	const char *name;
	umode_t (*is_visible)(struct kobject___272 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___272 *, struct bin_attribute___272 *, int);
	struct attribute **attrs;
	struct bin_attribute___272 **bin_attrs;
};

struct bin_attribute___272 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___284 * (*f_mapping)();
	ssize_t (*read)(struct file___284 *, struct kobject___272 *, struct bin_attribute___272 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___284 *, struct kobject___272 *, struct bin_attribute___272 *, char *, loff_t, size_t);
	int (*mmap)(struct file___284 *, struct kobject___272 *, struct bin_attribute___272 *, struct vm_area_struct___289 *);
};

struct sysfs_ops___272 {
	ssize_t (*show)(struct kobject___272 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___272 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___272;

struct kset___272 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___272 kobj;
	const struct kset_uevent_ops___272 *uevent_ops;
};

struct kobj_type___272 {
	void (*release)(struct kobject___272 *);
	const struct sysfs_ops___272 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___272 **default_groups;
	const struct kobj_ns_type_operations___80 * (*child_ns_type)(struct kobject___272 *);
	const void * (*namespace)(struct kobject___272 *);
	void (*get_ownership)(struct kobject___272 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___272 {
	int (* const filter)(struct kset___272 *, struct kobject___272 *);
	const char * (* const name)(struct kset___272 *, struct kobject___272 *);
	int (* const uevent)(struct kset___272 *, struct kobject___272 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___268 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___268 *);
	int (*get)(char *, const struct kernel_param___268 *);
	void (*free)(void *);
};

struct kparam_array___268;

struct kernel_param___268 {
	const char *name;
	struct module___268 *mod;
	const struct kernel_param_ops___268 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___268 *arr;
	};
};

struct kparam_array___268 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___268 *ops;
	void *elem;
};

struct module_attribute___268 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___268 *, struct module_kobject___269 *, char *);
	ssize_t (*store)(struct module_attribute___268 *, struct module_kobject___269 *, const char *, size_t);
	void (*setup)(struct module___268 *, const char *);
	int (*test)(struct module___268 *);
	void (*free)(struct module___268 *);
};

struct cgroup_namespace___211 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___211 *root_cset;
};

struct socket_wq___81 {
	wait_queue_head_t wait;
	struct fasync_struct___284 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___81;

struct socket___82 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___284 *file;
	struct sock___80 *sk;
	const struct proto_ops___81 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___81 wq;
};

typedef int (*sk_read_actor_t___80)(read_descriptor_t *, struct sk_buff___94 *, unsigned int, size_t);

struct proto_ops___81 {
	int family;
	struct module___268 *owner;
	int (*release)(struct socket___82 *);
	int (*bind)(struct socket___82 *, struct sockaddr *, int);
	int (*connect)(struct socket___82 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___82 *, struct socket___82 *);
	int (*accept)(struct socket___82 *, struct socket___82 *, int, bool);
	int (*getname)(struct socket___82 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___284 *, struct socket___82 *, struct poll_table_struct___205 *);
	int (*ioctl)(struct socket___82 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___82 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___82 *, void *, bool, bool);
	int (*listen)(struct socket___82 *, int);
	int (*shutdown)(struct socket___82 *, int);
	int (*setsockopt)(struct socket___82 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___82 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___259 *, struct socket___82 *);
	int (*sendmsg)(struct socket___82 *, struct msghdr___82 *, size_t);
	int (*recvmsg)(struct socket___82 *, struct msghdr___82 *, size_t, int);
	int (*mmap)(struct file___284 *, struct socket___82 *, struct vm_area_struct___289 *);
	ssize_t (*sendpage)(struct socket___82 *, struct page___289 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___82 *, loff_t *, struct pipe_inode_info___125 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___80 *, int);
	int (*peek_len)(struct socket___82 *);
	int (*read_sock)(struct sock___80 *, read_descriptor_t *, sk_read_actor_t___80);
	int (*sendpage_locked)(struct sock___80 *, struct page___289 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___80 *, struct msghdr___82 *, size_t);
	int (*set_rcvlowat)(struct sock___80 *, int);
};

struct dev_pm_ops___265 {
	int (*prepare)(struct device___265 *);
	void (*complete)(struct device___265 *);
	int (*suspend)(struct device___265 *);
	int (*resume)(struct device___265 *);
	int (*freeze)(struct device___265 *);
	int (*thaw)(struct device___265 *);
	int (*poweroff)(struct device___265 *);
	int (*restore)(struct device___265 *);
	int (*suspend_late)(struct device___265 *);
	int (*resume_early)(struct device___265 *);
	int (*freeze_late)(struct device___265 *);
	int (*thaw_early)(struct device___265 *);
	int (*poweroff_late)(struct device___265 *);
	int (*restore_early)(struct device___265 *);
	int (*suspend_noirq)(struct device___265 *);
	int (*resume_noirq)(struct device___265 *);
	int (*freeze_noirq)(struct device___265 *);
	int (*thaw_noirq)(struct device___265 *);
	int (*poweroff_noirq)(struct device___265 *);
	int (*restore_noirq)(struct device___265 *);
	int (*runtime_suspend)(struct device___265 *);
	int (*runtime_resume)(struct device___265 *);
	int (*runtime_idle)(struct device___265 *);
};

struct wakeup_source___265 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___265 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___265 {
	struct dev_pm_ops___265 ops;
	int (*start)(struct device___265 *);
	void (*detach)(struct device___265 *, bool);
	int (*activate)(struct device___265 *);
	void (*sync)(struct device___265 *);
	void (*dismiss)(struct device___265 *);
};

struct bus_type___265 {
	const char *name;
	const char *dev_name;
	struct device___265 *dev_root;
	const struct attribute_group___272 **bus_groups;
	const struct attribute_group___272 **dev_groups;
	const struct attribute_group___272 **drv_groups;
	int (*match)(struct device___265 *, struct device_driver___265 *);
	int (*uevent)(struct device___265 *, struct kobj_uevent_env *);
	int (*probe)(struct device___265 *);
	void (*sync_state)(struct device___265 *);
	void (*remove)(struct device___265 *);
	void (*shutdown)(struct device___265 *);
	int (*online)(struct device___265 *);
	int (*offline)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	int (*num_vf)(struct device___265 *);
	int (*dma_configure)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___265 {
	const char *name;
	struct bus_type___265 *bus;
	struct module___268 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___265 *);
	void (*sync_state)(struct device___265 *);
	int (*remove)(struct device___265 *);
	void (*shutdown)(struct device___265 *);
	int (*suspend)(struct device___265 *, pm_message_t);
	int (*resume)(struct device___265 *);
	const struct attribute_group___272 **groups;
	const struct attribute_group___272 **dev_groups;
	const struct dev_pm_ops___265 *pm;
	void (*coredump)(struct device___265 *);
	struct driver_private *p;
};

struct device_type___265 {
	const char *name;
	const struct attribute_group___272 **groups;
	int (*uevent)(struct device___265 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___265 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___265 *);
	const struct dev_pm_ops___265 *pm;
};

struct class___265 {
	const char *name;
	struct module___268 *owner;
	const struct attribute_group___272 **class_groups;
	const struct attribute_group___272 **dev_groups;
	struct kobject___272 *dev_kobj;
	int (*dev_uevent)(struct device___265 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___265 *, umode_t *);
	void (*class_release)(struct class___265 *);
	void (*dev_release)(struct device___265 *);
	int (*shutdown_pre)(struct device___265 *);
	const struct kobj_ns_type_operations___80 *ns_type;
	const void * (*namespace)(struct device___265 *);
	void (*get_ownership)(struct device___265 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___265 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___125;

struct pipe_buffer___125 {
	struct page___289 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___125 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___125 {
	int (*confirm)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
	void (*release)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
	bool (*try_steal)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
	bool (*get)(struct pipe_inode_info___125 *, struct pipe_buffer___125 *);
};

typedef struct bio_vec___201 skb_frag_t___36;

struct skb_shared_info___32 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___94 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___36 frags[17];
};

struct seq_operations___259 {
	void * (*start)(struct seq_file___259 *, loff_t *);
	void (*stop)(struct seq_file___259 *, void *);
	void * (*next)(struct seq_file___259 *, void *, loff_t *);
	int (*show)(struct seq_file___259 *, void *);
};

struct seq_net_private___12 {
	struct net___98 *net;
};

struct pernet_operations___32 {
	struct list_head list;
	int (*init)(struct net___98 *);
	void (*pre_exit)(struct net___98 *);
	void (*exit)(struct net___98 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___93 {
	int (*ieee_getets)(struct net_device___93 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___93 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___93 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___93 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___93 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___93 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___93 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___93 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___93 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___93 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___93 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___93 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___93 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___93 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___93 *);
	u8 (*setstate)(struct net_device___93 *, u8);
	void (*getpermhwaddr)(struct net_device___93 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___93 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___93 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___93 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___93 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___93 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___93 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___93 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___93 *, int, u8 *);
	void (*setpfccfg)(struct net_device___93 *, int, u8);
	void (*getpfccfg)(struct net_device___93 *, int, u8 *);
	u8 (*setall)(struct net_device___93 *);
	u8 (*getcap)(struct net_device___93 *, int, u8 *);
	int (*getnumtcs)(struct net_device___93 *, int, u8 *);
	int (*setnumtcs)(struct net_device___93 *, int, u8);
	u8 (*getpfcstate)(struct net_device___93 *);
	void (*setpfcstate)(struct net_device___93 *, u8);
	void (*getbcncfg)(struct net_device___93 *, int, u32 *);
	void (*setbcncfg)(struct net_device___93 *, int, u32);
	void (*getbcnrp)(struct net_device___93 *, int, u8 *);
	void (*setbcnrp)(struct net_device___93 *, int, u8);
	int (*setapp)(struct net_device___93 *, u8, u16, u8);
	int (*getapp)(struct net_device___93 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___93 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___93 *, int, u8);
	u8 (*getdcbx)(struct net_device___93 *);
	u8 (*setdcbx)(struct net_device___93 *, u8);
	int (*peer_getappinfo)(struct net_device___93 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___93 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___93 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___93 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___93 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___93 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___96;

typedef int (*bpf_iter_init_seq_priv_t___95)(void *, struct bpf_iter_aux_info___96 *);

struct bpf_map___96;

struct bpf_iter_aux_info___96 {
	struct bpf_map___96 *map;
};

struct bpf_iter_seq_info___95 {
	const struct seq_operations___259 *seq_ops;
	bpf_iter_init_seq_priv_t___95 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___95 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___96 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___96 *, struct file___284 *);
	void (*map_free)(struct bpf_map___96 *);
	int (*map_get_next_key)(struct bpf_map___96 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___96 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___96 *, void *);
	int (*map_lookup_batch)(struct bpf_map___96 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___96 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___96 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___96 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___96 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___96 *, void *);
	int (*map_update_elem)(struct bpf_map___96 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___96 *, void *);
	int (*map_push_elem)(struct bpf_map___96 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___96 *, void *);
	int (*map_peek_elem)(struct bpf_map___96 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___96 *, struct file___284 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___96 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___96 *, void *, struct seq_file___259 *);
	int (*map_check_btf)(const struct bpf_map___96 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___96 *, struct bpf_prog_aux___96 *);
	void (*map_poke_untrack)(struct bpf_map___96 *, struct bpf_prog_aux___96 *);
	void (*map_poke_run)(struct bpf_map___96 *, u32, struct bpf_prog___87 *, struct bpf_prog___87 *);
	int (*map_direct_value_addr)(const struct bpf_map___96 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___96 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___96 *, struct vm_area_struct___289 *);
	__poll_t (*map_poll)(struct bpf_map___96 *, struct file___284 *, struct poll_table_struct___205 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___96 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___96 *, const struct bpf_map___96 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___96 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___95 *iter_seq_info;
};

struct bpf_map___96 {
	const struct bpf_map_ops___95 *ops;
	struct bpf_map___96 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___149 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___95;

struct bpf_jit_poke_descriptor___95;

struct bpf_prog_ops___87;

struct btf_mod_pair___95;

struct bpf_prog_offload___93;

struct bpf_prog_aux___96 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___87 *dst_prog;
	struct bpf_trampoline___95 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___87 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___95 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___87 *ops;
	struct bpf_map___96 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___95 *used_btfs;
	struct bpf_prog___87 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___96 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___93 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___93;

struct bpf_map_dev_ops___93 {
	int (*map_get_next_key)(struct bpf_offloaded_map___93 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___93 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___93 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___93 *, void *);
};

struct bpf_offloaded_map___93 {
	struct bpf_map___96 map;
	struct net_device___93 *netdev;
	const struct bpf_map_dev_ops___93 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___87 {
	int (*test_run)(struct bpf_prog___87 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___93 {
	struct bpf_prog___87 *prog;
	struct net_device___93 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___95 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___87 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___268 *mod;
};

struct bpf_jit_poke_descriptor___95 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___96 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___95 {
	struct btf *btf;
	struct module___268 *module;
};

struct cftype___211;

struct cgroup_subsys___211 {
	struct cgroup_subsys_state___211 * (*css_alloc)(struct cgroup_subsys_state___211 *);
	int (*css_online)(struct cgroup_subsys_state___211 *);
	void (*css_offline)(struct cgroup_subsys_state___211 *);
	void (*css_released)(struct cgroup_subsys_state___211 *);
	void (*css_free)(struct cgroup_subsys_state___211 *);
	void (*css_reset)(struct cgroup_subsys_state___211 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___211 *, int);
	int (*css_extra_stat_show)(struct seq_file___259 *, struct cgroup_subsys_state___211 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___291 *, struct css_set___211 *);
	void (*cancel_fork)(struct task_struct___291 *, struct css_set___211 *);
	void (*fork)(struct task_struct___291 *);
	void (*exit)(struct task_struct___291 *);
	void (*release)(struct task_struct___291 *);
	void (*bind)(struct cgroup_subsys_state___211 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___211 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___211 *dfl_cftypes;
	struct cftype___211 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___211 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___211 *updated_children;
	struct cgroup___211 *updated_next;
};

struct cgroup_root___211 {
	struct kernfs_root___272 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___211 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___211 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___211 *ss;
	struct list_head node;
	struct kernfs_ops___272 *kf_ops;
	int (*open)(struct kernfs_open_file___272 *);
	void (*release)(struct kernfs_open_file___272 *);
	u64 (*read_u64)(struct cgroup_subsys_state___211 *, struct cftype___211 *);
	s64 (*read_s64)(struct cgroup_subsys_state___211 *, struct cftype___211 *);
	int (*seq_show)(struct seq_file___259 *, void *);
	void * (*seq_start)(struct seq_file___259 *, loff_t *);
	void * (*seq_next)(struct seq_file___259 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___259 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___211 *, struct cftype___211 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___211 *, struct cftype___211 *, s64);
	ssize_t (*write)(struct kernfs_open_file___272 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___272 *, struct poll_table_struct___205 *);
};

struct xdp_rxq_info___93 {
	struct net_device___93 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___93 {
	struct net_device___93 *dev;
};

struct xdp_buff___93 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___93 *rxq;
	struct xdp_txq_info___93 *txq;
	u32 frame_sz;
};

struct xdp_frame___93 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___93 *dev_rx;
};

struct netlink_skb_parms___19 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___80 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___93 {
	struct sk_buff___94 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___94 *, struct netlink_callback___93 *);
	int (*done)(struct netlink_callback___93 *);
	void *data;
	struct module___268 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___93 {
	int (*create)(struct sk_buff___94 *, struct net_device___93 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___94 *, unsigned char *);
	int (*cache)(const struct neighbour___80 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___93 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___94 *);
};

struct netdev_queue___93 {
	struct net_device___93 *dev;
	struct Qdisc___87 *qdisc;
	struct Qdisc___87 *qdisc_sleeping;
	struct kobject___272 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___93 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___87 {
	struct sk_buff___94 *head;
	struct sk_buff___94 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___87;

struct Qdisc___87 {
	int (*enqueue)(struct sk_buff___94 *, struct Qdisc___87 *, struct sk_buff___94 **);
	struct sk_buff___94 * (*dequeue)(struct Qdisc___87 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___87 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___93 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___93 gso_skb;
	struct qdisc_skb_head___87 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___87 *next_sched;
	struct sk_buff_head___93 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___93 {
	struct xdp_rxq_info___93 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___272 kobj;
	struct net_device___93 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___93 {
	enum net_device_path_type type;
	const struct net_device___93 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___93 = 0,
				DEV_PATH_BR_VLAN_TAG___93 = 1,
				DEV_PATH_BR_VLAN_UNTAG___93 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___93 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___93 {
	const struct net_device___93 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___93 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___87 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___93 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___93 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___94 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___93 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___93 *dev;
	const char *name;
};

struct net_device_ops___93 {
	int (*ndo_init)(struct net_device___93 *);
	void (*ndo_uninit)(struct net_device___93 *);
	int (*ndo_open)(struct net_device___93 *);
	int (*ndo_stop)(struct net_device___93 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___94 *, struct net_device___93 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___94 *, struct net_device___93 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___93 *, struct sk_buff___94 *, struct net_device___93 *);
	void (*ndo_change_rx_flags)(struct net_device___93 *, int);
	void (*ndo_set_rx_mode)(struct net_device___93 *);
	int (*ndo_set_mac_address)(struct net_device___93 *, void *);
	int (*ndo_validate_addr)(struct net_device___93 *);
	int (*ndo_do_ioctl)(struct net_device___93 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___93 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___93 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___93 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___93 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___93 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___93 *, int);
	int (*ndo_neigh_setup)(struct net_device___93 *, struct neigh_parms___80 *);
	void (*ndo_tx_timeout)(struct net_device___93 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___93 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___93 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___93 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___93 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___93 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___93 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___93 *);
	int (*ndo_netpoll_setup)(struct net_device___93 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___93 *);
	int (*ndo_set_vf_mac)(struct net_device___93 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___93 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___93 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___93 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___93 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___93 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___93 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___93 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___93 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___93 *, int, struct sk_buff___94 *);
	int (*ndo_get_vf_guid)(struct net_device___93 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___93 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___93 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___93 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___93 *);
	int (*ndo_fcoe_disable)(struct net_device___93 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___93 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___93 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___93 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___93 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___93 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___93 *, const struct sk_buff___94 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___93 *, struct net_device___93 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___93 *, struct net_device___93 *);
	struct net_device___93 * (*ndo_get_xmit_slave)(struct net_device___93 *, struct sk_buff___94 *, bool);
	struct net_device___93 * (*ndo_sk_get_lower_dev)(struct net_device___93 *, struct sock___80 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___93 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___93 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___93 *, struct neighbour___80 *);
	void (*ndo_neigh_destroy)(struct net_device___93 *, struct neighbour___80 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___93 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___93 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___94 *, struct netlink_callback___93 *, struct net_device___93 *, struct net_device___93 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___94 *, struct nlattr **, struct net_device___93 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___93 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___94 *, u32, u32, struct net_device___93 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___93 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___93 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___93 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___93 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___93 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___93 *, struct net_device___93 *);
	void (*ndo_dfwd_del_station)(struct net_device___93 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___93 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___93 *);
	int (*ndo_change_proto_down)(struct net_device___93 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___93 *, struct sk_buff___94 *);
	void (*ndo_set_rx_headroom)(struct net_device___93 *, int);
	int (*ndo_bpf)(struct net_device___93 *, struct netdev_bpf___93 *);
	int (*ndo_xdp_xmit)(struct net_device___93 *, int, struct xdp_frame___93 **, u32);
	struct net_device___93 * (*ndo_xdp_get_xmit_slave)(struct net_device___93 *, struct xdp_buff___93 *);
	int (*ndo_xsk_wakeup)(struct net_device___93 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___93 *);
	int (*ndo_tunnel_ctl)(struct net_device___93 *, struct ip_tunnel_parm *, int);
	struct net_device___93 * (*ndo_get_peer_dev)(struct net_device___93 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___93 *, struct net_device_path___93 *);
};

struct neigh_parms___80 {
	possible_net_t___93 net;
	struct net_device___93 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___80 *);
	struct neigh_table___80 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___80 {
	u32 (*l3mdev_fib_table)(const struct net_device___93 *);
	struct sk_buff___94 * (*l3mdev_l3_rcv)(struct net_device___93 *, struct sk_buff___94 *, u16);
	struct sk_buff___94 * (*l3mdev_l3_out)(struct net_device___93 *, struct sock___80 *, struct sk_buff___94 *, u16);
	struct dst_entry___80 * (*l3mdev_link_scope_lookup)(const struct net_device___93 *, struct flowi6 *);
};

struct ndisc_ops___62 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___93 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___93 *, struct neighbour___80 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___93 *, u8, struct neighbour___80 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___93 *, struct sk_buff___94 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___98 *, struct net_device___93 *, const struct prefix_info *, struct inet6_dev___62 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___20;

struct ip_mc_list___7;

struct in_device___20 {
	struct net_device___93 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___20 *ifa_list;
	struct ip_mc_list___7 *mc_list;
	struct ip_mc_list___7 **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list___7 *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___80 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___62;

struct ifacaddr6___25;

struct inet6_dev___62 {
	struct net_device___93 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___62 *mc_list;
	struct ifmcaddr6___62 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___93 mc_query_queue;
	struct sk_buff_head___93 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___25 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___80 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___87;

struct tcf_block___87;

struct mini_Qdisc___87 {
	struct tcf_proto___87 *filter_list;
	struct tcf_block___87 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___87 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___93 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___93 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___98 *, struct net_device___93 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___93 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___93 *, struct list_head *);
	size_t (*get_size)(const struct net_device___93 *);
	int (*fill_info)(struct sk_buff___94 *, const struct net_device___93 *);
	size_t (*get_xstats_size)(const struct net_device___93 *);
	int (*fill_xstats)(struct sk_buff___94 *, const struct net_device___93 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___93 *, struct net_device___93 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___93 *, const struct net_device___93 *);
	int (*fill_slave_info)(struct sk_buff___94 *, const struct net_device___93 *, const struct net_device___93 *);
	struct net___98 * (*get_link_net)(const struct net_device___93 *);
	size_t (*get_linkxstats_size)(const struct net_device___93 *, int);
	int (*fill_linkxstats)(struct sk_buff___94 *, const struct net_device___93 *, int *, int);
};

struct netdev_notifier_info___17 {
	struct net_device___93 *dev;
	struct netlink_ext_ack *extack;
};

struct in_ifaddr___20 {
	struct hlist_node hash;
	struct in_ifaddr___20 *ifa_next;
	struct in_device___20 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct ip_mc_list___7 {
	struct in_device___20 *interface;
	__be32 multiaddr;
	unsigned int sfmode;
	struct ip_sf_list *sources;
	struct ip_sf_list *tomb;
	long unsigned int sfcount[2];
	union {
		struct ip_mc_list___7 *next;
		struct ip_mc_list___7 *next_rcu;
	};
	struct ip_mc_list___7 *next_hash;
	struct timer_list timer;
	int users;
	refcount_t refcnt;
	spinlock_t lock;
	char tm_running;
	char reporter;
	char unsolicit_count;
	char loaded;
	unsigned char gsquery;
	unsigned char crcount;
	struct callback_head rcu;
};

enum {
	PIM_TYPE_HELLO = 0,
	PIM_TYPE_REGISTER = 1,
	PIM_TYPE_REGISTER_STOP = 2,
	PIM_TYPE_JOIN_PRUNE = 3,
	PIM_TYPE_BOOTSTRAP = 4,
	PIM_TYPE_ASSERT = 5,
	PIM_TYPE_GRAFT = 6,
	PIM_TYPE_GRAFT_ACK = 7,
	PIM_TYPE_CANDIDATE_RP_ADV = 8,
};

struct pimreghdr {
	__u8 type;
	__u8 reserved;
	__be16 csum;
	__be32 flags;
};

typedef int (*rtnl_doit_func___11)(struct sk_buff___94 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___11)(struct sk_buff___94 *, struct netlink_callback___93 *);

struct fib_rule___80 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___80 *ctarget;
	struct net___98 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___80 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___80 *rule;
	u32 table;
	int flags;
};

typedef short unsigned int vifi_t;

struct vifctl {
	vifi_t vifc_vifi;
	unsigned char vifc_flags;
	unsigned char vifc_threshold;
	unsigned int vifc_rate_limit;
	union {
		struct in_addr vifc_lcl_addr;
		int vifc_lcl_ifindex;
	};
	struct in_addr vifc_rmt_addr;
};

struct mfcctl {
	struct in_addr mfcc_origin;
	struct in_addr mfcc_mcastgrp;
	vifi_t mfcc_parent;
	unsigned char mfcc_ttls[32];
	unsigned int mfcc_pkt_cnt;
	unsigned int mfcc_byte_cnt;
	unsigned int mfcc_wrong_if;
	int mfcc_expire;
};

struct sioc_sg_req {
	struct in_addr src;
	struct in_addr grp;
	long unsigned int pktcnt;
	long unsigned int bytecnt;
	long unsigned int wrong_if;
};

struct sioc_vif_req {
	vifi_t vifi;
	long unsigned int icount;
	long unsigned int ocount;
	long unsigned int ibytes;
	long unsigned int obytes;
};

struct igmpmsg {
	__u32 unused1;
	__u32 unused2;
	unsigned char im_msgtype;
	unsigned char im_mbz;
	unsigned char im_vif;
	unsigned char im_vif_hi;
	struct in_addr im_src;
	struct in_addr im_dst;
};

enum {
	IPMRA_TABLE_UNSPEC = 0,
	IPMRA_TABLE_ID = 1,
	IPMRA_TABLE_CACHE_RES_QUEUE_LEN = 2,
	IPMRA_TABLE_MROUTE_REG_VIF_NUM = 3,
	IPMRA_TABLE_MROUTE_DO_ASSERT = 4,
	IPMRA_TABLE_MROUTE_DO_PIM = 5,
	IPMRA_TABLE_VIFS = 6,
	IPMRA_TABLE_MROUTE_DO_WRVIFWHOLE = 7,
	__IPMRA_TABLE_MAX = 8,
};

enum {
	IPMRA_VIF_UNSPEC = 0,
	IPMRA_VIF = 1,
	__IPMRA_VIF_MAX = 2,
};

enum {
	IPMRA_VIFA_UNSPEC = 0,
	IPMRA_VIFA_IFINDEX = 1,
	IPMRA_VIFA_VIF_ID = 2,
	IPMRA_VIFA_FLAGS = 3,
	IPMRA_VIFA_BYTES_IN = 4,
	IPMRA_VIFA_BYTES_OUT = 5,
	IPMRA_VIFA_PACKETS_IN = 6,
	IPMRA_VIFA_PACKETS_OUT = 7,
	IPMRA_VIFA_LOCAL_ADDR = 8,
	IPMRA_VIFA_REMOTE_ADDR = 9,
	IPMRA_VIFA_PAD = 10,
	__IPMRA_VIFA_MAX = 11,
};

enum {
	IPMRA_CREPORT_UNSPEC = 0,
	IPMRA_CREPORT_MSGTYPE = 1,
	IPMRA_CREPORT_VIF_ID = 2,
	IPMRA_CREPORT_SRC_ADDR = 3,
	IPMRA_CREPORT_DST_ADDR = 4,
	IPMRA_CREPORT_PKT = 5,
	IPMRA_CREPORT_TABLE = 6,
	__IPMRA_CREPORT_MAX = 7,
};

struct block_device_operations___175;

struct gendisk___178 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___178 *part0;
	const struct block_device_operations___175 *fops;
	struct request_queue___175 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___161 *bdi;
	struct kobject___272 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___272 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___175 {
	struct bio___175 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___201 *bip_vec;
	struct bio_vec___201 bip_inline_vecs[0];
};

struct blkcg___163;

struct blkg_policy_data___163;

struct blkcg_gq___163 {
	struct request_queue___175 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___163 *blkcg;
	struct blkcg_gq___163 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___163 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___175 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___175(struct request___175 *);

typedef void integrity_complete_fn___175(struct request___175 *, unsigned int);

struct blk_integrity_profile___175 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___175 *prepare_fn;
	integrity_complete_fn___175 *complete_fn;
	const char *name;
};

struct block_device_operations___175 {
	blk_qc_t (*submit_bio)(struct bio___175 *);
	int (*open)(struct block_device___178 *, fmode_t);
	void (*release)(struct gendisk___178 *, fmode_t);
	int (*rw_page)(struct block_device___178 *, sector_t, struct page___289 *, unsigned int);
	int (*ioctl)(struct block_device___178 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___178 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___178 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___178 *);
	int (*getgeo)(struct block_device___178 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___178 *, bool);
	void (*swap_slot_free_notify)(struct block_device___178 *, long unsigned int);
	int (*report_zones)(struct gendisk___178 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___178 *, umode_t *);
	struct module___268 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___178 *, sector_t *);
};

typedef void rq_end_io_fn___175(struct request___175 *, blk_status_t);

struct request___175 {
	struct request_queue___175 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___170 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___175 *bio;
	struct bio___175 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___201 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___175 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___175 *saved_end_io;
		} flush;
	};
	struct gendisk___178 *rq_disk;
	struct block_device___178 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___175 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___170 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___175 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___272 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___284 *debugfs_dir;
	struct dentry___284 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___175;

struct elevator_mq_ops___175 {
	int (*init_sched)(struct request_queue___175 *, struct elevator_type___175 *);
	void (*exit_sched)(struct elevator_queue___175 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___170 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___170 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___170 *);
	bool (*allow_merge)(struct request_queue___175 *, struct request___175 *, struct bio___175 *);
	bool (*bio_merge)(struct request_queue___175 *, struct bio___175 *, unsigned int);
	int (*request_merge)(struct request_queue___175 *, struct request___175 **, struct bio___175 *);
	void (*request_merged)(struct request_queue___175 *, struct request___175 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___175 *, struct request___175 *, struct request___175 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___175 *);
	void (*finish_request)(struct request___175 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___170 *, struct list_head *, bool);
	struct request___175 * (*dispatch_request)(struct blk_mq_hw_ctx___170 *);
	bool (*has_work)(struct blk_mq_hw_ctx___170 *);
	void (*completed_request)(struct request___175 *, u64);
	void (*requeue_request)(struct request___175 *);
	struct request___175 * (*former_request)(struct request_queue___175 *, struct request___175 *);
	struct request___175 * (*next_request)(struct request_queue___175 *, struct request___175 *);
	void (*init_icq)(struct io_cq___175 *);
	void (*exit_icq)(struct io_cq___175 *);
};

struct elv_fs_entry___175;

struct elevator_type___175 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___175 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___175 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___268 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___175 {
	struct elevator_type___175 *type;
	void *elevator_data;
	struct kobject___272 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___175 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___175 *, char *);
	ssize_t (*store)(struct elevator_queue___175 *, const char *, size_t);
};

struct blk_mq_queue_data___170;

struct blk_mq_ops___170 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___170 *, const struct blk_mq_queue_data___170 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___170 *);
	int (*get_budget)(struct request_queue___175 *);
	void (*put_budget)(struct request_queue___175 *, int);
	void (*set_rq_budget_token)(struct request___175 *, int);
	int (*get_rq_budget_token)(struct request___175 *);
	enum blk_eh_timer_return (*timeout)(struct request___175 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___170 *);
	void (*complete)(struct request___175 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___170 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___170 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___170 *, struct request___175 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___170 *, struct request___175 *, unsigned int);
	void (*initialize_rq_fn)(struct request___175 *);
	void (*cleanup_rq)(struct request___175 *);
	bool (*busy)(struct request_queue___175 *);
	int (*map_queues)(struct blk_mq_tag_set___170 *);
	void (*show_rq)(struct seq_file___259 *, struct request___175 *);
};

struct blk_mq_tag_set___170 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___170 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___170 {
	struct request___175 *rq;
	bool last;
};

struct blkcg_policy_data___163;

struct blkcg___163 {
	struct cgroup_subsys_state___211 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___163 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___163 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___163 {
	struct blkcg___163 *blkcg;
	int plid;
};

struct blkg_policy_data___163 {
	struct blkcg_gq___163 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___149 {
	struct mem_cgroup___149 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___149 {
	struct lruvec___157 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___149 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___149 *memcg;
};

struct obj_cgroup___149 {
	struct percpu_ref refcnt;
	struct mem_cgroup___149 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___87 {
	spinlock_t *lock;
	struct sk_buff___94 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___87;

struct Qdisc_ops___87 {
	struct Qdisc_ops___87 *next;
	const struct Qdisc_class_ops___87 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___94 *, struct Qdisc___87 *, struct sk_buff___94 **);
	struct sk_buff___94 * (*dequeue)(struct Qdisc___87 *);
	struct sk_buff___94 * (*peek)(struct Qdisc___87 *);
	int (*init)(struct Qdisc___87 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___87 *);
	void (*destroy)(struct Qdisc___87 *);
	int (*change)(struct Qdisc___87 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___87 *);
	int (*change_tx_queue_len)(struct Qdisc___87 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___87 *, unsigned int);
	int (*dump)(struct Qdisc___87 *, struct sk_buff___94 *);
	int (*dump_stats)(struct Qdisc___87 *, struct gnet_dump___87 *);
	void (*ingress_block_set)(struct Qdisc___87 *, u32);
	void (*egress_block_set)(struct Qdisc___87 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___87 *);
	u32 (*egress_block_get)(struct Qdisc___87 *);
	struct module___268 *owner;
};

struct Qdisc_class_ops___87 {
	unsigned int flags;
	struct netdev_queue___93 * (*select_queue)(struct Qdisc___87 *, struct tcmsg *);
	int (*graft)(struct Qdisc___87 *, long unsigned int, struct Qdisc___87 *, struct Qdisc___87 **, struct netlink_ext_ack *);
	struct Qdisc___87 * (*leaf)(struct Qdisc___87 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___87 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___87 *, u32);
	int (*change)(struct Qdisc___87 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___87 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___87 *, struct qdisc_walker *);
	struct tcf_block___87 * (*tcf_block)(struct Qdisc___87 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___87 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___87 *, long unsigned int);
	int (*dump)(struct Qdisc___87 *, long unsigned int, struct sk_buff___94 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___87 *, long unsigned int, struct gnet_dump___87 *);
};

struct tcf_chain___87;

struct tcf_block___87 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___98 *net;
	struct Qdisc___87 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___87 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___87;

struct tcf_proto_ops___87;

struct tcf_proto___87 {
	struct tcf_proto___87 *next;
	void *root;
	int (*classify)(struct sk_buff___94 *, const struct tcf_proto___87 *, struct tcf_result___87 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___87 *ops;
	struct tcf_chain___87 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___87 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___87 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___87 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___94 *, const struct tcf_proto___87 *, struct tcf_result___87 *);
	int (*init)(struct tcf_proto___87 *);
	void (*destroy)(struct tcf_proto___87 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___87 *, u32);
	void (*put)(struct tcf_proto___87 *, void *);
	int (*change)(struct net___98 *, struct sk_buff___94 *, struct tcf_proto___87 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___87 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___87 *);
	void (*walk)(struct tcf_proto___87 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___87 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___87 *, void *);
	void (*hw_del)(struct tcf_proto___87 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___98 *, struct tcf_chain___87 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___98 *, struct tcf_proto___87 *, void *, struct sk_buff___94 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___98 *, struct tcf_proto___87 *, void *, struct sk_buff___94 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___94 *, struct net___98 *, void *);
	struct module___268 *owner;
	int flags;
};

struct tcf_chain___87 {
	struct mutex filter_chain_lock;
	struct tcf_proto___87 *filter_chain;
	struct list_head list;
	struct tcf_block___87 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___87 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___80 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___87 *prog;
};

struct pneigh_entry___80;

struct neigh_hash_table___80;

struct neigh_table___80 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___93 *, __u32 *);
	bool (*key_eq)(const struct neighbour___80 *, const void *);
	int (*constructor)(struct neighbour___80 *);
	int (*pconstructor)(struct pneigh_entry___80 *);
	void (*pdestructor)(struct pneigh_entry___80 *);
	void (*proxy_redo)(struct sk_buff___94 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___93 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___80 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___93 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___80 *nht;
	struct pneigh_entry___80 **phash_buckets;
};

struct neigh_ops___80 {
	int family;
	void (*solicit)(struct neighbour___80 *, struct sk_buff___94 *);
	void (*error_report)(struct neighbour___80 *, struct sk_buff___94 *);
	int (*output)(struct neighbour___80 *, struct sk_buff___94 *);
	int (*connected_output)(struct neighbour___80 *, struct sk_buff___94 *);
};

struct pneigh_entry___80 {
	struct pneigh_entry___80 *next;
	possible_net_t___93 net;
	struct net_device___93 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___80 {
	struct neighbour___80 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___56 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___98 *, struct sock___80 *, struct sk_buff___94 *);
	int (*orig_input)(struct sk_buff___94 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct request_sock_ops___65;

struct timewait_sock_ops___64;

struct proto___80 {
	void (*close)(struct sock___80 *, long int);
	int (*pre_connect)(struct sock___80 *, struct sockaddr *, int);
	int (*connect)(struct sock___80 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___80 *, int);
	struct sock___80 * (*accept)(struct sock___80 *, int, int *, bool);
	int (*ioctl)(struct sock___80 *, int, long unsigned int);
	int (*init)(struct sock___80 *);
	void (*destroy)(struct sock___80 *);
	void (*shutdown)(struct sock___80 *, int);
	int (*setsockopt)(struct sock___80 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___80 *, int, int, char *, int *);
	void (*keepalive)(struct sock___80 *, int);
	int (*compat_ioctl)(struct sock___80 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___80 *, struct msghdr___82 *, size_t);
	int (*recvmsg)(struct sock___80 *, struct msghdr___82 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___80 *, struct page___289 *, int, size_t, int);
	int (*bind)(struct sock___80 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___80 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___80 *, struct sk_buff___94 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___80 *);
	int (*hash)(struct sock___80 *);
	void (*unhash)(struct sock___80 *);
	void (*rehash)(struct sock___80 *);
	int (*get_port)(struct sock___80 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___80 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___80 *, int);
	bool (*sock_is_readable)(struct sock___80 *);
	void (*enter_memory_pressure)(struct sock___80 *);
	void (*leave_memory_pressure)(struct sock___80 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___65 *rsk_prot;
	struct timewait_sock_ops___64 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___268 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___80 *, int);
};

struct request_sock___66;

struct request_sock_ops___65 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___80 *, struct request_sock___66 *);
	void (*send_ack)(const struct sock___80 *, struct sk_buff___94 *, struct request_sock___66 *);
	void (*send_reset)(const struct sock___80 *, struct sk_buff___94 *);
	void (*destructor)(struct request_sock___66 *);
	void (*syn_ack_timeout)(const struct request_sock___66 *);
};

struct timewait_sock_ops___64 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___80 *, struct sock___80 *, void *);
	void (*twsk_destructor)(struct sock___80 *);
};

struct request_sock___66 {
	struct sock_common___80 __req_common;
	struct request_sock___66 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___65 *rsk_ops;
	struct sock___80 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___19 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___80 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___19 {
	struct inet_cork___19 base;
	struct flowi fl;
};

struct ipv6_pinfo___18;

struct inet_sock___19 {
	struct sock___80 sk;
	struct ipv6_pinfo___18 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___19 cork;
};

struct ipv6_fl_socklist___18;

struct ipv6_pinfo___18 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___18 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___94 *pktoptions;
	struct sk_buff___94 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___18;

struct ipv6_fl_socklist___18 {
	struct ipv6_fl_socklist___18 *next;
	struct ip6_flowlabel___18 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___62 {
	struct in6_addr mca_addr;
	struct inet6_dev___62 *idev;
	struct ifmcaddr6___62 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___25 {
	struct in6_addr aca_addr;
	struct fib6_info___25 *aca_rt;
	struct ifacaddr6___25 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___18 {
	struct ip6_flowlabel___18 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___261 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___98 *fl_net;
};

struct fib_nh_exception___25 {
	struct fib_nh_exception___25 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___27 *fnhe_rth_input;
	struct rtable___27 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___27 {
	struct dst_entry___80 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___25 {
	struct fib_nh_exception___25 *chain;
};

struct fib_info___16;

struct fib_nh___16 {
	struct fib_nh_common___25 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___16 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___16 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___98 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___16 *nh;
	struct callback_head rcu;
	struct fib_nh___16 fib_nh[0];
};

struct nh_info___16;

struct nh_group___16;

struct nexthop___16 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___98 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___16 *nh_info;
		struct nh_group___16 *nh_grp;
	};
};

struct fib_dump_filter___3 {
	u32 table_id;
	bool filter_set;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___93 *dev;
};

struct vif_device {
	struct net_device___93 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	int link;
	struct netdev_phys_item_id dev_parent_id;
	__be32 local;
	__be32 remote;
};

struct vif_entry_notifier_info {
	struct fib_notifier_info info;
	struct net_device___93 *dev;
	short unsigned int vif_index;
	short unsigned int vif_flags;
	u32 tb_id;
};

enum {
	MFC_STATIC = 1,
	MFC_OFFLOAD = 2,
};

struct mr_mfc {
	struct rhlist_head mnode;
	short unsigned int mfc_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___93 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			long unsigned int lastuse;
			unsigned char ttls[32];
			refcount_t refcount;
		} res;
	} mfc_un;
	struct list_head list;
	struct callback_head rcu;
	void (*free)(struct callback_head *);
};

struct mfc_entry_notifier_info {
	struct fib_notifier_info info;
	struct mr_mfc *mfc;
	u32 tb_id;
};

struct mr_table_ops {
	const struct rhashtable_params *rht_params;
	void *cmparg_any;
};

struct mr_table {
	struct list_head list;
	possible_net_t___93 net;
	struct mr_table_ops ops;
	u32 id;
	struct sock___80 *mroute_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc_unres_queue;
	struct vif_device vif_table[32];
	struct rhltable mfc_hash;
	struct list_head mfc_cache_list;
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	bool mroute_do_wrvifwhole;
	int mroute_reg_vif_num;
};

struct mr_vif_iter {
	struct seq_net_private___12 p;
	struct mr_table *mrt;
	int ct;
};

struct mr_mfc_iter {
	struct seq_net_private___12 p;
	struct mr_table *mrt;
	struct list_head *cache;
	spinlock_t *lock;
};

struct mfc_cache_cmp_arg {
	__be32 mfc_mcastgrp;
	__be32 mfc_origin;
};

struct mfc_cache {
	struct mr_mfc _c;
	union {
		struct {
			__be32 mfc_mcastgrp;
			__be32 mfc_origin;
		};
		struct mfc_cache_cmp_arg cmparg;
	};
};

struct net_protocol___7 {
	int (*early_demux)(struct sk_buff___94 *);
	int (*early_demux_handler)(struct sk_buff___94 *);
	int (*handler)(struct sk_buff___94 *);
	int (*err_handler)(struct sk_buff___94 *, u32);
	unsigned int no_policy: 1;
	unsigned int icmp_strict_tag_validation: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct raw_sock___2 {
	struct inet_sock___19 inet;
	struct icmp_filter filter;
	u32 ipmr_table;
};

struct nf_hook_state___17 {
	u8 hook;
	u8 pf;
	struct net_device___93 *in;
	struct net_device___93 *out;
	struct sock___80 *sk;
	struct net___98 *net;
	int (*okfn)(struct net___98 *, struct sock___80 *, struct sk_buff___94 *);
};

struct nh_info___16 {
	struct hlist_node dev_hash;
	struct nexthop___16 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___25 fib_nhc;
		struct fib_nh___16 fib_nh;
		struct fib6_nh___25 fib6_nh;
	};
};

struct nh_grp_entry___16;

struct nh_res_bucket___16 {
	struct nh_grp_entry___16 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___16 {
	struct nexthop___16 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___16 *nh_parent;
};

struct nh_res_table___16 {
	struct net___98 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___16 nh_buckets[0];
};

struct nh_group___16 {
	struct nh_group___16 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___16 *res_table;
	struct nh_grp_entry___16 nh_entries[0];
};

struct ipmr_result {
	struct mr_table *mrt;
};

struct compat_sioc_sg_req {
	struct in_addr src;
	struct in_addr grp;
	compat_ulong_t pktcnt;
	compat_ulong_t bytecnt;
	compat_ulong_t wrong_if;
};

struct compat_sioc_vif_req {
	vifi_t vifi;
	compat_ulong_t icount;
	compat_ulong_t ocount;
	compat_ulong_t ibytes;
	compat_ulong_t obytes;
};

struct seq_net_private___13 {
	struct net___80 *net;
};

struct rta_mfc_stats {
	__u64 mfcs_packets;
	__u64 mfcs_bytes;
	__u64 mfcs_wrong_if;
};

struct fib_dump_filter___4 {
	u32 table_id;
	bool filter_set;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___75 *dev;
};

struct vif_device___2 {
	struct net_device___75 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	int link;
	struct netdev_phys_item_id dev_parent_id;
	__be32 local;
	__be32 remote;
};

struct vif_entry_notifier_info___2 {
	struct fib_notifier_info info;
	struct net_device___75 *dev;
	short unsigned int vif_index;
	short unsigned int vif_flags;
	u32 tb_id;
};

struct mr_mfc___2 {
	struct rhlist_head mnode;
	short unsigned int mfc_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___75 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			long unsigned int lastuse;
			unsigned char ttls[32];
			refcount_t refcount;
		} res;
	} mfc_un;
	struct list_head list;
	struct callback_head rcu;
	void (*free)(struct callback_head *);
};

struct mfc_entry_notifier_info___2 {
	struct fib_notifier_info info;
	struct mr_mfc___2 *mfc;
	u32 tb_id;
};

struct mr_table___2 {
	struct list_head list;
	possible_net_t___75 net;
	struct mr_table_ops ops;
	u32 id;
	struct sock___62 *mroute_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc_unres_queue;
	struct vif_device___2 vif_table[32];
	struct rhltable mfc_hash;
	struct list_head mfc_cache_list;
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	bool mroute_do_wrvifwhole;
	int mroute_reg_vif_num;
};

struct mr_vif_iter___2 {
	struct seq_net_private___13 p;
	struct mr_table___2 *mrt;
	int ct;
};

struct mr_mfc_iter___2 {
	struct seq_net_private___13 p;
	struct mr_table___2 *mrt;
	struct list_head *cache;
	spinlock_t *lock;
};

typedef unsigned int nf_hookfn___20(void *, struct sk_buff___92 *, const struct nf_hook_state *);

struct module_version_attribute___9 {
	struct module_attribute___266 mattr;
	const char *module_name;
	const char *version;
};

struct bictcp {
	u32 cnt;
	u32 last_max_cwnd;
	u32 last_cwnd;
	u32 last_time;
	u32 bic_origin_point;
	u32 bic_K;
	u32 delay_min;
	u32 epoch_start;
	u32 ack_cnt;
	u32 tcp_cwnd;
	u16 unused;
	u8 sample_cnt;
	u8 found;
	u32 round_start;
	u32 end_seq;
	u32 last_ack;
	u32 curr_rtt;
};

struct dentry___285;

struct super_block___285;

struct module___269;

struct file_system_type___285 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___285 * (*mount)(struct file_system_type___285 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___285 *);
	struct module___269 *owner;
	struct file_system_type___285 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___285;

struct kiocb___285;

struct iov_iter___205;

struct poll_table_struct___206;

struct vm_area_struct___290;

struct inode___285;

struct file_lock___285;

struct page___290;

struct pipe_inode_info___126;

struct seq_file___260;

struct file_operations___286 {
	struct module___269 *owner;
	loff_t (*llseek)(struct file___285 *, loff_t, int);
	ssize_t (*read)(struct file___285 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___285 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___285 *, struct iov_iter___205 *);
	ssize_t (*write_iter)(struct kiocb___285 *, struct iov_iter___205 *);
	int (*iopoll)(struct kiocb___285 *, bool);
	int (*iterate)(struct file___285 *, struct dir_context *);
	int (*iterate_shared)(struct file___285 *, struct dir_context *);
	__poll_t (*poll)(struct file___285 *, struct poll_table_struct___206 *);
	long int (*unlocked_ioctl)(struct file___285 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___285 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___285 *, struct vm_area_struct___290 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___285 *, struct file___285 *);
	int (*flush)(struct file___285 *, fl_owner_t);
	int (*release)(struct inode___285 *, struct file___285 *);
	int (*fsync)(struct file___285 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___285 *, int);
	int (*lock)(struct file___285 *, int, struct file_lock___285 *);
	ssize_t (*sendpage)(struct file___285 *, struct page___290 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___285 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___285 *, long unsigned int);
	int (*flock)(struct file___285 *, int, struct file_lock___285 *);
	ssize_t (*splice_write)(struct pipe_inode_info___126 *, struct file___285 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___285 *, loff_t *, struct pipe_inode_info___126 *, size_t, unsigned int);
	int (*setlease)(struct file___285 *, long int, struct file_lock___285 **, void **);
	long int (*fallocate)(struct file___285 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___260 *, struct file___285 *);
	ssize_t (*copy_file_range)(struct file___285 *, loff_t, struct file___285 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___285 *, loff_t, struct file___285 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___285 *, loff_t, loff_t, int);
};

struct vmacache___290 {
	u64 seqnum;
	struct vm_area_struct___290 *vmas[4];
};

struct page_frag___290 {
	struct page___290 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___291;

struct pid___262;

struct nsproxy___271;

struct signal_struct___286;

struct bio_list___176;

struct backing_dev_info___162;

struct io_context___176;

struct css_set___212;

struct mem_cgroup___150;

struct request_queue___176;

struct vm_struct___268;

struct task_struct___292 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___292 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___291 *mm;
	struct mm_struct___291 *active_mm;
	struct vmacache___290 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___292 *real_parent;
	struct task_struct___292 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___292 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___262 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___271 *nsproxy;
	struct signal_struct___286 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___292 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___176 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___162 *backing_dev_info;
	struct io_context___176 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___212 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___126 *splice_pipe;
	struct page_frag___290 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___150 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___150 *active_memcg;
	struct request_queue___176 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___292 *oom_reaper_list;
	struct vm_struct___268 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___273;

struct kobj_type___273;

struct kernfs_node___273;

struct kobject___273 {
	const char *name;
	struct list_head entry;
	struct kobject___273 *parent;
	struct kset___273 *kset;
	struct kobj_type___273 *ktype;
	struct kernfs_node___273 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___270 {
	struct kobject___273 kobj;
	struct module___269 *mod;
	struct kobject___273 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___269 {
	struct module___269 *mod;
	struct latch_tree_node node;
};

struct module_layout___269 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___269 mtn;
};

struct module_attribute___269;

struct kernel_param___269;

struct module___269 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___270 mkobj;
	struct module_attribute___269 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___273 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___269 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___269 core_layout;
	struct module_layout___269 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___285;

struct path___285 {
	struct vfsmount___285 *mnt;
	struct dentry___285 *dentry;
};

struct fown_struct___262 {
	rwlock_t lock;
	struct pid___262 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___285;

struct file___285 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___285 f_path;
	struct inode___285 *f_inode;
	const struct file_operations___286 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___262 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___285 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___290 *pgtable_t___290;

struct page_pool___114;

struct dev_pagemap___280;

struct page___290 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___285 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___114 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___290 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___290 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___291 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___280 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___280;

struct vm_area_struct___290 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___290 *vm_next;
	struct vm_area_struct___290 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___291 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___280 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___285 *vm_file;
	struct file___285 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___290;

struct mm_struct___291 {
	struct {
		struct vm_area_struct___290 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___285 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___290 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___292 *owner;
		struct user_namespace___26 *user_ns;
		struct file___285 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___285;

struct address_space___285 {
	struct inode___285 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___285 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___266;

struct page_pool_params___114 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___266 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___114 {
	u32 count;
	struct page___290 *cache[128];
};

struct page_pool___114 {
	struct page_pool_params___114 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___290 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___114 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___280;

struct dev_pagemap___280 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___280 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___280;

struct vm_operations_struct___280 {
	void (*open)(struct vm_area_struct___290 *);
	void (*close)(struct vm_area_struct___290 *);
	int (*may_split)(struct vm_area_struct___290 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___290 *);
	int (*mprotect)(struct vm_area_struct___290 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___280 *);
	vm_fault_t (*huge_fault)(struct vm_fault___280 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___280 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___290 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___280 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___280 *);
	int (*access)(struct vm_area_struct___290 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___290 *);
	int (*set_policy)(struct vm_area_struct___290 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___290 *, long unsigned int);
	struct page___290 * (*find_special_page)(struct vm_area_struct___290 *, long unsigned int);
};

struct core_thread___290 {
	struct task_struct___292 *task;
	struct core_thread___290 *next;
};

struct core_state___290 {
	atomic_t nr_threads;
	struct core_thread___290 dumper;
	struct completion startup;
};

struct vm_fault___280 {
	const struct {
		struct vm_area_struct___290 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___290 *cow_page;
	struct page___290 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___290 prealloc_pte;
};

struct pid_namespace___262;

struct upid___262 {
	int nr;
	struct pid_namespace___262 *ns;
};

struct pid_namespace___262 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___292 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___262 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___262 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___262 numbers[1];
};

struct signal_struct___286 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___292 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___292 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___262 *pids[4];
	struct pid___262 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___291 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___99;

struct cgroup_namespace___212;

struct nsproxy___271 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___262 *pid_ns_for_children;
	struct net___99 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___212 *cgroup_ns;
};

struct bio___176;

struct bio_list___176 {
	struct bio___176 *head;
	struct bio___176 *tail;
};

struct cgroup_subsys_state___212;

struct bdi_writeback___162 {
	struct backing_dev_info___162 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___212 *memcg_css;
	struct cgroup_subsys_state___212 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___162 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___162 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___266 *dev;
	char dev_name[64];
	struct device___266 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___285 *debug_dir;
};

struct io_cq___176;

struct io_context___176 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___176 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___212;

struct css_set___212 {
	struct cgroup_subsys_state___212 *subsys[14];
	refcount_t refcount;
	struct css_set___212 *dom_cset;
	struct cgroup___212 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___212 *mg_src_cgrp;
	struct cgroup___212 *mg_dst_cgrp;
	struct css_set___212 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___285;

struct pipe_buffer___126;

struct pipe_inode_info___126 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___290 *tmp_page;
	struct fasync_struct___285 *fasync_readers;
	struct fasync_struct___285 *fasync_writers;
	struct pipe_buffer___126 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___212;

struct cgroup_subsys_state___212 {
	struct cgroup___212 *cgroup;
	struct cgroup_subsys___212 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___212 *parent;
};

struct cgroup_file___212 {
	struct kernfs_node___273 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___150;

struct mem_cgroup_per_node___150;

struct mem_cgroup___150 {
	struct cgroup_subsys_state___212 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___212 events_file;
	struct cgroup_file___212 events_local_file;
	struct cgroup_file___212 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___150 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___292 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___150 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___176;

struct blk_integrity___176 {
	const struct blk_integrity_profile___176 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___176 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___176 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___176;

struct elevator_queue___176;

struct blk_mq_ops___171;

struct blk_mq_hw_ctx___171;

struct gendisk___179;

struct blkcg_gq___164;

struct blk_mq_tag_set___171;

struct request_queue___176 {
	struct request___176 *last_merge;
	struct elevator_queue___176 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___171 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___171 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___179 *disk;
	struct kobject___273 kobj;
	struct kobject___273 *mq_kobj;
	struct blk_integrity___176 integrity;
	struct device___266 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___164 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___171 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___176 bio_split;
	struct dentry___285 *debugfs_dir;
	struct dentry___285 *sched_debugfs_dir;
	struct dentry___285 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___268 {
	struct vm_struct___268 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___290 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___158;

struct lruvec___158 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___158 *pgdat;
};

struct zone___158 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___158 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___158 {
	struct zone___158 *zone;
	int zone_idx;
};

struct zonelist___158 {
	struct zoneref___158 _zonerefs[321];
};

struct pglist_data___158 {
	struct zone___158 node_zones[5];
	struct zonelist___158 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___292 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___292 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___158 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___285;

struct dentry___285 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___285 *d_parent;
	struct qstr d_name;
	struct inode___285 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___285 *d_op;
	struct super_block___285 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___285;

struct inode___285 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___285 *i_op;
	struct super_block___285 *i_sb;
	struct address_space___285 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___162 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___286 *i_fop;
		void (*free_inode)(struct inode___285 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___285 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___126 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___285 {
	int (*d_revalidate)(struct dentry___285 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___285 *, unsigned int);
	int (*d_hash)(const struct dentry___285 *, struct qstr *);
	int (*d_compare)(const struct dentry___285 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___285 *);
	int (*d_init)(struct dentry___285 *);
	void (*d_release)(struct dentry___285 *);
	void (*d_prune)(struct dentry___285 *);
	void (*d_iput)(struct dentry___285 *, struct inode___285 *);
	char * (*d_dname)(struct dentry___285 *, char *, int);
	struct vfsmount___285 * (*d_automount)(struct path___285 *);
	int (*d_manage)(const struct path___285 *, bool);
	struct dentry___285 * (*d_real)(struct dentry___285 *, const struct inode___285 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___285;

struct mem_dqinfo___285 {
	struct quota_format_type___285 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___285;

struct quota_info___285 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___285 *files[3];
	struct mem_dqinfo___285 info[3];
	const struct quota_format_ops___285 *ops[3];
};

struct rcuwait___286 {
	struct task_struct___292 *task;
};

struct percpu_rw_semaphore___286 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___286 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___285 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___286 rw_sem[3];
};

struct shrink_control___150;

struct shrinker___150 {
	long unsigned int (*count_objects)(struct shrinker___150 *, struct shrink_control___150 *);
	long unsigned int (*scan_objects)(struct shrinker___150 *, struct shrink_control___150 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___285;

struct dquot_operations___285;

struct quotactl_ops___285;

struct block_device___179;

struct super_block___285 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___285 *s_type;
	const struct super_operations___285 *s_op;
	const struct dquot_operations___285 *dq_op;
	const struct quotactl_ops___285 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___285 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___179 *s_bdev;
	struct backing_dev_info___162 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___285 s_dquot;
	struct sb_writers___285 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___285 *s_d_op;
	int cleancache_poolid;
	struct shrinker___150 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___285 {
	struct dentry___285 *mnt_root;
	struct super_block___285 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___150 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___150 *memcg;
};

struct psi_group___212 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___292 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___88;

struct cgroup_bpf___88 {
	struct bpf_prog_array___88 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___88 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___212;

struct cgroup_rstat_cpu___212;

struct cgroup___212 {
	struct cgroup_subsys_state___212 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___273 *kn;
	struct cgroup_file___212 procs_file;
	struct cgroup_file___212 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___212 *subsys[14];
	struct cgroup_root___212 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___212 *dom_cgrp;
	struct cgroup___212 *old_dom_cgrp;
	struct cgroup_rstat_cpu___212 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___212 psi;
	struct cgroup_bpf___88 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___176 {
	struct request_queue___176 *q;
	struct io_context___176 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___285 {
	struct file___285 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___285 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___285 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___285 *ia_file;
};

struct dquot___285 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___285 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___285 {
	int qf_fmt_id;
	const struct quota_format_ops___285 *qf_ops;
	struct module___269 *qf_owner;
	struct quota_format_type___285 *qf_next;
};

struct quota_format_ops___285 {
	int (*check_quota_file)(struct super_block___285 *, int);
	int (*read_file_info)(struct super_block___285 *, int);
	int (*write_file_info)(struct super_block___285 *, int);
	int (*free_file_info)(struct super_block___285 *, int);
	int (*read_dqblk)(struct dquot___285 *);
	int (*commit_dqblk)(struct dquot___285 *);
	int (*release_dqblk)(struct dquot___285 *);
	int (*get_next_id)(struct super_block___285 *, struct kqid *);
};

struct dquot_operations___285 {
	int (*write_dquot)(struct dquot___285 *);
	struct dquot___285 * (*alloc_dquot)(struct super_block___285 *, int);
	void (*destroy_dquot)(struct dquot___285 *);
	int (*acquire_dquot)(struct dquot___285 *);
	int (*release_dquot)(struct dquot___285 *);
	int (*mark_dirty)(struct dquot___285 *);
	int (*write_info)(struct super_block___285 *, int);
	qsize_t * (*get_reserved_space)(struct inode___285 *);
	int (*get_projid)(struct inode___285 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___285 *, qsize_t *);
	int (*get_next_id)(struct super_block___285 *, struct kqid *);
};

struct quotactl_ops___285 {
	int (*quota_on)(struct super_block___285 *, int, int, const struct path___285 *);
	int (*quota_off)(struct super_block___285 *, int);
	int (*quota_enable)(struct super_block___285 *, unsigned int);
	int (*quota_disable)(struct super_block___285 *, unsigned int);
	int (*quota_sync)(struct super_block___285 *, int);
	int (*set_info)(struct super_block___285 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___285 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___285 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___285 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___285 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___285 *, unsigned int);
};

struct writeback_control___162;

struct address_space_operations___285 {
	int (*writepage)(struct page___290 *, struct writeback_control___162 *);
	int (*readpage)(struct file___285 *, struct page___290 *);
	int (*writepages)(struct address_space___285 *, struct writeback_control___162 *);
	int (*set_page_dirty)(struct page___290 *);
	int (*readpages)(struct file___285 *, struct address_space___285 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___285 *, struct address_space___285 *, loff_t, unsigned int, unsigned int, struct page___290 **, void **);
	int (*write_end)(struct file___285 *, struct address_space___285 *, loff_t, unsigned int, unsigned int, struct page___290 *, void *);
	sector_t (*bmap)(struct address_space___285 *, sector_t);
	void (*invalidatepage)(struct page___290 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___290 *, gfp_t);
	void (*freepage)(struct page___290 *);
	ssize_t (*direct_IO)(struct kiocb___285 *, struct iov_iter___205 *);
	int (*migratepage)(struct address_space___285 *, struct page___290 *, struct page___290 *, enum migrate_mode);
	bool (*isolate_page)(struct page___290 *, isolate_mode_t);
	void (*putback_page)(struct page___290 *);
	int (*launder_page)(struct page___290 *);
	int (*is_partially_uptodate)(struct page___290 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___290 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___285 *, struct page___290 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___285 *, sector_t *);
	void (*swap_deactivate)(struct file___285 *);
};

struct writeback_control___162 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___162 *wb;
	struct inode___285 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___202;

struct iov_iter___205 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___202 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___126 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___285 {
	struct dentry___285 * (*lookup)(struct inode___285 *, struct dentry___285 *, unsigned int);
	const char * (*get_link)(struct dentry___285 *, struct inode___285 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___285 *, int);
	struct posix_acl * (*get_acl)(struct inode___285 *, int, bool);
	int (*readlink)(struct dentry___285 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___285 *, struct dentry___285 *, umode_t, bool);
	int (*link)(struct dentry___285 *, struct inode___285 *, struct dentry___285 *);
	int (*unlink)(struct inode___285 *, struct dentry___285 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___285 *, struct dentry___285 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___285 *, struct dentry___285 *, umode_t);
	int (*rmdir)(struct inode___285 *, struct dentry___285 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___285 *, struct dentry___285 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___285 *, struct dentry___285 *, struct inode___285 *, struct dentry___285 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___285 *, struct iattr___285 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___285 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___285 *, char *, size_t);
	int (*fiemap)(struct inode___285 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___285 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___285 *, struct dentry___285 *, struct file___285 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___285 *, struct dentry___285 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___285 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___285 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___285 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___285 {
	void (*fl_copy_lock)(struct file_lock___285 *, struct file_lock___285 *);
	void (*fl_release_private)(struct file_lock___285 *);
};

struct lock_manager_operations___285;

struct file_lock___285 {
	struct file_lock___285 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___285 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___285 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___285 *fl_ops;
	const struct lock_manager_operations___285 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___285 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___285 *);
	int (*lm_grant)(struct file_lock___285 *, int);
	bool (*lm_break)(struct file_lock___285 *);
	int (*lm_change)(struct file_lock___285 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___285 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___285 *);
};

struct fasync_struct___285 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___285 *fa_next;
	struct file___285 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___285 {
	struct inode___285 * (*alloc_inode)(struct super_block___285 *);
	void (*destroy_inode)(struct inode___285 *);
	void (*free_inode)(struct inode___285 *);
	void (*dirty_inode)(struct inode___285 *, int);
	int (*write_inode)(struct inode___285 *, struct writeback_control___162 *);
	int (*drop_inode)(struct inode___285 *);
	void (*evict_inode)(struct inode___285 *);
	void (*put_super)(struct super_block___285 *);
	int (*sync_fs)(struct super_block___285 *, int);
	int (*freeze_super)(struct super_block___285 *);
	int (*freeze_fs)(struct super_block___285 *);
	int (*thaw_super)(struct super_block___285 *);
	int (*unfreeze_fs)(struct super_block___285 *);
	int (*statfs)(struct dentry___285 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___285 *, int *, char *);
	void (*umount_begin)(struct super_block___285 *);
	int (*show_options)(struct seq_file___260 *, struct dentry___285 *);
	int (*show_devname)(struct seq_file___260 *, struct dentry___285 *);
	int (*show_path)(struct seq_file___260 *, struct dentry___285 *);
	int (*show_stats)(struct seq_file___260 *, struct dentry___285 *);
	ssize_t (*quota_read)(struct super_block___285 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___285 *, int, const char *, size_t, loff_t);
	struct dquot___285 ** (*get_dquots)(struct inode___285 *);
	long int (*nr_cached_objects)(struct super_block___285 *, struct shrink_control___150 *);
	long int (*free_cached_objects)(struct super_block___285 *, struct shrink_control___150 *);
	struct file___285 * (*real_loop)(struct file___285 *);
};

struct wakeup_source___266;

struct dev_pm_info___266 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___266 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___266 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___266;

struct bus_type___266;

struct device_driver___266;

struct dev_pm_domain___266;

struct fwnode_handle___262;

struct class___266;

struct attribute_group___273;

struct device___266 {
	struct kobject___273 kobj;
	struct device___266 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___266 *type;
	struct bus_type___266 *bus;
	struct device_driver___266 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___266 power;
	struct dev_pm_domain___266 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___262 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___266 *class;
	const struct attribute_group___273 **groups;
	void (*release)(struct device___266 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___179 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___285 *bd_inode;
	struct super_block___285 *bd_super;
	void *bd_claiming;
	struct device___266 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___273 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___179 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___285 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___214)(struct file___285 *, wait_queue_head_t *, struct poll_table_struct___206 *);

struct poll_table_struct___206 {
	poll_queue_proc___214 _qproc;
	__poll_t _key;
};

struct seq_operations___260;

struct seq_file___260 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___260 *op;
	int poll_event;
	const struct file___285 *file;
	void *private;
};

typedef void bio_end_io_t___176(struct bio___176 *);

struct bio_vec___202 {
	struct page___290 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___176;

struct bio___176 {
	struct bio___176 *bi_next;
	struct block_device___179 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___176 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___164 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___176 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___202 *bi_io_vec;
	struct bio_set___176 *bi_pool;
	struct bio_vec___202 bi_inline_vecs[0];
};

struct kernfs_root___273;

struct kernfs_elem_dir___273 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___273 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___273;

struct kernfs_root___273 {
	struct kernfs_node___273 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___273 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___273 {
	struct kernfs_node___273 *target_kn;
};

struct kernfs_ops___273;

struct kernfs_elem_attr___273 {
	const struct kernfs_ops___273 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___273 *notify_next;
};

struct kernfs_node___273 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___273 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___273 dir;
		struct kernfs_elem_symlink___273 symlink;
		struct kernfs_elem_attr___273 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___273;

struct kernfs_ops___273 {
	int (*open)(struct kernfs_open_file___273 *);
	void (*release)(struct kernfs_open_file___273 *);
	int (*seq_show)(struct seq_file___260 *, void *);
	void * (*seq_start)(struct seq_file___260 *, loff_t *);
	void * (*seq_next)(struct seq_file___260 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___260 *, void *);
	ssize_t (*read)(struct kernfs_open_file___273 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___273 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___273 *, struct poll_table_struct___206 *);
	int (*mmap)(struct kernfs_open_file___273 *, struct vm_area_struct___290 *);
};

struct kernfs_syscall_ops___273 {
	int (*show_options)(struct seq_file___260 *, struct kernfs_root___273 *);
	int (*mkdir)(struct kernfs_node___273 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___273 *);
	int (*rename)(struct kernfs_node___273 *, struct kernfs_node___273 *, const char *);
	int (*show_path)(struct seq_file___260 *, struct kernfs_node___273 *, struct kernfs_root___273 *);
};

struct kernfs_open_file___273 {
	struct kernfs_node___273 *kn;
	struct file___285 *file;
	struct seq_file___260 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___280 *vm_ops;
};

struct sock___81;

struct kobj_ns_type_operations___81 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___81 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___99 *net;
} possible_net_t___94;

struct proto___81;

struct sock_common___81 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___81 *skc_prot;
	possible_net_t___94 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___81 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___95;

struct sk_buff_head___94 {
	struct sk_buff___95 *next;
	struct sk_buff___95 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___81 {
	struct cgroup___212 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___81;

struct socket_wq___82;

struct dst_entry___81;

struct socket___83;

struct net_device___94;

struct sock_reuseport___29;

struct sock___81 {
	struct sock_common___81 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___94 sk_error_queue;
	struct sk_buff___95 *sk_rx_skb_cache;
	struct sk_buff_head___94 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___95 *head;
		struct sk_buff___95 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___81 *sk_filter;
	union {
		struct socket_wq___82 *sk_wq;
		struct socket_wq___82 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___81 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___81 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___95 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___95 *sk_tx_skb_cache;
	struct sk_buff_head___94 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___290 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___81 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___262 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___83 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___81 sk_cgrp_data;
	struct mem_cgroup___150 *sk_memcg;
	void (*sk_state_change)(struct sock___81 *);
	void (*sk_data_ready)(struct sock___81 *);
	void (*sk_write_space)(struct sock___81 *);
	void (*sk_error_report)(struct sock___81 *);
	int (*sk_backlog_rcv)(struct sock___81 *, struct sk_buff___95 *);
	struct sk_buff___95 * (*sk_validate_xmit_skb)(struct sock___81 *, struct net_device___94 *, struct sk_buff___95 *);
	void (*sk_destruct)(struct sock___81 *);
	struct sock_reuseport___29 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___273;

struct attribute_group___273 {
	const char *name;
	umode_t (*is_visible)(struct kobject___273 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___273 *, struct bin_attribute___273 *, int);
	struct attribute **attrs;
	struct bin_attribute___273 **bin_attrs;
};

struct bin_attribute___273 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___285 * (*f_mapping)();
	ssize_t (*read)(struct file___285 *, struct kobject___273 *, struct bin_attribute___273 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___285 *, struct kobject___273 *, struct bin_attribute___273 *, char *, loff_t, size_t);
	int (*mmap)(struct file___285 *, struct kobject___273 *, struct bin_attribute___273 *, struct vm_area_struct___290 *);
};

struct sysfs_ops___273 {
	ssize_t (*show)(struct kobject___273 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___273 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___273;

struct kset___273 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___273 kobj;
	const struct kset_uevent_ops___273 *uevent_ops;
};

struct kobj_type___273 {
	void (*release)(struct kobject___273 *);
	const struct sysfs_ops___273 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___273 **default_groups;
	const struct kobj_ns_type_operations___81 * (*child_ns_type)(struct kobject___273 *);
	const void * (*namespace)(struct kobject___273 *);
	void (*get_ownership)(struct kobject___273 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___273 {
	int (* const filter)(struct kset___273 *, struct kobject___273 *);
	const char * (* const name)(struct kset___273 *, struct kobject___273 *);
	int (* const uevent)(struct kset___273 *, struct kobject___273 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___269 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___269 *);
	int (*get)(char *, const struct kernel_param___269 *);
	void (*free)(void *);
};

struct kparam_array___269;

struct kernel_param___269 {
	const char *name;
	struct module___269 *mod;
	const struct kernel_param_ops___269 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___269 *arr;
	};
};

struct kparam_array___269 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___269 *ops;
	void *elem;
};

struct module_attribute___269 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___269 *, struct module_kobject___270 *, char *);
	ssize_t (*store)(struct module_attribute___269 *, struct module_kobject___270 *, const char *, size_t);
	void (*setup)(struct module___269 *, const char *);
	int (*test)(struct module___269 *);
	void (*free)(struct module___269 *);
};

struct dev_pagemap_ops___280 {
	void (*page_free)(struct page___290 *);
	void (*kill)(struct dev_pagemap___280 *);
	void (*cleanup)(struct dev_pagemap___280 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___280 *);
};

struct bpf_iter_aux_info___97;

typedef int (*bpf_iter_init_seq_priv_t___96)(void *, struct bpf_iter_aux_info___97 *);

struct bpf_map___97;

struct bpf_iter_aux_info___97 {
	struct bpf_map___97 *map;
};

struct bpf_iter_seq_info___96 {
	const struct seq_operations___260 *seq_ops;
	bpf_iter_init_seq_priv_t___96 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___260 {
	void * (*start)(struct seq_file___260 *, loff_t *);
	void (*stop)(struct seq_file___260 *, void *);
	void * (*next)(struct seq_file___260 *, void *, loff_t *);
	int (*show)(struct seq_file___260 *, void *);
};

struct bpf_prog_aux___97;

struct bpf_prog___88;

struct bpf_map_ops___96 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___97 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___97 *, struct file___285 *);
	void (*map_free)(struct bpf_map___97 *);
	int (*map_get_next_key)(struct bpf_map___97 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___97 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___97 *, void *);
	int (*map_lookup_batch)(struct bpf_map___97 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___97 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___97 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___97 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___97 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___97 *, void *);
	int (*map_update_elem)(struct bpf_map___97 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___97 *, void *);
	int (*map_push_elem)(struct bpf_map___97 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___97 *, void *);
	int (*map_peek_elem)(struct bpf_map___97 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___97 *, struct file___285 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___97 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___97 *, void *, struct seq_file___260 *);
	int (*map_check_btf)(const struct bpf_map___97 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___97 *, struct bpf_prog_aux___97 *);
	void (*map_poke_untrack)(struct bpf_map___97 *, struct bpf_prog_aux___97 *);
	void (*map_poke_run)(struct bpf_map___97 *, u32, struct bpf_prog___88 *, struct bpf_prog___88 *);
	int (*map_direct_value_addr)(const struct bpf_map___97 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___97 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___97 *, struct vm_area_struct___290 *);
	__poll_t (*map_poll)(struct bpf_map___97 *, struct file___285 *, struct poll_table_struct___206 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___97 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___97 *, const struct bpf_map___97 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___97 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___96 *iter_seq_info;
};

struct bpf_map___97 {
	const struct bpf_map_ops___96 *ops;
	struct bpf_map___97 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___150 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___96;

struct bpf_jit_poke_descriptor___96;

struct bpf_prog_ops___88;

struct btf_mod_pair___96;

struct bpf_prog_offload___94;

struct bpf_prog_aux___97 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___88 *dst_prog;
	struct bpf_trampoline___96 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___88 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___96 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___88 *ops;
	struct bpf_map___97 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___96 *used_btfs;
	struct bpf_prog___88 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___97 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___94 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___88 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___97 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___94;

struct bpf_map_dev_ops___94 {
	int (*map_get_next_key)(struct bpf_offloaded_map___94 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___94 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___94 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___94 *, void *);
};

struct bpf_offloaded_map___94 {
	struct bpf_map___97 map;
	struct net_device___94 *netdev;
	const struct bpf_map_dev_ops___94 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___94(struct sk_buff___95 **);

struct bpf_xdp_entity___88 {
	struct bpf_prog___88 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___94;

struct net_device_ops___94;

struct l3mdev_ops___81;

struct ndisc_ops___63;

struct xfrmdev_ops___94;

struct tlsdev_ops___2;

struct header_ops___94;

struct inet6_dev___63;

struct netdev_rx_queue___94;

struct mini_Qdisc___88;

struct netdev_queue___94;

struct Qdisc___88;

struct rtnl_link_ops___88;

struct dcbnl_rtnl_ops___94;

struct net_device___94 {
	char name[16];
	struct netdev_name_node___94 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___94 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___81 *l3mdev_ops;
	const struct ndisc_ops___63 *ndisc_ops;
	const struct xfrmdev_ops___94 *xfrmdev_ops;
	const struct tlsdev_ops___2 *tlsdev_ops;
	const struct header_ops___94 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___273 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___63 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___94 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___88 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___94 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___88 *miniq_ingress;
	struct netdev_queue___94 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___94 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___88 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___88 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___94 = 0,
		NETREG_REGISTERED___94 = 1,
		NETREG_UNREGISTERING___94 = 2,
		NETREG_UNREGISTERED___94 = 3,
		NETREG_RELEASED___94 = 4,
		NETREG_DUMMY___94 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___94 = 0,
		RTNL_LINK_INITIALIZING___94 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___94 *);
	struct netpoll_info *npinfo;
	possible_net_t___94 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___266 dev;
	const struct attribute_group___273 *sysfs_groups[4];
	const struct attribute_group___273 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___88 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___94 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___88 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___88 {
	int (*test_run)(struct bpf_prog___88 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___94 {
	struct bpf_prog___88 *prog;
	struct net_device___94 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___96 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___88 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___269 *mod;
};

struct bpf_jit_poke_descriptor___96 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___97 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___96 {
	struct btf *btf;
	struct module___269 *module;
};

struct bpf_prog_array_item___88 {
	struct bpf_prog___88 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___88 {
	struct callback_head rcu;
	struct bpf_prog_array_item___88 items[0];
};

struct sk_buff___95 {
	union {
		struct {
			struct sk_buff___95 *next;
			struct sk_buff___95 *prev;
			union {
				struct net_device___94 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___81 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___95 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct msghdr___83 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___205 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___285 *msg_iocb;
};

struct fwnode_operations___262;

struct fwnode_handle___262 {
	struct fwnode_handle___262 *secondary;
	const struct fwnode_operations___262 *ops;
	struct device___266 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___262;

struct fwnode_endpoint___262;

struct fwnode_operations___262 {
	struct fwnode_handle___262 * (*get)(struct fwnode_handle___262 *);
	void (*put)(struct fwnode_handle___262 *);
	bool (*device_is_available)(const struct fwnode_handle___262 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___262 *, const struct device___266 *);
	bool (*property_present)(const struct fwnode_handle___262 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___262 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___262 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___262 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*get_parent)(const struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*get_next_child_node)(const struct fwnode_handle___262 *, struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*get_named_child_node)(const struct fwnode_handle___262 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___262 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___262 *);
	struct fwnode_handle___262 * (*graph_get_next_endpoint)(const struct fwnode_handle___262 *, struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*graph_get_remote_endpoint)(const struct fwnode_handle___262 *);
	struct fwnode_handle___262 * (*graph_get_port_parent)(struct fwnode_handle___262 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___262 *, struct fwnode_endpoint___262 *);
	int (*add_links)(struct fwnode_handle___262 *);
};

struct fwnode_endpoint___262 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___262 *local_fwnode;
};

struct fwnode_reference_args___262 {
	struct fwnode_handle___262 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___54;

struct fib_rules_ops___81;

struct fqdir___99;

struct tcp_congestion_ops___27;

struct fib_notifier_ops___81;

struct netns_ipv4___99 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___54 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___81 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___81 *fibnl;
	struct sock___81 **icmp_sk;
	struct sock___81 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___81 **tcp_sk;
	struct fqdir___99 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___27 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___81 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___81 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___81 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___81;

struct dst_ops___99 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___99 *);
	struct dst_entry___81 * (*check)(struct dst_entry___81 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___81 *);
	unsigned int (*mtu)(const struct dst_entry___81 *);
	u32 * (*cow_metrics)(struct dst_entry___81 *, long unsigned int);
	void (*destroy)(struct dst_entry___81 *);
	void (*ifdown)(struct dst_entry___81 *, struct net_device___94 *, int);
	struct dst_entry___81 * (*negative_advice)(struct dst_entry___81 *);
	void (*link_failure)(struct sk_buff___95 *);
	void (*update_pmtu)(struct dst_entry___81 *, struct sock___81 *, struct sk_buff___95 *, u32, bool);
	void (*redirect)(struct dst_entry___81 *, struct sock___81 *, struct sk_buff___95 *);
	int (*local_out)(struct net___99 *, struct sock___81 *, struct sk_buff___95 *);
	struct neighbour___81 * (*neigh_lookup)(const struct dst_entry___81 *, struct sk_buff___95 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___81 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___99 {
	struct dst_ops___99 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___99 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___81 *fib6_rules_ops;
	struct sock___81 **icmp_sk;
	struct sock___81 *ndisc_sk;
	struct sock___81 *tcp_sk;
	struct sock___81 *igmp_sk;
	struct sock___81 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___81 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___81 *notifier_ops;
	struct fib_notifier_ops___81 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___99 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___99 *fqdir;
};

struct netns_sctp___81 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___81 *ctl_sock;
	struct sock___81 *udp4_sock;
	struct sock___81 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___88 {
	struct bpf_prog_array___88 *run_array[2];
	struct bpf_prog___88 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___99 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___81 *nlsk;
	struct sock___81 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___99 xfrm4_dst_ops;
	struct dst_ops___99 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___99 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___81 *rtnl;
	struct sock___81 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___94 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___99 ipv4;
	struct netns_ipv6___99 ipv6;
	struct netns_ieee802154_lowpan___99 ieee802154_lowpan;
	struct netns_sctp___81 sctp;
	struct netns_nf___17 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___94 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___88 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___99 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___81 *crypto_nlsk;
	struct sock___81 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___212 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___212 *root_cset;
};

struct socket_wq___82 {
	wait_queue_head_t wait;
	struct fasync_struct___285 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___82;

struct socket___83 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___285 *file;
	struct sock___81 *sk;
	const struct proto_ops___82 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___82 wq;
};

typedef int (*sk_read_actor_t___81)(read_descriptor_t *, struct sk_buff___95 *, unsigned int, size_t);

struct proto_ops___82 {
	int family;
	struct module___269 *owner;
	int (*release)(struct socket___83 *);
	int (*bind)(struct socket___83 *, struct sockaddr *, int);
	int (*connect)(struct socket___83 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___83 *, struct socket___83 *);
	int (*accept)(struct socket___83 *, struct socket___83 *, int, bool);
	int (*getname)(struct socket___83 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___285 *, struct socket___83 *, struct poll_table_struct___206 *);
	int (*ioctl)(struct socket___83 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___83 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___83 *, void *, bool, bool);
	int (*listen)(struct socket___83 *, int);
	int (*shutdown)(struct socket___83 *, int);
	int (*setsockopt)(struct socket___83 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___83 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___260 *, struct socket___83 *);
	int (*sendmsg)(struct socket___83 *, struct msghdr___83 *, size_t);
	int (*recvmsg)(struct socket___83 *, struct msghdr___83 *, size_t, int);
	int (*mmap)(struct file___285 *, struct socket___83 *, struct vm_area_struct___290 *);
	ssize_t (*sendpage)(struct socket___83 *, struct page___290 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___83 *, loff_t *, struct pipe_inode_info___126 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___81 *, int);
	int (*peek_len)(struct socket___83 *);
	int (*read_sock)(struct sock___81 *, read_descriptor_t *, sk_read_actor_t___81);
	int (*sendpage_locked)(struct sock___81 *, struct page___290 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___81 *, struct msghdr___83 *, size_t);
	int (*set_rcvlowat)(struct sock___81 *, int);
};

struct dev_pm_ops___266 {
	int (*prepare)(struct device___266 *);
	void (*complete)(struct device___266 *);
	int (*suspend)(struct device___266 *);
	int (*resume)(struct device___266 *);
	int (*freeze)(struct device___266 *);
	int (*thaw)(struct device___266 *);
	int (*poweroff)(struct device___266 *);
	int (*restore)(struct device___266 *);
	int (*suspend_late)(struct device___266 *);
	int (*resume_early)(struct device___266 *);
	int (*freeze_late)(struct device___266 *);
	int (*thaw_early)(struct device___266 *);
	int (*poweroff_late)(struct device___266 *);
	int (*restore_early)(struct device___266 *);
	int (*suspend_noirq)(struct device___266 *);
	int (*resume_noirq)(struct device___266 *);
	int (*freeze_noirq)(struct device___266 *);
	int (*thaw_noirq)(struct device___266 *);
	int (*poweroff_noirq)(struct device___266 *);
	int (*restore_noirq)(struct device___266 *);
	int (*runtime_suspend)(struct device___266 *);
	int (*runtime_resume)(struct device___266 *);
	int (*runtime_idle)(struct device___266 *);
};

struct wakeup_source___266 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___266 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___266 {
	struct dev_pm_ops___266 ops;
	int (*start)(struct device___266 *);
	void (*detach)(struct device___266 *, bool);
	int (*activate)(struct device___266 *);
	void (*sync)(struct device___266 *);
	void (*dismiss)(struct device___266 *);
};

struct bus_type___266 {
	const char *name;
	const char *dev_name;
	struct device___266 *dev_root;
	const struct attribute_group___273 **bus_groups;
	const struct attribute_group___273 **dev_groups;
	const struct attribute_group___273 **drv_groups;
	int (*match)(struct device___266 *, struct device_driver___266 *);
	int (*uevent)(struct device___266 *, struct kobj_uevent_env *);
	int (*probe)(struct device___266 *);
	void (*sync_state)(struct device___266 *);
	void (*remove)(struct device___266 *);
	void (*shutdown)(struct device___266 *);
	int (*online)(struct device___266 *);
	int (*offline)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	int (*num_vf)(struct device___266 *);
	int (*dma_configure)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___266 {
	const char *name;
	struct bus_type___266 *bus;
	struct module___269 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___266 *);
	void (*sync_state)(struct device___266 *);
	int (*remove)(struct device___266 *);
	void (*shutdown)(struct device___266 *);
	int (*suspend)(struct device___266 *, pm_message_t);
	int (*resume)(struct device___266 *);
	const struct attribute_group___273 **groups;
	const struct attribute_group___273 **dev_groups;
	const struct dev_pm_ops___266 *pm;
	void (*coredump)(struct device___266 *);
	struct driver_private *p;
};

struct device_type___266 {
	const char *name;
	const struct attribute_group___273 **groups;
	int (*uevent)(struct device___266 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___266 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___266 *);
	const struct dev_pm_ops___266 *pm;
};

struct class___266 {
	const char *name;
	struct module___269 *owner;
	const struct attribute_group___273 **class_groups;
	const struct attribute_group___273 **dev_groups;
	struct kobject___273 *dev_kobj;
	int (*dev_uevent)(struct device___266 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___266 *, umode_t *);
	void (*class_release)(struct class___266 *);
	void (*dev_release)(struct device___266 *);
	int (*shutdown_pre)(struct device___266 *);
	const struct kobj_ns_type_operations___81 *ns_type;
	const void * (*namespace)(struct device___266 *);
	void (*get_ownership)(struct device___266 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___266 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___126;

struct pipe_buffer___126 {
	struct page___290 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___126 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___126 {
	int (*confirm)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
	void (*release)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
	bool (*try_steal)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
	bool (*get)(struct pipe_inode_info___126 *, struct pipe_buffer___126 *);
};

struct inet_frags___99;

struct fqdir___99 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___99 *f;
	struct net___99 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___99;

struct inet_frags___99 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___99 *, const void *);
	void (*destructor)(struct inet_frag_queue___99 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___99 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___95 *fragments_tail;
	struct sk_buff___95 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___99 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___54 {
	struct ip_ra_chain___54 *next;
	struct sock___81 *sk;
	union {
		void (*destructor)(struct sock___81 *);
		struct sock___81 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___81;

struct fib_lookup_arg___81;

struct fib_rules_ops___81 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___81 *, struct flowi *, int, struct fib_lookup_arg___81 *);
	bool (*suppress)(struct fib_rule___81 *, int, struct fib_lookup_arg___81 *);
	int (*match)(struct fib_rule___81 *, struct flowi *, int);
	int (*configure)(struct fib_rule___81 *, struct sk_buff___95 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___81 *);
	int (*compare)(struct fib_rule___81 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___81 *, struct sk_buff___95 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___81 *);
	void (*flush_cache)(struct fib_rules_ops___81 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___269 *owner;
	struct net___99 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___27 {
	u32 (*ssthresh)(struct sock___81 *);
	void (*cong_avoid)(struct sock___81 *, u32, u32);
	void (*set_state)(struct sock___81 *, u8);
	void (*cwnd_event)(struct sock___81 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___81 *, u32);
	void (*pkts_acked)(struct sock___81 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___81 *);
	void (*cong_control)(struct sock___81 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___81 *);
	u32 (*sndbuf_expand)(struct sock___81 *);
	size_t (*get_info)(struct sock___81 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___269 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___81 *);
	void (*release)(struct sock___81 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___81 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___99 *);
	int (*fib_dump)(struct net___99 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___269 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___57;

struct dst_entry___81 {
	struct net_device___94 *dev;
	struct dst_ops___99 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___95 *);
	int (*output)(struct net___99 *, struct sock___81 *, struct sk_buff___95 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___57 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___81;

struct neigh_parms___81;

struct neigh_ops___81;

struct neighbour___81 {
	struct neighbour___81 *next;
	struct neigh_table___81 *tbl;
	struct neigh_parms___81 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___94 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___81 *, struct sk_buff___95 *);
	const struct neigh_ops___81 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___94 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___94 {
	int (*ieee_getets)(struct net_device___94 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___94 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___94 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___94 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___94 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___94 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___94 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___94 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___94 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___94 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___94 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___94 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___94 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___94 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___94 *);
	u8 (*setstate)(struct net_device___94 *, u8);
	void (*getpermhwaddr)(struct net_device___94 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___94 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___94 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___94 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___94 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___94 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___94 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___94 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___94 *, int, u8 *);
	void (*setpfccfg)(struct net_device___94 *, int, u8);
	void (*getpfccfg)(struct net_device___94 *, int, u8 *);
	u8 (*setall)(struct net_device___94 *);
	u8 (*getcap)(struct net_device___94 *, int, u8 *);
	int (*getnumtcs)(struct net_device___94 *, int, u8 *);
	int (*setnumtcs)(struct net_device___94 *, int, u8);
	u8 (*getpfcstate)(struct net_device___94 *);
	void (*setpfcstate)(struct net_device___94 *, u8);
	void (*getbcncfg)(struct net_device___94 *, int, u32 *);
	void (*setbcncfg)(struct net_device___94 *, int, u32);
	void (*getbcnrp)(struct net_device___94 *, int, u8 *);
	void (*setbcnrp)(struct net_device___94 *, int, u8);
	int (*setapp)(struct net_device___94 *, u8, u16, u8);
	int (*getapp)(struct net_device___94 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___94 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___94 *, int, u8);
	u8 (*getdcbx)(struct net_device___94 *);
	u8 (*setdcbx)(struct net_device___94 *, u8);
	int (*peer_getappinfo)(struct net_device___94 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___94 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___94 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___94 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___94 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___94 *, struct dcbnl_buffer *);
};

struct cftype___212;

struct cgroup_subsys___212 {
	struct cgroup_subsys_state___212 * (*css_alloc)(struct cgroup_subsys_state___212 *);
	int (*css_online)(struct cgroup_subsys_state___212 *);
	void (*css_offline)(struct cgroup_subsys_state___212 *);
	void (*css_released)(struct cgroup_subsys_state___212 *);
	void (*css_free)(struct cgroup_subsys_state___212 *);
	void (*css_reset)(struct cgroup_subsys_state___212 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___212 *, int);
	int (*css_extra_stat_show)(struct seq_file___260 *, struct cgroup_subsys_state___212 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___292 *, struct css_set___212 *);
	void (*cancel_fork)(struct task_struct___292 *, struct css_set___212 *);
	void (*fork)(struct task_struct___292 *);
	void (*exit)(struct task_struct___292 *);
	void (*release)(struct task_struct___292 *);
	void (*bind)(struct cgroup_subsys_state___212 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___212 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___212 *dfl_cftypes;
	struct cftype___212 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___212 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___212 *updated_children;
	struct cgroup___212 *updated_next;
};

struct cgroup_root___212 {
	struct kernfs_root___273 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___212 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___212 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___212 *ss;
	struct list_head node;
	struct kernfs_ops___273 *kf_ops;
	int (*open)(struct kernfs_open_file___273 *);
	void (*release)(struct kernfs_open_file___273 *);
	u64 (*read_u64)(struct cgroup_subsys_state___212 *, struct cftype___212 *);
	s64 (*read_s64)(struct cgroup_subsys_state___212 *, struct cftype___212 *);
	int (*seq_show)(struct seq_file___260 *, void *);
	void * (*seq_start)(struct seq_file___260 *, loff_t *);
	void * (*seq_next)(struct seq_file___260 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___260 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___212 *, struct cftype___212 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___212 *, struct cftype___212 *, s64);
	ssize_t (*write)(struct kernfs_open_file___273 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___273 *, struct poll_table_struct___206 *);
};

struct xdp_rxq_info___94 {
	struct net_device___94 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___94 {
	struct net_device___94 *dev;
};

struct xdp_buff___94 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___94 *rxq;
	struct xdp_txq_info___94 *txq;
	u32 frame_sz;
};

struct xdp_frame___94 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___94 *dev_rx;
};

struct netlink_callback___94 {
	struct sk_buff___95 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___95 *, struct netlink_callback___94 *);
	int (*done)(struct netlink_callback___94 *);
	void *data;
	struct module___269 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___94 {
	int (*create)(struct sk_buff___95 *, struct net_device___94 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___95 *, unsigned char *);
	int (*cache)(const struct neighbour___81 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___94 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___95 *);
};

struct netdev_queue___94 {
	struct net_device___94 *dev;
	struct Qdisc___88 *qdisc;
	struct Qdisc___88 *qdisc_sleeping;
	struct kobject___273 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___94 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___88 {
	struct sk_buff___95 *head;
	struct sk_buff___95 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___88;

struct Qdisc___88 {
	int (*enqueue)(struct sk_buff___95 *, struct Qdisc___88 *, struct sk_buff___95 **);
	struct sk_buff___95 * (*dequeue)(struct Qdisc___88 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___88 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___94 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___94 gso_skb;
	struct qdisc_skb_head___88 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___88 *next_sched;
	struct sk_buff_head___94 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___94 {
	struct xdp_rxq_info___94 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___273 kobj;
	struct net_device___94 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___94 {
	enum net_device_path_type type;
	const struct net_device___94 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___94 = 0,
				DEV_PATH_BR_VLAN_TAG___94 = 1,
				DEV_PATH_BR_VLAN_UNTAG___94 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___94 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___94 {
	const struct net_device___94 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___94 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___88 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___94 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___94 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___95 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___94 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___94 *dev;
	const char *name;
};

struct net_device_ops___94 {
	int (*ndo_init)(struct net_device___94 *);
	void (*ndo_uninit)(struct net_device___94 *);
	int (*ndo_open)(struct net_device___94 *);
	int (*ndo_stop)(struct net_device___94 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___95 *, struct net_device___94 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___95 *, struct net_device___94 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___94 *, struct sk_buff___95 *, struct net_device___94 *);
	void (*ndo_change_rx_flags)(struct net_device___94 *, int);
	void (*ndo_set_rx_mode)(struct net_device___94 *);
	int (*ndo_set_mac_address)(struct net_device___94 *, void *);
	int (*ndo_validate_addr)(struct net_device___94 *);
	int (*ndo_do_ioctl)(struct net_device___94 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___94 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___94 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___94 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___94 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___94 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___94 *, int);
	int (*ndo_neigh_setup)(struct net_device___94 *, struct neigh_parms___81 *);
	void (*ndo_tx_timeout)(struct net_device___94 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___94 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___94 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___94 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___94 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___94 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___94 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___94 *);
	int (*ndo_netpoll_setup)(struct net_device___94 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___94 *);
	int (*ndo_set_vf_mac)(struct net_device___94 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___94 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___94 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___94 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___94 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___94 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___94 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___94 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___94 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___94 *, int, struct sk_buff___95 *);
	int (*ndo_get_vf_guid)(struct net_device___94 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___94 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___94 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___94 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___94 *);
	int (*ndo_fcoe_disable)(struct net_device___94 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___94 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___94 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___94 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___94 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___94 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___94 *, const struct sk_buff___95 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___94 *, struct net_device___94 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___94 *, struct net_device___94 *);
	struct net_device___94 * (*ndo_get_xmit_slave)(struct net_device___94 *, struct sk_buff___95 *, bool);
	struct net_device___94 * (*ndo_sk_get_lower_dev)(struct net_device___94 *, struct sock___81 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___94 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___94 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___94 *, struct neighbour___81 *);
	void (*ndo_neigh_destroy)(struct net_device___94 *, struct neighbour___81 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___94 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___94 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___95 *, struct netlink_callback___94 *, struct net_device___94 *, struct net_device___94 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___95 *, struct nlattr **, struct net_device___94 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___94 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___95 *, u32, u32, struct net_device___94 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___94 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___94 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___94 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___94 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___94 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___94 *, struct net_device___94 *);
	void (*ndo_dfwd_del_station)(struct net_device___94 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___94 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___94 *);
	int (*ndo_change_proto_down)(struct net_device___94 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___94 *, struct sk_buff___95 *);
	void (*ndo_set_rx_headroom)(struct net_device___94 *, int);
	int (*ndo_bpf)(struct net_device___94 *, struct netdev_bpf___94 *);
	int (*ndo_xdp_xmit)(struct net_device___94 *, int, struct xdp_frame___94 **, u32);
	struct net_device___94 * (*ndo_xdp_get_xmit_slave)(struct net_device___94 *, struct xdp_buff___94 *);
	int (*ndo_xsk_wakeup)(struct net_device___94 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___94 *);
	int (*ndo_tunnel_ctl)(struct net_device___94 *, struct ip_tunnel_parm *, int);
	struct net_device___94 * (*ndo_get_peer_dev)(struct net_device___94 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___94 *, struct net_device_path___94 *);
};

struct neigh_parms___81 {
	possible_net_t___94 net;
	struct net_device___94 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___81 *);
	struct neigh_table___81 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___81 {
	u32 (*l3mdev_fib_table)(const struct net_device___94 *);
	struct sk_buff___95 * (*l3mdev_l3_rcv)(struct net_device___94 *, struct sk_buff___95 *, u16);
	struct sk_buff___95 * (*l3mdev_l3_out)(struct net_device___94 *, struct sock___81 *, struct sk_buff___95 *, u16);
	struct dst_entry___81 * (*l3mdev_link_scope_lookup)(const struct net_device___94 *, struct flowi6 *);
};

struct ndisc_ops___63 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___94 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___94 *, struct neighbour___81 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___94 *, u8, struct neighbour___81 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___94 *, struct sk_buff___95 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___99 *, struct net_device___94 *, const struct prefix_info *, struct inet6_dev___63 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct tls_context___2;

struct tlsdev_ops___2 {
	int (*tls_dev_add)(struct net_device___94 *, struct sock___81 *, enum tls_offload_ctx_dir, struct tls_crypto_info *, u32);
	void (*tls_dev_del)(struct net_device___94 *, struct tls_context___2 *, enum tls_offload_ctx_dir);
	int (*tls_dev_resync)(struct net_device___94 *, struct sock___81 *, u32, u8 *, enum tls_offload_ctx_dir);
};

struct ifmcaddr6___63;

struct inet6_dev___63 {
	struct net_device___94 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___63 *mc_list;
	struct ifmcaddr6___63 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___94 mc_query_queue;
	struct sk_buff_head___94 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___25 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___81 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___88;

struct tcf_block___88;

struct mini_Qdisc___88 {
	struct tcf_proto___88 *filter_list;
	struct tcf_block___88 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___88 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___94 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___94 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___99 *, struct net_device___94 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___94 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___94 *, struct list_head *);
	size_t (*get_size)(const struct net_device___94 *);
	int (*fill_info)(struct sk_buff___95 *, const struct net_device___94 *);
	size_t (*get_xstats_size)(const struct net_device___94 *);
	int (*fill_xstats)(struct sk_buff___95 *, const struct net_device___94 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___94 *, struct net_device___94 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___94 *, const struct net_device___94 *);
	int (*fill_slave_info)(struct sk_buff___95 *, const struct net_device___94 *, const struct net_device___94 *);
	struct net___99 * (*get_link_net)(const struct net_device___94 *);
	size_t (*get_linkxstats_size)(const struct net_device___94 *, int);
	int (*fill_linkxstats)(struct sk_buff___95 *, const struct net_device___94 *, int *, int);
};

struct gnet_dump___88 {
	spinlock_t *lock;
	struct sk_buff___95 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___88;

struct Qdisc_ops___88 {
	struct Qdisc_ops___88 *next;
	const struct Qdisc_class_ops___88 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___95 *, struct Qdisc___88 *, struct sk_buff___95 **);
	struct sk_buff___95 * (*dequeue)(struct Qdisc___88 *);
	struct sk_buff___95 * (*peek)(struct Qdisc___88 *);
	int (*init)(struct Qdisc___88 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___88 *);
	void (*destroy)(struct Qdisc___88 *);
	int (*change)(struct Qdisc___88 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___88 *);
	int (*change_tx_queue_len)(struct Qdisc___88 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___88 *, unsigned int);
	int (*dump)(struct Qdisc___88 *, struct sk_buff___95 *);
	int (*dump_stats)(struct Qdisc___88 *, struct gnet_dump___88 *);
	void (*ingress_block_set)(struct Qdisc___88 *, u32);
	void (*egress_block_set)(struct Qdisc___88 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___88 *);
	u32 (*egress_block_get)(struct Qdisc___88 *);
	struct module___269 *owner;
};

struct Qdisc_class_ops___88 {
	unsigned int flags;
	struct netdev_queue___94 * (*select_queue)(struct Qdisc___88 *, struct tcmsg *);
	int (*graft)(struct Qdisc___88 *, long unsigned int, struct Qdisc___88 *, struct Qdisc___88 **, struct netlink_ext_ack *);
	struct Qdisc___88 * (*leaf)(struct Qdisc___88 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___88 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___88 *, u32);
	int (*change)(struct Qdisc___88 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___88 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___88 *, struct qdisc_walker *);
	struct tcf_block___88 * (*tcf_block)(struct Qdisc___88 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___88 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___88 *, long unsigned int);
	int (*dump)(struct Qdisc___88 *, long unsigned int, struct sk_buff___95 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___88 *, long unsigned int, struct gnet_dump___88 *);
};

struct tcf_chain___88;

struct tcf_block___88 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___99 *net;
	struct Qdisc___88 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___88 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___88;

struct tcf_proto_ops___88;

struct tcf_proto___88 {
	struct tcf_proto___88 *next;
	void *root;
	int (*classify)(struct sk_buff___95 *, const struct tcf_proto___88 *, struct tcf_result___88 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___88 *ops;
	struct tcf_chain___88 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___88 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___88 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___88 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___95 *, const struct tcf_proto___88 *, struct tcf_result___88 *);
	int (*init)(struct tcf_proto___88 *);
	void (*destroy)(struct tcf_proto___88 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___88 *, u32);
	void (*put)(struct tcf_proto___88 *, void *);
	int (*change)(struct net___99 *, struct sk_buff___95 *, struct tcf_proto___88 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___88 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___88 *);
	void (*walk)(struct tcf_proto___88 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___88 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___88 *, void *);
	void (*hw_del)(struct tcf_proto___88 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___99 *, struct tcf_chain___88 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___99 *, struct tcf_proto___88 *, void *, struct sk_buff___95 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___99 *, struct tcf_proto___88 *, void *, struct sk_buff___95 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___95 *, struct net___99 *, void *);
	struct module___269 *owner;
	int flags;
};

struct tcf_chain___88 {
	struct mutex filter_chain_lock;
	struct tcf_proto___88 *filter_chain;
	struct list_head list;
	struct tcf_block___88 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___88 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___81 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___88 *prog;
};

struct block_device_operations___176;

struct gendisk___179 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___179 *part0;
	const struct block_device_operations___176 *fops;
	struct request_queue___176 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___162 *bdi;
	struct kobject___273 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___273 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___176 {
	struct bio___176 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___202 *bip_vec;
	struct bio_vec___202 bip_inline_vecs[0];
};

struct blkcg___164;

struct blkg_policy_data___164;

struct blkcg_gq___164 {
	struct request_queue___176 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___164 *blkcg;
	struct blkcg_gq___164 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___164 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___176 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___176(struct request___176 *);

typedef void integrity_complete_fn___176(struct request___176 *, unsigned int);

struct blk_integrity_profile___176 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___176 *prepare_fn;
	integrity_complete_fn___176 *complete_fn;
	const char *name;
};

struct block_device_operations___176 {
	blk_qc_t (*submit_bio)(struct bio___176 *);
	int (*open)(struct block_device___179 *, fmode_t);
	void (*release)(struct gendisk___179 *, fmode_t);
	int (*rw_page)(struct block_device___179 *, sector_t, struct page___290 *, unsigned int);
	int (*ioctl)(struct block_device___179 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___179 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___179 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___179 *);
	int (*getgeo)(struct block_device___179 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___179 *, bool);
	void (*swap_slot_free_notify)(struct block_device___179 *, long unsigned int);
	int (*report_zones)(struct gendisk___179 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___179 *, umode_t *);
	struct module___269 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___179 *, sector_t *);
};

typedef void rq_end_io_fn___176(struct request___176 *, blk_status_t);

struct request___176 {
	struct request_queue___176 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___171 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___176 *bio;
	struct bio___176 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___202 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___176 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___176 *saved_end_io;
		} flush;
	};
	struct gendisk___179 *rq_disk;
	struct block_device___179 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___176 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___171 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___176 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___273 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___285 *debugfs_dir;
	struct dentry___285 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___176;

struct elevator_mq_ops___176 {
	int (*init_sched)(struct request_queue___176 *, struct elevator_type___176 *);
	void (*exit_sched)(struct elevator_queue___176 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___171 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___171 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___171 *);
	bool (*allow_merge)(struct request_queue___176 *, struct request___176 *, struct bio___176 *);
	bool (*bio_merge)(struct request_queue___176 *, struct bio___176 *, unsigned int);
	int (*request_merge)(struct request_queue___176 *, struct request___176 **, struct bio___176 *);
	void (*request_merged)(struct request_queue___176 *, struct request___176 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___176 *, struct request___176 *, struct request___176 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___176 *);
	void (*finish_request)(struct request___176 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___171 *, struct list_head *, bool);
	struct request___176 * (*dispatch_request)(struct blk_mq_hw_ctx___171 *);
	bool (*has_work)(struct blk_mq_hw_ctx___171 *);
	void (*completed_request)(struct request___176 *, u64);
	void (*requeue_request)(struct request___176 *);
	struct request___176 * (*former_request)(struct request_queue___176 *, struct request___176 *);
	struct request___176 * (*next_request)(struct request_queue___176 *, struct request___176 *);
	void (*init_icq)(struct io_cq___176 *);
	void (*exit_icq)(struct io_cq___176 *);
};

struct elv_fs_entry___176;

struct elevator_type___176 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___176 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___176 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___269 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___176 {
	struct elevator_type___176 *type;
	void *elevator_data;
	struct kobject___273 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___176 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___176 *, char *);
	ssize_t (*store)(struct elevator_queue___176 *, const char *, size_t);
};

struct blk_mq_queue_data___171;

struct blk_mq_ops___171 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___171 *, const struct blk_mq_queue_data___171 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___171 *);
	int (*get_budget)(struct request_queue___176 *);
	void (*put_budget)(struct request_queue___176 *, int);
	void (*set_rq_budget_token)(struct request___176 *, int);
	int (*get_rq_budget_token)(struct request___176 *);
	enum blk_eh_timer_return (*timeout)(struct request___176 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___171 *);
	void (*complete)(struct request___176 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___171 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___171 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___171 *, struct request___176 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___171 *, struct request___176 *, unsigned int);
	void (*initialize_rq_fn)(struct request___176 *);
	void (*cleanup_rq)(struct request___176 *);
	bool (*busy)(struct request_queue___176 *);
	int (*map_queues)(struct blk_mq_tag_set___171 *);
	void (*show_rq)(struct seq_file___260 *, struct request___176 *);
};

struct blk_mq_tag_set___171 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___171 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___171 {
	struct request___176 *rq;
	bool last;
};

struct blkcg_policy_data___164;

struct blkcg___164 {
	struct cgroup_subsys_state___212 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___164 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___164 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___164 {
	struct blkcg___164 *blkcg;
	int plid;
};

struct blkg_policy_data___164 {
	struct blkcg_gq___164 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___150 {
	struct mem_cgroup___150 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___150 {
	struct lruvec___158 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___150 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___150 *memcg;
};

struct obj_cgroup___150 {
	struct percpu_ref refcnt;
	struct mem_cgroup___150 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___81;

struct neigh_hash_table___81;

struct neigh_table___81 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___94 *, __u32 *);
	bool (*key_eq)(const struct neighbour___81 *, const void *);
	int (*constructor)(struct neighbour___81 *);
	int (*pconstructor)(struct pneigh_entry___81 *);
	void (*pdestructor)(struct pneigh_entry___81 *);
	void (*proxy_redo)(struct sk_buff___95 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___94 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___81 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___94 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___81 *nht;
	struct pneigh_entry___81 **phash_buckets;
};

struct neigh_ops___81 {
	int family;
	void (*solicit)(struct neighbour___81 *, struct sk_buff___95 *);
	void (*error_report)(struct neighbour___81 *, struct sk_buff___95 *);
	int (*output)(struct neighbour___81 *, struct sk_buff___95 *);
	int (*connected_output)(struct neighbour___81 *, struct sk_buff___95 *);
};

struct pneigh_entry___81 {
	struct pneigh_entry___81 *next;
	possible_net_t___94 net;
	struct net_device___94 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___81 {
	struct neighbour___81 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___57 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___99 *, struct sock___81 *, struct sk_buff___95 *);
	int (*orig_input)(struct sk_buff___95 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___81 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___81 *ctarget;
	struct net___99 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___81 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___81 *rule;
	u32 table;
	int flags;
};

struct sk_psock___3;

struct request_sock_ops___66;

struct timewait_sock_ops___65;

struct proto___81 {
	void (*close)(struct sock___81 *, long int);
	int (*pre_connect)(struct sock___81 *, struct sockaddr *, int);
	int (*connect)(struct sock___81 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___81 *, int);
	struct sock___81 * (*accept)(struct sock___81 *, int, int *, bool);
	int (*ioctl)(struct sock___81 *, int, long unsigned int);
	int (*init)(struct sock___81 *);
	void (*destroy)(struct sock___81 *);
	void (*shutdown)(struct sock___81 *, int);
	int (*setsockopt)(struct sock___81 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___81 *, int, int, char *, int *);
	void (*keepalive)(struct sock___81 *, int);
	int (*compat_ioctl)(struct sock___81 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___81 *, struct msghdr___83 *, size_t);
	int (*recvmsg)(struct sock___81 *, struct msghdr___83 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___81 *, struct page___290 *, int, size_t, int);
	int (*bind)(struct sock___81 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___81 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___81 *, struct sk_buff___95 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___81 *);
	int (*hash)(struct sock___81 *);
	void (*unhash)(struct sock___81 *);
	void (*rehash)(struct sock___81 *);
	int (*get_port)(struct sock___81 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___81 *, struct sk_psock___3 *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___81 *, int);
	bool (*sock_is_readable)(struct sock___81 *);
	void (*enter_memory_pressure)(struct sock___81 *);
	void (*leave_memory_pressure)(struct sock___81 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___66 *rsk_prot;
	struct timewait_sock_ops___65 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___269 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___81 *, int);
};

struct sock_reuseport___29 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___88 *prog;
	struct sock___81 *socks[0];
};

struct sk_psock_progs___3 {
	struct bpf_prog___88 *msg_parser;
	struct bpf_prog___88 *stream_parser;
	struct bpf_prog___88 *stream_verdict;
	struct bpf_prog___88 *skb_verdict;
};

struct strparser___3;

struct strp_callbacks___3 {
	int (*parse_msg)(struct strparser___3 *, struct sk_buff___95 *);
	void (*rcv_msg)(struct strparser___3 *, struct sk_buff___95 *);
	int (*read_sock_done)(struct strparser___3 *, int);
	void (*abort_parser)(struct strparser___3 *, int);
	void (*lock)(struct strparser___3 *);
	void (*unlock)(struct strparser___3 *);
};

struct strparser___3 {
	struct sock___81 *sk;
	u32 stopped;
	u32 paused;
	u32 aborted;
	u32 interrupted;
	u32 unrecov_intr;
	long: 32;
	long: 64;
	struct sk_buff___95 **skb_nextp;
	struct sk_buff___95 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___3 cb;
};

struct sk_psock_work_state___3 {
	struct sk_buff___95 *skb;
	u32 len;
	u32 off;
};

struct sk_msg___3;

struct sk_psock___3 {
	struct sock___81 *sk;
	struct sock___81 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg___3 *cork;
	struct sk_psock_progs___3 progs;
	struct strparser___3 strp;
	struct sk_buff_head___94 ingress_skb;
	struct list_head ingress_msg;
	spinlock_t ingress_lock;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___81 *);
	void (*saved_close)(struct sock___81 *, long int);
	void (*saved_write_space)(struct sock___81 *);
	void (*saved_data_ready)(struct sock___81 *);
	int (*psock_update_sk_prot)(struct sock___81 *, struct sk_psock___3 *, bool);
	struct proto___81 *sk_proto;
	struct mutex work_mutex;
	struct sk_psock_work_state___3 work_state;
	struct work_struct work;
	struct rcu_work rwork;
};

struct request_sock___67;

struct request_sock_ops___66 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___81 *, struct request_sock___67 *);
	void (*send_ack)(const struct sock___81 *, struct sk_buff___95 *, struct request_sock___67 *);
	void (*send_reset)(const struct sock___81 *, struct sk_buff___95 *);
	void (*destructor)(struct request_sock___67 *);
	void (*syn_ack_timeout)(const struct request_sock___67 *);
};

struct timewait_sock_ops___65 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___81 *, struct sock___81 *, void *);
	void (*twsk_destructor)(struct sock___81 *);
};

struct request_sock___67 {
	struct sock_common___81 __req_common;
	struct request_sock___67 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___66 *rsk_ops;
	struct sock___81 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___10 {
	struct request_sock___67 *rskq_rst_head;
	struct request_sock___67 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___10 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___67 *rskq_accept_head;
	struct request_sock___67 *rskq_accept_tail;
	struct fastopen_queue___10 fastopenq;
};

struct inet_cork___20 {
	unsigned int flags;
	__be32 addr;
	struct ip_options___2 *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___81 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___20 {
	struct inet_cork___20 base;
	struct flowi fl;
};

struct ipv6_pinfo___19;

struct inet_sock___20 {
	struct sock___81 sk;
	struct ipv6_pinfo___19 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu___2 *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___20 cork;
};

struct ipv6_fl_socklist___19;

struct ipv6_pinfo___19 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___19 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___95 *pktoptions;
	struct sk_buff___95 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___10 {
	int (*queue_xmit)(struct sock___81 *, struct sk_buff___95 *, struct flowi *);
	void (*send_check)(struct sock___81 *, struct sk_buff___95 *);
	int (*rebuild_header)(struct sock___81 *);
	void (*sk_rx_dst_set)(struct sock___81 *, const struct sk_buff___95 *);
	int (*conn_request)(struct sock___81 *, struct sk_buff___95 *);
	struct sock___81 * (*syn_recv_sock)(const struct sock___81 *, struct sk_buff___95 *, struct request_sock___67 *, struct dst_entry___81 *, struct request_sock___67 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___81 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___81 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___81 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___81 *);
};

struct inet_bind_bucket___10;

struct tcp_ulp_ops___10;

struct inet_connection_sock___10 {
	struct inet_sock___20 icsk_inet;
	struct request_sock_queue___10 icsk_accept_queue;
	struct inet_bind_bucket___10 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___27 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___10 *icsk_af_ops;
	const struct tcp_ulp_ops___10 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___81 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___81 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___10 {
	possible_net_t___94 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___10 {
	struct list_head list;
	int (*init)(struct sock___81 *);
	void (*update)(struct sock___81 *, struct proto___81 *, void (*)(struct sock___81 *));
	void (*release)(struct sock___81 *);
	int (*get_info)(const struct sock___81 *, struct sk_buff___95 *);
	size_t (*get_info_size)(const struct sock___81 *);
	void (*clone)(const struct request_sock___67 *, struct sock___81 *, const gfp_t);
	char name[16];
	struct module___269 *owner;
};

struct ip6_flowlabel___19;

struct ipv6_fl_socklist___19 {
	struct ipv6_fl_socklist___19 *next;
	struct ip6_flowlabel___19 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___63 {
	struct in6_addr mca_addr;
	struct inet6_dev___63 *idev;
	struct ifmcaddr6___63 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___19 {
	struct ip6_flowlabel___19 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___262 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___99 *fl_net;
};

struct sk_msg___3 {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___95 *skb;
	struct sock___81 *sk_redir;
	struct sock___81 *sk;
	struct list_head list;
};

struct crypto_async_request___12;

typedef void (*crypto_completion_t___12)(struct crypto_async_request___12 *, int);

struct crypto_tfm___27;

struct crypto_async_request___12 {
	struct list_head list;
	crypto_completion_t___12 complete;
	void *data;
	struct crypto_tfm___27 *tfm;
	u32 flags;
};

struct crypto_alg___27;

struct crypto_tfm___27 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___27 *);
	struct crypto_alg___27 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___27 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___27 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___27 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___27 *, u8 *, const u8 *);
};

struct compress_alg___27 {
	int (*coa_compress)(struct crypto_tfm___27 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___27 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___27 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___27 cipher;
		struct compress_alg___27 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___27 *);
	void (*cra_exit)(struct crypto_tfm___27 *);
	void (*cra_destroy)(struct crypto_alg___27 *);
	struct module___269 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct aead_request___3 {
	struct crypto_async_request___12 base;
	unsigned int assoclen;
	unsigned int cryptlen;
	u8 *iv;
	struct scatterlist *src;
	struct scatterlist *dst;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct crypto_aead___4 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___27 base;
};

struct tls_rec {
	struct list_head list;
	int tx_ready;
	int tx_flags;
	struct sk_msg___3 msg_plaintext;
	struct sk_msg___3 msg_encrypted;
	struct scatterlist sg_aead_in[2];
	struct scatterlist sg_aead_out[2];
	char content_type;
	struct scatterlist sg_content_type;
	char aad_space[13];
	u8 iv_data[16];
	long: 24;
	long: 64;
	long: 64;
	struct aead_request___3 aead_req;
	u8 aead_req_ctx[0];
};

struct tx_work {
	struct delayed_work work;
	struct sock___81 *sk;
};

struct tls_sw_context_tx {
	struct crypto_aead___4 *aead_send;
	struct crypto_wait async_wait;
	struct tx_work tx_work;
	struct tls_rec *open_rec;
	struct list_head tx_list;
	atomic_t encrypt_pending;
	spinlock_t encrypt_compl_lock;
	int async_notify;
	u8 async_capable: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int tx_bitmask;
};

struct tls_context___2 {
	struct tls_prot_info prot_info;
	u8 tx_conf: 3;
	u8 rx_conf: 3;
	long: 61;
	long: 64;
	long: 64;
	int (*push_pending_record)(struct sock___81 *, int);
	void (*sk_write_space)(struct sock___81 *);
	void *priv_ctx_tx;
	void *priv_ctx_rx;
	struct net_device___94 *netdev;
	struct cipher_context tx;
	struct cipher_context rx;
	struct scatterlist *partially_sent_record;
	u16 partially_sent_offset;
	bool in_tcp_sendpages;
	bool pending_open_record_frags;
	struct mutex tx_lock;
	long unsigned int flags;
	struct proto___81 *sk_proto;
	struct sock___81 *sk;
	void (*sk_destruct)(struct sock___81 *);
	union tls_crypto_context crypto_send;
	union tls_crypto_context crypto_recv;
	struct list_head list;
	refcount_t refcount;
	struct callback_head rcu;
};

enum {
	TCP_BPF_IPV4 = 0,
	TCP_BPF_IPV6 = 1,
	TCP_BPF_NUM_PROTS = 2,
};

enum {
	TCP_BPF_BASE = 0,
	TCP_BPF_TX = 1,
	TCP_BPF_RX = 2,
	TCP_BPF_TXRX = 3,
	TCP_BPF_NUM_CFGS = 4,
};

struct udp_sock___4 {
	struct inet_sock___20 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	unsigned char encap_enabled: 1;
	unsigned char gro_enabled: 1;
	unsigned char accept_udp_l4: 1;
	unsigned char accept_udp_fraglist: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___81 *, struct sk_buff___95 *);
	int (*encap_err_lookup)(struct sock___81 *, struct sk_buff___95 *);
	void (*encap_destroy)(struct sock___81 *);
	struct sk_buff___95 * (*gro_receive)(struct sock___81 *, struct list_head *, struct sk_buff___95 *);
	int (*gro_complete)(struct sock___81 *, struct sk_buff___95 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___94 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

enum {
	UDP_BPF_IPV4 = 0,
	UDP_BPF_IPV6 = 1,
	UDP_BPF_NUM_PROTS = 2,
};

typedef struct bio_vec___202 skb_frag_t___37;

struct cipso_v4_map_cache_bkt {
	spinlock_t lock;
	u32 size;
	struct list_head list;
};

struct cipso_v4_map_cache_entry {
	u32 hash;
	unsigned char *key;
	size_t key_len;
	struct netlbl_lsm_cache *lsm_data;
	u32 activity;
	struct list_head list;
};

struct xfrm_policy_afinfo {
	struct dst_ops___99 *dst_ops;
	struct dst_entry___81 * (*dst_lookup)(struct net___99 *, int, int, const xfrm_address_t *, const xfrm_address_t *, u32);
	int (*get_saddr)(struct net___99 *, int, xfrm_address_t *, xfrm_address_t *, u32);
	int (*fill_dst)(struct xfrm_dst___2 *, struct net_device___94 *, const struct flowi *);
	struct dst_entry___81 * (*blackhole_route)(struct net___99 *, struct dst_entry___81 *);
};

struct xfrm_state_afinfo {
	u8 family;
	u8 proto;
	const struct xfrm_type_offload *type_offload_esp;
	const struct xfrm_type *type_esp;
	const struct xfrm_type *type_ipip;
	const struct xfrm_type *type_ipip6;
	const struct xfrm_type *type_comp;
	const struct xfrm_type *type_ah;
	const struct xfrm_type *type_routing;
	const struct xfrm_type *type_dstopts;
	int (*output)(struct net___99 *, struct sock___81 *, struct sk_buff___95 *);
	int (*transport_finish)(struct sk_buff___95 *, int);
	void (*local_error)(struct sk_buff___95 *, u32);
};

typedef unsigned int nf_hookfn___21(void *, struct sk_buff___95 *, const struct nf_hook_state *);

struct ip_tunnel;

struct ip6_tnl;

struct xfrm_tunnel_skb_cb {
	union {
		struct inet_skb_parm___2 h4;
		struct inet6_skb_parm h6;
	} header;
	union {
		struct ip_tunnel *ip4;
		struct ip6_tnl *ip6;
	} tunnel;
};

struct xfrm_mode_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	__be16 id;
	__be16 frag_off;
	u8 ihl;
	u8 tos;
	u8 ttl;
	u8 protocol;
	u8 optlen;
	u8 flow_lbl[3];
};

struct xfrm_spi_skb_cb {
	struct xfrm_tunnel_skb_cb header;
	unsigned int daddroff;
	unsigned int family;
	__be32 seq;
};

struct xfrm_input_afinfo {
	u8 family;
	bool is_ipip;
	int (*callback)(struct sk_buff___95 *, u8, int);
};

struct xfrm_tunnel_skb_cb___2 {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	union {
		struct ip_tunnel *ip4;
		struct ip6_tnl *ip6;
	} tunnel;
};

struct xfrm_spi_skb_cb___2 {
	struct xfrm_tunnel_skb_cb___2 header;
	unsigned int daddroff;
	unsigned int family;
	__be32 seq;
};

struct xfrm4_protocol {
	int (*handler)(struct sk_buff___95 *);
	int (*input_handler)(struct sk_buff___95 *, int, __be32, int);
	int (*cb_handler)(struct sk_buff___95 *, int);
	int (*err_handler)(struct sk_buff___95 *, u32);
	struct xfrm4_protocol *next;
	int priority;
};

struct dentry___286;

struct super_block___286;

struct module___270;

struct file_system_type___286 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___286 * (*mount)(struct file_system_type___286 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___286 *);
	struct module___270 *owner;
	struct file_system_type___286 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___286;

struct kiocb___286;

struct iov_iter___206;

struct poll_table_struct___207;

struct vm_area_struct___291;

struct inode___286;

struct file_lock___286;

struct page___291;

struct pipe_inode_info___127;

struct seq_file___261;

struct file_operations___287 {
	struct module___270 *owner;
	loff_t (*llseek)(struct file___286 *, loff_t, int);
	ssize_t (*read)(struct file___286 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___286 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___286 *, struct iov_iter___206 *);
	ssize_t (*write_iter)(struct kiocb___286 *, struct iov_iter___206 *);
	int (*iopoll)(struct kiocb___286 *, bool);
	int (*iterate)(struct file___286 *, struct dir_context *);
	int (*iterate_shared)(struct file___286 *, struct dir_context *);
	__poll_t (*poll)(struct file___286 *, struct poll_table_struct___207 *);
	long int (*unlocked_ioctl)(struct file___286 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___286 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___286 *, struct vm_area_struct___291 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___286 *, struct file___286 *);
	int (*flush)(struct file___286 *, fl_owner_t);
	int (*release)(struct inode___286 *, struct file___286 *);
	int (*fsync)(struct file___286 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___286 *, int);
	int (*lock)(struct file___286 *, int, struct file_lock___286 *);
	ssize_t (*sendpage)(struct file___286 *, struct page___291 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___286 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___286 *, long unsigned int);
	int (*flock)(struct file___286 *, int, struct file_lock___286 *);
	ssize_t (*splice_write)(struct pipe_inode_info___127 *, struct file___286 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___286 *, loff_t *, struct pipe_inode_info___127 *, size_t, unsigned int);
	int (*setlease)(struct file___286 *, long int, struct file_lock___286 **, void **);
	long int (*fallocate)(struct file___286 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___261 *, struct file___286 *);
	ssize_t (*copy_file_range)(struct file___286 *, loff_t, struct file___286 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___286 *, loff_t, struct file___286 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___286 *, loff_t, loff_t, int);
};

struct vmacache___291 {
	u64 seqnum;
	struct vm_area_struct___291 *vmas[4];
};

struct page_frag___291 {
	struct page___291 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___292;

struct pid___263;

struct nsproxy___272;

struct signal_struct___287;

struct bio_list___177;

struct backing_dev_info___163;

struct io_context___177;

struct css_set___213;

struct mem_cgroup___151;

struct request_queue___177;

struct vm_struct___269;

struct bpf_local_storage___10;

struct task_struct___293 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___293 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___292 *mm;
	struct mm_struct___292 *active_mm;
	struct vmacache___291 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___293 *real_parent;
	struct task_struct___293 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___293 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___263 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___272 *nsproxy;
	struct signal_struct___287 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___293 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___177 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___163 *backing_dev_info;
	struct io_context___177 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___213 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___127 *splice_pipe;
	struct page_frag___291 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___151 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___151 *active_memcg;
	struct request_queue___177 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___293 *oom_reaper_list;
	struct vm_struct___269 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage___10 *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___274;

struct kobj_type___274;

struct kernfs_node___274;

struct kobject___274 {
	const char *name;
	struct list_head entry;
	struct kobject___274 *parent;
	struct kset___274 *kset;
	struct kobj_type___274 *ktype;
	struct kernfs_node___274 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___271 {
	struct kobject___274 kobj;
	struct module___270 *mod;
	struct kobject___274 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___270 {
	struct module___270 *mod;
	struct latch_tree_node node;
};

struct module_layout___270 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___270 mtn;
};

struct module_attribute___270;

struct kernel_param___270;

struct module___270 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___271 mkobj;
	struct module_attribute___270 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___274 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___270 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___270 core_layout;
	struct module_layout___270 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___286;

struct path___286 {
	struct vfsmount___286 *mnt;
	struct dentry___286 *dentry;
};

struct fown_struct___263 {
	rwlock_t lock;
	struct pid___263 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___286;

struct file___286 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___286 f_path;
	struct inode___286 *f_inode;
	const struct file_operations___287 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___263 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___286 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___291 *pgtable_t___291;

struct page_pool___115;

struct dev_pagemap___281;

struct page___291 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___286 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___115 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___291 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___291 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___292 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___281 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___281;

struct vm_area_struct___291 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___291 *vm_next;
	struct vm_area_struct___291 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___292 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___281 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___286 *vm_file;
	struct file___286 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___291;

struct mm_struct___292 {
	struct {
		struct vm_area_struct___291 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___286 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___291 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___293 *owner;
		struct user_namespace___26 *user_ns;
		struct file___286 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___286;

struct address_space___286 {
	struct inode___286 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___286 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___267;

struct page_pool_params___115 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___267 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___115 {
	u32 count;
	struct page___291 *cache[128];
};

struct page_pool___115 {
	struct page_pool_params___115 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___291 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___115 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___281;

struct dev_pagemap___281 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___281 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___281;

struct vm_operations_struct___281 {
	void (*open)(struct vm_area_struct___291 *);
	void (*close)(struct vm_area_struct___291 *);
	int (*may_split)(struct vm_area_struct___291 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___291 *);
	int (*mprotect)(struct vm_area_struct___291 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___281 *);
	vm_fault_t (*huge_fault)(struct vm_fault___281 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___281 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___291 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___281 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___281 *);
	int (*access)(struct vm_area_struct___291 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___291 *);
	int (*set_policy)(struct vm_area_struct___291 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___291 *, long unsigned int);
	struct page___291 * (*find_special_page)(struct vm_area_struct___291 *, long unsigned int);
};

struct core_thread___291 {
	struct task_struct___293 *task;
	struct core_thread___291 *next;
};

struct core_state___291 {
	atomic_t nr_threads;
	struct core_thread___291 dumper;
	struct completion startup;
};

struct vm_fault___281 {
	const struct {
		struct vm_area_struct___291 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___291 *cow_page;
	struct page___291 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___291 prealloc_pte;
};

struct pid_namespace___263;

struct upid___263 {
	int nr;
	struct pid_namespace___263 *ns;
};

struct pid_namespace___263 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___293 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___263 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___263 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___263 numbers[1];
};

struct signal_struct___287 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___293 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___293 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___263 *pids[4];
	struct pid___263 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___292 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___100;

struct cgroup_namespace___213;

struct nsproxy___272 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___263 *pid_ns_for_children;
	struct net___100 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___213 *cgroup_ns;
};

struct bio___177;

struct bio_list___177 {
	struct bio___177 *head;
	struct bio___177 *tail;
};

struct cgroup_subsys_state___213;

struct bdi_writeback___163 {
	struct backing_dev_info___163 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___213 *memcg_css;
	struct cgroup_subsys_state___213 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___163 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___163 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___267 *dev;
	char dev_name[64];
	struct device___267 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___286 *debug_dir;
};

struct io_cq___177;

struct io_context___177 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___177 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___213;

struct css_set___213 {
	struct cgroup_subsys_state___213 *subsys[14];
	refcount_t refcount;
	struct css_set___213 *dom_cset;
	struct cgroup___213 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___213 *mg_src_cgrp;
	struct cgroup___213 *mg_dst_cgrp;
	struct css_set___213 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___286;

struct pipe_buffer___127;

struct pipe_inode_info___127 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___291 *tmp_page;
	struct fasync_struct___286 *fasync_readers;
	struct fasync_struct___286 *fasync_writers;
	struct pipe_buffer___127 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___213;

struct cgroup_subsys_state___213 {
	struct cgroup___213 *cgroup;
	struct cgroup_subsys___213 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___213 *parent;
};

struct cgroup_file___213 {
	struct kernfs_node___274 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___151;

struct mem_cgroup_per_node___151;

struct mem_cgroup___151 {
	struct cgroup_subsys_state___213 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___213 events_file;
	struct cgroup_file___213 events_local_file;
	struct cgroup_file___213 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___151 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___293 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___151 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___177;

struct blk_integrity___177 {
	const struct blk_integrity_profile___177 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___177 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___177 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___177;

struct elevator_queue___177;

struct blk_mq_ops___172;

struct blk_mq_hw_ctx___172;

struct gendisk___180;

struct blkcg_gq___165;

struct blk_mq_tag_set___172;

struct request_queue___177 {
	struct request___177 *last_merge;
	struct elevator_queue___177 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___172 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___172 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___180 *disk;
	struct kobject___274 kobj;
	struct kobject___274 *mq_kobj;
	struct blk_integrity___177 integrity;
	struct device___267 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___165 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___172 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___177 bio_split;
	struct dentry___286 *debugfs_dir;
	struct dentry___286 *sched_debugfs_dir;
	struct dentry___286 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___269 {
	struct vm_struct___269 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___291 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bpf_local_storage_data___10;

struct bpf_local_storage___10 {
	struct bpf_local_storage_data___10 *cache[16];
	struct hlist_head list;
	void *owner;
	struct callback_head rcu;
	raw_spinlock_t lock;
};

struct pglist_data___159;

struct lruvec___159 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___159 *pgdat;
};

struct zone___159 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___159 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___159 {
	struct zone___159 *zone;
	int zone_idx;
};

struct zonelist___159 {
	struct zoneref___159 _zonerefs[321];
};

struct pglist_data___159 {
	struct zone___159 node_zones[5];
	struct zonelist___159 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___293 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___293 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___159 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___286;

struct dentry___286 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___286 *d_parent;
	struct qstr d_name;
	struct inode___286 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___286 *d_op;
	struct super_block___286 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___286;

struct inode___286 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___286 *i_op;
	struct super_block___286 *i_sb;
	struct address_space___286 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___163 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___287 *i_fop;
		void (*free_inode)(struct inode___286 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___286 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___127 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___286 {
	int (*d_revalidate)(struct dentry___286 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___286 *, unsigned int);
	int (*d_hash)(const struct dentry___286 *, struct qstr *);
	int (*d_compare)(const struct dentry___286 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___286 *);
	int (*d_init)(struct dentry___286 *);
	void (*d_release)(struct dentry___286 *);
	void (*d_prune)(struct dentry___286 *);
	void (*d_iput)(struct dentry___286 *, struct inode___286 *);
	char * (*d_dname)(struct dentry___286 *, char *, int);
	struct vfsmount___286 * (*d_automount)(struct path___286 *);
	int (*d_manage)(const struct path___286 *, bool);
	struct dentry___286 * (*d_real)(struct dentry___286 *, const struct inode___286 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___286;

struct mem_dqinfo___286 {
	struct quota_format_type___286 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___286;

struct quota_info___286 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___286 *files[3];
	struct mem_dqinfo___286 info[3];
	const struct quota_format_ops___286 *ops[3];
};

struct rcuwait___287 {
	struct task_struct___293 *task;
};

struct percpu_rw_semaphore___287 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___287 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___286 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___287 rw_sem[3];
};

struct shrink_control___151;

struct shrinker___151 {
	long unsigned int (*count_objects)(struct shrinker___151 *, struct shrink_control___151 *);
	long unsigned int (*scan_objects)(struct shrinker___151 *, struct shrink_control___151 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___286;

struct dquot_operations___286;

struct quotactl_ops___286;

struct block_device___180;

struct super_block___286 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___286 *s_type;
	const struct super_operations___286 *s_op;
	const struct dquot_operations___286 *dq_op;
	const struct quotactl_ops___286 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___286 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___180 *s_bdev;
	struct backing_dev_info___163 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___286 s_dquot;
	struct sb_writers___286 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___286 *s_d_op;
	int cleancache_poolid;
	struct shrinker___151 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___286 {
	struct dentry___286 *mnt_root;
	struct super_block___286 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___151 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___151 *memcg;
};

struct psi_group___213 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___293 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___89;

struct cgroup_bpf___89 {
	struct bpf_prog_array___89 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___89 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___213;

struct cgroup_rstat_cpu___213;

struct cgroup___213 {
	struct cgroup_subsys_state___213 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___274 *kn;
	struct cgroup_file___213 procs_file;
	struct cgroup_file___213 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___213 *subsys[14];
	struct cgroup_root___213 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___213 *dom_cgrp;
	struct cgroup___213 *old_dom_cgrp;
	struct cgroup_rstat_cpu___213 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___213 psi;
	struct cgroup_bpf___89 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___177 {
	struct request_queue___177 *q;
	struct io_context___177 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___286 {
	struct file___286 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___286 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___286 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___286 *ia_file;
};

struct dquot___286 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___286 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___286 {
	int qf_fmt_id;
	const struct quota_format_ops___286 *qf_ops;
	struct module___270 *qf_owner;
	struct quota_format_type___286 *qf_next;
};

struct quota_format_ops___286 {
	int (*check_quota_file)(struct super_block___286 *, int);
	int (*read_file_info)(struct super_block___286 *, int);
	int (*write_file_info)(struct super_block___286 *, int);
	int (*free_file_info)(struct super_block___286 *, int);
	int (*read_dqblk)(struct dquot___286 *);
	int (*commit_dqblk)(struct dquot___286 *);
	int (*release_dqblk)(struct dquot___286 *);
	int (*get_next_id)(struct super_block___286 *, struct kqid *);
};

struct dquot_operations___286 {
	int (*write_dquot)(struct dquot___286 *);
	struct dquot___286 * (*alloc_dquot)(struct super_block___286 *, int);
	void (*destroy_dquot)(struct dquot___286 *);
	int (*acquire_dquot)(struct dquot___286 *);
	int (*release_dquot)(struct dquot___286 *);
	int (*mark_dirty)(struct dquot___286 *);
	int (*write_info)(struct super_block___286 *, int);
	qsize_t * (*get_reserved_space)(struct inode___286 *);
	int (*get_projid)(struct inode___286 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___286 *, qsize_t *);
	int (*get_next_id)(struct super_block___286 *, struct kqid *);
};

struct quotactl_ops___286 {
	int (*quota_on)(struct super_block___286 *, int, int, const struct path___286 *);
	int (*quota_off)(struct super_block___286 *, int);
	int (*quota_enable)(struct super_block___286 *, unsigned int);
	int (*quota_disable)(struct super_block___286 *, unsigned int);
	int (*quota_sync)(struct super_block___286 *, int);
	int (*set_info)(struct super_block___286 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___286 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___286 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___286 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___286 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___286 *, unsigned int);
};

struct writeback_control___163;

struct address_space_operations___286 {
	int (*writepage)(struct page___291 *, struct writeback_control___163 *);
	int (*readpage)(struct file___286 *, struct page___291 *);
	int (*writepages)(struct address_space___286 *, struct writeback_control___163 *);
	int (*set_page_dirty)(struct page___291 *);
	int (*readpages)(struct file___286 *, struct address_space___286 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___286 *, struct address_space___286 *, loff_t, unsigned int, unsigned int, struct page___291 **, void **);
	int (*write_end)(struct file___286 *, struct address_space___286 *, loff_t, unsigned int, unsigned int, struct page___291 *, void *);
	sector_t (*bmap)(struct address_space___286 *, sector_t);
	void (*invalidatepage)(struct page___291 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___291 *, gfp_t);
	void (*freepage)(struct page___291 *);
	ssize_t (*direct_IO)(struct kiocb___286 *, struct iov_iter___206 *);
	int (*migratepage)(struct address_space___286 *, struct page___291 *, struct page___291 *, enum migrate_mode);
	bool (*isolate_page)(struct page___291 *, isolate_mode_t);
	void (*putback_page)(struct page___291 *);
	int (*launder_page)(struct page___291 *);
	int (*is_partially_uptodate)(struct page___291 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___291 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___286 *, struct page___291 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___286 *, sector_t *);
	void (*swap_deactivate)(struct file___286 *);
};

struct writeback_control___163 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___163 *wb;
	struct inode___286 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___203;

struct iov_iter___206 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___203 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___127 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___286 {
	struct dentry___286 * (*lookup)(struct inode___286 *, struct dentry___286 *, unsigned int);
	const char * (*get_link)(struct dentry___286 *, struct inode___286 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___286 *, int);
	struct posix_acl * (*get_acl)(struct inode___286 *, int, bool);
	int (*readlink)(struct dentry___286 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___286 *, struct dentry___286 *, umode_t, bool);
	int (*link)(struct dentry___286 *, struct inode___286 *, struct dentry___286 *);
	int (*unlink)(struct inode___286 *, struct dentry___286 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___286 *, struct dentry___286 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___286 *, struct dentry___286 *, umode_t);
	int (*rmdir)(struct inode___286 *, struct dentry___286 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___286 *, struct dentry___286 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___286 *, struct dentry___286 *, struct inode___286 *, struct dentry___286 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___286 *, struct iattr___286 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___286 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___286 *, char *, size_t);
	int (*fiemap)(struct inode___286 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___286 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___286 *, struct dentry___286 *, struct file___286 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___286 *, struct dentry___286 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___286 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___286 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___286 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___286 {
	void (*fl_copy_lock)(struct file_lock___286 *, struct file_lock___286 *);
	void (*fl_release_private)(struct file_lock___286 *);
};

struct lock_manager_operations___286;

struct file_lock___286 {
	struct file_lock___286 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___286 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___286 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___286 *fl_ops;
	const struct lock_manager_operations___286 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___286 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___286 *);
	int (*lm_grant)(struct file_lock___286 *, int);
	bool (*lm_break)(struct file_lock___286 *);
	int (*lm_change)(struct file_lock___286 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___286 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___286 *);
};

struct fasync_struct___286 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___286 *fa_next;
	struct file___286 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___286 {
	struct inode___286 * (*alloc_inode)(struct super_block___286 *);
	void (*destroy_inode)(struct inode___286 *);
	void (*free_inode)(struct inode___286 *);
	void (*dirty_inode)(struct inode___286 *, int);
	int (*write_inode)(struct inode___286 *, struct writeback_control___163 *);
	int (*drop_inode)(struct inode___286 *);
	void (*evict_inode)(struct inode___286 *);
	void (*put_super)(struct super_block___286 *);
	int (*sync_fs)(struct super_block___286 *, int);
	int (*freeze_super)(struct super_block___286 *);
	int (*freeze_fs)(struct super_block___286 *);
	int (*thaw_super)(struct super_block___286 *);
	int (*unfreeze_fs)(struct super_block___286 *);
	int (*statfs)(struct dentry___286 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___286 *, int *, char *);
	void (*umount_begin)(struct super_block___286 *);
	int (*show_options)(struct seq_file___261 *, struct dentry___286 *);
	int (*show_devname)(struct seq_file___261 *, struct dentry___286 *);
	int (*show_path)(struct seq_file___261 *, struct dentry___286 *);
	int (*show_stats)(struct seq_file___261 *, struct dentry___286 *);
	ssize_t (*quota_read)(struct super_block___286 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___286 *, int, const char *, size_t, loff_t);
	struct dquot___286 ** (*get_dquots)(struct inode___286 *);
	long int (*nr_cached_objects)(struct super_block___286 *, struct shrink_control___151 *);
	long int (*free_cached_objects)(struct super_block___286 *, struct shrink_control___151 *);
	struct file___286 * (*real_loop)(struct file___286 *);
};

struct wakeup_source___267;

struct dev_pm_info___267 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___267 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___267 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___267;

struct bus_type___267;

struct device_driver___267;

struct dev_pm_domain___267;

struct fwnode_handle___263;

struct class___267;

struct attribute_group___274;

struct device___267 {
	struct kobject___274 kobj;
	struct device___267 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___267 *type;
	struct bus_type___267 *bus;
	struct device_driver___267 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___267 power;
	struct dev_pm_domain___267 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___263 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___267 *class;
	const struct attribute_group___274 **groups;
	void (*release)(struct device___267 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___180 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___286 *bd_inode;
	struct super_block___286 *bd_super;
	void *bd_claiming;
	struct device___267 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___274 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___180 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___286 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___215)(struct file___286 *, wait_queue_head_t *, struct poll_table_struct___207 *);

struct poll_table_struct___207 {
	poll_queue_proc___215 _qproc;
	__poll_t _key;
};

struct seq_operations___261;

struct seq_file___261 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___261 *op;
	int poll_event;
	const struct file___286 *file;
	void *private;
};

typedef void bio_end_io_t___177(struct bio___177 *);

struct bio_vec___203 {
	struct page___291 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___177;

struct bio___177 {
	struct bio___177 *bi_next;
	struct block_device___180 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___177 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___165 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___177 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___203 *bi_io_vec;
	struct bio_set___177 *bi_pool;
	struct bio_vec___203 bi_inline_vecs[0];
};

struct kernfs_root___274;

struct kernfs_elem_dir___274 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___274 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___274;

struct kernfs_root___274 {
	struct kernfs_node___274 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___274 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___274 {
	struct kernfs_node___274 *target_kn;
};

struct kernfs_ops___274;

struct kernfs_elem_attr___274 {
	const struct kernfs_ops___274 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___274 *notify_next;
};

struct kernfs_node___274 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___274 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___274 dir;
		struct kernfs_elem_symlink___274 symlink;
		struct kernfs_elem_attr___274 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___274;

struct kernfs_ops___274 {
	int (*open)(struct kernfs_open_file___274 *);
	void (*release)(struct kernfs_open_file___274 *);
	int (*seq_show)(struct seq_file___261 *, void *);
	void * (*seq_start)(struct seq_file___261 *, loff_t *);
	void * (*seq_next)(struct seq_file___261 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___261 *, void *);
	ssize_t (*read)(struct kernfs_open_file___274 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___274 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___274 *, struct poll_table_struct___207 *);
	int (*mmap)(struct kernfs_open_file___274 *, struct vm_area_struct___291 *);
};

struct kernfs_syscall_ops___274 {
	int (*show_options)(struct seq_file___261 *, struct kernfs_root___274 *);
	int (*mkdir)(struct kernfs_node___274 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___274 *);
	int (*rename)(struct kernfs_node___274 *, struct kernfs_node___274 *, const char *);
	int (*show_path)(struct seq_file___261 *, struct kernfs_node___274 *, struct kernfs_root___274 *);
};

struct kernfs_open_file___274 {
	struct kernfs_node___274 *kn;
	struct file___286 *file;
	struct seq_file___261 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___281 *vm_ops;
};

struct sock___82;

struct kobj_ns_type_operations___82 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___82 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___100 *net;
} possible_net_t___95;

struct proto___82;

struct sock_common___82 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___82 *skc_prot;
	possible_net_t___95 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___82 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___96;

struct sk_buff_head___95 {
	struct sk_buff___96 *next;
	struct sk_buff___96 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___82 {
	struct cgroup___213 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___82;

struct socket_wq___83;

struct dst_entry___82;

struct socket___84;

struct net_device___95;

struct sock_reuseport___30;

struct sock___82 {
	struct sock_common___82 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___95 sk_error_queue;
	struct sk_buff___96 *sk_rx_skb_cache;
	struct sk_buff_head___95 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___96 *head;
		struct sk_buff___96 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___82 *sk_filter;
	union {
		struct socket_wq___83 *sk_wq;
		struct socket_wq___83 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___82 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___82 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___96 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___96 *sk_tx_skb_cache;
	struct sk_buff_head___95 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___291 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___82 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___263 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___84 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___82 sk_cgrp_data;
	struct mem_cgroup___151 *sk_memcg;
	void (*sk_state_change)(struct sock___82 *);
	void (*sk_data_ready)(struct sock___82 *);
	void (*sk_write_space)(struct sock___82 *);
	void (*sk_error_report)(struct sock___82 *);
	int (*sk_backlog_rcv)(struct sock___82 *, struct sk_buff___96 *);
	struct sk_buff___96 * (*sk_validate_xmit_skb)(struct sock___82 *, struct net_device___95 *, struct sk_buff___96 *);
	void (*sk_destruct)(struct sock___82 *);
	struct sock_reuseport___30 *sk_reuseport_cb;
	struct bpf_local_storage___10 *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___274;

struct attribute_group___274 {
	const char *name;
	umode_t (*is_visible)(struct kobject___274 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___274 *, struct bin_attribute___274 *, int);
	struct attribute **attrs;
	struct bin_attribute___274 **bin_attrs;
};

struct bin_attribute___274 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___286 * (*f_mapping)();
	ssize_t (*read)(struct file___286 *, struct kobject___274 *, struct bin_attribute___274 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___286 *, struct kobject___274 *, struct bin_attribute___274 *, char *, loff_t, size_t);
	int (*mmap)(struct file___286 *, struct kobject___274 *, struct bin_attribute___274 *, struct vm_area_struct___291 *);
};

struct sysfs_ops___274 {
	ssize_t (*show)(struct kobject___274 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___274 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___274;

struct kset___274 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___274 kobj;
	const struct kset_uevent_ops___274 *uevent_ops;
};

struct kobj_type___274 {
	void (*release)(struct kobject___274 *);
	const struct sysfs_ops___274 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___274 **default_groups;
	const struct kobj_ns_type_operations___82 * (*child_ns_type)(struct kobject___274 *);
	const void * (*namespace)(struct kobject___274 *);
	void (*get_ownership)(struct kobject___274 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___274 {
	int (* const filter)(struct kset___274 *, struct kobject___274 *);
	const char * (* const name)(struct kset___274 *, struct kobject___274 *);
	int (* const uevent)(struct kset___274 *, struct kobject___274 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___270 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___270 *);
	int (*get)(char *, const struct kernel_param___270 *);
	void (*free)(void *);
};

struct kparam_array___270;

struct kernel_param___270 {
	const char *name;
	struct module___270 *mod;
	const struct kernel_param_ops___270 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___270 *arr;
	};
};

struct kparam_array___270 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___270 *ops;
	void *elem;
};

struct module_attribute___270 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___270 *, struct module_kobject___271 *, char *);
	ssize_t (*store)(struct module_attribute___270 *, struct module_kobject___271 *, const char *, size_t);
	void (*setup)(struct module___270 *, const char *);
	int (*test)(struct module___270 *);
	void (*free)(struct module___270 *);
};

struct dev_pagemap_ops___281 {
	void (*page_free)(struct page___291 *);
	void (*kill)(struct dev_pagemap___281 *);
	void (*cleanup)(struct dev_pagemap___281 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___281 *);
};

struct bpf_iter_aux_info___98;

typedef int (*bpf_iter_init_seq_priv_t___97)(void *, struct bpf_iter_aux_info___98 *);

struct bpf_map___98;

struct bpf_iter_aux_info___98 {
	struct bpf_map___98 *map;
};

struct bpf_iter_seq_info___97 {
	const struct seq_operations___261 *seq_ops;
	bpf_iter_init_seq_priv_t___97 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___261 {
	void * (*start)(struct seq_file___261 *, loff_t *);
	void (*stop)(struct seq_file___261 *, void *);
	void * (*next)(struct seq_file___261 *, void *, loff_t *);
	int (*show)(struct seq_file___261 *, void *);
};

struct bpf_prog_aux___98;

struct bpf_prog___89;

struct bpf_local_storage_map___10;

struct bpf_verifier_env___6;

struct bpf_func_state___6;

struct bpf_map_ops___97 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___98 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___98 *, struct file___286 *);
	void (*map_free)(struct bpf_map___98 *);
	int (*map_get_next_key)(struct bpf_map___98 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___98 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___98 *, void *);
	int (*map_lookup_batch)(struct bpf_map___98 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___98 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___98 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___98 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___98 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___98 *, void *);
	int (*map_update_elem)(struct bpf_map___98 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___98 *, void *);
	int (*map_push_elem)(struct bpf_map___98 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___98 *, void *);
	int (*map_peek_elem)(struct bpf_map___98 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___98 *, struct file___286 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___98 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___98 *, void *, struct seq_file___261 *);
	int (*map_check_btf)(const struct bpf_map___98 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___98 *, struct bpf_prog_aux___98 *);
	void (*map_poke_untrack)(struct bpf_map___98 *, struct bpf_prog_aux___98 *);
	void (*map_poke_run)(struct bpf_map___98 *, u32, struct bpf_prog___89 *, struct bpf_prog___89 *);
	int (*map_direct_value_addr)(const struct bpf_map___98 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___98 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___98 *, struct vm_area_struct___291 *);
	__poll_t (*map_poll)(struct bpf_map___98 *, struct file___286 *, struct poll_table_struct___207 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map___10 *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map___10 *, void *, u32);
	struct bpf_local_storage___10 ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___98 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___98 *, const struct bpf_map___98 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env___6 *, struct bpf_func_state___6 *, struct bpf_func_state___6 *);
	int (*map_for_each_callback)(struct bpf_map___98 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___97 *iter_seq_info;
};

struct bpf_map___98 {
	const struct bpf_map_ops___97 *ops;
	struct bpf_map___98 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___151 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___97;

struct bpf_jit_poke_descriptor___97;

struct bpf_prog_ops___89;

struct btf_mod_pair___97;

struct bpf_prog_offload___95;

struct bpf_prog_aux___98 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___89 *dst_prog;
	struct bpf_trampoline___97 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___89 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___97 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___89 *ops;
	struct bpf_map___98 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___97 *used_btfs;
	struct bpf_prog___89 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___98 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___95 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___89 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___98 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_local_storage_map___10 {
	struct bpf_map___98 map;
	struct bpf_local_storage_map_bucket *buckets;
	u32 bucket_log;
	u16 elem_size;
	u16 cache_idx;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct btf_mod_pair___97 {
	struct btf *btf;
	struct module___270 *module;
};

struct bpf_verifier_ops___9;

struct bpf_verifier_state___6;

struct bpf_verifier_state_list___6;

struct bpf_verifier_env___6 {
	u32 insn_idx;
	u32 prev_insn_idx;
	struct bpf_prog___89 *prog;
	const struct bpf_verifier_ops___9 *ops;
	struct bpf_verifier_stack_elem *head;
	int stack_size;
	bool strict_alignment;
	bool test_state_freq;
	struct bpf_verifier_state___6 *cur_state;
	struct bpf_verifier_state_list___6 **explored_states;
	struct bpf_verifier_state_list___6 *free_list;
	struct bpf_map___98 *used_maps[64];
	struct btf_mod_pair___97 used_btfs[64];
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 id_gen;
	bool explore_alu_limits;
	bool allow_ptr_leaks;
	bool allow_uninit_stack;
	bool allow_ptr_to_map_access;
	bool bpf_capable;
	bool bypass_spec_v1;
	bool bypass_spec_v4;
	bool seen_direct_write;
	struct bpf_insn_aux_data *insn_aux_data;
	const struct bpf_line_info *prev_linfo;
	struct bpf_verifier_log log;
	struct bpf_subprog_info subprog_info[257];
	struct bpf_id_pair idmap_scratch[75];
	struct {
		int *insn_state;
		int *insn_stack;
		int cur_stack;
	} cfg;
	u32 pass_cnt;
	u32 subprog_cnt;
	u32 prev_insn_processed;
	u32 insn_processed;
	u32 prev_jmps_processed;
	u32 jmps_processed;
	u64 verification_time;
	u32 max_states_per_insn;
	u32 total_states;
	u32 peak_states;
	u32 longest_mark_read_walk;
	bpfptr_t fd_array;
};

struct bpf_reg_state___6 {
	enum bpf_reg_type type;
	s32 off;
	union {
		int range;
		struct {
			struct bpf_map___98 *map_ptr;
			u32 map_uid;
		};
		struct {
			struct btf *btf;
			u32 btf_id;
		};
		u32 mem_size;
		struct {
			long unsigned int raw1;
			long unsigned int raw2;
		} raw;
		u32 subprogno;
	};
	u32 id;
	u32 ref_obj_id;
	struct tnum var_off;
	s64 smin_value;
	s64 smax_value;
	u64 umin_value;
	u64 umax_value;
	s32 s32_min_value;
	s32 s32_max_value;
	u32 u32_min_value;
	u32 u32_max_value;
	struct bpf_reg_state___6 *parent;
	u32 frameno;
	s32 subreg_def;
	enum bpf_reg_liveness live;
	bool precise;
};

struct bpf_stack_state___6;

struct bpf_func_state___6 {
	struct bpf_reg_state___6 regs[11];
	int callsite;
	u32 frameno;
	u32 subprogno;
	u32 async_entry_cnt;
	bool in_callback_fn;
	bool in_async_callback_fn;
	int acquired_refs;
	struct bpf_reference_state *refs;
	int allocated_stack;
	struct bpf_stack_state___6 *stack;
};

struct bpf_offloaded_map___95;

struct bpf_map_dev_ops___95 {
	int (*map_get_next_key)(struct bpf_offloaded_map___95 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___95 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___95 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___95 *, void *);
};

struct bpf_offloaded_map___95 {
	struct bpf_map___98 map;
	struct net_device___95 *netdev;
	const struct bpf_map_dev_ops___95 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___95(struct sk_buff___96 **);

struct bpf_xdp_entity___89 {
	struct bpf_prog___89 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___95;

struct net_device_ops___95;

struct l3mdev_ops___82;

struct ndisc_ops___64;

struct xfrmdev_ops___95;

struct header_ops___95;

struct inet6_dev___64;

struct netdev_rx_queue___95;

struct mini_Qdisc___89;

struct netdev_queue___95;

struct Qdisc___89;

struct rtnl_link_ops___89;

struct dcbnl_rtnl_ops___95;

struct net_device___95 {
	char name[16];
	struct netdev_name_node___95 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___95 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___82 *l3mdev_ops;
	const struct ndisc_ops___64 *ndisc_ops;
	const struct xfrmdev_ops___95 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___95 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___274 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___64 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___95 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___89 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___95 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___89 *miniq_ingress;
	struct netdev_queue___95 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___95 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___89 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___89 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___95 = 0,
		NETREG_REGISTERED___95 = 1,
		NETREG_UNREGISTERING___95 = 2,
		NETREG_UNREGISTERED___95 = 3,
		NETREG_RELEASED___95 = 4,
		NETREG_DUMMY___95 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___95 = 0,
		RTNL_LINK_INITIALIZING___95 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___95 *);
	struct netpoll_info *npinfo;
	possible_net_t___95 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___267 dev;
	const struct attribute_group___274 *sysfs_groups[4];
	const struct attribute_group___274 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___89 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___95 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___89 xdp_state[3];
	long: 64;
};

struct bpf_func_proto___15 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___89 *);
};

struct bpf_prog_ops___89 {
	int (*test_run)(struct bpf_prog___89 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_verifier_ops___9 {
	const struct bpf_func_proto___15 * (*get_func_proto)(enum bpf_func_id, const struct bpf_prog___89 *);
	bool (*is_valid_access)(int, int, enum bpf_access_type, const struct bpf_prog___89 *, struct bpf_insn_access_aux *);
	int (*gen_prologue)(struct bpf_insn *, bool, const struct bpf_prog___89 *);
	int (*gen_ld_abs)(const struct bpf_insn *, struct bpf_insn *);
	u32 (*convert_ctx_access)(enum bpf_access_type, const struct bpf_insn *, struct bpf_insn *, struct bpf_prog___89 *, u32 *);
	int (*btf_struct_access)(struct bpf_verifier_log *, const struct btf *, const struct btf_type *, int, int, enum bpf_access_type, u32 *);
	bool (*check_kfunc_call)(u32);
};

struct bpf_prog_offload___95 {
	struct bpf_prog___89 *prog;
	struct net_device___95 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___97 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___89 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___270 *mod;
};

struct bpf_jit_poke_descriptor___97 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___98 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct bpf_struct_ops___3 {
	const struct bpf_verifier_ops___9 *verifier_ops;
	int (*init)(struct btf *);
	int (*check_member)(const struct btf_type *, const struct btf_member *);
	int (*init_member)(const struct btf_type *, const struct btf_member *, void *, const void *);
	int (*reg)(void *);
	void (*unreg)(void *);
	const struct btf_type *type;
	const struct btf_type *value_type;
	const char *name;
	struct btf_func_model func_models[64];
	u32 type_id;
	u32 value_id;
};

struct bpf_prog_array_item___89 {
	struct bpf_prog___89 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___89 {
	struct callback_head rcu;
	struct bpf_prog_array_item___89 items[0];
};

struct sk_buff___96 {
	union {
		struct {
			struct sk_buff___96 *next;
			struct sk_buff___96 *prev;
			union {
				struct net_device___95 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___82 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___96 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct msghdr___84 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___206 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___286 *msg_iocb;
};

struct fwnode_operations___263;

struct fwnode_handle___263 {
	struct fwnode_handle___263 *secondary;
	const struct fwnode_operations___263 *ops;
	struct device___267 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___263;

struct fwnode_endpoint___263;

struct fwnode_operations___263 {
	struct fwnode_handle___263 * (*get)(struct fwnode_handle___263 *);
	void (*put)(struct fwnode_handle___263 *);
	bool (*device_is_available)(const struct fwnode_handle___263 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___263 *, const struct device___267 *);
	bool (*property_present)(const struct fwnode_handle___263 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___263 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___263 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___263 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*get_parent)(const struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*get_next_child_node)(const struct fwnode_handle___263 *, struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*get_named_child_node)(const struct fwnode_handle___263 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___263 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___263 *);
	struct fwnode_handle___263 * (*graph_get_next_endpoint)(const struct fwnode_handle___263 *, struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*graph_get_remote_endpoint)(const struct fwnode_handle___263 *);
	struct fwnode_handle___263 * (*graph_get_port_parent)(struct fwnode_handle___263 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___263 *, struct fwnode_endpoint___263 *);
	int (*add_links)(struct fwnode_handle___263 *);
};

struct fwnode_endpoint___263 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___263 *local_fwnode;
};

struct fwnode_reference_args___263 {
	struct fwnode_handle___263 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___55;

struct fib_rules_ops___82;

struct fqdir___100;

struct tcp_congestion_ops___28;

struct fib_notifier_ops___82;

struct netns_ipv4___100 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___55 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___82 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___82 *fibnl;
	struct sock___82 **icmp_sk;
	struct sock___82 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___82 **tcp_sk;
	struct fqdir___100 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___28 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___82 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___82 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___82 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___82;

struct dst_ops___100 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___100 *);
	struct dst_entry___82 * (*check)(struct dst_entry___82 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___82 *);
	unsigned int (*mtu)(const struct dst_entry___82 *);
	u32 * (*cow_metrics)(struct dst_entry___82 *, long unsigned int);
	void (*destroy)(struct dst_entry___82 *);
	void (*ifdown)(struct dst_entry___82 *, struct net_device___95 *, int);
	struct dst_entry___82 * (*negative_advice)(struct dst_entry___82 *);
	void (*link_failure)(struct sk_buff___96 *);
	void (*update_pmtu)(struct dst_entry___82 *, struct sock___82 *, struct sk_buff___96 *, u32, bool);
	void (*redirect)(struct dst_entry___82 *, struct sock___82 *, struct sk_buff___96 *);
	int (*local_out)(struct net___100 *, struct sock___82 *, struct sk_buff___96 *);
	struct neighbour___82 * (*neigh_lookup)(const struct dst_entry___82 *, struct sk_buff___96 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___82 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___100 {
	struct dst_ops___100 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___100 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___82 *fib6_rules_ops;
	struct sock___82 **icmp_sk;
	struct sock___82 *ndisc_sk;
	struct sock___82 *tcp_sk;
	struct sock___82 *igmp_sk;
	struct sock___82 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___82 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___82 *notifier_ops;
	struct fib_notifier_ops___82 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___100 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___100 *fqdir;
};

struct netns_sctp___82 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___82 *ctl_sock;
	struct sock___82 *udp4_sock;
	struct sock___82 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___89 {
	struct bpf_prog_array___89 *run_array[2];
	struct bpf_prog___89 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___100 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___82 *nlsk;
	struct sock___82 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___100 xfrm4_dst_ops;
	struct dst_ops___100 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___100 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___82 *rtnl;
	struct sock___82 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___95 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___100 ipv4;
	struct netns_ipv6___100 ipv6;
	struct netns_ieee802154_lowpan___100 ieee802154_lowpan;
	struct netns_sctp___82 sctp;
	struct netns_nf___17 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___95 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___89 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___100 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___82 *crypto_nlsk;
	struct sock___82 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___213 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___213 *root_cset;
};

struct socket_wq___83 {
	wait_queue_head_t wait;
	struct fasync_struct___286 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___83;

struct socket___84 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___286 *file;
	struct sock___82 *sk;
	const struct proto_ops___83 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___83 wq;
};

typedef int (*sk_read_actor_t___82)(read_descriptor_t *, struct sk_buff___96 *, unsigned int, size_t);

struct proto_ops___83 {
	int family;
	struct module___270 *owner;
	int (*release)(struct socket___84 *);
	int (*bind)(struct socket___84 *, struct sockaddr *, int);
	int (*connect)(struct socket___84 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___84 *, struct socket___84 *);
	int (*accept)(struct socket___84 *, struct socket___84 *, int, bool);
	int (*getname)(struct socket___84 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___286 *, struct socket___84 *, struct poll_table_struct___207 *);
	int (*ioctl)(struct socket___84 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___84 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___84 *, void *, bool, bool);
	int (*listen)(struct socket___84 *, int);
	int (*shutdown)(struct socket___84 *, int);
	int (*setsockopt)(struct socket___84 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___84 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___261 *, struct socket___84 *);
	int (*sendmsg)(struct socket___84 *, struct msghdr___84 *, size_t);
	int (*recvmsg)(struct socket___84 *, struct msghdr___84 *, size_t, int);
	int (*mmap)(struct file___286 *, struct socket___84 *, struct vm_area_struct___291 *);
	ssize_t (*sendpage)(struct socket___84 *, struct page___291 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___84 *, loff_t *, struct pipe_inode_info___127 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___82 *, int);
	int (*peek_len)(struct socket___84 *);
	int (*read_sock)(struct sock___82 *, read_descriptor_t *, sk_read_actor_t___82);
	int (*sendpage_locked)(struct sock___82 *, struct page___291 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___82 *, struct msghdr___84 *, size_t);
	int (*set_rcvlowat)(struct sock___82 *, int);
};

struct dev_pm_ops___267 {
	int (*prepare)(struct device___267 *);
	void (*complete)(struct device___267 *);
	int (*suspend)(struct device___267 *);
	int (*resume)(struct device___267 *);
	int (*freeze)(struct device___267 *);
	int (*thaw)(struct device___267 *);
	int (*poweroff)(struct device___267 *);
	int (*restore)(struct device___267 *);
	int (*suspend_late)(struct device___267 *);
	int (*resume_early)(struct device___267 *);
	int (*freeze_late)(struct device___267 *);
	int (*thaw_early)(struct device___267 *);
	int (*poweroff_late)(struct device___267 *);
	int (*restore_early)(struct device___267 *);
	int (*suspend_noirq)(struct device___267 *);
	int (*resume_noirq)(struct device___267 *);
	int (*freeze_noirq)(struct device___267 *);
	int (*thaw_noirq)(struct device___267 *);
	int (*poweroff_noirq)(struct device___267 *);
	int (*restore_noirq)(struct device___267 *);
	int (*runtime_suspend)(struct device___267 *);
	int (*runtime_resume)(struct device___267 *);
	int (*runtime_idle)(struct device___267 *);
};

struct wakeup_source___267 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___267 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___267 {
	struct dev_pm_ops___267 ops;
	int (*start)(struct device___267 *);
	void (*detach)(struct device___267 *, bool);
	int (*activate)(struct device___267 *);
	void (*sync)(struct device___267 *);
	void (*dismiss)(struct device___267 *);
};

struct bus_type___267 {
	const char *name;
	const char *dev_name;
	struct device___267 *dev_root;
	const struct attribute_group___274 **bus_groups;
	const struct attribute_group___274 **dev_groups;
	const struct attribute_group___274 **drv_groups;
	int (*match)(struct device___267 *, struct device_driver___267 *);
	int (*uevent)(struct device___267 *, struct kobj_uevent_env *);
	int (*probe)(struct device___267 *);
	void (*sync_state)(struct device___267 *);
	void (*remove)(struct device___267 *);
	void (*shutdown)(struct device___267 *);
	int (*online)(struct device___267 *);
	int (*offline)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	int (*num_vf)(struct device___267 *);
	int (*dma_configure)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___267 {
	const char *name;
	struct bus_type___267 *bus;
	struct module___270 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___267 *);
	void (*sync_state)(struct device___267 *);
	int (*remove)(struct device___267 *);
	void (*shutdown)(struct device___267 *);
	int (*suspend)(struct device___267 *, pm_message_t);
	int (*resume)(struct device___267 *);
	const struct attribute_group___274 **groups;
	const struct attribute_group___274 **dev_groups;
	const struct dev_pm_ops___267 *pm;
	void (*coredump)(struct device___267 *);
	struct driver_private *p;
};

struct device_type___267 {
	const char *name;
	const struct attribute_group___274 **groups;
	int (*uevent)(struct device___267 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___267 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___267 *);
	const struct dev_pm_ops___267 *pm;
};

struct class___267 {
	const char *name;
	struct module___270 *owner;
	const struct attribute_group___274 **class_groups;
	const struct attribute_group___274 **dev_groups;
	struct kobject___274 *dev_kobj;
	int (*dev_uevent)(struct device___267 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___267 *, umode_t *);
	void (*class_release)(struct class___267 *);
	void (*dev_release)(struct device___267 *);
	int (*shutdown_pre)(struct device___267 *);
	const struct kobj_ns_type_operations___82 *ns_type;
	const void * (*namespace)(struct device___267 *);
	void (*get_ownership)(struct device___267 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___267 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___127;

struct pipe_buffer___127 {
	struct page___291 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___127 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___127 {
	int (*confirm)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
	void (*release)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
	bool (*try_steal)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
	bool (*get)(struct pipe_inode_info___127 *, struct pipe_buffer___127 *);
};

struct ubuf_info___12 {
	void (*callback)(struct sk_buff___96 *, struct ubuf_info___12 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct inet_frags___100;

struct fqdir___100 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___100 *f;
	struct net___100 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___100;

struct inet_frags___100 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___100 *, const void *);
	void (*destructor)(struct inet_frag_queue___100 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___100 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___96 *fragments_tail;
	struct sk_buff___96 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___100 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___55 {
	struct ip_ra_chain___55 *next;
	struct sock___82 *sk;
	union {
		void (*destructor)(struct sock___82 *);
		struct sock___82 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___82;

struct fib_lookup_arg___82;

struct fib_rules_ops___82 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___82 *, struct flowi *, int, struct fib_lookup_arg___82 *);
	bool (*suppress)(struct fib_rule___82 *, int, struct fib_lookup_arg___82 *);
	int (*match)(struct fib_rule___82 *, struct flowi *, int);
	int (*configure)(struct fib_rule___82 *, struct sk_buff___96 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___82 *);
	int (*compare)(struct fib_rule___82 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___82 *, struct sk_buff___96 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___82 *);
	void (*flush_cache)(struct fib_rules_ops___82 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___270 *owner;
	struct net___100 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___28 {
	u32 (*ssthresh)(struct sock___82 *);
	void (*cong_avoid)(struct sock___82 *, u32, u32);
	void (*set_state)(struct sock___82 *, u8);
	void (*cwnd_event)(struct sock___82 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___82 *, u32);
	void (*pkts_acked)(struct sock___82 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___82 *);
	void (*cong_control)(struct sock___82 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___82 *);
	u32 (*sndbuf_expand)(struct sock___82 *);
	size_t (*get_info)(struct sock___82 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___270 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___82 *);
	void (*release)(struct sock___82 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___82 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___100 *);
	int (*fib_dump)(struct net___100 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___270 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___58;

struct dst_entry___82 {
	struct net_device___95 *dev;
	struct dst_ops___100 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___96 *);
	int (*output)(struct net___100 *, struct sock___82 *, struct sk_buff___96 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___58 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___82;

struct neigh_parms___82;

struct neigh_ops___82;

struct neighbour___82 {
	struct neighbour___82 *next;
	struct neigh_table___82 *tbl;
	struct neigh_parms___82 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___95 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___82 *, struct sk_buff___96 *);
	const struct neigh_ops___82 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___95 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___95 {
	int (*ieee_getets)(struct net_device___95 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___95 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___95 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___95 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___95 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___95 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___95 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___95 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___95 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___95 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___95 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___95 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___95 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___95 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___95 *);
	u8 (*setstate)(struct net_device___95 *, u8);
	void (*getpermhwaddr)(struct net_device___95 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___95 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___95 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___95 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___95 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___95 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___95 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___95 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___95 *, int, u8 *);
	void (*setpfccfg)(struct net_device___95 *, int, u8);
	void (*getpfccfg)(struct net_device___95 *, int, u8 *);
	u8 (*setall)(struct net_device___95 *);
	u8 (*getcap)(struct net_device___95 *, int, u8 *);
	int (*getnumtcs)(struct net_device___95 *, int, u8 *);
	int (*setnumtcs)(struct net_device___95 *, int, u8);
	u8 (*getpfcstate)(struct net_device___95 *);
	void (*setpfcstate)(struct net_device___95 *, u8);
	void (*getbcncfg)(struct net_device___95 *, int, u32 *);
	void (*setbcncfg)(struct net_device___95 *, int, u32);
	void (*getbcnrp)(struct net_device___95 *, int, u8 *);
	void (*setbcnrp)(struct net_device___95 *, int, u8);
	int (*setapp)(struct net_device___95 *, u8, u16, u8);
	int (*getapp)(struct net_device___95 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___95 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___95 *, int, u8);
	u8 (*getdcbx)(struct net_device___95 *);
	u8 (*setdcbx)(struct net_device___95 *, u8);
	int (*peer_getappinfo)(struct net_device___95 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___95 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___95 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___95 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___95 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___95 *, struct dcbnl_buffer *);
};

struct cftype___213;

struct cgroup_subsys___213 {
	struct cgroup_subsys_state___213 * (*css_alloc)(struct cgroup_subsys_state___213 *);
	int (*css_online)(struct cgroup_subsys_state___213 *);
	void (*css_offline)(struct cgroup_subsys_state___213 *);
	void (*css_released)(struct cgroup_subsys_state___213 *);
	void (*css_free)(struct cgroup_subsys_state___213 *);
	void (*css_reset)(struct cgroup_subsys_state___213 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___213 *, int);
	int (*css_extra_stat_show)(struct seq_file___261 *, struct cgroup_subsys_state___213 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___293 *, struct css_set___213 *);
	void (*cancel_fork)(struct task_struct___293 *, struct css_set___213 *);
	void (*fork)(struct task_struct___293 *);
	void (*exit)(struct task_struct___293 *);
	void (*release)(struct task_struct___293 *);
	void (*bind)(struct cgroup_subsys_state___213 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___213 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___213 *dfl_cftypes;
	struct cftype___213 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___213 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___213 *updated_children;
	struct cgroup___213 *updated_next;
};

struct cgroup_root___213 {
	struct kernfs_root___274 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___213 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___213 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___213 *ss;
	struct list_head node;
	struct kernfs_ops___274 *kf_ops;
	int (*open)(struct kernfs_open_file___274 *);
	void (*release)(struct kernfs_open_file___274 *);
	u64 (*read_u64)(struct cgroup_subsys_state___213 *, struct cftype___213 *);
	s64 (*read_s64)(struct cgroup_subsys_state___213 *, struct cftype___213 *);
	int (*seq_show)(struct seq_file___261 *, void *);
	void * (*seq_start)(struct seq_file___261 *, loff_t *);
	void * (*seq_next)(struct seq_file___261 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___261 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___213 *, struct cftype___213 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___213 *, struct cftype___213 *, s64);
	ssize_t (*write)(struct kernfs_open_file___274 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___274 *, struct poll_table_struct___207 *);
};

struct xdp_rxq_info___95 {
	struct net_device___95 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___95 {
	struct net_device___95 *dev;
};

struct xdp_buff___95 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___95 *rxq;
	struct xdp_txq_info___95 *txq;
	u32 frame_sz;
};

struct xdp_frame___95 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___95 *dev_rx;
};

struct netlink_callback___95 {
	struct sk_buff___96 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___96 *, struct netlink_callback___95 *);
	int (*done)(struct netlink_callback___95 *);
	void *data;
	struct module___270 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___95 {
	int (*create)(struct sk_buff___96 *, struct net_device___95 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___96 *, unsigned char *);
	int (*cache)(const struct neighbour___82 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___95 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___96 *);
};

struct netdev_queue___95 {
	struct net_device___95 *dev;
	struct Qdisc___89 *qdisc;
	struct Qdisc___89 *qdisc_sleeping;
	struct kobject___274 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___95 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___89 {
	struct sk_buff___96 *head;
	struct sk_buff___96 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___89;

struct Qdisc___89 {
	int (*enqueue)(struct sk_buff___96 *, struct Qdisc___89 *, struct sk_buff___96 **);
	struct sk_buff___96 * (*dequeue)(struct Qdisc___89 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___89 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___95 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___95 gso_skb;
	struct qdisc_skb_head___89 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___89 *next_sched;
	struct sk_buff_head___95 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___95 {
	struct xdp_rxq_info___95 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___274 kobj;
	struct net_device___95 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___95 {
	enum net_device_path_type type;
	const struct net_device___95 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___95 = 0,
				DEV_PATH_BR_VLAN_TAG___95 = 1,
				DEV_PATH_BR_VLAN_UNTAG___95 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___95 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___95 {
	const struct net_device___95 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___95 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___89 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___95 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___95 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___96 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___95 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___95 *dev;
	const char *name;
};

struct net_device_ops___95 {
	int (*ndo_init)(struct net_device___95 *);
	void (*ndo_uninit)(struct net_device___95 *);
	int (*ndo_open)(struct net_device___95 *);
	int (*ndo_stop)(struct net_device___95 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___96 *, struct net_device___95 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___96 *, struct net_device___95 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___95 *, struct sk_buff___96 *, struct net_device___95 *);
	void (*ndo_change_rx_flags)(struct net_device___95 *, int);
	void (*ndo_set_rx_mode)(struct net_device___95 *);
	int (*ndo_set_mac_address)(struct net_device___95 *, void *);
	int (*ndo_validate_addr)(struct net_device___95 *);
	int (*ndo_do_ioctl)(struct net_device___95 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___95 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___95 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___95 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___95 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___95 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___95 *, int);
	int (*ndo_neigh_setup)(struct net_device___95 *, struct neigh_parms___82 *);
	void (*ndo_tx_timeout)(struct net_device___95 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___95 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___95 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___95 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___95 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___95 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___95 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___95 *);
	int (*ndo_netpoll_setup)(struct net_device___95 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___95 *);
	int (*ndo_set_vf_mac)(struct net_device___95 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___95 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___95 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___95 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___95 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___95 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___95 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___95 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___95 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___95 *, int, struct sk_buff___96 *);
	int (*ndo_get_vf_guid)(struct net_device___95 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___95 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___95 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___95 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___95 *);
	int (*ndo_fcoe_disable)(struct net_device___95 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___95 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___95 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___95 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___95 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___95 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___95 *, const struct sk_buff___96 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___95 *, struct net_device___95 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___95 *, struct net_device___95 *);
	struct net_device___95 * (*ndo_get_xmit_slave)(struct net_device___95 *, struct sk_buff___96 *, bool);
	struct net_device___95 * (*ndo_sk_get_lower_dev)(struct net_device___95 *, struct sock___82 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___95 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___95 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___95 *, struct neighbour___82 *);
	void (*ndo_neigh_destroy)(struct net_device___95 *, struct neighbour___82 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___95 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___95 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___96 *, struct netlink_callback___95 *, struct net_device___95 *, struct net_device___95 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___96 *, struct nlattr **, struct net_device___95 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___95 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___96 *, u32, u32, struct net_device___95 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___95 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___95 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___95 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___95 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___95 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___95 *, struct net_device___95 *);
	void (*ndo_dfwd_del_station)(struct net_device___95 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___95 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___95 *);
	int (*ndo_change_proto_down)(struct net_device___95 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___95 *, struct sk_buff___96 *);
	void (*ndo_set_rx_headroom)(struct net_device___95 *, int);
	int (*ndo_bpf)(struct net_device___95 *, struct netdev_bpf___95 *);
	int (*ndo_xdp_xmit)(struct net_device___95 *, int, struct xdp_frame___95 **, u32);
	struct net_device___95 * (*ndo_xdp_get_xmit_slave)(struct net_device___95 *, struct xdp_buff___95 *);
	int (*ndo_xsk_wakeup)(struct net_device___95 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___95 *);
	int (*ndo_tunnel_ctl)(struct net_device___95 *, struct ip_tunnel_parm *, int);
	struct net_device___95 * (*ndo_get_peer_dev)(struct net_device___95 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___95 *, struct net_device_path___95 *);
};

struct neigh_parms___82 {
	possible_net_t___95 net;
	struct net_device___95 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___82 *);
	struct neigh_table___82 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___82 {
	u32 (*l3mdev_fib_table)(const struct net_device___95 *);
	struct sk_buff___96 * (*l3mdev_l3_rcv)(struct net_device___95 *, struct sk_buff___96 *, u16);
	struct sk_buff___96 * (*l3mdev_l3_out)(struct net_device___95 *, struct sock___82 *, struct sk_buff___96 *, u16);
	struct dst_entry___82 * (*l3mdev_link_scope_lookup)(const struct net_device___95 *, struct flowi6 *);
};

struct ndisc_ops___64 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___95 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___95 *, struct neighbour___82 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___95 *, u8, struct neighbour___82 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___95 *, struct sk_buff___96 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___100 *, struct net_device___95 *, const struct prefix_info *, struct inet6_dev___64 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___64;

struct inet6_dev___64 {
	struct net_device___95 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___64 *mc_list;
	struct ifmcaddr6___64 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___95 mc_query_queue;
	struct sk_buff_head___95 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___25 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___82 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___89;

struct tcf_block___89;

struct mini_Qdisc___89 {
	struct tcf_proto___89 *filter_list;
	struct tcf_block___89 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___89 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___95 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___95 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___100 *, struct net_device___95 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___95 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___95 *, struct list_head *);
	size_t (*get_size)(const struct net_device___95 *);
	int (*fill_info)(struct sk_buff___96 *, const struct net_device___95 *);
	size_t (*get_xstats_size)(const struct net_device___95 *);
	int (*fill_xstats)(struct sk_buff___96 *, const struct net_device___95 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___95 *, struct net_device___95 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___95 *, const struct net_device___95 *);
	int (*fill_slave_info)(struct sk_buff___96 *, const struct net_device___95 *, const struct net_device___95 *);
	struct net___100 * (*get_link_net)(const struct net_device___95 *);
	size_t (*get_linkxstats_size)(const struct net_device___95 *, int);
	int (*fill_linkxstats)(struct sk_buff___96 *, const struct net_device___95 *, int *, int);
};

struct gnet_dump___89 {
	spinlock_t *lock;
	struct sk_buff___96 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___89;

struct Qdisc_ops___89 {
	struct Qdisc_ops___89 *next;
	const struct Qdisc_class_ops___89 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___96 *, struct Qdisc___89 *, struct sk_buff___96 **);
	struct sk_buff___96 * (*dequeue)(struct Qdisc___89 *);
	struct sk_buff___96 * (*peek)(struct Qdisc___89 *);
	int (*init)(struct Qdisc___89 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___89 *);
	void (*destroy)(struct Qdisc___89 *);
	int (*change)(struct Qdisc___89 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___89 *);
	int (*change_tx_queue_len)(struct Qdisc___89 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___89 *, unsigned int);
	int (*dump)(struct Qdisc___89 *, struct sk_buff___96 *);
	int (*dump_stats)(struct Qdisc___89 *, struct gnet_dump___89 *);
	void (*ingress_block_set)(struct Qdisc___89 *, u32);
	void (*egress_block_set)(struct Qdisc___89 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___89 *);
	u32 (*egress_block_get)(struct Qdisc___89 *);
	struct module___270 *owner;
};

struct Qdisc_class_ops___89 {
	unsigned int flags;
	struct netdev_queue___95 * (*select_queue)(struct Qdisc___89 *, struct tcmsg *);
	int (*graft)(struct Qdisc___89 *, long unsigned int, struct Qdisc___89 *, struct Qdisc___89 **, struct netlink_ext_ack *);
	struct Qdisc___89 * (*leaf)(struct Qdisc___89 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___89 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___89 *, u32);
	int (*change)(struct Qdisc___89 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___89 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___89 *, struct qdisc_walker *);
	struct tcf_block___89 * (*tcf_block)(struct Qdisc___89 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___89 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___89 *, long unsigned int);
	int (*dump)(struct Qdisc___89 *, long unsigned int, struct sk_buff___96 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___89 *, long unsigned int, struct gnet_dump___89 *);
};

struct tcf_chain___89;

struct tcf_block___89 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___100 *net;
	struct Qdisc___89 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___89 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___89;

struct tcf_proto_ops___89;

struct tcf_proto___89 {
	struct tcf_proto___89 *next;
	void *root;
	int (*classify)(struct sk_buff___96 *, const struct tcf_proto___89 *, struct tcf_result___89 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___89 *ops;
	struct tcf_chain___89 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___89 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___89 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___89 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___96 *, const struct tcf_proto___89 *, struct tcf_result___89 *);
	int (*init)(struct tcf_proto___89 *);
	void (*destroy)(struct tcf_proto___89 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___89 *, u32);
	void (*put)(struct tcf_proto___89 *, void *);
	int (*change)(struct net___100 *, struct sk_buff___96 *, struct tcf_proto___89 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___89 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___89 *);
	void (*walk)(struct tcf_proto___89 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___89 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___89 *, void *);
	void (*hw_del)(struct tcf_proto___89 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___100 *, struct tcf_chain___89 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___100 *, struct tcf_proto___89 *, void *, struct sk_buff___96 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___100 *, struct tcf_proto___89 *, void *, struct sk_buff___96 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___96 *, struct net___100 *, void *);
	struct module___270 *owner;
	int flags;
};

struct tcf_chain___89 {
	struct mutex filter_chain_lock;
	struct tcf_proto___89 *filter_chain;
	struct list_head list;
	struct tcf_block___89 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___89 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___82 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___89 *prog;
};

struct bpf_stack_state___6 {
	struct bpf_reg_state___6 spilled_ptr;
	u8 slot_type[8];
};

struct bpf_verifier_state___6 {
	struct bpf_func_state___6 *frame[8];
	struct bpf_verifier_state___6 *parent;
	u32 branches;
	u32 insn_idx;
	u32 curframe;
	u32 active_spin_lock;
	bool speculative;
	u32 first_insn_idx;
	u32 last_insn_idx;
	struct bpf_idx_pair *jmp_history;
	u32 jmp_history_cnt;
};

struct bpf_verifier_state_list___6 {
	struct bpf_verifier_state___6 state;
	struct bpf_verifier_state_list___6 *next;
	int miss_cnt;
	int hit_cnt;
};

struct block_device_operations___177;

struct gendisk___180 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___180 *part0;
	const struct block_device_operations___177 *fops;
	struct request_queue___177 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___163 *bdi;
	struct kobject___274 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___274 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___177 {
	struct bio___177 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___203 *bip_vec;
	struct bio_vec___203 bip_inline_vecs[0];
};

struct blkcg___165;

struct blkg_policy_data___165;

struct blkcg_gq___165 {
	struct request_queue___177 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___165 *blkcg;
	struct blkcg_gq___165 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___165 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___177 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___177(struct request___177 *);

typedef void integrity_complete_fn___177(struct request___177 *, unsigned int);

struct blk_integrity_profile___177 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___177 *prepare_fn;
	integrity_complete_fn___177 *complete_fn;
	const char *name;
};

struct block_device_operations___177 {
	blk_qc_t (*submit_bio)(struct bio___177 *);
	int (*open)(struct block_device___180 *, fmode_t);
	void (*release)(struct gendisk___180 *, fmode_t);
	int (*rw_page)(struct block_device___180 *, sector_t, struct page___291 *, unsigned int);
	int (*ioctl)(struct block_device___180 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___180 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___180 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___180 *);
	int (*getgeo)(struct block_device___180 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___180 *, bool);
	void (*swap_slot_free_notify)(struct block_device___180 *, long unsigned int);
	int (*report_zones)(struct gendisk___180 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___180 *, umode_t *);
	struct module___270 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___180 *, sector_t *);
};

typedef void rq_end_io_fn___177(struct request___177 *, blk_status_t);

struct request___177 {
	struct request_queue___177 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___172 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___177 *bio;
	struct bio___177 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___203 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___177 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___177 *saved_end_io;
		} flush;
	};
	struct gendisk___180 *rq_disk;
	struct block_device___180 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___177 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___172 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___177 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___274 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___286 *debugfs_dir;
	struct dentry___286 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___177;

struct elevator_mq_ops___177 {
	int (*init_sched)(struct request_queue___177 *, struct elevator_type___177 *);
	void (*exit_sched)(struct elevator_queue___177 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___172 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___172 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___172 *);
	bool (*allow_merge)(struct request_queue___177 *, struct request___177 *, struct bio___177 *);
	bool (*bio_merge)(struct request_queue___177 *, struct bio___177 *, unsigned int);
	int (*request_merge)(struct request_queue___177 *, struct request___177 **, struct bio___177 *);
	void (*request_merged)(struct request_queue___177 *, struct request___177 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___177 *, struct request___177 *, struct request___177 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___177 *);
	void (*finish_request)(struct request___177 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___172 *, struct list_head *, bool);
	struct request___177 * (*dispatch_request)(struct blk_mq_hw_ctx___172 *);
	bool (*has_work)(struct blk_mq_hw_ctx___172 *);
	void (*completed_request)(struct request___177 *, u64);
	void (*requeue_request)(struct request___177 *);
	struct request___177 * (*former_request)(struct request_queue___177 *, struct request___177 *);
	struct request___177 * (*next_request)(struct request_queue___177 *, struct request___177 *);
	void (*init_icq)(struct io_cq___177 *);
	void (*exit_icq)(struct io_cq___177 *);
};

struct elv_fs_entry___177;

struct elevator_type___177 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___177 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___177 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___270 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___177 {
	struct elevator_type___177 *type;
	void *elevator_data;
	struct kobject___274 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___177 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___177 *, char *);
	ssize_t (*store)(struct elevator_queue___177 *, const char *, size_t);
};

struct blk_mq_queue_data___172;

struct blk_mq_ops___172 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___172 *, const struct blk_mq_queue_data___172 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___172 *);
	int (*get_budget)(struct request_queue___177 *);
	void (*put_budget)(struct request_queue___177 *, int);
	void (*set_rq_budget_token)(struct request___177 *, int);
	int (*get_rq_budget_token)(struct request___177 *);
	enum blk_eh_timer_return (*timeout)(struct request___177 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___172 *);
	void (*complete)(struct request___177 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___172 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___172 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___172 *, struct request___177 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___172 *, struct request___177 *, unsigned int);
	void (*initialize_rq_fn)(struct request___177 *);
	void (*cleanup_rq)(struct request___177 *);
	bool (*busy)(struct request_queue___177 *);
	int (*map_queues)(struct blk_mq_tag_set___172 *);
	void (*show_rq)(struct seq_file___261 *, struct request___177 *);
};

struct blk_mq_tag_set___172 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___172 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___172 {
	struct request___177 *rq;
	bool last;
};

struct blkcg_policy_data___165;

struct blkcg___165 {
	struct cgroup_subsys_state___213 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___165 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___165 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___165 {
	struct blkcg___165 *blkcg;
	int plid;
};

struct blkg_policy_data___165 {
	struct blkcg_gq___165 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___151 {
	struct mem_cgroup___151 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___151 {
	struct lruvec___159 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___151 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___151 *memcg;
};

struct obj_cgroup___151 {
	struct percpu_ref refcnt;
	struct mem_cgroup___151 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___82;

struct neigh_hash_table___82;

struct neigh_table___82 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___95 *, __u32 *);
	bool (*key_eq)(const struct neighbour___82 *, const void *);
	int (*constructor)(struct neighbour___82 *);
	int (*pconstructor)(struct pneigh_entry___82 *);
	void (*pdestructor)(struct pneigh_entry___82 *);
	void (*proxy_redo)(struct sk_buff___96 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___95 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___82 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___95 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___82 *nht;
	struct pneigh_entry___82 **phash_buckets;
};

struct neigh_ops___82 {
	int family;
	void (*solicit)(struct neighbour___82 *, struct sk_buff___96 *);
	void (*error_report)(struct neighbour___82 *, struct sk_buff___96 *);
	int (*output)(struct neighbour___82 *, struct sk_buff___96 *);
	int (*connected_output)(struct neighbour___82 *, struct sk_buff___96 *);
};

struct pneigh_entry___82 {
	struct pneigh_entry___82 *next;
	possible_net_t___95 net;
	struct net_device___95 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___82 {
	struct neighbour___82 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___58 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___100 *, struct sock___82 *, struct sk_buff___96 *);
	int (*orig_input)(struct sk_buff___96 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___82 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___82 *ctarget;
	struct net___100 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___82 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___82 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___67;

struct timewait_sock_ops___66;

struct proto___82 {
	void (*close)(struct sock___82 *, long int);
	int (*pre_connect)(struct sock___82 *, struct sockaddr *, int);
	int (*connect)(struct sock___82 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___82 *, int);
	struct sock___82 * (*accept)(struct sock___82 *, int, int *, bool);
	int (*ioctl)(struct sock___82 *, int, long unsigned int);
	int (*init)(struct sock___82 *);
	void (*destroy)(struct sock___82 *);
	void (*shutdown)(struct sock___82 *, int);
	int (*setsockopt)(struct sock___82 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___82 *, int, int, char *, int *);
	void (*keepalive)(struct sock___82 *, int);
	int (*compat_ioctl)(struct sock___82 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___82 *, struct msghdr___84 *, size_t);
	int (*recvmsg)(struct sock___82 *, struct msghdr___84 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___82 *, struct page___291 *, int, size_t, int);
	int (*bind)(struct sock___82 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___82 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___82 *, struct sk_buff___96 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___82 *);
	int (*hash)(struct sock___82 *);
	void (*unhash)(struct sock___82 *);
	void (*rehash)(struct sock___82 *);
	int (*get_port)(struct sock___82 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___82 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___82 *, int);
	bool (*sock_is_readable)(struct sock___82 *);
	void (*enter_memory_pressure)(struct sock___82 *);
	void (*leave_memory_pressure)(struct sock___82 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___67 *rsk_prot;
	struct timewait_sock_ops___66 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___270 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___82 *, int);
};

struct sock_reuseport___30 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___89 *prog;
	struct sock___82 *socks[0];
};

struct request_sock___68;

struct request_sock_ops___67 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___82 *, struct request_sock___68 *);
	void (*send_ack)(const struct sock___82 *, struct sk_buff___96 *, struct request_sock___68 *);
	void (*send_reset)(const struct sock___82 *, struct sk_buff___96 *);
	void (*destructor)(struct request_sock___68 *);
	void (*syn_ack_timeout)(const struct request_sock___68 *);
};

struct timewait_sock_ops___66 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___82 *, struct sock___82 *, void *);
	void (*twsk_destructor)(struct sock___82 *);
};

struct request_sock___68 {
	struct sock_common___82 __req_common;
	struct request_sock___68 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___67 *rsk_ops;
	struct sock___82 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___11 {
	struct request_sock___68 *rskq_rst_head;
	struct request_sock___68 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___11 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___68 *rskq_accept_head;
	struct request_sock___68 *rskq_accept_tail;
	struct fastopen_queue___11 fastopenq;
};

struct inet_cork___21 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___82 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___21 {
	struct inet_cork___21 base;
	struct flowi fl;
};

struct ipv6_pinfo___20;

struct inet_sock___21 {
	struct sock___82 sk;
	struct ipv6_pinfo___20 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___21 cork;
};

struct ipv6_fl_socklist___20;

struct ipv6_pinfo___20 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___20 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___96 *pktoptions;
	struct sk_buff___96 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___11 {
	int (*queue_xmit)(struct sock___82 *, struct sk_buff___96 *, struct flowi *);
	void (*send_check)(struct sock___82 *, struct sk_buff___96 *);
	int (*rebuild_header)(struct sock___82 *);
	void (*sk_rx_dst_set)(struct sock___82 *, const struct sk_buff___96 *);
	int (*conn_request)(struct sock___82 *, struct sk_buff___96 *);
	struct sock___82 * (*syn_recv_sock)(const struct sock___82 *, struct sk_buff___96 *, struct request_sock___68 *, struct dst_entry___82 *, struct request_sock___68 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___82 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___82 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___82 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___82 *);
};

struct inet_bind_bucket___11;

struct tcp_ulp_ops___11;

struct inet_connection_sock___11 {
	struct inet_sock___21 icsk_inet;
	struct request_sock_queue___11 icsk_accept_queue;
	struct inet_bind_bucket___11 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___28 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___11 *icsk_af_ops;
	const struct tcp_ulp_ops___11 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___82 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___82 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___11 {
	possible_net_t___95 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___11 {
	struct list_head list;
	int (*init)(struct sock___82 *);
	void (*update)(struct sock___82 *, struct proto___82 *, void (*)(struct sock___82 *));
	void (*release)(struct sock___82 *);
	int (*get_info)(const struct sock___82 *, struct sk_buff___96 *);
	size_t (*get_info_size)(const struct sock___82 *);
	void (*clone)(const struct request_sock___68 *, struct sock___82 *, const gfp_t);
	char name[16];
	struct module___270 *owner;
};

struct tcp_sock_af_ops___10;

struct tcp_fastopen_request___10;

struct tcp_sock___10 {
	struct inet_connection_sock___11 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___96 *lost_skb_hint;
	struct sk_buff___96 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___96 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___96 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___10 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___10 *fastopen_req;
	struct request_sock___68 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___10 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___82 *, const struct sock___82 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___82 *, const struct sk_buff___96 *);
	int (*md5_parse)(struct sock___82 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___10 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___84 *data;
	size_t size;
	int copied;
	struct ubuf_info___12 *uarg;
};

struct ip6_flowlabel___20;

struct ipv6_fl_socklist___20 {
	struct ipv6_fl_socklist___20 *next;
	struct ip6_flowlabel___20 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___64 {
	struct in6_addr mca_addr;
	struct inet6_dev___64 *idev;
	struct ifmcaddr6___64 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___20 {
	struct ip6_flowlabel___20 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___263 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___100 *fl_net;
};

struct bpf_local_storage_data___10 {
	struct bpf_local_storage_map___10 *smap;
	u8 data[0];
};

typedef u64 (*btf_bpf_tcp_send_ack)(struct tcp_sock___10 *, u32);

struct dentry___287;

struct super_block___287;

struct module___271;

struct file_system_type___287 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___287 * (*mount)(struct file_system_type___287 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___287 *);
	struct module___271 *owner;
	struct file_system_type___287 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___287;

struct kiocb___287;

struct iov_iter___207;

struct poll_table_struct___208;

struct vm_area_struct___292;

struct inode___287;

struct file_lock___287;

struct page___292;

struct pipe_inode_info___128;

struct seq_file___262;

struct file_operations___288 {
	struct module___271 *owner;
	loff_t (*llseek)(struct file___287 *, loff_t, int);
	ssize_t (*read)(struct file___287 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___287 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___287 *, struct iov_iter___207 *);
	ssize_t (*write_iter)(struct kiocb___287 *, struct iov_iter___207 *);
	int (*iopoll)(struct kiocb___287 *, bool);
	int (*iterate)(struct file___287 *, struct dir_context *);
	int (*iterate_shared)(struct file___287 *, struct dir_context *);
	__poll_t (*poll)(struct file___287 *, struct poll_table_struct___208 *);
	long int (*unlocked_ioctl)(struct file___287 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___287 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___287 *, struct vm_area_struct___292 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___287 *, struct file___287 *);
	int (*flush)(struct file___287 *, fl_owner_t);
	int (*release)(struct inode___287 *, struct file___287 *);
	int (*fsync)(struct file___287 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___287 *, int);
	int (*lock)(struct file___287 *, int, struct file_lock___287 *);
	ssize_t (*sendpage)(struct file___287 *, struct page___292 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___287 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___287 *, long unsigned int);
	int (*flock)(struct file___287 *, int, struct file_lock___287 *);
	ssize_t (*splice_write)(struct pipe_inode_info___128 *, struct file___287 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___287 *, loff_t *, struct pipe_inode_info___128 *, size_t, unsigned int);
	int (*setlease)(struct file___287 *, long int, struct file_lock___287 **, void **);
	long int (*fallocate)(struct file___287 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___262 *, struct file___287 *);
	ssize_t (*copy_file_range)(struct file___287 *, loff_t, struct file___287 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___287 *, loff_t, struct file___287 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___287 *, loff_t, loff_t, int);
};

struct vmacache___292 {
	u64 seqnum;
	struct vm_area_struct___292 *vmas[4];
};

struct page_frag___292 {
	struct page___292 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___293;

struct pid___264;

struct nsproxy___273;

struct signal_struct___288;

struct bio_list___178;

struct backing_dev_info___164;

struct io_context___178;

struct css_set___214;

struct mem_cgroup___152;

struct request_queue___178;

struct vm_struct___270;

struct task_struct___294 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___294 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___293 *mm;
	struct mm_struct___293 *active_mm;
	struct vmacache___292 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___294 *real_parent;
	struct task_struct___294 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___294 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___264 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___273 *nsproxy;
	struct signal_struct___288 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___294 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___178 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___164 *backing_dev_info;
	struct io_context___178 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___214 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___128 *splice_pipe;
	struct page_frag___292 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___152 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___152 *active_memcg;
	struct request_queue___178 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___294 *oom_reaper_list;
	struct vm_struct___270 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___275;

struct kobj_type___275;

struct kernfs_node___275;

struct kobject___275 {
	const char *name;
	struct list_head entry;
	struct kobject___275 *parent;
	struct kset___275 *kset;
	struct kobj_type___275 *ktype;
	struct kernfs_node___275 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___272 {
	struct kobject___275 kobj;
	struct module___271 *mod;
	struct kobject___275 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___271 {
	struct module___271 *mod;
	struct latch_tree_node node;
};

struct module_layout___271 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___271 mtn;
};

struct module_attribute___271;

struct kernel_param___271;

struct module___271 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___272 mkobj;
	struct module_attribute___271 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___275 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___271 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___271 core_layout;
	struct module_layout___271 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___292 *pgtable_t___292;

struct address_space___287;

struct page_pool___116;

struct dev_pagemap___282;

struct page___292 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___287 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___116 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___292 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___292 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___293 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___282 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___282;

struct vm_area_struct___292 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___292 *vm_next;
	struct vm_area_struct___292 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___293 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___282 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___287 *vm_file;
	struct file___287 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___292;

struct mm_struct___293 {
	struct {
		struct vm_area_struct___292 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___287 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___292 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___294 *owner;
		struct user_namespace___26 *user_ns;
		struct file___287 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___287;

struct address_space___287 {
	struct inode___287 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___287 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___268;

struct page_pool_params___116 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___268 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___116 {
	u32 count;
	struct page___292 *cache[128];
};

struct page_pool___116 {
	struct page_pool_params___116 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___292 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___116 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___282;

struct dev_pagemap___282 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___282 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___287;

struct path___287 {
	struct vfsmount___287 *mnt;
	struct dentry___287 *dentry;
};

struct fown_struct___264 {
	rwlock_t lock;
	struct pid___264 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___287 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___287 f_path;
	struct inode___287 *f_inode;
	const struct file_operations___288 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___264 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___287 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___282;

struct vm_operations_struct___282 {
	void (*open)(struct vm_area_struct___292 *);
	void (*close)(struct vm_area_struct___292 *);
	int (*may_split)(struct vm_area_struct___292 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___292 *);
	int (*mprotect)(struct vm_area_struct___292 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___282 *);
	vm_fault_t (*huge_fault)(struct vm_fault___282 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___282 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___292 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___282 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___282 *);
	int (*access)(struct vm_area_struct___292 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___292 *);
	int (*set_policy)(struct vm_area_struct___292 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___292 *, long unsigned int);
	struct page___292 * (*find_special_page)(struct vm_area_struct___292 *, long unsigned int);
};

struct core_thread___292 {
	struct task_struct___294 *task;
	struct core_thread___292 *next;
};

struct core_state___292 {
	atomic_t nr_threads;
	struct core_thread___292 dumper;
	struct completion startup;
};

struct vm_fault___282 {
	const struct {
		struct vm_area_struct___292 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___292 *cow_page;
	struct page___292 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___292 prealloc_pte;
};

struct pglist_data___160;

struct lruvec___160 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___160 *pgdat;
};

struct zone___160 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___160 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___160 {
	struct zone___160 *zone;
	int zone_idx;
};

struct zonelist___160 {
	struct zoneref___160 _zonerefs[321];
};

struct pglist_data___160 {
	struct zone___160 node_zones[5];
	struct zonelist___160 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___294 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___294 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___160 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___264;

struct upid___264 {
	int nr;
	struct pid_namespace___264 *ns;
};

struct pid_namespace___264 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___294 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___264 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___264 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___264 numbers[1];
};

struct signal_struct___288 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___294 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___294 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___264 *pids[4];
	struct pid___264 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___293 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___101;

struct cgroup_namespace___214;

struct nsproxy___273 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___264 *pid_ns_for_children;
	struct net___101 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___214 *cgroup_ns;
};

struct bio___178;

struct bio_list___178 {
	struct bio___178 *head;
	struct bio___178 *tail;
};

struct cgroup_subsys_state___214;

struct bdi_writeback___164 {
	struct backing_dev_info___164 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___214 *memcg_css;
	struct cgroup_subsys_state___214 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___164 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___164 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___268 *dev;
	char dev_name[64];
	struct device___268 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___287 *debug_dir;
};

struct io_cq___178;

struct io_context___178 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___178 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___214;

struct css_set___214 {
	struct cgroup_subsys_state___214 *subsys[14];
	refcount_t refcount;
	struct css_set___214 *dom_cset;
	struct cgroup___214 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___214 *mg_src_cgrp;
	struct cgroup___214 *mg_dst_cgrp;
	struct css_set___214 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___287;

struct pipe_buffer___128;

struct pipe_inode_info___128 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___292 *tmp_page;
	struct fasync_struct___287 *fasync_readers;
	struct fasync_struct___287 *fasync_writers;
	struct pipe_buffer___128 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___214;

struct cgroup_subsys_state___214 {
	struct cgroup___214 *cgroup;
	struct cgroup_subsys___214 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___214 *parent;
};

struct cgroup_file___214 {
	struct kernfs_node___275 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___152;

struct mem_cgroup_per_node___152;

struct mem_cgroup___152 {
	struct cgroup_subsys_state___214 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___214 events_file;
	struct cgroup_file___214 events_local_file;
	struct cgroup_file___214 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___152 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___294 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___152 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___178;

struct blk_integrity___178 {
	const struct blk_integrity_profile___178 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___178 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___178 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___178;

struct elevator_queue___178;

struct blk_mq_ops___173;

struct blk_mq_hw_ctx___173;

struct gendisk___181;

struct blkcg_gq___166;

struct blk_mq_tag_set___173;

struct request_queue___178 {
	struct request___178 *last_merge;
	struct elevator_queue___178 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___173 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___173 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___181 *disk;
	struct kobject___275 kobj;
	struct kobject___275 *mq_kobj;
	struct blk_integrity___178 integrity;
	struct device___268 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___166 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___173 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___178 bio_split;
	struct dentry___287 *debugfs_dir;
	struct dentry___287 *sched_debugfs_dir;
	struct dentry___287 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___270 {
	struct vm_struct___270 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___292 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___204 {
	struct page___292 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___207 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___204 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___128 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___85 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___207 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___287 *msg_iocb;
};

struct kiocb___287 {
	struct file___287 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___287 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct net_device___96;

struct sock___83;

struct sk_buff___97 {
	union {
		struct {
			struct sk_buff___97 *next;
			struct sk_buff___97 *prev;
			union {
				struct net_device___96 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___83 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___97 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___101;

struct fqdir___101 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___101 *f;
	struct net___101 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___101;

struct inet_frags___101 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___101 *, const void *);
	void (*destructor)(struct inet_frag_queue___101 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___56;

struct fib_rules_ops___83;

struct tcp_congestion_ops___29;

struct fib_notifier_ops___83;

struct netns_ipv4___101 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___56 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___83 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___83 *fibnl;
	struct sock___83 **icmp_sk;
	struct sock___83 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___83 **tcp_sk;
	struct fqdir___101 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___29 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___83 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___83 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___83 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___83;

struct neighbour___83;

struct dst_ops___101 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___101 *);
	struct dst_entry___83 * (*check)(struct dst_entry___83 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___83 *);
	unsigned int (*mtu)(const struct dst_entry___83 *);
	u32 * (*cow_metrics)(struct dst_entry___83 *, long unsigned int);
	void (*destroy)(struct dst_entry___83 *);
	void (*ifdown)(struct dst_entry___83 *, struct net_device___96 *, int);
	struct dst_entry___83 * (*negative_advice)(struct dst_entry___83 *);
	void (*link_failure)(struct sk_buff___97 *);
	void (*update_pmtu)(struct dst_entry___83 *, struct sock___83 *, struct sk_buff___97 *, u32, bool);
	void (*redirect)(struct dst_entry___83 *, struct sock___83 *, struct sk_buff___97 *);
	int (*local_out)(struct net___101 *, struct sock___83 *, struct sk_buff___97 *);
	struct neighbour___83 * (*neigh_lookup)(const struct dst_entry___83 *, struct sk_buff___97 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___83 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___26;

struct rt6_info___26;

struct fib6_table___26;

struct netns_ipv6___101 {
	struct dst_ops___101 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___101 *fqdir;
	struct fib6_info___26 *fib6_null_entry;
	struct rt6_info___26 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___26 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___26 *ip6_prohibit_entry;
	struct rt6_info___26 *ip6_blk_hole_entry;
	struct fib6_table___26 *fib6_local_tbl;
	struct fib_rules_ops___83 *fib6_rules_ops;
	struct sock___83 **icmp_sk;
	struct sock___83 *ndisc_sk;
	struct sock___83 *tcp_sk;
	struct sock___83 *igmp_sk;
	struct sock___83 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___83 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___83 *notifier_ops;
	struct fib_notifier_ops___83 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___101 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___101 *fqdir;
};

struct netns_sctp___83 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___83 *ctl_sock;
	struct sock___83 *udp4_sock;
	struct sock___83 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___18;

struct netns_nf___18 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___18 *hooks_ipv4[5];
	struct nf_hook_entries___18 *hooks_ipv6[5];
	struct nf_hook_entries___18 *hooks_arp[3];
	struct nf_hook_entries___18 *hooks_bridge[5];
	struct nf_hook_entries___18 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct sk_buff_head___96 {
	struct sk_buff___97 *next;
	struct sk_buff___97 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___90;

struct bpf_prog___90;

struct netns_bpf___90 {
	struct bpf_prog_array___90 *run_array[2];
	struct bpf_prog___90 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___101 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___83 *nlsk;
	struct sock___83 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___101 xfrm4_dst_ops;
	struct dst_ops___101 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___101 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___83 *rtnl;
	struct sock___83 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___96 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___101 ipv4;
	struct netns_ipv6___101 ipv6;
	struct netns_ieee802154_lowpan___101 ieee802154_lowpan;
	struct netns_sctp___83 sctp;
	struct netns_nf___18 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___96 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___90 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___101 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___83 *crypto_nlsk;
	struct sock___83 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___101 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___97 *fragments_tail;
	struct sk_buff___97 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___101 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___56 {
	struct ip_ra_chain___56 *next;
	struct sock___83 *sk;
	union {
		void (*destructor)(struct sock___83 *);
		struct sock___83 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___83;

struct fib_lookup_arg___83;

struct fib_rules_ops___83 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___83 *, struct flowi *, int, struct fib_lookup_arg___83 *);
	bool (*suppress)(struct fib_rule___83 *, int, struct fib_lookup_arg___83 *);
	int (*match)(struct fib_rule___83 *, struct flowi *, int);
	int (*configure)(struct fib_rule___83 *, struct sk_buff___97 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___83 *);
	int (*compare)(struct fib_rule___83 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___83 *, struct sk_buff___97 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___83 *);
	void (*flush_cache)(struct fib_rules_ops___83 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___271 *owner;
	struct net___101 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___101 *net;
} possible_net_t___96;

struct proto___83;

struct sock_common___83 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___83 *skc_prot;
	possible_net_t___96 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___83 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___83 {
	struct cgroup___214 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___83;

struct socket_wq___84;

struct xfrm_policy___19;

struct socket___85;

struct sock_reuseport___31;

struct sock___83 {
	struct sock_common___83 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___96 sk_error_queue;
	struct sk_buff___97 *sk_rx_skb_cache;
	struct sk_buff_head___96 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___97 *head;
		struct sk_buff___97 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___83 *sk_filter;
	union {
		struct socket_wq___84 *sk_wq;
		struct socket_wq___84 *sk_wq_raw;
	};
	struct xfrm_policy___19 *sk_policy[2];
	struct dst_entry___83 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___83 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___97 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___97 *sk_tx_skb_cache;
	struct sk_buff_head___96 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___292 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___83 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___264 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___85 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___83 sk_cgrp_data;
	struct mem_cgroup___152 *sk_memcg;
	void (*sk_state_change)(struct sock___83 *);
	void (*sk_data_ready)(struct sock___83 *);
	void (*sk_write_space)(struct sock___83 *);
	void (*sk_error_report)(struct sock___83 *);
	int (*sk_backlog_rcv)(struct sock___83 *, struct sk_buff___97 *);
	struct sk_buff___97 * (*sk_validate_xmit_skb)(struct sock___83 *, struct net_device___96 *, struct sk_buff___97 *);
	void (*sk_destruct)(struct sock___83 *);
	struct sock_reuseport___31 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct tcp_congestion_ops___29 {
	u32 (*ssthresh)(struct sock___83 *);
	void (*cong_avoid)(struct sock___83 *, u32, u32);
	void (*set_state)(struct sock___83 *, u8);
	void (*cwnd_event)(struct sock___83 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___83 *, u32);
	void (*pkts_acked)(struct sock___83 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___83 *);
	void (*cong_control)(struct sock___83 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___83 *);
	u32 (*sndbuf_expand)(struct sock___83 *);
	size_t (*get_info)(struct sock___83 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___271 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___83 *);
	void (*release)(struct sock___83 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___83 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___101 *);
	int (*fib_dump)(struct net___101 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___271 *owner;
	struct callback_head rcu;
};

struct xfrm_state___19;

struct lwtunnel_state___59;

struct dst_entry___83 {
	struct net_device___96 *dev;
	struct dst_ops___101 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___19 *xfrm;
	int (*input)(struct sk_buff___97 *);
	int (*output)(struct net___101 *, struct sock___83 *, struct sk_buff___97 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___59 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___96(struct sk_buff___97 **);

struct wakeup_source___268;

struct dev_pm_info___268 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___268 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___268 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___268;

struct bus_type___268;

struct device_driver___268;

struct dev_pm_domain___268;

struct fwnode_handle___264;

struct class___268;

struct attribute_group___275;

struct device___268 {
	struct kobject___275 kobj;
	struct device___268 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___268 *type;
	struct bus_type___268 *bus;
	struct device_driver___268 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___268 power;
	struct dev_pm_domain___268 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___264 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___268 *class;
	const struct attribute_group___275 **groups;
	void (*release)(struct device___268 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___90 {
	struct bpf_prog___90 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___96;

struct net_device_ops___96;

struct l3mdev_ops___83;

struct ndisc_ops___65;

struct xfrmdev_ops___96;

struct header_ops___96;

struct inet6_dev___65;

struct netdev_rx_queue___96;

struct mini_Qdisc___90;

struct netdev_queue___96;

struct Qdisc___90;

struct rtnl_link_ops___90;

struct dcbnl_rtnl_ops___96;

struct net_device___96 {
	char name[16];
	struct netdev_name_node___96 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___96 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___83 *l3mdev_ops;
	const struct ndisc_ops___65 *ndisc_ops;
	const struct xfrmdev_ops___96 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___96 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___275 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___65 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___96 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___90 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___96 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___90 *miniq_ingress;
	struct netdev_queue___96 *ingress_queue;
	struct nf_hook_entries___18 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___96 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___90 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___90 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___96 = 0,
		NETREG_REGISTERED___96 = 1,
		NETREG_UNREGISTERING___96 = 2,
		NETREG_UNREGISTERED___96 = 3,
		NETREG_RELEASED___96 = 4,
		NETREG_DUMMY___96 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___96 = 0,
		RTNL_LINK_INITIALIZING___96 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___96 *);
	struct netpoll_info *npinfo;
	possible_net_t___96 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___268 dev;
	const struct attribute_group___275 *sysfs_groups[4];
	const struct attribute_group___275 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___90 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___96 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___90 xdp_state[3];
	long: 64;
};

struct neigh_table___83;

struct neigh_parms___83;

struct neigh_ops___83;

struct neighbour___83 {
	struct neighbour___83 *next;
	struct neigh_table___83 *tbl;
	struct neigh_parms___83 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___96 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___83 *, struct sk_buff___97 *);
	const struct neigh_ops___83 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___96 *dev;
	u8 primary_key[0];
};

struct rtable___28;

struct fnhe_hash_bucket___26;

struct fib_nh_common___26 {
	struct net_device___96 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___59 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___28 **nhc_pcpu_rth_output;
	struct rtable___28 *nhc_rth_input;
	struct fnhe_hash_bucket___26 *nhc_exceptions;
};

struct fib6_nh___26 {
	struct fib_nh_common___26 nh_common;
	long unsigned int last_probe;
	struct rt6_info___26 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___26;

struct nexthop___17;

struct fib6_info___26 {
	struct fib6_table___26 *fib6_table;
	struct fib6_info___26 *fib6_next;
	struct fib6_node___26 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___17 *nh;
	struct fib6_nh___26 fib6_nh[0];
};

struct rt6_info___26 {
	struct dst_entry___83 dst;
	struct fib6_info___26 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___65 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___26 {
	struct fib6_node___26 *parent;
	struct fib6_node___26 *left;
	struct fib6_node___26 *right;
	struct fib6_node___26 *subtree;
	struct fib6_info___26 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___26 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___26 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___26 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___18;

typedef unsigned int nf_hookfn___22(void *, struct sk_buff___97 *, const struct nf_hook_state___18 *);

struct nf_hook_entry___18 {
	nf_hookfn___22 *hook;
	void *priv;
};

struct nf_hook_entries___18 {
	u16 num_hook_entries;
	struct nf_hook_entry___18 hooks[0];
};

struct bpf_prog_array_item___90 {
	struct bpf_prog___90 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___90 {
	struct callback_head rcu;
	struct bpf_prog_array_item___90 items[0];
};

struct bpf_prog_aux___99;

struct bpf_prog___90 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___99 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___287;

struct dentry___287 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___287 *d_parent;
	struct qstr d_name;
	struct inode___287 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___287 *d_op;
	struct super_block___287 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___287;

struct inode___287 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___287 *i_op;
	struct super_block___287 *i_sb;
	struct address_space___287 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___164 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___288 *i_fop;
		void (*free_inode)(struct inode___287 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___287 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___128 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___287 {
	int (*d_revalidate)(struct dentry___287 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___287 *, unsigned int);
	int (*d_hash)(const struct dentry___287 *, struct qstr *);
	int (*d_compare)(const struct dentry___287 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___287 *);
	int (*d_init)(struct dentry___287 *);
	void (*d_release)(struct dentry___287 *);
	void (*d_prune)(struct dentry___287 *);
	void (*d_iput)(struct dentry___287 *, struct inode___287 *);
	char * (*d_dname)(struct dentry___287 *, char *, int);
	struct vfsmount___287 * (*d_automount)(struct path___287 *);
	int (*d_manage)(const struct path___287 *, bool);
	struct dentry___287 * (*d_real)(struct dentry___287 *, const struct inode___287 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___287;

struct mem_dqinfo___287 {
	struct quota_format_type___287 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___287;

struct quota_info___287 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___287 *files[3];
	struct mem_dqinfo___287 info[3];
	const struct quota_format_ops___287 *ops[3];
};

struct rcuwait___288 {
	struct task_struct___294 *task;
};

struct percpu_rw_semaphore___288 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___288 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___287 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___288 rw_sem[3];
};

struct shrink_control___152;

struct shrinker___152 {
	long unsigned int (*count_objects)(struct shrinker___152 *, struct shrink_control___152 *);
	long unsigned int (*scan_objects)(struct shrinker___152 *, struct shrink_control___152 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___287;

struct dquot_operations___287;

struct quotactl_ops___287;

struct block_device___181;

struct super_block___287 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___287 *s_type;
	const struct super_operations___287 *s_op;
	const struct dquot_operations___287 *dq_op;
	const struct quotactl_ops___287 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___287 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___181 *s_bdev;
	struct backing_dev_info___164 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___287 s_dquot;
	struct sb_writers___287 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___287 *s_d_op;
	int cleancache_poolid;
	struct shrinker___152 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___287 {
	struct dentry___287 *mnt_root;
	struct super_block___287 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___152 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___152 *memcg;
};

struct psi_group___214 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___294 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___90 {
	struct bpf_prog_array___90 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___90 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___214;

struct cgroup_rstat_cpu___214;

struct cgroup___214 {
	struct cgroup_subsys_state___214 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___275 *kn;
	struct cgroup_file___214 procs_file;
	struct cgroup_file___214 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___214 *subsys[14];
	struct cgroup_root___214 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___214 *dom_cgrp;
	struct cgroup___214 *old_dom_cgrp;
	struct cgroup_rstat_cpu___214 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___214 psi;
	struct cgroup_bpf___90 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___178 {
	struct request_queue___178 *q;
	struct io_context___178 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___287 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___287 *ia_file;
};

struct dquot___287 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___287 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___287 {
	int qf_fmt_id;
	const struct quota_format_ops___287 *qf_ops;
	struct module___271 *qf_owner;
	struct quota_format_type___287 *qf_next;
};

struct quota_format_ops___287 {
	int (*check_quota_file)(struct super_block___287 *, int);
	int (*read_file_info)(struct super_block___287 *, int);
	int (*write_file_info)(struct super_block___287 *, int);
	int (*free_file_info)(struct super_block___287 *, int);
	int (*read_dqblk)(struct dquot___287 *);
	int (*commit_dqblk)(struct dquot___287 *);
	int (*release_dqblk)(struct dquot___287 *);
	int (*get_next_id)(struct super_block___287 *, struct kqid *);
};

struct dquot_operations___287 {
	int (*write_dquot)(struct dquot___287 *);
	struct dquot___287 * (*alloc_dquot)(struct super_block___287 *, int);
	void (*destroy_dquot)(struct dquot___287 *);
	int (*acquire_dquot)(struct dquot___287 *);
	int (*release_dquot)(struct dquot___287 *);
	int (*mark_dirty)(struct dquot___287 *);
	int (*write_info)(struct super_block___287 *, int);
	qsize_t * (*get_reserved_space)(struct inode___287 *);
	int (*get_projid)(struct inode___287 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___287 *, qsize_t *);
	int (*get_next_id)(struct super_block___287 *, struct kqid *);
};

struct quotactl_ops___287 {
	int (*quota_on)(struct super_block___287 *, int, int, const struct path___287 *);
	int (*quota_off)(struct super_block___287 *, int);
	int (*quota_enable)(struct super_block___287 *, unsigned int);
	int (*quota_disable)(struct super_block___287 *, unsigned int);
	int (*quota_sync)(struct super_block___287 *, int);
	int (*set_info)(struct super_block___287 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___287 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___287 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___287 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___287 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___287 *, unsigned int);
};

struct writeback_control___164;

struct address_space_operations___287 {
	int (*writepage)(struct page___292 *, struct writeback_control___164 *);
	int (*readpage)(struct file___287 *, struct page___292 *);
	int (*writepages)(struct address_space___287 *, struct writeback_control___164 *);
	int (*set_page_dirty)(struct page___292 *);
	int (*readpages)(struct file___287 *, struct address_space___287 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___287 *, struct address_space___287 *, loff_t, unsigned int, unsigned int, struct page___292 **, void **);
	int (*write_end)(struct file___287 *, struct address_space___287 *, loff_t, unsigned int, unsigned int, struct page___292 *, void *);
	sector_t (*bmap)(struct address_space___287 *, sector_t);
	void (*invalidatepage)(struct page___292 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___292 *, gfp_t);
	void (*freepage)(struct page___292 *);
	ssize_t (*direct_IO)(struct kiocb___287 *, struct iov_iter___207 *);
	int (*migratepage)(struct address_space___287 *, struct page___292 *, struct page___292 *, enum migrate_mode);
	bool (*isolate_page)(struct page___292 *, isolate_mode_t);
	void (*putback_page)(struct page___292 *);
	int (*launder_page)(struct page___292 *);
	int (*is_partially_uptodate)(struct page___292 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___292 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___287 *, struct page___292 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___287 *, sector_t *);
	void (*swap_deactivate)(struct file___287 *);
};

struct writeback_control___164 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___164 *wb;
	struct inode___287 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___287 {
	struct dentry___287 * (*lookup)(struct inode___287 *, struct dentry___287 *, unsigned int);
	const char * (*get_link)(struct dentry___287 *, struct inode___287 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___287 *, int);
	struct posix_acl * (*get_acl)(struct inode___287 *, int, bool);
	int (*readlink)(struct dentry___287 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___287 *, struct dentry___287 *, umode_t, bool);
	int (*link)(struct dentry___287 *, struct inode___287 *, struct dentry___287 *);
	int (*unlink)(struct inode___287 *, struct dentry___287 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___287 *, struct dentry___287 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___287 *, struct dentry___287 *, umode_t);
	int (*rmdir)(struct inode___287 *, struct dentry___287 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___287 *, struct dentry___287 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___287 *, struct dentry___287 *, struct inode___287 *, struct dentry___287 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___287 *, struct iattr___287 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___287 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___287 *, char *, size_t);
	int (*fiemap)(struct inode___287 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___287 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___287 *, struct dentry___287 *, struct file___287 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___287 *, struct dentry___287 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___287 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___287 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___287 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___287 {
	void (*fl_copy_lock)(struct file_lock___287 *, struct file_lock___287 *);
	void (*fl_release_private)(struct file_lock___287 *);
};

struct lock_manager_operations___287;

struct file_lock___287 {
	struct file_lock___287 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___287 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___287 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___287 *fl_ops;
	const struct lock_manager_operations___287 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___287 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___287 *);
	int (*lm_grant)(struct file_lock___287 *, int);
	bool (*lm_break)(struct file_lock___287 *);
	int (*lm_change)(struct file_lock___287 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___287 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___287 *);
};

struct fasync_struct___287 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___287 *fa_next;
	struct file___287 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___287 {
	struct inode___287 * (*alloc_inode)(struct super_block___287 *);
	void (*destroy_inode)(struct inode___287 *);
	void (*free_inode)(struct inode___287 *);
	void (*dirty_inode)(struct inode___287 *, int);
	int (*write_inode)(struct inode___287 *, struct writeback_control___164 *);
	int (*drop_inode)(struct inode___287 *);
	void (*evict_inode)(struct inode___287 *);
	void (*put_super)(struct super_block___287 *);
	int (*sync_fs)(struct super_block___287 *, int);
	int (*freeze_super)(struct super_block___287 *);
	int (*freeze_fs)(struct super_block___287 *);
	int (*thaw_super)(struct super_block___287 *);
	int (*unfreeze_fs)(struct super_block___287 *);
	int (*statfs)(struct dentry___287 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___287 *, int *, char *);
	void (*umount_begin)(struct super_block___287 *);
	int (*show_options)(struct seq_file___262 *, struct dentry___287 *);
	int (*show_devname)(struct seq_file___262 *, struct dentry___287 *);
	int (*show_path)(struct seq_file___262 *, struct dentry___287 *);
	int (*show_stats)(struct seq_file___262 *, struct dentry___287 *);
	ssize_t (*quota_read)(struct super_block___287 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___287 *, int, const char *, size_t, loff_t);
	struct dquot___287 ** (*get_dquots)(struct inode___287 *);
	long int (*nr_cached_objects)(struct super_block___287 *, struct shrink_control___152 *);
	long int (*free_cached_objects)(struct super_block___287 *, struct shrink_control___152 *);
	struct file___287 * (*real_loop)(struct file___287 *);
};

struct block_device___181 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___287 *bd_inode;
	struct super_block___287 *bd_super;
	void *bd_claiming;
	struct device___268 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___275 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___181 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___287 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___216)(struct file___287 *, wait_queue_head_t *, struct poll_table_struct___208 *);

struct poll_table_struct___208 {
	poll_queue_proc___216 _qproc;
	__poll_t _key;
};

struct seq_operations___262;

struct seq_file___262 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___262 *op;
	int poll_event;
	const struct file___287 *file;
	void *private;
};

typedef void bio_end_io_t___178(struct bio___178 *);

struct bio_integrity_payload___178;

struct bio___178 {
	struct bio___178 *bi_next;
	struct block_device___181 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___178 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___166 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___178 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___204 *bi_io_vec;
	struct bio_set___178 *bi_pool;
	struct bio_vec___204 bi_inline_vecs[0];
};

struct dev_pagemap_ops___282 {
	void (*page_free)(struct page___292 *);
	void (*kill)(struct dev_pagemap___282 *);
	void (*cleanup)(struct dev_pagemap___282 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___282 *);
};

struct fwnode_operations___264;

struct fwnode_handle___264 {
	struct fwnode_handle___264 *secondary;
	const struct fwnode_operations___264 *ops;
	struct device___268 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___264;

struct fwnode_endpoint___264;

struct fwnode_operations___264 {
	struct fwnode_handle___264 * (*get)(struct fwnode_handle___264 *);
	void (*put)(struct fwnode_handle___264 *);
	bool (*device_is_available)(const struct fwnode_handle___264 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___264 *, const struct device___268 *);
	bool (*property_present)(const struct fwnode_handle___264 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___264 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___264 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___264 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*get_parent)(const struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*get_next_child_node)(const struct fwnode_handle___264 *, struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*get_named_child_node)(const struct fwnode_handle___264 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___264 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___264 *);
	struct fwnode_handle___264 * (*graph_get_next_endpoint)(const struct fwnode_handle___264 *, struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*graph_get_remote_endpoint)(const struct fwnode_handle___264 *);
	struct fwnode_handle___264 * (*graph_get_port_parent)(struct fwnode_handle___264 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___264 *, struct fwnode_endpoint___264 *);
	int (*add_links)(struct fwnode_handle___264 *);
};

struct fwnode_endpoint___264 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___264 *local_fwnode;
};

struct fwnode_reference_args___264 {
	struct fwnode_handle___264 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___275;

struct kernfs_elem_dir___275 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___275 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___275;

struct kernfs_root___275 {
	struct kernfs_node___275 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___275 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___275 {
	struct kernfs_node___275 *target_kn;
};

struct kernfs_ops___275;

struct kernfs_elem_attr___275 {
	const struct kernfs_ops___275 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___275 *notify_next;
};

struct kernfs_node___275 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___275 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___275 dir;
		struct kernfs_elem_symlink___275 symlink;
		struct kernfs_elem_attr___275 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___275;

struct kernfs_ops___275 {
	int (*open)(struct kernfs_open_file___275 *);
	void (*release)(struct kernfs_open_file___275 *);
	int (*seq_show)(struct seq_file___262 *, void *);
	void * (*seq_start)(struct seq_file___262 *, loff_t *);
	void * (*seq_next)(struct seq_file___262 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___262 *, void *);
	ssize_t (*read)(struct kernfs_open_file___275 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___275 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___275 *, struct poll_table_struct___208 *);
	int (*mmap)(struct kernfs_open_file___275 *, struct vm_area_struct___292 *);
};

struct kernfs_syscall_ops___275 {
	int (*show_options)(struct seq_file___262 *, struct kernfs_root___275 *);
	int (*mkdir)(struct kernfs_node___275 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___275 *);
	int (*rename)(struct kernfs_node___275 *, struct kernfs_node___275 *, const char *);
	int (*show_path)(struct seq_file___262 *, struct kernfs_node___275 *, struct kernfs_root___275 *);
};

struct kernfs_open_file___275 {
	struct kernfs_node___275 *kn;
	struct file___287 *file;
	struct seq_file___262 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___282 *vm_ops;
};

struct kobj_ns_type_operations___83 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___83 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___275;

struct attribute_group___275 {
	const char *name;
	umode_t (*is_visible)(struct kobject___275 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___275 *, struct bin_attribute___275 *, int);
	struct attribute **attrs;
	struct bin_attribute___275 **bin_attrs;
};

struct bin_attribute___275 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___287 * (*f_mapping)();
	ssize_t (*read)(struct file___287 *, struct kobject___275 *, struct bin_attribute___275 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___287 *, struct kobject___275 *, struct bin_attribute___275 *, char *, loff_t, size_t);
	int (*mmap)(struct file___287 *, struct kobject___275 *, struct bin_attribute___275 *, struct vm_area_struct___292 *);
};

struct sysfs_ops___275 {
	ssize_t (*show)(struct kobject___275 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___275 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___275;

struct kset___275 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___275 kobj;
	const struct kset_uevent_ops___275 *uevent_ops;
};

struct kobj_type___275 {
	void (*release)(struct kobject___275 *);
	const struct sysfs_ops___275 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___275 **default_groups;
	const struct kobj_ns_type_operations___83 * (*child_ns_type)(struct kobject___275 *);
	const void * (*namespace)(struct kobject___275 *);
	void (*get_ownership)(struct kobject___275 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___275 {
	int (* const filter)(struct kset___275 *, struct kobject___275 *);
	const char * (* const name)(struct kset___275 *, struct kobject___275 *);
	int (* const uevent)(struct kset___275 *, struct kobject___275 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___271 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___271 *);
	int (*get)(char *, const struct kernel_param___271 *);
	void (*free)(void *);
};

struct kparam_array___271;

struct kernel_param___271 {
	const char *name;
	struct module___271 *mod;
	const struct kernel_param_ops___271 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___271 *arr;
	};
};

struct kparam_array___271 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___271 *ops;
	void *elem;
};

struct module_attribute___271 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___271 *, struct module_kobject___272 *, char *);
	ssize_t (*store)(struct module_attribute___271 *, struct module_kobject___272 *, const char *, size_t);
	void (*setup)(struct module___271 *, const char *);
	int (*test)(struct module___271 *);
	void (*free)(struct module___271 *);
};

struct cgroup_namespace___214 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___214 *root_cset;
};

struct socket_wq___84 {
	wait_queue_head_t wait;
	struct fasync_struct___287 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___84;

struct socket___85 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___287 *file;
	struct sock___83 *sk;
	const struct proto_ops___84 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___84 wq;
};

typedef int (*sk_read_actor_t___83)(read_descriptor_t *, struct sk_buff___97 *, unsigned int, size_t);

struct proto_ops___84 {
	int family;
	struct module___271 *owner;
	int (*release)(struct socket___85 *);
	int (*bind)(struct socket___85 *, struct sockaddr *, int);
	int (*connect)(struct socket___85 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___85 *, struct socket___85 *);
	int (*accept)(struct socket___85 *, struct socket___85 *, int, bool);
	int (*getname)(struct socket___85 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___287 *, struct socket___85 *, struct poll_table_struct___208 *);
	int (*ioctl)(struct socket___85 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___85 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___85 *, void *, bool, bool);
	int (*listen)(struct socket___85 *, int);
	int (*shutdown)(struct socket___85 *, int);
	int (*setsockopt)(struct socket___85 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___85 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___262 *, struct socket___85 *);
	int (*sendmsg)(struct socket___85 *, struct msghdr___85 *, size_t);
	int (*recvmsg)(struct socket___85 *, struct msghdr___85 *, size_t, int);
	int (*mmap)(struct file___287 *, struct socket___85 *, struct vm_area_struct___292 *);
	ssize_t (*sendpage)(struct socket___85 *, struct page___292 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___85 *, loff_t *, struct pipe_inode_info___128 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___83 *, int);
	int (*peek_len)(struct socket___85 *);
	int (*read_sock)(struct sock___83 *, read_descriptor_t *, sk_read_actor_t___83);
	int (*sendpage_locked)(struct sock___83 *, struct page___292 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___83 *, struct msghdr___85 *, size_t);
	int (*set_rcvlowat)(struct sock___83 *, int);
};

struct dev_pm_ops___268 {
	int (*prepare)(struct device___268 *);
	void (*complete)(struct device___268 *);
	int (*suspend)(struct device___268 *);
	int (*resume)(struct device___268 *);
	int (*freeze)(struct device___268 *);
	int (*thaw)(struct device___268 *);
	int (*poweroff)(struct device___268 *);
	int (*restore)(struct device___268 *);
	int (*suspend_late)(struct device___268 *);
	int (*resume_early)(struct device___268 *);
	int (*freeze_late)(struct device___268 *);
	int (*thaw_early)(struct device___268 *);
	int (*poweroff_late)(struct device___268 *);
	int (*restore_early)(struct device___268 *);
	int (*suspend_noirq)(struct device___268 *);
	int (*resume_noirq)(struct device___268 *);
	int (*freeze_noirq)(struct device___268 *);
	int (*thaw_noirq)(struct device___268 *);
	int (*poweroff_noirq)(struct device___268 *);
	int (*restore_noirq)(struct device___268 *);
	int (*runtime_suspend)(struct device___268 *);
	int (*runtime_resume)(struct device___268 *);
	int (*runtime_idle)(struct device___268 *);
};

struct wakeup_source___268 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___268 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___268 {
	struct dev_pm_ops___268 ops;
	int (*start)(struct device___268 *);
	void (*detach)(struct device___268 *, bool);
	int (*activate)(struct device___268 *);
	void (*sync)(struct device___268 *);
	void (*dismiss)(struct device___268 *);
};

struct bus_type___268 {
	const char *name;
	const char *dev_name;
	struct device___268 *dev_root;
	const struct attribute_group___275 **bus_groups;
	const struct attribute_group___275 **dev_groups;
	const struct attribute_group___275 **drv_groups;
	int (*match)(struct device___268 *, struct device_driver___268 *);
	int (*uevent)(struct device___268 *, struct kobj_uevent_env *);
	int (*probe)(struct device___268 *);
	void (*sync_state)(struct device___268 *);
	void (*remove)(struct device___268 *);
	void (*shutdown)(struct device___268 *);
	int (*online)(struct device___268 *);
	int (*offline)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	int (*num_vf)(struct device___268 *);
	int (*dma_configure)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___268 {
	const char *name;
	struct bus_type___268 *bus;
	struct module___271 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___268 *);
	void (*sync_state)(struct device___268 *);
	int (*remove)(struct device___268 *);
	void (*shutdown)(struct device___268 *);
	int (*suspend)(struct device___268 *, pm_message_t);
	int (*resume)(struct device___268 *);
	const struct attribute_group___275 **groups;
	const struct attribute_group___275 **dev_groups;
	const struct dev_pm_ops___268 *pm;
	void (*coredump)(struct device___268 *);
	struct driver_private *p;
};

struct device_type___268 {
	const char *name;
	const struct attribute_group___275 **groups;
	int (*uevent)(struct device___268 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___268 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___268 *);
	const struct dev_pm_ops___268 *pm;
};

struct class___268 {
	const char *name;
	struct module___271 *owner;
	const struct attribute_group___275 **class_groups;
	const struct attribute_group___275 **dev_groups;
	struct kobject___275 *dev_kobj;
	int (*dev_uevent)(struct device___268 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___268 *, umode_t *);
	void (*class_release)(struct class___268 *);
	void (*dev_release)(struct device___268 *);
	int (*shutdown_pre)(struct device___268 *);
	const struct kobj_ns_type_operations___83 *ns_type;
	const void * (*namespace)(struct device___268 *);
	void (*get_ownership)(struct device___268 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___268 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___128;

struct pipe_buffer___128 {
	struct page___292 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___128 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___128 {
	int (*confirm)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
	void (*release)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
	bool (*try_steal)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
	bool (*get)(struct pipe_inode_info___128 *, struct pipe_buffer___128 *);
};

struct sk_buff_fclones___3 {
	struct sk_buff___97 skb1;
	struct sk_buff___97 skb2;
	refcount_t fclone_ref;
};

struct seq_operations___262 {
	void * (*start)(struct seq_file___262 *, loff_t *);
	void (*stop)(struct seq_file___262 *, void *);
	void * (*next)(struct seq_file___262 *, void *, loff_t *);
	int (*show)(struct seq_file___262 *, void *);
};

struct pernet_operations___33 {
	struct list_head list;
	int (*init)(struct net___101 *);
	void (*pre_exit)(struct net___101 *);
	void (*exit)(struct net___101 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___96 {
	int (*ieee_getets)(struct net_device___96 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___96 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___96 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___96 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___96 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___96 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___96 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___96 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___96 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___96 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___96 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___96 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___96 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___96 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___96 *);
	u8 (*setstate)(struct net_device___96 *, u8);
	void (*getpermhwaddr)(struct net_device___96 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___96 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___96 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___96 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___96 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___96 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___96 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___96 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___96 *, int, u8 *);
	void (*setpfccfg)(struct net_device___96 *, int, u8);
	void (*getpfccfg)(struct net_device___96 *, int, u8 *);
	u8 (*setall)(struct net_device___96 *);
	u8 (*getcap)(struct net_device___96 *, int, u8 *);
	int (*getnumtcs)(struct net_device___96 *, int, u8 *);
	int (*setnumtcs)(struct net_device___96 *, int, u8);
	u8 (*getpfcstate)(struct net_device___96 *);
	void (*setpfcstate)(struct net_device___96 *, u8);
	void (*getbcncfg)(struct net_device___96 *, int, u32 *);
	void (*setbcncfg)(struct net_device___96 *, int, u32);
	void (*getbcnrp)(struct net_device___96 *, int, u8 *);
	void (*setbcnrp)(struct net_device___96 *, int, u8);
	int (*setapp)(struct net_device___96 *, u8, u16, u8);
	int (*getapp)(struct net_device___96 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___96 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___96 *, int, u8);
	u8 (*getdcbx)(struct net_device___96 *);
	u8 (*setdcbx)(struct net_device___96 *, u8);
	int (*peer_getappinfo)(struct net_device___96 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___96 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___96 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___96 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___96 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___96 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___99;

typedef int (*bpf_iter_init_seq_priv_t___98)(void *, struct bpf_iter_aux_info___99 *);

struct bpf_map___99;

struct bpf_iter_aux_info___99 {
	struct bpf_map___99 *map;
};

struct bpf_iter_seq_info___98 {
	const struct seq_operations___262 *seq_ops;
	bpf_iter_init_seq_priv_t___98 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___98 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___99 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___99 *, struct file___287 *);
	void (*map_free)(struct bpf_map___99 *);
	int (*map_get_next_key)(struct bpf_map___99 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___99 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___99 *, void *);
	int (*map_lookup_batch)(struct bpf_map___99 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___99 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___99 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___99 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___99 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___99 *, void *);
	int (*map_update_elem)(struct bpf_map___99 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___99 *, void *);
	int (*map_push_elem)(struct bpf_map___99 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___99 *, void *);
	int (*map_peek_elem)(struct bpf_map___99 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___99 *, struct file___287 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___99 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___99 *, void *, struct seq_file___262 *);
	int (*map_check_btf)(const struct bpf_map___99 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___99 *, struct bpf_prog_aux___99 *);
	void (*map_poke_untrack)(struct bpf_map___99 *, struct bpf_prog_aux___99 *);
	void (*map_poke_run)(struct bpf_map___99 *, u32, struct bpf_prog___90 *, struct bpf_prog___90 *);
	int (*map_direct_value_addr)(const struct bpf_map___99 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___99 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___99 *, struct vm_area_struct___292 *);
	__poll_t (*map_poll)(struct bpf_map___99 *, struct file___287 *, struct poll_table_struct___208 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___99 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___99 *, const struct bpf_map___99 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___99 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___98 *iter_seq_info;
};

struct bpf_map___99 {
	const struct bpf_map_ops___98 *ops;
	struct bpf_map___99 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___152 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___98;

struct bpf_jit_poke_descriptor___98;

struct bpf_prog_ops___90;

struct btf_mod_pair___98;

struct bpf_prog_offload___96;

struct bpf_prog_aux___99 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___90 *dst_prog;
	struct bpf_trampoline___98 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___90 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___98 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___90 *ops;
	struct bpf_map___99 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___98 *used_btfs;
	struct bpf_prog___90 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___99 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___96 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___96;

struct bpf_map_dev_ops___96 {
	int (*map_get_next_key)(struct bpf_offloaded_map___96 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___96 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___96 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___96 *, void *);
};

struct bpf_offloaded_map___96 {
	struct bpf_map___99 map;
	struct net_device___96 *netdev;
	const struct bpf_map_dev_ops___96 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___90 {
	int (*test_run)(struct bpf_prog___90 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___96 {
	struct bpf_prog___90 *prog;
	struct net_device___96 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___98 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___90 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___271 *mod;
};

struct bpf_jit_poke_descriptor___98 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___99 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___98 {
	struct btf *btf;
	struct module___271 *module;
};

struct cftype___214;

struct cgroup_subsys___214 {
	struct cgroup_subsys_state___214 * (*css_alloc)(struct cgroup_subsys_state___214 *);
	int (*css_online)(struct cgroup_subsys_state___214 *);
	void (*css_offline)(struct cgroup_subsys_state___214 *);
	void (*css_released)(struct cgroup_subsys_state___214 *);
	void (*css_free)(struct cgroup_subsys_state___214 *);
	void (*css_reset)(struct cgroup_subsys_state___214 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___214 *, int);
	int (*css_extra_stat_show)(struct seq_file___262 *, struct cgroup_subsys_state___214 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___294 *, struct css_set___214 *);
	void (*cancel_fork)(struct task_struct___294 *, struct css_set___214 *);
	void (*fork)(struct task_struct___294 *);
	void (*exit)(struct task_struct___294 *);
	void (*release)(struct task_struct___294 *);
	void (*bind)(struct cgroup_subsys_state___214 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___214 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___214 *dfl_cftypes;
	struct cftype___214 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___214 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___214 *updated_children;
	struct cgroup___214 *updated_next;
};

struct cgroup_root___214 {
	struct kernfs_root___275 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___214 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___214 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___214 *ss;
	struct list_head node;
	struct kernfs_ops___275 *kf_ops;
	int (*open)(struct kernfs_open_file___275 *);
	void (*release)(struct kernfs_open_file___275 *);
	u64 (*read_u64)(struct cgroup_subsys_state___214 *, struct cftype___214 *);
	s64 (*read_s64)(struct cgroup_subsys_state___214 *, struct cftype___214 *);
	int (*seq_show)(struct seq_file___262 *, void *);
	void * (*seq_start)(struct seq_file___262 *, loff_t *);
	void * (*seq_next)(struct seq_file___262 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___262 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___214 *, struct cftype___214 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___214 *, struct cftype___214 *, s64);
	ssize_t (*write)(struct kernfs_open_file___275 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___275 *, struct poll_table_struct___208 *);
};

struct xdp_rxq_info___96 {
	struct net_device___96 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___96 {
	struct net_device___96 *dev;
};

struct xdp_buff___96 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___96 *rxq;
	struct xdp_txq_info___96 *txq;
	u32 frame_sz;
};

struct xdp_frame___96 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___96 *dev_rx;
};

struct netlink_callback___96 {
	struct sk_buff___97 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___97 *, struct netlink_callback___96 *);
	int (*done)(struct netlink_callback___96 *);
	void *data;
	struct module___271 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___96 {
	int (*create)(struct sk_buff___97 *, struct net_device___96 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___97 *, unsigned char *);
	int (*cache)(const struct neighbour___83 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___96 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___97 *);
};

struct netdev_queue___96 {
	struct net_device___96 *dev;
	struct Qdisc___90 *qdisc;
	struct Qdisc___90 *qdisc_sleeping;
	struct kobject___275 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___96 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___90 {
	struct sk_buff___97 *head;
	struct sk_buff___97 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___90;

struct Qdisc___90 {
	int (*enqueue)(struct sk_buff___97 *, struct Qdisc___90 *, struct sk_buff___97 **);
	struct sk_buff___97 * (*dequeue)(struct Qdisc___90 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___90 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___96 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___96 gso_skb;
	struct qdisc_skb_head___90 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___90 *next_sched;
	struct sk_buff_head___96 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___96 {
	struct xdp_rxq_info___96 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___275 kobj;
	struct net_device___96 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___96 {
	enum net_device_path_type type;
	const struct net_device___96 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___96 = 0,
				DEV_PATH_BR_VLAN_TAG___96 = 1,
				DEV_PATH_BR_VLAN_UNTAG___96 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___96 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___96 {
	const struct net_device___96 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___96 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___90 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___96 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___96 {
	int (*xdo_dev_state_add)(struct xfrm_state___19 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___19 *);
	void (*xdo_dev_state_free)(struct xfrm_state___19 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___97 *, struct xfrm_state___19 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___19 *);
};

struct xfrm_state_offload___19 {
	struct net_device___96 *dev;
	struct net_device___96 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___19;

struct xfrm_type_offload___19;

struct xfrm_state___19 {
	possible_net_t___96 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___83 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___19 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___19 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___292 xfrag;
	const struct xfrm_type___19 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___19 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___96 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___96 *dev;
	const char *name;
};

struct net_device_ops___96 {
	int (*ndo_init)(struct net_device___96 *);
	void (*ndo_uninit)(struct net_device___96 *);
	int (*ndo_open)(struct net_device___96 *);
	int (*ndo_stop)(struct net_device___96 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___97 *, struct net_device___96 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___97 *, struct net_device___96 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___96 *, struct sk_buff___97 *, struct net_device___96 *);
	void (*ndo_change_rx_flags)(struct net_device___96 *, int);
	void (*ndo_set_rx_mode)(struct net_device___96 *);
	int (*ndo_set_mac_address)(struct net_device___96 *, void *);
	int (*ndo_validate_addr)(struct net_device___96 *);
	int (*ndo_do_ioctl)(struct net_device___96 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___96 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___96 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___96 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___96 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___96 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___96 *, int);
	int (*ndo_neigh_setup)(struct net_device___96 *, struct neigh_parms___83 *);
	void (*ndo_tx_timeout)(struct net_device___96 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___96 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___96 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___96 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___96 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___96 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___96 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___96 *);
	int (*ndo_netpoll_setup)(struct net_device___96 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___96 *);
	int (*ndo_set_vf_mac)(struct net_device___96 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___96 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___96 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___96 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___96 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___96 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___96 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___96 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___96 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___96 *, int, struct sk_buff___97 *);
	int (*ndo_get_vf_guid)(struct net_device___96 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___96 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___96 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___96 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___96 *);
	int (*ndo_fcoe_disable)(struct net_device___96 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___96 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___96 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___96 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___96 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___96 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___96 *, const struct sk_buff___97 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___96 *, struct net_device___96 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___96 *, struct net_device___96 *);
	struct net_device___96 * (*ndo_get_xmit_slave)(struct net_device___96 *, struct sk_buff___97 *, bool);
	struct net_device___96 * (*ndo_sk_get_lower_dev)(struct net_device___96 *, struct sock___83 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___96 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___96 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___96 *, struct neighbour___83 *);
	void (*ndo_neigh_destroy)(struct net_device___96 *, struct neighbour___83 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___96 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___96 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___97 *, struct netlink_callback___96 *, struct net_device___96 *, struct net_device___96 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___97 *, struct nlattr **, struct net_device___96 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___96 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___97 *, u32, u32, struct net_device___96 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___96 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___96 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___96 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___96 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___96 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___96 *, struct net_device___96 *);
	void (*ndo_dfwd_del_station)(struct net_device___96 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___96 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___96 *);
	int (*ndo_change_proto_down)(struct net_device___96 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___96 *, struct sk_buff___97 *);
	void (*ndo_set_rx_headroom)(struct net_device___96 *, int);
	int (*ndo_bpf)(struct net_device___96 *, struct netdev_bpf___96 *);
	int (*ndo_xdp_xmit)(struct net_device___96 *, int, struct xdp_frame___96 **, u32);
	struct net_device___96 * (*ndo_xdp_get_xmit_slave)(struct net_device___96 *, struct xdp_buff___96 *);
	int (*ndo_xsk_wakeup)(struct net_device___96 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___96 *);
	int (*ndo_tunnel_ctl)(struct net_device___96 *, struct ip_tunnel_parm *, int);
	struct net_device___96 * (*ndo_get_peer_dev)(struct net_device___96 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___96 *, struct net_device_path___96 *);
};

struct neigh_parms___83 {
	possible_net_t___96 net;
	struct net_device___96 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___83 *);
	struct neigh_table___83 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___83 {
	u32 (*l3mdev_fib_table)(const struct net_device___96 *);
	struct sk_buff___97 * (*l3mdev_l3_rcv)(struct net_device___96 *, struct sk_buff___97 *, u16);
	struct sk_buff___97 * (*l3mdev_l3_out)(struct net_device___96 *, struct sock___83 *, struct sk_buff___97 *, u16);
	struct dst_entry___83 * (*l3mdev_link_scope_lookup)(const struct net_device___96 *, struct flowi6 *);
};

struct ndisc_ops___65 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___96 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___96 *, struct neighbour___83 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___96 *, u8, struct neighbour___83 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___96 *, struct sk_buff___97 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___101 *, struct net_device___96 *, const struct prefix_info *, struct inet6_dev___65 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___65;

struct ifacaddr6___26;

struct inet6_dev___65 {
	struct net_device___96 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___65 *mc_list;
	struct ifmcaddr6___65 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___96 mc_query_queue;
	struct sk_buff_head___96 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___26 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___83 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___90;

struct tcf_block___90;

struct mini_Qdisc___90 {
	struct tcf_proto___90 *filter_list;
	struct tcf_block___90 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___90 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___96 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___96 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___101 *, struct net_device___96 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___96 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___96 *, struct list_head *);
	size_t (*get_size)(const struct net_device___96 *);
	int (*fill_info)(struct sk_buff___97 *, const struct net_device___96 *);
	size_t (*get_xstats_size)(const struct net_device___96 *);
	int (*fill_xstats)(struct sk_buff___97 *, const struct net_device___96 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___96 *, struct net_device___96 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___96 *, const struct net_device___96 *);
	int (*fill_slave_info)(struct sk_buff___97 *, const struct net_device___96 *, const struct net_device___96 *);
	struct net___101 * (*get_link_net)(const struct net_device___96 *);
	size_t (*get_linkxstats_size)(const struct net_device___96 *, int);
	int (*fill_linkxstats)(struct sk_buff___97 *, const struct net_device___96 *, int *, int);
};

struct nf_hook_state___18 {
	u8 hook;
	u8 pf;
	struct net_device___96 *in;
	struct net_device___96 *out;
	struct sock___83 *sk;
	struct net___101 *net;
	int (*okfn)(struct net___101 *, struct sock___83 *, struct sk_buff___97 *);
};

struct nf_nat_hook___2 {
	int (*parse_nat_setup)(struct nf_conn___3 *, enum nf_nat_manip_type, const struct nlattr *);
	void (*decode_session)(struct sk_buff___97 *, struct flowi *);
	unsigned int (*manip_pkt)(struct sk_buff___97 *, struct nf_conn___3 *, enum nf_nat_manip_type, enum ip_conntrack_dir);
};

struct pneigh_entry___83;

struct neigh_hash_table___83;

struct neigh_table___83 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___96 *, __u32 *);
	bool (*key_eq)(const struct neighbour___83 *, const void *);
	int (*constructor)(struct neighbour___83 *);
	int (*pconstructor)(struct pneigh_entry___83 *);
	void (*pdestructor)(struct pneigh_entry___83 *);
	void (*proxy_redo)(struct sk_buff___97 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___96 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___83 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___96 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___83 *nht;
	struct pneigh_entry___83 **phash_buckets;
};

struct neigh_ops___83 {
	int family;
	void (*solicit)(struct neighbour___83 *, struct sk_buff___97 *);
	void (*error_report)(struct neighbour___83 *, struct sk_buff___97 *);
	int (*output)(struct neighbour___83 *, struct sk_buff___97 *);
	int (*connected_output)(struct neighbour___83 *, struct sk_buff___97 *);
};

struct pneigh_entry___83 {
	struct pneigh_entry___83 *next;
	possible_net_t___96 net;
	struct net_device___96 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___83 {
	struct neighbour___83 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___59 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___101 *, struct sock___83 *, struct sk_buff___97 *);
	int (*orig_input)(struct sk_buff___97 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct block_device_operations___178;

struct gendisk___181 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___181 *part0;
	const struct block_device_operations___178 *fops;
	struct request_queue___178 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___164 *bdi;
	struct kobject___275 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___275 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___178 {
	struct bio___178 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___204 *bip_vec;
	struct bio_vec___204 bip_inline_vecs[0];
};

struct blkcg___166;

struct blkg_policy_data___166;

struct blkcg_gq___166 {
	struct request_queue___178 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___166 *blkcg;
	struct blkcg_gq___166 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___166 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___178 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___178(struct request___178 *);

typedef void integrity_complete_fn___178(struct request___178 *, unsigned int);

struct blk_integrity_profile___178 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___178 *prepare_fn;
	integrity_complete_fn___178 *complete_fn;
	const char *name;
};

struct block_device_operations___178 {
	blk_qc_t (*submit_bio)(struct bio___178 *);
	int (*open)(struct block_device___181 *, fmode_t);
	void (*release)(struct gendisk___181 *, fmode_t);
	int (*rw_page)(struct block_device___181 *, sector_t, struct page___292 *, unsigned int);
	int (*ioctl)(struct block_device___181 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___181 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___181 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___181 *);
	int (*getgeo)(struct block_device___181 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___181 *, bool);
	void (*swap_slot_free_notify)(struct block_device___181 *, long unsigned int);
	int (*report_zones)(struct gendisk___181 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___181 *, umode_t *);
	struct module___271 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___181 *, sector_t *);
};

typedef void rq_end_io_fn___178(struct request___178 *, blk_status_t);

struct request___178 {
	struct request_queue___178 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___173 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___178 *bio;
	struct bio___178 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___204 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___178 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___178 *saved_end_io;
		} flush;
	};
	struct gendisk___181 *rq_disk;
	struct block_device___181 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___178 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___173 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___178 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___275 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___287 *debugfs_dir;
	struct dentry___287 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___178;

struct elevator_mq_ops___178 {
	int (*init_sched)(struct request_queue___178 *, struct elevator_type___178 *);
	void (*exit_sched)(struct elevator_queue___178 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___173 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___173 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___173 *);
	bool (*allow_merge)(struct request_queue___178 *, struct request___178 *, struct bio___178 *);
	bool (*bio_merge)(struct request_queue___178 *, struct bio___178 *, unsigned int);
	int (*request_merge)(struct request_queue___178 *, struct request___178 **, struct bio___178 *);
	void (*request_merged)(struct request_queue___178 *, struct request___178 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___178 *, struct request___178 *, struct request___178 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___178 *);
	void (*finish_request)(struct request___178 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___173 *, struct list_head *, bool);
	struct request___178 * (*dispatch_request)(struct blk_mq_hw_ctx___173 *);
	bool (*has_work)(struct blk_mq_hw_ctx___173 *);
	void (*completed_request)(struct request___178 *, u64);
	void (*requeue_request)(struct request___178 *);
	struct request___178 * (*former_request)(struct request_queue___178 *, struct request___178 *);
	struct request___178 * (*next_request)(struct request_queue___178 *, struct request___178 *);
	void (*init_icq)(struct io_cq___178 *);
	void (*exit_icq)(struct io_cq___178 *);
};

struct elv_fs_entry___178;

struct elevator_type___178 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___178 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___178 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___271 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___178 {
	struct elevator_type___178 *type;
	void *elevator_data;
	struct kobject___275 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___178 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___178 *, char *);
	ssize_t (*store)(struct elevator_queue___178 *, const char *, size_t);
};

struct blk_mq_queue_data___173;

struct blk_mq_ops___173 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___173 *, const struct blk_mq_queue_data___173 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___173 *);
	int (*get_budget)(struct request_queue___178 *);
	void (*put_budget)(struct request_queue___178 *, int);
	void (*set_rq_budget_token)(struct request___178 *, int);
	int (*get_rq_budget_token)(struct request___178 *);
	enum blk_eh_timer_return (*timeout)(struct request___178 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___173 *);
	void (*complete)(struct request___178 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___173 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___173 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___173 *, struct request___178 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___173 *, struct request___178 *, unsigned int);
	void (*initialize_rq_fn)(struct request___178 *);
	void (*cleanup_rq)(struct request___178 *);
	bool (*busy)(struct request_queue___178 *);
	int (*map_queues)(struct blk_mq_tag_set___173 *);
	void (*show_rq)(struct seq_file___262 *, struct request___178 *);
};

struct blk_mq_tag_set___173 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___173 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___173 {
	struct request___178 *rq;
	bool last;
};

struct blkcg_policy_data___166;

struct blkcg___166 {
	struct cgroup_subsys_state___214 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___166 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___166 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___166 {
	struct blkcg___166 *blkcg;
	int plid;
};

struct blkg_policy_data___166 {
	struct blkcg_gq___166 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___152 {
	struct mem_cgroup___152 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___152 {
	struct lruvec___160 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___152 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___152 *memcg;
};

struct obj_cgroup___152 {
	struct percpu_ref refcnt;
	struct mem_cgroup___152 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___90 {
	spinlock_t *lock;
	struct sk_buff___97 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___90;

struct Qdisc_ops___90 {
	struct Qdisc_ops___90 *next;
	const struct Qdisc_class_ops___90 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___97 *, struct Qdisc___90 *, struct sk_buff___97 **);
	struct sk_buff___97 * (*dequeue)(struct Qdisc___90 *);
	struct sk_buff___97 * (*peek)(struct Qdisc___90 *);
	int (*init)(struct Qdisc___90 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___90 *);
	void (*destroy)(struct Qdisc___90 *);
	int (*change)(struct Qdisc___90 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___90 *);
	int (*change_tx_queue_len)(struct Qdisc___90 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___90 *, unsigned int);
	int (*dump)(struct Qdisc___90 *, struct sk_buff___97 *);
	int (*dump_stats)(struct Qdisc___90 *, struct gnet_dump___90 *);
	void (*ingress_block_set)(struct Qdisc___90 *, u32);
	void (*egress_block_set)(struct Qdisc___90 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___90 *);
	u32 (*egress_block_get)(struct Qdisc___90 *);
	struct module___271 *owner;
};

struct Qdisc_class_ops___90 {
	unsigned int flags;
	struct netdev_queue___96 * (*select_queue)(struct Qdisc___90 *, struct tcmsg *);
	int (*graft)(struct Qdisc___90 *, long unsigned int, struct Qdisc___90 *, struct Qdisc___90 **, struct netlink_ext_ack *);
	struct Qdisc___90 * (*leaf)(struct Qdisc___90 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___90 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___90 *, u32);
	int (*change)(struct Qdisc___90 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___90 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___90 *, struct qdisc_walker *);
	struct tcf_block___90 * (*tcf_block)(struct Qdisc___90 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___90 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___90 *, long unsigned int);
	int (*dump)(struct Qdisc___90 *, long unsigned int, struct sk_buff___97 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___90 *, long unsigned int, struct gnet_dump___90 *);
};

struct tcf_chain___90;

struct tcf_block___90 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___101 *net;
	struct Qdisc___90 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___90 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___90;

struct tcf_proto_ops___90;

struct tcf_proto___90 {
	struct tcf_proto___90 *next;
	void *root;
	int (*classify)(struct sk_buff___97 *, const struct tcf_proto___90 *, struct tcf_result___90 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___90 *ops;
	struct tcf_chain___90 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___90 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___90 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___90 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___97 *, const struct tcf_proto___90 *, struct tcf_result___90 *);
	int (*init)(struct tcf_proto___90 *);
	void (*destroy)(struct tcf_proto___90 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___90 *, u32);
	void (*put)(struct tcf_proto___90 *, void *);
	int (*change)(struct net___101 *, struct sk_buff___97 *, struct tcf_proto___90 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___90 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___90 *);
	void (*walk)(struct tcf_proto___90 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___90 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___90 *, void *);
	void (*hw_del)(struct tcf_proto___90 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___101 *, struct tcf_chain___90 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___101 *, struct tcf_proto___90 *, void *, struct sk_buff___97 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___101 *, struct tcf_proto___90 *, void *, struct sk_buff___97 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___97 *, struct net___101 *, void *);
	struct module___271 *owner;
	int flags;
};

struct tcf_chain___90 {
	struct mutex filter_chain_lock;
	struct tcf_proto___90 *filter_chain;
	struct list_head list;
	struct tcf_block___90 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___90 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___83 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___90 *prog;
};

struct fib_rule___83 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___83 *ctarget;
	struct net___101 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___83 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___83 *rule;
	u32 table;
	int flags;
};

struct sk_psock___4;

struct request_sock_ops___68;

struct timewait_sock_ops___67;

struct proto___83 {
	void (*close)(struct sock___83 *, long int);
	int (*pre_connect)(struct sock___83 *, struct sockaddr *, int);
	int (*connect)(struct sock___83 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___83 *, int);
	struct sock___83 * (*accept)(struct sock___83 *, int, int *, bool);
	int (*ioctl)(struct sock___83 *, int, long unsigned int);
	int (*init)(struct sock___83 *);
	void (*destroy)(struct sock___83 *);
	void (*shutdown)(struct sock___83 *, int);
	int (*setsockopt)(struct sock___83 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___83 *, int, int, char *, int *);
	void (*keepalive)(struct sock___83 *, int);
	int (*compat_ioctl)(struct sock___83 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___83 *, struct msghdr___85 *, size_t);
	int (*recvmsg)(struct sock___83 *, struct msghdr___85 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___83 *, struct page___292 *, int, size_t, int);
	int (*bind)(struct sock___83 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___83 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___83 *, struct sk_buff___97 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___83 *);
	int (*hash)(struct sock___83 *);
	void (*unhash)(struct sock___83 *);
	void (*rehash)(struct sock___83 *);
	int (*get_port)(struct sock___83 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___83 *, struct sk_psock___4 *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___83 *, int);
	bool (*sock_is_readable)(struct sock___83 *);
	void (*enter_memory_pressure)(struct sock___83 *);
	void (*leave_memory_pressure)(struct sock___83 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___68 *rsk_prot;
	struct timewait_sock_ops___67 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___271 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___83 *, int);
};

struct xfrm_policy_queue___19 {
	struct sk_buff_head___96 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___19 {
	possible_net_t___96 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___19 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___31 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___90 *prog;
	struct sock___83 *socks[0];
};

struct sk_psock_progs___4 {
	struct bpf_prog___90 *msg_parser;
	struct bpf_prog___90 *stream_parser;
	struct bpf_prog___90 *stream_verdict;
	struct bpf_prog___90 *skb_verdict;
};

struct strparser___4;

struct strp_callbacks___4 {
	int (*parse_msg)(struct strparser___4 *, struct sk_buff___97 *);
	void (*rcv_msg)(struct strparser___4 *, struct sk_buff___97 *);
	int (*read_sock_done)(struct strparser___4 *, int);
	void (*abort_parser)(struct strparser___4 *, int);
	void (*lock)(struct strparser___4 *);
	void (*unlock)(struct strparser___4 *);
};

struct strparser___4 {
	struct sock___83 *sk;
	u32 stopped: 1;
	u32 paused: 1;
	u32 aborted: 1;
	u32 interrupted: 1;
	u32 unrecov_intr: 1;
	long: 63;
	long: 64;
	struct sk_buff___97 **skb_nextp;
	struct sk_buff___97 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___4 cb;
};

struct sk_psock_work_state___4 {
	struct sk_buff___97 *skb;
	u32 len;
	u32 off;
};

struct sk_msg___4;

struct sk_psock___4 {
	struct sock___83 *sk;
	struct sock___83 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg___4 *cork;
	struct sk_psock_progs___4 progs;
	struct strparser___4 strp;
	struct sk_buff_head___96 ingress_skb;
	struct list_head ingress_msg;
	spinlock_t ingress_lock;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___83 *);
	void (*saved_close)(struct sock___83 *, long int);
	void (*saved_write_space)(struct sock___83 *);
	void (*saved_data_ready)(struct sock___83 *);
	int (*psock_update_sk_prot)(struct sock___83 *, struct sk_psock___4 *, bool);
	struct proto___83 *sk_proto;
	struct mutex work_mutex;
	struct sk_psock_work_state___4 work_state;
	struct work_struct work;
	struct rcu_work rwork;
};

struct request_sock___69;

struct request_sock_ops___68 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___83 *, struct request_sock___69 *);
	void (*send_ack)(const struct sock___83 *, struct sk_buff___97 *, struct request_sock___69 *);
	void (*send_reset)(const struct sock___83 *, struct sk_buff___97 *);
	void (*destructor)(struct request_sock___69 *);
	void (*syn_ack_timeout)(const struct request_sock___69 *);
};

struct timewait_sock_ops___67 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___83 *, struct sock___83 *, void *);
	void (*twsk_destructor)(struct sock___83 *);
};

struct request_sock___69 {
	struct sock_common___83 __req_common;
	struct request_sock___69 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___68 *rsk_ops;
	struct sock___83 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___65 {
	struct in6_addr mca_addr;
	struct inet6_dev___65 *idev;
	struct ifmcaddr6___65 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___26 {
	struct in6_addr aca_addr;
	struct fib6_info___26 *aca_rt;
	struct ifacaddr6___26 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___26 {
	struct fib_nh_exception___26 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___28 *fnhe_rth_input;
	struct rtable___28 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___28 {
	struct dst_entry___83 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___26 {
	struct fib_nh_exception___26 *chain;
};

struct fib_info___17;

struct fib_nh___17 {
	struct fib_nh_common___26 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___17 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___17 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___101 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___17 *nh;
	struct callback_head rcu;
	struct fib_nh___17 fib_nh[0];
};

struct nh_info___17;

struct nh_group___17;

struct nexthop___17 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___101 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___17 *nh_info;
		struct nh_group___17 *nh_grp;
	};
};

struct xfrm_type___19 {
	struct module___271 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___19 *);
	void (*destructor)(struct xfrm_state___19 *);
	int (*input)(struct xfrm_state___19 *, struct sk_buff___97 *);
	int (*output)(struct xfrm_state___19 *, struct sk_buff___97 *);
	int (*reject)(struct xfrm_state___19 *, struct sk_buff___97 *, const struct flowi *);
};

struct xfrm_type_offload___19 {
	struct module___271 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___19 *, struct sk_buff___97 *);
	int (*input_tail)(struct xfrm_state___19 *, struct sk_buff___97 *);
	int (*xmit)(struct xfrm_state___19 *, struct sk_buff___97 *, netdev_features_t);
};

enum {
	XFRM_STATE_VOID = 0,
	XFRM_STATE_ACQ = 1,
	XFRM_STATE_VALID = 2,
	XFRM_STATE_ERROR = 3,
	XFRM_STATE_EXPIRED = 4,
	XFRM_STATE_DEAD = 5,
};

struct xfrm_if;

struct xfrm_if_cb {
	struct xfrm_if * (*decode_session)(struct sk_buff___97 *, short unsigned int);
};

struct xfrm_if_parms {
	int link;
	u32 if_id;
};

struct xfrm_if {
	struct xfrm_if *next;
	struct net_device___96 *dev;
	struct net___101 *net;
	struct xfrm_if_parms p;
	struct gro_cells gro_cells;
};

struct xfrm_dst___5;

struct xfrm_policy_afinfo___2 {
	struct dst_ops___101 *dst_ops;
	struct dst_entry___83 * (*dst_lookup)(struct net___101 *, int, int, const xfrm_address_t *, const xfrm_address_t *, u32);
	int (*get_saddr)(struct net___101 *, int, xfrm_address_t *, xfrm_address_t *, u32);
	int (*fill_dst)(struct xfrm_dst___5 *, struct net_device___96 *, const struct flowi *);
	struct dst_entry___83 * (*blackhole_route)(struct net___101 *, struct dst_entry___83 *);
};

struct xfrm_dst___5 {
	union {
		struct dst_entry___83 dst;
		struct rtable___28 rt;
		struct rt6_info___26 rt6;
	} u;
	struct dst_entry___83 *route;
	struct dst_entry___83 *child;
	struct dst_entry___83 *path;
	struct xfrm_policy___19 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct xfrm_state_afinfo___2 {
	u8 family;
	u8 proto;
	const struct xfrm_type_offload___19 *type_offload_esp;
	const struct xfrm_type___19 *type_esp;
	const struct xfrm_type___19 *type_ipip;
	const struct xfrm_type___19 *type_ipip6;
	const struct xfrm_type___19 *type_comp;
	const struct xfrm_type___19 *type_ah;
	const struct xfrm_type___19 *type_routing;
	const struct xfrm_type___19 *type_dstopts;
	int (*output)(struct net___101 *, struct sock___83 *, struct sk_buff___97 *);
	int (*transport_finish)(struct sk_buff___97 *, int);
	void (*local_error)(struct sk_buff___97 *, u32);
};

struct xfrm_policy_walk {
	struct xfrm_policy_walk_entry walk;
	u8 type;
	u32 seq;
};

struct sec_path___7 {
	int len;
	int olen;
	struct xfrm_state___19 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct xfrmk_spdinfo {
	u32 incnt;
	u32 outcnt;
	u32 fwdcnt;
	u32 inscnt;
	u32 outscnt;
	u32 fwdscnt;
	u32 spdhcnt;
	u32 spdhmcnt;
};

struct nh_info___17 {
	struct hlist_node dev_hash;
	struct nexthop___17 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___26 fib_nhc;
		struct fib_nh___17 fib_nh;
		struct fib6_nh___26 fib6_nh;
	};
};

struct nh_grp_entry___17;

struct nh_res_bucket___17 {
	struct nh_grp_entry___17 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___17 {
	struct nexthop___17 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___17 *nh_parent;
};

struct nh_res_table___17 {
	struct net___101 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___17 nh_buckets[0];
};

struct nh_group___17 {
	struct nh_group___17 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___17 *res_table;
	struct nh_grp_entry___17 nh_entries[0];
};

struct ip6_mh {
	__u8 ip6mh_proto;
	__u8 ip6mh_hdrlen;
	__u8 ip6mh_type;
	__u8 ip6mh_reserved;
	__u16 ip6mh_cksum;
	__u8 data[0];
};

struct sk_msg___4 {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___97 *skb;
	struct sock___83 *sk_redir;
	struct sock___83 *sk;
	struct list_head list;
};

struct xfrm_flo {
	struct dst_entry___83 *dst_orig;
	u8 flags;
};

struct xfrm_pol_inexact_node {
	struct rb_node node;
	union {
		xfrm_address_t addr;
		struct callback_head rcu;
	};
	u8 prefixlen;
	struct rb_root root;
	struct hlist_head hhead;
};

struct xfrm_pol_inexact_key {
	possible_net_t___96 net;
	u32 if_id;
	u16 family;
	u8 dir;
	u8 type;
};

struct xfrm_pol_inexact_bin {
	struct xfrm_pol_inexact_key k;
	struct rhash_head head;
	struct hlist_head hhead;
	seqcount_spinlock_t count;
	struct rb_root root_d;
	struct rb_root root_s;
	struct list_head inexact_bins;
	struct callback_head rcu;
};

enum xfrm_pol_inexact_candidate_type {
	XFRM_POL_CAND_BOTH = 0,
	XFRM_POL_CAND_SADDR = 1,
	XFRM_POL_CAND_DADDR = 2,
	XFRM_POL_CAND_ANY = 3,
	XFRM_POL_CAND_MAX = 4,
};

struct xfrm_pol_inexact_candidates {
	struct hlist_head *res[4];
};

enum xfrm_ae_ftype_t {
	XFRM_AE_UNSPEC = 0,
	XFRM_AE_RTHR = 1,
	XFRM_AE_RVAL = 2,
	XFRM_AE_LVAL = 4,
	XFRM_AE_ETHR = 8,
	XFRM_AE_CR = 16,
	XFRM_AE_CE = 32,
	XFRM_AE_CU = 64,
	__XFRM_AE_MAX = 65,
};

enum xfrm_nlgroups {
	XFRMNLGRP_NONE = 0,
	XFRMNLGRP_ACQUIRE = 1,
	XFRMNLGRP_EXPIRE = 2,
	XFRMNLGRP_SA = 3,
	XFRMNLGRP_POLICY = 4,
	XFRMNLGRP_AEVENTS = 5,
	XFRMNLGRP_REPORT = 6,
	XFRMNLGRP_MIGRATE = 7,
	XFRMNLGRP_MAPPING = 8,
	__XFRMNLGRP_MAX = 9,
};

enum {
	XFRM_MODE_FLAG_TUNNEL = 1,
};

struct km_event {
	union {
		u32 hard;
		u32 proto;
		u32 byid;
		u32 aevent;
		u32 type;
	} data;
	u32 seq;
	u32 portid;
	u32 event;
	struct net___91 *net;
};

struct xfrm_state_afinfo___3 {
	u8 family;
	u8 proto;
	const struct xfrm_type_offload___16 *type_offload_esp;
	const struct xfrm_type___16 *type_esp;
	const struct xfrm_type___16 *type_ipip;
	const struct xfrm_type___16 *type_ipip6;
	const struct xfrm_type___16 *type_comp;
	const struct xfrm_type___16 *type_ah;
	const struct xfrm_type___16 *type_routing;
	const struct xfrm_type___16 *type_dstopts;
	int (*output)(struct net___91 *, struct sock___73 *, struct sk_buff___87 *);
	int (*transport_finish)(struct sk_buff___87 *, int);
	void (*local_error)(struct sk_buff___87 *, u32);
};

struct xfrm_kmaddress {
	xfrm_address_t local;
	xfrm_address_t remote;
	u32 reserved;
	u16 family;
};

struct xfrm_migrate {
	xfrm_address_t old_daddr;
	xfrm_address_t old_saddr;
	xfrm_address_t new_daddr;
	xfrm_address_t new_saddr;
	u8 proto;
	u8 mode;
	u16 reserved;
	u32 reqid;
	u16 old_family;
	u16 new_family;
};

struct xfrm_mgr {
	struct list_head list;
	int (*notify)(struct xfrm_state___16 *, const struct km_event *);
	int (*acquire)(struct xfrm_state___16 *, struct xfrm_tmpl *, struct xfrm_policy___16 *);
	struct xfrm_policy___16 * (*compile_policy)(struct sock___73 *, int, u8 *, int, int *);
	int (*new_mapping)(struct xfrm_state___16 *, xfrm_address_t *, __be16);
	int (*notify_policy)(struct xfrm_policy___16 *, int, const struct km_event *);
	int (*report)(struct net___91 *, u8, struct xfrm_selector *, xfrm_address_t *);
	int (*migrate)(const struct xfrm_selector *, u8, u8, const struct xfrm_migrate *, int, const struct xfrm_kmaddress *, const struct xfrm_encap_tmpl *);
	bool (*is_alive)(const struct km_event *);
};

struct xfrmk_sadinfo {
	u32 sadhcnt;
	u32 sadhmcnt;
	u32 sadcnt;
};

struct xfrm_translator {
	int (*alloc_compat)(struct sk_buff___87 *, const struct nlmsghdr *);
	struct nlmsghdr * (*rcv_msg_compat)(const struct nlmsghdr *, int, const struct nla_policy *, struct netlink_ext_ack *);
	int (*xlate_user_policy_sockptr)(u8 **, int);
	struct module___261 *owner;
};

struct crypto_alg___28;

struct crypto_tfm___28 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___28 *);
	struct crypto_alg___28 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___28 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___28 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___28 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___28 *, u8 *, const u8 *);
};

struct compress_alg___28 {
	int (*coa_compress)(struct crypto_tfm___28 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___28 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___28 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___28 cipher;
		struct compress_alg___28 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___28 *);
	void (*cra_exit)(struct crypto_tfm___28 *);
	void (*cra_destroy)(struct crypto_alg___28 *);
	struct module___261 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_aead___5 {
	unsigned int authsize;
	unsigned int reqsize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___28 base;
};

struct ip_beet_phdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 padlen;
	__u8 reserved;
};

struct xfrm_state_afinfo___4 {
	u8 family;
	u8 proto;
	const struct xfrm_type_offload___18 *type_offload_esp;
	const struct xfrm_type___18 *type_esp;
	const struct xfrm_type___18 *type_ipip;
	const struct xfrm_type___18 *type_ipip6;
	const struct xfrm_type___18 *type_comp;
	const struct xfrm_type___18 *type_ah;
	const struct xfrm_type___18 *type_routing;
	const struct xfrm_type___18 *type_dstopts;
	int (*output)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
	int (*transport_finish)(struct sk_buff___90 *, int);
	void (*local_error)(struct sk_buff___90 *, u32);
};

struct xfrm_input_afinfo___2 {
	u8 family;
	bool is_ipip;
	int (*callback)(struct sk_buff___90 *, u8, int);
};

struct ip_tunnel_6rd_parm {
	struct in6_addr prefix;
	__be32 relay_prefix;
	u16 prefixlen;
	u16 relay_prefixlen;
};

struct ip_tunnel_fan {
	struct list_head fan_maps;
};

struct ip_tunnel_prl_entry;

struct ip_tunnel {
	struct ip_tunnel *next;
	struct hlist_node hash_node;
	struct net_device___89 *dev;
	struct net___94 *net;
	long unsigned int err_time;
	int err_count;
	u32 i_seqno;
	u32 o_seqno;
	int tun_hlen;
	u32 index;
	u8 erspan_ver;
	u8 dir;
	u16 hwid;
	struct dst_cache dst_cache;
	struct ip_tunnel_parm parms;
	int mlink;
	int encap_hlen;
	int hlen;
	struct ip_tunnel_encap encap;
	struct ip_tunnel_6rd_parm ip6rd;
	struct ip_tunnel_prl_entry *prl;
	unsigned int prl_count;
	struct ip_tunnel_fan fan;
	unsigned int ip_tnl_net_id;
	struct gro_cells gro_cells;
	__u32 fwmark;
	bool collect_md;
	bool ignore_df;
};

struct __ip6_tnl_parm {
	char name[16];
	int link;
	__u8 proto;
	__u8 encap_limit;
	__u8 hop_limit;
	bool collect_md;
	__be32 flowinfo;
	__u32 flags;
	struct in6_addr laddr;
	struct in6_addr raddr;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	__u32 fwmark;
	__u32 index;
	__u8 erspan_ver;
	__u8 dir;
	__u16 hwid;
};

struct ip6_tnl {
	struct ip6_tnl *next;
	struct net_device___89 *dev;
	struct net___94 *net;
	struct __ip6_tnl_parm parms;
	struct flowi fl;
	struct dst_cache dst_cache;
	struct gro_cells gro_cells;
	int err_count;
	long unsigned int err_time;
	__u32 i_seqno;
	__u32 o_seqno;
	int hlen;
	int tun_hlen;
	int encap_hlen;
	struct ip_tunnel_encap encap;
	int mlink;
};

struct xfrm_skb_cb {
	struct xfrm_tunnel_skb_cb___2 header;
	union {
		struct {
			__u32 low;
			__u32 hi;
		} output;
		struct {
			__be32 low;
			__be32 hi;
		} input;
	} seq;
};

struct xfrm_mode_skb_cb___2 {
	struct xfrm_tunnel_skb_cb___2 header;
	__be16 id;
	__be16 frag_off;
	u8 ihl;
	u8 tos;
	u8 ttl;
	u8 protocol;
	u8 optlen;
	u8 flow_lbl[3];
};

struct sec_path___8 {
	int len;
	int olen;
	struct xfrm_state___18 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct ip_tunnel_prl_entry {
	struct ip_tunnel_prl_entry *next;
	__be32 addr;
	u16 flags;
	struct callback_head callback_head;
};

struct xfrm_trans_tasklet {
	struct tasklet_struct tasklet;
	struct sk_buff_head___89 queue;
};

struct xfrm_trans_cb {
	union {
		struct inet_skb_parm h4;
		struct inet6_skb_parm h6;
	} header;
	int (*finish)(struct net___94 *, struct sock___76 *, struct sk_buff___90 *);
	struct net___94 *net;
};

typedef struct bio_vec___203 skb_frag_t___38;

typedef unsigned int nf_hookfn___23(void *, struct sk_buff___96 *, const struct nf_hook_state___5 *);

struct km_event___2 {
	union {
		u32 hard;
		u32 proto;
		u32 byid;
		u32 aevent;
		u32 type;
	} data;
	u32 seq;
	u32 portid;
	u32 event;
	struct net___100 *net;
};

struct xfrm_skb_cb___2 {
	struct xfrm_tunnel_skb_cb header;
	union {
		struct {
			__u32 low;
			__u32 hi;
		} output;
		struct {
			__be32 low;
			__be32 hi;
		} input;
	} seq;
};

struct xfrm_user_offload {
	int ifindex;
	__u8 flags;
};

struct dentry___288;

struct super_block___288;

struct module___272;

struct file_system_type___288 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___288 * (*mount)(struct file_system_type___288 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___288 *);
	struct module___272 *owner;
	struct file_system_type___288 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___288;

struct kiocb___288;

struct iov_iter___208;

struct poll_table_struct___209;

struct vm_area_struct___293;

struct inode___288;

struct file_lock___288;

struct page___293;

struct pipe_inode_info___129;

struct seq_file___263;

struct file_operations___289 {
	struct module___272 *owner;
	loff_t (*llseek)(struct file___288 *, loff_t, int);
	ssize_t (*read)(struct file___288 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___288 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___288 *, struct iov_iter___208 *);
	ssize_t (*write_iter)(struct kiocb___288 *, struct iov_iter___208 *);
	int (*iopoll)(struct kiocb___288 *, bool);
	int (*iterate)(struct file___288 *, struct dir_context *);
	int (*iterate_shared)(struct file___288 *, struct dir_context *);
	__poll_t (*poll)(struct file___288 *, struct poll_table_struct___209 *);
	long int (*unlocked_ioctl)(struct file___288 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___288 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___288 *, struct vm_area_struct___293 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___288 *, struct file___288 *);
	int (*flush)(struct file___288 *, fl_owner_t);
	int (*release)(struct inode___288 *, struct file___288 *);
	int (*fsync)(struct file___288 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___288 *, int);
	int (*lock)(struct file___288 *, int, struct file_lock___288 *);
	ssize_t (*sendpage)(struct file___288 *, struct page___293 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___288 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___288 *, long unsigned int);
	int (*flock)(struct file___288 *, int, struct file_lock___288 *);
	ssize_t (*splice_write)(struct pipe_inode_info___129 *, struct file___288 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___288 *, loff_t *, struct pipe_inode_info___129 *, size_t, unsigned int);
	int (*setlease)(struct file___288 *, long int, struct file_lock___288 **, void **);
	long int (*fallocate)(struct file___288 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___263 *, struct file___288 *);
	ssize_t (*copy_file_range)(struct file___288 *, loff_t, struct file___288 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___288 *, loff_t, struct file___288 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___288 *, loff_t, loff_t, int);
};

struct vmacache___293 {
	u64 seqnum;
	struct vm_area_struct___293 *vmas[4];
};

struct page_frag___293 {
	struct page___293 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___294;

struct pid___265;

struct nsproxy___274;

struct signal_struct___289;

struct bio_list___179;

struct backing_dev_info___165;

struct io_context___179;

struct css_set___215;

struct mem_cgroup___153;

struct request_queue___179;

struct vm_struct___271;

struct task_struct___295 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___295 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___294 *mm;
	struct mm_struct___294 *active_mm;
	struct vmacache___293 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___295 *real_parent;
	struct task_struct___295 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___295 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___265 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___274 *nsproxy;
	struct signal_struct___289 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___295 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___179 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___165 *backing_dev_info;
	struct io_context___179 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___215 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___129 *splice_pipe;
	struct page_frag___293 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___153 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___153 *active_memcg;
	struct request_queue___179 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___295 *oom_reaper_list;
	struct vm_struct___271 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___276;

struct kobj_type___276;

struct kernfs_node___276;

struct kobject___276 {
	const char *name;
	struct list_head entry;
	struct kobject___276 *parent;
	struct kset___276 *kset;
	struct kobj_type___276 *ktype;
	struct kernfs_node___276 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___273 {
	struct kobject___276 kobj;
	struct module___272 *mod;
	struct kobject___276 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___272 {
	struct module___272 *mod;
	struct latch_tree_node node;
};

struct module_layout___272 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___272 mtn;
};

struct module_attribute___272;

struct kernel_param___272;

struct module___272 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___273 mkobj;
	struct module_attribute___272 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___276 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___272 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___272 core_layout;
	struct module_layout___272 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___288;

struct dentry___288 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___288 *d_parent;
	struct qstr d_name;
	struct inode___288 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___288 *d_op;
	struct super_block___288 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___288;

struct address_space___288 {
	struct inode___288 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___288 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___288;

struct bdi_writeback___165;

struct inode___288 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___288 *i_op;
	struct super_block___288 *i_sb;
	struct address_space___288 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___165 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___289 *i_fop;
		void (*free_inode)(struct inode___288 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___288 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___129 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___288;

struct path___288;

struct dentry_operations___288 {
	int (*d_revalidate)(struct dentry___288 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___288 *, unsigned int);
	int (*d_hash)(const struct dentry___288 *, struct qstr *);
	int (*d_compare)(const struct dentry___288 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___288 *);
	int (*d_init)(struct dentry___288 *);
	void (*d_release)(struct dentry___288 *);
	void (*d_prune)(struct dentry___288 *);
	void (*d_iput)(struct dentry___288 *, struct inode___288 *);
	char * (*d_dname)(struct dentry___288 *, char *, int);
	struct vfsmount___288 * (*d_automount)(struct path___288 *);
	int (*d_manage)(const struct path___288 *, bool);
	struct dentry___288 * (*d_real)(struct dentry___288 *, const struct inode___288 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___288;

struct mem_dqinfo___288 {
	struct quota_format_type___288 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___288;

struct quota_info___288 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___288 *files[3];
	struct mem_dqinfo___288 info[3];
	const struct quota_format_ops___288 *ops[3];
};

struct rcuwait___289 {
	struct task_struct___295 *task;
};

struct percpu_rw_semaphore___289 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___289 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___288 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___289 rw_sem[3];
};

struct shrink_control___153;

struct shrinker___153 {
	long unsigned int (*count_objects)(struct shrinker___153 *, struct shrink_control___153 *);
	long unsigned int (*scan_objects)(struct shrinker___153 *, struct shrink_control___153 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___288;

struct dquot_operations___288;

struct quotactl_ops___288;

struct block_device___182;

struct super_block___288 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___288 *s_type;
	const struct super_operations___288 *s_op;
	const struct dquot_operations___288 *dq_op;
	const struct quotactl_ops___288 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___288 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___182 *s_bdev;
	struct backing_dev_info___165 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___288 s_dquot;
	struct sb_writers___288 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___288 *s_d_op;
	int cleancache_poolid;
	struct shrinker___153 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___288 {
	struct dentry___288 *mnt_root;
	struct super_block___288 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___288 {
	struct vfsmount___288 *mnt;
	struct dentry___288 *dentry;
};

struct pid_namespace___265;

struct upid___265 {
	int nr;
	struct pid_namespace___265 *ns;
};

struct pid_namespace___265 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___295 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___265 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___265 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___265 numbers[1];
};

typedef struct page___293 *pgtable_t___293;

struct page_pool___117;

struct dev_pagemap___283;

struct page___293 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___288 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___117 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___293 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___293 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___294 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___283 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___283;

struct vm_area_struct___293 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___293 *vm_next;
	struct vm_area_struct___293 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___294 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___283 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___288 *vm_file;
	struct file___288 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___289 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___295 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___295 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___265 *pids[4];
	struct pid___265 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___294 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___293;

struct mm_struct___294 {
	struct {
		struct vm_area_struct___293 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___288 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___293 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___295 *owner;
		struct user_namespace___26 *user_ns;
		struct file___288 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___102;

struct cgroup_namespace___215;

struct nsproxy___274 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___265 *pid_ns_for_children;
	struct net___102 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___215 *cgroup_ns;
};

struct bio___179;

struct bio_list___179 {
	struct bio___179 *head;
	struct bio___179 *tail;
};

struct cgroup_subsys_state___215;

struct bdi_writeback___165 {
	struct backing_dev_info___165 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___215 *memcg_css;
	struct cgroup_subsys_state___215 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___269;

struct backing_dev_info___165 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___165 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___269 *dev;
	char dev_name[64];
	struct device___269 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___288 *debug_dir;
};

struct io_cq___179;

struct io_context___179 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___179 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___215;

struct css_set___215 {
	struct cgroup_subsys_state___215 *subsys[14];
	refcount_t refcount;
	struct css_set___215 *dom_cset;
	struct cgroup___215 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___215 *mg_src_cgrp;
	struct cgroup___215 *mg_dst_cgrp;
	struct css_set___215 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___288;

struct pipe_buffer___129;

struct pipe_inode_info___129 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___293 *tmp_page;
	struct fasync_struct___288 *fasync_readers;
	struct fasync_struct___288 *fasync_writers;
	struct pipe_buffer___129 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___215;

struct cgroup_subsys_state___215 {
	struct cgroup___215 *cgroup;
	struct cgroup_subsys___215 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___215 *parent;
};

struct cgroup_file___215 {
	struct kernfs_node___276 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___153;

struct mem_cgroup_per_node___153;

struct mem_cgroup___153 {
	struct cgroup_subsys_state___215 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___215 events_file;
	struct cgroup_file___215 events_local_file;
	struct cgroup_file___215 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___153 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___295 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___153 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___179;

struct blk_integrity___179 {
	const struct blk_integrity_profile___179 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___179 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___179 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___179;

struct elevator_queue___179;

struct blk_mq_ops___174;

struct blk_mq_hw_ctx___174;

struct gendisk___182;

struct blkcg_gq___167;

struct blk_mq_tag_set___174;

struct request_queue___179 {
	struct request___179 *last_merge;
	struct elevator_queue___179 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___174 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___174 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___182 *disk;
	struct kobject___276 kobj;
	struct kobject___276 *mq_kobj;
	struct blk_integrity___179 integrity;
	struct device___269 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___167 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___174 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___179 bio_split;
	struct dentry___288 *debugfs_dir;
	struct dentry___288 *sched_debugfs_dir;
	struct dentry___288 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___271 {
	struct vm_struct___271 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___293 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___153 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___153 *memcg;
};

struct page_pool_params___117 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___269 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___117 {
	u32 count;
	struct page___293 *cache[128];
};

struct page_pool___117 {
	struct page_pool_params___117 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___293 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___117 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___283;

struct dev_pagemap___283 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___283 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___265 {
	rwlock_t lock;
	struct pid___265 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___288 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___288 f_path;
	struct inode___288 *f_inode;
	const struct file_operations___289 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___265 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___288 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___283;

struct vm_operations_struct___283 {
	void (*open)(struct vm_area_struct___293 *);
	void (*close)(struct vm_area_struct___293 *);
	int (*may_split)(struct vm_area_struct___293 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___293 *);
	int (*mprotect)(struct vm_area_struct___293 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___283 *);
	vm_fault_t (*huge_fault)(struct vm_fault___283 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___283 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___293 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___283 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___283 *);
	int (*access)(struct vm_area_struct___293 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___293 *);
	int (*set_policy)(struct vm_area_struct___293 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___293 *, long unsigned int);
	struct page___293 * (*find_special_page)(struct vm_area_struct___293 *, long unsigned int);
};

struct core_thread___293 {
	struct task_struct___295 *task;
	struct core_thread___293 *next;
};

struct core_state___293 {
	atomic_t nr_threads;
	struct core_thread___293 dumper;
	struct completion startup;
};

struct vm_fault___283 {
	const struct {
		struct vm_area_struct___293 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___293 *cow_page;
	struct page___293 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___293 prealloc_pte;
};

struct pglist_data___161;

struct lruvec___161 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___161 *pgdat;
};

struct zone___161 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___161 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___161 {
	struct zone___161 *zone;
	int zone_idx;
};

struct zonelist___161 {
	struct zoneref___161 _zonerefs[321];
};

struct pglist_data___161 {
	struct zone___161 node_zones[5];
	struct zonelist___161 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___295 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___295 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___161 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___215 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___295 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___91;

struct cgroup_bpf___91 {
	struct bpf_prog_array___91 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___91 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___215;

struct cgroup_rstat_cpu___215;

struct cgroup___215 {
	struct cgroup_subsys_state___215 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___276 *kn;
	struct cgroup_file___215 procs_file;
	struct cgroup_file___215 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___215 *subsys[14];
	struct cgroup_root___215 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___215 *dom_cgrp;
	struct cgroup___215 *old_dom_cgrp;
	struct cgroup_rstat_cpu___215 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___215 psi;
	struct cgroup_bpf___91 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___179 {
	struct request_queue___179 *q;
	struct io_context___179 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___288 {
	struct file___288 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___288 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___288 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___288 *ia_file;
};

struct dquot___288 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___288 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___288 {
	int qf_fmt_id;
	const struct quota_format_ops___288 *qf_ops;
	struct module___272 *qf_owner;
	struct quota_format_type___288 *qf_next;
};

struct quota_format_ops___288 {
	int (*check_quota_file)(struct super_block___288 *, int);
	int (*read_file_info)(struct super_block___288 *, int);
	int (*write_file_info)(struct super_block___288 *, int);
	int (*free_file_info)(struct super_block___288 *, int);
	int (*read_dqblk)(struct dquot___288 *);
	int (*commit_dqblk)(struct dquot___288 *);
	int (*release_dqblk)(struct dquot___288 *);
	int (*get_next_id)(struct super_block___288 *, struct kqid *);
};

struct dquot_operations___288 {
	int (*write_dquot)(struct dquot___288 *);
	struct dquot___288 * (*alloc_dquot)(struct super_block___288 *, int);
	void (*destroy_dquot)(struct dquot___288 *);
	int (*acquire_dquot)(struct dquot___288 *);
	int (*release_dquot)(struct dquot___288 *);
	int (*mark_dirty)(struct dquot___288 *);
	int (*write_info)(struct super_block___288 *, int);
	qsize_t * (*get_reserved_space)(struct inode___288 *);
	int (*get_projid)(struct inode___288 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___288 *, qsize_t *);
	int (*get_next_id)(struct super_block___288 *, struct kqid *);
};

struct quotactl_ops___288 {
	int (*quota_on)(struct super_block___288 *, int, int, const struct path___288 *);
	int (*quota_off)(struct super_block___288 *, int);
	int (*quota_enable)(struct super_block___288 *, unsigned int);
	int (*quota_disable)(struct super_block___288 *, unsigned int);
	int (*quota_sync)(struct super_block___288 *, int);
	int (*set_info)(struct super_block___288 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___288 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___288 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___288 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___288 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___288 *, unsigned int);
};

struct writeback_control___165;

struct address_space_operations___288 {
	int (*writepage)(struct page___293 *, struct writeback_control___165 *);
	int (*readpage)(struct file___288 *, struct page___293 *);
	int (*writepages)(struct address_space___288 *, struct writeback_control___165 *);
	int (*set_page_dirty)(struct page___293 *);
	int (*readpages)(struct file___288 *, struct address_space___288 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___288 *, struct address_space___288 *, loff_t, unsigned int, unsigned int, struct page___293 **, void **);
	int (*write_end)(struct file___288 *, struct address_space___288 *, loff_t, unsigned int, unsigned int, struct page___293 *, void *);
	sector_t (*bmap)(struct address_space___288 *, sector_t);
	void (*invalidatepage)(struct page___293 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___293 *, gfp_t);
	void (*freepage)(struct page___293 *);
	ssize_t (*direct_IO)(struct kiocb___288 *, struct iov_iter___208 *);
	int (*migratepage)(struct address_space___288 *, struct page___293 *, struct page___293 *, enum migrate_mode);
	bool (*isolate_page)(struct page___293 *, isolate_mode_t);
	void (*putback_page)(struct page___293 *);
	int (*launder_page)(struct page___293 *);
	int (*is_partially_uptodate)(struct page___293 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___293 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___288 *, struct page___293 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___288 *, sector_t *);
	void (*swap_deactivate)(struct file___288 *);
};

struct writeback_control___165 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___165 *wb;
	struct inode___288 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___205;

struct iov_iter___208 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___205 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___129 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___288 {
	struct dentry___288 * (*lookup)(struct inode___288 *, struct dentry___288 *, unsigned int);
	const char * (*get_link)(struct dentry___288 *, struct inode___288 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___288 *, int);
	struct posix_acl * (*get_acl)(struct inode___288 *, int, bool);
	int (*readlink)(struct dentry___288 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___288 *, struct dentry___288 *, umode_t, bool);
	int (*link)(struct dentry___288 *, struct inode___288 *, struct dentry___288 *);
	int (*unlink)(struct inode___288 *, struct dentry___288 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___288 *, struct dentry___288 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___288 *, struct dentry___288 *, umode_t);
	int (*rmdir)(struct inode___288 *, struct dentry___288 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___288 *, struct dentry___288 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___288 *, struct dentry___288 *, struct inode___288 *, struct dentry___288 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___288 *, struct iattr___288 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___288 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___288 *, char *, size_t);
	int (*fiemap)(struct inode___288 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___288 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___288 *, struct dentry___288 *, struct file___288 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___288 *, struct dentry___288 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___288 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___288 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___288 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___288 {
	void (*fl_copy_lock)(struct file_lock___288 *, struct file_lock___288 *);
	void (*fl_release_private)(struct file_lock___288 *);
};

struct lock_manager_operations___288;

struct file_lock___288 {
	struct file_lock___288 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___288 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___288 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___288 *fl_ops;
	const struct lock_manager_operations___288 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___288 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___288 *);
	int (*lm_grant)(struct file_lock___288 *, int);
	bool (*lm_break)(struct file_lock___288 *);
	int (*lm_change)(struct file_lock___288 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___288 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___288 *);
};

struct fasync_struct___288 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___288 *fa_next;
	struct file___288 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___288 {
	struct inode___288 * (*alloc_inode)(struct super_block___288 *);
	void (*destroy_inode)(struct inode___288 *);
	void (*free_inode)(struct inode___288 *);
	void (*dirty_inode)(struct inode___288 *, int);
	int (*write_inode)(struct inode___288 *, struct writeback_control___165 *);
	int (*drop_inode)(struct inode___288 *);
	void (*evict_inode)(struct inode___288 *);
	void (*put_super)(struct super_block___288 *);
	int (*sync_fs)(struct super_block___288 *, int);
	int (*freeze_super)(struct super_block___288 *);
	int (*freeze_fs)(struct super_block___288 *);
	int (*thaw_super)(struct super_block___288 *);
	int (*unfreeze_fs)(struct super_block___288 *);
	int (*statfs)(struct dentry___288 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___288 *, int *, char *);
	void (*umount_begin)(struct super_block___288 *);
	int (*show_options)(struct seq_file___263 *, struct dentry___288 *);
	int (*show_devname)(struct seq_file___263 *, struct dentry___288 *);
	int (*show_path)(struct seq_file___263 *, struct dentry___288 *);
	int (*show_stats)(struct seq_file___263 *, struct dentry___288 *);
	ssize_t (*quota_read)(struct super_block___288 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___288 *, int, const char *, size_t, loff_t);
	struct dquot___288 ** (*get_dquots)(struct inode___288 *);
	long int (*nr_cached_objects)(struct super_block___288 *, struct shrink_control___153 *);
	long int (*free_cached_objects)(struct super_block___288 *, struct shrink_control___153 *);
	struct file___288 * (*real_loop)(struct file___288 *);
};

struct wakeup_source___269;

struct dev_pm_info___269 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___269 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___269 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___269;

struct bus_type___269;

struct device_driver___269;

struct dev_pm_domain___269;

struct fwnode_handle___265;

struct class___269;

struct attribute_group___276;

struct device___269 {
	struct kobject___276 kobj;
	struct device___269 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___269 *type;
	struct bus_type___269 *bus;
	struct device_driver___269 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___269 power;
	struct dev_pm_domain___269 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___265 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___269 *class;
	const struct attribute_group___276 **groups;
	void (*release)(struct device___269 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___182 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___288 *bd_inode;
	struct super_block___288 *bd_super;
	void *bd_claiming;
	struct device___269 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___276 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___182 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___288 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___217)(struct file___288 *, wait_queue_head_t *, struct poll_table_struct___209 *);

struct poll_table_struct___209 {
	poll_queue_proc___217 _qproc;
	__poll_t _key;
};

struct seq_operations___263;

struct seq_file___263 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___263 *op;
	int poll_event;
	const struct file___288 *file;
	void *private;
};

typedef void bio_end_io_t___179(struct bio___179 *);

struct bio_vec___205 {
	struct page___293 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___179;

struct bio___179 {
	struct bio___179 *bi_next;
	struct block_device___182 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___179 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___167 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___179 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___205 *bi_io_vec;
	struct bio_set___179 *bi_pool;
	struct bio_vec___205 bi_inline_vecs[0];
};

struct dev_pagemap_ops___283 {
	void (*page_free)(struct page___293 *);
	void (*kill)(struct dev_pagemap___283 *);
	void (*cleanup)(struct dev_pagemap___283 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___283 *);
};

struct fwnode_operations___265;

struct fwnode_handle___265 {
	struct fwnode_handle___265 *secondary;
	const struct fwnode_operations___265 *ops;
	struct device___269 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___265;

struct fwnode_endpoint___265;

struct fwnode_operations___265 {
	struct fwnode_handle___265 * (*get)(struct fwnode_handle___265 *);
	void (*put)(struct fwnode_handle___265 *);
	bool (*device_is_available)(const struct fwnode_handle___265 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___265 *, const struct device___269 *);
	bool (*property_present)(const struct fwnode_handle___265 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___265 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___265 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___265 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*get_parent)(const struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*get_next_child_node)(const struct fwnode_handle___265 *, struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*get_named_child_node)(const struct fwnode_handle___265 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___265 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___265 *);
	struct fwnode_handle___265 * (*graph_get_next_endpoint)(const struct fwnode_handle___265 *, struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*graph_get_remote_endpoint)(const struct fwnode_handle___265 *);
	struct fwnode_handle___265 * (*graph_get_port_parent)(struct fwnode_handle___265 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___265 *, struct fwnode_endpoint___265 *);
	int (*add_links)(struct fwnode_handle___265 *);
};

struct fwnode_endpoint___265 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___265 *local_fwnode;
};

struct fwnode_reference_args___265 {
	struct fwnode_handle___265 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___276;

struct kernfs_elem_dir___276 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___276 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___276;

struct kernfs_root___276 {
	struct kernfs_node___276 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___276 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___276 {
	struct kernfs_node___276 *target_kn;
};

struct kernfs_ops___276;

struct kernfs_elem_attr___276 {
	const struct kernfs_ops___276 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___276 *notify_next;
};

struct kernfs_node___276 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___276 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___276 dir;
		struct kernfs_elem_symlink___276 symlink;
		struct kernfs_elem_attr___276 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___276;

struct kernfs_ops___276 {
	int (*open)(struct kernfs_open_file___276 *);
	void (*release)(struct kernfs_open_file___276 *);
	int (*seq_show)(struct seq_file___263 *, void *);
	void * (*seq_start)(struct seq_file___263 *, loff_t *);
	void * (*seq_next)(struct seq_file___263 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___263 *, void *);
	ssize_t (*read)(struct kernfs_open_file___276 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___276 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___276 *, struct poll_table_struct___209 *);
	int (*mmap)(struct kernfs_open_file___276 *, struct vm_area_struct___293 *);
};

struct kernfs_syscall_ops___276 {
	int (*show_options)(struct seq_file___263 *, struct kernfs_root___276 *);
	int (*mkdir)(struct kernfs_node___276 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___276 *);
	int (*rename)(struct kernfs_node___276 *, struct kernfs_node___276 *, const char *);
	int (*show_path)(struct seq_file___263 *, struct kernfs_node___276 *, struct kernfs_root___276 *);
};

struct kernfs_open_file___276 {
	struct kernfs_node___276 *kn;
	struct file___288 *file;
	struct seq_file___263 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___283 *vm_ops;
};

struct sock___84;

struct kobj_ns_type_operations___84 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___84 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___102 *net;
} possible_net_t___97;

struct proto___84;

struct sock_common___84 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___84 *skc_prot;
	possible_net_t___97 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___84 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___98;

struct sk_buff_head___97 {
	struct sk_buff___98 *next;
	struct sk_buff___98 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___84 {
	struct cgroup___215 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___84;

struct socket_wq___85;

struct xfrm_policy___20;

struct dst_entry___84;

struct socket___86;

struct net_device___97;

struct sock_reuseport___32;

struct sock___84 {
	struct sock_common___84 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___97 sk_error_queue;
	struct sk_buff___98 *sk_rx_skb_cache;
	struct sk_buff_head___97 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___98 *head;
		struct sk_buff___98 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___84 *sk_filter;
	union {
		struct socket_wq___85 *sk_wq;
		struct socket_wq___85 *sk_wq_raw;
	};
	struct xfrm_policy___20 *sk_policy[2];
	struct dst_entry___84 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___84 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___98 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___98 *sk_tx_skb_cache;
	struct sk_buff_head___97 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___293 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___84 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___265 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___86 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___84 sk_cgrp_data;
	struct mem_cgroup___153 *sk_memcg;
	void (*sk_state_change)(struct sock___84 *);
	void (*sk_data_ready)(struct sock___84 *);
	void (*sk_write_space)(struct sock___84 *);
	void (*sk_error_report)(struct sock___84 *);
	int (*sk_backlog_rcv)(struct sock___84 *, struct sk_buff___98 *);
	struct sk_buff___98 * (*sk_validate_xmit_skb)(struct sock___84 *, struct net_device___97 *, struct sk_buff___98 *);
	void (*sk_destruct)(struct sock___84 *);
	struct sock_reuseport___32 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___276;

struct attribute_group___276 {
	const char *name;
	umode_t (*is_visible)(struct kobject___276 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___276 *, struct bin_attribute___276 *, int);
	struct attribute **attrs;
	struct bin_attribute___276 **bin_attrs;
};

struct bin_attribute___276 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___288 * (*f_mapping)();
	ssize_t (*read)(struct file___288 *, struct kobject___276 *, struct bin_attribute___276 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___288 *, struct kobject___276 *, struct bin_attribute___276 *, char *, loff_t, size_t);
	int (*mmap)(struct file___288 *, struct kobject___276 *, struct bin_attribute___276 *, struct vm_area_struct___293 *);
};

struct sysfs_ops___276 {
	ssize_t (*show)(struct kobject___276 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___276 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___276;

struct kset___276 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___276 kobj;
	const struct kset_uevent_ops___276 *uevent_ops;
};

struct kobj_type___276 {
	void (*release)(struct kobject___276 *);
	const struct sysfs_ops___276 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___276 **default_groups;
	const struct kobj_ns_type_operations___84 * (*child_ns_type)(struct kobject___276 *);
	const void * (*namespace)(struct kobject___276 *);
	void (*get_ownership)(struct kobject___276 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___276 {
	int (* const filter)(struct kset___276 *, struct kobject___276 *);
	const char * (* const name)(struct kset___276 *, struct kobject___276 *);
	int (* const uevent)(struct kset___276 *, struct kobject___276 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___272 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___272 *);
	int (*get)(char *, const struct kernel_param___272 *);
	void (*free)(void *);
};

struct kparam_array___272;

struct kernel_param___272 {
	const char *name;
	struct module___272 *mod;
	const struct kernel_param_ops___272 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___272 *arr;
	};
};

struct kparam_array___272 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___272 *ops;
	void *elem;
};

struct module_attribute___272 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___272 *, struct module_kobject___273 *, char *);
	ssize_t (*store)(struct module_attribute___272 *, struct module_kobject___273 *, const char *, size_t);
	void (*setup)(struct module___272 *, const char *);
	int (*test)(struct module___272 *);
	void (*free)(struct module___272 *);
};

struct ip_ra_chain___57;

struct fib_rules_ops___84;

struct fqdir___102;

struct tcp_congestion_ops___30;

struct fib_notifier_ops___84;

struct netns_ipv4___102 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___57 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___84 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___84 *fibnl;
	struct sock___84 **icmp_sk;
	struct sock___84 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___84 **tcp_sk;
	struct fqdir___102 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___30 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___84 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___84 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___84 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___84;

struct dst_ops___102 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___102 *);
	struct dst_entry___84 * (*check)(struct dst_entry___84 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___84 *);
	unsigned int (*mtu)(const struct dst_entry___84 *);
	u32 * (*cow_metrics)(struct dst_entry___84 *, long unsigned int);
	void (*destroy)(struct dst_entry___84 *);
	void (*ifdown)(struct dst_entry___84 *, struct net_device___97 *, int);
	struct dst_entry___84 * (*negative_advice)(struct dst_entry___84 *);
	void (*link_failure)(struct sk_buff___98 *);
	void (*update_pmtu)(struct dst_entry___84 *, struct sock___84 *, struct sk_buff___98 *, u32, bool);
	void (*redirect)(struct dst_entry___84 *, struct sock___84 *, struct sk_buff___98 *);
	int (*local_out)(struct net___102 *, struct sock___84 *, struct sk_buff___98 *);
	struct neighbour___84 * (*neigh_lookup)(const struct dst_entry___84 *, struct sk_buff___98 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___84 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___27;

struct rt6_info___27;

struct fib6_table___27;

struct netns_ipv6___102 {
	struct dst_ops___102 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___102 *fqdir;
	struct fib6_info___27 *fib6_null_entry;
	struct rt6_info___27 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___27 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___27 *ip6_prohibit_entry;
	struct rt6_info___27 *ip6_blk_hole_entry;
	struct fib6_table___27 *fib6_local_tbl;
	struct fib_rules_ops___84 *fib6_rules_ops;
	struct sock___84 **icmp_sk;
	struct sock___84 *ndisc_sk;
	struct sock___84 *tcp_sk;
	struct sock___84 *igmp_sk;
	struct sock___84 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___84 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___84 *notifier_ops;
	struct fib_notifier_ops___84 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___102 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___102 *fqdir;
};

struct netns_sctp___84 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___84 *ctl_sock;
	struct sock___84 *udp4_sock;
	struct sock___84 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___91;

struct netns_bpf___91 {
	struct bpf_prog_array___91 *run_array[2];
	struct bpf_prog___91 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___102 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___84 *nlsk;
	struct sock___84 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___102 xfrm4_dst_ops;
	struct dst_ops___102 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___102 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___84 *rtnl;
	struct sock___84 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___97 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___102 ipv4;
	struct netns_ipv6___102 ipv6;
	struct netns_ieee802154_lowpan___102 ieee802154_lowpan;
	struct netns_sctp___84 sctp;
	struct netns_nf___18 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___97 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___91 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___102 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___84 *crypto_nlsk;
	struct sock___84 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___215 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___215 *root_cset;
};

struct msghdr___86 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___208 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___288 *msg_iocb;
};

struct socket_wq___85 {
	wait_queue_head_t wait;
	struct fasync_struct___288 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___85;

struct socket___86 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___288 *file;
	struct sock___84 *sk;
	const struct proto_ops___85 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___85 wq;
};

typedef int (*sk_read_actor_t___84)(read_descriptor_t *, struct sk_buff___98 *, unsigned int, size_t);

struct proto_ops___85 {
	int family;
	struct module___272 *owner;
	int (*release)(struct socket___86 *);
	int (*bind)(struct socket___86 *, struct sockaddr *, int);
	int (*connect)(struct socket___86 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___86 *, struct socket___86 *);
	int (*accept)(struct socket___86 *, struct socket___86 *, int, bool);
	int (*getname)(struct socket___86 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___288 *, struct socket___86 *, struct poll_table_struct___209 *);
	int (*ioctl)(struct socket___86 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___86 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___86 *, void *, bool, bool);
	int (*listen)(struct socket___86 *, int);
	int (*shutdown)(struct socket___86 *, int);
	int (*setsockopt)(struct socket___86 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___86 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___263 *, struct socket___86 *);
	int (*sendmsg)(struct socket___86 *, struct msghdr___86 *, size_t);
	int (*recvmsg)(struct socket___86 *, struct msghdr___86 *, size_t, int);
	int (*mmap)(struct file___288 *, struct socket___86 *, struct vm_area_struct___293 *);
	ssize_t (*sendpage)(struct socket___86 *, struct page___293 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___86 *, loff_t *, struct pipe_inode_info___129 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___84 *, int);
	int (*peek_len)(struct socket___86 *);
	int (*read_sock)(struct sock___84 *, read_descriptor_t *, sk_read_actor_t___84);
	int (*sendpage_locked)(struct sock___84 *, struct page___293 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___84 *, struct msghdr___86 *, size_t);
	int (*set_rcvlowat)(struct sock___84 *, int);
};

struct sk_buff___98 {
	union {
		struct {
			struct sk_buff___98 *next;
			struct sk_buff___98 *prev;
			union {
				struct net_device___97 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___84 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___98 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___269 {
	int (*prepare)(struct device___269 *);
	void (*complete)(struct device___269 *);
	int (*suspend)(struct device___269 *);
	int (*resume)(struct device___269 *);
	int (*freeze)(struct device___269 *);
	int (*thaw)(struct device___269 *);
	int (*poweroff)(struct device___269 *);
	int (*restore)(struct device___269 *);
	int (*suspend_late)(struct device___269 *);
	int (*resume_early)(struct device___269 *);
	int (*freeze_late)(struct device___269 *);
	int (*thaw_early)(struct device___269 *);
	int (*poweroff_late)(struct device___269 *);
	int (*restore_early)(struct device___269 *);
	int (*suspend_noirq)(struct device___269 *);
	int (*resume_noirq)(struct device___269 *);
	int (*freeze_noirq)(struct device___269 *);
	int (*thaw_noirq)(struct device___269 *);
	int (*poweroff_noirq)(struct device___269 *);
	int (*restore_noirq)(struct device___269 *);
	int (*runtime_suspend)(struct device___269 *);
	int (*runtime_resume)(struct device___269 *);
	int (*runtime_idle)(struct device___269 *);
};

struct wakeup_source___269 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___269 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___269 {
	struct dev_pm_ops___269 ops;
	int (*start)(struct device___269 *);
	void (*detach)(struct device___269 *, bool);
	int (*activate)(struct device___269 *);
	void (*sync)(struct device___269 *);
	void (*dismiss)(struct device___269 *);
};

struct bus_type___269 {
	const char *name;
	const char *dev_name;
	struct device___269 *dev_root;
	const struct attribute_group___276 **bus_groups;
	const struct attribute_group___276 **dev_groups;
	const struct attribute_group___276 **drv_groups;
	int (*match)(struct device___269 *, struct device_driver___269 *);
	int (*uevent)(struct device___269 *, struct kobj_uevent_env *);
	int (*probe)(struct device___269 *);
	void (*sync_state)(struct device___269 *);
	void (*remove)(struct device___269 *);
	void (*shutdown)(struct device___269 *);
	int (*online)(struct device___269 *);
	int (*offline)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	int (*num_vf)(struct device___269 *);
	int (*dma_configure)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___269 {
	const char *name;
	struct bus_type___269 *bus;
	struct module___272 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___269 *);
	void (*sync_state)(struct device___269 *);
	int (*remove)(struct device___269 *);
	void (*shutdown)(struct device___269 *);
	int (*suspend)(struct device___269 *, pm_message_t);
	int (*resume)(struct device___269 *);
	const struct attribute_group___276 **groups;
	const struct attribute_group___276 **dev_groups;
	const struct dev_pm_ops___269 *pm;
	void (*coredump)(struct device___269 *);
	struct driver_private *p;
};

struct device_type___269 {
	const char *name;
	const struct attribute_group___276 **groups;
	int (*uevent)(struct device___269 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___269 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___269 *);
	const struct dev_pm_ops___269 *pm;
};

struct class___269 {
	const char *name;
	struct module___272 *owner;
	const struct attribute_group___276 **class_groups;
	const struct attribute_group___276 **dev_groups;
	struct kobject___276 *dev_kobj;
	int (*dev_uevent)(struct device___269 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___269 *, umode_t *);
	void (*class_release)(struct class___269 *);
	void (*dev_release)(struct device___269 *);
	int (*shutdown_pre)(struct device___269 *);
	const struct kobj_ns_type_operations___84 *ns_type;
	const void * (*namespace)(struct device___269 *);
	void (*get_ownership)(struct device___269 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___269 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___129;

struct pipe_buffer___129 {
	struct page___293 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___129 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___129 {
	int (*confirm)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
	void (*release)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
	bool (*try_steal)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
	bool (*get)(struct pipe_inode_info___129 *, struct pipe_buffer___129 *);
};

typedef rx_handler_result_t rx_handler_func_t___97(struct sk_buff___98 **);

struct bpf_xdp_entity___91 {
	struct bpf_prog___91 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___97;

struct net_device_ops___97;

struct l3mdev_ops___84;

struct ndisc_ops___66;

struct xfrmdev_ops___97;

struct header_ops___97;

struct inet6_dev___66;

struct netdev_rx_queue___97;

struct mini_Qdisc___91;

struct netdev_queue___97;

struct Qdisc___91;

struct rtnl_link_ops___91;

struct dcbnl_rtnl_ops___97;

struct net_device___97 {
	char name[16];
	struct netdev_name_node___97 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___97 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___84 *l3mdev_ops;
	const struct ndisc_ops___66 *ndisc_ops;
	const struct xfrmdev_ops___97 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___97 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___276 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___66 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___97 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___91 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___97 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___91 *miniq_ingress;
	struct netdev_queue___97 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___97 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___91 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___91 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___97 = 0,
		NETREG_REGISTERED___97 = 1,
		NETREG_UNREGISTERING___97 = 2,
		NETREG_UNREGISTERED___97 = 3,
		NETREG_RELEASED___97 = 4,
		NETREG_DUMMY___97 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___97 = 0,
		RTNL_LINK_INITIALIZING___97 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___97 *);
	struct netpoll_info *npinfo;
	possible_net_t___97 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___269 dev;
	const struct attribute_group___276 *sysfs_groups[4];
	const struct attribute_group___276 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___91 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___97 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___91 xdp_state[3];
	long: 64;
};

struct inet_frags___102;

struct fqdir___102 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___102 *f;
	struct net___102 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___102;

struct inet_frags___102 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___102 *, const void *);
	void (*destructor)(struct inet_frag_queue___102 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___102 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___98 *fragments_tail;
	struct sk_buff___98 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___102 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___57 {
	struct ip_ra_chain___57 *next;
	struct sock___84 *sk;
	union {
		void (*destructor)(struct sock___84 *);
		struct sock___84 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___84;

struct fib_lookup_arg___84;

struct fib_rules_ops___84 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___84 *, struct flowi *, int, struct fib_lookup_arg___84 *);
	bool (*suppress)(struct fib_rule___84 *, int, struct fib_lookup_arg___84 *);
	int (*match)(struct fib_rule___84 *, struct flowi *, int);
	int (*configure)(struct fib_rule___84 *, struct sk_buff___98 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___84 *);
	int (*compare)(struct fib_rule___84 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___84 *, struct sk_buff___98 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___84 *);
	void (*flush_cache)(struct fib_rules_ops___84 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___272 *owner;
	struct net___102 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___30 {
	u32 (*ssthresh)(struct sock___84 *);
	void (*cong_avoid)(struct sock___84 *, u32, u32);
	void (*set_state)(struct sock___84 *, u8);
	void (*cwnd_event)(struct sock___84 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___84 *, u32);
	void (*pkts_acked)(struct sock___84 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___84 *);
	void (*cong_control)(struct sock___84 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___84 *);
	u32 (*sndbuf_expand)(struct sock___84 *);
	size_t (*get_info)(struct sock___84 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___272 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___84 *);
	void (*release)(struct sock___84 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___84 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___102 *);
	int (*fib_dump)(struct net___102 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___272 *owner;
	struct callback_head rcu;
};

struct xfrm_state___20;

struct lwtunnel_state___60;

struct dst_entry___84 {
	struct net_device___97 *dev;
	struct dst_ops___102 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___20 *xfrm;
	int (*input)(struct sk_buff___98 *);
	int (*output)(struct net___102 *, struct sock___84 *, struct sk_buff___98 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___60 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___84;

struct neigh_parms___84;

struct neigh_ops___84;

struct neighbour___84 {
	struct neighbour___84 *next;
	struct neigh_table___84 *tbl;
	struct neigh_parms___84 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___97 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___84 *, struct sk_buff___98 *);
	const struct neigh_ops___84 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___97 *dev;
	u8 primary_key[0];
};

struct rtable___29;

struct fnhe_hash_bucket___27;

struct fib_nh_common___27 {
	struct net_device___97 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___60 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___29 **nhc_pcpu_rth_output;
	struct rtable___29 *nhc_rth_input;
	struct fnhe_hash_bucket___27 *nhc_exceptions;
};

struct fib6_nh___27 {
	struct fib_nh_common___27 nh_common;
	long unsigned int last_probe;
	struct rt6_info___27 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___27;

struct fib6_info___27 {
	struct fib6_table___27 *fib6_table;
	struct fib6_info___27 *fib6_next;
	struct fib6_node___27 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop *nh;
	struct fib6_nh___27 fib6_nh[0];
};

struct rt6_info___27 {
	struct dst_entry___84 dst;
	struct fib6_info___27 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___66 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___27 {
	struct fib6_node___27 *parent;
	struct fib6_node___27 *left;
	struct fib6_node___27 *right;
	struct fib6_node___27 *subtree;
	struct fib6_info___27 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___27 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___27 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___27 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___91 {
	struct bpf_prog___91 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___91 {
	struct callback_head rcu;
	struct bpf_prog_array_item___91 items[0];
};

struct bpf_prog_aux___100;

struct bpf_prog___91 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___100 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___263 {
	void * (*start)(struct seq_file___263 *, loff_t *);
	void (*stop)(struct seq_file___263 *, void *);
	void * (*next)(struct seq_file___263 *, void *, loff_t *);
	int (*show)(struct seq_file___263 *, void *);
};

struct dcbnl_rtnl_ops___97 {
	int (*ieee_getets)(struct net_device___97 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___97 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___97 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___97 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___97 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___97 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___97 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___97 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___97 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___97 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___97 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___97 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___97 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___97 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___97 *);
	u8 (*setstate)(struct net_device___97 *, u8);
	void (*getpermhwaddr)(struct net_device___97 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___97 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___97 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___97 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___97 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___97 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___97 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___97 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___97 *, int, u8 *);
	void (*setpfccfg)(struct net_device___97 *, int, u8);
	void (*getpfccfg)(struct net_device___97 *, int, u8 *);
	u8 (*setall)(struct net_device___97 *);
	u8 (*getcap)(struct net_device___97 *, int, u8 *);
	int (*getnumtcs)(struct net_device___97 *, int, u8 *);
	int (*setnumtcs)(struct net_device___97 *, int, u8);
	u8 (*getpfcstate)(struct net_device___97 *);
	void (*setpfcstate)(struct net_device___97 *, u8);
	void (*getbcncfg)(struct net_device___97 *, int, u32 *);
	void (*setbcncfg)(struct net_device___97 *, int, u32);
	void (*getbcnrp)(struct net_device___97 *, int, u8 *);
	void (*setbcnrp)(struct net_device___97 *, int, u8);
	int (*setapp)(struct net_device___97 *, u8, u16, u8);
	int (*getapp)(struct net_device___97 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___97 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___97 *, int, u8);
	u8 (*getdcbx)(struct net_device___97 *);
	u8 (*setdcbx)(struct net_device___97 *, u8);
	int (*peer_getappinfo)(struct net_device___97 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___97 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___97 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___97 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___97 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___97 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___100;

typedef int (*bpf_iter_init_seq_priv_t___99)(void *, struct bpf_iter_aux_info___100 *);

struct bpf_map___100;

struct bpf_iter_aux_info___100 {
	struct bpf_map___100 *map;
};

struct bpf_iter_seq_info___99 {
	const struct seq_operations___263 *seq_ops;
	bpf_iter_init_seq_priv_t___99 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___99 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___100 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___100 *, struct file___288 *);
	void (*map_free)(struct bpf_map___100 *);
	int (*map_get_next_key)(struct bpf_map___100 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___100 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___100 *, void *);
	int (*map_lookup_batch)(struct bpf_map___100 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___100 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___100 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___100 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___100 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___100 *, void *);
	int (*map_update_elem)(struct bpf_map___100 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___100 *, void *);
	int (*map_push_elem)(struct bpf_map___100 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___100 *, void *);
	int (*map_peek_elem)(struct bpf_map___100 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___100 *, struct file___288 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___100 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___100 *, void *, struct seq_file___263 *);
	int (*map_check_btf)(const struct bpf_map___100 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___100 *, struct bpf_prog_aux___100 *);
	void (*map_poke_untrack)(struct bpf_map___100 *, struct bpf_prog_aux___100 *);
	void (*map_poke_run)(struct bpf_map___100 *, u32, struct bpf_prog___91 *, struct bpf_prog___91 *);
	int (*map_direct_value_addr)(const struct bpf_map___100 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___100 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___100 *, struct vm_area_struct___293 *);
	__poll_t (*map_poll)(struct bpf_map___100 *, struct file___288 *, struct poll_table_struct___209 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___100 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___100 *, const struct bpf_map___100 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___100 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___99 *iter_seq_info;
};

struct bpf_map___100 {
	const struct bpf_map_ops___99 *ops;
	struct bpf_map___100 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___153 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___99;

struct bpf_jit_poke_descriptor___99;

struct bpf_prog_ops___91;

struct btf_mod_pair___99;

struct bpf_prog_offload___97;

struct bpf_prog_aux___100 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___91 *dst_prog;
	struct bpf_trampoline___99 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___91 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___99 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___91 *ops;
	struct bpf_map___100 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___99 *used_btfs;
	struct bpf_prog___91 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___100 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___97 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___97;

struct bpf_map_dev_ops___97 {
	int (*map_get_next_key)(struct bpf_offloaded_map___97 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___97 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___97 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___97 *, void *);
};

struct bpf_offloaded_map___97 {
	struct bpf_map___100 map;
	struct net_device___97 *netdev;
	const struct bpf_map_dev_ops___97 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___91 {
	int (*test_run)(struct bpf_prog___91 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___97 {
	struct bpf_prog___91 *prog;
	struct net_device___97 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___99 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___91 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___272 *mod;
};

struct bpf_jit_poke_descriptor___99 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___100 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___99 {
	struct btf *btf;
	struct module___272 *module;
};

struct cftype___215;

struct cgroup_subsys___215 {
	struct cgroup_subsys_state___215 * (*css_alloc)(struct cgroup_subsys_state___215 *);
	int (*css_online)(struct cgroup_subsys_state___215 *);
	void (*css_offline)(struct cgroup_subsys_state___215 *);
	void (*css_released)(struct cgroup_subsys_state___215 *);
	void (*css_free)(struct cgroup_subsys_state___215 *);
	void (*css_reset)(struct cgroup_subsys_state___215 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___215 *, int);
	int (*css_extra_stat_show)(struct seq_file___263 *, struct cgroup_subsys_state___215 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___295 *, struct css_set___215 *);
	void (*cancel_fork)(struct task_struct___295 *, struct css_set___215 *);
	void (*fork)(struct task_struct___295 *);
	void (*exit)(struct task_struct___295 *);
	void (*release)(struct task_struct___295 *);
	void (*bind)(struct cgroup_subsys_state___215 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___215 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___215 *dfl_cftypes;
	struct cftype___215 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___215 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___215 *updated_children;
	struct cgroup___215 *updated_next;
};

struct cgroup_root___215 {
	struct kernfs_root___276 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___215 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___215 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___215 *ss;
	struct list_head node;
	struct kernfs_ops___276 *kf_ops;
	int (*open)(struct kernfs_open_file___276 *);
	void (*release)(struct kernfs_open_file___276 *);
	u64 (*read_u64)(struct cgroup_subsys_state___215 *, struct cftype___215 *);
	s64 (*read_s64)(struct cgroup_subsys_state___215 *, struct cftype___215 *);
	int (*seq_show)(struct seq_file___263 *, void *);
	void * (*seq_start)(struct seq_file___263 *, loff_t *);
	void * (*seq_next)(struct seq_file___263 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___263 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___215 *, struct cftype___215 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___215 *, struct cftype___215 *, s64);
	ssize_t (*write)(struct kernfs_open_file___276 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___276 *, struct poll_table_struct___209 *);
};

struct xdp_rxq_info___97 {
	struct net_device___97 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___97 {
	struct net_device___97 *dev;
};

struct xdp_buff___97 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___97 *rxq;
	struct xdp_txq_info___97 *txq;
	u32 frame_sz;
};

struct xdp_frame___97 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___97 *dev_rx;
};

struct netlink_callback___97 {
	struct sk_buff___98 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___98 *, struct netlink_callback___97 *);
	int (*done)(struct netlink_callback___97 *);
	void *data;
	struct module___272 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___97 {
	int (*create)(struct sk_buff___98 *, struct net_device___97 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___98 *, unsigned char *);
	int (*cache)(const struct neighbour___84 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___97 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___98 *);
};

struct netdev_queue___97 {
	struct net_device___97 *dev;
	struct Qdisc___91 *qdisc;
	struct Qdisc___91 *qdisc_sleeping;
	struct kobject___276 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___97 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___91 {
	struct sk_buff___98 *head;
	struct sk_buff___98 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___91;

struct Qdisc___91 {
	int (*enqueue)(struct sk_buff___98 *, struct Qdisc___91 *, struct sk_buff___98 **);
	struct sk_buff___98 * (*dequeue)(struct Qdisc___91 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___91 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___97 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___97 gso_skb;
	struct qdisc_skb_head___91 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___91 *next_sched;
	struct sk_buff_head___97 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___97 {
	struct xdp_rxq_info___97 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___276 kobj;
	struct net_device___97 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___97 {
	enum net_device_path_type type;
	const struct net_device___97 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___97 = 0,
				DEV_PATH_BR_VLAN_TAG___97 = 1,
				DEV_PATH_BR_VLAN_UNTAG___97 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___97 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___97 {
	const struct net_device___97 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___97 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___91 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___97 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___97 {
	int (*xdo_dev_state_add)(struct xfrm_state___20 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___20 *);
	void (*xdo_dev_state_free)(struct xfrm_state___20 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___98 *, struct xfrm_state___20 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___20 *);
};

struct xfrm_state_offload___20 {
	struct net_device___97 *dev;
	struct net_device___97 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___20;

struct xfrm_type_offload___20;

struct xfrm_state___20 {
	possible_net_t___97 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	long: 64;
	long: 64;
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___84 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___20 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___20 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___293 xfrag;
	const struct xfrm_type___20 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___20 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___97 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___97 *dev;
	const char *name;
};

struct net_device_ops___97 {
	int (*ndo_init)(struct net_device___97 *);
	void (*ndo_uninit)(struct net_device___97 *);
	int (*ndo_open)(struct net_device___97 *);
	int (*ndo_stop)(struct net_device___97 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___98 *, struct net_device___97 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___98 *, struct net_device___97 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___97 *, struct sk_buff___98 *, struct net_device___97 *);
	void (*ndo_change_rx_flags)(struct net_device___97 *, int);
	void (*ndo_set_rx_mode)(struct net_device___97 *);
	int (*ndo_set_mac_address)(struct net_device___97 *, void *);
	int (*ndo_validate_addr)(struct net_device___97 *);
	int (*ndo_do_ioctl)(struct net_device___97 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___97 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___97 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___97 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___97 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___97 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___97 *, int);
	int (*ndo_neigh_setup)(struct net_device___97 *, struct neigh_parms___84 *);
	void (*ndo_tx_timeout)(struct net_device___97 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___97 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___97 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___97 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___97 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___97 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___97 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___97 *);
	int (*ndo_netpoll_setup)(struct net_device___97 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___97 *);
	int (*ndo_set_vf_mac)(struct net_device___97 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___97 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___97 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___97 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___97 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___97 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___97 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___97 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___97 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___97 *, int, struct sk_buff___98 *);
	int (*ndo_get_vf_guid)(struct net_device___97 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___97 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___97 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___97 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___97 *);
	int (*ndo_fcoe_disable)(struct net_device___97 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___97 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___97 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___97 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___97 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___97 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___97 *, const struct sk_buff___98 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___97 *, struct net_device___97 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___97 *, struct net_device___97 *);
	struct net_device___97 * (*ndo_get_xmit_slave)(struct net_device___97 *, struct sk_buff___98 *, bool);
	struct net_device___97 * (*ndo_sk_get_lower_dev)(struct net_device___97 *, struct sock___84 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___97 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___97 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___97 *, struct neighbour___84 *);
	void (*ndo_neigh_destroy)(struct net_device___97 *, struct neighbour___84 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___97 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___97 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___98 *, struct netlink_callback___97 *, struct net_device___97 *, struct net_device___97 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___98 *, struct nlattr **, struct net_device___97 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___97 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___98 *, u32, u32, struct net_device___97 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___97 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___97 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___97 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___97 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___97 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___97 *, struct net_device___97 *);
	void (*ndo_dfwd_del_station)(struct net_device___97 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___97 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___97 *);
	int (*ndo_change_proto_down)(struct net_device___97 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___97 *, struct sk_buff___98 *);
	void (*ndo_set_rx_headroom)(struct net_device___97 *, int);
	int (*ndo_bpf)(struct net_device___97 *, struct netdev_bpf___97 *);
	int (*ndo_xdp_xmit)(struct net_device___97 *, int, struct xdp_frame___97 **, u32);
	struct net_device___97 * (*ndo_xdp_get_xmit_slave)(struct net_device___97 *, struct xdp_buff___97 *);
	int (*ndo_xsk_wakeup)(struct net_device___97 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___97 *);
	int (*ndo_tunnel_ctl)(struct net_device___97 *, struct ip_tunnel_parm *, int);
	struct net_device___97 * (*ndo_get_peer_dev)(struct net_device___97 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___97 *, struct net_device_path___97 *);
};

struct neigh_parms___84 {
	possible_net_t___97 net;
	struct net_device___97 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___84 *);
	struct neigh_table___84 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___84 {
	u32 (*l3mdev_fib_table)(const struct net_device___97 *);
	struct sk_buff___98 * (*l3mdev_l3_rcv)(struct net_device___97 *, struct sk_buff___98 *, u16);
	struct sk_buff___98 * (*l3mdev_l3_out)(struct net_device___97 *, struct sock___84 *, struct sk_buff___98 *, u16);
	struct dst_entry___84 * (*l3mdev_link_scope_lookup)(const struct net_device___97 *, struct flowi6 *);
};

struct ndisc_ops___66 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___97 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___97 *, struct neighbour___84 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___97 *, u8, struct neighbour___84 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___97 *, struct sk_buff___98 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___102 *, struct net_device___97 *, const struct prefix_info *, struct inet6_dev___66 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___66;

struct ifacaddr6___27;

struct inet6_dev___66 {
	struct net_device___97 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___66 *mc_list;
	struct ifmcaddr6___66 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___97 mc_query_queue;
	struct sk_buff_head___97 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___27 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___84 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___91;

struct tcf_block___91;

struct mini_Qdisc___91 {
	struct tcf_proto___91 *filter_list;
	struct tcf_block___91 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___91 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___97 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___97 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___102 *, struct net_device___97 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___97 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___97 *, struct list_head *);
	size_t (*get_size)(const struct net_device___97 *);
	int (*fill_info)(struct sk_buff___98 *, const struct net_device___97 *);
	size_t (*get_xstats_size)(const struct net_device___97 *);
	int (*fill_xstats)(struct sk_buff___98 *, const struct net_device___97 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___97 *, struct net_device___97 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___97 *, const struct net_device___97 *);
	int (*fill_slave_info)(struct sk_buff___98 *, const struct net_device___97 *, const struct net_device___97 *);
	struct net___102 * (*get_link_net)(const struct net_device___97 *);
	size_t (*get_linkxstats_size)(const struct net_device___97 *, int);
	int (*fill_linkxstats)(struct sk_buff___98 *, const struct net_device___97 *, int *, int);
};

struct block_device_operations___179;

struct gendisk___182 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___182 *part0;
	const struct block_device_operations___179 *fops;
	struct request_queue___179 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___165 *bdi;
	struct kobject___276 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___276 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___179 {
	struct bio___179 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___205 *bip_vec;
	struct bio_vec___205 bip_inline_vecs[0];
};

struct blkcg___167;

struct blkg_policy_data___167;

struct blkcg_gq___167 {
	struct request_queue___179 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___167 *blkcg;
	struct blkcg_gq___167 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___167 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___179 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___179(struct request___179 *);

typedef void integrity_complete_fn___179(struct request___179 *, unsigned int);

struct blk_integrity_profile___179 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___179 *prepare_fn;
	integrity_complete_fn___179 *complete_fn;
	const char *name;
};

struct block_device_operations___179 {
	blk_qc_t (*submit_bio)(struct bio___179 *);
	int (*open)(struct block_device___182 *, fmode_t);
	void (*release)(struct gendisk___182 *, fmode_t);
	int (*rw_page)(struct block_device___182 *, sector_t, struct page___293 *, unsigned int);
	int (*ioctl)(struct block_device___182 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___182 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___182 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___182 *);
	int (*getgeo)(struct block_device___182 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___182 *, bool);
	void (*swap_slot_free_notify)(struct block_device___182 *, long unsigned int);
	int (*report_zones)(struct gendisk___182 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___182 *, umode_t *);
	struct module___272 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___182 *, sector_t *);
};

typedef void rq_end_io_fn___179(struct request___179 *, blk_status_t);

struct request___179 {
	struct request_queue___179 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___174 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___179 *bio;
	struct bio___179 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___205 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___179 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___179 *saved_end_io;
		} flush;
	};
	struct gendisk___182 *rq_disk;
	struct block_device___182 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___179 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___174 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___179 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___276 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___288 *debugfs_dir;
	struct dentry___288 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___179;

struct elevator_mq_ops___179 {
	int (*init_sched)(struct request_queue___179 *, struct elevator_type___179 *);
	void (*exit_sched)(struct elevator_queue___179 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___174 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___174 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___174 *);
	bool (*allow_merge)(struct request_queue___179 *, struct request___179 *, struct bio___179 *);
	bool (*bio_merge)(struct request_queue___179 *, struct bio___179 *, unsigned int);
	int (*request_merge)(struct request_queue___179 *, struct request___179 **, struct bio___179 *);
	void (*request_merged)(struct request_queue___179 *, struct request___179 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___179 *, struct request___179 *, struct request___179 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___179 *);
	void (*finish_request)(struct request___179 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___174 *, struct list_head *, bool);
	struct request___179 * (*dispatch_request)(struct blk_mq_hw_ctx___174 *);
	bool (*has_work)(struct blk_mq_hw_ctx___174 *);
	void (*completed_request)(struct request___179 *, u64);
	void (*requeue_request)(struct request___179 *);
	struct request___179 * (*former_request)(struct request_queue___179 *, struct request___179 *);
	struct request___179 * (*next_request)(struct request_queue___179 *, struct request___179 *);
	void (*init_icq)(struct io_cq___179 *);
	void (*exit_icq)(struct io_cq___179 *);
};

struct elv_fs_entry___179;

struct elevator_type___179 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___179 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___179 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___272 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___179 {
	struct elevator_type___179 *type;
	void *elevator_data;
	struct kobject___276 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___179 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___179 *, char *);
	ssize_t (*store)(struct elevator_queue___179 *, const char *, size_t);
};

struct blk_mq_queue_data___174;

struct blk_mq_ops___174 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___174 *, const struct blk_mq_queue_data___174 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___174 *);
	int (*get_budget)(struct request_queue___179 *);
	void (*put_budget)(struct request_queue___179 *, int);
	void (*set_rq_budget_token)(struct request___179 *, int);
	int (*get_rq_budget_token)(struct request___179 *);
	enum blk_eh_timer_return (*timeout)(struct request___179 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___174 *);
	void (*complete)(struct request___179 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___174 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___174 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___174 *, struct request___179 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___174 *, struct request___179 *, unsigned int);
	void (*initialize_rq_fn)(struct request___179 *);
	void (*cleanup_rq)(struct request___179 *);
	bool (*busy)(struct request_queue___179 *);
	int (*map_queues)(struct blk_mq_tag_set___174 *);
	void (*show_rq)(struct seq_file___263 *, struct request___179 *);
};

struct blk_mq_tag_set___174 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___174 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___174 {
	struct request___179 *rq;
	bool last;
};

struct blkcg_policy_data___167;

struct blkcg___167 {
	struct cgroup_subsys_state___215 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___167 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___167 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___167 {
	struct blkcg___167 *blkcg;
	int plid;
};

struct blkg_policy_data___167 {
	struct blkcg_gq___167 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___153 {
	struct mem_cgroup___153 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___153 {
	struct lruvec___161 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___153 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___153 *memcg;
};

struct obj_cgroup___153 {
	struct percpu_ref refcnt;
	struct mem_cgroup___153 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___91 {
	spinlock_t *lock;
	struct sk_buff___98 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___9 {
	struct nlmsghdr *nlh;
	struct net___102 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct Qdisc_class_ops___91;

struct Qdisc_ops___91 {
	struct Qdisc_ops___91 *next;
	const struct Qdisc_class_ops___91 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___98 *, struct Qdisc___91 *, struct sk_buff___98 **);
	struct sk_buff___98 * (*dequeue)(struct Qdisc___91 *);
	struct sk_buff___98 * (*peek)(struct Qdisc___91 *);
	int (*init)(struct Qdisc___91 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___91 *);
	void (*destroy)(struct Qdisc___91 *);
	int (*change)(struct Qdisc___91 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___91 *);
	int (*change_tx_queue_len)(struct Qdisc___91 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___91 *, unsigned int);
	int (*dump)(struct Qdisc___91 *, struct sk_buff___98 *);
	int (*dump_stats)(struct Qdisc___91 *, struct gnet_dump___91 *);
	void (*ingress_block_set)(struct Qdisc___91 *, u32);
	void (*egress_block_set)(struct Qdisc___91 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___91 *);
	u32 (*egress_block_get)(struct Qdisc___91 *);
	struct module___272 *owner;
};

struct Qdisc_class_ops___91 {
	unsigned int flags;
	struct netdev_queue___97 * (*select_queue)(struct Qdisc___91 *, struct tcmsg *);
	int (*graft)(struct Qdisc___91 *, long unsigned int, struct Qdisc___91 *, struct Qdisc___91 **, struct netlink_ext_ack *);
	struct Qdisc___91 * (*leaf)(struct Qdisc___91 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___91 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___91 *, u32);
	int (*change)(struct Qdisc___91 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___91 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___91 *, struct qdisc_walker *);
	struct tcf_block___91 * (*tcf_block)(struct Qdisc___91 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___91 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___91 *, long unsigned int);
	int (*dump)(struct Qdisc___91 *, long unsigned int, struct sk_buff___98 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___91 *, long unsigned int, struct gnet_dump___91 *);
};

struct tcf_chain___91;

struct tcf_block___91 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___102 *net;
	struct Qdisc___91 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___91 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___91;

struct tcf_proto_ops___91;

struct tcf_proto___91 {
	struct tcf_proto___91 *next;
	void *root;
	int (*classify)(struct sk_buff___98 *, const struct tcf_proto___91 *, struct tcf_result___91 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___91 *ops;
	struct tcf_chain___91 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___91 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___91 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___91 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___98 *, const struct tcf_proto___91 *, struct tcf_result___91 *);
	int (*init)(struct tcf_proto___91 *);
	void (*destroy)(struct tcf_proto___91 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___91 *, u32);
	void (*put)(struct tcf_proto___91 *, void *);
	int (*change)(struct net___102 *, struct sk_buff___98 *, struct tcf_proto___91 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___91 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___91 *);
	void (*walk)(struct tcf_proto___91 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___91 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___91 *, void *);
	void (*hw_del)(struct tcf_proto___91 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___102 *, struct tcf_chain___91 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___102 *, struct tcf_proto___91 *, void *, struct sk_buff___98 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___102 *, struct tcf_proto___91 *, void *, struct sk_buff___98 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___98 *, struct net___102 *, void *);
	struct module___272 *owner;
	int flags;
};

struct tcf_chain___91 {
	struct mutex filter_chain_lock;
	struct tcf_proto___91 *filter_chain;
	struct list_head list;
	struct tcf_block___91 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___91 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___84 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___91 *prog;
};

typedef struct poll_table_struct___209 poll_table___52;

struct pneigh_entry___84;

struct neigh_hash_table___84;

struct neigh_table___84 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___97 *, __u32 *);
	bool (*key_eq)(const struct neighbour___84 *, const void *);
	int (*constructor)(struct neighbour___84 *);
	int (*pconstructor)(struct pneigh_entry___84 *);
	void (*pdestructor)(struct pneigh_entry___84 *);
	void (*proxy_redo)(struct sk_buff___98 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___97 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___84 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___97 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___84 *nht;
	struct pneigh_entry___84 **phash_buckets;
};

struct neigh_ops___84 {
	int family;
	void (*solicit)(struct neighbour___84 *, struct sk_buff___98 *);
	void (*error_report)(struct neighbour___84 *, struct sk_buff___98 *);
	int (*output)(struct neighbour___84 *, struct sk_buff___98 *);
	int (*connected_output)(struct neighbour___84 *, struct sk_buff___98 *);
};

struct pneigh_entry___84 {
	struct pneigh_entry___84 *next;
	possible_net_t___97 net;
	struct net_device___97 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___84 {
	struct neighbour___84 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___60 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___102 *, struct sock___84 *, struct sk_buff___98 *);
	int (*orig_input)(struct sk_buff___98 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___84 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___84 *ctarget;
	struct net___102 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___84 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___84 *rule;
	u32 table;
	int flags;
};

struct sk_psock___5;

struct request_sock_ops___69;

struct timewait_sock_ops___68;

struct proto___84 {
	void (*close)(struct sock___84 *, long int);
	int (*pre_connect)(struct sock___84 *, struct sockaddr *, int);
	int (*connect)(struct sock___84 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___84 *, int);
	struct sock___84 * (*accept)(struct sock___84 *, int, int *, bool);
	int (*ioctl)(struct sock___84 *, int, long unsigned int);
	int (*init)(struct sock___84 *);
	void (*destroy)(struct sock___84 *);
	void (*shutdown)(struct sock___84 *, int);
	int (*setsockopt)(struct sock___84 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___84 *, int, int, char *, int *);
	void (*keepalive)(struct sock___84 *, int);
	int (*compat_ioctl)(struct sock___84 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___84 *, struct msghdr___86 *, size_t);
	int (*recvmsg)(struct sock___84 *, struct msghdr___86 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___84 *, struct page___293 *, int, size_t, int);
	int (*bind)(struct sock___84 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___84 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___84 *, struct sk_buff___98 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___84 *);
	int (*hash)(struct sock___84 *);
	void (*unhash)(struct sock___84 *);
	void (*rehash)(struct sock___84 *);
	int (*get_port)(struct sock___84 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___84 *, struct sk_psock___5 *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___84 *, int);
	bool (*sock_is_readable)(struct sock___84 *);
	void (*enter_memory_pressure)(struct sock___84 *);
	void (*leave_memory_pressure)(struct sock___84 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___69 *rsk_prot;
	struct timewait_sock_ops___68 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___272 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___84 *, int);
};

struct xfrm_policy_queue___20 {
	struct sk_buff_head___97 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___20 {
	possible_net_t___97 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___20 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___32 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___91 *prog;
	struct sock___84 *socks[0];
};

struct sk_psock_progs___5 {
	struct bpf_prog___91 *msg_parser;
	struct bpf_prog___91 *stream_parser;
	struct bpf_prog___91 *stream_verdict;
	struct bpf_prog___91 *skb_verdict;
};

struct strparser___5;

struct strp_callbacks___5 {
	int (*parse_msg)(struct strparser___5 *, struct sk_buff___98 *);
	void (*rcv_msg)(struct strparser___5 *, struct sk_buff___98 *);
	int (*read_sock_done)(struct strparser___5 *, int);
	void (*abort_parser)(struct strparser___5 *, int);
	void (*lock)(struct strparser___5 *);
	void (*unlock)(struct strparser___5 *);
};

struct strparser___5 {
	struct sock___84 *sk;
	u32 stopped: 1;
	u32 paused: 1;
	u32 aborted: 1;
	u32 interrupted: 1;
	u32 unrecov_intr: 1;
	long: 63;
	long: 64;
	struct sk_buff___98 **skb_nextp;
	struct sk_buff___98 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___5 cb;
};

struct sk_psock_work_state___5 {
	struct sk_buff___98 *skb;
	u32 len;
	u32 off;
};

struct sk_msg___5;

struct sk_psock___5 {
	struct sock___84 *sk;
	struct sock___84 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg___5 *cork;
	struct sk_psock_progs___5 progs;
	struct strparser___5 strp;
	struct sk_buff_head___97 ingress_skb;
	struct list_head ingress_msg;
	spinlock_t ingress_lock;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___84 *);
	void (*saved_close)(struct sock___84 *, long int);
	void (*saved_write_space)(struct sock___84 *);
	void (*saved_data_ready)(struct sock___84 *);
	int (*psock_update_sk_prot)(struct sock___84 *, struct sk_psock___5 *, bool);
	struct proto___84 *sk_proto;
	struct mutex work_mutex;
	struct sk_psock_work_state___5 work_state;
	struct work_struct work;
	struct rcu_work rwork;
};

struct request_sock___70;

struct request_sock_ops___69 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___84 *, struct request_sock___70 *);
	void (*send_ack)(const struct sock___84 *, struct sk_buff___98 *, struct request_sock___70 *);
	void (*send_reset)(const struct sock___84 *, struct sk_buff___98 *);
	void (*destructor)(struct request_sock___70 *);
	void (*syn_ack_timeout)(const struct request_sock___70 *);
};

struct timewait_sock_ops___68 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___84 *, struct sock___84 *, void *);
	void (*twsk_destructor)(struct sock___84 *);
};

struct request_sock___70 {
	struct sock_common___84 __req_common;
	struct request_sock___70 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___69 *rsk_ops;
	struct sock___84 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___12 {
	struct request_sock___70 *rskq_rst_head;
	struct request_sock___70 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___12 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___70 *rskq_accept_head;
	struct request_sock___70 *rskq_accept_tail;
	struct fastopen_queue___12 fastopenq;
};

struct inet_cork___22 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___84 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___22 {
	struct inet_cork___22 base;
	struct flowi fl;
};

struct ipv6_pinfo___21;

struct inet_sock___22 {
	struct sock___84 sk;
	struct ipv6_pinfo___21 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___22 cork;
};

struct ipv6_fl_socklist___21;

struct ipv6_pinfo___21 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___21 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___98 *pktoptions;
	struct sk_buff___98 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___12 {
	int (*queue_xmit)(struct sock___84 *, struct sk_buff___98 *, struct flowi *);
	void (*send_check)(struct sock___84 *, struct sk_buff___98 *);
	int (*rebuild_header)(struct sock___84 *);
	void (*sk_rx_dst_set)(struct sock___84 *, const struct sk_buff___98 *);
	int (*conn_request)(struct sock___84 *, struct sk_buff___98 *);
	struct sock___84 * (*syn_recv_sock)(const struct sock___84 *, struct sk_buff___98 *, struct request_sock___70 *, struct dst_entry___84 *, struct request_sock___70 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___84 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___84 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___84 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___84 *);
};

struct inet_bind_bucket___12;

struct tcp_ulp_ops___12;

struct inet_connection_sock___12 {
	struct inet_sock___22 icsk_inet;
	struct request_sock_queue___12 icsk_accept_queue;
	struct inet_bind_bucket___12 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___30 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___12 *icsk_af_ops;
	const struct tcp_ulp_ops___12 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___84 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___84 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___12 {
	possible_net_t___97 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___12 {
	struct list_head list;
	int (*init)(struct sock___84 *);
	void (*update)(struct sock___84 *, struct proto___84 *, void (*)(struct sock___84 *));
	void (*release)(struct sock___84 *);
	int (*get_info)(const struct sock___84 *, struct sk_buff___98 *);
	size_t (*get_info_size)(const struct sock___84 *);
	void (*clone)(const struct request_sock___70 *, struct sock___84 *, const gfp_t);
	char name[16];
	struct module___272 *owner;
};

struct ip6_flowlabel___21;

struct ipv6_fl_socklist___21 {
	struct ipv6_fl_socklist___21 *next;
	struct ip6_flowlabel___21 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___66 {
	struct in6_addr mca_addr;
	struct inet6_dev___66 *idev;
	struct ifmcaddr6___66 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___27 {
	struct in6_addr aca_addr;
	struct fib6_info___27 *aca_rt;
	struct ifacaddr6___27 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result___7;

struct fib6_config___8;

struct ipv6_stub___8 {
	int (*ipv6_sock_mc_join)(struct sock___84 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___84 *, int, const struct in6_addr *);
	struct dst_entry___84 * (*ipv6_dst_lookup_flow)(struct net___102 *, const struct sock___84 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___98 *);
	struct fib6_table___27 * (*fib6_get_table)(struct net___102 *, u32);
	int (*fib6_lookup)(struct net___102 *, int, struct flowi6 *, struct fib6_result___7 *, int);
	int (*fib6_table_lookup)(struct net___102 *, struct fib6_table___27 *, int, struct flowi6 *, struct fib6_result___7 *, int);
	void (*fib6_select_path)(const struct net___102 *, struct fib6_result___7 *, struct flowi6 *, int, bool, const struct sk_buff___98 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___7 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___102 *, struct fib6_nh___27 *, struct fib6_config___8 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___27 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___27 *);
	void (*fib6_update_sernum)(struct net___102 *, struct fib6_info___27 *);
	int (*ip6_del_rt)(struct net___102 *, struct fib6_info___27 *, bool);
	void (*fib6_rt_update)(struct net___102 *, struct fib6_info___27 *, struct nl_info___9 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___97 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___98 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___84 *, struct sk_buff___98 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___98 *, int, __be32, int);
	struct neigh_table___84 *nd_tbl;
	int (*ipv6_fragment)(struct net___102 *, struct sock___84 *, struct sk_buff___98 *, int (*)(struct net___102 *, struct sock___84 *, struct sk_buff___98 *));
	struct net_device___97 * (*ipv6_dev_find)(struct net___102 *, const struct in6_addr *, struct net_device___97 *);
};

struct fib6_result___7 {
	struct fib6_nh___27 *nh;
	struct fib6_info___27 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___27 *rt6;
};

struct fib6_config___8 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___9 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct ip6_flowlabel___21 {
	struct ip6_flowlabel___21 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___265 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___102 *fl_net;
};

struct fib_nh_exception___27 {
	struct fib_nh_exception___27 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___29 *fnhe_rth_input;
	struct rtable___29 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___29 {
	struct dst_entry___84 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___27 {
	struct fib_nh_exception___27 *chain;
};

struct xfrm_type___20 {
	struct module___272 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___20 *);
	void (*destructor)(struct xfrm_state___20 *);
	int (*input)(struct xfrm_state___20 *, struct sk_buff___98 *);
	int (*output)(struct xfrm_state___20 *, struct sk_buff___98 *);
	int (*reject)(struct xfrm_state___20 *, struct sk_buff___98 *, const struct flowi *);
};

struct xfrm_type_offload___20 {
	struct module___272 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___20 *, struct sk_buff___98 *);
	int (*input_tail)(struct xfrm_state___20 *, struct sk_buff___98 *);
	int (*xmit)(struct xfrm_state___20 *, struct sk_buff___98 *, netdev_features_t);
};

struct sk_msg___5 {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___98 *skb;
	struct sock___84 *sk_redir;
	struct sock___84 *sk;
	struct list_head list;
};

struct espintcp_msg {
	struct sk_buff___98 *skb;
	struct sk_msg___5 skmsg;
	int offset;
	int len;
};

struct espintcp_ctx {
	struct strparser___5 strp;
	struct sk_buff_head___97 ike_queue;
	struct sk_buff_head___97 out_queue;
	struct espintcp_msg partial;
	void (*saved_data_ready)(struct sock___84 *);
	void (*saved_write_space)(struct sock___84 *);
	void (*saved_destruct)(struct sock___84 *);
	struct work_struct work;
	bool tx_running;
};

typedef int (*bpf_iter_attach_target_t___7)(struct bpf_prog___69 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___78 *);

typedef void (*bpf_iter_detach_target_t___7)(struct bpf_iter_aux_info___78 *);

typedef void (*bpf_iter_show_fdinfo_t___7)(const struct bpf_iter_aux_info___78 *, struct seq_file___241 *);

typedef int (*bpf_iter_fill_link_info_t___7)(const struct bpf_iter_aux_info___78 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___11 * (*bpf_iter_get_func_proto_t___8)(enum bpf_func_id, const struct bpf_prog___69 *);

typedef struct poll_table_struct___187 poll_table___53;

struct unix_stream_read_state {
	int (*recv_actor)(struct sk_buff___76 *, int, int, struct unix_stream_read_state *);
	struct socket___64 *socket;
	struct msghdr___64 *msg;
	struct pipe_inode_info___107 *pipe;
	size_t size;
	int flags;
	unsigned int splice_flags;
};

struct bpf_iter__unix {
	union {
		struct bpf_iter_meta___5 *meta;
	};
	union {
		struct unix_sock___3 *unix_sk;
	};
	uid_t uid;
};

struct scm_fp_list___5 {
	short int count;
	short int max;
	struct user_struct *user;
	struct file___283 *fp[253];
};

struct unix_skb_parms___2 {
	struct pid___260 *pid;
	kuid_t uid;
	kgid_t gid;
	struct scm_fp_list___5 *fp;
	struct lsmblob lsmblob;
	u32 consumed;
};

struct unix_sock___4 {
	struct sock___79 sk;
	struct unix_address *addr;
	struct path___283 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___79 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___80 peer_wq;
	wait_queue_entry_t peer_wake;
	struct scm_stat scm_stat;
	struct sk_buff___93 *oob_skb;
	long: 64;
};

struct dentry___289;

struct super_block___289;

struct module___273;

struct file_system_type___289 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___289 * (*mount)(struct file_system_type___289 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___289 *);
	struct module___273 *owner;
	struct file_system_type___289 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___289;

struct kiocb___289;

struct iov_iter___209;

struct poll_table_struct___210;

struct vm_area_struct___294;

struct inode___289;

struct file_lock___289;

struct page___294;

struct pipe_inode_info___130;

struct seq_file___264;

struct file_operations___290 {
	struct module___273 *owner;
	loff_t (*llseek)(struct file___289 *, loff_t, int);
	ssize_t (*read)(struct file___289 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___289 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___289 *, struct iov_iter___209 *);
	ssize_t (*write_iter)(struct kiocb___289 *, struct iov_iter___209 *);
	int (*iopoll)(struct kiocb___289 *, bool);
	int (*iterate)(struct file___289 *, struct dir_context *);
	int (*iterate_shared)(struct file___289 *, struct dir_context *);
	__poll_t (*poll)(struct file___289 *, struct poll_table_struct___210 *);
	long int (*unlocked_ioctl)(struct file___289 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___289 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___289 *, struct vm_area_struct___294 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___289 *, struct file___289 *);
	int (*flush)(struct file___289 *, fl_owner_t);
	int (*release)(struct inode___289 *, struct file___289 *);
	int (*fsync)(struct file___289 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___289 *, int);
	int (*lock)(struct file___289 *, int, struct file_lock___289 *);
	ssize_t (*sendpage)(struct file___289 *, struct page___294 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___289 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___289 *, long unsigned int);
	int (*flock)(struct file___289 *, int, struct file_lock___289 *);
	ssize_t (*splice_write)(struct pipe_inode_info___130 *, struct file___289 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___289 *, loff_t *, struct pipe_inode_info___130 *, size_t, unsigned int);
	int (*setlease)(struct file___289 *, long int, struct file_lock___289 **, void **);
	long int (*fallocate)(struct file___289 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___264 *, struct file___289 *);
	ssize_t (*copy_file_range)(struct file___289 *, loff_t, struct file___289 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___289 *, loff_t, struct file___289 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___289 *, loff_t, loff_t, int);
};

struct vmacache___294 {
	u64 seqnum;
	struct vm_area_struct___294 *vmas[4];
};

struct page_frag___294 {
	struct page___294 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___295;

struct pid___266;

struct nsproxy___275;

struct signal_struct___290;

struct bio_list___180;

struct backing_dev_info___166;

struct io_context___180;

struct css_set___216;

struct mem_cgroup___154;

struct request_queue___180;

struct vm_struct___272;

struct task_struct___296 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___296 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___295 *mm;
	struct mm_struct___295 *active_mm;
	struct vmacache___294 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___296 *real_parent;
	struct task_struct___296 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___296 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___266 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___275 *nsproxy;
	struct signal_struct___290 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___296 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___180 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___166 *backing_dev_info;
	struct io_context___180 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___216 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___130 *splice_pipe;
	struct page_frag___294 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___154 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___154 *active_memcg;
	struct request_queue___180 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___296 *oom_reaper_list;
	struct vm_struct___272 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___277;

struct kobj_type___277;

struct kernfs_node___277;

struct kobject___277 {
	const char *name;
	struct list_head entry;
	struct kobject___277 *parent;
	struct kset___277 *kset;
	struct kobj_type___277 *ktype;
	struct kernfs_node___277 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___274 {
	struct kobject___277 kobj;
	struct module___273 *mod;
	struct kobject___277 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___273 {
	struct module___273 *mod;
	struct latch_tree_node node;
};

struct module_layout___273 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___273 mtn;
};

struct module_attribute___273;

struct kernel_param___273;

struct module___273 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___274 mkobj;
	struct module_attribute___273 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___277 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___273 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___273 core_layout;
	struct module_layout___273 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vfsmount___289;

struct path___289 {
	struct vfsmount___289 *mnt;
	struct dentry___289 *dentry;
};

struct fown_struct___266 {
	rwlock_t lock;
	struct pid___266 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct address_space___289;

struct file___289 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___289 f_path;
	struct inode___289 *f_inode;
	const struct file_operations___290 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___266 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___289 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

typedef struct page___294 *pgtable_t___294;

struct page_pool___118;

struct dev_pagemap___284;

struct page___294 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___289 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___118 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___294 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___294 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___295 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___284 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___284;

struct vm_area_struct___294 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___294 *vm_next;
	struct vm_area_struct___294 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___295 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___284 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___289 *vm_file;
	struct file___289 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___294;

struct mm_struct___295 {
	struct {
		struct vm_area_struct___294 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___289 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___294 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___296 *owner;
		struct user_namespace___26 *user_ns;
		struct file___289 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___289;

struct address_space___289 {
	struct inode___289 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___289 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___270;

struct page_pool_params___118 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___270 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___118 {
	u32 count;
	struct page___294 *cache[128];
};

struct page_pool___118 {
	struct page_pool_params___118 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___294 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___118 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___284;

struct dev_pagemap___284 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___284 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vm_fault___284;

struct vm_operations_struct___284 {
	void (*open)(struct vm_area_struct___294 *);
	void (*close)(struct vm_area_struct___294 *);
	int (*may_split)(struct vm_area_struct___294 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___294 *);
	int (*mprotect)(struct vm_area_struct___294 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___284 *);
	vm_fault_t (*huge_fault)(struct vm_fault___284 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___284 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___294 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___284 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___284 *);
	int (*access)(struct vm_area_struct___294 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___294 *);
	int (*set_policy)(struct vm_area_struct___294 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___294 *, long unsigned int);
	struct page___294 * (*find_special_page)(struct vm_area_struct___294 *, long unsigned int);
};

struct core_thread___294 {
	struct task_struct___296 *task;
	struct core_thread___294 *next;
};

struct core_state___294 {
	atomic_t nr_threads;
	struct core_thread___294 dumper;
	struct completion startup;
};

struct vm_fault___284 {
	const struct {
		struct vm_area_struct___294 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___294 *cow_page;
	struct page___294 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___294 prealloc_pte;
};

struct pid_namespace___266;

struct upid___266 {
	int nr;
	struct pid_namespace___266 *ns;
};

struct pid_namespace___266 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___296 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___266 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___266 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___266 numbers[1];
};

struct signal_struct___290 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___296 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___296 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___266 *pids[4];
	struct pid___266 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___295 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___103;

struct cgroup_namespace___216;

struct nsproxy___275 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___266 *pid_ns_for_children;
	struct net___103 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___216 *cgroup_ns;
};

struct bio___180;

struct bio_list___180 {
	struct bio___180 *head;
	struct bio___180 *tail;
};

struct cgroup_subsys_state___216;

struct bdi_writeback___166 {
	struct backing_dev_info___166 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___216 *memcg_css;
	struct cgroup_subsys_state___216 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___166 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___166 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___270 *dev;
	char dev_name[64];
	struct device___270 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___289 *debug_dir;
};

struct io_cq___180;

struct io_context___180 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___180 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___216;

struct css_set___216 {
	struct cgroup_subsys_state___216 *subsys[14];
	refcount_t refcount;
	struct css_set___216 *dom_cset;
	struct cgroup___216 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___216 *mg_src_cgrp;
	struct cgroup___216 *mg_dst_cgrp;
	struct css_set___216 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___289;

struct pipe_buffer___130;

struct pipe_inode_info___130 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___294 *tmp_page;
	struct fasync_struct___289 *fasync_readers;
	struct fasync_struct___289 *fasync_writers;
	struct pipe_buffer___130 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___216;

struct cgroup_subsys_state___216 {
	struct cgroup___216 *cgroup;
	struct cgroup_subsys___216 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___216 *parent;
};

struct cgroup_file___216 {
	struct kernfs_node___277 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___154;

struct mem_cgroup_per_node___154;

struct mem_cgroup___154 {
	struct cgroup_subsys_state___216 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___216 events_file;
	struct cgroup_file___216 events_local_file;
	struct cgroup_file___216 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___154 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___296 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___154 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___180;

struct blk_integrity___180 {
	const struct blk_integrity_profile___180 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___180 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___180 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___180;

struct elevator_queue___180;

struct blk_mq_ops___175;

struct blk_mq_hw_ctx___175;

struct gendisk___183;

struct blkcg_gq___168;

struct blk_mq_tag_set___175;

struct request_queue___180 {
	struct request___180 *last_merge;
	struct elevator_queue___180 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___175 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___175 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___183 *disk;
	struct kobject___277 kobj;
	struct kobject___277 *mq_kobj;
	struct blk_integrity___180 integrity;
	struct device___270 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___168 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___175 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___180 bio_split;
	struct dentry___289 *debugfs_dir;
	struct dentry___289 *sched_debugfs_dir;
	struct dentry___289 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___272 {
	struct vm_struct___272 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___294 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct pglist_data___162;

struct lruvec___162 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___162 *pgdat;
};

struct zone___162 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___162 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___162 {
	struct zone___162 *zone;
	int zone_idx;
};

struct zonelist___162 {
	struct zoneref___162 _zonerefs[321];
};

struct pglist_data___162 {
	struct zone___162 node_zones[5];
	struct zonelist___162 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___296 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___296 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___162 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___289;

struct dentry___289 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___289 *d_parent;
	struct qstr d_name;
	struct inode___289 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___289 *d_op;
	struct super_block___289 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___289;

struct inode___289 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___289 *i_op;
	struct super_block___289 *i_sb;
	struct address_space___289 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___166 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___290 *i_fop;
		void (*free_inode)(struct inode___289 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___289 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___130 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___289 {
	int (*d_revalidate)(struct dentry___289 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___289 *, unsigned int);
	int (*d_hash)(const struct dentry___289 *, struct qstr *);
	int (*d_compare)(const struct dentry___289 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___289 *);
	int (*d_init)(struct dentry___289 *);
	void (*d_release)(struct dentry___289 *);
	void (*d_prune)(struct dentry___289 *);
	void (*d_iput)(struct dentry___289 *, struct inode___289 *);
	char * (*d_dname)(struct dentry___289 *, char *, int);
	struct vfsmount___289 * (*d_automount)(struct path___289 *);
	int (*d_manage)(const struct path___289 *, bool);
	struct dentry___289 * (*d_real)(struct dentry___289 *, const struct inode___289 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___289;

struct mem_dqinfo___289 {
	struct quota_format_type___289 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___289;

struct quota_info___289 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___289 *files[3];
	struct mem_dqinfo___289 info[3];
	const struct quota_format_ops___289 *ops[3];
};

struct rcuwait___290 {
	struct task_struct___296 *task;
};

struct percpu_rw_semaphore___290 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___290 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___289 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___290 rw_sem[3];
};

struct shrink_control___154;

struct shrinker___154 {
	long unsigned int (*count_objects)(struct shrinker___154 *, struct shrink_control___154 *);
	long unsigned int (*scan_objects)(struct shrinker___154 *, struct shrink_control___154 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___289;

struct dquot_operations___289;

struct quotactl_ops___289;

struct block_device___183;

struct super_block___289 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___289 *s_type;
	const struct super_operations___289 *s_op;
	const struct dquot_operations___289 *dq_op;
	const struct quotactl_ops___289 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___289 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___183 *s_bdev;
	struct backing_dev_info___166 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___289 s_dquot;
	struct sb_writers___289 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___289 *s_d_op;
	int cleancache_poolid;
	struct shrinker___154 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___289 {
	struct dentry___289 *mnt_root;
	struct super_block___289 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___154 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___154 *memcg;
};

struct psi_group___216 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___296 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___92;

struct cgroup_bpf___92 {
	struct bpf_prog_array___92 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___92 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___216;

struct cgroup_rstat_cpu___216;

struct cgroup___216 {
	struct cgroup_subsys_state___216 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___277 *kn;
	struct cgroup_file___216 procs_file;
	struct cgroup_file___216 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___216 *subsys[14];
	struct cgroup_root___216 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___216 *dom_cgrp;
	struct cgroup___216 *old_dom_cgrp;
	struct cgroup_rstat_cpu___216 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___216 psi;
	struct cgroup_bpf___92 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___180 {
	struct request_queue___180 *q;
	struct io_context___180 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___289 {
	struct file___289 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___289 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___289 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___289 *ia_file;
};

struct dquot___289 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___289 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___289 {
	int qf_fmt_id;
	const struct quota_format_ops___289 *qf_ops;
	struct module___273 *qf_owner;
	struct quota_format_type___289 *qf_next;
};

struct quota_format_ops___289 {
	int (*check_quota_file)(struct super_block___289 *, int);
	int (*read_file_info)(struct super_block___289 *, int);
	int (*write_file_info)(struct super_block___289 *, int);
	int (*free_file_info)(struct super_block___289 *, int);
	int (*read_dqblk)(struct dquot___289 *);
	int (*commit_dqblk)(struct dquot___289 *);
	int (*release_dqblk)(struct dquot___289 *);
	int (*get_next_id)(struct super_block___289 *, struct kqid *);
};

struct dquot_operations___289 {
	int (*write_dquot)(struct dquot___289 *);
	struct dquot___289 * (*alloc_dquot)(struct super_block___289 *, int);
	void (*destroy_dquot)(struct dquot___289 *);
	int (*acquire_dquot)(struct dquot___289 *);
	int (*release_dquot)(struct dquot___289 *);
	int (*mark_dirty)(struct dquot___289 *);
	int (*write_info)(struct super_block___289 *, int);
	qsize_t * (*get_reserved_space)(struct inode___289 *);
	int (*get_projid)(struct inode___289 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___289 *, qsize_t *);
	int (*get_next_id)(struct super_block___289 *, struct kqid *);
};

struct quotactl_ops___289 {
	int (*quota_on)(struct super_block___289 *, int, int, const struct path___289 *);
	int (*quota_off)(struct super_block___289 *, int);
	int (*quota_enable)(struct super_block___289 *, unsigned int);
	int (*quota_disable)(struct super_block___289 *, unsigned int);
	int (*quota_sync)(struct super_block___289 *, int);
	int (*set_info)(struct super_block___289 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___289 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___289 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___289 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___289 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___289 *, unsigned int);
};

struct writeback_control___166;

struct address_space_operations___289 {
	int (*writepage)(struct page___294 *, struct writeback_control___166 *);
	int (*readpage)(struct file___289 *, struct page___294 *);
	int (*writepages)(struct address_space___289 *, struct writeback_control___166 *);
	int (*set_page_dirty)(struct page___294 *);
	int (*readpages)(struct file___289 *, struct address_space___289 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___289 *, struct address_space___289 *, loff_t, unsigned int, unsigned int, struct page___294 **, void **);
	int (*write_end)(struct file___289 *, struct address_space___289 *, loff_t, unsigned int, unsigned int, struct page___294 *, void *);
	sector_t (*bmap)(struct address_space___289 *, sector_t);
	void (*invalidatepage)(struct page___294 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___294 *, gfp_t);
	void (*freepage)(struct page___294 *);
	ssize_t (*direct_IO)(struct kiocb___289 *, struct iov_iter___209 *);
	int (*migratepage)(struct address_space___289 *, struct page___294 *, struct page___294 *, enum migrate_mode);
	bool (*isolate_page)(struct page___294 *, isolate_mode_t);
	void (*putback_page)(struct page___294 *);
	int (*launder_page)(struct page___294 *);
	int (*is_partially_uptodate)(struct page___294 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___294 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___289 *, struct page___294 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___289 *, sector_t *);
	void (*swap_deactivate)(struct file___289 *);
};

struct writeback_control___166 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___166 *wb;
	struct inode___289 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___206;

struct iov_iter___209 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___206 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___130 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___289 {
	struct dentry___289 * (*lookup)(struct inode___289 *, struct dentry___289 *, unsigned int);
	const char * (*get_link)(struct dentry___289 *, struct inode___289 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___289 *, int);
	struct posix_acl * (*get_acl)(struct inode___289 *, int, bool);
	int (*readlink)(struct dentry___289 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___289 *, struct dentry___289 *, umode_t, bool);
	int (*link)(struct dentry___289 *, struct inode___289 *, struct dentry___289 *);
	int (*unlink)(struct inode___289 *, struct dentry___289 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___289 *, struct dentry___289 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___289 *, struct dentry___289 *, umode_t);
	int (*rmdir)(struct inode___289 *, struct dentry___289 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___289 *, struct dentry___289 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___289 *, struct dentry___289 *, struct inode___289 *, struct dentry___289 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___289 *, struct iattr___289 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___289 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___289 *, char *, size_t);
	int (*fiemap)(struct inode___289 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___289 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___289 *, struct dentry___289 *, struct file___289 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___289 *, struct dentry___289 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___289 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___289 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___289 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___289 {
	void (*fl_copy_lock)(struct file_lock___289 *, struct file_lock___289 *);
	void (*fl_release_private)(struct file_lock___289 *);
};

struct lock_manager_operations___289;

struct file_lock___289 {
	struct file_lock___289 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___289 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___289 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___289 *fl_ops;
	const struct lock_manager_operations___289 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___289 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___289 *);
	int (*lm_grant)(struct file_lock___289 *, int);
	bool (*lm_break)(struct file_lock___289 *);
	int (*lm_change)(struct file_lock___289 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___289 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___289 *);
};

struct fasync_struct___289 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___289 *fa_next;
	struct file___289 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___289 {
	struct inode___289 * (*alloc_inode)(struct super_block___289 *);
	void (*destroy_inode)(struct inode___289 *);
	void (*free_inode)(struct inode___289 *);
	void (*dirty_inode)(struct inode___289 *, int);
	int (*write_inode)(struct inode___289 *, struct writeback_control___166 *);
	int (*drop_inode)(struct inode___289 *);
	void (*evict_inode)(struct inode___289 *);
	void (*put_super)(struct super_block___289 *);
	int (*sync_fs)(struct super_block___289 *, int);
	int (*freeze_super)(struct super_block___289 *);
	int (*freeze_fs)(struct super_block___289 *);
	int (*thaw_super)(struct super_block___289 *);
	int (*unfreeze_fs)(struct super_block___289 *);
	int (*statfs)(struct dentry___289 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___289 *, int *, char *);
	void (*umount_begin)(struct super_block___289 *);
	int (*show_options)(struct seq_file___264 *, struct dentry___289 *);
	int (*show_devname)(struct seq_file___264 *, struct dentry___289 *);
	int (*show_path)(struct seq_file___264 *, struct dentry___289 *);
	int (*show_stats)(struct seq_file___264 *, struct dentry___289 *);
	ssize_t (*quota_read)(struct super_block___289 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___289 *, int, const char *, size_t, loff_t);
	struct dquot___289 ** (*get_dquots)(struct inode___289 *);
	long int (*nr_cached_objects)(struct super_block___289 *, struct shrink_control___154 *);
	long int (*free_cached_objects)(struct super_block___289 *, struct shrink_control___154 *);
	struct file___289 * (*real_loop)(struct file___289 *);
};

struct wakeup_source___270;

struct dev_pm_info___270 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___270 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___270 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___270;

struct bus_type___270;

struct device_driver___270;

struct dev_pm_domain___270;

struct fwnode_handle___266;

struct class___270;

struct attribute_group___277;

struct device___270 {
	struct kobject___277 kobj;
	struct device___270 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___270 *type;
	struct bus_type___270 *bus;
	struct device_driver___270 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___270 power;
	struct dev_pm_domain___270 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___266 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___270 *class;
	const struct attribute_group___277 **groups;
	void (*release)(struct device___270 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___183 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___289 *bd_inode;
	struct super_block___289 *bd_super;
	void *bd_claiming;
	struct device___270 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___277 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___183 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___289 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___218)(struct file___289 *, wait_queue_head_t *, struct poll_table_struct___210 *);

struct poll_table_struct___210 {
	poll_queue_proc___218 _qproc;
	__poll_t _key;
};

struct seq_operations___264;

struct seq_file___264 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___264 *op;
	int poll_event;
	const struct file___289 *file;
	void *private;
};

typedef void bio_end_io_t___180(struct bio___180 *);

struct bio_vec___206 {
	struct page___294 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___180;

struct bio___180 {
	struct bio___180 *bi_next;
	struct block_device___183 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___180 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___168 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___180 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___206 *bi_io_vec;
	struct bio_set___180 *bi_pool;
	struct bio_vec___206 bi_inline_vecs[0];
};

struct kernfs_root___277;

struct kernfs_elem_dir___277 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___277 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___277;

struct kernfs_root___277 {
	struct kernfs_node___277 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___277 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___277 {
	struct kernfs_node___277 *target_kn;
};

struct kernfs_ops___277;

struct kernfs_elem_attr___277 {
	const struct kernfs_ops___277 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___277 *notify_next;
};

struct kernfs_node___277 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___277 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___277 dir;
		struct kernfs_elem_symlink___277 symlink;
		struct kernfs_elem_attr___277 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___277;

struct kernfs_ops___277 {
	int (*open)(struct kernfs_open_file___277 *);
	void (*release)(struct kernfs_open_file___277 *);
	int (*seq_show)(struct seq_file___264 *, void *);
	void * (*seq_start)(struct seq_file___264 *, loff_t *);
	void * (*seq_next)(struct seq_file___264 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___264 *, void *);
	ssize_t (*read)(struct kernfs_open_file___277 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___277 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___277 *, struct poll_table_struct___210 *);
	int (*mmap)(struct kernfs_open_file___277 *, struct vm_area_struct___294 *);
};

struct kernfs_syscall_ops___277 {
	int (*show_options)(struct seq_file___264 *, struct kernfs_root___277 *);
	int (*mkdir)(struct kernfs_node___277 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___277 *);
	int (*rename)(struct kernfs_node___277 *, struct kernfs_node___277 *, const char *);
	int (*show_path)(struct seq_file___264 *, struct kernfs_node___277 *, struct kernfs_root___277 *);
};

struct kernfs_open_file___277 {
	struct kernfs_node___277 *kn;
	struct file___289 *file;
	struct seq_file___264 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___284 *vm_ops;
};

struct sock___85;

struct kobj_ns_type_operations___85 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___85 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___103 *net;
} possible_net_t___98;

struct proto___85;

struct sock_common___85 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___85 *skc_prot;
	possible_net_t___98 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___85 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___99;

struct sk_buff_head___98 {
	struct sk_buff___99 *next;
	struct sk_buff___99 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___85 {
	struct cgroup___216 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___85;

struct socket_wq___86;

struct dst_entry___85;

struct socket___87;

struct net_device___98;

struct sock_reuseport___33;

struct sock___85 {
	struct sock_common___85 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___98 sk_error_queue;
	struct sk_buff___99 *sk_rx_skb_cache;
	struct sk_buff_head___98 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___99 *head;
		struct sk_buff___99 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___85 *sk_filter;
	union {
		struct socket_wq___86 *sk_wq;
		struct socket_wq___86 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___85 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___85 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___99 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___99 *sk_tx_skb_cache;
	struct sk_buff_head___98 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___294 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___85 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___266 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___87 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___85 sk_cgrp_data;
	struct mem_cgroup___154 *sk_memcg;
	void (*sk_state_change)(struct sock___85 *);
	void (*sk_data_ready)(struct sock___85 *);
	void (*sk_write_space)(struct sock___85 *);
	void (*sk_error_report)(struct sock___85 *);
	int (*sk_backlog_rcv)(struct sock___85 *, struct sk_buff___99 *);
	struct sk_buff___99 * (*sk_validate_xmit_skb)(struct sock___85 *, struct net_device___98 *, struct sk_buff___99 *);
	void (*sk_destruct)(struct sock___85 *);
	struct sock_reuseport___33 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___277;

struct attribute_group___277 {
	const char *name;
	umode_t (*is_visible)(struct kobject___277 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___277 *, struct bin_attribute___277 *, int);
	struct attribute **attrs;
	struct bin_attribute___277 **bin_attrs;
};

struct bin_attribute___277 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___289 * (*f_mapping)();
	ssize_t (*read)(struct file___289 *, struct kobject___277 *, struct bin_attribute___277 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___289 *, struct kobject___277 *, struct bin_attribute___277 *, char *, loff_t, size_t);
	int (*mmap)(struct file___289 *, struct kobject___277 *, struct bin_attribute___277 *, struct vm_area_struct___294 *);
};

struct sysfs_ops___277 {
	ssize_t (*show)(struct kobject___277 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___277 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___277;

struct kset___277 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___277 kobj;
	const struct kset_uevent_ops___277 *uevent_ops;
};

struct kobj_type___277 {
	void (*release)(struct kobject___277 *);
	const struct sysfs_ops___277 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___277 **default_groups;
	const struct kobj_ns_type_operations___85 * (*child_ns_type)(struct kobject___277 *);
	const void * (*namespace)(struct kobject___277 *);
	void (*get_ownership)(struct kobject___277 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___277 {
	int (* const filter)(struct kset___277 *, struct kobject___277 *);
	const char * (* const name)(struct kset___277 *, struct kobject___277 *);
	int (* const uevent)(struct kset___277 *, struct kobject___277 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___273 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___273 *);
	int (*get)(char *, const struct kernel_param___273 *);
	void (*free)(void *);
};

struct kparam_array___273;

struct kernel_param___273 {
	const char *name;
	struct module___273 *mod;
	const struct kernel_param_ops___273 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___273 *arr;
	};
};

struct kparam_array___273 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___273 *ops;
	void *elem;
};

struct module_attribute___273 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___273 *, struct module_kobject___274 *, char *);
	ssize_t (*store)(struct module_attribute___273 *, struct module_kobject___274 *, const char *, size_t);
	void (*setup)(struct module___273 *, const char *);
	int (*test)(struct module___273 *);
	void (*free)(struct module___273 *);
};

struct dev_pagemap_ops___284 {
	void (*page_free)(struct page___294 *);
	void (*kill)(struct dev_pagemap___284 *);
	void (*cleanup)(struct dev_pagemap___284 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___284 *);
};

struct bpf_iter_aux_info___101;

typedef int (*bpf_iter_init_seq_priv_t___100)(void *, struct bpf_iter_aux_info___101 *);

struct bpf_map___101;

struct bpf_iter_aux_info___101 {
	struct bpf_map___101 *map;
};

struct bpf_iter_seq_info___100 {
	const struct seq_operations___264 *seq_ops;
	bpf_iter_init_seq_priv_t___100 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct seq_operations___264 {
	void * (*start)(struct seq_file___264 *, loff_t *);
	void (*stop)(struct seq_file___264 *, void *);
	void * (*next)(struct seq_file___264 *, void *, loff_t *);
	int (*show)(struct seq_file___264 *, void *);
};

struct bpf_prog_aux___101;

struct bpf_prog___92;

struct bpf_map_ops___100 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___101 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___101 *, struct file___289 *);
	void (*map_free)(struct bpf_map___101 *);
	int (*map_get_next_key)(struct bpf_map___101 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___101 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___101 *, void *);
	int (*map_lookup_batch)(struct bpf_map___101 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___101 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___101 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___101 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___101 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___101 *, void *);
	int (*map_update_elem)(struct bpf_map___101 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___101 *, void *);
	int (*map_push_elem)(struct bpf_map___101 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___101 *, void *);
	int (*map_peek_elem)(struct bpf_map___101 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___101 *, struct file___289 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___101 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___101 *, void *, struct seq_file___264 *);
	int (*map_check_btf)(const struct bpf_map___101 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___101 *, struct bpf_prog_aux___101 *);
	void (*map_poke_untrack)(struct bpf_map___101 *, struct bpf_prog_aux___101 *);
	void (*map_poke_run)(struct bpf_map___101 *, u32, struct bpf_prog___92 *, struct bpf_prog___92 *);
	int (*map_direct_value_addr)(const struct bpf_map___101 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___101 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___101 *, struct vm_area_struct___294 *);
	__poll_t (*map_poll)(struct bpf_map___101 *, struct file___289 *, struct poll_table_struct___210 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___101 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___101 *, const struct bpf_map___101 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___101 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___100 *iter_seq_info;
};

struct bpf_map___101 {
	const struct bpf_map_ops___100 *ops;
	struct bpf_map___101 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___154 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___100;

struct bpf_jit_poke_descriptor___100;

struct bpf_prog_ops___92;

struct btf_mod_pair___100;

struct bpf_prog_offload___98;

struct bpf_prog_aux___101 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___92 *dst_prog;
	struct bpf_trampoline___100 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___92 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___100 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___92 *ops;
	struct bpf_map___101 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___100 *used_btfs;
	struct bpf_prog___92 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___101 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___98 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_prog___92 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___101 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct bpf_offloaded_map___98;

struct bpf_map_dev_ops___98 {
	int (*map_get_next_key)(struct bpf_offloaded_map___98 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___98 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___98 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___98 *, void *);
};

struct bpf_offloaded_map___98 {
	struct bpf_map___101 map;
	struct net_device___98 *netdev;
	const struct bpf_map_dev_ops___98 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

typedef rx_handler_result_t rx_handler_func_t___98(struct sk_buff___99 **);

struct bpf_xdp_entity___92 {
	struct bpf_prog___92 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___98;

struct net_device_ops___98;

struct l3mdev_ops___85;

struct ndisc_ops___67;

struct xfrmdev_ops___98;

struct header_ops___98;

struct inet6_dev___67;

struct netdev_rx_queue___98;

struct mini_Qdisc___92;

struct netdev_queue___98;

struct Qdisc___92;

struct rtnl_link_ops___92;

struct dcbnl_rtnl_ops___98;

struct net_device___98 {
	char name[16];
	struct netdev_name_node___98 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___98 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___85 *l3mdev_ops;
	const struct ndisc_ops___67 *ndisc_ops;
	const struct xfrmdev_ops___98 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___98 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___277 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___67 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___98 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___92 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___98 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___92 *miniq_ingress;
	struct netdev_queue___98 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___98 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___92 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___92 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___98 = 0,
		NETREG_REGISTERED___98 = 1,
		NETREG_UNREGISTERING___98 = 2,
		NETREG_UNREGISTERED___98 = 3,
		NETREG_RELEASED___98 = 4,
		NETREG_DUMMY___98 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___98 = 0,
		RTNL_LINK_INITIALIZING___98 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___98 *);
	struct netpoll_info *npinfo;
	possible_net_t___98 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___270 dev;
	const struct attribute_group___277 *sysfs_groups[4];
	const struct attribute_group___277 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___92 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___98 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___92 xdp_state[3];
	long: 64;
};

struct bpf_prog_ops___92 {
	int (*test_run)(struct bpf_prog___92 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___98 {
	struct bpf_prog___92 *prog;
	struct net_device___98 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___100 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___92 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___273 *mod;
};

struct bpf_jit_poke_descriptor___100 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___101 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___100 {
	struct btf *btf;
	struct module___273 *module;
};

struct bpf_prog_array_item___92 {
	struct bpf_prog___92 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___92 {
	struct callback_head rcu;
	struct bpf_prog_array_item___92 items[0];
};

struct sk_buff___99 {
	union {
		struct {
			struct sk_buff___99 *next;
			struct sk_buff___99 *prev;
			union {
				struct net_device___98 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___85 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___99 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct msghdr___87 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___209 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___289 *msg_iocb;
};

struct fwnode_operations___266;

struct fwnode_handle___266 {
	struct fwnode_handle___266 *secondary;
	const struct fwnode_operations___266 *ops;
	struct device___270 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___266;

struct fwnode_endpoint___266;

struct fwnode_operations___266 {
	struct fwnode_handle___266 * (*get)(struct fwnode_handle___266 *);
	void (*put)(struct fwnode_handle___266 *);
	bool (*device_is_available)(const struct fwnode_handle___266 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___266 *, const struct device___270 *);
	bool (*property_present)(const struct fwnode_handle___266 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___266 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___266 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___266 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*get_parent)(const struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*get_next_child_node)(const struct fwnode_handle___266 *, struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*get_named_child_node)(const struct fwnode_handle___266 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___266 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___266 *);
	struct fwnode_handle___266 * (*graph_get_next_endpoint)(const struct fwnode_handle___266 *, struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*graph_get_remote_endpoint)(const struct fwnode_handle___266 *);
	struct fwnode_handle___266 * (*graph_get_port_parent)(struct fwnode_handle___266 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___266 *, struct fwnode_endpoint___266 *);
	int (*add_links)(struct fwnode_handle___266 *);
};

struct fwnode_endpoint___266 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___266 *local_fwnode;
};

struct fwnode_reference_args___266 {
	struct fwnode_handle___266 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct ip_ra_chain___58;

struct fib_rules_ops___85;

struct fqdir___103;

struct tcp_congestion_ops___31;

struct fib_notifier_ops___85;

struct netns_ipv4___103 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___58 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___85 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___85 *fibnl;
	struct sock___85 **icmp_sk;
	struct sock___85 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___85 **tcp_sk;
	struct fqdir___103 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___31 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___85 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___85 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___85 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___85;

struct dst_ops___103 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___103 *);
	struct dst_entry___85 * (*check)(struct dst_entry___85 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___85 *);
	unsigned int (*mtu)(const struct dst_entry___85 *);
	u32 * (*cow_metrics)(struct dst_entry___85 *, long unsigned int);
	void (*destroy)(struct dst_entry___85 *);
	void (*ifdown)(struct dst_entry___85 *, struct net_device___98 *, int);
	struct dst_entry___85 * (*negative_advice)(struct dst_entry___85 *);
	void (*link_failure)(struct sk_buff___99 *);
	void (*update_pmtu)(struct dst_entry___85 *, struct sock___85 *, struct sk_buff___99 *, u32, bool);
	void (*redirect)(struct dst_entry___85 *, struct sock___85 *, struct sk_buff___99 *);
	int (*local_out)(struct net___103 *, struct sock___85 *, struct sk_buff___99 *);
	struct neighbour___85 * (*neigh_lookup)(const struct dst_entry___85 *, struct sk_buff___99 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___85 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___103 {
	struct dst_ops___103 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___103 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___85 *fib6_rules_ops;
	struct sock___85 **icmp_sk;
	struct sock___85 *ndisc_sk;
	struct sock___85 *tcp_sk;
	struct sock___85 *igmp_sk;
	struct sock___85 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___85 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___85 *notifier_ops;
	struct fib_notifier_ops___85 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___103 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___103 *fqdir;
};

struct netns_sctp___85 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___85 *ctl_sock;
	struct sock___85 *udp4_sock;
	struct sock___85 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___92 {
	struct bpf_prog_array___92 *run_array[2];
	struct bpf_prog___92 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___103 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___85 *nlsk;
	struct sock___85 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___103 xfrm4_dst_ops;
	struct dst_ops___103 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___103 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___85 *rtnl;
	struct sock___85 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___98 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___103 ipv4;
	struct netns_ipv6___103 ipv6;
	struct netns_ieee802154_lowpan___103 ieee802154_lowpan;
	struct netns_sctp___85 sctp;
	struct netns_nf___18 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___98 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___92 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___103 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___85 *crypto_nlsk;
	struct sock___85 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___216 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___216 *root_cset;
};

struct socket_wq___86 {
	wait_queue_head_t wait;
	struct fasync_struct___289 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___86;

struct socket___87 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___289 *file;
	struct sock___85 *sk;
	const struct proto_ops___86 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___86 wq;
};

typedef int (*sk_read_actor_t___85)(read_descriptor_t *, struct sk_buff___99 *, unsigned int, size_t);

struct proto_ops___86 {
	int family;
	struct module___273 *owner;
	int (*release)(struct socket___87 *);
	int (*bind)(struct socket___87 *, struct sockaddr *, int);
	int (*connect)(struct socket___87 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___87 *, struct socket___87 *);
	int (*accept)(struct socket___87 *, struct socket___87 *, int, bool);
	int (*getname)(struct socket___87 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___289 *, struct socket___87 *, struct poll_table_struct___210 *);
	int (*ioctl)(struct socket___87 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___87 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___87 *, void *, bool, bool);
	int (*listen)(struct socket___87 *, int);
	int (*shutdown)(struct socket___87 *, int);
	int (*setsockopt)(struct socket___87 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___87 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___264 *, struct socket___87 *);
	int (*sendmsg)(struct socket___87 *, struct msghdr___87 *, size_t);
	int (*recvmsg)(struct socket___87 *, struct msghdr___87 *, size_t, int);
	int (*mmap)(struct file___289 *, struct socket___87 *, struct vm_area_struct___294 *);
	ssize_t (*sendpage)(struct socket___87 *, struct page___294 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___87 *, loff_t *, struct pipe_inode_info___130 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___85 *, int);
	int (*peek_len)(struct socket___87 *);
	int (*read_sock)(struct sock___85 *, read_descriptor_t *, sk_read_actor_t___85);
	int (*sendpage_locked)(struct sock___85 *, struct page___294 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___85 *, struct msghdr___87 *, size_t);
	int (*set_rcvlowat)(struct sock___85 *, int);
};

struct dev_pm_ops___270 {
	int (*prepare)(struct device___270 *);
	void (*complete)(struct device___270 *);
	int (*suspend)(struct device___270 *);
	int (*resume)(struct device___270 *);
	int (*freeze)(struct device___270 *);
	int (*thaw)(struct device___270 *);
	int (*poweroff)(struct device___270 *);
	int (*restore)(struct device___270 *);
	int (*suspend_late)(struct device___270 *);
	int (*resume_early)(struct device___270 *);
	int (*freeze_late)(struct device___270 *);
	int (*thaw_early)(struct device___270 *);
	int (*poweroff_late)(struct device___270 *);
	int (*restore_early)(struct device___270 *);
	int (*suspend_noirq)(struct device___270 *);
	int (*resume_noirq)(struct device___270 *);
	int (*freeze_noirq)(struct device___270 *);
	int (*thaw_noirq)(struct device___270 *);
	int (*poweroff_noirq)(struct device___270 *);
	int (*restore_noirq)(struct device___270 *);
	int (*runtime_suspend)(struct device___270 *);
	int (*runtime_resume)(struct device___270 *);
	int (*runtime_idle)(struct device___270 *);
};

struct wakeup_source___270 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___270 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___270 {
	struct dev_pm_ops___270 ops;
	int (*start)(struct device___270 *);
	void (*detach)(struct device___270 *, bool);
	int (*activate)(struct device___270 *);
	void (*sync)(struct device___270 *);
	void (*dismiss)(struct device___270 *);
};

struct bus_type___270 {
	const char *name;
	const char *dev_name;
	struct device___270 *dev_root;
	const struct attribute_group___277 **bus_groups;
	const struct attribute_group___277 **dev_groups;
	const struct attribute_group___277 **drv_groups;
	int (*match)(struct device___270 *, struct device_driver___270 *);
	int (*uevent)(struct device___270 *, struct kobj_uevent_env *);
	int (*probe)(struct device___270 *);
	void (*sync_state)(struct device___270 *);
	void (*remove)(struct device___270 *);
	void (*shutdown)(struct device___270 *);
	int (*online)(struct device___270 *);
	int (*offline)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	int (*num_vf)(struct device___270 *);
	int (*dma_configure)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___270 {
	const char *name;
	struct bus_type___270 *bus;
	struct module___273 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___270 *);
	void (*sync_state)(struct device___270 *);
	int (*remove)(struct device___270 *);
	void (*shutdown)(struct device___270 *);
	int (*suspend)(struct device___270 *, pm_message_t);
	int (*resume)(struct device___270 *);
	const struct attribute_group___277 **groups;
	const struct attribute_group___277 **dev_groups;
	const struct dev_pm_ops___270 *pm;
	void (*coredump)(struct device___270 *);
	struct driver_private *p;
};

struct device_type___270 {
	const char *name;
	const struct attribute_group___277 **groups;
	int (*uevent)(struct device___270 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___270 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___270 *);
	const struct dev_pm_ops___270 *pm;
};

struct class___270 {
	const char *name;
	struct module___273 *owner;
	const struct attribute_group___277 **class_groups;
	const struct attribute_group___277 **dev_groups;
	struct kobject___277 *dev_kobj;
	int (*dev_uevent)(struct device___270 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___270 *, umode_t *);
	void (*class_release)(struct class___270 *);
	void (*dev_release)(struct device___270 *);
	int (*shutdown_pre)(struct device___270 *);
	const struct kobj_ns_type_operations___85 *ns_type;
	const void * (*namespace)(struct device___270 *);
	void (*get_ownership)(struct device___270 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___270 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___130;

struct pipe_buffer___130 {
	struct page___294 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___130 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___130 {
	int (*confirm)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
	void (*release)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
	bool (*try_steal)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
	bool (*get)(struct pipe_inode_info___130 *, struct pipe_buffer___130 *);
};

struct inet_frags___103;

struct fqdir___103 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___103 *f;
	struct net___103 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___103;

struct inet_frags___103 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___103 *, const void *);
	void (*destructor)(struct inet_frag_queue___103 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___103 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___99 *fragments_tail;
	struct sk_buff___99 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___103 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___58 {
	struct ip_ra_chain___58 *next;
	struct sock___85 *sk;
	union {
		void (*destructor)(struct sock___85 *);
		struct sock___85 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___85;

struct fib_lookup_arg___85;

struct fib_rules_ops___85 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___85 *, struct flowi *, int, struct fib_lookup_arg___85 *);
	bool (*suppress)(struct fib_rule___85 *, int, struct fib_lookup_arg___85 *);
	int (*match)(struct fib_rule___85 *, struct flowi *, int);
	int (*configure)(struct fib_rule___85 *, struct sk_buff___99 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___85 *);
	int (*compare)(struct fib_rule___85 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___85 *, struct sk_buff___99 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___85 *);
	void (*flush_cache)(struct fib_rules_ops___85 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___273 *owner;
	struct net___103 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___31 {
	u32 (*ssthresh)(struct sock___85 *);
	void (*cong_avoid)(struct sock___85 *, u32, u32);
	void (*set_state)(struct sock___85 *, u8);
	void (*cwnd_event)(struct sock___85 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___85 *, u32);
	void (*pkts_acked)(struct sock___85 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___85 *);
	void (*cong_control)(struct sock___85 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___85 *);
	u32 (*sndbuf_expand)(struct sock___85 *);
	size_t (*get_info)(struct sock___85 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___273 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___85 *);
	void (*release)(struct sock___85 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___85 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___103 *);
	int (*fib_dump)(struct net___103 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___273 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___61;

struct dst_entry___85 {
	struct net_device___98 *dev;
	struct dst_ops___103 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___99 *);
	int (*output)(struct net___103 *, struct sock___85 *, struct sk_buff___99 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___61 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___85;

struct neigh_parms___85;

struct neigh_ops___85;

struct neighbour___85 {
	struct neighbour___85 *next;
	struct neigh_table___85 *tbl;
	struct neigh_parms___85 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___98 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___85 *, struct sk_buff___99 *);
	const struct neigh_ops___85 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___98 *dev;
	u8 primary_key[0];
};

struct dcbnl_rtnl_ops___98 {
	int (*ieee_getets)(struct net_device___98 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___98 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___98 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___98 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___98 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___98 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___98 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___98 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___98 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___98 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___98 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___98 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___98 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___98 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___98 *);
	u8 (*setstate)(struct net_device___98 *, u8);
	void (*getpermhwaddr)(struct net_device___98 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___98 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___98 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___98 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___98 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___98 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___98 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___98 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___98 *, int, u8 *);
	void (*setpfccfg)(struct net_device___98 *, int, u8);
	void (*getpfccfg)(struct net_device___98 *, int, u8 *);
	u8 (*setall)(struct net_device___98 *);
	u8 (*getcap)(struct net_device___98 *, int, u8 *);
	int (*getnumtcs)(struct net_device___98 *, int, u8 *);
	int (*setnumtcs)(struct net_device___98 *, int, u8);
	u8 (*getpfcstate)(struct net_device___98 *);
	void (*setpfcstate)(struct net_device___98 *, u8);
	void (*getbcncfg)(struct net_device___98 *, int, u32 *);
	void (*setbcncfg)(struct net_device___98 *, int, u32);
	void (*getbcnrp)(struct net_device___98 *, int, u8 *);
	void (*setbcnrp)(struct net_device___98 *, int, u8);
	int (*setapp)(struct net_device___98 *, u8, u16, u8);
	int (*getapp)(struct net_device___98 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___98 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___98 *, int, u8);
	u8 (*getdcbx)(struct net_device___98 *);
	u8 (*setdcbx)(struct net_device___98 *, u8);
	int (*peer_getappinfo)(struct net_device___98 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___98 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___98 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___98 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___98 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___98 *, struct dcbnl_buffer *);
};

struct cftype___216;

struct cgroup_subsys___216 {
	struct cgroup_subsys_state___216 * (*css_alloc)(struct cgroup_subsys_state___216 *);
	int (*css_online)(struct cgroup_subsys_state___216 *);
	void (*css_offline)(struct cgroup_subsys_state___216 *);
	void (*css_released)(struct cgroup_subsys_state___216 *);
	void (*css_free)(struct cgroup_subsys_state___216 *);
	void (*css_reset)(struct cgroup_subsys_state___216 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___216 *, int);
	int (*css_extra_stat_show)(struct seq_file___264 *, struct cgroup_subsys_state___216 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___296 *, struct css_set___216 *);
	void (*cancel_fork)(struct task_struct___296 *, struct css_set___216 *);
	void (*fork)(struct task_struct___296 *);
	void (*exit)(struct task_struct___296 *);
	void (*release)(struct task_struct___296 *);
	void (*bind)(struct cgroup_subsys_state___216 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___216 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___216 *dfl_cftypes;
	struct cftype___216 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___216 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___216 *updated_children;
	struct cgroup___216 *updated_next;
};

struct cgroup_root___216 {
	struct kernfs_root___277 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___216 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___216 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___216 *ss;
	struct list_head node;
	struct kernfs_ops___277 *kf_ops;
	int (*open)(struct kernfs_open_file___277 *);
	void (*release)(struct kernfs_open_file___277 *);
	u64 (*read_u64)(struct cgroup_subsys_state___216 *, struct cftype___216 *);
	s64 (*read_s64)(struct cgroup_subsys_state___216 *, struct cftype___216 *);
	int (*seq_show)(struct seq_file___264 *, void *);
	void * (*seq_start)(struct seq_file___264 *, loff_t *);
	void * (*seq_next)(struct seq_file___264 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___264 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___216 *, struct cftype___216 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___216 *, struct cftype___216 *, s64);
	ssize_t (*write)(struct kernfs_open_file___277 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___277 *, struct poll_table_struct___210 *);
};

struct xdp_rxq_info___98 {
	struct net_device___98 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___98 {
	struct net_device___98 *dev;
};

struct xdp_buff___98 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___98 *rxq;
	struct xdp_txq_info___98 *txq;
	u32 frame_sz;
};

struct xdp_frame___98 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___98 *dev_rx;
};

struct netlink_callback___98 {
	struct sk_buff___99 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___99 *, struct netlink_callback___98 *);
	int (*done)(struct netlink_callback___98 *);
	void *data;
	struct module___273 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___98 {
	int (*create)(struct sk_buff___99 *, struct net_device___98 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___99 *, unsigned char *);
	int (*cache)(const struct neighbour___85 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___98 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___99 *);
};

struct netdev_queue___98 {
	struct net_device___98 *dev;
	struct Qdisc___92 *qdisc;
	struct Qdisc___92 *qdisc_sleeping;
	struct kobject___277 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___98 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___92 {
	struct sk_buff___99 *head;
	struct sk_buff___99 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___92;

struct Qdisc___92 {
	int (*enqueue)(struct sk_buff___99 *, struct Qdisc___92 *, struct sk_buff___99 **);
	struct sk_buff___99 * (*dequeue)(struct Qdisc___92 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___92 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___98 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___98 gso_skb;
	struct qdisc_skb_head___92 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___92 *next_sched;
	struct sk_buff_head___98 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___98 {
	struct xdp_rxq_info___98 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___277 kobj;
	struct net_device___98 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___98 {
	enum net_device_path_type type;
	const struct net_device___98 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___98 = 0,
				DEV_PATH_BR_VLAN_TAG___98 = 1,
				DEV_PATH_BR_VLAN_UNTAG___98 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___98 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___98 {
	const struct net_device___98 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___98 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___92 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___98 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___98 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___99 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___98 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___98 *dev;
	const char *name;
};

struct net_device_ops___98 {
	int (*ndo_init)(struct net_device___98 *);
	void (*ndo_uninit)(struct net_device___98 *);
	int (*ndo_open)(struct net_device___98 *);
	int (*ndo_stop)(struct net_device___98 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___99 *, struct net_device___98 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___99 *, struct net_device___98 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___98 *, struct sk_buff___99 *, struct net_device___98 *);
	void (*ndo_change_rx_flags)(struct net_device___98 *, int);
	void (*ndo_set_rx_mode)(struct net_device___98 *);
	int (*ndo_set_mac_address)(struct net_device___98 *, void *);
	int (*ndo_validate_addr)(struct net_device___98 *);
	int (*ndo_do_ioctl)(struct net_device___98 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___98 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___98 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___98 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___98 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___98 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___98 *, int);
	int (*ndo_neigh_setup)(struct net_device___98 *, struct neigh_parms___85 *);
	void (*ndo_tx_timeout)(struct net_device___98 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___98 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___98 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___98 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___98 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___98 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___98 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___98 *);
	int (*ndo_netpoll_setup)(struct net_device___98 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___98 *);
	int (*ndo_set_vf_mac)(struct net_device___98 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___98 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___98 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___98 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___98 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___98 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___98 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___98 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___98 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___98 *, int, struct sk_buff___99 *);
	int (*ndo_get_vf_guid)(struct net_device___98 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___98 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___98 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___98 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___98 *);
	int (*ndo_fcoe_disable)(struct net_device___98 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___98 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___98 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___98 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___98 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___98 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___98 *, const struct sk_buff___99 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___98 *, struct net_device___98 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___98 *, struct net_device___98 *);
	struct net_device___98 * (*ndo_get_xmit_slave)(struct net_device___98 *, struct sk_buff___99 *, bool);
	struct net_device___98 * (*ndo_sk_get_lower_dev)(struct net_device___98 *, struct sock___85 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___98 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___98 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___98 *, struct neighbour___85 *);
	void (*ndo_neigh_destroy)(struct net_device___98 *, struct neighbour___85 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___98 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___98 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___99 *, struct netlink_callback___98 *, struct net_device___98 *, struct net_device___98 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___99 *, struct nlattr **, struct net_device___98 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___98 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___99 *, u32, u32, struct net_device___98 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___98 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___98 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___98 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___98 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___98 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___98 *, struct net_device___98 *);
	void (*ndo_dfwd_del_station)(struct net_device___98 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___98 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___98 *);
	int (*ndo_change_proto_down)(struct net_device___98 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___98 *, struct sk_buff___99 *);
	void (*ndo_set_rx_headroom)(struct net_device___98 *, int);
	int (*ndo_bpf)(struct net_device___98 *, struct netdev_bpf___98 *);
	int (*ndo_xdp_xmit)(struct net_device___98 *, int, struct xdp_frame___98 **, u32);
	struct net_device___98 * (*ndo_xdp_get_xmit_slave)(struct net_device___98 *, struct xdp_buff___98 *);
	int (*ndo_xsk_wakeup)(struct net_device___98 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___98 *);
	int (*ndo_tunnel_ctl)(struct net_device___98 *, struct ip_tunnel_parm *, int);
	struct net_device___98 * (*ndo_get_peer_dev)(struct net_device___98 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___98 *, struct net_device_path___98 *);
};

struct neigh_parms___85 {
	possible_net_t___98 net;
	struct net_device___98 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___85 *);
	struct neigh_table___85 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___85 {
	u32 (*l3mdev_fib_table)(const struct net_device___98 *);
	struct sk_buff___99 * (*l3mdev_l3_rcv)(struct net_device___98 *, struct sk_buff___99 *, u16);
	struct sk_buff___99 * (*l3mdev_l3_out)(struct net_device___98 *, struct sock___85 *, struct sk_buff___99 *, u16);
	struct dst_entry___85 * (*l3mdev_link_scope_lookup)(const struct net_device___98 *, struct flowi6 *);
};

struct ndisc_ops___67 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___98 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___98 *, struct neighbour___85 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___98 *, u8, struct neighbour___85 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___98 *, struct sk_buff___99 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___103 *, struct net_device___98 *, const struct prefix_info *, struct inet6_dev___67 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___67;

struct inet6_dev___67 {
	struct net_device___98 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___67 *mc_list;
	struct ifmcaddr6___67 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___98 mc_query_queue;
	struct sk_buff_head___98 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___27 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___85 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___92;

struct tcf_block___92;

struct mini_Qdisc___92 {
	struct tcf_proto___92 *filter_list;
	struct tcf_block___92 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___92 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___98 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___98 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___103 *, struct net_device___98 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___98 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___98 *, struct list_head *);
	size_t (*get_size)(const struct net_device___98 *);
	int (*fill_info)(struct sk_buff___99 *, const struct net_device___98 *);
	size_t (*get_xstats_size)(const struct net_device___98 *);
	int (*fill_xstats)(struct sk_buff___99 *, const struct net_device___98 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___98 *, struct net_device___98 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___98 *, const struct net_device___98 *);
	int (*fill_slave_info)(struct sk_buff___99 *, const struct net_device___98 *, const struct net_device___98 *);
	struct net___103 * (*get_link_net)(const struct net_device___98 *);
	size_t (*get_linkxstats_size)(const struct net_device___98 *, int);
	int (*fill_linkxstats)(struct sk_buff___99 *, const struct net_device___98 *, int *, int);
};

struct gnet_dump___92 {
	spinlock_t *lock;
	struct sk_buff___99 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___92;

struct Qdisc_ops___92 {
	struct Qdisc_ops___92 *next;
	const struct Qdisc_class_ops___92 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___99 *, struct Qdisc___92 *, struct sk_buff___99 **);
	struct sk_buff___99 * (*dequeue)(struct Qdisc___92 *);
	struct sk_buff___99 * (*peek)(struct Qdisc___92 *);
	int (*init)(struct Qdisc___92 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___92 *);
	void (*destroy)(struct Qdisc___92 *);
	int (*change)(struct Qdisc___92 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___92 *);
	int (*change_tx_queue_len)(struct Qdisc___92 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___92 *, unsigned int);
	int (*dump)(struct Qdisc___92 *, struct sk_buff___99 *);
	int (*dump_stats)(struct Qdisc___92 *, struct gnet_dump___92 *);
	void (*ingress_block_set)(struct Qdisc___92 *, u32);
	void (*egress_block_set)(struct Qdisc___92 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___92 *);
	u32 (*egress_block_get)(struct Qdisc___92 *);
	struct module___273 *owner;
};

struct Qdisc_class_ops___92 {
	unsigned int flags;
	struct netdev_queue___98 * (*select_queue)(struct Qdisc___92 *, struct tcmsg *);
	int (*graft)(struct Qdisc___92 *, long unsigned int, struct Qdisc___92 *, struct Qdisc___92 **, struct netlink_ext_ack *);
	struct Qdisc___92 * (*leaf)(struct Qdisc___92 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___92 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___92 *, u32);
	int (*change)(struct Qdisc___92 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___92 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___92 *, struct qdisc_walker *);
	struct tcf_block___92 * (*tcf_block)(struct Qdisc___92 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___92 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___92 *, long unsigned int);
	int (*dump)(struct Qdisc___92 *, long unsigned int, struct sk_buff___99 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___92 *, long unsigned int, struct gnet_dump___92 *);
};

struct tcf_chain___92;

struct tcf_block___92 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___103 *net;
	struct Qdisc___92 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___92 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___92;

struct tcf_proto_ops___92;

struct tcf_proto___92 {
	struct tcf_proto___92 *next;
	void *root;
	int (*classify)(struct sk_buff___99 *, const struct tcf_proto___92 *, struct tcf_result___92 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___92 *ops;
	struct tcf_chain___92 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___92 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___92 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___92 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___99 *, const struct tcf_proto___92 *, struct tcf_result___92 *);
	int (*init)(struct tcf_proto___92 *);
	void (*destroy)(struct tcf_proto___92 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___92 *, u32);
	void (*put)(struct tcf_proto___92 *, void *);
	int (*change)(struct net___103 *, struct sk_buff___99 *, struct tcf_proto___92 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___92 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___92 *);
	void (*walk)(struct tcf_proto___92 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___92 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___92 *, void *);
	void (*hw_del)(struct tcf_proto___92 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___103 *, struct tcf_chain___92 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___103 *, struct tcf_proto___92 *, void *, struct sk_buff___99 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___103 *, struct tcf_proto___92 *, void *, struct sk_buff___99 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___99 *, struct net___103 *, void *);
	struct module___273 *owner;
	int flags;
};

struct tcf_chain___92 {
	struct mutex filter_chain_lock;
	struct tcf_proto___92 *filter_chain;
	struct list_head list;
	struct tcf_block___92 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___92 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___85 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___92 *prog;
};

struct block_device_operations___180;

struct gendisk___183 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___183 *part0;
	const struct block_device_operations___180 *fops;
	struct request_queue___180 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___166 *bdi;
	struct kobject___277 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___277 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___180 {
	struct bio___180 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___206 *bip_vec;
	struct bio_vec___206 bip_inline_vecs[0];
};

struct blkcg___168;

struct blkg_policy_data___168;

struct blkcg_gq___168 {
	struct request_queue___180 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___168 *blkcg;
	struct blkcg_gq___168 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___168 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___180 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___180(struct request___180 *);

typedef void integrity_complete_fn___180(struct request___180 *, unsigned int);

struct blk_integrity_profile___180 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___180 *prepare_fn;
	integrity_complete_fn___180 *complete_fn;
	const char *name;
};

struct block_device_operations___180 {
	blk_qc_t (*submit_bio)(struct bio___180 *);
	int (*open)(struct block_device___183 *, fmode_t);
	void (*release)(struct gendisk___183 *, fmode_t);
	int (*rw_page)(struct block_device___183 *, sector_t, struct page___294 *, unsigned int);
	int (*ioctl)(struct block_device___183 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___183 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___183 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___183 *);
	int (*getgeo)(struct block_device___183 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___183 *, bool);
	void (*swap_slot_free_notify)(struct block_device___183 *, long unsigned int);
	int (*report_zones)(struct gendisk___183 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___183 *, umode_t *);
	struct module___273 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___183 *, sector_t *);
};

typedef void rq_end_io_fn___180(struct request___180 *, blk_status_t);

struct request___180 {
	struct request_queue___180 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___175 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___180 *bio;
	struct bio___180 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___206 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___180 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___180 *saved_end_io;
		} flush;
	};
	struct gendisk___183 *rq_disk;
	struct block_device___183 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___180 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___175 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___180 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___277 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___289 *debugfs_dir;
	struct dentry___289 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___180;

struct elevator_mq_ops___180 {
	int (*init_sched)(struct request_queue___180 *, struct elevator_type___180 *);
	void (*exit_sched)(struct elevator_queue___180 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___175 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___175 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___175 *);
	bool (*allow_merge)(struct request_queue___180 *, struct request___180 *, struct bio___180 *);
	bool (*bio_merge)(struct request_queue___180 *, struct bio___180 *, unsigned int);
	int (*request_merge)(struct request_queue___180 *, struct request___180 **, struct bio___180 *);
	void (*request_merged)(struct request_queue___180 *, struct request___180 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___180 *, struct request___180 *, struct request___180 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___180 *);
	void (*finish_request)(struct request___180 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___175 *, struct list_head *, bool);
	struct request___180 * (*dispatch_request)(struct blk_mq_hw_ctx___175 *);
	bool (*has_work)(struct blk_mq_hw_ctx___175 *);
	void (*completed_request)(struct request___180 *, u64);
	void (*requeue_request)(struct request___180 *);
	struct request___180 * (*former_request)(struct request_queue___180 *, struct request___180 *);
	struct request___180 * (*next_request)(struct request_queue___180 *, struct request___180 *);
	void (*init_icq)(struct io_cq___180 *);
	void (*exit_icq)(struct io_cq___180 *);
};

struct elv_fs_entry___180;

struct elevator_type___180 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___180 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___180 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___273 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___180 {
	struct elevator_type___180 *type;
	void *elevator_data;
	struct kobject___277 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___180 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___180 *, char *);
	ssize_t (*store)(struct elevator_queue___180 *, const char *, size_t);
};

struct blk_mq_queue_data___175;

struct blk_mq_ops___175 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___175 *, const struct blk_mq_queue_data___175 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___175 *);
	int (*get_budget)(struct request_queue___180 *);
	void (*put_budget)(struct request_queue___180 *, int);
	void (*set_rq_budget_token)(struct request___180 *, int);
	int (*get_rq_budget_token)(struct request___180 *);
	enum blk_eh_timer_return (*timeout)(struct request___180 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___175 *);
	void (*complete)(struct request___180 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___175 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___175 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___175 *, struct request___180 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___175 *, struct request___180 *, unsigned int);
	void (*initialize_rq_fn)(struct request___180 *);
	void (*cleanup_rq)(struct request___180 *);
	bool (*busy)(struct request_queue___180 *);
	int (*map_queues)(struct blk_mq_tag_set___175 *);
	void (*show_rq)(struct seq_file___264 *, struct request___180 *);
};

struct blk_mq_tag_set___175 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___175 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___175 {
	struct request___180 *rq;
	bool last;
};

struct blkcg_policy_data___168;

struct blkcg___168 {
	struct cgroup_subsys_state___216 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___168 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___168 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___168 {
	struct blkcg___168 *blkcg;
	int plid;
};

struct blkg_policy_data___168 {
	struct blkcg_gq___168 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___154 {
	struct mem_cgroup___154 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___154 {
	struct lruvec___162 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___154 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___154 *memcg;
};

struct obj_cgroup___154 {
	struct percpu_ref refcnt;
	struct mem_cgroup___154 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct pneigh_entry___85;

struct neigh_hash_table___85;

struct neigh_table___85 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___98 *, __u32 *);
	bool (*key_eq)(const struct neighbour___85 *, const void *);
	int (*constructor)(struct neighbour___85 *);
	int (*pconstructor)(struct pneigh_entry___85 *);
	void (*pdestructor)(struct pneigh_entry___85 *);
	void (*proxy_redo)(struct sk_buff___99 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___98 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___85 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___98 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___85 *nht;
	struct pneigh_entry___85 **phash_buckets;
};

struct neigh_ops___85 {
	int family;
	void (*solicit)(struct neighbour___85 *, struct sk_buff___99 *);
	void (*error_report)(struct neighbour___85 *, struct sk_buff___99 *);
	int (*output)(struct neighbour___85 *, struct sk_buff___99 *);
	int (*connected_output)(struct neighbour___85 *, struct sk_buff___99 *);
};

struct pneigh_entry___85 {
	struct pneigh_entry___85 *next;
	possible_net_t___98 net;
	struct net_device___98 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___85 {
	struct neighbour___85 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___61 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___103 *, struct sock___85 *, struct sk_buff___99 *);
	int (*orig_input)(struct sk_buff___99 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___85 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___85 *ctarget;
	struct net___103 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___85 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___85 *rule;
	u32 table;
	int flags;
};

struct sk_psock___6;

struct request_sock_ops___70;

struct timewait_sock_ops___69;

struct proto___85 {
	void (*close)(struct sock___85 *, long int);
	int (*pre_connect)(struct sock___85 *, struct sockaddr *, int);
	int (*connect)(struct sock___85 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___85 *, int);
	struct sock___85 * (*accept)(struct sock___85 *, int, int *, bool);
	int (*ioctl)(struct sock___85 *, int, long unsigned int);
	int (*init)(struct sock___85 *);
	void (*destroy)(struct sock___85 *);
	void (*shutdown)(struct sock___85 *, int);
	int (*setsockopt)(struct sock___85 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___85 *, int, int, char *, int *);
	void (*keepalive)(struct sock___85 *, int);
	int (*compat_ioctl)(struct sock___85 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___85 *, struct msghdr___87 *, size_t);
	int (*recvmsg)(struct sock___85 *, struct msghdr___87 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___85 *, struct page___294 *, int, size_t, int);
	int (*bind)(struct sock___85 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___85 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___85 *, struct sk_buff___99 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___85 *);
	int (*hash)(struct sock___85 *);
	void (*unhash)(struct sock___85 *);
	void (*rehash)(struct sock___85 *);
	int (*get_port)(struct sock___85 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___85 *, struct sk_psock___6 *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___85 *, int);
	bool (*sock_is_readable)(struct sock___85 *);
	void (*enter_memory_pressure)(struct sock___85 *);
	void (*leave_memory_pressure)(struct sock___85 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___70 *rsk_prot;
	struct timewait_sock_ops___69 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___273 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___85 *, int);
};

struct sock_reuseport___33 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___92 *prog;
	struct sock___85 *socks[0];
};

struct sk_psock_progs___6 {
	struct bpf_prog___92 *msg_parser;
	struct bpf_prog___92 *stream_parser;
	struct bpf_prog___92 *stream_verdict;
	struct bpf_prog___92 *skb_verdict;
};

struct strparser___6;

struct strp_callbacks___6 {
	int (*parse_msg)(struct strparser___6 *, struct sk_buff___99 *);
	void (*rcv_msg)(struct strparser___6 *, struct sk_buff___99 *);
	int (*read_sock_done)(struct strparser___6 *, int);
	void (*abort_parser)(struct strparser___6 *, int);
	void (*lock)(struct strparser___6 *);
	void (*unlock)(struct strparser___6 *);
};

struct strparser___6 {
	struct sock___85 *sk;
	u32 stopped;
	u32 paused;
	u32 aborted;
	u32 interrupted;
	u32 unrecov_intr;
	long: 32;
	long: 64;
	struct sk_buff___99 **skb_nextp;
	struct sk_buff___99 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___6 cb;
};

struct sk_psock_work_state___6 {
	struct sk_buff___99 *skb;
	u32 len;
	u32 off;
};

struct sk_msg___6;

struct sk_psock___6 {
	struct sock___85 *sk;
	struct sock___85 *sk_redir;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 eval;
	struct sk_msg___6 *cork;
	struct sk_psock_progs___6 progs;
	struct strparser___6 strp;
	struct sk_buff_head___98 ingress_skb;
	struct list_head ingress_msg;
	spinlock_t ingress_lock;
	long unsigned int state;
	struct list_head link;
	spinlock_t link_lock;
	refcount_t refcnt;
	void (*saved_unhash)(struct sock___85 *);
	void (*saved_close)(struct sock___85 *, long int);
	void (*saved_write_space)(struct sock___85 *);
	void (*saved_data_ready)(struct sock___85 *);
	int (*psock_update_sk_prot)(struct sock___85 *, struct sk_psock___6 *, bool);
	struct proto___85 *sk_proto;
	struct mutex work_mutex;
	struct sk_psock_work_state___6 work_state;
	struct work_struct work;
	struct rcu_work rwork;
};

struct request_sock___71;

struct request_sock_ops___70 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___85 *, struct request_sock___71 *);
	void (*send_ack)(const struct sock___85 *, struct sk_buff___99 *, struct request_sock___71 *);
	void (*send_reset)(const struct sock___85 *, struct sk_buff___99 *);
	void (*destructor)(struct request_sock___71 *);
	void (*syn_ack_timeout)(const struct request_sock___71 *);
};

struct timewait_sock_ops___69 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___85 *, struct sock___85 *, void *);
	void (*twsk_destructor)(struct sock___85 *);
};

struct request_sock___71 {
	struct sock_common___85 __req_common;
	struct request_sock___71 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___70 *rsk_ops;
	struct sock___85 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___67 {
	struct in6_addr mca_addr;
	struct inet6_dev___67 *idev;
	struct ifmcaddr6___67 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct sk_msg___6 {
	struct sk_msg_sg sg;
	void *data;
	void *data_end;
	u32 apply_bytes;
	u32 cork_bytes;
	u32 flags;
	struct sk_buff___99 *skb;
	struct sock___85 *sk_redir;
	struct sock___85 *sk;
	struct list_head list;
};

struct unix_sock___5 {
	struct sock___85 sk;
	struct unix_address *addr;
	struct path___289 path;
	struct mutex iolock;
	struct mutex bindlock;
	struct sock___85 *peer;
	struct list_head link;
	atomic_long_t inflight;
	spinlock_t lock;
	long unsigned int gc_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___86 peer_wq;
	wait_queue_entry_t peer_wake;
	struct scm_stat scm_stat;
	struct sk_buff___99 *oob_skb;
	long: 64;
};

struct scm_cookie___4 {
	struct pid___260 *pid;
	struct scm_fp_list___5 *fp;
	struct scm_creds creds;
	struct lsmblob lsmblob;
};

struct socket_alloc___6 {
	struct socket___81 socket;
	struct inode___283 vfs_inode;
	long: 64;
};

struct net_proto_family___4 {
	int family;
	int (*create)(struct net___90 *, struct socket___74 *, int, int);
	struct module___260 *owner;
};

struct ioam6_pernet_data {
	struct mutex lock;
	struct rhashtable namespaces;
	struct rhashtable schemas;
};

struct packet_type___7 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___85 *dev;
	int (*func)(struct sk_buff___86 *, struct net_device___85 *, struct packet_type___7 *, struct net_device___85 *);
	void (*list_func)(struct list_head *, struct packet_type___7 *, struct net_device___85 *);
	bool (*id_match)(struct packet_type___7 *, struct sock___72 *);
	struct net___90 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct ipv6_params {
	__s32 disable_ipv6;
	__s32 autoconf;
};

typedef struct poll_table_struct___197 poll_table___54;

struct ipv6_bpf_stub___2 {
	int (*inet6_bind)(struct sock___72 *, struct sockaddr *, int, u32);
	struct sock___72 * (*udp6_lib_lookup)(struct net___90 *, const struct in6_addr *, __be16, const struct in6_addr *, __be16, int, int, struct udp_table *, struct sk_buff___86 *);
};

enum flowlabel_reflect {
	FLOWLABEL_REFLECT_ESTABLISHED = 1,
	FLOWLABEL_REFLECT_TCP_RESET = 2,
	FLOWLABEL_REFLECT_ICMPV6_ECHO_REPLIES = 4,
};

struct inet_protosw___3 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___72 *prot;
	const struct proto_ops___73 *ops;
	unsigned char flags;
};

struct in6_rtmsg {
	struct in6_addr rtmsg_dst;
	struct in6_addr rtmsg_src;
	struct in6_addr rtmsg_gateway;
	__u32 rtmsg_type;
	__u16 rtmsg_dst_len;
	__u16 rtmsg_src_len;
	__u32 rtmsg_metric;
	long unsigned int rtmsg_info;
	__u32 rtmsg_flags;
	int rtmsg_ifindex;
};

struct compat_in6_rtmsg {
	struct in6_addr rtmsg_dst;
	struct in6_addr rtmsg_src;
	struct in6_addr rtmsg_gateway;
	u32 rtmsg_type;
	u16 rtmsg_dst_len;
	u16 rtmsg_src_len;
	u32 rtmsg_metric;
	u32 rtmsg_info;
	u32 rtmsg_flags;
	s32 rtmsg_ifindex;
};

struct ac6_iter_state {
	struct seq_net_private___11 p;
	struct net_device___95 *dev;
	struct inet6_dev___64 *idev;
};

struct ubuf_info___13 {
	void (*callback)(struct sk_buff___86 *, struct ubuf_info___13 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___33 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___86 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___35 frags[17];
};

struct napi_struct___15 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___15 *, int);
	int poll_owner;
	struct net_device___85 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___86 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___283 *thread;
};

struct softnet_data___7 {
	struct list_head poll_list;
	struct sk_buff_head___85 process_queue;
	unsigned int processed;
	unsigned int time_squeeze;
	unsigned int received_rps;
	struct softnet_data___7 *rps_ipi_list;
	struct sd_flow_limit *flow_limit;
	struct Qdisc___79 *output_queue;
	struct Qdisc___79 **output_queue_tailp;
	struct sk_buff___86 *completion_queue;
	struct sk_buff_head___85 xfrm_backlog;
	struct {
		u16 recursion;
		u8 more;
	} xmit;
	int: 32;
	unsigned int input_queue_head;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	call_single_data_t csd;
	struct softnet_data___7 *rps_ipi_next;
	unsigned int cpu;
	unsigned int input_queue_tail;
	unsigned int dropped;
	struct sk_buff_head___85 input_pkt_queue;
	struct napi_struct___15 backlog;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct ip6_fraglist_iter {
	struct ipv6hdr *tmp_hdr;
	struct sk_buff___86 *frag;
	int offset;
	unsigned int hlen;
	__be32 frag_id;
	u8 nexthdr;
};

struct ip6_frag_state {
	u8 *prevhdr;
	unsigned int hlen;
	unsigned int mtu;
	unsigned int left;
	int offset;
	int ptr;
	int hroom;
	int troom;
	__be32 frag_id;
	u8 nexthdr;
};

struct ip6_ra_chain {
	struct ip6_ra_chain *next;
	struct sock___72 *sk;
	int sel;
	void (*destructor)(struct sock___72 *);
};

struct ipcm6_cookie {
	struct sockcm_cookie sockc;
	__s16 hlimit;
	__s16 tclass;
	__s8 dontfrag;
	struct ipv6_txoptions *opt;
	__u16 gso_size;
};

struct xfrm_dst___6 {
	union {
		struct dst_entry___72 dst;
		struct rtable___22 rt;
		struct rt6_info___21 rt6;
	} u;
	struct dst_entry___72 *route;
	struct dst_entry___72 *child;
	struct dst_entry___72 *path;
	struct xfrm_policy___15 *pols[2];
	int num_pols;
	int num_xfrms;
	u32 xfrm_genid;
	u32 policy_genid;
	u32 route_mtu_cached;
	u32 child_mtu_cached;
	u32 route_cookie;
	u32 path_cookie;
};

struct dentry___290;

struct super_block___290;

struct module___274;

struct file_system_type___290 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___290 * (*mount)(struct file_system_type___290 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___290 *);
	struct module___274 *owner;
	struct file_system_type___290 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___290;

struct kiocb___290;

struct iov_iter___210;

struct poll_table_struct___211;

struct vm_area_struct___295;

struct inode___290;

struct file_lock___290;

struct page___295;

struct pipe_inode_info___131;

struct seq_file___265;

struct file_operations___291 {
	struct module___274 *owner;
	loff_t (*llseek)(struct file___290 *, loff_t, int);
	ssize_t (*read)(struct file___290 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___290 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___290 *, struct iov_iter___210 *);
	ssize_t (*write_iter)(struct kiocb___290 *, struct iov_iter___210 *);
	int (*iopoll)(struct kiocb___290 *, bool);
	int (*iterate)(struct file___290 *, struct dir_context *);
	int (*iterate_shared)(struct file___290 *, struct dir_context *);
	__poll_t (*poll)(struct file___290 *, struct poll_table_struct___211 *);
	long int (*unlocked_ioctl)(struct file___290 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___290 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___290 *, struct vm_area_struct___295 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___290 *, struct file___290 *);
	int (*flush)(struct file___290 *, fl_owner_t);
	int (*release)(struct inode___290 *, struct file___290 *);
	int (*fsync)(struct file___290 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___290 *, int);
	int (*lock)(struct file___290 *, int, struct file_lock___290 *);
	ssize_t (*sendpage)(struct file___290 *, struct page___295 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___290 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___290 *, long unsigned int);
	int (*flock)(struct file___290 *, int, struct file_lock___290 *);
	ssize_t (*splice_write)(struct pipe_inode_info___131 *, struct file___290 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___290 *, loff_t *, struct pipe_inode_info___131 *, size_t, unsigned int);
	int (*setlease)(struct file___290 *, long int, struct file_lock___290 **, void **);
	long int (*fallocate)(struct file___290 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___265 *, struct file___290 *);
	ssize_t (*copy_file_range)(struct file___290 *, loff_t, struct file___290 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___290 *, loff_t, struct file___290 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___290 *, loff_t, loff_t, int);
};

struct bio_vec___207 {
	struct page___295 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___290;

struct pipe_buffer___131;

struct pipe_inode_info___131 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___295 *tmp_page;
	struct fasync_struct___290 *fasync_readers;
	struct fasync_struct___290 *fasync_writers;
	struct pipe_buffer___131 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___210 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___207 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___131 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___88 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___210 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___290 *msg_iocb;
};

struct kiocb___290 {
	struct file___290 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___290 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct kset___278;

struct kobj_type___278;

struct kernfs_node___278;

struct kobject___278 {
	const char *name;
	struct list_head entry;
	struct kobject___278 *parent;
	struct kset___278 *kset;
	struct kobj_type___278 *ktype;
	struct kernfs_node___278 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___275 {
	struct kobject___278 kobj;
	struct module___274 *mod;
	struct kobject___278 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___274 {
	struct module___274 *mod;
	struct latch_tree_node node;
};

struct module_layout___274 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___274 mtn;
};

struct module_attribute___274;

struct kernel_param___274;

struct module___274 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___275 mkobj;
	struct module_attribute___274 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___278 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___274 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___274 core_layout;
	struct module_layout___274 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___295 {
	u64 seqnum;
	struct vm_area_struct___295 *vmas[4];
};

struct page_frag___295 {
	struct page___295 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___296;

struct pid___267;

struct nsproxy___276;

struct signal_struct___291;

struct bio_list___181;

struct backing_dev_info___167;

struct io_context___181;

struct css_set___217;

struct mem_cgroup___155;

struct request_queue___181;

struct vm_struct___273;

struct task_struct___297 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___297 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___296 *mm;
	struct mm_struct___296 *active_mm;
	struct vmacache___295 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___297 *real_parent;
	struct task_struct___297 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___297 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___267 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___276 *nsproxy;
	struct signal_struct___291 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___297 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___181 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___167 *backing_dev_info;
	struct io_context___181 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___217 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___131 *splice_pipe;
	struct page_frag___295 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___155 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___155 *active_memcg;
	struct request_queue___181 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___297 *oom_reaper_list;
	struct vm_struct___273 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___267;

struct upid___267 {
	int nr;
	struct pid_namespace___267 *ns;
};

struct pid_namespace___267 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___297 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___267 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___267 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___267 numbers[1];
};

typedef struct page___295 *pgtable_t___295;

struct address_space___290;

struct page_pool___119;

struct dev_pagemap___285;

struct page___295 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___290 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___119 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___295 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___295 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___296 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___285 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___285;

struct vm_area_struct___295 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___295 *vm_next;
	struct vm_area_struct___295 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___296 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___285 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___290 *vm_file;
	struct file___290 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___291 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___297 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___297 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___267 *pids[4];
	struct pid___267 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___296 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___295;

struct mm_struct___296 {
	struct {
		struct vm_area_struct___295 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___290 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___295 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___297 *owner;
		struct user_namespace___26 *user_ns;
		struct file___290 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___104;

struct cgroup_namespace___217;

struct nsproxy___276 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___267 *pid_ns_for_children;
	struct net___104 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___217 *cgroup_ns;
};

struct bio___181;

struct bio_list___181 {
	struct bio___181 *head;
	struct bio___181 *tail;
};

struct cgroup_subsys_state___217;

struct bdi_writeback___167 {
	struct backing_dev_info___167 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___217 *memcg_css;
	struct cgroup_subsys_state___217 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___271;

struct backing_dev_info___167 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___167 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___271 *dev;
	char dev_name[64];
	struct device___271 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___290 *debug_dir;
};

struct io_cq___181;

struct io_context___181 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___181 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___217;

struct css_set___217 {
	struct cgroup_subsys_state___217 *subsys[14];
	refcount_t refcount;
	struct css_set___217 *dom_cset;
	struct cgroup___217 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___217 *mg_src_cgrp;
	struct cgroup___217 *mg_dst_cgrp;
	struct css_set___217 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___217;

struct cgroup_subsys_state___217 {
	struct cgroup___217 *cgroup;
	struct cgroup_subsys___217 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___217 *parent;
};

struct cgroup_file___217 {
	struct kernfs_node___278 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___155;

struct mem_cgroup_per_node___155;

struct mem_cgroup___155 {
	struct cgroup_subsys_state___217 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___217 events_file;
	struct cgroup_file___217 events_local_file;
	struct cgroup_file___217 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___155 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___297 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___155 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___181;

struct blk_integrity___181 {
	const struct blk_integrity_profile___181 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___181 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___181 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___181;

struct elevator_queue___181;

struct blk_mq_ops___176;

struct blk_mq_hw_ctx___176;

struct gendisk___184;

struct blkcg_gq___169;

struct blk_mq_tag_set___176;

struct request_queue___181 {
	struct request___181 *last_merge;
	struct elevator_queue___181 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___176 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___176 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___184 *disk;
	struct kobject___278 kobj;
	struct kobject___278 *mq_kobj;
	struct blk_integrity___181 integrity;
	struct device___271 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___169 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___176 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___181 bio_split;
	struct dentry___290 *debugfs_dir;
	struct dentry___290 *sched_debugfs_dir;
	struct dentry___290 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___273 {
	struct vm_struct___273 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___295 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___290;

struct dentry___290 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___290 *d_parent;
	struct qstr d_name;
	struct inode___290 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___290 *d_op;
	struct super_block___290 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___290;

struct address_space___290 {
	struct inode___290 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___290 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___290;

struct inode___290 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___290 *i_op;
	struct super_block___290 *i_sb;
	struct address_space___290 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___167 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___291 *i_fop;
		void (*free_inode)(struct inode___290 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___290 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___131 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___290;

struct path___290;

struct dentry_operations___290 {
	int (*d_revalidate)(struct dentry___290 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___290 *, unsigned int);
	int (*d_hash)(const struct dentry___290 *, struct qstr *);
	int (*d_compare)(const struct dentry___290 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___290 *);
	int (*d_init)(struct dentry___290 *);
	void (*d_release)(struct dentry___290 *);
	void (*d_prune)(struct dentry___290 *);
	void (*d_iput)(struct dentry___290 *, struct inode___290 *);
	char * (*d_dname)(struct dentry___290 *, char *, int);
	struct vfsmount___290 * (*d_automount)(struct path___290 *);
	int (*d_manage)(const struct path___290 *, bool);
	struct dentry___290 * (*d_real)(struct dentry___290 *, const struct inode___290 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___290;

struct mem_dqinfo___290 {
	struct quota_format_type___290 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___290;

struct quota_info___290 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___290 *files[3];
	struct mem_dqinfo___290 info[3];
	const struct quota_format_ops___290 *ops[3];
};

struct rcuwait___291 {
	struct task_struct___297 *task;
};

struct percpu_rw_semaphore___291 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___291 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___290 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___291 rw_sem[3];
};

struct shrink_control___155;

struct shrinker___155 {
	long unsigned int (*count_objects)(struct shrinker___155 *, struct shrink_control___155 *);
	long unsigned int (*scan_objects)(struct shrinker___155 *, struct shrink_control___155 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___290;

struct dquot_operations___290;

struct quotactl_ops___290;

struct block_device___184;

struct super_block___290 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___290 *s_type;
	const struct super_operations___290 *s_op;
	const struct dquot_operations___290 *dq_op;
	const struct quotactl_ops___290 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___290 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___184 *s_bdev;
	struct backing_dev_info___167 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___290 s_dquot;
	struct sb_writers___290 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___290 *s_d_op;
	int cleancache_poolid;
	struct shrinker___155 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___290 {
	struct dentry___290 *mnt_root;
	struct super_block___290 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___290 {
	struct vfsmount___290 *mnt;
	struct dentry___290 *dentry;
};

struct shrink_control___155 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___155 *memcg;
};

struct page_pool_params___119 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___271 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___119 {
	u32 count;
	struct page___295 *cache[128];
};

struct page_pool___119 {
	struct page_pool_params___119 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___295 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___119 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___285;

struct dev_pagemap___285 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___285 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___267 {
	rwlock_t lock;
	struct pid___267 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___290 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___290 f_path;
	struct inode___290 *f_inode;
	const struct file_operations___291 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___267 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___290 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___285;

struct vm_operations_struct___285 {
	void (*open)(struct vm_area_struct___295 *);
	void (*close)(struct vm_area_struct___295 *);
	int (*may_split)(struct vm_area_struct___295 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___295 *);
	int (*mprotect)(struct vm_area_struct___295 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___285 *);
	vm_fault_t (*huge_fault)(struct vm_fault___285 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___285 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___295 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___285 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___285 *);
	int (*access)(struct vm_area_struct___295 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___295 *);
	int (*set_policy)(struct vm_area_struct___295 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___295 *, long unsigned int);
	struct page___295 * (*find_special_page)(struct vm_area_struct___295 *, long unsigned int);
};

struct core_thread___295 {
	struct task_struct___297 *task;
	struct core_thread___295 *next;
};

struct core_state___295 {
	atomic_t nr_threads;
	struct core_thread___295 dumper;
	struct completion startup;
};

struct vm_fault___285 {
	const struct {
		struct vm_area_struct___295 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___295 *cow_page;
	struct page___295 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___295 prealloc_pte;
};

struct pglist_data___163;

struct lruvec___163 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___163 *pgdat;
};

struct zone___163 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___163 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___163 {
	struct zone___163 *zone;
	int zone_idx;
};

struct zonelist___163 {
	struct zoneref___163 _zonerefs[321];
};

struct pglist_data___163 {
	struct zone___163 node_zones[5];
	struct zonelist___163 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___297 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___297 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___163 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___217 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___297 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___93;

struct cgroup_bpf___93 {
	struct bpf_prog_array___93 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___93 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___217;

struct cgroup_rstat_cpu___217;

struct cgroup___217 {
	struct cgroup_subsys_state___217 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___278 *kn;
	struct cgroup_file___217 procs_file;
	struct cgroup_file___217 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___217 *subsys[14];
	struct cgroup_root___217 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___217 *dom_cgrp;
	struct cgroup___217 *old_dom_cgrp;
	struct cgroup_rstat_cpu___217 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___217 psi;
	struct cgroup_bpf___93 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___181 {
	struct request_queue___181 *q;
	struct io_context___181 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___290 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___290 *ia_file;
};

struct dquot___290 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___290 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___290 {
	int qf_fmt_id;
	const struct quota_format_ops___290 *qf_ops;
	struct module___274 *qf_owner;
	struct quota_format_type___290 *qf_next;
};

struct quota_format_ops___290 {
	int (*check_quota_file)(struct super_block___290 *, int);
	int (*read_file_info)(struct super_block___290 *, int);
	int (*write_file_info)(struct super_block___290 *, int);
	int (*free_file_info)(struct super_block___290 *, int);
	int (*read_dqblk)(struct dquot___290 *);
	int (*commit_dqblk)(struct dquot___290 *);
	int (*release_dqblk)(struct dquot___290 *);
	int (*get_next_id)(struct super_block___290 *, struct kqid *);
};

struct dquot_operations___290 {
	int (*write_dquot)(struct dquot___290 *);
	struct dquot___290 * (*alloc_dquot)(struct super_block___290 *, int);
	void (*destroy_dquot)(struct dquot___290 *);
	int (*acquire_dquot)(struct dquot___290 *);
	int (*release_dquot)(struct dquot___290 *);
	int (*mark_dirty)(struct dquot___290 *);
	int (*write_info)(struct super_block___290 *, int);
	qsize_t * (*get_reserved_space)(struct inode___290 *);
	int (*get_projid)(struct inode___290 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___290 *, qsize_t *);
	int (*get_next_id)(struct super_block___290 *, struct kqid *);
};

struct quotactl_ops___290 {
	int (*quota_on)(struct super_block___290 *, int, int, const struct path___290 *);
	int (*quota_off)(struct super_block___290 *, int);
	int (*quota_enable)(struct super_block___290 *, unsigned int);
	int (*quota_disable)(struct super_block___290 *, unsigned int);
	int (*quota_sync)(struct super_block___290 *, int);
	int (*set_info)(struct super_block___290 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___290 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___290 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___290 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___290 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___290 *, unsigned int);
};

struct writeback_control___167;

struct address_space_operations___290 {
	int (*writepage)(struct page___295 *, struct writeback_control___167 *);
	int (*readpage)(struct file___290 *, struct page___295 *);
	int (*writepages)(struct address_space___290 *, struct writeback_control___167 *);
	int (*set_page_dirty)(struct page___295 *);
	int (*readpages)(struct file___290 *, struct address_space___290 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___290 *, struct address_space___290 *, loff_t, unsigned int, unsigned int, struct page___295 **, void **);
	int (*write_end)(struct file___290 *, struct address_space___290 *, loff_t, unsigned int, unsigned int, struct page___295 *, void *);
	sector_t (*bmap)(struct address_space___290 *, sector_t);
	void (*invalidatepage)(struct page___295 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___295 *, gfp_t);
	void (*freepage)(struct page___295 *);
	ssize_t (*direct_IO)(struct kiocb___290 *, struct iov_iter___210 *);
	int (*migratepage)(struct address_space___290 *, struct page___295 *, struct page___295 *, enum migrate_mode);
	bool (*isolate_page)(struct page___295 *, isolate_mode_t);
	void (*putback_page)(struct page___295 *);
	int (*launder_page)(struct page___295 *);
	int (*is_partially_uptodate)(struct page___295 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___295 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___290 *, struct page___295 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___290 *, sector_t *);
	void (*swap_deactivate)(struct file___290 *);
};

struct writeback_control___167 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___167 *wb;
	struct inode___290 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___290 {
	struct dentry___290 * (*lookup)(struct inode___290 *, struct dentry___290 *, unsigned int);
	const char * (*get_link)(struct dentry___290 *, struct inode___290 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___290 *, int);
	struct posix_acl * (*get_acl)(struct inode___290 *, int, bool);
	int (*readlink)(struct dentry___290 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___290 *, struct dentry___290 *, umode_t, bool);
	int (*link)(struct dentry___290 *, struct inode___290 *, struct dentry___290 *);
	int (*unlink)(struct inode___290 *, struct dentry___290 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___290 *, struct dentry___290 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___290 *, struct dentry___290 *, umode_t);
	int (*rmdir)(struct inode___290 *, struct dentry___290 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___290 *, struct dentry___290 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___290 *, struct dentry___290 *, struct inode___290 *, struct dentry___290 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___290 *, struct iattr___290 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___290 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___290 *, char *, size_t);
	int (*fiemap)(struct inode___290 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___290 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___290 *, struct dentry___290 *, struct file___290 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___290 *, struct dentry___290 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___290 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___290 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___290 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___290 {
	void (*fl_copy_lock)(struct file_lock___290 *, struct file_lock___290 *);
	void (*fl_release_private)(struct file_lock___290 *);
};

struct lock_manager_operations___290;

struct file_lock___290 {
	struct file_lock___290 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___290 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___290 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___290 *fl_ops;
	const struct lock_manager_operations___290 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___290 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___290 *);
	int (*lm_grant)(struct file_lock___290 *, int);
	bool (*lm_break)(struct file_lock___290 *);
	int (*lm_change)(struct file_lock___290 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___290 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___290 *);
};

struct fasync_struct___290 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___290 *fa_next;
	struct file___290 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___290 {
	struct inode___290 * (*alloc_inode)(struct super_block___290 *);
	void (*destroy_inode)(struct inode___290 *);
	void (*free_inode)(struct inode___290 *);
	void (*dirty_inode)(struct inode___290 *, int);
	int (*write_inode)(struct inode___290 *, struct writeback_control___167 *);
	int (*drop_inode)(struct inode___290 *);
	void (*evict_inode)(struct inode___290 *);
	void (*put_super)(struct super_block___290 *);
	int (*sync_fs)(struct super_block___290 *, int);
	int (*freeze_super)(struct super_block___290 *);
	int (*freeze_fs)(struct super_block___290 *);
	int (*thaw_super)(struct super_block___290 *);
	int (*unfreeze_fs)(struct super_block___290 *);
	int (*statfs)(struct dentry___290 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___290 *, int *, char *);
	void (*umount_begin)(struct super_block___290 *);
	int (*show_options)(struct seq_file___265 *, struct dentry___290 *);
	int (*show_devname)(struct seq_file___265 *, struct dentry___290 *);
	int (*show_path)(struct seq_file___265 *, struct dentry___290 *);
	int (*show_stats)(struct seq_file___265 *, struct dentry___290 *);
	ssize_t (*quota_read)(struct super_block___290 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___290 *, int, const char *, size_t, loff_t);
	struct dquot___290 ** (*get_dquots)(struct inode___290 *);
	long int (*nr_cached_objects)(struct super_block___290 *, struct shrink_control___155 *);
	long int (*free_cached_objects)(struct super_block___290 *, struct shrink_control___155 *);
	struct file___290 * (*real_loop)(struct file___290 *);
};

struct wakeup_source___271;

struct dev_pm_info___271 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___271 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___271 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___271;

struct bus_type___271;

struct device_driver___271;

struct dev_pm_domain___271;

struct fwnode_handle___267;

struct class___271;

struct attribute_group___278;

struct device___271 {
	struct kobject___278 kobj;
	struct device___271 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___271 *type;
	struct bus_type___271 *bus;
	struct device_driver___271 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___271 power;
	struct dev_pm_domain___271 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___267 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___271 *class;
	const struct attribute_group___278 **groups;
	void (*release)(struct device___271 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___184 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___290 *bd_inode;
	struct super_block___290 *bd_super;
	void *bd_claiming;
	struct device___271 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___278 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___184 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___290 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___219)(struct file___290 *, wait_queue_head_t *, struct poll_table_struct___211 *);

struct poll_table_struct___211 {
	poll_queue_proc___219 _qproc;
	__poll_t _key;
};

struct seq_operations___265;

struct seq_file___265 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___265 *op;
	int poll_event;
	const struct file___290 *file;
	void *private;
};

typedef void bio_end_io_t___181(struct bio___181 *);

struct bio_integrity_payload___181;

struct bio___181 {
	struct bio___181 *bi_next;
	struct block_device___184 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___181 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___169 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___181 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___207 *bi_io_vec;
	struct bio_set___181 *bi_pool;
	struct bio_vec___207 bi_inline_vecs[0];
};

struct dev_pagemap_ops___285 {
	void (*page_free)(struct page___295 *);
	void (*kill)(struct dev_pagemap___285 *);
	void (*cleanup)(struct dev_pagemap___285 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___285 *);
};

struct socket_wq___87 {
	wait_queue_head_t wait;
	struct fasync_struct___290 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___86;

struct proto_ops___87;

struct socket___88 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___290 *file;
	struct sock___86 *sk;
	const struct proto_ops___87 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___87 wq;
};

typedef struct {
	struct net___104 *net;
} possible_net_t___99;

struct proto___86;

struct sock_common___86 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___86 *skc_prot;
	possible_net_t___99 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___86 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___100;

struct sk_buff_head___99 {
	struct sk_buff___100 *next;
	struct sk_buff___100 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___86 {
	struct cgroup___217 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___86;

struct xfrm_policy___21;

struct dst_entry___86;

struct net_device___99;

struct sock_reuseport___34;

struct sock___86 {
	struct sock_common___86 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___99 sk_error_queue;
	struct sk_buff___100 *sk_rx_skb_cache;
	struct sk_buff_head___99 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___100 *head;
		struct sk_buff___100 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___86 *sk_filter;
	union {
		struct socket_wq___87 *sk_wq;
		struct socket_wq___87 *sk_wq_raw;
	};
	struct xfrm_policy___21 *sk_policy[2];
	struct dst_entry___86 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___86 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___100 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___100 *sk_tx_skb_cache;
	struct sk_buff_head___99 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___295 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___86 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___267 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___88 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___86 sk_cgrp_data;
	struct mem_cgroup___155 *sk_memcg;
	void (*sk_state_change)(struct sock___86 *);
	void (*sk_data_ready)(struct sock___86 *);
	void (*sk_write_space)(struct sock___86 *);
	void (*sk_error_report)(struct sock___86 *);
	int (*sk_backlog_rcv)(struct sock___86 *, struct sk_buff___100 *);
	struct sk_buff___100 * (*sk_validate_xmit_skb)(struct sock___86 *, struct net_device___99 *, struct sk_buff___100 *);
	void (*sk_destruct)(struct sock___86 *);
	struct sock_reuseport___34 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___86)(read_descriptor_t *, struct sk_buff___100 *, unsigned int, size_t);

struct proto_ops___87 {
	int family;
	struct module___274 *owner;
	int (*release)(struct socket___88 *);
	int (*bind)(struct socket___88 *, struct sockaddr *, int);
	int (*connect)(struct socket___88 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___88 *, struct socket___88 *);
	int (*accept)(struct socket___88 *, struct socket___88 *, int, bool);
	int (*getname)(struct socket___88 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___290 *, struct socket___88 *, struct poll_table_struct___211 *);
	int (*ioctl)(struct socket___88 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___88 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___88 *, void *, bool, bool);
	int (*listen)(struct socket___88 *, int);
	int (*shutdown)(struct socket___88 *, int);
	int (*setsockopt)(struct socket___88 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___88 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___265 *, struct socket___88 *);
	int (*sendmsg)(struct socket___88 *, struct msghdr___88 *, size_t);
	int (*recvmsg)(struct socket___88 *, struct msghdr___88 *, size_t, int);
	int (*mmap)(struct file___290 *, struct socket___88 *, struct vm_area_struct___295 *);
	ssize_t (*sendpage)(struct socket___88 *, struct page___295 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___88 *, loff_t *, struct pipe_inode_info___131 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___86 *, int);
	int (*peek_len)(struct socket___88 *);
	int (*read_sock)(struct sock___86 *, read_descriptor_t *, sk_read_actor_t___86);
	int (*sendpage_locked)(struct sock___86 *, struct page___295 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___86 *, struct msghdr___88 *, size_t);
	int (*set_rcvlowat)(struct sock___86 *, int);
};

struct sk_buff___100 {
	union {
		struct {
			struct sk_buff___100 *next;
			struct sk_buff___100 *prev;
			union {
				struct net_device___99 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___86 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___100 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___59;

struct fib_rules_ops___86;

struct fqdir___104;

struct tcp_congestion_ops___32;

struct fib_notifier_ops___86;

struct netns_ipv4___104 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___59 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___86 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___86 *fibnl;
	struct sock___86 **icmp_sk;
	struct sock___86 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___86 **tcp_sk;
	struct fqdir___104 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___32 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___86 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___86 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___86 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___86;

struct dst_ops___104 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___104 *);
	struct dst_entry___86 * (*check)(struct dst_entry___86 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___86 *);
	unsigned int (*mtu)(const struct dst_entry___86 *);
	u32 * (*cow_metrics)(struct dst_entry___86 *, long unsigned int);
	void (*destroy)(struct dst_entry___86 *);
	void (*ifdown)(struct dst_entry___86 *, struct net_device___99 *, int);
	struct dst_entry___86 * (*negative_advice)(struct dst_entry___86 *);
	void (*link_failure)(struct sk_buff___100 *);
	void (*update_pmtu)(struct dst_entry___86 *, struct sock___86 *, struct sk_buff___100 *, u32, bool);
	void (*redirect)(struct dst_entry___86 *, struct sock___86 *, struct sk_buff___100 *);
	int (*local_out)(struct net___104 *, struct sock___86 *, struct sk_buff___100 *);
	struct neighbour___86 * (*neigh_lookup)(const struct dst_entry___86 *, struct sk_buff___100 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___86 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___28;

struct rt6_info___28;

struct fib6_table___28;

struct netns_ipv6___104 {
	struct dst_ops___104 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___104 *fqdir;
	struct fib6_info___28 *fib6_null_entry;
	struct rt6_info___28 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___28 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___28 *ip6_prohibit_entry;
	struct rt6_info___28 *ip6_blk_hole_entry;
	struct fib6_table___28 *fib6_local_tbl;
	struct fib_rules_ops___86 *fib6_rules_ops;
	struct sock___86 **icmp_sk;
	struct sock___86 *ndisc_sk;
	struct sock___86 *tcp_sk;
	struct sock___86 *igmp_sk;
	struct sock___86 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___86 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___86 *notifier_ops;
	struct fib_notifier_ops___86 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___104 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___104 *fqdir;
};

struct netns_sctp___86 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___86 *ctl_sock;
	struct sock___86 *udp4_sock;
	struct sock___86 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___19;

struct netns_nf___19 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___19 *hooks_ipv4[5];
	struct nf_hook_entries___19 *hooks_ipv6[5];
	struct nf_hook_entries___19 *hooks_arp[3];
	struct nf_hook_entries___19 *hooks_bridge[5];
	struct nf_hook_entries___19 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___93;

struct netns_bpf___93 {
	struct bpf_prog_array___93 *run_array[2];
	struct bpf_prog___93 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___104 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___86 *nlsk;
	struct sock___86 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___104 xfrm4_dst_ops;
	struct dst_ops___104 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___104 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___86 *rtnl;
	struct sock___86 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___99 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___104 ipv4;
	struct netns_ipv6___104 ipv6;
	struct netns_ieee802154_lowpan___104 ieee802154_lowpan;
	struct netns_sctp___86 sctp;
	struct netns_nf___19 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___99 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___93 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___104 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___86 *crypto_nlsk;
	struct sock___86 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___104;

struct fqdir___104 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___104 *f;
	struct net___104 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___104;

struct inet_frags___104 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___104 *, const void *);
	void (*destructor)(struct inet_frag_queue___104 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___104 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___100 *fragments_tail;
	struct sk_buff___100 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___104 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___59 {
	struct ip_ra_chain___59 *next;
	struct sock___86 *sk;
	union {
		void (*destructor)(struct sock___86 *);
		struct sock___86 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___86;

struct fib_lookup_arg___86;

struct fib_rules_ops___86 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___86 *, struct flowi *, int, struct fib_lookup_arg___86 *);
	bool (*suppress)(struct fib_rule___86 *, int, struct fib_lookup_arg___86 *);
	int (*match)(struct fib_rule___86 *, struct flowi *, int);
	int (*configure)(struct fib_rule___86 *, struct sk_buff___100 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___86 *);
	int (*compare)(struct fib_rule___86 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___86 *, struct sk_buff___100 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___86 *);
	void (*flush_cache)(struct fib_rules_ops___86 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___274 *owner;
	struct net___104 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___32 {
	u32 (*ssthresh)(struct sock___86 *);
	void (*cong_avoid)(struct sock___86 *, u32, u32);
	void (*set_state)(struct sock___86 *, u8);
	void (*cwnd_event)(struct sock___86 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___86 *, u32);
	void (*pkts_acked)(struct sock___86 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___86 *);
	void (*cong_control)(struct sock___86 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___86 *);
	u32 (*sndbuf_expand)(struct sock___86 *);
	size_t (*get_info)(struct sock___86 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___274 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___86 *);
	void (*release)(struct sock___86 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___86 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___104 *);
	int (*fib_dump)(struct net___104 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___274 *owner;
	struct callback_head rcu;
};

struct xfrm_state___21;

struct lwtunnel_state___62;

struct dst_entry___86 {
	struct net_device___99 *dev;
	struct dst_ops___104 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___21 *xfrm;
	int (*input)(struct sk_buff___100 *);
	int (*output)(struct net___104 *, struct sock___86 *, struct sk_buff___100 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___62 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___99(struct sk_buff___100 **);

struct bpf_xdp_entity___93 {
	struct bpf_prog___93 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___99;

struct net_device_ops___99;

struct l3mdev_ops___86;

struct ndisc_ops___68;

struct xfrmdev_ops___99;

struct header_ops___99;

struct inet6_dev___68;

struct netdev_rx_queue___99;

struct mini_Qdisc___93;

struct netdev_queue___99;

struct Qdisc___93;

struct rtnl_link_ops___93;

struct dcbnl_rtnl_ops___99;

struct net_device___99 {
	char name[16];
	struct netdev_name_node___99 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___99 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___86 *l3mdev_ops;
	const struct ndisc_ops___68 *ndisc_ops;
	const struct xfrmdev_ops___99 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___99 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___278 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___68 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___99 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___93 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___99 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___93 *miniq_ingress;
	struct netdev_queue___99 *ingress_queue;
	struct nf_hook_entries___19 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___99 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___93 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___93 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___99 = 0,
		NETREG_REGISTERED___99 = 1,
		NETREG_UNREGISTERING___99 = 2,
		NETREG_UNREGISTERED___99 = 3,
		NETREG_RELEASED___99 = 4,
		NETREG_DUMMY___99 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___99 = 0,
		RTNL_LINK_INITIALIZING___99 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___99 *);
	struct netpoll_info *npinfo;
	possible_net_t___99 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___271 dev;
	const struct attribute_group___278 *sysfs_groups[4];
	const struct attribute_group___278 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___93 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___99 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___93 xdp_state[3];
	long: 64;
};

struct neigh_table___86;

struct neigh_parms___86;

struct neigh_ops___86;

struct neighbour___86 {
	struct neighbour___86 *next;
	struct neigh_table___86 *tbl;
	struct neigh_parms___86 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___99 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___86 *, struct sk_buff___100 *);
	const struct neigh_ops___86 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___99 *dev;
	u8 primary_key[0];
};

struct rtable___30;

struct fnhe_hash_bucket___28;

struct fib_nh_common___28 {
	struct net_device___99 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___62 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___30 **nhc_pcpu_rth_output;
	struct rtable___30 *nhc_rth_input;
	struct fnhe_hash_bucket___28 *nhc_exceptions;
};

struct fib6_nh___28 {
	struct fib_nh_common___28 nh_common;
	long unsigned int last_probe;
	struct rt6_info___28 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___28;

struct nexthop___18;

struct fib6_info___28 {
	struct fib6_table___28 *fib6_table;
	struct fib6_info___28 *fib6_next;
	struct fib6_node___28 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___18 *nh;
	struct fib6_nh___28 fib6_nh[0];
};

struct rt6_info___28 {
	struct dst_entry___86 dst;
	struct fib6_info___28 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___68 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___28 {
	struct fib6_node___28 *parent;
	struct fib6_node___28 *left;
	struct fib6_node___28 *right;
	struct fib6_node___28 *subtree;
	struct fib6_info___28 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___28 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___28 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___28 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___19;

typedef unsigned int nf_hookfn___24(void *, struct sk_buff___100 *, const struct nf_hook_state___19 *);

struct nf_hook_entry___19 {
	nf_hookfn___24 *hook;
	void *priv;
};

struct nf_hook_entries___19 {
	u16 num_hook_entries;
	struct nf_hook_entry___19 hooks[0];
};

struct bpf_prog_array_item___93 {
	struct bpf_prog___93 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___93 {
	struct callback_head rcu;
	struct bpf_prog_array_item___93 items[0];
};

struct bpf_prog_aux___102;

struct bpf_prog___93 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___102 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___267;

struct fwnode_handle___267 {
	struct fwnode_handle___267 *secondary;
	const struct fwnode_operations___267 *ops;
	struct device___271 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___267;

struct fwnode_endpoint___267;

struct fwnode_operations___267 {
	struct fwnode_handle___267 * (*get)(struct fwnode_handle___267 *);
	void (*put)(struct fwnode_handle___267 *);
	bool (*device_is_available)(const struct fwnode_handle___267 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___267 *, const struct device___271 *);
	bool (*property_present)(const struct fwnode_handle___267 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___267 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___267 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___267 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*get_parent)(const struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*get_next_child_node)(const struct fwnode_handle___267 *, struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*get_named_child_node)(const struct fwnode_handle___267 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___267 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___267 *);
	struct fwnode_handle___267 * (*graph_get_next_endpoint)(const struct fwnode_handle___267 *, struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*graph_get_remote_endpoint)(const struct fwnode_handle___267 *);
	struct fwnode_handle___267 * (*graph_get_port_parent)(struct fwnode_handle___267 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___267 *, struct fwnode_endpoint___267 *);
	int (*add_links)(struct fwnode_handle___267 *);
};

struct fwnode_endpoint___267 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___267 *local_fwnode;
};

struct fwnode_reference_args___267 {
	struct fwnode_handle___267 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___278;

struct kernfs_elem_dir___278 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___278 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___278;

struct kernfs_root___278 {
	struct kernfs_node___278 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___278 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___278 {
	struct kernfs_node___278 *target_kn;
};

struct kernfs_ops___278;

struct kernfs_elem_attr___278 {
	const struct kernfs_ops___278 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___278 *notify_next;
};

struct kernfs_node___278 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___278 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___278 dir;
		struct kernfs_elem_symlink___278 symlink;
		struct kernfs_elem_attr___278 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___278;

struct kernfs_ops___278 {
	int (*open)(struct kernfs_open_file___278 *);
	void (*release)(struct kernfs_open_file___278 *);
	int (*seq_show)(struct seq_file___265 *, void *);
	void * (*seq_start)(struct seq_file___265 *, loff_t *);
	void * (*seq_next)(struct seq_file___265 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___265 *, void *);
	ssize_t (*read)(struct kernfs_open_file___278 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___278 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___278 *, struct poll_table_struct___211 *);
	int (*mmap)(struct kernfs_open_file___278 *, struct vm_area_struct___295 *);
};

struct kernfs_syscall_ops___278 {
	int (*show_options)(struct seq_file___265 *, struct kernfs_root___278 *);
	int (*mkdir)(struct kernfs_node___278 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___278 *);
	int (*rename)(struct kernfs_node___278 *, struct kernfs_node___278 *, const char *);
	int (*show_path)(struct seq_file___265 *, struct kernfs_node___278 *, struct kernfs_root___278 *);
};

struct kernfs_open_file___278 {
	struct kernfs_node___278 *kn;
	struct file___290 *file;
	struct seq_file___265 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___285 *vm_ops;
};

struct kobj_ns_type_operations___86 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___86 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___278;

struct attribute_group___278 {
	const char *name;
	umode_t (*is_visible)(struct kobject___278 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___278 *, struct bin_attribute___278 *, int);
	struct attribute **attrs;
	struct bin_attribute___278 **bin_attrs;
};

struct bin_attribute___278 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___290 * (*f_mapping)();
	ssize_t (*read)(struct file___290 *, struct kobject___278 *, struct bin_attribute___278 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___290 *, struct kobject___278 *, struct bin_attribute___278 *, char *, loff_t, size_t);
	int (*mmap)(struct file___290 *, struct kobject___278 *, struct bin_attribute___278 *, struct vm_area_struct___295 *);
};

struct sysfs_ops___278 {
	ssize_t (*show)(struct kobject___278 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___278 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___278;

struct kset___278 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___278 kobj;
	const struct kset_uevent_ops___278 *uevent_ops;
};

struct kobj_type___278 {
	void (*release)(struct kobject___278 *);
	const struct sysfs_ops___278 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___278 **default_groups;
	const struct kobj_ns_type_operations___86 * (*child_ns_type)(struct kobject___278 *);
	const void * (*namespace)(struct kobject___278 *);
	void (*get_ownership)(struct kobject___278 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___278 {
	int (* const filter)(struct kset___278 *, struct kobject___278 *);
	const char * (* const name)(struct kset___278 *, struct kobject___278 *);
	int (* const uevent)(struct kset___278 *, struct kobject___278 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___274 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___274 *);
	int (*get)(char *, const struct kernel_param___274 *);
	void (*free)(void *);
};

struct kparam_array___274;

struct kernel_param___274 {
	const char *name;
	struct module___274 *mod;
	const struct kernel_param_ops___274 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___274 *arr;
	};
};

struct kparam_array___274 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___274 *ops;
	void *elem;
};

struct module_attribute___274 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___274 *, struct module_kobject___275 *, char *);
	ssize_t (*store)(struct module_attribute___274 *, struct module_kobject___275 *, const char *, size_t);
	void (*setup)(struct module___274 *, const char *);
	int (*test)(struct module___274 *);
	void (*free)(struct module___274 *);
};

struct cgroup_namespace___217 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___217 *root_cset;
};

struct dev_pm_ops___271 {
	int (*prepare)(struct device___271 *);
	void (*complete)(struct device___271 *);
	int (*suspend)(struct device___271 *);
	int (*resume)(struct device___271 *);
	int (*freeze)(struct device___271 *);
	int (*thaw)(struct device___271 *);
	int (*poweroff)(struct device___271 *);
	int (*restore)(struct device___271 *);
	int (*suspend_late)(struct device___271 *);
	int (*resume_early)(struct device___271 *);
	int (*freeze_late)(struct device___271 *);
	int (*thaw_early)(struct device___271 *);
	int (*poweroff_late)(struct device___271 *);
	int (*restore_early)(struct device___271 *);
	int (*suspend_noirq)(struct device___271 *);
	int (*resume_noirq)(struct device___271 *);
	int (*freeze_noirq)(struct device___271 *);
	int (*thaw_noirq)(struct device___271 *);
	int (*poweroff_noirq)(struct device___271 *);
	int (*restore_noirq)(struct device___271 *);
	int (*runtime_suspend)(struct device___271 *);
	int (*runtime_resume)(struct device___271 *);
	int (*runtime_idle)(struct device___271 *);
};

struct wakeup_source___271 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___271 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___271 {
	struct dev_pm_ops___271 ops;
	int (*start)(struct device___271 *);
	void (*detach)(struct device___271 *, bool);
	int (*activate)(struct device___271 *);
	void (*sync)(struct device___271 *);
	void (*dismiss)(struct device___271 *);
};

struct bus_type___271 {
	const char *name;
	const char *dev_name;
	struct device___271 *dev_root;
	const struct attribute_group___278 **bus_groups;
	const struct attribute_group___278 **dev_groups;
	const struct attribute_group___278 **drv_groups;
	int (*match)(struct device___271 *, struct device_driver___271 *);
	int (*uevent)(struct device___271 *, struct kobj_uevent_env *);
	int (*probe)(struct device___271 *);
	void (*sync_state)(struct device___271 *);
	void (*remove)(struct device___271 *);
	void (*shutdown)(struct device___271 *);
	int (*online)(struct device___271 *);
	int (*offline)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	int (*num_vf)(struct device___271 *);
	int (*dma_configure)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___271 {
	const char *name;
	struct bus_type___271 *bus;
	struct module___274 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___271 *);
	void (*sync_state)(struct device___271 *);
	int (*remove)(struct device___271 *);
	void (*shutdown)(struct device___271 *);
	int (*suspend)(struct device___271 *, pm_message_t);
	int (*resume)(struct device___271 *);
	const struct attribute_group___278 **groups;
	const struct attribute_group___278 **dev_groups;
	const struct dev_pm_ops___271 *pm;
	void (*coredump)(struct device___271 *);
	struct driver_private *p;
};

struct device_type___271 {
	const char *name;
	const struct attribute_group___278 **groups;
	int (*uevent)(struct device___271 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___271 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___271 *);
	const struct dev_pm_ops___271 *pm;
};

struct class___271 {
	const char *name;
	struct module___274 *owner;
	const struct attribute_group___278 **class_groups;
	const struct attribute_group___278 **dev_groups;
	struct kobject___278 *dev_kobj;
	int (*dev_uevent)(struct device___271 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___271 *, umode_t *);
	void (*class_release)(struct class___271 *);
	void (*dev_release)(struct device___271 *);
	int (*shutdown_pre)(struct device___271 *);
	const struct kobj_ns_type_operations___86 *ns_type;
	const void * (*namespace)(struct device___271 *);
	void (*get_ownership)(struct device___271 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___271 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___131;

struct pipe_buffer___131 {
	struct page___295 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___131 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___131 {
	int (*confirm)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
	void (*release)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
	bool (*try_steal)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
	bool (*get)(struct pipe_inode_info___131 *, struct pipe_buffer___131 *);
};

typedef struct bio_vec___207 skb_frag_t___39;

struct skb_shared_info___34 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___100 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___39 frags[17];
};

struct seq_operations___265 {
	void * (*start)(struct seq_file___265 *, loff_t *);
	void (*stop)(struct seq_file___265 *, void *);
	void * (*next)(struct seq_file___265 *, void *, loff_t *);
	int (*show)(struct seq_file___265 *, void *);
};

struct dcbnl_rtnl_ops___99 {
	int (*ieee_getets)(struct net_device___99 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___99 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___99 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___99 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___99 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___99 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___99 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___99 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___99 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___99 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___99 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___99 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___99 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___99 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___99 *);
	u8 (*setstate)(struct net_device___99 *, u8);
	void (*getpermhwaddr)(struct net_device___99 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___99 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___99 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___99 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___99 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___99 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___99 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___99 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___99 *, int, u8 *);
	void (*setpfccfg)(struct net_device___99 *, int, u8);
	void (*getpfccfg)(struct net_device___99 *, int, u8 *);
	u8 (*setall)(struct net_device___99 *);
	u8 (*getcap)(struct net_device___99 *, int, u8 *);
	int (*getnumtcs)(struct net_device___99 *, int, u8 *);
	int (*setnumtcs)(struct net_device___99 *, int, u8);
	u8 (*getpfcstate)(struct net_device___99 *);
	void (*setpfcstate)(struct net_device___99 *, u8);
	void (*getbcncfg)(struct net_device___99 *, int, u32 *);
	void (*setbcncfg)(struct net_device___99 *, int, u32);
	void (*getbcnrp)(struct net_device___99 *, int, u8 *);
	void (*setbcnrp)(struct net_device___99 *, int, u8);
	int (*setapp)(struct net_device___99 *, u8, u16, u8);
	int (*getapp)(struct net_device___99 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___99 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___99 *, int, u8);
	u8 (*getdcbx)(struct net_device___99 *);
	u8 (*setdcbx)(struct net_device___99 *, u8);
	int (*peer_getappinfo)(struct net_device___99 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___99 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___99 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___99 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___99 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___99 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___102;

typedef int (*bpf_iter_init_seq_priv_t___101)(void *, struct bpf_iter_aux_info___102 *);

struct bpf_map___102;

struct bpf_iter_aux_info___102 {
	struct bpf_map___102 *map;
};

struct bpf_iter_seq_info___101 {
	const struct seq_operations___265 *seq_ops;
	bpf_iter_init_seq_priv_t___101 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___101 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___102 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___102 *, struct file___290 *);
	void (*map_free)(struct bpf_map___102 *);
	int (*map_get_next_key)(struct bpf_map___102 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___102 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___102 *, void *);
	int (*map_lookup_batch)(struct bpf_map___102 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___102 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___102 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___102 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___102 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___102 *, void *);
	int (*map_update_elem)(struct bpf_map___102 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___102 *, void *);
	int (*map_push_elem)(struct bpf_map___102 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___102 *, void *);
	int (*map_peek_elem)(struct bpf_map___102 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___102 *, struct file___290 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___102 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___102 *, void *, struct seq_file___265 *);
	int (*map_check_btf)(const struct bpf_map___102 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___102 *, struct bpf_prog_aux___102 *);
	void (*map_poke_untrack)(struct bpf_map___102 *, struct bpf_prog_aux___102 *);
	void (*map_poke_run)(struct bpf_map___102 *, u32, struct bpf_prog___93 *, struct bpf_prog___93 *);
	int (*map_direct_value_addr)(const struct bpf_map___102 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___102 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___102 *, struct vm_area_struct___295 *);
	__poll_t (*map_poll)(struct bpf_map___102 *, struct file___290 *, struct poll_table_struct___211 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___102 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___102 *, const struct bpf_map___102 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___102 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___101 *iter_seq_info;
};

struct bpf_map___102 {
	const struct bpf_map_ops___101 *ops;
	struct bpf_map___102 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___155 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___101;

struct bpf_jit_poke_descriptor___101;

struct bpf_prog_ops___93;

struct btf_mod_pair___101;

struct bpf_prog_offload___99;

struct bpf_prog_aux___102 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___93 *dst_prog;
	struct bpf_trampoline___101 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___93 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___101 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___93 *ops;
	struct bpf_map___102 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___101 *used_btfs;
	struct bpf_prog___93 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___102 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___99 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___99;

struct bpf_map_dev_ops___99 {
	int (*map_get_next_key)(struct bpf_offloaded_map___99 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___99 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___99 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___99 *, void *);
};

struct bpf_offloaded_map___99 {
	struct bpf_map___102 map;
	struct net_device___99 *netdev;
	const struct bpf_map_dev_ops___99 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___93 {
	int (*test_run)(struct bpf_prog___93 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___99 {
	struct bpf_prog___93 *prog;
	struct net_device___99 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___101 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___93 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___274 *mod;
};

struct bpf_jit_poke_descriptor___101 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___102 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___101 {
	struct btf *btf;
	struct module___274 *module;
};

struct cftype___217;

struct cgroup_subsys___217 {
	struct cgroup_subsys_state___217 * (*css_alloc)(struct cgroup_subsys_state___217 *);
	int (*css_online)(struct cgroup_subsys_state___217 *);
	void (*css_offline)(struct cgroup_subsys_state___217 *);
	void (*css_released)(struct cgroup_subsys_state___217 *);
	void (*css_free)(struct cgroup_subsys_state___217 *);
	void (*css_reset)(struct cgroup_subsys_state___217 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___217 *, int);
	int (*css_extra_stat_show)(struct seq_file___265 *, struct cgroup_subsys_state___217 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___297 *, struct css_set___217 *);
	void (*cancel_fork)(struct task_struct___297 *, struct css_set___217 *);
	void (*fork)(struct task_struct___297 *);
	void (*exit)(struct task_struct___297 *);
	void (*release)(struct task_struct___297 *);
	void (*bind)(struct cgroup_subsys_state___217 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___217 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___217 *dfl_cftypes;
	struct cftype___217 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___217 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___217 *updated_children;
	struct cgroup___217 *updated_next;
};

struct cgroup_root___217 {
	struct kernfs_root___278 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___217 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___217 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___217 *ss;
	struct list_head node;
	struct kernfs_ops___278 *kf_ops;
	int (*open)(struct kernfs_open_file___278 *);
	void (*release)(struct kernfs_open_file___278 *);
	u64 (*read_u64)(struct cgroup_subsys_state___217 *, struct cftype___217 *);
	s64 (*read_s64)(struct cgroup_subsys_state___217 *, struct cftype___217 *);
	int (*seq_show)(struct seq_file___265 *, void *);
	void * (*seq_start)(struct seq_file___265 *, loff_t *);
	void * (*seq_next)(struct seq_file___265 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___265 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___217 *, struct cftype___217 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___217 *, struct cftype___217 *, s64);
	ssize_t (*write)(struct kernfs_open_file___278 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___278 *, struct poll_table_struct___211 *);
};

struct xdp_rxq_info___99 {
	struct net_device___99 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___99 {
	struct net_device___99 *dev;
};

struct xdp_buff___99 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___99 *rxq;
	struct xdp_txq_info___99 *txq;
	u32 frame_sz;
};

struct xdp_frame___99 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___99 *dev_rx;
};

struct netlink_callback___99 {
	struct sk_buff___100 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___100 *, struct netlink_callback___99 *);
	int (*done)(struct netlink_callback___99 *);
	void *data;
	struct module___274 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___99 {
	int (*create)(struct sk_buff___100 *, struct net_device___99 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___100 *, unsigned char *);
	int (*cache)(const struct neighbour___86 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___99 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___100 *);
};

struct netdev_queue___99 {
	struct net_device___99 *dev;
	struct Qdisc___93 *qdisc;
	struct Qdisc___93 *qdisc_sleeping;
	struct kobject___278 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___99 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___93 {
	struct sk_buff___100 *head;
	struct sk_buff___100 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___93;

struct Qdisc___93 {
	int (*enqueue)(struct sk_buff___100 *, struct Qdisc___93 *, struct sk_buff___100 **);
	struct sk_buff___100 * (*dequeue)(struct Qdisc___93 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___93 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___99 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___99 gso_skb;
	struct qdisc_skb_head___93 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___93 *next_sched;
	struct sk_buff_head___99 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___99 {
	struct xdp_rxq_info___99 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___278 kobj;
	struct net_device___99 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___99 {
	enum net_device_path_type type;
	const struct net_device___99 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___99 = 0,
				DEV_PATH_BR_VLAN_TAG___99 = 1,
				DEV_PATH_BR_VLAN_UNTAG___99 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___99 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___99 {
	const struct net_device___99 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___99 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___93 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___99 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___99 {
	int (*xdo_dev_state_add)(struct xfrm_state___21 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___21 *);
	void (*xdo_dev_state_free)(struct xfrm_state___21 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___100 *, struct xfrm_state___21 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___21 *);
};

struct xfrm_state_offload___21 {
	struct net_device___99 *dev;
	struct net_device___99 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___21;

struct xfrm_type_offload___21;

struct xfrm_state___21 {
	possible_net_t___99 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___86 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___21 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___21 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___295 xfrag;
	const struct xfrm_type___21 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___21 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___99 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___99 *dev;
	const char *name;
};

struct ip_tunnel_parm___2;

struct net_device_ops___99 {
	int (*ndo_init)(struct net_device___99 *);
	void (*ndo_uninit)(struct net_device___99 *);
	int (*ndo_open)(struct net_device___99 *);
	int (*ndo_stop)(struct net_device___99 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___100 *, struct net_device___99 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___100 *, struct net_device___99 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___99 *, struct sk_buff___100 *, struct net_device___99 *);
	void (*ndo_change_rx_flags)(struct net_device___99 *, int);
	void (*ndo_set_rx_mode)(struct net_device___99 *);
	int (*ndo_set_mac_address)(struct net_device___99 *, void *);
	int (*ndo_validate_addr)(struct net_device___99 *);
	int (*ndo_do_ioctl)(struct net_device___99 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___99 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___99 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___99 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___99 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___99 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___99 *, int);
	int (*ndo_neigh_setup)(struct net_device___99 *, struct neigh_parms___86 *);
	void (*ndo_tx_timeout)(struct net_device___99 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___99 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___99 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___99 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___99 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___99 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___99 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___99 *);
	int (*ndo_netpoll_setup)(struct net_device___99 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___99 *);
	int (*ndo_set_vf_mac)(struct net_device___99 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___99 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___99 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___99 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___99 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___99 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___99 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___99 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___99 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___99 *, int, struct sk_buff___100 *);
	int (*ndo_get_vf_guid)(struct net_device___99 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___99 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___99 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___99 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___99 *);
	int (*ndo_fcoe_disable)(struct net_device___99 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___99 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___99 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___99 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___99 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___99 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___99 *, const struct sk_buff___100 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___99 *, struct net_device___99 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___99 *, struct net_device___99 *);
	struct net_device___99 * (*ndo_get_xmit_slave)(struct net_device___99 *, struct sk_buff___100 *, bool);
	struct net_device___99 * (*ndo_sk_get_lower_dev)(struct net_device___99 *, struct sock___86 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___99 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___99 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___99 *, struct neighbour___86 *);
	void (*ndo_neigh_destroy)(struct net_device___99 *, struct neighbour___86 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___99 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___99 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___100 *, struct netlink_callback___99 *, struct net_device___99 *, struct net_device___99 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___100 *, struct nlattr **, struct net_device___99 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___99 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___100 *, u32, u32, struct net_device___99 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___99 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___99 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___99 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___99 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___99 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___99 *, struct net_device___99 *);
	void (*ndo_dfwd_del_station)(struct net_device___99 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___99 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___99 *);
	int (*ndo_change_proto_down)(struct net_device___99 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___99 *, struct sk_buff___100 *);
	void (*ndo_set_rx_headroom)(struct net_device___99 *, int);
	int (*ndo_bpf)(struct net_device___99 *, struct netdev_bpf___99 *);
	int (*ndo_xdp_xmit)(struct net_device___99 *, int, struct xdp_frame___99 **, u32);
	struct net_device___99 * (*ndo_xdp_get_xmit_slave)(struct net_device___99 *, struct xdp_buff___99 *);
	int (*ndo_xsk_wakeup)(struct net_device___99 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___99 *);
	int (*ndo_tunnel_ctl)(struct net_device___99 *, struct ip_tunnel_parm___2 *, int);
	struct net_device___99 * (*ndo_get_peer_dev)(struct net_device___99 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___99 *, struct net_device_path___99 *);
};

struct neigh_parms___86 {
	possible_net_t___99 net;
	struct net_device___99 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___86 *);
	struct neigh_table___86 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct ip_tunnel_parm___2 {
	char name[16];
	int link;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	struct iphdr___2 iph;
};

struct l3mdev_ops___86 {
	u32 (*l3mdev_fib_table)(const struct net_device___99 *);
	struct sk_buff___100 * (*l3mdev_l3_rcv)(struct net_device___99 *, struct sk_buff___100 *, u16);
	struct sk_buff___100 * (*l3mdev_l3_out)(struct net_device___99 *, struct sock___86 *, struct sk_buff___100 *, u16);
	struct dst_entry___86 * (*l3mdev_link_scope_lookup)(const struct net_device___99 *, struct flowi6 *);
};

struct ndisc_ops___68 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___99 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___99 *, struct neighbour___86 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___99 *, u8, struct neighbour___86 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___99 *, struct sk_buff___100 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___104 *, struct net_device___99 *, const struct prefix_info *, struct inet6_dev___68 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___68;

struct ifacaddr6___28;

struct inet6_dev___68 {
	struct net_device___99 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___68 *mc_list;
	struct ifmcaddr6___68 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___99 mc_query_queue;
	struct sk_buff_head___99 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___28 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___86 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___93;

struct tcf_block___93;

struct mini_Qdisc___93 {
	struct tcf_proto___93 *filter_list;
	struct tcf_block___93 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___93 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___99 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___99 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___104 *, struct net_device___99 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___99 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___99 *, struct list_head *);
	size_t (*get_size)(const struct net_device___99 *);
	int (*fill_info)(struct sk_buff___100 *, const struct net_device___99 *);
	size_t (*get_xstats_size)(const struct net_device___99 *);
	int (*fill_xstats)(struct sk_buff___100 *, const struct net_device___99 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___99 *, struct net_device___99 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___99 *, const struct net_device___99 *);
	int (*fill_slave_info)(struct sk_buff___100 *, const struct net_device___99 *, const struct net_device___99 *);
	struct net___104 * (*get_link_net)(const struct net_device___99 *);
	size_t (*get_linkxstats_size)(const struct net_device___99 *, int);
	int (*fill_linkxstats)(struct sk_buff___100 *, const struct net_device___99 *, int *, int);
};

struct packet_type___8 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___99 *dev;
	int (*func)(struct sk_buff___100 *, struct net_device___99 *, struct packet_type___8 *, struct net_device___99 *);
	void (*list_func)(struct list_head *, struct packet_type___8 *, struct net_device___99 *);
	bool (*id_match)(struct packet_type___8 *, struct sock___86 *);
	struct net___104 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct block_device_operations___181;

struct gendisk___184 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___184 *part0;
	const struct block_device_operations___181 *fops;
	struct request_queue___181 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___167 *bdi;
	struct kobject___278 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___278 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___181 {
	struct bio___181 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___207 *bip_vec;
	struct bio_vec___207 bip_inline_vecs[0];
};

struct blkcg___169;

struct blkg_policy_data___169;

struct blkcg_gq___169 {
	struct request_queue___181 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___169 *blkcg;
	struct blkcg_gq___169 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___169 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___181 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___181(struct request___181 *);

typedef void integrity_complete_fn___181(struct request___181 *, unsigned int);

struct blk_integrity_profile___181 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___181 *prepare_fn;
	integrity_complete_fn___181 *complete_fn;
	const char *name;
};

struct block_device_operations___181 {
	blk_qc_t (*submit_bio)(struct bio___181 *);
	int (*open)(struct block_device___184 *, fmode_t);
	void (*release)(struct gendisk___184 *, fmode_t);
	int (*rw_page)(struct block_device___184 *, sector_t, struct page___295 *, unsigned int);
	int (*ioctl)(struct block_device___184 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___184 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___184 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___184 *);
	int (*getgeo)(struct block_device___184 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___184 *, bool);
	void (*swap_slot_free_notify)(struct block_device___184 *, long unsigned int);
	int (*report_zones)(struct gendisk___184 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___184 *, umode_t *);
	struct module___274 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___184 *, sector_t *);
};

typedef void rq_end_io_fn___181(struct request___181 *, blk_status_t);

struct request___181 {
	struct request_queue___181 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___176 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___181 *bio;
	struct bio___181 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___207 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___181 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___181 *saved_end_io;
		} flush;
	};
	struct gendisk___184 *rq_disk;
	struct block_device___184 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___181 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___176 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___181 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___278 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___290 *debugfs_dir;
	struct dentry___290 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___181;

struct elevator_mq_ops___181 {
	int (*init_sched)(struct request_queue___181 *, struct elevator_type___181 *);
	void (*exit_sched)(struct elevator_queue___181 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___176 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___176 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___176 *);
	bool (*allow_merge)(struct request_queue___181 *, struct request___181 *, struct bio___181 *);
	bool (*bio_merge)(struct request_queue___181 *, struct bio___181 *, unsigned int);
	int (*request_merge)(struct request_queue___181 *, struct request___181 **, struct bio___181 *);
	void (*request_merged)(struct request_queue___181 *, struct request___181 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___181 *, struct request___181 *, struct request___181 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___181 *);
	void (*finish_request)(struct request___181 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___176 *, struct list_head *, bool);
	struct request___181 * (*dispatch_request)(struct blk_mq_hw_ctx___176 *);
	bool (*has_work)(struct blk_mq_hw_ctx___176 *);
	void (*completed_request)(struct request___181 *, u64);
	void (*requeue_request)(struct request___181 *);
	struct request___181 * (*former_request)(struct request_queue___181 *, struct request___181 *);
	struct request___181 * (*next_request)(struct request_queue___181 *, struct request___181 *);
	void (*init_icq)(struct io_cq___181 *);
	void (*exit_icq)(struct io_cq___181 *);
};

struct elv_fs_entry___181;

struct elevator_type___181 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___181 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___181 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___274 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___181 {
	struct elevator_type___181 *type;
	void *elevator_data;
	struct kobject___278 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___181 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___181 *, char *);
	ssize_t (*store)(struct elevator_queue___181 *, const char *, size_t);
};

struct blk_mq_queue_data___176;

struct blk_mq_ops___176 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___176 *, const struct blk_mq_queue_data___176 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___176 *);
	int (*get_budget)(struct request_queue___181 *);
	void (*put_budget)(struct request_queue___181 *, int);
	void (*set_rq_budget_token)(struct request___181 *, int);
	int (*get_rq_budget_token)(struct request___181 *);
	enum blk_eh_timer_return (*timeout)(struct request___181 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___176 *);
	void (*complete)(struct request___181 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___176 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___176 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___176 *, struct request___181 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___176 *, struct request___181 *, unsigned int);
	void (*initialize_rq_fn)(struct request___181 *);
	void (*cleanup_rq)(struct request___181 *);
	bool (*busy)(struct request_queue___181 *);
	int (*map_queues)(struct blk_mq_tag_set___176 *);
	void (*show_rq)(struct seq_file___265 *, struct request___181 *);
};

struct blk_mq_tag_set___176 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___176 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___176 {
	struct request___181 *rq;
	bool last;
};

struct blkcg_policy_data___169;

struct blkcg___169 {
	struct cgroup_subsys_state___217 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___169 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___169 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___169 {
	struct blkcg___169 *blkcg;
	int plid;
};

struct blkg_policy_data___169 {
	struct blkcg_gq___169 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___155 {
	struct mem_cgroup___155 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___155 {
	struct lruvec___163 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___155 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___155 *memcg;
};

struct obj_cgroup___155 {
	struct percpu_ref refcnt;
	struct mem_cgroup___155 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___93 {
	spinlock_t *lock;
	struct sk_buff___100 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___93;

struct Qdisc_ops___93 {
	struct Qdisc_ops___93 *next;
	const struct Qdisc_class_ops___93 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___100 *, struct Qdisc___93 *, struct sk_buff___100 **);
	struct sk_buff___100 * (*dequeue)(struct Qdisc___93 *);
	struct sk_buff___100 * (*peek)(struct Qdisc___93 *);
	int (*init)(struct Qdisc___93 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___93 *);
	void (*destroy)(struct Qdisc___93 *);
	int (*change)(struct Qdisc___93 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___93 *);
	int (*change_tx_queue_len)(struct Qdisc___93 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___93 *, unsigned int);
	int (*dump)(struct Qdisc___93 *, struct sk_buff___100 *);
	int (*dump_stats)(struct Qdisc___93 *, struct gnet_dump___93 *);
	void (*ingress_block_set)(struct Qdisc___93 *, u32);
	void (*egress_block_set)(struct Qdisc___93 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___93 *);
	u32 (*egress_block_get)(struct Qdisc___93 *);
	struct module___274 *owner;
};

struct Qdisc_class_ops___93 {
	unsigned int flags;
	struct netdev_queue___99 * (*select_queue)(struct Qdisc___93 *, struct tcmsg *);
	int (*graft)(struct Qdisc___93 *, long unsigned int, struct Qdisc___93 *, struct Qdisc___93 **, struct netlink_ext_ack *);
	struct Qdisc___93 * (*leaf)(struct Qdisc___93 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___93 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___93 *, u32);
	int (*change)(struct Qdisc___93 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___93 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___93 *, struct qdisc_walker *);
	struct tcf_block___93 * (*tcf_block)(struct Qdisc___93 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___93 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___93 *, long unsigned int);
	int (*dump)(struct Qdisc___93 *, long unsigned int, struct sk_buff___100 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___93 *, long unsigned int, struct gnet_dump___93 *);
};

struct tcf_chain___93;

struct tcf_block___93 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___104 *net;
	struct Qdisc___93 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___93 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___93;

struct tcf_proto_ops___93;

struct tcf_proto___93 {
	struct tcf_proto___93 *next;
	void *root;
	int (*classify)(struct sk_buff___100 *, const struct tcf_proto___93 *, struct tcf_result___93 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___93 *ops;
	struct tcf_chain___93 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___93 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___93 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___93 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___100 *, const struct tcf_proto___93 *, struct tcf_result___93 *);
	int (*init)(struct tcf_proto___93 *);
	void (*destroy)(struct tcf_proto___93 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___93 *, u32);
	void (*put)(struct tcf_proto___93 *, void *);
	int (*change)(struct net___104 *, struct sk_buff___100 *, struct tcf_proto___93 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___93 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___93 *);
	void (*walk)(struct tcf_proto___93 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___93 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___93 *, void *);
	void (*hw_del)(struct tcf_proto___93 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___104 *, struct tcf_chain___93 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___104 *, struct tcf_proto___93 *, void *, struct sk_buff___100 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___104 *, struct tcf_proto___93 *, void *, struct sk_buff___100 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___100 *, struct net___104 *, void *);
	struct module___274 *owner;
	int flags;
};

struct tcf_chain___93 {
	struct mutex filter_chain_lock;
	struct tcf_proto___93 *filter_chain;
	struct list_head list;
	struct tcf_block___93 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___93 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___86 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___93 *prog;
};

struct pneigh_entry___86;

struct neigh_hash_table___86;

struct neigh_table___86 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___99 *, __u32 *);
	bool (*key_eq)(const struct neighbour___86 *, const void *);
	int (*constructor)(struct neighbour___86 *);
	int (*pconstructor)(struct pneigh_entry___86 *);
	void (*pdestructor)(struct pneigh_entry___86 *);
	void (*proxy_redo)(struct sk_buff___100 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___99 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___86 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___99 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___86 *nht;
	struct pneigh_entry___86 **phash_buckets;
};

struct neigh_ops___86 {
	int family;
	void (*solicit)(struct neighbour___86 *, struct sk_buff___100 *);
	void (*error_report)(struct neighbour___86 *, struct sk_buff___100 *);
	int (*output)(struct neighbour___86 *, struct sk_buff___100 *);
	int (*connected_output)(struct neighbour___86 *, struct sk_buff___100 *);
};

struct pneigh_entry___86 {
	struct pneigh_entry___86 *next;
	possible_net_t___99 net;
	struct net_device___99 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___86 {
	struct neighbour___86 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___62 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___104 *, struct sock___86 *, struct sk_buff___100 *);
	int (*orig_input)(struct sk_buff___100 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___86 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___86 *ctarget;
	struct net___104 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___86 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___86 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___71;

struct timewait_sock_ops___70;

struct proto___86 {
	void (*close)(struct sock___86 *, long int);
	int (*pre_connect)(struct sock___86 *, struct sockaddr *, int);
	int (*connect)(struct sock___86 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___86 *, int);
	struct sock___86 * (*accept)(struct sock___86 *, int, int *, bool);
	int (*ioctl)(struct sock___86 *, int, long unsigned int);
	int (*init)(struct sock___86 *);
	void (*destroy)(struct sock___86 *);
	void (*shutdown)(struct sock___86 *, int);
	int (*setsockopt)(struct sock___86 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___86 *, int, int, char *, int *);
	void (*keepalive)(struct sock___86 *, int);
	int (*compat_ioctl)(struct sock___86 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___86 *, struct msghdr___88 *, size_t);
	int (*recvmsg)(struct sock___86 *, struct msghdr___88 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___86 *, struct page___295 *, int, size_t, int);
	int (*bind)(struct sock___86 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___86 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___86 *, struct sk_buff___100 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___86 *);
	int (*hash)(struct sock___86 *);
	void (*unhash)(struct sock___86 *);
	void (*rehash)(struct sock___86 *);
	int (*get_port)(struct sock___86 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___86 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___86 *, int);
	bool (*sock_is_readable)(struct sock___86 *);
	void (*enter_memory_pressure)(struct sock___86 *);
	void (*leave_memory_pressure)(struct sock___86 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___71 *rsk_prot;
	struct timewait_sock_ops___70 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___274 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___86 *, int);
};

struct xfrm_policy_queue___21 {
	struct sk_buff_head___99 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___21 {
	possible_net_t___99 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___21 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___34 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___93 *prog;
	struct sock___86 *socks[0];
};

struct request_sock___72;

struct request_sock_ops___71 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___86 *, struct request_sock___72 *);
	void (*send_ack)(const struct sock___86 *, struct sk_buff___100 *, struct request_sock___72 *);
	void (*send_reset)(const struct sock___86 *, struct sk_buff___100 *);
	void (*destructor)(struct request_sock___72 *);
	void (*syn_ack_timeout)(const struct request_sock___72 *);
};

struct timewait_sock_ops___70 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___86 *, struct sock___86 *, void *);
	void (*twsk_destructor)(struct sock___86 *);
};

struct request_sock___72 {
	struct sock_common___86 __req_common;
	struct request_sock___72 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___71 *rsk_ops;
	struct sock___86 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___68 {
	struct in6_addr mca_addr;
	struct inet6_dev___68 *idev;
	struct ifmcaddr6___68 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___28 {
	struct in6_addr aca_addr;
	struct fib6_info___28 *aca_rt;
	struct ifacaddr6___28 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib_nh_exception___28 {
	struct fib_nh_exception___28 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___30 *fnhe_rth_input;
	struct rtable___30 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___30 {
	struct dst_entry___86 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___28 {
	struct fib_nh_exception___28 *chain;
};

struct fib_info___18;

struct fib_nh___18 {
	struct fib_nh_common___28 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___18 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___18 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___104 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___18 *nh;
	struct callback_head rcu;
	struct fib_nh___18 fib_nh[0];
};

struct nh_info___18;

struct nh_group___18;

struct nexthop___18 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___104 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___18 *nh_info;
		struct nh_group___18 *nh_grp;
	};
};

struct nf_hook_state___19 {
	u8 hook;
	u8 pf;
	struct net_device___99 *in;
	struct net_device___99 *out;
	struct sock___86 *sk;
	struct net___104 *net;
	int (*okfn)(struct net___104 *, struct sock___86 *, struct sk_buff___100 *);
};

struct inet6_protocol___2 {
	void (*early_demux)(struct sk_buff___100 *);
	void (*early_demux_handler)(struct sk_buff___100 *);
	int (*handler)(struct sk_buff___100 *);
	int (*err_handler)(struct sk_buff___100 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct nh_info___18 {
	struct hlist_node dev_hash;
	struct nexthop___18 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___28 fib_nhc;
		struct fib_nh___18 fib_nh;
		struct fib6_nh___28 fib6_nh;
	};
};

struct nh_grp_entry___18;

struct nh_res_bucket___18 {
	struct nh_grp_entry___18 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___18 {
	struct nexthop___18 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___18 *nh_parent;
};

struct nh_res_table___18 {
	struct net___104 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___18 nh_buckets[0];
};

struct nh_group___18 {
	struct nh_group___18 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___18 *res_table;
	struct nh_grp_entry___18 nh_entries[0];
};

struct xfrm_type___21 {
	struct module___274 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___21 *);
	void (*destructor)(struct xfrm_state___21 *);
	int (*input)(struct xfrm_state___21 *, struct sk_buff___100 *);
	int (*output)(struct xfrm_state___21 *, struct sk_buff___100 *);
	int (*reject)(struct xfrm_state___21 *, struct sk_buff___100 *, const struct flowi *);
};

struct xfrm_type_offload___21 {
	struct module___274 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___21 *, struct sk_buff___100 *);
	int (*input_tail)(struct xfrm_state___21 *, struct sk_buff___100 *);
	int (*xmit)(struct xfrm_state___21 *, struct sk_buff___100 *, netdev_features_t);
};

struct dentry___291;

struct super_block___291;

struct module___275;

struct file_system_type___291 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___291 * (*mount)(struct file_system_type___291 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___291 *);
	struct module___275 *owner;
	struct file_system_type___291 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___291;

struct kiocb___291;

struct iov_iter___211;

struct poll_table_struct___212;

struct vm_area_struct___296;

struct inode___291;

struct file_lock___291;

struct page___296;

struct pipe_inode_info___132;

struct seq_file___266;

struct file_operations___292 {
	struct module___275 *owner;
	loff_t (*llseek)(struct file___291 *, loff_t, int);
	ssize_t (*read)(struct file___291 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___291 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___291 *, struct iov_iter___211 *);
	ssize_t (*write_iter)(struct kiocb___291 *, struct iov_iter___211 *);
	int (*iopoll)(struct kiocb___291 *, bool);
	int (*iterate)(struct file___291 *, struct dir_context *);
	int (*iterate_shared)(struct file___291 *, struct dir_context *);
	__poll_t (*poll)(struct file___291 *, struct poll_table_struct___212 *);
	long int (*unlocked_ioctl)(struct file___291 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___291 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___291 *, struct vm_area_struct___296 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___291 *, struct file___291 *);
	int (*flush)(struct file___291 *, fl_owner_t);
	int (*release)(struct inode___291 *, struct file___291 *);
	int (*fsync)(struct file___291 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___291 *, int);
	int (*lock)(struct file___291 *, int, struct file_lock___291 *);
	ssize_t (*sendpage)(struct file___291 *, struct page___296 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___291 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___291 *, long unsigned int);
	int (*flock)(struct file___291 *, int, struct file_lock___291 *);
	ssize_t (*splice_write)(struct pipe_inode_info___132 *, struct file___291 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___291 *, loff_t *, struct pipe_inode_info___132 *, size_t, unsigned int);
	int (*setlease)(struct file___291 *, long int, struct file_lock___291 **, void **);
	long int (*fallocate)(struct file___291 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___266 *, struct file___291 *);
	ssize_t (*copy_file_range)(struct file___291 *, loff_t, struct file___291 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___291 *, loff_t, struct file___291 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___291 *, loff_t, loff_t, int);
};

struct vmacache___296 {
	u64 seqnum;
	struct vm_area_struct___296 *vmas[4];
};

struct page_frag___296 {
	struct page___296 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___297;

struct pid___268;

struct nsproxy___277;

struct signal_struct___292;

struct bio_list___182;

struct backing_dev_info___168;

struct io_context___182;

struct css_set___218;

struct mem_cgroup___156;

struct request_queue___182;

struct vm_struct___274;

struct task_struct___298 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___298 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___297 *mm;
	struct mm_struct___297 *active_mm;
	struct vmacache___296 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___298 *real_parent;
	struct task_struct___298 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___298 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___268 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___277 *nsproxy;
	struct signal_struct___292 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___298 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___182 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___168 *backing_dev_info;
	struct io_context___182 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___218 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___132 *splice_pipe;
	struct page_frag___296 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___156 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___156 *active_memcg;
	struct request_queue___182 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___298 *oom_reaper_list;
	struct vm_struct___274 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___87 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___279;

struct kobj_type___279;

struct kernfs_node___279;

struct kobject___279 {
	const char *name;
	struct list_head entry;
	struct kobject___279 *parent;
	struct kset___279 *kset;
	struct kobj_type___279 *ktype;
	struct kernfs_node___279 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___276 {
	struct kobject___279 kobj;
	struct module___275 *mod;
	struct kobject___279 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___275 {
	struct module___275 *mod;
	struct latch_tree_node node;
};

struct module_layout___275 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___275 mtn;
};

struct module_attribute___275;

struct kernel_param___275;

struct module___275 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___276 mkobj;
	struct module_attribute___275 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___279 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___275 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___275 core_layout;
	struct module_layout___275 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___268;

struct upid___268 {
	int nr;
	struct pid_namespace___268 *ns;
};

struct pid_namespace___268 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___298 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___268 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___268 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___268 numbers[1];
};

typedef struct page___296 *pgtable_t___296;

struct address_space___291;

struct page_pool___120;

struct dev_pagemap___286;

struct page___296 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___291 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___120 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___296 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___296 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___297 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___286 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___286;

struct vm_area_struct___296 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___296 *vm_next;
	struct vm_area_struct___296 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___297 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___286 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___291 *vm_file;
	struct file___291 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___292 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___298 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___298 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___268 *pids[4];
	struct pid___268 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___297 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___296;

struct mm_struct___297 {
	struct {
		struct vm_area_struct___296 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___291 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___296 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___298 *owner;
		struct user_namespace___26 *user_ns;
		struct file___291 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___105;

struct cgroup_namespace___218;

struct nsproxy___277 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___268 *pid_ns_for_children;
	struct net___105 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___218 *cgroup_ns;
};

struct bio___182;

struct bio_list___182 {
	struct bio___182 *head;
	struct bio___182 *tail;
};

struct cgroup_subsys_state___218;

struct bdi_writeback___168 {
	struct backing_dev_info___168 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___218 *memcg_css;
	struct cgroup_subsys_state___218 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___272;

struct backing_dev_info___168 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___168 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___272 *dev;
	char dev_name[64];
	struct device___272 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___291 *debug_dir;
};

struct io_cq___182;

struct io_context___182 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___182 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___218;

struct css_set___218 {
	struct cgroup_subsys_state___218 *subsys[14];
	refcount_t refcount;
	struct css_set___218 *dom_cset;
	struct cgroup___218 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___218 *mg_src_cgrp;
	struct cgroup___218 *mg_dst_cgrp;
	struct css_set___218 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___291;

struct pipe_buffer___132;

struct pipe_inode_info___132 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___296 *tmp_page;
	struct fasync_struct___291 *fasync_readers;
	struct fasync_struct___291 *fasync_writers;
	struct pipe_buffer___132 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___218;

struct cgroup_subsys_state___218 {
	struct cgroup___218 *cgroup;
	struct cgroup_subsys___218 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___218 *parent;
};

struct cgroup_file___218 {
	struct kernfs_node___279 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___156;

struct mem_cgroup_per_node___156;

struct mem_cgroup___156 {
	struct cgroup_subsys_state___218 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___218 events_file;
	struct cgroup_file___218 events_local_file;
	struct cgroup_file___218 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___156 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___298 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___156 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___182;

struct blk_integrity___182 {
	const struct blk_integrity_profile___182 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___182 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___182 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___182;

struct elevator_queue___182;

struct blk_mq_ops___177;

struct blk_mq_hw_ctx___177;

struct gendisk___185;

struct blkcg_gq___170;

struct blk_mq_tag_set___177;

struct request_queue___182 {
	struct request___182 *last_merge;
	struct elevator_queue___182 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___177 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___177 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___185 *disk;
	struct kobject___279 kobj;
	struct kobject___279 *mq_kobj;
	struct blk_integrity___182 integrity;
	struct device___272 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___170 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___177 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___182 bio_split;
	struct dentry___291 *debugfs_dir;
	struct dentry___291 *sched_debugfs_dir;
	struct dentry___291 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___274 {
	struct vm_struct___274 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___296 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___291;

struct address_space___291 {
	struct inode___291 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___291 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___120 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___272 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___120 {
	u32 count;
	struct page___296 *cache[128];
};

struct page_pool___120 {
	struct page_pool_params___120 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___296 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___120 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___286;

struct dev_pagemap___286 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___286 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___291;

struct path___291 {
	struct vfsmount___291 *mnt;
	struct dentry___291 *dentry;
};

struct fown_struct___268 {
	rwlock_t lock;
	struct pid___268 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___291 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___291 f_path;
	struct inode___291 *f_inode;
	const struct file_operations___292 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___268 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___291 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___286;

struct vm_operations_struct___286 {
	void (*open)(struct vm_area_struct___296 *);
	void (*close)(struct vm_area_struct___296 *);
	int (*may_split)(struct vm_area_struct___296 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___296 *);
	int (*mprotect)(struct vm_area_struct___296 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___286 *);
	vm_fault_t (*huge_fault)(struct vm_fault___286 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___286 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___296 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___286 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___286 *);
	int (*access)(struct vm_area_struct___296 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___296 *);
	int (*set_policy)(struct vm_area_struct___296 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___296 *, long unsigned int);
	struct page___296 * (*find_special_page)(struct vm_area_struct___296 *, long unsigned int);
};

struct core_thread___296 {
	struct task_struct___298 *task;
	struct core_thread___296 *next;
};

struct core_state___296 {
	atomic_t nr_threads;
	struct core_thread___296 dumper;
	struct completion startup;
};

struct vm_fault___286 {
	const struct {
		struct vm_area_struct___296 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___296 *cow_page;
	struct page___296 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___296 prealloc_pte;
};

struct psi_group___218 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___298 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___94;

struct cgroup_bpf___94 {
	struct bpf_prog_array___94 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___94 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___218;

struct cgroup_rstat_cpu___218;

struct cgroup___218 {
	struct cgroup_subsys_state___218 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___279 *kn;
	struct cgroup_file___218 procs_file;
	struct cgroup_file___218 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___218 *subsys[14];
	struct cgroup_root___218 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___218 *dom_cgrp;
	struct cgroup___218 *old_dom_cgrp;
	struct cgroup_rstat_cpu___218 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___218 psi;
	struct cgroup_bpf___94 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___164;

struct lruvec___164 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___164 *pgdat;
};

struct zone___164 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___164 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___164 {
	struct zone___164 *zone;
	int zone_idx;
};

struct zonelist___164 {
	struct zoneref___164 _zonerefs[321];
};

struct pglist_data___164 {
	struct zone___164 node_zones[5];
	struct zonelist___164 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___298 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___298 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___164 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct bio_vec___208 {
	struct page___296 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___211 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___208 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___132 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___89 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___211 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___291 *msg_iocb;
};

struct kiocb___291 {
	struct file___291 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___291 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct dentry_operations___291;

struct dentry___291 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___291 *d_parent;
	struct qstr d_name;
	struct inode___291 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___291 *d_op;
	struct super_block___291 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___291;

struct inode___291 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___291 *i_op;
	struct super_block___291 *i_sb;
	struct address_space___291 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___168 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___292 *i_fop;
		void (*free_inode)(struct inode___291 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___291 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___132 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___291 {
	int (*d_revalidate)(struct dentry___291 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___291 *, unsigned int);
	int (*d_hash)(const struct dentry___291 *, struct qstr *);
	int (*d_compare)(const struct dentry___291 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___291 *);
	int (*d_init)(struct dentry___291 *);
	void (*d_release)(struct dentry___291 *);
	void (*d_prune)(struct dentry___291 *);
	void (*d_iput)(struct dentry___291 *, struct inode___291 *);
	char * (*d_dname)(struct dentry___291 *, char *, int);
	struct vfsmount___291 * (*d_automount)(struct path___291 *);
	int (*d_manage)(const struct path___291 *, bool);
	struct dentry___291 * (*d_real)(struct dentry___291 *, const struct inode___291 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___291;

struct mem_dqinfo___291 {
	struct quota_format_type___291 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___291;

struct quota_info___291 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___291 *files[3];
	struct mem_dqinfo___291 info[3];
	const struct quota_format_ops___291 *ops[3];
};

struct rcuwait___292 {
	struct task_struct___298 *task;
};

struct percpu_rw_semaphore___292 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___292 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___291 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___292 rw_sem[3];
};

struct shrink_control___156;

struct shrinker___156 {
	long unsigned int (*count_objects)(struct shrinker___156 *, struct shrink_control___156 *);
	long unsigned int (*scan_objects)(struct shrinker___156 *, struct shrink_control___156 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___291;

struct dquot_operations___291;

struct quotactl_ops___291;

struct block_device___185;

struct super_block___291 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___291 *s_type;
	const struct super_operations___291 *s_op;
	const struct dquot_operations___291 *dq_op;
	const struct quotactl_ops___291 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___291 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___185 *s_bdev;
	struct backing_dev_info___168 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___291 s_dquot;
	struct sb_writers___291 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___291 *s_d_op;
	int cleancache_poolid;
	struct shrinker___156 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___291 {
	struct dentry___291 *mnt_root;
	struct super_block___291 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___156 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___156 *memcg;
};

struct io_cq___182 {
	struct request_queue___182 *q;
	struct io_context___182 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___291 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___291 *ia_file;
};

struct dquot___291 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___291 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___291 {
	int qf_fmt_id;
	const struct quota_format_ops___291 *qf_ops;
	struct module___275 *qf_owner;
	struct quota_format_type___291 *qf_next;
};

struct quota_format_ops___291 {
	int (*check_quota_file)(struct super_block___291 *, int);
	int (*read_file_info)(struct super_block___291 *, int);
	int (*write_file_info)(struct super_block___291 *, int);
	int (*free_file_info)(struct super_block___291 *, int);
	int (*read_dqblk)(struct dquot___291 *);
	int (*commit_dqblk)(struct dquot___291 *);
	int (*release_dqblk)(struct dquot___291 *);
	int (*get_next_id)(struct super_block___291 *, struct kqid *);
};

struct dquot_operations___291 {
	int (*write_dquot)(struct dquot___291 *);
	struct dquot___291 * (*alloc_dquot)(struct super_block___291 *, int);
	void (*destroy_dquot)(struct dquot___291 *);
	int (*acquire_dquot)(struct dquot___291 *);
	int (*release_dquot)(struct dquot___291 *);
	int (*mark_dirty)(struct dquot___291 *);
	int (*write_info)(struct super_block___291 *, int);
	qsize_t * (*get_reserved_space)(struct inode___291 *);
	int (*get_projid)(struct inode___291 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___291 *, qsize_t *);
	int (*get_next_id)(struct super_block___291 *, struct kqid *);
};

struct quotactl_ops___291 {
	int (*quota_on)(struct super_block___291 *, int, int, const struct path___291 *);
	int (*quota_off)(struct super_block___291 *, int);
	int (*quota_enable)(struct super_block___291 *, unsigned int);
	int (*quota_disable)(struct super_block___291 *, unsigned int);
	int (*quota_sync)(struct super_block___291 *, int);
	int (*set_info)(struct super_block___291 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___291 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___291 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___291 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___291 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___291 *, unsigned int);
};

struct writeback_control___168;

struct address_space_operations___291 {
	int (*writepage)(struct page___296 *, struct writeback_control___168 *);
	int (*readpage)(struct file___291 *, struct page___296 *);
	int (*writepages)(struct address_space___291 *, struct writeback_control___168 *);
	int (*set_page_dirty)(struct page___296 *);
	int (*readpages)(struct file___291 *, struct address_space___291 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___291 *, struct address_space___291 *, loff_t, unsigned int, unsigned int, struct page___296 **, void **);
	int (*write_end)(struct file___291 *, struct address_space___291 *, loff_t, unsigned int, unsigned int, struct page___296 *, void *);
	sector_t (*bmap)(struct address_space___291 *, sector_t);
	void (*invalidatepage)(struct page___296 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___296 *, gfp_t);
	void (*freepage)(struct page___296 *);
	ssize_t (*direct_IO)(struct kiocb___291 *, struct iov_iter___211 *);
	int (*migratepage)(struct address_space___291 *, struct page___296 *, struct page___296 *, enum migrate_mode);
	bool (*isolate_page)(struct page___296 *, isolate_mode_t);
	void (*putback_page)(struct page___296 *);
	int (*launder_page)(struct page___296 *);
	int (*is_partially_uptodate)(struct page___296 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___296 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___291 *, struct page___296 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___291 *, sector_t *);
	void (*swap_deactivate)(struct file___291 *);
};

struct writeback_control___168 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___168 *wb;
	struct inode___291 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___291 {
	struct dentry___291 * (*lookup)(struct inode___291 *, struct dentry___291 *, unsigned int);
	const char * (*get_link)(struct dentry___291 *, struct inode___291 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___291 *, int);
	struct posix_acl * (*get_acl)(struct inode___291 *, int, bool);
	int (*readlink)(struct dentry___291 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___291 *, struct dentry___291 *, umode_t, bool);
	int (*link)(struct dentry___291 *, struct inode___291 *, struct dentry___291 *);
	int (*unlink)(struct inode___291 *, struct dentry___291 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___291 *, struct dentry___291 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___291 *, struct dentry___291 *, umode_t);
	int (*rmdir)(struct inode___291 *, struct dentry___291 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___291 *, struct dentry___291 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___291 *, struct dentry___291 *, struct inode___291 *, struct dentry___291 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___291 *, struct iattr___291 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___291 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___291 *, char *, size_t);
	int (*fiemap)(struct inode___291 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___291 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___291 *, struct dentry___291 *, struct file___291 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___291 *, struct dentry___291 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___291 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___291 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___291 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___291 {
	void (*fl_copy_lock)(struct file_lock___291 *, struct file_lock___291 *);
	void (*fl_release_private)(struct file_lock___291 *);
};

struct lock_manager_operations___291;

struct file_lock___291 {
	struct file_lock___291 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___291 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___291 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___291 *fl_ops;
	const struct lock_manager_operations___291 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___291 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___291 *);
	int (*lm_grant)(struct file_lock___291 *, int);
	bool (*lm_break)(struct file_lock___291 *);
	int (*lm_change)(struct file_lock___291 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___291 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___291 *);
};

struct fasync_struct___291 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___291 *fa_next;
	struct file___291 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___291 {
	struct inode___291 * (*alloc_inode)(struct super_block___291 *);
	void (*destroy_inode)(struct inode___291 *);
	void (*free_inode)(struct inode___291 *);
	void (*dirty_inode)(struct inode___291 *, int);
	int (*write_inode)(struct inode___291 *, struct writeback_control___168 *);
	int (*drop_inode)(struct inode___291 *);
	void (*evict_inode)(struct inode___291 *);
	void (*put_super)(struct super_block___291 *);
	int (*sync_fs)(struct super_block___291 *, int);
	int (*freeze_super)(struct super_block___291 *);
	int (*freeze_fs)(struct super_block___291 *);
	int (*thaw_super)(struct super_block___291 *);
	int (*unfreeze_fs)(struct super_block___291 *);
	int (*statfs)(struct dentry___291 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___291 *, int *, char *);
	void (*umount_begin)(struct super_block___291 *);
	int (*show_options)(struct seq_file___266 *, struct dentry___291 *);
	int (*show_devname)(struct seq_file___266 *, struct dentry___291 *);
	int (*show_path)(struct seq_file___266 *, struct dentry___291 *);
	int (*show_stats)(struct seq_file___266 *, struct dentry___291 *);
	ssize_t (*quota_read)(struct super_block___291 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___291 *, int, const char *, size_t, loff_t);
	struct dquot___291 ** (*get_dquots)(struct inode___291 *);
	long int (*nr_cached_objects)(struct super_block___291 *, struct shrink_control___156 *);
	long int (*free_cached_objects)(struct super_block___291 *, struct shrink_control___156 *);
	struct file___291 * (*real_loop)(struct file___291 *);
};

struct wakeup_source___272;

struct dev_pm_info___272 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___272 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___272 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___272;

struct bus_type___272;

struct device_driver___272;

struct dev_pm_domain___272;

struct fwnode_handle___268;

struct class___272;

struct attribute_group___279;

struct device___272 {
	struct kobject___279 kobj;
	struct device___272 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___272 *type;
	struct bus_type___272 *bus;
	struct device_driver___272 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___272 power;
	struct dev_pm_domain___272 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___268 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___272 *class;
	const struct attribute_group___279 **groups;
	void (*release)(struct device___272 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___185 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___291 *bd_inode;
	struct super_block___291 *bd_super;
	void *bd_claiming;
	struct device___272 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___279 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___185 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___291 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___220)(struct file___291 *, wait_queue_head_t *, struct poll_table_struct___212 *);

struct poll_table_struct___212 {
	poll_queue_proc___220 _qproc;
	__poll_t _key;
};

struct seq_operations___266;

struct seq_file___266 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___266 *op;
	int poll_event;
	const struct file___291 *file;
	void *private;
};

typedef void bio_end_io_t___182(struct bio___182 *);

struct bio_integrity_payload___182;

struct bio___182 {
	struct bio___182 *bi_next;
	struct block_device___185 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___182 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___170 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___182 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___208 *bi_io_vec;
	struct bio_set___182 *bi_pool;
	struct bio_vec___208 bi_inline_vecs[0];
};

struct dev_pagemap_ops___286 {
	void (*page_free)(struct page___296 *);
	void (*kill)(struct dev_pagemap___286 *);
	void (*cleanup)(struct dev_pagemap___286 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___286 *);
};

struct socket_wq___88 {
	wait_queue_head_t wait;
	struct fasync_struct___291 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___87;

struct proto_ops___88;

struct socket___89 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___291 *file;
	struct sock___87 *sk;
	const struct proto_ops___88 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___88 wq;
};

typedef struct {
	struct net___105 *net;
} possible_net_t___100;

struct proto___87;

struct sock_common___87 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___87 *skc_prot;
	possible_net_t___100 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___87 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___101;

struct sk_buff_head___100 {
	struct sk_buff___101 *next;
	struct sk_buff___101 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___87 {
	struct cgroup___218 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___87;

struct dst_entry___87;

struct net_device___100;

struct sock_reuseport___35;

struct sock___87 {
	struct sock_common___87 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___100 sk_error_queue;
	struct sk_buff___101 *sk_rx_skb_cache;
	struct sk_buff_head___100 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___101 *head;
		struct sk_buff___101 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___87 *sk_filter;
	union {
		struct socket_wq___88 *sk_wq;
		struct socket_wq___88 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___87 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___87 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___101 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___101 *sk_tx_skb_cache;
	struct sk_buff_head___100 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___296 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___87 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___268 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___89 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___87 sk_cgrp_data;
	struct mem_cgroup___156 *sk_memcg;
	void (*sk_state_change)(struct sock___87 *);
	void (*sk_data_ready)(struct sock___87 *);
	void (*sk_write_space)(struct sock___87 *);
	void (*sk_error_report)(struct sock___87 *);
	int (*sk_backlog_rcv)(struct sock___87 *, struct sk_buff___101 *);
	struct sk_buff___101 * (*sk_validate_xmit_skb)(struct sock___87 *, struct net_device___100 *, struct sk_buff___101 *);
	void (*sk_destruct)(struct sock___87 *);
	struct sock_reuseport___35 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___87)(read_descriptor_t *, struct sk_buff___101 *, unsigned int, size_t);

struct proto_ops___88 {
	int family;
	struct module___275 *owner;
	int (*release)(struct socket___89 *);
	int (*bind)(struct socket___89 *, struct sockaddr *, int);
	int (*connect)(struct socket___89 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___89 *, struct socket___89 *);
	int (*accept)(struct socket___89 *, struct socket___89 *, int, bool);
	int (*getname)(struct socket___89 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___291 *, struct socket___89 *, struct poll_table_struct___212 *);
	int (*ioctl)(struct socket___89 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___89 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___89 *, void *, bool, bool);
	int (*listen)(struct socket___89 *, int);
	int (*shutdown)(struct socket___89 *, int);
	int (*setsockopt)(struct socket___89 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___89 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___266 *, struct socket___89 *);
	int (*sendmsg)(struct socket___89 *, struct msghdr___89 *, size_t);
	int (*recvmsg)(struct socket___89 *, struct msghdr___89 *, size_t, int);
	int (*mmap)(struct file___291 *, struct socket___89 *, struct vm_area_struct___296 *);
	ssize_t (*sendpage)(struct socket___89 *, struct page___296 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___89 *, loff_t *, struct pipe_inode_info___132 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___87 *, int);
	int (*peek_len)(struct socket___89 *);
	int (*read_sock)(struct sock___87 *, read_descriptor_t *, sk_read_actor_t___87);
	int (*sendpage_locked)(struct sock___87 *, struct page___296 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___87 *, struct msghdr___89 *, size_t);
	int (*set_rcvlowat)(struct sock___87 *, int);
};

struct sk_buff___101 {
	union {
		struct {
			struct sk_buff___101 *next;
			struct sk_buff___101 *prev;
			union {
				struct net_device___100 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___87 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___101 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___60;

struct fib_rules_ops___87;

struct fqdir___105;

struct tcp_congestion_ops___33;

struct fib_notifier_ops___87;

struct netns_ipv4___105 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___60 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___87 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___87 *fibnl;
	struct sock___87 **icmp_sk;
	struct sock___87 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___87 **tcp_sk;
	struct fqdir___105 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___33 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___87 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___87 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___87 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___87;

struct dst_ops___105 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___105 *);
	struct dst_entry___87 * (*check)(struct dst_entry___87 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___87 *);
	unsigned int (*mtu)(const struct dst_entry___87 *);
	u32 * (*cow_metrics)(struct dst_entry___87 *, long unsigned int);
	void (*destroy)(struct dst_entry___87 *);
	void (*ifdown)(struct dst_entry___87 *, struct net_device___100 *, int);
	struct dst_entry___87 * (*negative_advice)(struct dst_entry___87 *);
	void (*link_failure)(struct sk_buff___101 *);
	void (*update_pmtu)(struct dst_entry___87 *, struct sock___87 *, struct sk_buff___101 *, u32, bool);
	void (*redirect)(struct dst_entry___87 *, struct sock___87 *, struct sk_buff___101 *);
	int (*local_out)(struct net___105 *, struct sock___87 *, struct sk_buff___101 *);
	struct neighbour___87 * (*neigh_lookup)(const struct dst_entry___87 *, struct sk_buff___101 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___87 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___29;

struct rt6_info___29;

struct fib6_table___29;

struct netns_ipv6___105 {
	struct dst_ops___105 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___105 *fqdir;
	struct fib6_info___29 *fib6_null_entry;
	struct rt6_info___29 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___29 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___29 *ip6_prohibit_entry;
	struct rt6_info___29 *ip6_blk_hole_entry;
	struct fib6_table___29 *fib6_local_tbl;
	struct fib_rules_ops___87 *fib6_rules_ops;
	struct sock___87 **icmp_sk;
	struct sock___87 *ndisc_sk;
	struct sock___87 *tcp_sk;
	struct sock___87 *igmp_sk;
	struct sock___87 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___87 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___87 *notifier_ops;
	struct fib_notifier_ops___87 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___105 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___105 *fqdir;
};

struct netns_sctp___87 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___87 *ctl_sock;
	struct sock___87 *udp4_sock;
	struct sock___87 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___94;

struct netns_bpf___94 {
	struct bpf_prog_array___94 *run_array[2];
	struct bpf_prog___94 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___105 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___87 *nlsk;
	struct sock___87 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___105 xfrm4_dst_ops;
	struct dst_ops___105 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___105 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___87 *rtnl;
	struct sock___87 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___100 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___105 ipv4;
	struct netns_ipv6___105 ipv6;
	struct netns_ieee802154_lowpan___105 ieee802154_lowpan;
	struct netns_sctp___87 sctp;
	struct netns_nf___19 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___100 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___94 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___105 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___87 *crypto_nlsk;
	struct sock___87 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___105;

struct fqdir___105 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___105 *f;
	struct net___105 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___105;

struct inet_frags___105 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___105 *, const void *);
	void (*destructor)(struct inet_frag_queue___105 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___105 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___101 *fragments_tail;
	struct sk_buff___101 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___105 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___60 {
	struct ip_ra_chain___60 *next;
	struct sock___87 *sk;
	union {
		void (*destructor)(struct sock___87 *);
		struct sock___87 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___87;

struct fib_lookup_arg___87;

struct fib_rules_ops___87 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___87 *, struct flowi *, int, struct fib_lookup_arg___87 *);
	bool (*suppress)(struct fib_rule___87 *, int, struct fib_lookup_arg___87 *);
	int (*match)(struct fib_rule___87 *, struct flowi *, int);
	int (*configure)(struct fib_rule___87 *, struct sk_buff___101 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___87 *);
	int (*compare)(struct fib_rule___87 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___87 *, struct sk_buff___101 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___87 *);
	void (*flush_cache)(struct fib_rules_ops___87 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___275 *owner;
	struct net___105 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___33 {
	u32 (*ssthresh)(struct sock___87 *);
	void (*cong_avoid)(struct sock___87 *, u32, u32);
	void (*set_state)(struct sock___87 *, u8);
	void (*cwnd_event)(struct sock___87 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___87 *, u32);
	void (*pkts_acked)(struct sock___87 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___87 *);
	void (*cong_control)(struct sock___87 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___87 *);
	u32 (*sndbuf_expand)(struct sock___87 *);
	size_t (*get_info)(struct sock___87 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___275 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___87 *);
	void (*release)(struct sock___87 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___87 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___105 *);
	int (*fib_dump)(struct net___105 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___275 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___63;

struct dst_entry___87 {
	struct net_device___100 *dev;
	struct dst_ops___105 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___101 *);
	int (*output)(struct net___105 *, struct sock___87 *, struct sk_buff___101 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___63 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___100(struct sk_buff___101 **);

struct bpf_xdp_entity___94 {
	struct bpf_prog___94 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___100;

struct net_device_ops___100;

struct l3mdev_ops___87;

struct ndisc_ops___69;

struct xfrmdev_ops___100;

struct header_ops___100;

struct in_device___21;

struct inet6_dev___69;

struct wpan_dev___3;

struct netdev_rx_queue___100;

struct mini_Qdisc___94;

struct netdev_queue___100;

struct Qdisc___94;

struct rtnl_link_ops___94;

struct dcbnl_rtnl_ops___100;

struct net_device___100 {
	char name[16];
	struct netdev_name_node___100 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___100 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___87 *l3mdev_ops;
	const struct ndisc_ops___69 *ndisc_ops;
	const struct xfrmdev_ops___100 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___100 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___279 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___21 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___69 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev___3 *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___100 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___94 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___100 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___94 *miniq_ingress;
	struct netdev_queue___100 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___100 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___94 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___94 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___100 = 0,
		NETREG_REGISTERED___100 = 1,
		NETREG_UNREGISTERING___100 = 2,
		NETREG_UNREGISTERED___100 = 3,
		NETREG_RELEASED___100 = 4,
		NETREG_DUMMY___100 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___100 = 0,
		RTNL_LINK_INITIALIZING___100 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___100 *);
	struct netpoll_info *npinfo;
	possible_net_t___100 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___272 dev;
	const struct attribute_group___279 *sysfs_groups[4];
	const struct attribute_group___279 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___94 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___100 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___94 xdp_state[3];
	long: 64;
};

struct neigh_table___87;

struct neigh_parms___87;

struct neigh_ops___87;

struct neighbour___87 {
	struct neighbour___87 *next;
	struct neigh_table___87 *tbl;
	struct neigh_parms___87 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___100 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___87 *, struct sk_buff___101 *);
	const struct neigh_ops___87 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___100 *dev;
	u8 primary_key[0];
};

struct rtable___31;

struct fnhe_hash_bucket___29;

struct fib_nh_common___29 {
	struct net_device___100 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___63 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___31 **nhc_pcpu_rth_output;
	struct rtable___31 *nhc_rth_input;
	struct fnhe_hash_bucket___29 *nhc_exceptions;
};

struct fib6_nh___29 {
	struct fib_nh_common___29 nh_common;
	long unsigned int last_probe;
	struct rt6_info___29 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___29;

struct nexthop___19;

struct fib6_info___29 {
	struct fib6_table___29 *fib6_table;
	struct fib6_info___29 *fib6_next;
	struct fib6_node___29 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___19 *nh;
	struct fib6_nh___29 fib6_nh[0];
};

struct rt6_info___29 {
	struct dst_entry___87 dst;
	struct fib6_info___29 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___69 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___29 {
	struct fib6_node___29 *parent;
	struct fib6_node___29 *left;
	struct fib6_node___29 *right;
	struct fib6_node___29 *subtree;
	struct fib6_info___29 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___29 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___29 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___29 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___94 {
	struct bpf_prog___94 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___94 {
	struct callback_head rcu;
	struct bpf_prog_array_item___94 items[0];
};

struct bpf_prog_aux___103;

struct bpf_prog___94 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___103 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___268;

struct fwnode_handle___268 {
	struct fwnode_handle___268 *secondary;
	const struct fwnode_operations___268 *ops;
	struct device___272 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___268;

struct fwnode_endpoint___268;

struct fwnode_operations___268 {
	struct fwnode_handle___268 * (*get)(struct fwnode_handle___268 *);
	void (*put)(struct fwnode_handle___268 *);
	bool (*device_is_available)(const struct fwnode_handle___268 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___268 *, const struct device___272 *);
	bool (*property_present)(const struct fwnode_handle___268 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___268 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___268 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___268 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*get_parent)(const struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*get_next_child_node)(const struct fwnode_handle___268 *, struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*get_named_child_node)(const struct fwnode_handle___268 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___268 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___268 *);
	struct fwnode_handle___268 * (*graph_get_next_endpoint)(const struct fwnode_handle___268 *, struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*graph_get_remote_endpoint)(const struct fwnode_handle___268 *);
	struct fwnode_handle___268 * (*graph_get_port_parent)(struct fwnode_handle___268 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___268 *, struct fwnode_endpoint___268 *);
	int (*add_links)(struct fwnode_handle___268 *);
};

struct fwnode_endpoint___268 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___268 *local_fwnode;
};

struct fwnode_reference_args___268 {
	struct fwnode_handle___268 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___279;

struct kernfs_elem_dir___279 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___279 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___279;

struct kernfs_root___279 {
	struct kernfs_node___279 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___279 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___279 {
	struct kernfs_node___279 *target_kn;
};

struct kernfs_ops___279;

struct kernfs_elem_attr___279 {
	const struct kernfs_ops___279 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___279 *notify_next;
};

struct kernfs_node___279 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___279 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___279 dir;
		struct kernfs_elem_symlink___279 symlink;
		struct kernfs_elem_attr___279 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___279;

struct kernfs_ops___279 {
	int (*open)(struct kernfs_open_file___279 *);
	void (*release)(struct kernfs_open_file___279 *);
	int (*seq_show)(struct seq_file___266 *, void *);
	void * (*seq_start)(struct seq_file___266 *, loff_t *);
	void * (*seq_next)(struct seq_file___266 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___266 *, void *);
	ssize_t (*read)(struct kernfs_open_file___279 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___279 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___279 *, struct poll_table_struct___212 *);
	int (*mmap)(struct kernfs_open_file___279 *, struct vm_area_struct___296 *);
};

struct kernfs_syscall_ops___279 {
	int (*show_options)(struct seq_file___266 *, struct kernfs_root___279 *);
	int (*mkdir)(struct kernfs_node___279 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___279 *);
	int (*rename)(struct kernfs_node___279 *, struct kernfs_node___279 *, const char *);
	int (*show_path)(struct seq_file___266 *, struct kernfs_node___279 *, struct kernfs_root___279 *);
};

struct kernfs_open_file___279 {
	struct kernfs_node___279 *kn;
	struct file___291 *file;
	struct seq_file___266 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___286 *vm_ops;
};

struct kobj_ns_type_operations___87 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___87 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___279;

struct attribute_group___279 {
	const char *name;
	umode_t (*is_visible)(struct kobject___279 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___279 *, struct bin_attribute___279 *, int);
	struct attribute **attrs;
	struct bin_attribute___279 **bin_attrs;
};

struct bin_attribute___279 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___291 * (*f_mapping)();
	ssize_t (*read)(struct file___291 *, struct kobject___279 *, struct bin_attribute___279 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___291 *, struct kobject___279 *, struct bin_attribute___279 *, char *, loff_t, size_t);
	int (*mmap)(struct file___291 *, struct kobject___279 *, struct bin_attribute___279 *, struct vm_area_struct___296 *);
};

struct sysfs_ops___279 {
	ssize_t (*show)(struct kobject___279 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___279 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___279;

struct kset___279 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___279 kobj;
	const struct kset_uevent_ops___279 *uevent_ops;
};

struct kobj_type___279 {
	void (*release)(struct kobject___279 *);
	const struct sysfs_ops___279 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___279 **default_groups;
	const struct kobj_ns_type_operations___87 * (*child_ns_type)(struct kobject___279 *);
	const void * (*namespace)(struct kobject___279 *);
	void (*get_ownership)(struct kobject___279 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___279 {
	int (* const filter)(struct kset___279 *, struct kobject___279 *);
	const char * (* const name)(struct kset___279 *, struct kobject___279 *);
	int (* const uevent)(struct kset___279 *, struct kobject___279 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___275 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___275 *);
	int (*get)(char *, const struct kernel_param___275 *);
	void (*free)(void *);
};

struct kparam_array___275;

struct kernel_param___275 {
	const char *name;
	struct module___275 *mod;
	const struct kernel_param_ops___275 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___275 *arr;
	};
};

struct kparam_array___275 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___275 *ops;
	void *elem;
};

struct module_attribute___275 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___275 *, struct module_kobject___276 *, char *);
	ssize_t (*store)(struct module_attribute___275 *, struct module_kobject___276 *, const char *, size_t);
	void (*setup)(struct module___275 *, const char *);
	int (*test)(struct module___275 *);
	void (*free)(struct module___275 *);
};

struct cgroup_namespace___218 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___218 *root_cset;
};

struct dev_pm_ops___272 {
	int (*prepare)(struct device___272 *);
	void (*complete)(struct device___272 *);
	int (*suspend)(struct device___272 *);
	int (*resume)(struct device___272 *);
	int (*freeze)(struct device___272 *);
	int (*thaw)(struct device___272 *);
	int (*poweroff)(struct device___272 *);
	int (*restore)(struct device___272 *);
	int (*suspend_late)(struct device___272 *);
	int (*resume_early)(struct device___272 *);
	int (*freeze_late)(struct device___272 *);
	int (*thaw_early)(struct device___272 *);
	int (*poweroff_late)(struct device___272 *);
	int (*restore_early)(struct device___272 *);
	int (*suspend_noirq)(struct device___272 *);
	int (*resume_noirq)(struct device___272 *);
	int (*freeze_noirq)(struct device___272 *);
	int (*thaw_noirq)(struct device___272 *);
	int (*poweroff_noirq)(struct device___272 *);
	int (*restore_noirq)(struct device___272 *);
	int (*runtime_suspend)(struct device___272 *);
	int (*runtime_resume)(struct device___272 *);
	int (*runtime_idle)(struct device___272 *);
};

struct wakeup_source___272 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___272 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___272 {
	struct dev_pm_ops___272 ops;
	int (*start)(struct device___272 *);
	void (*detach)(struct device___272 *, bool);
	int (*activate)(struct device___272 *);
	void (*sync)(struct device___272 *);
	void (*dismiss)(struct device___272 *);
};

struct bus_type___272 {
	const char *name;
	const char *dev_name;
	struct device___272 *dev_root;
	const struct attribute_group___279 **bus_groups;
	const struct attribute_group___279 **dev_groups;
	const struct attribute_group___279 **drv_groups;
	int (*match)(struct device___272 *, struct device_driver___272 *);
	int (*uevent)(struct device___272 *, struct kobj_uevent_env *);
	int (*probe)(struct device___272 *);
	void (*sync_state)(struct device___272 *);
	void (*remove)(struct device___272 *);
	void (*shutdown)(struct device___272 *);
	int (*online)(struct device___272 *);
	int (*offline)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	int (*num_vf)(struct device___272 *);
	int (*dma_configure)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___272 {
	const char *name;
	struct bus_type___272 *bus;
	struct module___275 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___272 *);
	void (*sync_state)(struct device___272 *);
	int (*remove)(struct device___272 *);
	void (*shutdown)(struct device___272 *);
	int (*suspend)(struct device___272 *, pm_message_t);
	int (*resume)(struct device___272 *);
	const struct attribute_group___279 **groups;
	const struct attribute_group___279 **dev_groups;
	const struct dev_pm_ops___272 *pm;
	void (*coredump)(struct device___272 *);
	struct driver_private *p;
};

struct device_type___272 {
	const char *name;
	const struct attribute_group___279 **groups;
	int (*uevent)(struct device___272 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___272 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___272 *);
	const struct dev_pm_ops___272 *pm;
};

struct class___272 {
	const char *name;
	struct module___275 *owner;
	const struct attribute_group___279 **class_groups;
	const struct attribute_group___279 **dev_groups;
	struct kobject___279 *dev_kobj;
	int (*dev_uevent)(struct device___272 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___272 *, umode_t *);
	void (*class_release)(struct class___272 *);
	void (*dev_release)(struct device___272 *);
	int (*shutdown_pre)(struct device___272 *);
	const struct kobj_ns_type_operations___87 *ns_type;
	const void * (*namespace)(struct device___272 *);
	void (*get_ownership)(struct device___272 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___272 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___132;

struct pipe_buffer___132 {
	struct page___296 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___132 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___132 {
	int (*confirm)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
	void (*release)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
	bool (*try_steal)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
	bool (*get)(struct pipe_inode_info___132 *, struct pipe_buffer___132 *);
};

struct seq_operations___266 {
	void * (*start)(struct seq_file___266 *, loff_t *);
	void (*stop)(struct seq_file___266 *, void *);
	void * (*next)(struct seq_file___266 *, void *, loff_t *);
	int (*show)(struct seq_file___266 *, void *);
};

struct seq_net_private___14 {
	struct net___105 *net;
};

struct pernet_operations___34 {
	struct list_head list;
	int (*init)(struct net___105 *);
	void (*pre_exit)(struct net___105 *);
	void (*exit)(struct net___105 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___100 {
	int (*ieee_getets)(struct net_device___100 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___100 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___100 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___100 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___100 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___100 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___100 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___100 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___100 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___100 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___100 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___100 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___100 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___100 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___100 *);
	u8 (*setstate)(struct net_device___100 *, u8);
	void (*getpermhwaddr)(struct net_device___100 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___100 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___100 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___100 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___100 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___100 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___100 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___100 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___100 *, int, u8 *);
	void (*setpfccfg)(struct net_device___100 *, int, u8);
	void (*getpfccfg)(struct net_device___100 *, int, u8 *);
	u8 (*setall)(struct net_device___100 *);
	u8 (*getcap)(struct net_device___100 *, int, u8 *);
	int (*getnumtcs)(struct net_device___100 *, int, u8 *);
	int (*setnumtcs)(struct net_device___100 *, int, u8);
	u8 (*getpfcstate)(struct net_device___100 *);
	void (*setpfcstate)(struct net_device___100 *, u8);
	void (*getbcncfg)(struct net_device___100 *, int, u32 *);
	void (*setbcncfg)(struct net_device___100 *, int, u32);
	void (*getbcnrp)(struct net_device___100 *, int, u8 *);
	void (*setbcnrp)(struct net_device___100 *, int, u8);
	int (*setapp)(struct net_device___100 *, u8, u16, u8);
	int (*getapp)(struct net_device___100 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___100 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___100 *, int, u8);
	u8 (*getdcbx)(struct net_device___100 *);
	u8 (*setdcbx)(struct net_device___100 *, u8);
	int (*peer_getappinfo)(struct net_device___100 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___100 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___100 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___100 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___100 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___100 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___103;

typedef int (*bpf_iter_init_seq_priv_t___102)(void *, struct bpf_iter_aux_info___103 *);

struct bpf_map___103;

struct bpf_iter_aux_info___103 {
	struct bpf_map___103 *map;
};

struct bpf_iter_seq_info___102 {
	const struct seq_operations___266 *seq_ops;
	bpf_iter_init_seq_priv_t___102 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___102 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___103 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___103 *, struct file___291 *);
	void (*map_free)(struct bpf_map___103 *);
	int (*map_get_next_key)(struct bpf_map___103 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___103 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___103 *, void *);
	int (*map_lookup_batch)(struct bpf_map___103 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___103 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___103 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___103 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___103 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___103 *, void *);
	int (*map_update_elem)(struct bpf_map___103 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___103 *, void *);
	int (*map_push_elem)(struct bpf_map___103 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___103 *, void *);
	int (*map_peek_elem)(struct bpf_map___103 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___103 *, struct file___291 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___103 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___103 *, void *, struct seq_file___266 *);
	int (*map_check_btf)(const struct bpf_map___103 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___103 *, struct bpf_prog_aux___103 *);
	void (*map_poke_untrack)(struct bpf_map___103 *, struct bpf_prog_aux___103 *);
	void (*map_poke_run)(struct bpf_map___103 *, u32, struct bpf_prog___94 *, struct bpf_prog___94 *);
	int (*map_direct_value_addr)(const struct bpf_map___103 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___103 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___103 *, struct vm_area_struct___296 *);
	__poll_t (*map_poll)(struct bpf_map___103 *, struct file___291 *, struct poll_table_struct___212 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___103 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___103 *, const struct bpf_map___103 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___103 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___102 *iter_seq_info;
};

struct bpf_map___103 {
	const struct bpf_map_ops___102 *ops;
	struct bpf_map___103 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___156 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___102;

struct bpf_jit_poke_descriptor___102;

struct bpf_prog_ops___94;

struct btf_mod_pair___102;

struct bpf_prog_offload___100;

struct bpf_prog_aux___103 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___94 *dst_prog;
	struct bpf_trampoline___102 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___94 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___102 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___94 *ops;
	struct bpf_map___103 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___102 *used_btfs;
	struct bpf_prog___94 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___103 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___100 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___100;

struct bpf_map_dev_ops___100 {
	int (*map_get_next_key)(struct bpf_offloaded_map___100 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___100 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___100 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___100 *, void *);
};

struct bpf_offloaded_map___100 {
	struct bpf_map___103 map;
	struct net_device___100 *netdev;
	const struct bpf_map_dev_ops___100 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___94 {
	int (*test_run)(struct bpf_prog___94 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___100 {
	struct bpf_prog___94 *prog;
	struct net_device___100 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___102 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___94 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___275 *mod;
};

struct bpf_jit_poke_descriptor___102 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___103 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___102 {
	struct btf *btf;
	struct module___275 *module;
};

struct cftype___218;

struct cgroup_subsys___218 {
	struct cgroup_subsys_state___218 * (*css_alloc)(struct cgroup_subsys_state___218 *);
	int (*css_online)(struct cgroup_subsys_state___218 *);
	void (*css_offline)(struct cgroup_subsys_state___218 *);
	void (*css_released)(struct cgroup_subsys_state___218 *);
	void (*css_free)(struct cgroup_subsys_state___218 *);
	void (*css_reset)(struct cgroup_subsys_state___218 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___218 *, int);
	int (*css_extra_stat_show)(struct seq_file___266 *, struct cgroup_subsys_state___218 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___298 *, struct css_set___218 *);
	void (*cancel_fork)(struct task_struct___298 *, struct css_set___218 *);
	void (*fork)(struct task_struct___298 *);
	void (*exit)(struct task_struct___298 *);
	void (*release)(struct task_struct___298 *);
	void (*bind)(struct cgroup_subsys_state___218 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___218 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___218 *dfl_cftypes;
	struct cftype___218 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___218 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___218 *updated_children;
	struct cgroup___218 *updated_next;
};

struct cgroup_root___218 {
	struct kernfs_root___279 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___218 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___218 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___218 *ss;
	struct list_head node;
	struct kernfs_ops___279 *kf_ops;
	int (*open)(struct kernfs_open_file___279 *);
	void (*release)(struct kernfs_open_file___279 *);
	u64 (*read_u64)(struct cgroup_subsys_state___218 *, struct cftype___218 *);
	s64 (*read_s64)(struct cgroup_subsys_state___218 *, struct cftype___218 *);
	int (*seq_show)(struct seq_file___266 *, void *);
	void * (*seq_start)(struct seq_file___266 *, loff_t *);
	void * (*seq_next)(struct seq_file___266 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___266 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___218 *, struct cftype___218 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___218 *, struct cftype___218 *, s64);
	ssize_t (*write)(struct kernfs_open_file___279 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___279 *, struct poll_table_struct___212 *);
};

struct xdp_rxq_info___100 {
	struct net_device___100 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___100 {
	struct net_device___100 *dev;
};

struct xdp_buff___100 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___100 *rxq;
	struct xdp_txq_info___100 *txq;
	u32 frame_sz;
};

struct xdp_frame___100 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___100 *dev_rx;
};

struct netlink_skb_parms___20 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___87 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___100 {
	struct sk_buff___101 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___101 *, struct netlink_callback___100 *);
	int (*done)(struct netlink_callback___100 *);
	void *data;
	struct module___275 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

enum {
	IFLA_INET6_UNSPEC = 0,
	IFLA_INET6_FLAGS = 1,
	IFLA_INET6_CONF = 2,
	IFLA_INET6_STATS = 3,
	IFLA_INET6_MCAST = 4,
	IFLA_INET6_CACHEINFO = 5,
	IFLA_INET6_ICMP6STATS = 6,
	IFLA_INET6_TOKEN = 7,
	IFLA_INET6_ADDR_GEN_MODE = 8,
	IFLA_INET6_RA_MTU = 9,
	__IFLA_INET6_MAX = 10,
};

enum in6_addr_gen_mode {
	IN6_ADDR_GEN_MODE_EUI64 = 0,
	IN6_ADDR_GEN_MODE_NONE = 1,
	IN6_ADDR_GEN_MODE_STABLE_PRIVACY = 2,
	IN6_ADDR_GEN_MODE_RANDOM = 3,
};

struct ifla_cacheinfo {
	__u32 max_reasm_len;
	__u32 tstamp;
	__u32 reachable_time;
	__u32 retrans_time;
};

struct header_ops___100 {
	int (*create)(struct sk_buff___101 *, struct net_device___100 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___101 *, unsigned char *);
	int (*cache)(const struct neighbour___87 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___100 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___101 *);
};

struct netdev_queue___100 {
	struct net_device___100 *dev;
	struct Qdisc___94 *qdisc;
	struct Qdisc___94 *qdisc_sleeping;
	struct kobject___279 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___100 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___94 {
	struct sk_buff___101 *head;
	struct sk_buff___101 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___94;

struct Qdisc___94 {
	int (*enqueue)(struct sk_buff___101 *, struct Qdisc___94 *, struct sk_buff___101 **);
	struct sk_buff___101 * (*dequeue)(struct Qdisc___94 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___94 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___100 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___100 gso_skb;
	struct qdisc_skb_head___94 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___94 *next_sched;
	struct sk_buff_head___100 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___100 {
	struct xdp_rxq_info___100 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___279 kobj;
	struct net_device___100 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___100 {
	enum net_device_path_type type;
	const struct net_device___100 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___100 = 0,
				DEV_PATH_BR_VLAN_TAG___100 = 1,
				DEV_PATH_BR_VLAN_UNTAG___100 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___100 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___100 {
	const struct net_device___100 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___100 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___94 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___100 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___100 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___101 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___100 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___100 *dev;
	const char *name;
};

struct net_device_ops___100 {
	int (*ndo_init)(struct net_device___100 *);
	void (*ndo_uninit)(struct net_device___100 *);
	int (*ndo_open)(struct net_device___100 *);
	int (*ndo_stop)(struct net_device___100 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___101 *, struct net_device___100 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___101 *, struct net_device___100 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___100 *, struct sk_buff___101 *, struct net_device___100 *);
	void (*ndo_change_rx_flags)(struct net_device___100 *, int);
	void (*ndo_set_rx_mode)(struct net_device___100 *);
	int (*ndo_set_mac_address)(struct net_device___100 *, void *);
	int (*ndo_validate_addr)(struct net_device___100 *);
	int (*ndo_do_ioctl)(struct net_device___100 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___100 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___100 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___100 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___100 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___100 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___100 *, int);
	int (*ndo_neigh_setup)(struct net_device___100 *, struct neigh_parms___87 *);
	void (*ndo_tx_timeout)(struct net_device___100 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___100 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___100 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___100 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___100 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___100 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___100 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___100 *);
	int (*ndo_netpoll_setup)(struct net_device___100 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___100 *);
	int (*ndo_set_vf_mac)(struct net_device___100 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___100 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___100 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___100 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___100 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___100 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___100 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___100 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___100 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___100 *, int, struct sk_buff___101 *);
	int (*ndo_get_vf_guid)(struct net_device___100 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___100 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___100 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___100 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___100 *);
	int (*ndo_fcoe_disable)(struct net_device___100 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___100 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___100 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___100 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___100 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___100 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___100 *, const struct sk_buff___101 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___100 *, struct net_device___100 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___100 *, struct net_device___100 *);
	struct net_device___100 * (*ndo_get_xmit_slave)(struct net_device___100 *, struct sk_buff___101 *, bool);
	struct net_device___100 * (*ndo_sk_get_lower_dev)(struct net_device___100 *, struct sock___87 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___100 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___100 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___100 *, struct neighbour___87 *);
	void (*ndo_neigh_destroy)(struct net_device___100 *, struct neighbour___87 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___100 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___100 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___101 *, struct netlink_callback___100 *, struct net_device___100 *, struct net_device___100 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___101 *, struct nlattr **, struct net_device___100 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___100 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___101 *, u32, u32, struct net_device___100 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___100 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___100 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___100 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___100 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___100 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___100 *, struct net_device___100 *);
	void (*ndo_dfwd_del_station)(struct net_device___100 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___100 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___100 *);
	int (*ndo_change_proto_down)(struct net_device___100 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___100 *, struct sk_buff___101 *);
	void (*ndo_set_rx_headroom)(struct net_device___100 *, int);
	int (*ndo_bpf)(struct net_device___100 *, struct netdev_bpf___100 *);
	int (*ndo_xdp_xmit)(struct net_device___100 *, int, struct xdp_frame___100 **, u32);
	struct net_device___100 * (*ndo_xdp_get_xmit_slave)(struct net_device___100 *, struct xdp_buff___100 *);
	int (*ndo_xsk_wakeup)(struct net_device___100 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___100 *);
	int (*ndo_tunnel_ctl)(struct net_device___100 *, struct ip_tunnel_parm *, int);
	struct net_device___100 * (*ndo_get_peer_dev)(struct net_device___100 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___100 *, struct net_device_path___100 *);
};

struct neigh_parms___87 {
	possible_net_t___100 net;
	struct net_device___100 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___87 *);
	struct neigh_table___87 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___87 {
	u32 (*l3mdev_fib_table)(const struct net_device___100 *);
	struct sk_buff___101 * (*l3mdev_l3_rcv)(struct net_device___100 *, struct sk_buff___101 *, u16);
	struct sk_buff___101 * (*l3mdev_l3_out)(struct net_device___100 *, struct sock___87 *, struct sk_buff___101 *, u16);
	struct dst_entry___87 * (*l3mdev_link_scope_lookup)(const struct net_device___100 *, struct flowi6 *);
};

struct ndisc_ops___69 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___100 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___100 *, struct neighbour___87 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___100 *, u8, struct neighbour___87 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___100 *, struct sk_buff___101 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___105 *, struct net_device___100 *, const struct prefix_info *, struct inet6_dev___69 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___21;

struct in_device___21 {
	struct net_device___100 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___21 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___87 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___69;

struct ifacaddr6___29;

struct inet6_dev___69 {
	struct net_device___100 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___69 *mc_list;
	struct ifmcaddr6___69 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___100 mc_query_queue;
	struct sk_buff_head___100 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___29 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___87 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct wpan_phy___2;

struct wpan_dev_header_ops___2;

struct wpan_dev___3 {
	struct wpan_phy___2 *wpan_phy;
	int iftype;
	struct list_head list;
	struct net_device___100 *netdev;
	const struct wpan_dev_header_ops___2 *header_ops;
	struct net_device___100 *lowpan_dev;
	u32 identifier;
	__le16 pan_id;
	__le16 short_addr;
	__le64 extended_addr;
	atomic_t bsn;
	atomic_t dsn;
	u8 min_be;
	u8 max_be;
	u8 csma_retries;
	s8 frame_retries;
	bool lbt;
	bool promiscuous_mode;
	bool ackreq;
};

struct tcf_proto___94;

struct tcf_block___94;

struct mini_Qdisc___94 {
	struct tcf_proto___94 *filter_list;
	struct tcf_block___94 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___94 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___100 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___100 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___105 *, struct net_device___100 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___100 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___100 *, struct list_head *);
	size_t (*get_size)(const struct net_device___100 *);
	int (*fill_info)(struct sk_buff___101 *, const struct net_device___100 *);
	size_t (*get_xstats_size)(const struct net_device___100 *);
	int (*fill_xstats)(struct sk_buff___101 *, const struct net_device___100 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___100 *, struct net_device___100 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___100 *, const struct net_device___100 *);
	int (*fill_slave_info)(struct sk_buff___101 *, const struct net_device___100 *, const struct net_device___100 *);
	struct net___105 * (*get_link_net)(const struct net_device___100 *);
	size_t (*get_linkxstats_size)(const struct net_device___100 *, int);
	int (*fill_linkxstats)(struct sk_buff___101 *, const struct net_device___100 *, int *, int);
};

struct netdev_notifier_info___18 {
	struct net_device___100 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_change_info___3 {
	struct netdev_notifier_info___18 info;
	unsigned int flags_changed;
};

struct netdev_notifier_changeupper_info___7 {
	struct netdev_notifier_info___18 info;
	struct net_device___100 *upper_dev;
	bool master;
	bool linking;
	void *upper_info;
};

struct prefixmsg {
	unsigned char prefix_family;
	unsigned char prefix_pad1;
	short unsigned int prefix_pad2;
	int prefix_ifindex;
	unsigned char prefix_type;
	unsigned char prefix_len;
	unsigned char prefix_flags;
	unsigned char prefix_pad3;
};

enum {
	PREFIX_UNSPEC = 0,
	PREFIX_ADDRESS = 1,
	PREFIX_CACHEINFO = 2,
	__PREFIX_MAX = 3,
};

struct prefix_cacheinfo {
	__u32 preferred_time;
	__u32 valid_time;
};

struct in_ifaddr___21 {
	struct hlist_node hash;
	struct in_ifaddr___21 *ifa_next;
	struct in_device___21 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct block_device_operations___182;

struct gendisk___185 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___185 *part0;
	const struct block_device_operations___182 *fops;
	struct request_queue___182 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___168 *bdi;
	struct kobject___279 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___279 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___182 {
	struct bio___182 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___208 *bip_vec;
	struct bio_vec___208 bip_inline_vecs[0];
};

struct blkcg___170;

struct blkg_policy_data___170;

struct blkcg_gq___170 {
	struct request_queue___182 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___170 *blkcg;
	struct blkcg_gq___170 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___170 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___182 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___182(struct request___182 *);

typedef void integrity_complete_fn___182(struct request___182 *, unsigned int);

struct blk_integrity_profile___182 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___182 *prepare_fn;
	integrity_complete_fn___182 *complete_fn;
	const char *name;
};

struct block_device_operations___182 {
	blk_qc_t (*submit_bio)(struct bio___182 *);
	int (*open)(struct block_device___185 *, fmode_t);
	void (*release)(struct gendisk___185 *, fmode_t);
	int (*rw_page)(struct block_device___185 *, sector_t, struct page___296 *, unsigned int);
	int (*ioctl)(struct block_device___185 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___185 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___185 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___185 *);
	int (*getgeo)(struct block_device___185 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___185 *, bool);
	void (*swap_slot_free_notify)(struct block_device___185 *, long unsigned int);
	int (*report_zones)(struct gendisk___185 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___185 *, umode_t *);
	struct module___275 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___185 *, sector_t *);
};

typedef void rq_end_io_fn___182(struct request___182 *, blk_status_t);

struct request___182 {
	struct request_queue___182 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___177 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___182 *bio;
	struct bio___182 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___208 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___182 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___182 *saved_end_io;
		} flush;
	};
	struct gendisk___185 *rq_disk;
	struct block_device___185 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___182 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___177 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___182 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___279 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___291 *debugfs_dir;
	struct dentry___291 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___182;

struct elevator_mq_ops___182 {
	int (*init_sched)(struct request_queue___182 *, struct elevator_type___182 *);
	void (*exit_sched)(struct elevator_queue___182 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___177 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___177 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___177 *);
	bool (*allow_merge)(struct request_queue___182 *, struct request___182 *, struct bio___182 *);
	bool (*bio_merge)(struct request_queue___182 *, struct bio___182 *, unsigned int);
	int (*request_merge)(struct request_queue___182 *, struct request___182 **, struct bio___182 *);
	void (*request_merged)(struct request_queue___182 *, struct request___182 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___182 *, struct request___182 *, struct request___182 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___182 *);
	void (*finish_request)(struct request___182 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___177 *, struct list_head *, bool);
	struct request___182 * (*dispatch_request)(struct blk_mq_hw_ctx___177 *);
	bool (*has_work)(struct blk_mq_hw_ctx___177 *);
	void (*completed_request)(struct request___182 *, u64);
	void (*requeue_request)(struct request___182 *);
	struct request___182 * (*former_request)(struct request_queue___182 *, struct request___182 *);
	struct request___182 * (*next_request)(struct request_queue___182 *, struct request___182 *);
	void (*init_icq)(struct io_cq___182 *);
	void (*exit_icq)(struct io_cq___182 *);
};

struct elv_fs_entry___182;

struct elevator_type___182 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___182 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___182 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___275 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___182 {
	struct elevator_type___182 *type;
	void *elevator_data;
	struct kobject___279 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___182 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___182 *, char *);
	ssize_t (*store)(struct elevator_queue___182 *, const char *, size_t);
};

struct blk_mq_queue_data___177;

struct blk_mq_ops___177 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___177 *, const struct blk_mq_queue_data___177 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___177 *);
	int (*get_budget)(struct request_queue___182 *);
	void (*put_budget)(struct request_queue___182 *, int);
	void (*set_rq_budget_token)(struct request___182 *, int);
	int (*get_rq_budget_token)(struct request___182 *);
	enum blk_eh_timer_return (*timeout)(struct request___182 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___177 *);
	void (*complete)(struct request___182 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___177 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___177 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___177 *, struct request___182 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___177 *, struct request___182 *, unsigned int);
	void (*initialize_rq_fn)(struct request___182 *);
	void (*cleanup_rq)(struct request___182 *);
	bool (*busy)(struct request_queue___182 *);
	int (*map_queues)(struct blk_mq_tag_set___177 *);
	void (*show_rq)(struct seq_file___266 *, struct request___182 *);
};

struct blk_mq_tag_set___177 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___177 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___177 {
	struct request___182 *rq;
	bool last;
};

struct blkcg_policy_data___170;

struct blkcg___170 {
	struct cgroup_subsys_state___218 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___170 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___170 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___170 {
	struct blkcg___170 *blkcg;
	int plid;
};

struct blkg_policy_data___170 {
	struct blkcg_gq___170 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___156 {
	struct mem_cgroup___156 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___156 {
	struct lruvec___164 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___156 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___156 *memcg;
};

struct obj_cgroup___156 {
	struct percpu_ref refcnt;
	struct mem_cgroup___156 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___94 {
	spinlock_t *lock;
	struct sk_buff___101 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___10 {
	struct nlmsghdr *nlh;
	struct net___105 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

typedef int (*rtnl_doit_func___12)(struct sk_buff___101 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___12)(struct sk_buff___101 *, struct netlink_callback___100 *);

struct rtnl_af_ops___3 {
	struct list_head list;
	int family;
	int (*fill_link_af)(struct sk_buff___101 *, const struct net_device___100 *, u32);
	size_t (*get_link_af_size)(const struct net_device___100 *, u32);
	int (*validate_link_af)(const struct net_device___100 *, const struct nlattr *, struct netlink_ext_ack *);
	int (*set_link_af)(struct net_device___100 *, const struct nlattr *, struct netlink_ext_ack *);
	int (*fill_stats_af)(struct sk_buff___101 *, const struct net_device___100 *);
	size_t (*get_stats_af_size)(const struct net_device___100 *);
};

struct Qdisc_class_ops___94;

struct Qdisc_ops___94 {
	struct Qdisc_ops___94 *next;
	const struct Qdisc_class_ops___94 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___101 *, struct Qdisc___94 *, struct sk_buff___101 **);
	struct sk_buff___101 * (*dequeue)(struct Qdisc___94 *);
	struct sk_buff___101 * (*peek)(struct Qdisc___94 *);
	int (*init)(struct Qdisc___94 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___94 *);
	void (*destroy)(struct Qdisc___94 *);
	int (*change)(struct Qdisc___94 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___94 *);
	int (*change_tx_queue_len)(struct Qdisc___94 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___94 *, unsigned int);
	int (*dump)(struct Qdisc___94 *, struct sk_buff___101 *);
	int (*dump_stats)(struct Qdisc___94 *, struct gnet_dump___94 *);
	void (*ingress_block_set)(struct Qdisc___94 *, u32);
	void (*egress_block_set)(struct Qdisc___94 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___94 *);
	u32 (*egress_block_get)(struct Qdisc___94 *);
	struct module___275 *owner;
};

struct qdisc_walker___10;

struct Qdisc_class_ops___94 {
	unsigned int flags;
	struct netdev_queue___100 * (*select_queue)(struct Qdisc___94 *, struct tcmsg *);
	int (*graft)(struct Qdisc___94 *, long unsigned int, struct Qdisc___94 *, struct Qdisc___94 **, struct netlink_ext_ack *);
	struct Qdisc___94 * (*leaf)(struct Qdisc___94 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___94 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___94 *, u32);
	int (*change)(struct Qdisc___94 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___94 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___94 *, struct qdisc_walker___10 *);
	struct tcf_block___94 * (*tcf_block)(struct Qdisc___94 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___94 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___94 *, long unsigned int);
	int (*dump)(struct Qdisc___94 *, long unsigned int, struct sk_buff___101 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___94 *, long unsigned int, struct gnet_dump___94 *);
};

struct qdisc_walker___10 {
	int stop;
	int skip;
	int count;
	int (*fn)(struct Qdisc___94 *, long unsigned int, struct qdisc_walker___10 *);
};

struct tcf_chain___94;

struct tcf_block___94 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___105 *net;
	struct Qdisc___94 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___94 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___94;

struct tcf_proto_ops___94;

struct tcf_proto___94 {
	struct tcf_proto___94 *next;
	void *root;
	int (*classify)(struct sk_buff___101 *, const struct tcf_proto___94 *, struct tcf_result___94 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___94 *ops;
	struct tcf_chain___94 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___94 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___94 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___94 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___101 *, const struct tcf_proto___94 *, struct tcf_result___94 *);
	int (*init)(struct tcf_proto___94 *);
	void (*destroy)(struct tcf_proto___94 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___94 *, u32);
	void (*put)(struct tcf_proto___94 *, void *);
	int (*change)(struct net___105 *, struct sk_buff___101 *, struct tcf_proto___94 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___94 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___94 *);
	void (*walk)(struct tcf_proto___94 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___94 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___94 *, void *);
	void (*hw_del)(struct tcf_proto___94 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___105 *, struct tcf_chain___94 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___105 *, struct tcf_proto___94 *, void *, struct sk_buff___101 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___105 *, struct tcf_proto___94 *, void *, struct sk_buff___101 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___101 *, struct net___105 *, void *);
	struct module___275 *owner;
	int flags;
};

struct tcf_chain___94 {
	struct mutex filter_chain_lock;
	struct tcf_proto___94 *filter_chain;
	struct list_head list;
	struct tcf_block___94 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___94 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___87 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___94 *prog;
};

struct pneigh_entry___87;

struct neigh_hash_table___87;

struct neigh_table___87 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___100 *, __u32 *);
	bool (*key_eq)(const struct neighbour___87 *, const void *);
	int (*constructor)(struct neighbour___87 *);
	int (*pconstructor)(struct pneigh_entry___87 *);
	void (*pdestructor)(struct pneigh_entry___87 *);
	void (*proxy_redo)(struct sk_buff___101 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___100 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___87 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___100 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___87 *nht;
	struct pneigh_entry___87 **phash_buckets;
};

struct neigh_ops___87 {
	int family;
	void (*solicit)(struct neighbour___87 *, struct sk_buff___101 *);
	void (*error_report)(struct neighbour___87 *, struct sk_buff___101 *);
	int (*output)(struct neighbour___87 *, struct sk_buff___101 *);
	int (*connected_output)(struct neighbour___87 *, struct sk_buff___101 *);
};

struct pneigh_entry___87 {
	struct pneigh_entry___87 *next;
	possible_net_t___100 net;
	struct net_device___100 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___87 {
	struct neighbour___87 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___63 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___105 *, struct sock___87 *, struct sk_buff___101 *);
	int (*orig_input)(struct sk_buff___101 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___87 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___87 *ctarget;
	struct net___105 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___87 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___87 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___72;

struct timewait_sock_ops___71;

struct proto___87 {
	void (*close)(struct sock___87 *, long int);
	int (*pre_connect)(struct sock___87 *, struct sockaddr *, int);
	int (*connect)(struct sock___87 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___87 *, int);
	struct sock___87 * (*accept)(struct sock___87 *, int, int *, bool);
	int (*ioctl)(struct sock___87 *, int, long unsigned int);
	int (*init)(struct sock___87 *);
	void (*destroy)(struct sock___87 *);
	void (*shutdown)(struct sock___87 *, int);
	int (*setsockopt)(struct sock___87 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___87 *, int, int, char *, int *);
	void (*keepalive)(struct sock___87 *, int);
	int (*compat_ioctl)(struct sock___87 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___87 *, struct msghdr___89 *, size_t);
	int (*recvmsg)(struct sock___87 *, struct msghdr___89 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___87 *, struct page___296 *, int, size_t, int);
	int (*bind)(struct sock___87 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___87 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___87 *, struct sk_buff___101 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___87 *);
	int (*hash)(struct sock___87 *);
	void (*unhash)(struct sock___87 *);
	void (*rehash)(struct sock___87 *);
	int (*get_port)(struct sock___87 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___87 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___87 *, int);
	bool (*sock_is_readable)(struct sock___87 *);
	void (*enter_memory_pressure)(struct sock___87 *);
	void (*leave_memory_pressure)(struct sock___87 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___72 *rsk_prot;
	struct timewait_sock_ops___71 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___275 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___87 *, int);
};

struct sock_reuseport___35 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___94 *prog;
	struct sock___87 *socks[0];
};

struct request_sock___73;

struct request_sock_ops___72 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___87 *, struct request_sock___73 *);
	void (*send_ack)(const struct sock___87 *, struct sk_buff___101 *, struct request_sock___73 *);
	void (*send_reset)(const struct sock___87 *, struct sk_buff___101 *);
	void (*destructor)(struct request_sock___73 *);
	void (*syn_ack_timeout)(const struct request_sock___73 *);
};

struct timewait_sock_ops___71 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___87 *, struct sock___87 *, void *);
	void (*twsk_destructor)(struct sock___87 *);
};

struct in6_ifreq {
	struct in6_addr ifr6_addr;
	__u32 ifr6_prefixlen;
	int ifr6_ifindex;
};

enum {
	DEVCONF_FORWARDING = 0,
	DEVCONF_HOPLIMIT = 1,
	DEVCONF_MTU6 = 2,
	DEVCONF_ACCEPT_RA = 3,
	DEVCONF_ACCEPT_REDIRECTS = 4,
	DEVCONF_AUTOCONF = 5,
	DEVCONF_DAD_TRANSMITS = 6,
	DEVCONF_RTR_SOLICITS = 7,
	DEVCONF_RTR_SOLICIT_INTERVAL = 8,
	DEVCONF_RTR_SOLICIT_DELAY = 9,
	DEVCONF_USE_TEMPADDR = 10,
	DEVCONF_TEMP_VALID_LFT = 11,
	DEVCONF_TEMP_PREFERED_LFT = 12,
	DEVCONF_REGEN_MAX_RETRY = 13,
	DEVCONF_MAX_DESYNC_FACTOR = 14,
	DEVCONF_MAX_ADDRESSES = 15,
	DEVCONF_FORCE_MLD_VERSION = 16,
	DEVCONF_ACCEPT_RA_DEFRTR = 17,
	DEVCONF_ACCEPT_RA_PINFO = 18,
	DEVCONF_ACCEPT_RA_RTR_PREF = 19,
	DEVCONF_RTR_PROBE_INTERVAL = 20,
	DEVCONF_ACCEPT_RA_RT_INFO_MAX_PLEN = 21,
	DEVCONF_PROXY_NDP = 22,
	DEVCONF_OPTIMISTIC_DAD = 23,
	DEVCONF_ACCEPT_SOURCE_ROUTE = 24,
	DEVCONF_MC_FORWARDING = 25,
	DEVCONF_DISABLE_IPV6 = 26,
	DEVCONF_ACCEPT_DAD = 27,
	DEVCONF_FORCE_TLLAO = 28,
	DEVCONF_NDISC_NOTIFY = 29,
	DEVCONF_MLDV1_UNSOLICITED_REPORT_INTERVAL = 30,
	DEVCONF_MLDV2_UNSOLICITED_REPORT_INTERVAL = 31,
	DEVCONF_SUPPRESS_FRAG_NDISC = 32,
	DEVCONF_ACCEPT_RA_FROM_LOCAL = 33,
	DEVCONF_USE_OPTIMISTIC = 34,
	DEVCONF_ACCEPT_RA_MTU = 35,
	DEVCONF_STABLE_SECRET = 36,
	DEVCONF_USE_OIF_ADDRS_ONLY = 37,
	DEVCONF_ACCEPT_RA_MIN_HOP_LIMIT = 38,
	DEVCONF_IGNORE_ROUTES_WITH_LINKDOWN = 39,
	DEVCONF_DROP_UNICAST_IN_L2_MULTICAST = 40,
	DEVCONF_DROP_UNSOLICITED_NA = 41,
	DEVCONF_KEEP_ADDR_ON_DOWN = 42,
	DEVCONF_RTR_SOLICIT_MAX_INTERVAL = 43,
	DEVCONF_SEG6_ENABLED = 44,
	DEVCONF_SEG6_REQUIRE_HMAC = 45,
	DEVCONF_ENHANCED_DAD = 46,
	DEVCONF_ADDR_GEN_MODE = 47,
	DEVCONF_DISABLE_POLICY = 48,
	DEVCONF_ACCEPT_RA_RT_INFO_MIN_PLEN = 49,
	DEVCONF_NDISC_TCLASS = 50,
	DEVCONF_RPL_SEG_ENABLED = 51,
	DEVCONF_RA_DEFRTR_METRIC = 52,
	DEVCONF_IOAM6_ENABLED = 53,
	DEVCONF_IOAM6_ID = 54,
	DEVCONF_IOAM6_ID_WIDE = 55,
	DEVCONF_MAX = 56,
};

struct request_sock___73 {
	struct sock_common___87 __req_common;
	struct request_sock___73 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___72 *rsk_ops;
	struct sock___87 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

enum {
	INET6_IFADDR_STATE_PREDAD = 0,
	INET6_IFADDR_STATE_DAD = 1,
	INET6_IFADDR_STATE_POSTDAD = 2,
	INET6_IFADDR_STATE_ERRDAD = 3,
	INET6_IFADDR_STATE_DEAD = 4,
};

struct inet6_ifaddr___2 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___69 *idev;
	struct fib6_info___29 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___2 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___69 {
	struct in6_addr mca_addr;
	struct inet6_dev___69 *idev;
	struct ifmcaddr6___69 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___29 {
	struct in6_addr aca_addr;
	struct fib6_info___29 *aca_rt;
	struct ifacaddr6___29 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_config___9 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___10 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct wpan_phy___2 {
	const void *privid;
	u32 flags;
	u8 current_channel;
	u8 current_page;
	struct wpan_phy_supported supported;
	s32 transmit_power;
	struct wpan_phy_cca cca;
	__le64 perm_extended_addr;
	s32 cca_ed_level;
	u8 symbol_duration;
	u16 lifs_period;
	u16 sifs_period;
	struct device___272 dev;
	possible_net_t___100 _net;
	long: 64;
	long: 64;
	char priv[0];
};

struct wpan_dev_header_ops___2 {
	int (*create)(struct sk_buff___101 *, struct net_device___100 *, const struct ieee802154_addr *, const struct ieee802154_addr *, unsigned int);
};

union fwnet_hwaddr {
	u8 u[16];
	struct {
		__be64 uniq_id;
		u8 max_rec;
		u8 sspd;
		__be16 fifo_hi;
		__be32 fifo_lo;
	} uc;
};

struct in6_validator_info {
	struct in6_addr i6vi_addr;
	struct inet6_dev___69 *i6vi_dev;
	struct netlink_ext_ack *extack;
};

struct ifa6_config {
	const struct in6_addr *pfx;
	unsigned int plen;
	const struct in6_addr *peer_pfx;
	u32 rt_priority;
	u32 ifa_flags;
	u32 preferred_lft;
	u32 valid_lft;
	u16 scope;
};

struct fib_nh_exception___29 {
	struct fib_nh_exception___29 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___31 *fnhe_rth_input;
	struct rtable___31 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___31 {
	struct dst_entry___87 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___29 {
	struct fib_nh_exception___29 *chain;
};

struct fib_info___19;

struct fib_nh___19 {
	struct fib_nh_common___29 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___19 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___19 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___105 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___19 *nh;
	struct callback_head rcu;
	struct fib_nh___19 fib_nh[0];
};

struct nh_info___19;

struct nh_group___19;

struct nexthop___19 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___105 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___19 *nh_info;
		struct nh_group___19 *nh_grp;
	};
};

struct nh_info___19 {
	struct hlist_node dev_hash;
	struct nexthop___19 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___29 fib_nhc;
		struct fib_nh___19 fib_nh;
		struct fib6_nh___29 fib6_nh;
	};
};

struct nh_grp_entry___19;

struct nh_res_bucket___19 {
	struct nh_grp_entry___19 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___19 {
	struct nexthop___19 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___19 *nh_parent;
};

struct nh_res_table___19 {
	struct net___105 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___19 nh_buckets[0];
};

struct nh_group___19 {
	struct nh_group___19 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___19 *res_table;
	struct nh_grp_entry___19 nh_entries[0];
};

enum cleanup_prefix_rt_t {
	CLEANUP_PREFIX_RT_NOP = 0,
	CLEANUP_PREFIX_RT_DEL = 1,
	CLEANUP_PREFIX_RT_EXPIRE = 2,
};

enum {
	IPV6_SADDR_RULE_INIT = 0,
	IPV6_SADDR_RULE_LOCAL = 1,
	IPV6_SADDR_RULE_SCOPE = 2,
	IPV6_SADDR_RULE_PREFERRED = 3,
	IPV6_SADDR_RULE_OIF = 4,
	IPV6_SADDR_RULE_LABEL = 5,
	IPV6_SADDR_RULE_PRIVACY = 6,
	IPV6_SADDR_RULE_ORCHID = 7,
	IPV6_SADDR_RULE_PREFIX = 8,
	IPV6_SADDR_RULE_MAX = 9,
};

struct ipv6_saddr_score {
	int rule;
	int addr_type;
	struct inet6_ifaddr___2 *ifa;
	long unsigned int scorebits[1];
	int scopedist;
	int matchlen;
};

struct ipv6_saddr_dst {
	const struct in6_addr *addr;
	int ifindex;
	int scope;
	int label;
	unsigned int prefs;
};

struct if6_iter_state {
	struct seq_net_private___14 p;
	int bucket;
	int offset;
};

enum addr_type_t {
	UNICAST_ADDR = 0,
	MULTICAST_ADDR = 1,
	ANYCAST_ADDR = 2,
};

struct inet6_fill_args {
	u32 portid;
	u32 seq;
	int event;
	unsigned int flags;
	int netnsid;
	int ifindex;
	enum addr_type_t type;
};

enum {
	DAD_PROCESS = 0,
	DAD_BEGIN = 1,
	DAD_ABORT = 2,
};

typedef int (*rtnl_doit_func___13)(struct sk_buff___99 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___13)(struct sk_buff___99 *, struct netlink_callback___98 *);

struct ifaddrlblmsg {
	__u8 ifal_family;
	__u8 __ifal_reserved;
	__u8 ifal_prefixlen;
	__u8 ifal_flags;
	__u32 ifal_index;
	__u32 ifal_seq;
};

enum {
	IFAL_ADDRESS = 1,
	IFAL_LABEL = 2,
	__IFAL_MAX = 3,
};

struct ip6addrlbl_entry {
	struct in6_addr prefix;
	int prefixlen;
	int ifindex;
	int addrtype;
	u32 label;
	struct hlist_node list;
	struct callback_head rcu;
};

struct ip6addrlbl_init_table {
	const struct in6_addr *prefix;
	int prefixlen;
	u32 label;
};

struct dentry___292;

struct super_block___292;

struct module___276;

struct file_system_type___292 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___292 * (*mount)(struct file_system_type___292 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___292 *);
	struct module___276 *owner;
	struct file_system_type___292 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___292;

struct kiocb___292;

struct iov_iter___212;

struct poll_table_struct___213;

struct vm_area_struct___297;

struct inode___292;

struct file_lock___292;

struct page___297;

struct pipe_inode_info___133;

struct seq_file___267;

struct file_operations___293 {
	struct module___276 *owner;
	loff_t (*llseek)(struct file___292 *, loff_t, int);
	ssize_t (*read)(struct file___292 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___292 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___292 *, struct iov_iter___212 *);
	ssize_t (*write_iter)(struct kiocb___292 *, struct iov_iter___212 *);
	int (*iopoll)(struct kiocb___292 *, bool);
	int (*iterate)(struct file___292 *, struct dir_context *);
	int (*iterate_shared)(struct file___292 *, struct dir_context *);
	__poll_t (*poll)(struct file___292 *, struct poll_table_struct___213 *);
	long int (*unlocked_ioctl)(struct file___292 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___292 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___292 *, struct vm_area_struct___297 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___292 *, struct file___292 *);
	int (*flush)(struct file___292 *, fl_owner_t);
	int (*release)(struct inode___292 *, struct file___292 *);
	int (*fsync)(struct file___292 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___292 *, int);
	int (*lock)(struct file___292 *, int, struct file_lock___292 *);
	ssize_t (*sendpage)(struct file___292 *, struct page___297 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___292 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___292 *, long unsigned int);
	int (*flock)(struct file___292 *, int, struct file_lock___292 *);
	ssize_t (*splice_write)(struct pipe_inode_info___133 *, struct file___292 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___292 *, loff_t *, struct pipe_inode_info___133 *, size_t, unsigned int);
	int (*setlease)(struct file___292 *, long int, struct file_lock___292 **, void **);
	long int (*fallocate)(struct file___292 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___267 *, struct file___292 *);
	ssize_t (*copy_file_range)(struct file___292 *, loff_t, struct file___292 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___292 *, loff_t, struct file___292 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___292 *, loff_t, loff_t, int);
};

struct bio_vec___209 {
	struct page___297 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___292;

struct pipe_buffer___133;

struct pipe_inode_info___133 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___297 *tmp_page;
	struct fasync_struct___292 *fasync_readers;
	struct fasync_struct___292 *fasync_writers;
	struct pipe_buffer___133 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___212 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___209 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___133 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___90 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___212 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___292 *msg_iocb;
};

struct kiocb___292 {
	struct file___292 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___292 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct kset___280;

struct kobj_type___280;

struct kernfs_node___280;

struct kobject___280 {
	const char *name;
	struct list_head entry;
	struct kobject___280 *parent;
	struct kset___280 *kset;
	struct kobj_type___280 *ktype;
	struct kernfs_node___280 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___277 {
	struct kobject___280 kobj;
	struct module___276 *mod;
	struct kobject___280 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___276 {
	struct module___276 *mod;
	struct latch_tree_node node;
};

struct module_layout___276 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___276 mtn;
};

struct module_attribute___276;

struct kernel_param___276;

struct trace_event_call___82;

struct module___276 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___277 mkobj;
	struct module_attribute___276 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___280 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___276 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___276 core_layout;
	struct module_layout___276 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___82 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___297 {
	u64 seqnum;
	struct vm_area_struct___297 *vmas[4];
};

struct page_frag___297 {
	struct page___297 *page;
	__u32 offset;
	__u32 size;
};

struct perf_event___88;

struct debug_info___88 {
	int suspended_step;
	int bps_disabled;
	int wps_disabled;
	struct perf_event___88 *hbp_break[16];
	struct perf_event___88 *hbp_watch[16];
};

struct thread_struct___88 {
	struct cpu_context cpu_context;
	long: 64;
	struct {
		long unsigned int tp_value;
		long unsigned int tp2_value;
		struct user_fpsimd_state fpsimd_state;
	} uw;
	unsigned int fpsimd_cpu;
	void *sve_state;
	unsigned int sve_vl;
	unsigned int sve_vl_onexec;
	long unsigned int fault_address;
	long unsigned int fault_code;
	struct debug_info___88 debug;
	struct ptrauth_keys_user keys_user;
	struct ptrauth_keys_kernel keys_kernel;
	u64 mte_ctrl;
	u64 sctlr_user;
	long: 64;
};

struct mm_struct___298;

struct pid___269;

struct nsproxy___278;

struct signal_struct___293;

struct bio_list___183;

struct backing_dev_info___169;

struct io_context___183;

struct css_set___219;

struct perf_event_context___88;

struct mem_cgroup___157;

struct request_queue___183;

struct vm_struct___275;

struct task_struct___299 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___299 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___298 *mm;
	struct mm_struct___298 *active_mm;
	struct vmacache___297 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___299 *real_parent;
	struct task_struct___299 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___299 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___269 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___278 *nsproxy;
	struct signal_struct___293 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___299 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___183 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___169 *backing_dev_info;
	struct io_context___183 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___219 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___88 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___133 *splice_pipe;
	struct page_frag___297 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___157 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___157 *active_memcg;
	struct request_queue___183 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___299 *oom_reaper_list;
	struct vm_struct___275 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct hw_perf_event___88 {
	union {
		struct {
			u64 config;
			u64 last_tag;
			long unsigned int config_base;
			long unsigned int event_base;
			int event_base_rdpmc;
			int idx;
			int last_cpu;
			int flags;
			struct hw_perf_event_extra extra_reg;
			struct hw_perf_event_extra branch_reg;
		};
		struct {
			struct hrtimer hrtimer;
		};
		struct {
			struct list_head tp_list;
		};
		struct {
			u64 pwr_acc;
			u64 ptsc;
		};
		struct {
			struct arch_hw_breakpoint info;
			struct list_head bp_list;
		};
		struct {
			u8 iommu_bank;
			u8 iommu_cntr;
			u16 padding;
			u64 conf;
			u64 conf1;
		};
	};
	struct task_struct___299 *target;
	void *addr_filters;
	long unsigned int addr_filters_gen;
	int state;
	local64_t prev_count;
	u64 sample_period;
	union {
		struct {
			u64 last_period;
			local64_t period_left;
		};
		struct {
			u64 saved_metric;
			u64 saved_slots;
		};
	};
	u64 interrupts_seq;
	u64 interrupts;
	u64 freq_time_stamp;
	u64 freq_count_stamp;
};

typedef void (*perf_overflow_handler_t___88)(struct perf_event___88 *, struct perf_sample_data___2 *, struct pt_regs *);

struct pmu___88;

struct pid_namespace___269;

struct bpf_prog___95;

struct perf_cgroup___88;

struct perf_event___88 {
	struct list_head event_entry;
	struct list_head sibling_list;
	struct list_head active_list;
	struct rb_node group_node;
	u64 group_index;
	struct list_head migrate_entry;
	struct hlist_node hlist_entry;
	struct list_head active_entry;
	int nr_siblings;
	int event_caps;
	int group_caps;
	struct perf_event___88 *group_leader;
	struct pmu___88 *pmu;
	void *pmu_private;
	enum perf_event_state state;
	unsigned int attach_state;
	local64_t count;
	atomic64_t child_count;
	u64 total_time_enabled;
	u64 total_time_running;
	u64 tstamp;
	struct perf_event_attr attr;
	u16 header_size;
	u16 id_header_size;
	u16 read_size;
	struct hw_perf_event___88 hw;
	struct perf_event_context___88 *ctx;
	atomic_long_t refcount;
	atomic64_t child_total_time_enabled;
	atomic64_t child_total_time_running;
	struct mutex child_mutex;
	struct list_head child_list;
	struct perf_event___88 *parent;
	int oncpu;
	int cpu;
	struct list_head owner_entry;
	struct task_struct___299 *owner;
	struct mutex mmap_mutex;
	atomic_t mmap_count;
	struct perf_buffer *rb;
	struct list_head rb_entry;
	long unsigned int rcu_batches;
	int rcu_pending;
	wait_queue_head_t waitq;
	struct fasync_struct___292 *fasync;
	int pending_wakeup;
	int pending_kill;
	int pending_disable;
	long unsigned int pending_addr;
	struct irq_work pending;
	atomic_t event_limit;
	struct perf_addr_filters_head addr_filters;
	struct perf_addr_filter_range *addr_filter_ranges;
	long unsigned int addr_filters_gen;
	struct perf_event___88 *aux_event;
	void (*destroy)(struct perf_event___88 *);
	struct callback_head callback_head;
	struct pid_namespace___269 *ns;
	u64 id;
	u64 (*clock)();
	perf_overflow_handler_t___88 overflow_handler;
	void *overflow_handler_context;
	perf_overflow_handler_t___88 orig_overflow_handler;
	struct bpf_prog___95 *prog;
	u64 bpf_cookie;
	struct trace_event_call___82 *tp_event;
	struct event_filter *filter;
	struct ftrace_ops ftrace_ops;
	struct perf_cgroup___88 *cgrp;
	void *security;
	struct list_head sb_list;
};

struct upid___269 {
	int nr;
	struct pid_namespace___269 *ns;
};

struct pid_namespace___269 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___299 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___269 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___269 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___269 numbers[1];
};

typedef struct page___297 *pgtable_t___297;

struct address_space___292;

struct page_pool___121;

struct dev_pagemap___287;

struct page___297 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___292 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___121 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___297 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___297 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___298 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___287 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___287;

struct vm_area_struct___297 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___297 *vm_next;
	struct vm_area_struct___297 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___298 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___287 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___292 *vm_file;
	struct file___292 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___293 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___299 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___299 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___269 *pids[4];
	struct pid___269 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___298 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___297;

struct mm_struct___298 {
	struct {
		struct vm_area_struct___297 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___292 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___297 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___299 *owner;
		struct user_namespace___26 *user_ns;
		struct file___292 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___106;

struct cgroup_namespace___219;

struct nsproxy___278 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___269 *pid_ns_for_children;
	struct net___106 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___219 *cgroup_ns;
};

struct bio___183;

struct bio_list___183 {
	struct bio___183 *head;
	struct bio___183 *tail;
};

struct cgroup_subsys_state___219;

struct bdi_writeback___169 {
	struct backing_dev_info___169 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___219 *memcg_css;
	struct cgroup_subsys_state___219 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___273;

struct backing_dev_info___169 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___169 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___273 *dev;
	char dev_name[64];
	struct device___273 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___292 *debug_dir;
};

struct io_cq___183;

struct io_context___183 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___183 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___219;

struct css_set___219 {
	struct cgroup_subsys_state___219 *subsys[14];
	refcount_t refcount;
	struct css_set___219 *dom_cset;
	struct cgroup___219 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___219 *mg_src_cgrp;
	struct cgroup___219 *mg_dst_cgrp;
	struct css_set___219 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct perf_event_context___88 {
	struct pmu___88 *pmu;
	raw_spinlock_t lock;
	struct mutex mutex;
	struct list_head active_ctx_list;
	struct perf_event_groups pinned_groups;
	struct perf_event_groups flexible_groups;
	struct list_head event_list;
	struct list_head pinned_active;
	struct list_head flexible_active;
	int nr_events;
	int nr_active;
	int is_active;
	int nr_stat;
	int nr_freq;
	int rotate_disable;
	int rotate_necessary;
	refcount_t refcount;
	struct task_struct___299 *task;
	u64 time;
	u64 timestamp;
	u64 timeoffset;
	struct perf_event_context___88 *parent_ctx;
	u64 parent_gen;
	u64 generation;
	int pin_count;
	int nr_cgroups;
	void *task_ctx_data;
	struct callback_head callback_head;
};

struct cgroup_subsys___219;

struct cgroup_subsys_state___219 {
	struct cgroup___219 *cgroup;
	struct cgroup_subsys___219 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___219 *parent;
};

struct cgroup_file___219 {
	struct kernfs_node___280 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___157;

struct mem_cgroup_per_node___157;

struct mem_cgroup___157 {
	struct cgroup_subsys_state___219 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___219 events_file;
	struct cgroup_file___219 events_local_file;
	struct cgroup_file___219 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___157 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___299 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___157 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___183;

struct blk_integrity___183 {
	const struct blk_integrity_profile___183 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___183 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___183 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___183;

struct elevator_queue___183;

struct blk_mq_ops___178;

struct blk_mq_hw_ctx___178;

struct gendisk___186;

struct blkcg_gq___171;

struct blk_mq_tag_set___178;

struct request_queue___183 {
	struct request___183 *last_merge;
	struct elevator_queue___183 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___178 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___178 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___186 *disk;
	struct kobject___280 kobj;
	struct kobject___280 *mq_kobj;
	struct blk_integrity___183 integrity;
	struct device___273 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___171 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___178 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___183 bio_split;
	struct dentry___292 *debugfs_dir;
	struct dentry___292 *sched_debugfs_dir;
	struct dentry___292 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___275 {
	struct vm_struct___275 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___297 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___292;

struct dentry___292 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___292 *d_parent;
	struct qstr d_name;
	struct inode___292 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___292 *d_op;
	struct super_block___292 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___292;

struct address_space___292 {
	struct inode___292 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___292 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___292;

struct inode___292 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___292 *i_op;
	struct super_block___292 *i_sb;
	struct address_space___292 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___169 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___293 *i_fop;
		void (*free_inode)(struct inode___292 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___292 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___133 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___292;

struct path___292;

struct dentry_operations___292 {
	int (*d_revalidate)(struct dentry___292 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___292 *, unsigned int);
	int (*d_hash)(const struct dentry___292 *, struct qstr *);
	int (*d_compare)(const struct dentry___292 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___292 *);
	int (*d_init)(struct dentry___292 *);
	void (*d_release)(struct dentry___292 *);
	void (*d_prune)(struct dentry___292 *);
	void (*d_iput)(struct dentry___292 *, struct inode___292 *);
	char * (*d_dname)(struct dentry___292 *, char *, int);
	struct vfsmount___292 * (*d_automount)(struct path___292 *);
	int (*d_manage)(const struct path___292 *, bool);
	struct dentry___292 * (*d_real)(struct dentry___292 *, const struct inode___292 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___292;

struct mem_dqinfo___292 {
	struct quota_format_type___292 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___292;

struct quota_info___292 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___292 *files[3];
	struct mem_dqinfo___292 info[3];
	const struct quota_format_ops___292 *ops[3];
};

struct rcuwait___293 {
	struct task_struct___299 *task;
};

struct percpu_rw_semaphore___293 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___293 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___292 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___293 rw_sem[3];
};

struct shrink_control___157;

struct shrinker___157 {
	long unsigned int (*count_objects)(struct shrinker___157 *, struct shrink_control___157 *);
	long unsigned int (*scan_objects)(struct shrinker___157 *, struct shrink_control___157 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___292;

struct dquot_operations___292;

struct quotactl_ops___292;

struct block_device___186;

struct super_block___292 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___292 *s_type;
	const struct super_operations___292 *s_op;
	const struct dquot_operations___292 *dq_op;
	const struct quotactl_ops___292 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___292 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___186 *s_bdev;
	struct backing_dev_info___169 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___292 s_dquot;
	struct sb_writers___292 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___292 *s_d_op;
	int cleancache_poolid;
	struct shrinker___157 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___292 {
	struct dentry___292 *mnt_root;
	struct super_block___292 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___292 {
	struct vfsmount___292 *mnt;
	struct dentry___292 *dentry;
};

struct shrink_control___157 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___157 *memcg;
};

struct page_pool_params___121 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___273 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___121 {
	u32 count;
	struct page___297 *cache[128];
};

struct page_pool___121 {
	struct page_pool_params___121 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___297 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___121 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___287;

struct dev_pagemap___287 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___287 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___269 {
	rwlock_t lock;
	struct pid___269 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___292 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___292 f_path;
	struct inode___292 *f_inode;
	const struct file_operations___293 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___269 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___292 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___287;

struct vm_operations_struct___287 {
	void (*open)(struct vm_area_struct___297 *);
	void (*close)(struct vm_area_struct___297 *);
	int (*may_split)(struct vm_area_struct___297 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___297 *);
	int (*mprotect)(struct vm_area_struct___297 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___287 *);
	vm_fault_t (*huge_fault)(struct vm_fault___287 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___287 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___297 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___287 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___287 *);
	int (*access)(struct vm_area_struct___297 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___297 *);
	int (*set_policy)(struct vm_area_struct___297 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___297 *, long unsigned int);
	struct page___297 * (*find_special_page)(struct vm_area_struct___297 *, long unsigned int);
};

struct core_thread___297 {
	struct task_struct___299 *task;
	struct core_thread___297 *next;
};

struct core_state___297 {
	atomic_t nr_threads;
	struct core_thread___297 dumper;
	struct completion startup;
};

struct vm_fault___287 {
	const struct {
		struct vm_area_struct___297 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___297 *cow_page;
	struct page___297 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___297 prealloc_pte;
};

struct pglist_data___165;

struct lruvec___165 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___165 *pgdat;
};

struct zone___165 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___165 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___165 {
	struct zone___165 *zone;
	int zone_idx;
};

struct zonelist___165 {
	struct zoneref___165 _zonerefs[321];
};

struct pglist_data___165 {
	struct zone___165 node_zones[5];
	struct zonelist___165 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___299 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___299 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___165 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___219 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___299 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___95;

struct cgroup_bpf___95 {
	struct bpf_prog_array___95 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___95 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___219;

struct cgroup_rstat_cpu___219;

struct cgroup___219 {
	struct cgroup_subsys_state___219 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___280 *kn;
	struct cgroup_file___219 procs_file;
	struct cgroup_file___219 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___219 *subsys[14];
	struct cgroup_root___219 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___219 *dom_cgrp;
	struct cgroup___219 *old_dom_cgrp;
	struct cgroup_rstat_cpu___219 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___219 psi;
	struct cgroup_bpf___95 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___183 {
	struct request_queue___183 *q;
	struct io_context___183 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___292 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___292 *ia_file;
};

struct dquot___292 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___292 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___292 {
	int qf_fmt_id;
	const struct quota_format_ops___292 *qf_ops;
	struct module___276 *qf_owner;
	struct quota_format_type___292 *qf_next;
};

struct quota_format_ops___292 {
	int (*check_quota_file)(struct super_block___292 *, int);
	int (*read_file_info)(struct super_block___292 *, int);
	int (*write_file_info)(struct super_block___292 *, int);
	int (*free_file_info)(struct super_block___292 *, int);
	int (*read_dqblk)(struct dquot___292 *);
	int (*commit_dqblk)(struct dquot___292 *);
	int (*release_dqblk)(struct dquot___292 *);
	int (*get_next_id)(struct super_block___292 *, struct kqid *);
};

struct dquot_operations___292 {
	int (*write_dquot)(struct dquot___292 *);
	struct dquot___292 * (*alloc_dquot)(struct super_block___292 *, int);
	void (*destroy_dquot)(struct dquot___292 *);
	int (*acquire_dquot)(struct dquot___292 *);
	int (*release_dquot)(struct dquot___292 *);
	int (*mark_dirty)(struct dquot___292 *);
	int (*write_info)(struct super_block___292 *, int);
	qsize_t * (*get_reserved_space)(struct inode___292 *);
	int (*get_projid)(struct inode___292 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___292 *, qsize_t *);
	int (*get_next_id)(struct super_block___292 *, struct kqid *);
};

struct quotactl_ops___292 {
	int (*quota_on)(struct super_block___292 *, int, int, const struct path___292 *);
	int (*quota_off)(struct super_block___292 *, int);
	int (*quota_enable)(struct super_block___292 *, unsigned int);
	int (*quota_disable)(struct super_block___292 *, unsigned int);
	int (*quota_sync)(struct super_block___292 *, int);
	int (*set_info)(struct super_block___292 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___292 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___292 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___292 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___292 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___292 *, unsigned int);
};

struct writeback_control___169;

struct address_space_operations___292 {
	int (*writepage)(struct page___297 *, struct writeback_control___169 *);
	int (*readpage)(struct file___292 *, struct page___297 *);
	int (*writepages)(struct address_space___292 *, struct writeback_control___169 *);
	int (*set_page_dirty)(struct page___297 *);
	int (*readpages)(struct file___292 *, struct address_space___292 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___292 *, struct address_space___292 *, loff_t, unsigned int, unsigned int, struct page___297 **, void **);
	int (*write_end)(struct file___292 *, struct address_space___292 *, loff_t, unsigned int, unsigned int, struct page___297 *, void *);
	sector_t (*bmap)(struct address_space___292 *, sector_t);
	void (*invalidatepage)(struct page___297 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___297 *, gfp_t);
	void (*freepage)(struct page___297 *);
	ssize_t (*direct_IO)(struct kiocb___292 *, struct iov_iter___212 *);
	int (*migratepage)(struct address_space___292 *, struct page___297 *, struct page___297 *, enum migrate_mode);
	bool (*isolate_page)(struct page___297 *, isolate_mode_t);
	void (*putback_page)(struct page___297 *);
	int (*launder_page)(struct page___297 *);
	int (*is_partially_uptodate)(struct page___297 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___297 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___292 *, struct page___297 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___292 *, sector_t *);
	void (*swap_deactivate)(struct file___292 *);
};

struct writeback_control___169 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___169 *wb;
	struct inode___292 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___292 {
	struct dentry___292 * (*lookup)(struct inode___292 *, struct dentry___292 *, unsigned int);
	const char * (*get_link)(struct dentry___292 *, struct inode___292 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___292 *, int);
	struct posix_acl * (*get_acl)(struct inode___292 *, int, bool);
	int (*readlink)(struct dentry___292 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___292 *, struct dentry___292 *, umode_t, bool);
	int (*link)(struct dentry___292 *, struct inode___292 *, struct dentry___292 *);
	int (*unlink)(struct inode___292 *, struct dentry___292 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___292 *, struct dentry___292 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___292 *, struct dentry___292 *, umode_t);
	int (*rmdir)(struct inode___292 *, struct dentry___292 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___292 *, struct dentry___292 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___292 *, struct dentry___292 *, struct inode___292 *, struct dentry___292 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___292 *, struct iattr___292 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___292 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___292 *, char *, size_t);
	int (*fiemap)(struct inode___292 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___292 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___292 *, struct dentry___292 *, struct file___292 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___292 *, struct dentry___292 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___292 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___292 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___292 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___292 {
	void (*fl_copy_lock)(struct file_lock___292 *, struct file_lock___292 *);
	void (*fl_release_private)(struct file_lock___292 *);
};

struct lock_manager_operations___292;

struct file_lock___292 {
	struct file_lock___292 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___292 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___292 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___292 *fl_ops;
	const struct lock_manager_operations___292 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___292 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___292 *);
	int (*lm_grant)(struct file_lock___292 *, int);
	bool (*lm_break)(struct file_lock___292 *);
	int (*lm_change)(struct file_lock___292 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___292 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___292 *);
};

struct fasync_struct___292 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___292 *fa_next;
	struct file___292 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___292 {
	struct inode___292 * (*alloc_inode)(struct super_block___292 *);
	void (*destroy_inode)(struct inode___292 *);
	void (*free_inode)(struct inode___292 *);
	void (*dirty_inode)(struct inode___292 *, int);
	int (*write_inode)(struct inode___292 *, struct writeback_control___169 *);
	int (*drop_inode)(struct inode___292 *);
	void (*evict_inode)(struct inode___292 *);
	void (*put_super)(struct super_block___292 *);
	int (*sync_fs)(struct super_block___292 *, int);
	int (*freeze_super)(struct super_block___292 *);
	int (*freeze_fs)(struct super_block___292 *);
	int (*thaw_super)(struct super_block___292 *);
	int (*unfreeze_fs)(struct super_block___292 *);
	int (*statfs)(struct dentry___292 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___292 *, int *, char *);
	void (*umount_begin)(struct super_block___292 *);
	int (*show_options)(struct seq_file___267 *, struct dentry___292 *);
	int (*show_devname)(struct seq_file___267 *, struct dentry___292 *);
	int (*show_path)(struct seq_file___267 *, struct dentry___292 *);
	int (*show_stats)(struct seq_file___267 *, struct dentry___292 *);
	ssize_t (*quota_read)(struct super_block___292 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___292 *, int, const char *, size_t, loff_t);
	struct dquot___292 ** (*get_dquots)(struct inode___292 *);
	long int (*nr_cached_objects)(struct super_block___292 *, struct shrink_control___157 *);
	long int (*free_cached_objects)(struct super_block___292 *, struct shrink_control___157 *);
	struct file___292 * (*real_loop)(struct file___292 *);
};

struct wakeup_source___273;

struct dev_pm_info___273 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___273 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___273 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___273;

struct bus_type___273;

struct device_driver___273;

struct dev_pm_domain___273;

struct fwnode_handle___269;

struct class___273;

struct attribute_group___280;

struct device___273 {
	struct kobject___280 kobj;
	struct device___273 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___273 *type;
	struct bus_type___273 *bus;
	struct device_driver___273 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___273 power;
	struct dev_pm_domain___273 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___269 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___273 *class;
	const struct attribute_group___280 **groups;
	void (*release)(struct device___273 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___186 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___292 *bd_inode;
	struct super_block___292 *bd_super;
	void *bd_claiming;
	struct device___273 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___280 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___186 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___292 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___221)(struct file___292 *, wait_queue_head_t *, struct poll_table_struct___213 *);

struct poll_table_struct___213 {
	poll_queue_proc___221 _qproc;
	__poll_t _key;
};

struct seq_operations___267;

struct seq_file___267 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___267 *op;
	int poll_event;
	const struct file___292 *file;
	void *private;
};

typedef void bio_end_io_t___183(struct bio___183 *);

struct bio_integrity_payload___183;

struct bio___183 {
	struct bio___183 *bi_next;
	struct block_device___186 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___183 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___171 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___183 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___209 *bi_io_vec;
	struct bio_set___183 *bi_pool;
	struct bio_vec___209 bi_inline_vecs[0];
};

struct dev_pagemap_ops___287 {
	void (*page_free)(struct page___297 *);
	void (*kill)(struct dev_pagemap___287 *);
	void (*cleanup)(struct dev_pagemap___287 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___287 *);
};

struct socket_wq___89 {
	wait_queue_head_t wait;
	struct fasync_struct___292 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___88;

struct proto_ops___89;

struct socket___90 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___292 *file;
	struct sock___88 *sk;
	const struct proto_ops___89 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___89 wq;
};

typedef struct {
	struct net___106 *net;
} possible_net_t___101;

struct proto___88;

struct sock_common___88 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___88 *skc_prot;
	possible_net_t___101 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___88 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___102;

struct sk_buff_head___101 {
	struct sk_buff___102 *next;
	struct sk_buff___102 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___88 {
	struct cgroup___219 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___88;

struct xfrm_policy___22;

struct dst_entry___88;

struct net_device___101;

struct sock_reuseport___36;

struct sock___88 {
	struct sock_common___88 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___101 sk_error_queue;
	struct sk_buff___102 *sk_rx_skb_cache;
	struct sk_buff_head___101 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___102 *head;
		struct sk_buff___102 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___88 *sk_filter;
	union {
		struct socket_wq___89 *sk_wq;
		struct socket_wq___89 *sk_wq_raw;
	};
	struct xfrm_policy___22 *sk_policy[2];
	struct dst_entry___88 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___88 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___102 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___102 *sk_tx_skb_cache;
	struct sk_buff_head___101 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___297 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___88 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___269 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___90 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___88 sk_cgrp_data;
	struct mem_cgroup___157 *sk_memcg;
	void (*sk_state_change)(struct sock___88 *);
	void (*sk_data_ready)(struct sock___88 *);
	void (*sk_write_space)(struct sock___88 *);
	void (*sk_error_report)(struct sock___88 *);
	int (*sk_backlog_rcv)(struct sock___88 *, struct sk_buff___102 *);
	struct sk_buff___102 * (*sk_validate_xmit_skb)(struct sock___88 *, struct net_device___101 *, struct sk_buff___102 *);
	void (*sk_destruct)(struct sock___88 *);
	struct sock_reuseport___36 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___88)(read_descriptor_t *, struct sk_buff___102 *, unsigned int, size_t);

struct proto_ops___89 {
	int family;
	struct module___276 *owner;
	int (*release)(struct socket___90 *);
	int (*bind)(struct socket___90 *, struct sockaddr *, int);
	int (*connect)(struct socket___90 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___90 *, struct socket___90 *);
	int (*accept)(struct socket___90 *, struct socket___90 *, int, bool);
	int (*getname)(struct socket___90 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___292 *, struct socket___90 *, struct poll_table_struct___213 *);
	int (*ioctl)(struct socket___90 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___90 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___90 *, void *, bool, bool);
	int (*listen)(struct socket___90 *, int);
	int (*shutdown)(struct socket___90 *, int);
	int (*setsockopt)(struct socket___90 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___90 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___267 *, struct socket___90 *);
	int (*sendmsg)(struct socket___90 *, struct msghdr___90 *, size_t);
	int (*recvmsg)(struct socket___90 *, struct msghdr___90 *, size_t, int);
	int (*mmap)(struct file___292 *, struct socket___90 *, struct vm_area_struct___297 *);
	ssize_t (*sendpage)(struct socket___90 *, struct page___297 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___90 *, loff_t *, struct pipe_inode_info___133 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___88 *, int);
	int (*peek_len)(struct socket___90 *);
	int (*read_sock)(struct sock___88 *, read_descriptor_t *, sk_read_actor_t___88);
	int (*sendpage_locked)(struct sock___88 *, struct page___297 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___88 *, struct msghdr___90 *, size_t);
	int (*set_rcvlowat)(struct sock___88 *, int);
};

struct sk_buff___102 {
	union {
		struct {
			struct sk_buff___102 *next;
			struct sk_buff___102 *prev;
			union {
				struct net_device___101 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___88 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___102 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___61;

struct fib_rules_ops___88;

struct fqdir___106;

struct tcp_congestion_ops___34;

struct fib_notifier_ops___88;

struct netns_ipv4___106 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___61 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___88 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___88 *fibnl;
	struct sock___88 **icmp_sk;
	struct sock___88 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___88 **tcp_sk;
	struct fqdir___106 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___34 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___88 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___88 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___88 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___88;

struct dst_ops___106 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___106 *);
	struct dst_entry___88 * (*check)(struct dst_entry___88 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___88 *);
	unsigned int (*mtu)(const struct dst_entry___88 *);
	u32 * (*cow_metrics)(struct dst_entry___88 *, long unsigned int);
	void (*destroy)(struct dst_entry___88 *);
	void (*ifdown)(struct dst_entry___88 *, struct net_device___101 *, int);
	struct dst_entry___88 * (*negative_advice)(struct dst_entry___88 *);
	void (*link_failure)(struct sk_buff___102 *);
	void (*update_pmtu)(struct dst_entry___88 *, struct sock___88 *, struct sk_buff___102 *, u32, bool);
	void (*redirect)(struct dst_entry___88 *, struct sock___88 *, struct sk_buff___102 *);
	int (*local_out)(struct net___106 *, struct sock___88 *, struct sk_buff___102 *);
	struct neighbour___88 * (*neigh_lookup)(const struct dst_entry___88 *, struct sk_buff___102 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___88 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___30;

struct rt6_info___30;

struct fib6_table___30;

struct netns_ipv6___106 {
	struct dst_ops___106 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___106 *fqdir;
	struct fib6_info___30 *fib6_null_entry;
	struct rt6_info___30 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___30 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___30 *ip6_prohibit_entry;
	struct rt6_info___30 *ip6_blk_hole_entry;
	struct fib6_table___30 *fib6_local_tbl;
	struct fib_rules_ops___88 *fib6_rules_ops;
	struct sock___88 **icmp_sk;
	struct sock___88 *ndisc_sk;
	struct sock___88 *tcp_sk;
	struct sock___88 *igmp_sk;
	struct sock___88 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___88 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___88 *notifier_ops;
	struct fib_notifier_ops___88 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___106 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___106 *fqdir;
};

struct netns_sctp___88 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___88 *ctl_sock;
	struct sock___88 *udp4_sock;
	struct sock___88 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct netns_bpf___95 {
	struct bpf_prog_array___95 *run_array[2];
	struct bpf_prog___95 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___106 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___88 *nlsk;
	struct sock___88 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___106 xfrm4_dst_ops;
	struct dst_ops___106 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___106 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___88 *rtnl;
	struct sock___88 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___101 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___106 ipv4;
	struct netns_ipv6___106 ipv6;
	struct netns_ieee802154_lowpan___106 ieee802154_lowpan;
	struct netns_sctp___88 sctp;
	struct netns_nf___19 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___101 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___95 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___106 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___88 *crypto_nlsk;
	struct sock___88 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___106;

struct fqdir___106 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___106 *f;
	struct net___106 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___106;

struct inet_frags___106 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___106 *, const void *);
	void (*destructor)(struct inet_frag_queue___106 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___106 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___102 *fragments_tail;
	struct sk_buff___102 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___106 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___61 {
	struct ip_ra_chain___61 *next;
	struct sock___88 *sk;
	union {
		void (*destructor)(struct sock___88 *);
		struct sock___88 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___88;

struct fib_lookup_arg___88;

struct fib_rules_ops___88 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___88 *, struct flowi *, int, struct fib_lookup_arg___88 *);
	bool (*suppress)(struct fib_rule___88 *, int, struct fib_lookup_arg___88 *);
	int (*match)(struct fib_rule___88 *, struct flowi *, int);
	int (*configure)(struct fib_rule___88 *, struct sk_buff___102 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___88 *);
	int (*compare)(struct fib_rule___88 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___88 *, struct sk_buff___102 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___88 *);
	void (*flush_cache)(struct fib_rules_ops___88 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___276 *owner;
	struct net___106 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___34 {
	u32 (*ssthresh)(struct sock___88 *);
	void (*cong_avoid)(struct sock___88 *, u32, u32);
	void (*set_state)(struct sock___88 *, u8);
	void (*cwnd_event)(struct sock___88 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___88 *, u32);
	void (*pkts_acked)(struct sock___88 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___88 *);
	void (*cong_control)(struct sock___88 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___88 *);
	u32 (*sndbuf_expand)(struct sock___88 *);
	size_t (*get_info)(struct sock___88 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___276 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___88 *);
	void (*release)(struct sock___88 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___88 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___106 *);
	int (*fib_dump)(struct net___106 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___276 *owner;
	struct callback_head rcu;
};

struct xfrm_state___22;

struct lwtunnel_state___64;

struct dst_entry___88 {
	struct net_device___101 *dev;
	struct dst_ops___106 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___22 *xfrm;
	int (*input)(struct sk_buff___102 *);
	int (*output)(struct net___106 *, struct sock___88 *, struct sk_buff___102 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___64 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___101(struct sk_buff___102 **);

struct bpf_xdp_entity___95 {
	struct bpf_prog___95 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___101;

struct net_device_ops___101;

struct l3mdev_ops___88;

struct ndisc_ops___70;

struct xfrmdev_ops___101;

struct header_ops___101;

struct inet6_dev___70;

struct netdev_rx_queue___101;

struct mini_Qdisc___95;

struct netdev_queue___101;

struct Qdisc___95;

struct rtnl_link_ops___95;

struct dcbnl_rtnl_ops___101;

struct net_device___101 {
	char name[16];
	struct netdev_name_node___101 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___101 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___88 *l3mdev_ops;
	const struct ndisc_ops___70 *ndisc_ops;
	const struct xfrmdev_ops___101 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___101 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___280 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___70 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___101 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___95 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___101 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___95 *miniq_ingress;
	struct netdev_queue___101 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___101 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___95 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___95 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___101 = 0,
		NETREG_REGISTERED___101 = 1,
		NETREG_UNREGISTERING___101 = 2,
		NETREG_UNREGISTERED___101 = 3,
		NETREG_RELEASED___101 = 4,
		NETREG_DUMMY___101 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___101 = 0,
		RTNL_LINK_INITIALIZING___101 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___101 *);
	struct netpoll_info *npinfo;
	possible_net_t___101 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___273 dev;
	const struct attribute_group___280 *sysfs_groups[4];
	const struct attribute_group___280 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___95 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___101 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___95 xdp_state[3];
	long: 64;
};

struct neigh_table___88;

struct neigh_parms___88;

struct neigh_ops___88;

struct neighbour___88 {
	struct neighbour___88 *next;
	struct neigh_table___88 *tbl;
	struct neigh_parms___88 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___101 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___88 *, struct sk_buff___102 *);
	const struct neigh_ops___88 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___101 *dev;
	u8 primary_key[0];
};

struct rtable___32;

struct fnhe_hash_bucket___30;

struct fib_nh_common___30 {
	struct net_device___101 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___64 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___32 **nhc_pcpu_rth_output;
	struct rtable___32 *nhc_rth_input;
	struct fnhe_hash_bucket___30 *nhc_exceptions;
};

struct fib6_nh___30 {
	struct fib_nh_common___30 nh_common;
	long unsigned int last_probe;
	struct rt6_info___30 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___30;

struct nexthop___20;

struct fib6_info___30 {
	struct fib6_table___30 *fib6_table;
	struct fib6_info___30 *fib6_next;
	struct fib6_node___30 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___20 *nh;
	struct fib6_nh___30 fib6_nh[0];
};

struct rt6_info___30 {
	struct dst_entry___88 dst;
	struct fib6_info___30 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___70 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___30 {
	struct fib6_node___30 *parent;
	struct fib6_node___30 *left;
	struct fib6_node___30 *right;
	struct fib6_node___30 *subtree;
	struct fib6_info___30 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___30 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___30 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___30 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___95 {
	struct bpf_prog___95 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___95 {
	struct callback_head rcu;
	struct bpf_prog_array_item___95 items[0];
};

struct bpf_prog_aux___104;

struct bpf_prog___95 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___104 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___269;

struct fwnode_handle___269 {
	struct fwnode_handle___269 *secondary;
	const struct fwnode_operations___269 *ops;
	struct device___273 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___269;

struct fwnode_endpoint___269;

struct fwnode_operations___269 {
	struct fwnode_handle___269 * (*get)(struct fwnode_handle___269 *);
	void (*put)(struct fwnode_handle___269 *);
	bool (*device_is_available)(const struct fwnode_handle___269 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___269 *, const struct device___273 *);
	bool (*property_present)(const struct fwnode_handle___269 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___269 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___269 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___269 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*get_parent)(const struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*get_next_child_node)(const struct fwnode_handle___269 *, struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*get_named_child_node)(const struct fwnode_handle___269 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___269 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___269 *);
	struct fwnode_handle___269 * (*graph_get_next_endpoint)(const struct fwnode_handle___269 *, struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*graph_get_remote_endpoint)(const struct fwnode_handle___269 *);
	struct fwnode_handle___269 * (*graph_get_port_parent)(struct fwnode_handle___269 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___269 *, struct fwnode_endpoint___269 *);
	int (*add_links)(struct fwnode_handle___269 *);
};

struct fwnode_endpoint___269 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___269 *local_fwnode;
};

struct fwnode_reference_args___269 {
	struct fwnode_handle___269 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___280;

struct kernfs_elem_dir___280 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___280 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___280;

struct kernfs_root___280 {
	struct kernfs_node___280 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___280 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___280 {
	struct kernfs_node___280 *target_kn;
};

struct kernfs_ops___280;

struct kernfs_elem_attr___280 {
	const struct kernfs_ops___280 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___280 *notify_next;
};

struct kernfs_node___280 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___280 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___280 dir;
		struct kernfs_elem_symlink___280 symlink;
		struct kernfs_elem_attr___280 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___280;

struct kernfs_ops___280 {
	int (*open)(struct kernfs_open_file___280 *);
	void (*release)(struct kernfs_open_file___280 *);
	int (*seq_show)(struct seq_file___267 *, void *);
	void * (*seq_start)(struct seq_file___267 *, loff_t *);
	void * (*seq_next)(struct seq_file___267 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___267 *, void *);
	ssize_t (*read)(struct kernfs_open_file___280 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___280 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___280 *, struct poll_table_struct___213 *);
	int (*mmap)(struct kernfs_open_file___280 *, struct vm_area_struct___297 *);
};

struct kernfs_syscall_ops___280 {
	int (*show_options)(struct seq_file___267 *, struct kernfs_root___280 *);
	int (*mkdir)(struct kernfs_node___280 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___280 *);
	int (*rename)(struct kernfs_node___280 *, struct kernfs_node___280 *, const char *);
	int (*show_path)(struct seq_file___267 *, struct kernfs_node___280 *, struct kernfs_root___280 *);
};

struct kernfs_open_file___280 {
	struct kernfs_node___280 *kn;
	struct file___292 *file;
	struct seq_file___267 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___287 *vm_ops;
};

struct kobj_ns_type_operations___88 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___88 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___280;

struct attribute_group___280 {
	const char *name;
	umode_t (*is_visible)(struct kobject___280 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___280 *, struct bin_attribute___280 *, int);
	struct attribute **attrs;
	struct bin_attribute___280 **bin_attrs;
};

struct bin_attribute___280 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___292 * (*f_mapping)();
	ssize_t (*read)(struct file___292 *, struct kobject___280 *, struct bin_attribute___280 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___292 *, struct kobject___280 *, struct bin_attribute___280 *, char *, loff_t, size_t);
	int (*mmap)(struct file___292 *, struct kobject___280 *, struct bin_attribute___280 *, struct vm_area_struct___297 *);
};

struct sysfs_ops___280 {
	ssize_t (*show)(struct kobject___280 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___280 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___280;

struct kset___280 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___280 kobj;
	const struct kset_uevent_ops___280 *uevent_ops;
};

struct kobj_type___280 {
	void (*release)(struct kobject___280 *);
	const struct sysfs_ops___280 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___280 **default_groups;
	const struct kobj_ns_type_operations___88 * (*child_ns_type)(struct kobject___280 *);
	const void * (*namespace)(struct kobject___280 *);
	void (*get_ownership)(struct kobject___280 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___280 {
	int (* const filter)(struct kset___280 *, struct kobject___280 *);
	const char * (* const name)(struct kset___280 *, struct kobject___280 *);
	int (* const uevent)(struct kset___280 *, struct kobject___280 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___276 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___276 *);
	int (*get)(char *, const struct kernel_param___276 *);
	void (*free)(void *);
};

struct kparam_array___276;

struct kernel_param___276 {
	const char *name;
	struct module___276 *mod;
	const struct kernel_param_ops___276 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___276 *arr;
	};
};

struct kparam_array___276 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___276 *ops;
	void *elem;
};

struct module_attribute___276 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___276 *, struct module_kobject___277 *, char *);
	ssize_t (*store)(struct module_attribute___276 *, struct module_kobject___277 *, const char *, size_t);
	void (*setup)(struct module___276 *, const char *);
	int (*test)(struct module___276 *);
	void (*free)(struct module___276 *);
};

struct trace_event_class___82;

struct trace_event_call___82 {
	struct list_head list;
	struct trace_event_class___82 *class;
	union {
		char *name;
		struct tracepoint *tp;
	};
	struct trace_event___4 event;
	char *print_fmt;
	struct event_filter *filter;
	union {
		void *module;
		atomic_t refcnt;
	};
	void *data;
	int flags;
	int perf_refcount;
	struct hlist_head *perf_events;
	struct bpf_prog_array___95 *prog_array;
	int (*perf_perm)(struct trace_event_call___82 *, struct perf_event___88 *);
};

struct cgroup_namespace___219 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___219 *root_cset;
};

struct dev_pm_ops___273 {
	int (*prepare)(struct device___273 *);
	void (*complete)(struct device___273 *);
	int (*suspend)(struct device___273 *);
	int (*resume)(struct device___273 *);
	int (*freeze)(struct device___273 *);
	int (*thaw)(struct device___273 *);
	int (*poweroff)(struct device___273 *);
	int (*restore)(struct device___273 *);
	int (*suspend_late)(struct device___273 *);
	int (*resume_early)(struct device___273 *);
	int (*freeze_late)(struct device___273 *);
	int (*thaw_early)(struct device___273 *);
	int (*poweroff_late)(struct device___273 *);
	int (*restore_early)(struct device___273 *);
	int (*suspend_noirq)(struct device___273 *);
	int (*resume_noirq)(struct device___273 *);
	int (*freeze_noirq)(struct device___273 *);
	int (*thaw_noirq)(struct device___273 *);
	int (*poweroff_noirq)(struct device___273 *);
	int (*restore_noirq)(struct device___273 *);
	int (*runtime_suspend)(struct device___273 *);
	int (*runtime_resume)(struct device___273 *);
	int (*runtime_idle)(struct device___273 *);
};

struct wakeup_source___273 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___273 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___273 {
	struct dev_pm_ops___273 ops;
	int (*start)(struct device___273 *);
	void (*detach)(struct device___273 *, bool);
	int (*activate)(struct device___273 *);
	void (*sync)(struct device___273 *);
	void (*dismiss)(struct device___273 *);
};

struct bus_type___273 {
	const char *name;
	const char *dev_name;
	struct device___273 *dev_root;
	const struct attribute_group___280 **bus_groups;
	const struct attribute_group___280 **dev_groups;
	const struct attribute_group___280 **drv_groups;
	int (*match)(struct device___273 *, struct device_driver___273 *);
	int (*uevent)(struct device___273 *, struct kobj_uevent_env *);
	int (*probe)(struct device___273 *);
	void (*sync_state)(struct device___273 *);
	void (*remove)(struct device___273 *);
	void (*shutdown)(struct device___273 *);
	int (*online)(struct device___273 *);
	int (*offline)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	int (*num_vf)(struct device___273 *);
	int (*dma_configure)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___273 {
	const char *name;
	struct bus_type___273 *bus;
	struct module___276 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___273 *);
	void (*sync_state)(struct device___273 *);
	int (*remove)(struct device___273 *);
	void (*shutdown)(struct device___273 *);
	int (*suspend)(struct device___273 *, pm_message_t);
	int (*resume)(struct device___273 *);
	const struct attribute_group___280 **groups;
	const struct attribute_group___280 **dev_groups;
	const struct dev_pm_ops___273 *pm;
	void (*coredump)(struct device___273 *);
	struct driver_private *p;
};

struct device_type___273 {
	const char *name;
	const struct attribute_group___280 **groups;
	int (*uevent)(struct device___273 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___273 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___273 *);
	const struct dev_pm_ops___273 *pm;
};

struct class___273 {
	const char *name;
	struct module___276 *owner;
	const struct attribute_group___280 **class_groups;
	const struct attribute_group___280 **dev_groups;
	struct kobject___280 *dev_kobj;
	int (*dev_uevent)(struct device___273 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___273 *, umode_t *);
	void (*class_release)(struct class___273 *);
	void (*dev_release)(struct device___273 *);
	int (*shutdown_pre)(struct device___273 *);
	const struct kobj_ns_type_operations___88 *ns_type;
	const void * (*namespace)(struct device___273 *);
	void (*get_ownership)(struct device___273 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___273 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___133;

struct pipe_buffer___133 {
	struct page___297 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___133 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___133 {
	int (*confirm)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
	void (*release)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
	bool (*try_steal)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
	bool (*get)(struct pipe_inode_info___133 *, struct pipe_buffer___133 *);
};

struct seq_operations___267 {
	void * (*start)(struct seq_file___267 *, loff_t *);
	void (*stop)(struct seq_file___267 *, void *);
	void * (*next)(struct seq_file___267 *, void *, loff_t *);
	int (*show)(struct seq_file___267 *, void *);
};

struct pernet_operations___35 {
	struct list_head list;
	int (*init)(struct net___106 *);
	void (*pre_exit)(struct net___106 *);
	void (*exit)(struct net___106 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___101 {
	int (*ieee_getets)(struct net_device___101 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___101 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___101 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___101 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___101 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___101 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___101 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___101 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___101 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___101 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___101 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___101 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___101 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___101 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___101 *);
	u8 (*setstate)(struct net_device___101 *, u8);
	void (*getpermhwaddr)(struct net_device___101 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___101 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___101 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___101 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___101 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___101 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___101 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___101 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___101 *, int, u8 *);
	void (*setpfccfg)(struct net_device___101 *, int, u8);
	void (*getpfccfg)(struct net_device___101 *, int, u8 *);
	u8 (*setall)(struct net_device___101 *);
	u8 (*getcap)(struct net_device___101 *, int, u8 *);
	int (*getnumtcs)(struct net_device___101 *, int, u8 *);
	int (*setnumtcs)(struct net_device___101 *, int, u8);
	u8 (*getpfcstate)(struct net_device___101 *);
	void (*setpfcstate)(struct net_device___101 *, u8);
	void (*getbcncfg)(struct net_device___101 *, int, u32 *);
	void (*setbcncfg)(struct net_device___101 *, int, u32);
	void (*getbcnrp)(struct net_device___101 *, int, u8 *);
	void (*setbcnrp)(struct net_device___101 *, int, u8);
	int (*setapp)(struct net_device___101 *, u8, u16, u8);
	int (*getapp)(struct net_device___101 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___101 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___101 *, int, u8);
	u8 (*getdcbx)(struct net_device___101 *);
	u8 (*setdcbx)(struct net_device___101 *, u8);
	int (*peer_getappinfo)(struct net_device___101 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___101 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___101 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___101 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___101 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___101 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___104;

typedef int (*bpf_iter_init_seq_priv_t___103)(void *, struct bpf_iter_aux_info___104 *);

struct bpf_map___104;

struct bpf_iter_aux_info___104 {
	struct bpf_map___104 *map;
};

struct bpf_iter_seq_info___103 {
	const struct seq_operations___267 *seq_ops;
	bpf_iter_init_seq_priv_t___103 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___103 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___104 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___104 *, struct file___292 *);
	void (*map_free)(struct bpf_map___104 *);
	int (*map_get_next_key)(struct bpf_map___104 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___104 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___104 *, void *);
	int (*map_lookup_batch)(struct bpf_map___104 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___104 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___104 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___104 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___104 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___104 *, void *);
	int (*map_update_elem)(struct bpf_map___104 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___104 *, void *);
	int (*map_push_elem)(struct bpf_map___104 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___104 *, void *);
	int (*map_peek_elem)(struct bpf_map___104 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___104 *, struct file___292 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___104 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___104 *, void *, struct seq_file___267 *);
	int (*map_check_btf)(const struct bpf_map___104 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___104 *, struct bpf_prog_aux___104 *);
	void (*map_poke_untrack)(struct bpf_map___104 *, struct bpf_prog_aux___104 *);
	void (*map_poke_run)(struct bpf_map___104 *, u32, struct bpf_prog___95 *, struct bpf_prog___95 *);
	int (*map_direct_value_addr)(const struct bpf_map___104 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___104 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___104 *, struct vm_area_struct___297 *);
	__poll_t (*map_poll)(struct bpf_map___104 *, struct file___292 *, struct poll_table_struct___213 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___104 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___104 *, const struct bpf_map___104 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___104 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___103 *iter_seq_info;
};

struct bpf_map___104 {
	const struct bpf_map_ops___103 *ops;
	struct bpf_map___104 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___157 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___103;

struct bpf_jit_poke_descriptor___103;

struct bpf_prog_ops___95;

struct btf_mod_pair___103;

struct bpf_prog_offload___101;

struct bpf_prog_aux___104 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___95 *dst_prog;
	struct bpf_trampoline___103 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___95 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___103 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___95 *ops;
	struct bpf_map___104 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___103 *used_btfs;
	struct bpf_prog___95 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___104 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___101 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___101;

struct bpf_map_dev_ops___101 {
	int (*map_get_next_key)(struct bpf_offloaded_map___101 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___101 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___101 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___101 *, void *);
};

struct bpf_offloaded_map___101 {
	struct bpf_map___104 map;
	struct net_device___101 *netdev;
	const struct bpf_map_dev_ops___101 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_func_proto___16 {
	u64 (*func)(u64, u64, u64, u64, u64);
	bool gpl_only;
	bool pkt_access;
	enum bpf_return_type ret_type;
	union {
		struct {
			enum bpf_arg_type arg1_type;
			enum bpf_arg_type arg2_type;
			enum bpf_arg_type arg3_type;
			enum bpf_arg_type arg4_type;
			enum bpf_arg_type arg5_type;
		};
		enum bpf_arg_type arg_type[5];
	};
	union {
		struct {
			u32 *arg1_btf_id;
			u32 *arg2_btf_id;
			u32 *arg3_btf_id;
			u32 *arg4_btf_id;
			u32 *arg5_btf_id;
		};
		u32 *arg_btf_id[5];
	};
	int *ret_btf_id;
	bool (*allowed)(const struct bpf_prog___95 *);
};

struct bpf_prog_ops___95 {
	int (*test_run)(struct bpf_prog___95 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___101 {
	struct bpf_prog___95 *prog;
	struct net_device___101 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___103 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___95 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___276 *mod;
};

struct bpf_jit_poke_descriptor___103 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___104 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___103 {
	struct btf *btf;
	struct module___276 *module;
};

typedef int (*bpf_iter_attach_target_t___8)(struct bpf_prog___95 *, union bpf_iter_link_info *, struct bpf_iter_aux_info___104 *);

typedef void (*bpf_iter_detach_target_t___8)(struct bpf_iter_aux_info___104 *);

typedef void (*bpf_iter_show_fdinfo_t___8)(const struct bpf_iter_aux_info___104 *, struct seq_file___267 *);

typedef int (*bpf_iter_fill_link_info_t___8)(const struct bpf_iter_aux_info___104 *, struct bpf_link_info *);

typedef const struct bpf_func_proto___16 * (*bpf_iter_get_func_proto_t___9)(enum bpf_func_id, const struct bpf_prog___95 *);

struct bpf_iter_reg___7 {
	const char *target;
	bpf_iter_attach_target_t___8 attach_target;
	bpf_iter_detach_target_t___8 detach_target;
	bpf_iter_show_fdinfo_t___8 show_fdinfo;
	bpf_iter_fill_link_info_t___8 fill_link_info;
	bpf_iter_get_func_proto_t___9 get_func_proto;
	u32 ctx_arg_info_size;
	u32 feature;
	struct bpf_ctx_arg_aux ctx_arg_info[2];
	const struct bpf_iter_seq_info___103 *seq_info;
};

struct bpf_iter_meta___8 {
	union {
		struct seq_file___267 *seq;
	};
	u64 session_id;
	u64 seq_num;
};

struct cftype___219;

struct cgroup_subsys___219 {
	struct cgroup_subsys_state___219 * (*css_alloc)(struct cgroup_subsys_state___219 *);
	int (*css_online)(struct cgroup_subsys_state___219 *);
	void (*css_offline)(struct cgroup_subsys_state___219 *);
	void (*css_released)(struct cgroup_subsys_state___219 *);
	void (*css_free)(struct cgroup_subsys_state___219 *);
	void (*css_reset)(struct cgroup_subsys_state___219 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___219 *, int);
	int (*css_extra_stat_show)(struct seq_file___267 *, struct cgroup_subsys_state___219 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___299 *, struct css_set___219 *);
	void (*cancel_fork)(struct task_struct___299 *, struct css_set___219 *);
	void (*fork)(struct task_struct___299 *);
	void (*exit)(struct task_struct___299 *);
	void (*release)(struct task_struct___299 *);
	void (*bind)(struct cgroup_subsys_state___219 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___219 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___219 *dfl_cftypes;
	struct cftype___219 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___219 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___219 *updated_children;
	struct cgroup___219 *updated_next;
};

struct cgroup_root___219 {
	struct kernfs_root___280 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___219 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___219 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___219 *ss;
	struct list_head node;
	struct kernfs_ops___280 *kf_ops;
	int (*open)(struct kernfs_open_file___280 *);
	void (*release)(struct kernfs_open_file___280 *);
	u64 (*read_u64)(struct cgroup_subsys_state___219 *, struct cftype___219 *);
	s64 (*read_s64)(struct cgroup_subsys_state___219 *, struct cftype___219 *);
	int (*seq_show)(struct seq_file___267 *, void *);
	void * (*seq_start)(struct seq_file___267 *, loff_t *);
	void * (*seq_next)(struct seq_file___267 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___267 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___219 *, struct cftype___219 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___219 *, struct cftype___219 *, s64);
	ssize_t (*write)(struct kernfs_open_file___280 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___280 *, struct poll_table_struct___213 *);
};

struct xdp_rxq_info___101 {
	struct net_device___101 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___101 {
	struct net_device___101 *dev;
};

struct xdp_buff___101 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___101 *rxq;
	struct xdp_txq_info___101 *txq;
	u32 frame_sz;
};

struct xdp_frame___101 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___101 *dev_rx;
};

struct netlink_skb_parms___21 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___88 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___101 {
	struct sk_buff___102 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___102 *, struct netlink_callback___101 *);
	int (*done)(struct netlink_callback___101 *);
	void *data;
	struct module___276 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___101 {
	int (*create)(struct sk_buff___102 *, struct net_device___101 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___102 *, unsigned char *);
	int (*cache)(const struct neighbour___88 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___101 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___102 *);
};

struct netdev_queue___101 {
	struct net_device___101 *dev;
	struct Qdisc___95 *qdisc;
	struct Qdisc___95 *qdisc_sleeping;
	struct kobject___280 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___101 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___95 {
	struct sk_buff___102 *head;
	struct sk_buff___102 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___95;

struct Qdisc___95 {
	int (*enqueue)(struct sk_buff___102 *, struct Qdisc___95 *, struct sk_buff___102 **);
	struct sk_buff___102 * (*dequeue)(struct Qdisc___95 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___95 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___101 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___101 gso_skb;
	struct qdisc_skb_head___95 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___95 *next_sched;
	struct sk_buff_head___101 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___101 {
	struct xdp_rxq_info___101 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___280 kobj;
	struct net_device___101 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___101 {
	enum net_device_path_type type;
	const struct net_device___101 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___101 = 0,
				DEV_PATH_BR_VLAN_TAG___101 = 1,
				DEV_PATH_BR_VLAN_UNTAG___101 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___101 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___101 {
	const struct net_device___101 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___101 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___95 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___101 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___101 {
	int (*xdo_dev_state_add)(struct xfrm_state___22 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___22 *);
	void (*xdo_dev_state_free)(struct xfrm_state___22 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___102 *, struct xfrm_state___22 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___22 *);
};

struct xfrm_state_offload___22 {
	struct net_device___101 *dev;
	struct net_device___101 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___22;

struct xfrm_type_offload___22;

struct xfrm_state___22 {
	possible_net_t___101 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___88 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___22 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___22 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___297 xfrag;
	const struct xfrm_type___22 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___22 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___101 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___101 *dev;
	const char *name;
};

struct net_device_ops___101 {
	int (*ndo_init)(struct net_device___101 *);
	void (*ndo_uninit)(struct net_device___101 *);
	int (*ndo_open)(struct net_device___101 *);
	int (*ndo_stop)(struct net_device___101 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___102 *, struct net_device___101 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___102 *, struct net_device___101 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___101 *, struct sk_buff___102 *, struct net_device___101 *);
	void (*ndo_change_rx_flags)(struct net_device___101 *, int);
	void (*ndo_set_rx_mode)(struct net_device___101 *);
	int (*ndo_set_mac_address)(struct net_device___101 *, void *);
	int (*ndo_validate_addr)(struct net_device___101 *);
	int (*ndo_do_ioctl)(struct net_device___101 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___101 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___101 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___101 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___101 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___101 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___101 *, int);
	int (*ndo_neigh_setup)(struct net_device___101 *, struct neigh_parms___88 *);
	void (*ndo_tx_timeout)(struct net_device___101 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___101 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___101 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___101 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___101 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___101 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___101 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___101 *);
	int (*ndo_netpoll_setup)(struct net_device___101 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___101 *);
	int (*ndo_set_vf_mac)(struct net_device___101 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___101 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___101 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___101 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___101 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___101 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___101 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___101 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___101 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___101 *, int, struct sk_buff___102 *);
	int (*ndo_get_vf_guid)(struct net_device___101 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___101 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___101 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___101 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___101 *);
	int (*ndo_fcoe_disable)(struct net_device___101 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___101 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___101 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___101 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___101 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___101 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___101 *, const struct sk_buff___102 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___101 *, struct net_device___101 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___101 *, struct net_device___101 *);
	struct net_device___101 * (*ndo_get_xmit_slave)(struct net_device___101 *, struct sk_buff___102 *, bool);
	struct net_device___101 * (*ndo_sk_get_lower_dev)(struct net_device___101 *, struct sock___88 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___101 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___101 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___101 *, struct neighbour___88 *);
	void (*ndo_neigh_destroy)(struct net_device___101 *, struct neighbour___88 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___101 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___101 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___102 *, struct netlink_callback___101 *, struct net_device___101 *, struct net_device___101 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___102 *, struct nlattr **, struct net_device___101 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___101 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___102 *, u32, u32, struct net_device___101 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___101 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___101 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___101 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___101 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___101 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___101 *, struct net_device___101 *);
	void (*ndo_dfwd_del_station)(struct net_device___101 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___101 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___101 *);
	int (*ndo_change_proto_down)(struct net_device___101 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___101 *, struct sk_buff___102 *);
	void (*ndo_set_rx_headroom)(struct net_device___101 *, int);
	int (*ndo_bpf)(struct net_device___101 *, struct netdev_bpf___101 *);
	int (*ndo_xdp_xmit)(struct net_device___101 *, int, struct xdp_frame___101 **, u32);
	struct net_device___101 * (*ndo_xdp_get_xmit_slave)(struct net_device___101 *, struct xdp_buff___101 *);
	int (*ndo_xsk_wakeup)(struct net_device___101 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___101 *);
	int (*ndo_tunnel_ctl)(struct net_device___101 *, struct ip_tunnel_parm *, int);
	struct net_device___101 * (*ndo_get_peer_dev)(struct net_device___101 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___101 *, struct net_device_path___101 *);
};

struct neigh_parms___88 {
	possible_net_t___101 net;
	struct net_device___101 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___88 *);
	struct neigh_table___88 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___88 {
	u32 (*l3mdev_fib_table)(const struct net_device___101 *);
	struct sk_buff___102 * (*l3mdev_l3_rcv)(struct net_device___101 *, struct sk_buff___102 *, u16);
	struct sk_buff___102 * (*l3mdev_l3_out)(struct net_device___101 *, struct sock___88 *, struct sk_buff___102 *, u16);
	struct dst_entry___88 * (*l3mdev_link_scope_lookup)(const struct net_device___101 *, struct flowi6 *);
};

struct ndisc_ops___70 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___101 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___101 *, struct neighbour___88 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___101 *, u8, struct neighbour___88 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___101 *, struct sk_buff___102 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___106 *, struct net_device___101 *, const struct prefix_info *, struct inet6_dev___70 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___70;

struct ifacaddr6___30;

struct inet6_dev___70 {
	struct net_device___101 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___70 *mc_list;
	struct ifmcaddr6___70 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___101 mc_query_queue;
	struct sk_buff_head___101 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___30 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___88 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___95;

struct tcf_block___95;

struct mini_Qdisc___95 {
	struct tcf_proto___95 *filter_list;
	struct tcf_block___95 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___95 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___101 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___101 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___106 *, struct net_device___101 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___101 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___101 *, struct list_head *);
	size_t (*get_size)(const struct net_device___101 *);
	int (*fill_info)(struct sk_buff___102 *, const struct net_device___101 *);
	size_t (*get_xstats_size)(const struct net_device___101 *);
	int (*fill_xstats)(struct sk_buff___102 *, const struct net_device___101 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___101 *, struct net_device___101 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___101 *, const struct net_device___101 *);
	int (*fill_slave_info)(struct sk_buff___102 *, const struct net_device___101 *, const struct net_device___101 *);
	struct net___106 * (*get_link_net)(const struct net_device___101 *);
	size_t (*get_linkxstats_size)(const struct net_device___101 *, int);
	int (*fill_linkxstats)(struct sk_buff___102 *, const struct net_device___101 *, int *, int);
};

struct netdev_notifier_info___19 {
	struct net_device___101 *dev;
	struct netlink_ext_ack *extack;
};

struct block_device_operations___183;

struct gendisk___186 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___186 *part0;
	const struct block_device_operations___183 *fops;
	struct request_queue___183 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___169 *bdi;
	struct kobject___280 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___280 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___183 {
	struct bio___183 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___209 *bip_vec;
	struct bio_vec___209 bip_inline_vecs[0];
};

struct blkcg___171;

struct blkg_policy_data___171;

struct blkcg_gq___171 {
	struct request_queue___183 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___171 *blkcg;
	struct blkcg_gq___171 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___171 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___183 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___183(struct request___183 *);

typedef void integrity_complete_fn___183(struct request___183 *, unsigned int);

struct blk_integrity_profile___183 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___183 *prepare_fn;
	integrity_complete_fn___183 *complete_fn;
	const char *name;
};

struct block_device_operations___183 {
	blk_qc_t (*submit_bio)(struct bio___183 *);
	int (*open)(struct block_device___186 *, fmode_t);
	void (*release)(struct gendisk___186 *, fmode_t);
	int (*rw_page)(struct block_device___186 *, sector_t, struct page___297 *, unsigned int);
	int (*ioctl)(struct block_device___186 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___186 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___186 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___186 *);
	int (*getgeo)(struct block_device___186 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___186 *, bool);
	void (*swap_slot_free_notify)(struct block_device___186 *, long unsigned int);
	int (*report_zones)(struct gendisk___186 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___186 *, umode_t *);
	struct module___276 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___186 *, sector_t *);
};

typedef void rq_end_io_fn___183(struct request___183 *, blk_status_t);

struct request___183 {
	struct request_queue___183 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___178 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___183 *bio;
	struct bio___183 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___209 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___183 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___183 *saved_end_io;
		} flush;
	};
	struct gendisk___186 *rq_disk;
	struct block_device___186 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___183 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___178 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___183 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___280 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___292 *debugfs_dir;
	struct dentry___292 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___183;

struct elevator_mq_ops___183 {
	int (*init_sched)(struct request_queue___183 *, struct elevator_type___183 *);
	void (*exit_sched)(struct elevator_queue___183 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___178 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___178 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___178 *);
	bool (*allow_merge)(struct request_queue___183 *, struct request___183 *, struct bio___183 *);
	bool (*bio_merge)(struct request_queue___183 *, struct bio___183 *, unsigned int);
	int (*request_merge)(struct request_queue___183 *, struct request___183 **, struct bio___183 *);
	void (*request_merged)(struct request_queue___183 *, struct request___183 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___183 *, struct request___183 *, struct request___183 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___183 *);
	void (*finish_request)(struct request___183 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___178 *, struct list_head *, bool);
	struct request___183 * (*dispatch_request)(struct blk_mq_hw_ctx___178 *);
	bool (*has_work)(struct blk_mq_hw_ctx___178 *);
	void (*completed_request)(struct request___183 *, u64);
	void (*requeue_request)(struct request___183 *);
	struct request___183 * (*former_request)(struct request_queue___183 *, struct request___183 *);
	struct request___183 * (*next_request)(struct request_queue___183 *, struct request___183 *);
	void (*init_icq)(struct io_cq___183 *);
	void (*exit_icq)(struct io_cq___183 *);
};

struct elv_fs_entry___183;

struct elevator_type___183 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___183 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___183 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___276 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___183 {
	struct elevator_type___183 *type;
	void *elevator_data;
	struct kobject___280 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___183 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___183 *, char *);
	ssize_t (*store)(struct elevator_queue___183 *, const char *, size_t);
};

struct blk_mq_queue_data___178;

struct blk_mq_ops___178 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___178 *, const struct blk_mq_queue_data___178 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___178 *);
	int (*get_budget)(struct request_queue___183 *);
	void (*put_budget)(struct request_queue___183 *, int);
	void (*set_rq_budget_token)(struct request___183 *, int);
	int (*get_rq_budget_token)(struct request___183 *);
	enum blk_eh_timer_return (*timeout)(struct request___183 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___178 *);
	void (*complete)(struct request___183 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___178 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___178 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___178 *, struct request___183 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___178 *, struct request___183 *, unsigned int);
	void (*initialize_rq_fn)(struct request___183 *);
	void (*cleanup_rq)(struct request___183 *);
	bool (*busy)(struct request_queue___183 *);
	int (*map_queues)(struct blk_mq_tag_set___178 *);
	void (*show_rq)(struct seq_file___267 *, struct request___183 *);
};

struct blk_mq_tag_set___178 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___178 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___178 {
	struct request___183 *rq;
	bool last;
};

struct blkcg_policy_data___171;

struct blkcg___171 {
	struct cgroup_subsys_state___219 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___171 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___171 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___171 {
	struct blkcg___171 *blkcg;
	int plid;
};

struct blkg_policy_data___171 {
	struct blkcg_gq___171 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___157 {
	struct mem_cgroup___157 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___157 {
	struct lruvec___165 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___157 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___157 *memcg;
};

struct obj_cgroup___157 {
	struct percpu_ref refcnt;
	struct mem_cgroup___157 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___95 {
	spinlock_t *lock;
	struct sk_buff___102 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct nl_info___11 {
	struct nlmsghdr *nlh;
	struct net___106 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

typedef int (*rtnl_doit_func___14)(struct sk_buff___102 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___14)(struct sk_buff___102 *, struct netlink_callback___101 *);

struct Qdisc_class_ops___95;

struct Qdisc_ops___95 {
	struct Qdisc_ops___95 *next;
	const struct Qdisc_class_ops___95 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___102 *, struct Qdisc___95 *, struct sk_buff___102 **);
	struct sk_buff___102 * (*dequeue)(struct Qdisc___95 *);
	struct sk_buff___102 * (*peek)(struct Qdisc___95 *);
	int (*init)(struct Qdisc___95 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___95 *);
	void (*destroy)(struct Qdisc___95 *);
	int (*change)(struct Qdisc___95 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___95 *);
	int (*change_tx_queue_len)(struct Qdisc___95 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___95 *, unsigned int);
	int (*dump)(struct Qdisc___95 *, struct sk_buff___102 *);
	int (*dump_stats)(struct Qdisc___95 *, struct gnet_dump___95 *);
	void (*ingress_block_set)(struct Qdisc___95 *, u32);
	void (*egress_block_set)(struct Qdisc___95 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___95 *);
	u32 (*egress_block_get)(struct Qdisc___95 *);
	struct module___276 *owner;
};

struct Qdisc_class_ops___95 {
	unsigned int flags;
	struct netdev_queue___101 * (*select_queue)(struct Qdisc___95 *, struct tcmsg *);
	int (*graft)(struct Qdisc___95 *, long unsigned int, struct Qdisc___95 *, struct Qdisc___95 **, struct netlink_ext_ack *);
	struct Qdisc___95 * (*leaf)(struct Qdisc___95 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___95 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___95 *, u32);
	int (*change)(struct Qdisc___95 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___95 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___95 *, struct qdisc_walker *);
	struct tcf_block___95 * (*tcf_block)(struct Qdisc___95 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___95 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___95 *, long unsigned int);
	int (*dump)(struct Qdisc___95 *, long unsigned int, struct sk_buff___102 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___95 *, long unsigned int, struct gnet_dump___95 *);
};

struct tcf_chain___95;

struct tcf_block___95 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___106 *net;
	struct Qdisc___95 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___95 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___95;

struct tcf_proto_ops___95;

struct tcf_proto___95 {
	struct tcf_proto___95 *next;
	void *root;
	int (*classify)(struct sk_buff___102 *, const struct tcf_proto___95 *, struct tcf_result___95 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___95 *ops;
	struct tcf_chain___95 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___95 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___95 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___95 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___102 *, const struct tcf_proto___95 *, struct tcf_result___95 *);
	int (*init)(struct tcf_proto___95 *);
	void (*destroy)(struct tcf_proto___95 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___95 *, u32);
	void (*put)(struct tcf_proto___95 *, void *);
	int (*change)(struct net___106 *, struct sk_buff___102 *, struct tcf_proto___95 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___95 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___95 *);
	void (*walk)(struct tcf_proto___95 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___95 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___95 *, void *);
	void (*hw_del)(struct tcf_proto___95 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___106 *, struct tcf_chain___95 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___106 *, struct tcf_proto___95 *, void *, struct sk_buff___102 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___106 *, struct tcf_proto___95 *, void *, struct sk_buff___102 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___102 *, struct net___106 *, void *);
	struct module___276 *owner;
	int flags;
};

struct tcf_chain___95 {
	struct mutex filter_chain_lock;
	struct tcf_proto___95 *filter_chain;
	struct list_head list;
	struct tcf_block___95 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___95 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___88 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___95 *prog;
};

struct pneigh_entry___88;

struct neigh_hash_table___88;

struct neigh_table___88 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___101 *, __u32 *);
	bool (*key_eq)(const struct neighbour___88 *, const void *);
	int (*constructor)(struct neighbour___88 *);
	int (*pconstructor)(struct pneigh_entry___88 *);
	void (*pdestructor)(struct pneigh_entry___88 *);
	void (*proxy_redo)(struct sk_buff___102 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___101 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___88 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___101 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___88 *nht;
	struct pneigh_entry___88 **phash_buckets;
};

struct neigh_ops___88 {
	int family;
	void (*solicit)(struct neighbour___88 *, struct sk_buff___102 *);
	void (*error_report)(struct neighbour___88 *, struct sk_buff___102 *);
	int (*output)(struct neighbour___88 *, struct sk_buff___102 *);
	int (*connected_output)(struct neighbour___88 *, struct sk_buff___102 *);
};

struct pneigh_entry___88 {
	struct pneigh_entry___88 *next;
	possible_net_t___101 net;
	struct net_device___101 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___88 {
	struct neighbour___88 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___64 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___106 *, struct sock___88 *, struct sk_buff___102 *);
	int (*orig_input)(struct sk_buff___102 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___88 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___88 *ctarget;
	struct net___106 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___88 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___88 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___73;

struct timewait_sock_ops___72;

struct proto___88 {
	void (*close)(struct sock___88 *, long int);
	int (*pre_connect)(struct sock___88 *, struct sockaddr *, int);
	int (*connect)(struct sock___88 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___88 *, int);
	struct sock___88 * (*accept)(struct sock___88 *, int, int *, bool);
	int (*ioctl)(struct sock___88 *, int, long unsigned int);
	int (*init)(struct sock___88 *);
	void (*destroy)(struct sock___88 *);
	void (*shutdown)(struct sock___88 *, int);
	int (*setsockopt)(struct sock___88 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___88 *, int, int, char *, int *);
	void (*keepalive)(struct sock___88 *, int);
	int (*compat_ioctl)(struct sock___88 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___88 *, struct msghdr___90 *, size_t);
	int (*recvmsg)(struct sock___88 *, struct msghdr___90 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___88 *, struct page___297 *, int, size_t, int);
	int (*bind)(struct sock___88 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___88 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___88 *, struct sk_buff___102 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___88 *);
	int (*hash)(struct sock___88 *);
	void (*unhash)(struct sock___88 *);
	void (*rehash)(struct sock___88 *);
	int (*get_port)(struct sock___88 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___88 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___88 *, int);
	bool (*sock_is_readable)(struct sock___88 *);
	void (*enter_memory_pressure)(struct sock___88 *);
	void (*leave_memory_pressure)(struct sock___88 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___73 *rsk_prot;
	struct timewait_sock_ops___72 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___276 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___88 *, int);
};

struct xfrm_policy_queue___22 {
	struct sk_buff_head___101 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___22 {
	possible_net_t___101 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___22 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___36 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___95 *prog;
	struct sock___88 *socks[0];
};

struct request_sock___74;

struct request_sock_ops___73 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___88 *, struct request_sock___74 *);
	void (*send_ack)(const struct sock___88 *, struct sk_buff___102 *, struct request_sock___74 *);
	void (*send_reset)(const struct sock___88 *, struct sk_buff___102 *);
	void (*destructor)(struct request_sock___74 *);
	void (*syn_ack_timeout)(const struct request_sock___74 *);
};

struct timewait_sock_ops___72 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___88 *, struct sock___88 *, void *);
	void (*twsk_destructor)(struct sock___88 *);
};

struct request_sock___74 {
	struct sock_common___88 __req_common;
	struct request_sock___74 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___73 *rsk_ops;
	struct sock___88 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___23 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___88 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___23 {
	struct inet_cork___23 base;
	struct flowi fl;
};

struct ipv6_pinfo___22;

struct inet_sock___23 {
	struct sock___88 sk;
	struct ipv6_pinfo___22 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___23 cork;
};

struct ipv6_fl_socklist___22;

struct ipv6_pinfo___22 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___22 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___102 *pktoptions;
	struct sk_buff___102 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___22;

struct ipv6_fl_socklist___22 {
	struct ipv6_fl_socklist___22 *next;
	struct ip6_flowlabel___22 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___3 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___70 *idev;
	struct fib6_info___30 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___3 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___70 {
	struct in6_addr mca_addr;
	struct inet6_dev___70 *idev;
	struct ifmcaddr6___70 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___30 {
	struct in6_addr aca_addr;
	struct fib6_info___30 *aca_rt;
	struct ifacaddr6___30 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct fib6_result___8 {
	struct fib6_nh___30 *nh;
	struct fib6_info___30 *f6i;
	u32 fib6_flags;
	u8 fib6_type;
	struct rt6_info___30 *rt6;
};

struct fib6_config___10 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___11 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

struct rd_msg {
	struct icmp6hdr icmph;
	struct in6_addr target;
	struct in6_addr dest;
	__u8 opt[0];
};

struct ip6_flowlabel___22 {
	struct ip6_flowlabel___22 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___269 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___106 *fl_net;
};

struct fib_nh_exception___30 {
	struct fib_nh_exception___30 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___32 *fnhe_rth_input;
	struct rtable___32 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___32 {
	struct dst_entry___88 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___30 {
	struct fib_nh_exception___30 *chain;
};

struct fib_info___20;

struct fib_nh___20 {
	struct fib_nh_common___30 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___20 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___20 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___106 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___20 *nh;
	struct callback_head rcu;
	struct fib_nh___20 fib_nh[0];
};

struct nh_info___20;

struct nh_group___20;

struct nexthop___20 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___106 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___20 *nh_info;
		struct nh_group___20 *nh_grp;
	};
};

struct fib_dump_filter___5 {
	u32 table_id;
	bool filter_set;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___101 *dev;
};

struct fib6_gc_args {
	int timeout;
	int more;
};

struct rt6_exception {
	struct hlist_node hlist;
	struct rt6_info___30 *rt6i;
	long unsigned int stamp;
	struct callback_head rcu;
};

typedef struct rt6_info___30 * (*pol_lookup_t)(struct net___106 *, struct fib6_table___30 *, struct flowi6 *, const struct sk_buff___102 *, int);

struct route_info {
	__u8 type;
	__u8 length;
	__u8 prefix_len;
	__u8 reserved_l: 3;
	__u8 route_pref: 2;
	__u8 reserved_h: 3;
	__be32 lifetime;
	__u8 prefix[0];
};

struct nh_info___20 {
	struct hlist_node dev_hash;
	struct nexthop___20 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___30 fib_nhc;
		struct fib_nh___20 fib_nh;
		struct fib6_nh___30 fib6_nh;
	};
};

struct nh_grp_entry___20;

struct nh_res_bucket___20 {
	struct nh_grp_entry___20 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___20 {
	struct nexthop___20 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___20 *nh_parent;
};

struct nh_res_table___20 {
	struct net___106 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___20 nh_buckets[0];
};

struct nh_group___20 {
	struct nh_group___20 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___20 *res_table;
	struct nh_grp_entry___20 nh_entries[0];
};

struct rt6_rtnl_dump_arg {
	struct sk_buff___102 *skb;
	struct netlink_callback___101 *cb;
	struct net___106 *net;
	struct fib_dump_filter___5 filter;
};

struct hw_port_info___9 {
	struct net_device___101 *lower_dev;
	u32 port_id;
};

struct metadata_dst___10 {
	struct dst_entry___88 dst;
	enum metadata_type type;
	union {
		struct ip_tunnel_info___2 tun_info;
		struct hw_port_info___9 port_info;
	} u;
};

struct xfrm_type___22 {
	struct module___276 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___22 *);
	void (*destructor)(struct xfrm_state___22 *);
	int (*input)(struct xfrm_state___22 *, struct sk_buff___102 *);
	int (*output)(struct xfrm_state___22 *, struct sk_buff___102 *);
	int (*reject)(struct xfrm_state___22 *, struct sk_buff___102 *, const struct flowi *);
};

struct xfrm_type_offload___22 {
	struct module___276 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___22 *, struct sk_buff___102 *);
	int (*input_tail)(struct xfrm_state___22 *, struct sk_buff___102 *);
	int (*xmit)(struct xfrm_state___22 *, struct sk_buff___102 *, netdev_features_t);
};

struct netevent_redirect {
	struct dst_entry___88 *old;
	struct dst_entry___88 *new;
	struct neighbour___88 *neigh;
	const void *daddr;
};

struct perf_cpu_context___88;

struct perf_output_handle___88;

struct pmu___88 {
	struct list_head entry;
	struct module___276 *module;
	struct device___273 *dev;
	const struct attribute_group___280 **attr_groups;
	const struct attribute_group___280 **attr_update;
	const char *name;
	int type;
	int capabilities;
	int *pmu_disable_count;
	struct perf_cpu_context___88 *pmu_cpu_context;
	atomic_t exclusive_cnt;
	int task_ctx_nr;
	int hrtimer_interval_ms;
	unsigned int nr_addr_filters;
	void (*pmu_enable)(struct pmu___88 *);
	void (*pmu_disable)(struct pmu___88 *);
	int (*event_init)(struct perf_event___88 *);
	void (*event_mapped)(struct perf_event___88 *, struct mm_struct___298 *);
	void (*event_unmapped)(struct perf_event___88 *, struct mm_struct___298 *);
	int (*add)(struct perf_event___88 *, int);
	void (*del)(struct perf_event___88 *, int);
	void (*start)(struct perf_event___88 *, int);
	void (*stop)(struct perf_event___88 *, int);
	void (*read)(struct perf_event___88 *);
	void (*start_txn)(struct pmu___88 *, unsigned int);
	int (*commit_txn)(struct pmu___88 *);
	void (*cancel_txn)(struct pmu___88 *);
	int (*event_idx)(struct perf_event___88 *);
	void (*sched_task)(struct perf_event_context___88 *, bool);
	struct kmem_cache *task_ctx_cache;
	void (*swap_task_ctx)(struct perf_event_context___88 *, struct perf_event_context___88 *);
	void * (*setup_aux)(struct perf_event___88 *, void **, int, bool);
	void (*free_aux)(void *);
	long int (*snapshot_aux)(struct perf_event___88 *, struct perf_output_handle___88 *, long unsigned int);
	int (*addr_filters_validate)(struct list_head *);
	void (*addr_filters_sync)(struct perf_event___88 *);
	int (*aux_output_match)(struct perf_event___88 *);
	int (*filter_match)(struct perf_event___88 *);
	int (*check_period)(struct perf_event___88 *, u64);
};

struct perf_cpu_context___88 {
	struct perf_event_context___88 ctx;
	struct perf_event_context___88 *task_ctx;
	int active_oncpu;
	int exclusive;
	raw_spinlock_t hrtimer_lock;
	struct hrtimer hrtimer;
	ktime_t hrtimer_interval;
	unsigned int hrtimer_active;
	struct perf_cgroup___88 *cgrp;
	struct list_head cgrp_cpuctx_entry;
	struct list_head sched_cb_entry;
	int sched_cb_usage;
	int online;
	int heap_size;
	struct perf_event___88 **heap;
	struct perf_event___88 *heap_default[2];
};

struct perf_output_handle___88 {
	struct perf_event___88 *event;
	struct perf_buffer *rb;
	long unsigned int wakeup;
	long unsigned int size;
	u64 aux_flags;
	union {
		void *addr;
		long unsigned int head;
	};
	int page;
};

struct perf_cgroup___88 {
	struct cgroup_subsys_state___219 css;
	struct perf_cgroup_info *info;
};

struct trace_event_fields___82 {
	const char *type;
	union {
		struct {
			const char *name;
			const int size;
			const int align;
			const int is_signed;
			const int filter_type;
		};
		int (*define_fields)(struct trace_event_call___82 *);
	};
};

struct trace_event_class___82 {
	const char *system;
	void *probe;
	void *perf_probe;
	int (*reg)(struct trace_event_call___82 *, enum trace_reg, void *);
	struct trace_event_fields___82 *fields_array;
	struct list_head * (*get_fields)(struct trace_event_call___82 *);
	struct list_head fields;
	int (*raw_init)(struct trace_event_call___82 *);
};

struct trace_event_file___42;

struct trace_event_buffer___41 {
	struct trace_buffer *buffer;
	struct ring_buffer_event *event;
	struct trace_event_file___42 *trace_file;
	void *entry;
	unsigned int trace_ctx;
	struct pt_regs *regs;
};

struct trace_event_file___42 {
	struct list_head list;
	struct trace_event_call___82 *event_call;
	struct event_filter *filter;
	struct dentry___292 *dir;
	struct trace_array *tr;
	struct trace_subsystem_dir *system;
	struct list_head triggers;
	long unsigned int flags;
	atomic_t sm_ref;
	atomic_t tm_ref;
};

struct trace_event_raw_fib6_table_lookup {
	struct trace_entry ent;
	u32 tb_id;
	int err;
	int oif;
	int iif;
	__u8 tos;
	__u8 scope;
	__u8 flags;
	__u8 src[16];
	__u8 dst[16];
	u16 sport;
	u16 dport;
	u8 proto;
	u8 rt_type;
	u32 __data_loc_name;
	__u8 gw[16];
	char __data[0];
};

struct trace_event_data_offsets_fib6_table_lookup {
	u32 name;
};

typedef void (*btf_trace_fib6_table_lookup)(void *, const struct net___106 *, const struct fib6_result___8 *, struct fib6_table___30 *, const struct flowi6 *);

enum rt6_nud_state {
	RT6_NUD_FAIL_HARD = 4294967293,
	RT6_NUD_FAIL_PROBE = 4294967294,
	RT6_NUD_FAIL_DO_RR = 4294967295,
	RT6_NUD_SUCCEED = 1,
};

struct fib6_nh_dm_arg {
	struct net___106 *net;
	const struct in6_addr *saddr;
	int oif;
	int flags;
	struct fib6_nh___30 *nh;
};

struct __rt6_probe_work {
	struct work_struct work;
	struct in6_addr target;
	struct net_device___101 *dev;
};

struct fib6_nh_frl_arg {
	u32 flags;
	int oif;
	int strict;
	int *mpri;
	bool *do_rr;
	struct fib6_nh___30 *nh;
};

struct fib6_nh_excptn_arg {
	struct rt6_info___30 *rt;
	int plen;
};

struct fib6_nh_match_arg {
	const struct net_device___101 *dev;
	const struct in6_addr *gw;
	struct fib6_nh___30 *match;
};

struct fib6_nh_age_excptn_arg {
	struct fib6_gc_args *gc_args;
	long unsigned int now;
};

struct fib6_nh_rd_arg {
	struct fib6_result___8 *res;
	struct flowi6 *fl6;
	const struct in6_addr *gw;
	struct rt6_info___30 **ret;
};

struct ip6rd_flowi {
	struct flowi6 fl6;
	struct in6_addr gateway;
};

struct fib6_nh_del_cached_rt_arg {
	struct fib6_config___10 *cfg;
	struct fib6_info___30 *f6i;
};

struct arg_dev_net_ip {
	struct net_device___101 *dev;
	struct net___106 *net;
	struct in6_addr *addr;
};

struct arg_netdev_event {
	const struct net_device___101 *dev;
	union {
		unsigned char nh_flags;
		long unsigned int event;
	};
};

struct rt6_mtu_change_arg {
	struct net_device___101 *dev;
	unsigned int mtu;
	struct fib6_info___30 *f6i;
};

struct rt6_nh {
	struct fib6_info___30 *fib6_info;
	struct fib6_config___10 r_cfg;
	struct list_head next;
};

struct fib6_nh_exception_dump_walker {
	struct rt6_rtnl_dump_arg *dump;
	struct fib6_info___30 *rt;
	unsigned int flags;
	unsigned int skip;
	unsigned int count;
};

enum fib6_walk_state {
	FWS_S = 0,
	FWS_L = 1,
	FWS_R = 2,
	FWS_C = 3,
	FWS_U = 4,
};

struct fib6_walker {
	struct list_head lh;
	struct fib6_node___30 *root;
	struct fib6_node___30 *node;
	struct fib6_info___30 *leaf;
	enum fib6_walk_state state;
	unsigned int skip;
	unsigned int count;
	unsigned int skip_in_node;
	int (*func)(struct fib6_walker *);
	void *args;
};

struct fib6_entry_notifier_info {
	struct fib_notifier_info info;
	struct fib6_info___30 *rt;
	unsigned int nsiblings;
};

struct ipv6_route_iter {
	struct seq_net_private___11 p;
	struct fib6_walker w;
	loff_t skip;
	struct fib6_table___30 *tbl;
	int sernum;
};

struct bpf_iter__ipv6_route {
	union {
		struct bpf_iter_meta___7 *meta;
	};
	union {
		struct fib6_info___30 *rt;
	};
};

struct fib6_cleaner {
	struct fib6_walker w;
	struct net___106 *net;
	int (*func)(struct fib6_info___30 *, void *);
	int sernum;
	void *arg;
	bool skip_notify;
};

enum {
	FIB6_NO_SERNUM_CHANGE = 0,
};

struct fib6_dump_arg {
	struct net___106 *net;
	struct notifier_block *nb;
	struct netlink_ext_ack *extack;
};

struct fib6_nh_pcpu_arg {
	struct fib6_info___30 *from;
	const struct fib6_table___30 *table;
};

struct lookup_args {
	int offset;
	const struct in6_addr *addr;
};

struct ipv6_mreq {
	struct in6_addr ipv6mr_multiaddr;
	int ipv6mr_ifindex;
};

struct in6_flowlabel_req {
	struct in6_addr flr_dst;
	__be32 flr_label;
	__u8 flr_action;
	__u8 flr_share;
	__u16 flr_flags;
	__u16 flr_expires;
	__u16 flr_linger;
	__u32 __flr_pad;
};

struct ip6_mtuinfo {
	struct sockaddr_in6 ip6m_addr;
	__u32 ip6m_mtu;
};

struct fastopen_queue___13 {
	struct request_sock___58 *rskq_rst_head;
	struct request_sock___58 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___13 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___58 *rskq_accept_head;
	struct request_sock___58 *rskq_accept_tail;
	struct fastopen_queue___13 fastopenq;
};

struct inet_connection_sock_af_ops___13 {
	int (*queue_xmit)(struct sock___72 *, struct sk_buff___86 *, struct flowi *);
	void (*send_check)(struct sock___72 *, struct sk_buff___86 *);
	int (*rebuild_header)(struct sock___72 *);
	void (*sk_rx_dst_set)(struct sock___72 *, const struct sk_buff___86 *);
	int (*conn_request)(struct sock___72 *, struct sk_buff___86 *);
	struct sock___72 * (*syn_recv_sock)(const struct sock___72 *, struct sk_buff___86 *, struct request_sock___58 *, struct dst_entry___72 *, struct request_sock___58 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___72 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___72 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___72 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___72 *);
};

struct inet_bind_bucket___13;

struct tcp_ulp_ops___13;

struct inet_connection_sock___13 {
	struct inet_sock___15 icsk_inet;
	struct request_sock_queue___13 icsk_accept_queue;
	struct inet_bind_bucket___13 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___21 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___13 *icsk_af_ops;
	const struct tcp_ulp_ops___13 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___72 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___72 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___13 {
	possible_net_t___85 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___13 {
	struct list_head list;
	int (*init)(struct sock___72 *);
	void (*update)(struct sock___72 *, struct proto___72 *, void (*)(struct sock___72 *));
	void (*release)(struct sock___72 *);
	int (*get_info)(const struct sock___72 *, struct sk_buff___86 *);
	size_t (*get_info_size)(const struct sock___72 *);
	void (*clone)(const struct request_sock___58 *, struct sock___72 *, const gfp_t);
	char name[16];
	struct module___260 *owner;
};

struct udp_sock___5 {
	struct inet_sock___15 inet;
	int pending;
	unsigned int corkflag;
	__u8 encap_type;
	unsigned char no_check6_tx: 1;
	unsigned char no_check6_rx: 1;
	unsigned char encap_enabled: 1;
	unsigned char gro_enabled: 1;
	unsigned char accept_udp_l4: 1;
	unsigned char accept_udp_fraglist: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 len;
	__u16 gso_size;
	__u16 pcslen;
	__u16 pcrlen;
	__u8 pcflag;
	__u8 unused[3];
	int (*encap_rcv)(struct sock___72 *, struct sk_buff___86 *);
	int (*encap_err_lookup)(struct sock___72 *, struct sk_buff___86 *);
	void (*encap_destroy)(struct sock___72 *);
	struct sk_buff___86 * (*gro_receive)(struct sock___72 *, struct list_head *, struct sk_buff___86 *);
	int (*gro_complete)(struct sock___72 *, struct sk_buff___86 *, int);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___85 reader_queue;
	int forward_deficit;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry___293;

struct super_block___293;

struct module___277;

struct file_system_type___293 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___293 * (*mount)(struct file_system_type___293 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___293 *);
	struct module___277 *owner;
	struct file_system_type___293 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___293;

struct kiocb___293;

struct iov_iter___213;

struct poll_table_struct___214;

struct vm_area_struct___298;

struct inode___293;

struct file_lock___293;

struct page___298;

struct pipe_inode_info___134;

struct seq_file___268;

struct file_operations___294 {
	struct module___277 *owner;
	loff_t (*llseek)(struct file___293 *, loff_t, int);
	ssize_t (*read)(struct file___293 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___293 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___293 *, struct iov_iter___213 *);
	ssize_t (*write_iter)(struct kiocb___293 *, struct iov_iter___213 *);
	int (*iopoll)(struct kiocb___293 *, bool);
	int (*iterate)(struct file___293 *, struct dir_context *);
	int (*iterate_shared)(struct file___293 *, struct dir_context *);
	__poll_t (*poll)(struct file___293 *, struct poll_table_struct___214 *);
	long int (*unlocked_ioctl)(struct file___293 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___293 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___293 *, struct vm_area_struct___298 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___293 *, struct file___293 *);
	int (*flush)(struct file___293 *, fl_owner_t);
	int (*release)(struct inode___293 *, struct file___293 *);
	int (*fsync)(struct file___293 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___293 *, int);
	int (*lock)(struct file___293 *, int, struct file_lock___293 *);
	ssize_t (*sendpage)(struct file___293 *, struct page___298 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___293 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___293 *, long unsigned int);
	int (*flock)(struct file___293 *, int, struct file_lock___293 *);
	ssize_t (*splice_write)(struct pipe_inode_info___134 *, struct file___293 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___293 *, loff_t *, struct pipe_inode_info___134 *, size_t, unsigned int);
	int (*setlease)(struct file___293 *, long int, struct file_lock___293 **, void **);
	long int (*fallocate)(struct file___293 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___268 *, struct file___293 *);
	ssize_t (*copy_file_range)(struct file___293 *, loff_t, struct file___293 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___293 *, loff_t, struct file___293 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___293 *, loff_t, loff_t, int);
};

struct vmacache___298 {
	u64 seqnum;
	struct vm_area_struct___298 *vmas[4];
};

struct page_frag___298 {
	struct page___298 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___299;

struct pid___270;

struct nsproxy___279;

struct signal_struct___294;

struct bio_list___184;

struct backing_dev_info___170;

struct io_context___184;

struct css_set___220;

struct mem_cgroup___158;

struct request_queue___184;

struct vm_struct___276;

struct task_struct___300 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___300 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___299 *mm;
	struct mm_struct___299 *active_mm;
	struct vmacache___298 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___300 *real_parent;
	struct task_struct___300 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___300 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___270 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___279 *nsproxy;
	struct signal_struct___294 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___300 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___184 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___170 *backing_dev_info;
	struct io_context___184 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___220 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___134 *splice_pipe;
	struct page_frag___298 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___158 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___158 *active_memcg;
	struct request_queue___184 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___300 *oom_reaper_list;
	struct vm_struct___276 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___281;

struct kobj_type___281;

struct kernfs_node___281;

struct kobject___281 {
	const char *name;
	struct list_head entry;
	struct kobject___281 *parent;
	struct kset___281 *kset;
	struct kobj_type___281 *ktype;
	struct kernfs_node___281 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___278 {
	struct kobject___281 kobj;
	struct module___277 *mod;
	struct kobject___281 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___277 {
	struct module___277 *mod;
	struct latch_tree_node node;
};

struct module_layout___277 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___277 mtn;
};

struct module_attribute___277;

struct kernel_param___277;

struct module___277 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___278 mkobj;
	struct module_attribute___277 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___281 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___277 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___277 core_layout;
	struct module_layout___277 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___270;

struct upid___270 {
	int nr;
	struct pid_namespace___270 *ns;
};

struct pid_namespace___270 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___300 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___270 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___270 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___270 numbers[1];
};

typedef struct page___298 *pgtable_t___298;

struct address_space___293;

struct page_pool___122;

struct dev_pagemap___288;

struct page___298 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___293 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___122 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___298 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___298 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___299 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___288 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___288;

struct vm_area_struct___298 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___298 *vm_next;
	struct vm_area_struct___298 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___299 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___288 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___293 *vm_file;
	struct file___293 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___294 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___300 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___300 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___270 *pids[4];
	struct pid___270 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___299 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___298;

struct mm_struct___299 {
	struct {
		struct vm_area_struct___298 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___293 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___298 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___300 *owner;
		struct user_namespace___26 *user_ns;
		struct file___293 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___107;

struct cgroup_namespace___220;

struct nsproxy___279 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___270 *pid_ns_for_children;
	struct net___107 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___220 *cgroup_ns;
};

struct bio___184;

struct bio_list___184 {
	struct bio___184 *head;
	struct bio___184 *tail;
};

struct cgroup_subsys_state___220;

struct bdi_writeback___170 {
	struct backing_dev_info___170 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___220 *memcg_css;
	struct cgroup_subsys_state___220 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___274;

struct backing_dev_info___170 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___170 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___274 *dev;
	char dev_name[64];
	struct device___274 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___293 *debug_dir;
};

struct io_cq___184;

struct io_context___184 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___184 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___220;

struct css_set___220 {
	struct cgroup_subsys_state___220 *subsys[14];
	refcount_t refcount;
	struct css_set___220 *dom_cset;
	struct cgroup___220 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___220 *mg_src_cgrp;
	struct cgroup___220 *mg_dst_cgrp;
	struct css_set___220 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___293;

struct pipe_buffer___134;

struct pipe_inode_info___134 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___298 *tmp_page;
	struct fasync_struct___293 *fasync_readers;
	struct fasync_struct___293 *fasync_writers;
	struct pipe_buffer___134 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___220;

struct cgroup_subsys_state___220 {
	struct cgroup___220 *cgroup;
	struct cgroup_subsys___220 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___220 *parent;
};

struct cgroup_file___220 {
	struct kernfs_node___281 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___158;

struct mem_cgroup_per_node___158;

struct mem_cgroup___158 {
	struct cgroup_subsys_state___220 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___220 events_file;
	struct cgroup_file___220 events_local_file;
	struct cgroup_file___220 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___158 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___300 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___158 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___184;

struct blk_integrity___184 {
	const struct blk_integrity_profile___184 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___184 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___184 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___184;

struct elevator_queue___184;

struct blk_mq_ops___179;

struct blk_mq_hw_ctx___179;

struct gendisk___187;

struct blkcg_gq___172;

struct blk_mq_tag_set___179;

struct request_queue___184 {
	struct request___184 *last_merge;
	struct elevator_queue___184 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___179 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___179 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___187 *disk;
	struct kobject___281 kobj;
	struct kobject___281 *mq_kobj;
	struct blk_integrity___184 integrity;
	struct device___274 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___172 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___179 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___184 bio_split;
	struct dentry___293 *debugfs_dir;
	struct dentry___293 *sched_debugfs_dir;
	struct dentry___293 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___276 {
	struct vm_struct___276 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___298 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___293;

struct address_space___293 {
	struct inode___293 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___293 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___122 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___274 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___122 {
	u32 count;
	struct page___298 *cache[128];
};

struct page_pool___122 {
	struct page_pool_params___122 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___298 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___122 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___288;

struct dev_pagemap___288 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___288 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___293;

struct path___293 {
	struct vfsmount___293 *mnt;
	struct dentry___293 *dentry;
};

struct fown_struct___270 {
	rwlock_t lock;
	struct pid___270 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___293 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___293 f_path;
	struct inode___293 *f_inode;
	const struct file_operations___294 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___270 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___293 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___288;

struct vm_operations_struct___288 {
	void (*open)(struct vm_area_struct___298 *);
	void (*close)(struct vm_area_struct___298 *);
	int (*may_split)(struct vm_area_struct___298 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___298 *);
	int (*mprotect)(struct vm_area_struct___298 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___288 *);
	vm_fault_t (*huge_fault)(struct vm_fault___288 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___288 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___298 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___288 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___288 *);
	int (*access)(struct vm_area_struct___298 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___298 *);
	int (*set_policy)(struct vm_area_struct___298 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___298 *, long unsigned int);
	struct page___298 * (*find_special_page)(struct vm_area_struct___298 *, long unsigned int);
};

struct core_thread___298 {
	struct task_struct___300 *task;
	struct core_thread___298 *next;
};

struct core_state___298 {
	atomic_t nr_threads;
	struct core_thread___298 dumper;
	struct completion startup;
};

struct vm_fault___288 {
	const struct {
		struct vm_area_struct___298 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___298 *cow_page;
	struct page___298 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___298 prealloc_pte;
};

struct pglist_data___166;

struct lruvec___166 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___166 *pgdat;
};

struct zone___166 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___166 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___166 {
	struct zone___166 *zone;
	int zone_idx;
};

struct zonelist___166 {
	struct zoneref___166 _zonerefs[321];
};

struct pglist_data___166 {
	struct zone___166 node_zones[5];
	struct zonelist___166 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___300 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___300 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___166 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___293;

struct dentry___293 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___293 *d_parent;
	struct qstr d_name;
	struct inode___293 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___293 *d_op;
	struct super_block___293 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___293;

struct inode___293 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___293 *i_op;
	struct super_block___293 *i_sb;
	struct address_space___293 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___170 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___294 *i_fop;
		void (*free_inode)(struct inode___293 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___293 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___134 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___293 {
	int (*d_revalidate)(struct dentry___293 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___293 *, unsigned int);
	int (*d_hash)(const struct dentry___293 *, struct qstr *);
	int (*d_compare)(const struct dentry___293 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___293 *);
	int (*d_init)(struct dentry___293 *);
	void (*d_release)(struct dentry___293 *);
	void (*d_prune)(struct dentry___293 *);
	void (*d_iput)(struct dentry___293 *, struct inode___293 *);
	char * (*d_dname)(struct dentry___293 *, char *, int);
	struct vfsmount___293 * (*d_automount)(struct path___293 *);
	int (*d_manage)(const struct path___293 *, bool);
	struct dentry___293 * (*d_real)(struct dentry___293 *, const struct inode___293 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___293;

struct mem_dqinfo___293 {
	struct quota_format_type___293 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___293;

struct quota_info___293 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___293 *files[3];
	struct mem_dqinfo___293 info[3];
	const struct quota_format_ops___293 *ops[3];
};

struct rcuwait___294 {
	struct task_struct___300 *task;
};

struct percpu_rw_semaphore___294 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___294 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___293 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___294 rw_sem[3];
};

struct shrink_control___158;

struct shrinker___158 {
	long unsigned int (*count_objects)(struct shrinker___158 *, struct shrink_control___158 *);
	long unsigned int (*scan_objects)(struct shrinker___158 *, struct shrink_control___158 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___293;

struct dquot_operations___293;

struct quotactl_ops___293;

struct block_device___187;

struct super_block___293 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___293 *s_type;
	const struct super_operations___293 *s_op;
	const struct dquot_operations___293 *dq_op;
	const struct quotactl_ops___293 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___293 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___187 *s_bdev;
	struct backing_dev_info___170 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___293 s_dquot;
	struct sb_writers___293 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___293 *s_d_op;
	int cleancache_poolid;
	struct shrinker___158 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___293 {
	struct dentry___293 *mnt_root;
	struct super_block___293 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___158 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___158 *memcg;
};

struct psi_group___220 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___300 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___96;

struct cgroup_bpf___96 {
	struct bpf_prog_array___96 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___96 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___220;

struct cgroup_rstat_cpu___220;

struct cgroup___220 {
	struct cgroup_subsys_state___220 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___281 *kn;
	struct cgroup_file___220 procs_file;
	struct cgroup_file___220 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___220 *subsys[14];
	struct cgroup_root___220 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___220 *dom_cgrp;
	struct cgroup___220 *old_dom_cgrp;
	struct cgroup_rstat_cpu___220 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___220 psi;
	struct cgroup_bpf___96 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___184 {
	struct request_queue___184 *q;
	struct io_context___184 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___293 {
	struct file___293 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___293 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___293 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___293 *ia_file;
};

struct dquot___293 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___293 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___293 {
	int qf_fmt_id;
	const struct quota_format_ops___293 *qf_ops;
	struct module___277 *qf_owner;
	struct quota_format_type___293 *qf_next;
};

struct quota_format_ops___293 {
	int (*check_quota_file)(struct super_block___293 *, int);
	int (*read_file_info)(struct super_block___293 *, int);
	int (*write_file_info)(struct super_block___293 *, int);
	int (*free_file_info)(struct super_block___293 *, int);
	int (*read_dqblk)(struct dquot___293 *);
	int (*commit_dqblk)(struct dquot___293 *);
	int (*release_dqblk)(struct dquot___293 *);
	int (*get_next_id)(struct super_block___293 *, struct kqid *);
};

struct dquot_operations___293 {
	int (*write_dquot)(struct dquot___293 *);
	struct dquot___293 * (*alloc_dquot)(struct super_block___293 *, int);
	void (*destroy_dquot)(struct dquot___293 *);
	int (*acquire_dquot)(struct dquot___293 *);
	int (*release_dquot)(struct dquot___293 *);
	int (*mark_dirty)(struct dquot___293 *);
	int (*write_info)(struct super_block___293 *, int);
	qsize_t * (*get_reserved_space)(struct inode___293 *);
	int (*get_projid)(struct inode___293 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___293 *, qsize_t *);
	int (*get_next_id)(struct super_block___293 *, struct kqid *);
};

struct quotactl_ops___293 {
	int (*quota_on)(struct super_block___293 *, int, int, const struct path___293 *);
	int (*quota_off)(struct super_block___293 *, int);
	int (*quota_enable)(struct super_block___293 *, unsigned int);
	int (*quota_disable)(struct super_block___293 *, unsigned int);
	int (*quota_sync)(struct super_block___293 *, int);
	int (*set_info)(struct super_block___293 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___293 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___293 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___293 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___293 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___293 *, unsigned int);
};

struct writeback_control___170;

struct address_space_operations___293 {
	int (*writepage)(struct page___298 *, struct writeback_control___170 *);
	int (*readpage)(struct file___293 *, struct page___298 *);
	int (*writepages)(struct address_space___293 *, struct writeback_control___170 *);
	int (*set_page_dirty)(struct page___298 *);
	int (*readpages)(struct file___293 *, struct address_space___293 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___293 *, struct address_space___293 *, loff_t, unsigned int, unsigned int, struct page___298 **, void **);
	int (*write_end)(struct file___293 *, struct address_space___293 *, loff_t, unsigned int, unsigned int, struct page___298 *, void *);
	sector_t (*bmap)(struct address_space___293 *, sector_t);
	void (*invalidatepage)(struct page___298 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___298 *, gfp_t);
	void (*freepage)(struct page___298 *);
	ssize_t (*direct_IO)(struct kiocb___293 *, struct iov_iter___213 *);
	int (*migratepage)(struct address_space___293 *, struct page___298 *, struct page___298 *, enum migrate_mode);
	bool (*isolate_page)(struct page___298 *, isolate_mode_t);
	void (*putback_page)(struct page___298 *);
	int (*launder_page)(struct page___298 *);
	int (*is_partially_uptodate)(struct page___298 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___298 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___293 *, struct page___298 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___293 *, sector_t *);
	void (*swap_deactivate)(struct file___293 *);
};

struct writeback_control___170 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___170 *wb;
	struct inode___293 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___210;

struct iov_iter___213 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___210 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___134 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___293 {
	struct dentry___293 * (*lookup)(struct inode___293 *, struct dentry___293 *, unsigned int);
	const char * (*get_link)(struct dentry___293 *, struct inode___293 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___293 *, int);
	struct posix_acl * (*get_acl)(struct inode___293 *, int, bool);
	int (*readlink)(struct dentry___293 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___293 *, struct dentry___293 *, umode_t, bool);
	int (*link)(struct dentry___293 *, struct inode___293 *, struct dentry___293 *);
	int (*unlink)(struct inode___293 *, struct dentry___293 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___293 *, struct dentry___293 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___293 *, struct dentry___293 *, umode_t);
	int (*rmdir)(struct inode___293 *, struct dentry___293 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___293 *, struct dentry___293 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___293 *, struct dentry___293 *, struct inode___293 *, struct dentry___293 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___293 *, struct iattr___293 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___293 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___293 *, char *, size_t);
	int (*fiemap)(struct inode___293 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___293 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___293 *, struct dentry___293 *, struct file___293 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___293 *, struct dentry___293 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___293 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___293 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___293 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___293 {
	void (*fl_copy_lock)(struct file_lock___293 *, struct file_lock___293 *);
	void (*fl_release_private)(struct file_lock___293 *);
};

struct lock_manager_operations___293;

struct file_lock___293 {
	struct file_lock___293 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___293 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___293 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___293 *fl_ops;
	const struct lock_manager_operations___293 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___293 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___293 *);
	int (*lm_grant)(struct file_lock___293 *, int);
	bool (*lm_break)(struct file_lock___293 *);
	int (*lm_change)(struct file_lock___293 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___293 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___293 *);
};

struct fasync_struct___293 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___293 *fa_next;
	struct file___293 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___293 {
	struct inode___293 * (*alloc_inode)(struct super_block___293 *);
	void (*destroy_inode)(struct inode___293 *);
	void (*free_inode)(struct inode___293 *);
	void (*dirty_inode)(struct inode___293 *, int);
	int (*write_inode)(struct inode___293 *, struct writeback_control___170 *);
	int (*drop_inode)(struct inode___293 *);
	void (*evict_inode)(struct inode___293 *);
	void (*put_super)(struct super_block___293 *);
	int (*sync_fs)(struct super_block___293 *, int);
	int (*freeze_super)(struct super_block___293 *);
	int (*freeze_fs)(struct super_block___293 *);
	int (*thaw_super)(struct super_block___293 *);
	int (*unfreeze_fs)(struct super_block___293 *);
	int (*statfs)(struct dentry___293 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___293 *, int *, char *);
	void (*umount_begin)(struct super_block___293 *);
	int (*show_options)(struct seq_file___268 *, struct dentry___293 *);
	int (*show_devname)(struct seq_file___268 *, struct dentry___293 *);
	int (*show_path)(struct seq_file___268 *, struct dentry___293 *);
	int (*show_stats)(struct seq_file___268 *, struct dentry___293 *);
	ssize_t (*quota_read)(struct super_block___293 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___293 *, int, const char *, size_t, loff_t);
	struct dquot___293 ** (*get_dquots)(struct inode___293 *);
	long int (*nr_cached_objects)(struct super_block___293 *, struct shrink_control___158 *);
	long int (*free_cached_objects)(struct super_block___293 *, struct shrink_control___158 *);
	struct file___293 * (*real_loop)(struct file___293 *);
};

struct wakeup_source___274;

struct dev_pm_info___274 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___274 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___274 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___274;

struct bus_type___274;

struct device_driver___274;

struct dev_pm_domain___274;

struct fwnode_handle___270;

struct class___274;

struct attribute_group___281;

struct device___274 {
	struct kobject___281 kobj;
	struct device___274 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___274 *type;
	struct bus_type___274 *bus;
	struct device_driver___274 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___274 power;
	struct dev_pm_domain___274 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___270 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___274 *class;
	const struct attribute_group___281 **groups;
	void (*release)(struct device___274 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___187 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___293 *bd_inode;
	struct super_block___293 *bd_super;
	void *bd_claiming;
	struct device___274 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___281 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___187 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___293 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___222)(struct file___293 *, wait_queue_head_t *, struct poll_table_struct___214 *);

struct poll_table_struct___214 {
	poll_queue_proc___222 _qproc;
	__poll_t _key;
};

struct seq_operations___268;

struct seq_file___268 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___268 *op;
	int poll_event;
	const struct file___293 *file;
	void *private;
};

typedef void bio_end_io_t___184(struct bio___184 *);

struct bio_vec___210 {
	struct page___298 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___184;

struct bio___184 {
	struct bio___184 *bi_next;
	struct block_device___187 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___184 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___172 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___184 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___210 *bi_io_vec;
	struct bio_set___184 *bi_pool;
	struct bio_vec___210 bi_inline_vecs[0];
};

struct kernfs_root___281;

struct kernfs_elem_dir___281 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___281 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___281;

struct kernfs_root___281 {
	struct kernfs_node___281 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___281 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___281 {
	struct kernfs_node___281 *target_kn;
};

struct kernfs_ops___281;

struct kernfs_elem_attr___281 {
	const struct kernfs_ops___281 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___281 *notify_next;
};

struct kernfs_node___281 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___281 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___281 dir;
		struct kernfs_elem_symlink___281 symlink;
		struct kernfs_elem_attr___281 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___281;

struct kernfs_ops___281 {
	int (*open)(struct kernfs_open_file___281 *);
	void (*release)(struct kernfs_open_file___281 *);
	int (*seq_show)(struct seq_file___268 *, void *);
	void * (*seq_start)(struct seq_file___268 *, loff_t *);
	void * (*seq_next)(struct seq_file___268 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___268 *, void *);
	ssize_t (*read)(struct kernfs_open_file___281 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___281 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___281 *, struct poll_table_struct___214 *);
	int (*mmap)(struct kernfs_open_file___281 *, struct vm_area_struct___298 *);
};

struct kernfs_syscall_ops___281 {
	int (*show_options)(struct seq_file___268 *, struct kernfs_root___281 *);
	int (*mkdir)(struct kernfs_node___281 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___281 *);
	int (*rename)(struct kernfs_node___281 *, struct kernfs_node___281 *, const char *);
	int (*show_path)(struct seq_file___268 *, struct kernfs_node___281 *, struct kernfs_root___281 *);
};

struct kernfs_open_file___281 {
	struct kernfs_node___281 *kn;
	struct file___293 *file;
	struct seq_file___268 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___288 *vm_ops;
};

struct sock___89;

struct kobj_ns_type_operations___89 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___89 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___107 *net;
} possible_net_t___102;

struct proto___89;

struct sock_common___89 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___89 *skc_prot;
	possible_net_t___102 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___89 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___103;

struct sk_buff_head___102 {
	struct sk_buff___103 *next;
	struct sk_buff___103 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___89 {
	struct cgroup___220 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___89;

struct socket_wq___90;

struct dst_entry___89;

struct socket___91;

struct net_device___102;

struct sock_reuseport___37;

struct sock___89 {
	struct sock_common___89 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___102 sk_error_queue;
	struct sk_buff___103 *sk_rx_skb_cache;
	struct sk_buff_head___102 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___103 *head;
		struct sk_buff___103 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___89 *sk_filter;
	union {
		struct socket_wq___90 *sk_wq;
		struct socket_wq___90 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___89 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___89 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___103 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___103 *sk_tx_skb_cache;
	struct sk_buff_head___102 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___298 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___89 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___270 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___91 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___89 sk_cgrp_data;
	struct mem_cgroup___158 *sk_memcg;
	void (*sk_state_change)(struct sock___89 *);
	void (*sk_data_ready)(struct sock___89 *);
	void (*sk_write_space)(struct sock___89 *);
	void (*sk_error_report)(struct sock___89 *);
	int (*sk_backlog_rcv)(struct sock___89 *, struct sk_buff___103 *);
	struct sk_buff___103 * (*sk_validate_xmit_skb)(struct sock___89 *, struct net_device___102 *, struct sk_buff___103 *);
	void (*sk_destruct)(struct sock___89 *);
	struct sock_reuseport___37 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___281;

struct attribute_group___281 {
	const char *name;
	umode_t (*is_visible)(struct kobject___281 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___281 *, struct bin_attribute___281 *, int);
	struct attribute **attrs;
	struct bin_attribute___281 **bin_attrs;
};

struct bin_attribute___281 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___293 * (*f_mapping)();
	ssize_t (*read)(struct file___293 *, struct kobject___281 *, struct bin_attribute___281 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___293 *, struct kobject___281 *, struct bin_attribute___281 *, char *, loff_t, size_t);
	int (*mmap)(struct file___293 *, struct kobject___281 *, struct bin_attribute___281 *, struct vm_area_struct___298 *);
};

struct sysfs_ops___281 {
	ssize_t (*show)(struct kobject___281 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___281 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___281;

struct kset___281 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___281 kobj;
	const struct kset_uevent_ops___281 *uevent_ops;
};

struct kobj_type___281 {
	void (*release)(struct kobject___281 *);
	const struct sysfs_ops___281 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___281 **default_groups;
	const struct kobj_ns_type_operations___89 * (*child_ns_type)(struct kobject___281 *);
	const void * (*namespace)(struct kobject___281 *);
	void (*get_ownership)(struct kobject___281 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___281 {
	int (* const filter)(struct kset___281 *, struct kobject___281 *);
	const char * (* const name)(struct kset___281 *, struct kobject___281 *);
	int (* const uevent)(struct kset___281 *, struct kobject___281 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___277 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___277 *);
	int (*get)(char *, const struct kernel_param___277 *);
	void (*free)(void *);
};

struct kparam_array___277;

struct kernel_param___277 {
	const char *name;
	struct module___277 *mod;
	const struct kernel_param_ops___277 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___277 *arr;
	};
};

struct kparam_array___277 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___277 *ops;
	void *elem;
};

struct module_attribute___277 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___277 *, struct module_kobject___278 *, char *);
	ssize_t (*store)(struct module_attribute___277 *, struct module_kobject___278 *, const char *, size_t);
	void (*setup)(struct module___277 *, const char *);
	int (*test)(struct module___277 *);
	void (*free)(struct module___277 *);
};

struct msghdr___91 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___213 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___293 *msg_iocb;
};

struct dev_pagemap_ops___288 {
	void (*page_free)(struct page___298 *);
	void (*kill)(struct dev_pagemap___288 *);
	void (*cleanup)(struct dev_pagemap___288 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___288 *);
};

struct socket_wq___90 {
	wait_queue_head_t wait;
	struct fasync_struct___293 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___90;

struct socket___91 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___293 *file;
	struct sock___89 *sk;
	const struct proto_ops___90 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___90 wq;
};

typedef int (*sk_read_actor_t___89)(read_descriptor_t *, struct sk_buff___103 *, unsigned int, size_t);

struct proto_ops___90 {
	int family;
	struct module___277 *owner;
	int (*release)(struct socket___91 *);
	int (*bind)(struct socket___91 *, struct sockaddr *, int);
	int (*connect)(struct socket___91 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___91 *, struct socket___91 *);
	int (*accept)(struct socket___91 *, struct socket___91 *, int, bool);
	int (*getname)(struct socket___91 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___293 *, struct socket___91 *, struct poll_table_struct___214 *);
	int (*ioctl)(struct socket___91 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___91 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___91 *, void *, bool, bool);
	int (*listen)(struct socket___91 *, int);
	int (*shutdown)(struct socket___91 *, int);
	int (*setsockopt)(struct socket___91 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___91 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___268 *, struct socket___91 *);
	int (*sendmsg)(struct socket___91 *, struct msghdr___91 *, size_t);
	int (*recvmsg)(struct socket___91 *, struct msghdr___91 *, size_t, int);
	int (*mmap)(struct file___293 *, struct socket___91 *, struct vm_area_struct___298 *);
	ssize_t (*sendpage)(struct socket___91 *, struct page___298 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___91 *, loff_t *, struct pipe_inode_info___134 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___89 *, int);
	int (*peek_len)(struct socket___91 *);
	int (*read_sock)(struct sock___89 *, read_descriptor_t *, sk_read_actor_t___89);
	int (*sendpage_locked)(struct sock___89 *, struct page___298 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___89 *, struct msghdr___91 *, size_t);
	int (*set_rcvlowat)(struct sock___89 *, int);
};

struct sk_buff___103 {
	union {
		struct {
			struct sk_buff___103 *next;
			struct sk_buff___103 *prev;
			union {
				struct net_device___102 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___89 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___103 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___62;

struct fib_rules_ops___89;

struct fqdir___107;

struct tcp_congestion_ops___35;

struct fib_notifier_ops___89;

struct netns_ipv4___107 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___62 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___89 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___89 *fibnl;
	struct sock___89 **icmp_sk;
	struct sock___89 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___89 **tcp_sk;
	struct fqdir___107 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___35 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___89 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___89 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___89 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___89;

struct dst_ops___107 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___107 *);
	struct dst_entry___89 * (*check)(struct dst_entry___89 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___89 *);
	unsigned int (*mtu)(const struct dst_entry___89 *);
	u32 * (*cow_metrics)(struct dst_entry___89 *, long unsigned int);
	void (*destroy)(struct dst_entry___89 *);
	void (*ifdown)(struct dst_entry___89 *, struct net_device___102 *, int);
	struct dst_entry___89 * (*negative_advice)(struct dst_entry___89 *);
	void (*link_failure)(struct sk_buff___103 *);
	void (*update_pmtu)(struct dst_entry___89 *, struct sock___89 *, struct sk_buff___103 *, u32, bool);
	void (*redirect)(struct dst_entry___89 *, struct sock___89 *, struct sk_buff___103 *);
	int (*local_out)(struct net___107 *, struct sock___89 *, struct sk_buff___103 *);
	struct neighbour___89 * (*neigh_lookup)(const struct dst_entry___89 *, struct sk_buff___103 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___89 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___31;

struct rt6_info___31;

struct fib6_table___31;

struct netns_ipv6___107 {
	struct dst_ops___107 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___107 *fqdir;
	struct fib6_info___31 *fib6_null_entry;
	struct rt6_info___31 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___31 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___31 *ip6_prohibit_entry;
	struct rt6_info___31 *ip6_blk_hole_entry;
	struct fib6_table___31 *fib6_local_tbl;
	struct fib_rules_ops___89 *fib6_rules_ops;
	struct sock___89 **icmp_sk;
	struct sock___89 *ndisc_sk;
	struct sock___89 *tcp_sk;
	struct sock___89 *igmp_sk;
	struct sock___89 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___89 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___89 *notifier_ops;
	struct fib_notifier_ops___89 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___107 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___107 *fqdir;
};

struct netns_sctp___89 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___89 *ctl_sock;
	struct sock___89 *udp4_sock;
	struct sock___89 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___20;

struct netns_nf___20 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___20 *hooks_ipv4[5];
	struct nf_hook_entries___20 *hooks_ipv6[5];
	struct nf_hook_entries___20 *hooks_arp[3];
	struct nf_hook_entries___20 *hooks_bridge[5];
	struct nf_hook_entries___20 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___96;

struct netns_bpf___96 {
	struct bpf_prog_array___96 *run_array[2];
	struct bpf_prog___96 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___107 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___89 *nlsk;
	struct sock___89 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___107 xfrm4_dst_ops;
	struct dst_ops___107 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___107 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___89 *rtnl;
	struct sock___89 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___102 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___107 ipv4;
	struct netns_ipv6___107 ipv6;
	struct netns_ieee802154_lowpan___107 ieee802154_lowpan;
	struct netns_sctp___89 sctp;
	struct netns_nf___20 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___102 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___96 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___107 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___89 *crypto_nlsk;
	struct sock___89 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct fwnode_operations___270;

struct fwnode_handle___270 {
	struct fwnode_handle___270 *secondary;
	const struct fwnode_operations___270 *ops;
	struct device___274 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___270;

struct fwnode_endpoint___270;

struct fwnode_operations___270 {
	struct fwnode_handle___270 * (*get)(struct fwnode_handle___270 *);
	void (*put)(struct fwnode_handle___270 *);
	bool (*device_is_available)(const struct fwnode_handle___270 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___270 *, const struct device___274 *);
	bool (*property_present)(const struct fwnode_handle___270 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___270 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___270 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___270 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*get_parent)(const struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*get_next_child_node)(const struct fwnode_handle___270 *, struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*get_named_child_node)(const struct fwnode_handle___270 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___270 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___270 *);
	struct fwnode_handle___270 * (*graph_get_next_endpoint)(const struct fwnode_handle___270 *, struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*graph_get_remote_endpoint)(const struct fwnode_handle___270 *);
	struct fwnode_handle___270 * (*graph_get_port_parent)(struct fwnode_handle___270 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___270 *, struct fwnode_endpoint___270 *);
	int (*add_links)(struct fwnode_handle___270 *);
};

struct fwnode_endpoint___270 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___270 *local_fwnode;
};

struct fwnode_reference_args___270 {
	struct fwnode_handle___270 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___220 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___220 *root_cset;
};

struct dev_pm_ops___274 {
	int (*prepare)(struct device___274 *);
	void (*complete)(struct device___274 *);
	int (*suspend)(struct device___274 *);
	int (*resume)(struct device___274 *);
	int (*freeze)(struct device___274 *);
	int (*thaw)(struct device___274 *);
	int (*poweroff)(struct device___274 *);
	int (*restore)(struct device___274 *);
	int (*suspend_late)(struct device___274 *);
	int (*resume_early)(struct device___274 *);
	int (*freeze_late)(struct device___274 *);
	int (*thaw_early)(struct device___274 *);
	int (*poweroff_late)(struct device___274 *);
	int (*restore_early)(struct device___274 *);
	int (*suspend_noirq)(struct device___274 *);
	int (*resume_noirq)(struct device___274 *);
	int (*freeze_noirq)(struct device___274 *);
	int (*thaw_noirq)(struct device___274 *);
	int (*poweroff_noirq)(struct device___274 *);
	int (*restore_noirq)(struct device___274 *);
	int (*runtime_suspend)(struct device___274 *);
	int (*runtime_resume)(struct device___274 *);
	int (*runtime_idle)(struct device___274 *);
};

struct wakeup_source___274 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___274 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___274 {
	struct dev_pm_ops___274 ops;
	int (*start)(struct device___274 *);
	void (*detach)(struct device___274 *, bool);
	int (*activate)(struct device___274 *);
	void (*sync)(struct device___274 *);
	void (*dismiss)(struct device___274 *);
};

struct bus_type___274 {
	const char *name;
	const char *dev_name;
	struct device___274 *dev_root;
	const struct attribute_group___281 **bus_groups;
	const struct attribute_group___281 **dev_groups;
	const struct attribute_group___281 **drv_groups;
	int (*match)(struct device___274 *, struct device_driver___274 *);
	int (*uevent)(struct device___274 *, struct kobj_uevent_env *);
	int (*probe)(struct device___274 *);
	void (*sync_state)(struct device___274 *);
	void (*remove)(struct device___274 *);
	void (*shutdown)(struct device___274 *);
	int (*online)(struct device___274 *);
	int (*offline)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	int (*num_vf)(struct device___274 *);
	int (*dma_configure)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___274 {
	const char *name;
	struct bus_type___274 *bus;
	struct module___277 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___274 *);
	void (*sync_state)(struct device___274 *);
	int (*remove)(struct device___274 *);
	void (*shutdown)(struct device___274 *);
	int (*suspend)(struct device___274 *, pm_message_t);
	int (*resume)(struct device___274 *);
	const struct attribute_group___281 **groups;
	const struct attribute_group___281 **dev_groups;
	const struct dev_pm_ops___274 *pm;
	void (*coredump)(struct device___274 *);
	struct driver_private *p;
};

struct device_type___274 {
	const char *name;
	const struct attribute_group___281 **groups;
	int (*uevent)(struct device___274 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___274 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___274 *);
	const struct dev_pm_ops___274 *pm;
};

struct class___274 {
	const char *name;
	struct module___277 *owner;
	const struct attribute_group___281 **class_groups;
	const struct attribute_group___281 **dev_groups;
	struct kobject___281 *dev_kobj;
	int (*dev_uevent)(struct device___274 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___274 *, umode_t *);
	void (*class_release)(struct class___274 *);
	void (*dev_release)(struct device___274 *);
	int (*shutdown_pre)(struct device___274 *);
	const struct kobj_ns_type_operations___89 *ns_type;
	const void * (*namespace)(struct device___274 *);
	void (*get_ownership)(struct device___274 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___274 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___134;

struct pipe_buffer___134 {
	struct page___298 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___134 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___134 {
	int (*confirm)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
	void (*release)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
	bool (*try_steal)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
	bool (*get)(struct pipe_inode_info___134 *, struct pipe_buffer___134 *);
};

typedef rx_handler_result_t rx_handler_func_t___102(struct sk_buff___103 **);

struct bpf_xdp_entity___96 {
	struct bpf_prog___96 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___102;

struct net_device_ops___102;

struct l3mdev_ops___89;

struct ndisc_ops___71;

struct xfrmdev_ops___102;

struct header_ops___102;

struct inet6_dev___71;

struct netdev_rx_queue___102;

struct mini_Qdisc___96;

struct netdev_queue___102;

struct Qdisc___96;

struct rtnl_link_ops___96;

struct dcbnl_rtnl_ops___102;

struct net_device___102 {
	char name[16];
	struct netdev_name_node___102 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___102 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___89 *l3mdev_ops;
	const struct ndisc_ops___71 *ndisc_ops;
	const struct xfrmdev_ops___102 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___102 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___281 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___71 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___102 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___96 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___102 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___96 *miniq_ingress;
	struct netdev_queue___102 *ingress_queue;
	struct nf_hook_entries___20 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___102 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___96 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___96 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___102 = 0,
		NETREG_REGISTERED___102 = 1,
		NETREG_UNREGISTERING___102 = 2,
		NETREG_UNREGISTERED___102 = 3,
		NETREG_RELEASED___102 = 4,
		NETREG_DUMMY___102 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___102 = 0,
		RTNL_LINK_INITIALIZING___102 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___102 *);
	struct netpoll_info *npinfo;
	possible_net_t___102 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___274 dev;
	const struct attribute_group___281 *sysfs_groups[4];
	const struct attribute_group___281 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___96 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___102 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___96 xdp_state[3];
	long: 64;
};

struct netlink_callback___102 {
	struct sk_buff___103 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___103 *, struct netlink_callback___102 *);
	int (*done)(struct netlink_callback___102 *);
	void *data;
	struct module___277 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct inet_frags___107;

struct fqdir___107 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___107 *f;
	struct net___107 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___107;

struct inet_frags___107 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___107 *, const void *);
	void (*destructor)(struct inet_frag_queue___107 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___107 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___103 *fragments_tail;
	struct sk_buff___103 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___107 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___62 {
	struct ip_ra_chain___62 *next;
	struct sock___89 *sk;
	union {
		void (*destructor)(struct sock___89 *);
		struct sock___89 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___89;

struct fib_lookup_arg___89;

struct fib_rules_ops___89 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___89 *, struct flowi *, int, struct fib_lookup_arg___89 *);
	bool (*suppress)(struct fib_rule___89 *, int, struct fib_lookup_arg___89 *);
	int (*match)(struct fib_rule___89 *, struct flowi *, int);
	int (*configure)(struct fib_rule___89 *, struct sk_buff___103 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___89 *);
	int (*compare)(struct fib_rule___89 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___89 *, struct sk_buff___103 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___89 *);
	void (*flush_cache)(struct fib_rules_ops___89 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___277 *owner;
	struct net___107 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___35 {
	u32 (*ssthresh)(struct sock___89 *);
	void (*cong_avoid)(struct sock___89 *, u32, u32);
	void (*set_state)(struct sock___89 *, u8);
	void (*cwnd_event)(struct sock___89 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___89 *, u32);
	void (*pkts_acked)(struct sock___89 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___89 *);
	void (*cong_control)(struct sock___89 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___89 *);
	u32 (*sndbuf_expand)(struct sock___89 *);
	size_t (*get_info)(struct sock___89 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___277 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___89 *);
	void (*release)(struct sock___89 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___89 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___107 *);
	int (*fib_dump)(struct net___107 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___277 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___65;

struct dst_entry___89 {
	struct net_device___102 *dev;
	struct dst_ops___107 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___103 *);
	int (*output)(struct net___107 *, struct sock___89 *, struct sk_buff___103 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___65 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___89;

struct neigh_parms___89;

struct neigh_ops___89;

struct neighbour___89 {
	struct neighbour___89 *next;
	struct neigh_table___89 *tbl;
	struct neigh_parms___89 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___102 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___89 *, struct sk_buff___103 *);
	const struct neigh_ops___89 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___102 *dev;
	u8 primary_key[0];
};

struct rtable___33;

struct fnhe_hash_bucket___31;

struct fib_nh_common___31 {
	struct net_device___102 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___65 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___33 **nhc_pcpu_rth_output;
	struct rtable___33 *nhc_rth_input;
	struct fnhe_hash_bucket___31 *nhc_exceptions;
};

struct fib6_nh___31 {
	struct fib_nh_common___31 nh_common;
	long unsigned int last_probe;
	struct rt6_info___31 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___31;

struct nexthop___21;

struct fib6_info___31 {
	struct fib6_table___31 *fib6_table;
	struct fib6_info___31 *fib6_next;
	struct fib6_node___31 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___21 *nh;
	struct fib6_nh___31 fib6_nh[0];
};

struct rt6_info___31 {
	struct dst_entry___89 dst;
	struct fib6_info___31 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___71 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___31 {
	struct fib6_node___31 *parent;
	struct fib6_node___31 *left;
	struct fib6_node___31 *right;
	struct fib6_node___31 *subtree;
	struct fib6_info___31 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___31 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___31 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___31 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___20;

typedef unsigned int nf_hookfn___25(void *, struct sk_buff___103 *, const struct nf_hook_state___20 *);

struct nf_hook_entry___20 {
	nf_hookfn___25 *hook;
	void *priv;
};

struct nf_hook_entries___20 {
	u16 num_hook_entries;
	struct nf_hook_entry___20 hooks[0];
};

struct bpf_prog_array_item___96 {
	struct bpf_prog___96 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___96 {
	struct callback_head rcu;
	struct bpf_prog_array_item___96 items[0];
};

struct bpf_prog_aux___105;

struct bpf_prog___96 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___105 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___268 {
	void * (*start)(struct seq_file___268 *, loff_t *);
	void (*stop)(struct seq_file___268 *, void *);
	void * (*next)(struct seq_file___268 *, void *, loff_t *);
	int (*show)(struct seq_file___268 *, void *);
};

struct pernet_operations___36 {
	struct list_head list;
	int (*init)(struct net___107 *);
	void (*pre_exit)(struct net___107 *);
	void (*exit)(struct net___107 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___102 {
	int (*ieee_getets)(struct net_device___102 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___102 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___102 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___102 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___102 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___102 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___102 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___102 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___102 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___102 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___102 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___102 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___102 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___102 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___102 *);
	u8 (*setstate)(struct net_device___102 *, u8);
	void (*getpermhwaddr)(struct net_device___102 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___102 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___102 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___102 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___102 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___102 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___102 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___102 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___102 *, int, u8 *);
	void (*setpfccfg)(struct net_device___102 *, int, u8);
	void (*getpfccfg)(struct net_device___102 *, int, u8 *);
	u8 (*setall)(struct net_device___102 *);
	u8 (*getcap)(struct net_device___102 *, int, u8 *);
	int (*getnumtcs)(struct net_device___102 *, int, u8 *);
	int (*setnumtcs)(struct net_device___102 *, int, u8);
	u8 (*getpfcstate)(struct net_device___102 *);
	void (*setpfcstate)(struct net_device___102 *, u8);
	void (*getbcncfg)(struct net_device___102 *, int, u32 *);
	void (*setbcncfg)(struct net_device___102 *, int, u32);
	void (*getbcnrp)(struct net_device___102 *, int, u8 *);
	void (*setbcnrp)(struct net_device___102 *, int, u8);
	int (*setapp)(struct net_device___102 *, u8, u16, u8);
	int (*getapp)(struct net_device___102 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___102 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___102 *, int, u8);
	u8 (*getdcbx)(struct net_device___102 *);
	u8 (*setdcbx)(struct net_device___102 *, u8);
	int (*peer_getappinfo)(struct net_device___102 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___102 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___102 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___102 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___102 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___102 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___105;

typedef int (*bpf_iter_init_seq_priv_t___104)(void *, struct bpf_iter_aux_info___105 *);

struct bpf_map___105;

struct bpf_iter_aux_info___105 {
	struct bpf_map___105 *map;
};

struct bpf_iter_seq_info___104 {
	const struct seq_operations___268 *seq_ops;
	bpf_iter_init_seq_priv_t___104 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___104 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___105 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___105 *, struct file___293 *);
	void (*map_free)(struct bpf_map___105 *);
	int (*map_get_next_key)(struct bpf_map___105 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___105 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___105 *, void *);
	int (*map_lookup_batch)(struct bpf_map___105 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___105 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___105 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___105 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___105 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___105 *, void *);
	int (*map_update_elem)(struct bpf_map___105 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___105 *, void *);
	int (*map_push_elem)(struct bpf_map___105 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___105 *, void *);
	int (*map_peek_elem)(struct bpf_map___105 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___105 *, struct file___293 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___105 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___105 *, void *, struct seq_file___268 *);
	int (*map_check_btf)(const struct bpf_map___105 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___105 *, struct bpf_prog_aux___105 *);
	void (*map_poke_untrack)(struct bpf_map___105 *, struct bpf_prog_aux___105 *);
	void (*map_poke_run)(struct bpf_map___105 *, u32, struct bpf_prog___96 *, struct bpf_prog___96 *);
	int (*map_direct_value_addr)(const struct bpf_map___105 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___105 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___105 *, struct vm_area_struct___298 *);
	__poll_t (*map_poll)(struct bpf_map___105 *, struct file___293 *, struct poll_table_struct___214 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___105 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___105 *, const struct bpf_map___105 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___105 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___104 *iter_seq_info;
};

struct bpf_map___105 {
	const struct bpf_map_ops___104 *ops;
	struct bpf_map___105 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___158 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___104;

struct bpf_jit_poke_descriptor___104;

struct bpf_prog_ops___96;

struct btf_mod_pair___104;

struct bpf_prog_offload___102;

struct bpf_prog_aux___105 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___96 *dst_prog;
	struct bpf_trampoline___104 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___96 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___104 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___96 *ops;
	struct bpf_map___105 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___104 *used_btfs;
	struct bpf_prog___96 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___105 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___102 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___102;

struct bpf_map_dev_ops___102 {
	int (*map_get_next_key)(struct bpf_offloaded_map___102 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___102 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___102 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___102 *, void *);
};

struct bpf_offloaded_map___102 {
	struct bpf_map___105 map;
	struct net_device___102 *netdev;
	const struct bpf_map_dev_ops___102 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___96 {
	int (*test_run)(struct bpf_prog___96 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___102 {
	struct bpf_prog___96 *prog;
	struct net_device___102 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___104 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___96 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___277 *mod;
};

struct bpf_jit_poke_descriptor___104 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___105 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___104 {
	struct btf *btf;
	struct module___277 *module;
};

struct cftype___220;

struct cgroup_subsys___220 {
	struct cgroup_subsys_state___220 * (*css_alloc)(struct cgroup_subsys_state___220 *);
	int (*css_online)(struct cgroup_subsys_state___220 *);
	void (*css_offline)(struct cgroup_subsys_state___220 *);
	void (*css_released)(struct cgroup_subsys_state___220 *);
	void (*css_free)(struct cgroup_subsys_state___220 *);
	void (*css_reset)(struct cgroup_subsys_state___220 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___220 *, int);
	int (*css_extra_stat_show)(struct seq_file___268 *, struct cgroup_subsys_state___220 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___300 *, struct css_set___220 *);
	void (*cancel_fork)(struct task_struct___300 *, struct css_set___220 *);
	void (*fork)(struct task_struct___300 *);
	void (*exit)(struct task_struct___300 *);
	void (*release)(struct task_struct___300 *);
	void (*bind)(struct cgroup_subsys_state___220 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___220 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___220 *dfl_cftypes;
	struct cftype___220 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___220 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___220 *updated_children;
	struct cgroup___220 *updated_next;
};

struct cgroup_root___220 {
	struct kernfs_root___281 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___220 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___220 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___220 *ss;
	struct list_head node;
	struct kernfs_ops___281 *kf_ops;
	int (*open)(struct kernfs_open_file___281 *);
	void (*release)(struct kernfs_open_file___281 *);
	u64 (*read_u64)(struct cgroup_subsys_state___220 *, struct cftype___220 *);
	s64 (*read_s64)(struct cgroup_subsys_state___220 *, struct cftype___220 *);
	int (*seq_show)(struct seq_file___268 *, void *);
	void * (*seq_start)(struct seq_file___268 *, loff_t *);
	void * (*seq_next)(struct seq_file___268 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___268 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___220 *, struct cftype___220 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___220 *, struct cftype___220 *, s64);
	ssize_t (*write)(struct kernfs_open_file___281 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___281 *, struct poll_table_struct___214 *);
};

struct xdp_rxq_info___102 {
	struct net_device___102 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___102 {
	struct net_device___102 *dev;
};

struct xdp_buff___102 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___102 *rxq;
	struct xdp_txq_info___102 *txq;
	u32 frame_sz;
};

struct xdp_frame___102 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___102 *dev_rx;
};

struct header_ops___102 {
	int (*create)(struct sk_buff___103 *, struct net_device___102 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___103 *, unsigned char *);
	int (*cache)(const struct neighbour___89 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___102 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___103 *);
};

struct netdev_queue___102 {
	struct net_device___102 *dev;
	struct Qdisc___96 *qdisc;
	struct Qdisc___96 *qdisc_sleeping;
	struct kobject___281 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___102 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___96 {
	struct sk_buff___103 *head;
	struct sk_buff___103 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___96;

struct Qdisc___96 {
	int (*enqueue)(struct sk_buff___103 *, struct Qdisc___96 *, struct sk_buff___103 **);
	struct sk_buff___103 * (*dequeue)(struct Qdisc___96 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___96 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___102 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___102 gso_skb;
	struct qdisc_skb_head___96 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___96 *next_sched;
	struct sk_buff_head___102 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___102 {
	struct xdp_rxq_info___102 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___281 kobj;
	struct net_device___102 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___102 {
	enum net_device_path_type type;
	const struct net_device___102 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___102 = 0,
				DEV_PATH_BR_VLAN_TAG___102 = 1,
				DEV_PATH_BR_VLAN_UNTAG___102 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___102 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___102 {
	const struct net_device___102 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___102 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___96 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___102 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___102 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___103 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___102 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___102 *dev;
	const char *name;
};

struct net_device_ops___102 {
	int (*ndo_init)(struct net_device___102 *);
	void (*ndo_uninit)(struct net_device___102 *);
	int (*ndo_open)(struct net_device___102 *);
	int (*ndo_stop)(struct net_device___102 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___103 *, struct net_device___102 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___103 *, struct net_device___102 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___102 *, struct sk_buff___103 *, struct net_device___102 *);
	void (*ndo_change_rx_flags)(struct net_device___102 *, int);
	void (*ndo_set_rx_mode)(struct net_device___102 *);
	int (*ndo_set_mac_address)(struct net_device___102 *, void *);
	int (*ndo_validate_addr)(struct net_device___102 *);
	int (*ndo_do_ioctl)(struct net_device___102 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___102 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___102 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___102 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___102 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___102 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___102 *, int);
	int (*ndo_neigh_setup)(struct net_device___102 *, struct neigh_parms___89 *);
	void (*ndo_tx_timeout)(struct net_device___102 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___102 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___102 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___102 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___102 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___102 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___102 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___102 *);
	int (*ndo_netpoll_setup)(struct net_device___102 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___102 *);
	int (*ndo_set_vf_mac)(struct net_device___102 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___102 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___102 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___102 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___102 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___102 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___102 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___102 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___102 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___102 *, int, struct sk_buff___103 *);
	int (*ndo_get_vf_guid)(struct net_device___102 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___102 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___102 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___102 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___102 *);
	int (*ndo_fcoe_disable)(struct net_device___102 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___102 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___102 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___102 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___102 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___102 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___102 *, const struct sk_buff___103 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___102 *, struct net_device___102 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___102 *, struct net_device___102 *);
	struct net_device___102 * (*ndo_get_xmit_slave)(struct net_device___102 *, struct sk_buff___103 *, bool);
	struct net_device___102 * (*ndo_sk_get_lower_dev)(struct net_device___102 *, struct sock___89 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___102 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___102 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___102 *, struct neighbour___89 *);
	void (*ndo_neigh_destroy)(struct net_device___102 *, struct neighbour___89 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___102 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___102 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___103 *, struct netlink_callback___102 *, struct net_device___102 *, struct net_device___102 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___103 *, struct nlattr **, struct net_device___102 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___102 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___103 *, u32, u32, struct net_device___102 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___102 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___102 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___102 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___102 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___102 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___102 *, struct net_device___102 *);
	void (*ndo_dfwd_del_station)(struct net_device___102 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___102 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___102 *);
	int (*ndo_change_proto_down)(struct net_device___102 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___102 *, struct sk_buff___103 *);
	void (*ndo_set_rx_headroom)(struct net_device___102 *, int);
	int (*ndo_bpf)(struct net_device___102 *, struct netdev_bpf___102 *);
	int (*ndo_xdp_xmit)(struct net_device___102 *, int, struct xdp_frame___102 **, u32);
	struct net_device___102 * (*ndo_xdp_get_xmit_slave)(struct net_device___102 *, struct xdp_buff___102 *);
	int (*ndo_xsk_wakeup)(struct net_device___102 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___102 *);
	int (*ndo_tunnel_ctl)(struct net_device___102 *, struct ip_tunnel_parm *, int);
	struct net_device___102 * (*ndo_get_peer_dev)(struct net_device___102 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___102 *, struct net_device_path___102 *);
};

struct neigh_parms___89 {
	possible_net_t___102 net;
	struct net_device___102 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___89 *);
	struct neigh_table___89 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___89 {
	u32 (*l3mdev_fib_table)(const struct net_device___102 *);
	struct sk_buff___103 * (*l3mdev_l3_rcv)(struct net_device___102 *, struct sk_buff___103 *, u16);
	struct sk_buff___103 * (*l3mdev_l3_out)(struct net_device___102 *, struct sock___89 *, struct sk_buff___103 *, u16);
	struct dst_entry___89 * (*l3mdev_link_scope_lookup)(const struct net_device___102 *, struct flowi6 *);
};

struct ndisc_ops___71 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___102 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___102 *, struct neighbour___89 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___102 *, u8, struct neighbour___89 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___102 *, struct sk_buff___103 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___107 *, struct net_device___102 *, const struct prefix_info *, struct inet6_dev___71 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___71;

struct ifacaddr6___31;

struct inet6_dev___71 {
	struct net_device___102 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___71 *mc_list;
	struct ifmcaddr6___71 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___102 mc_query_queue;
	struct sk_buff_head___102 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___31 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___89 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___96;

struct tcf_block___96;

struct mini_Qdisc___96 {
	struct tcf_proto___96 *filter_list;
	struct tcf_block___96 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___96 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___102 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___102 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___107 *, struct net_device___102 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___102 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___102 *, struct list_head *);
	size_t (*get_size)(const struct net_device___102 *);
	int (*fill_info)(struct sk_buff___103 *, const struct net_device___102 *);
	size_t (*get_xstats_size)(const struct net_device___102 *);
	int (*fill_xstats)(struct sk_buff___103 *, const struct net_device___102 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___102 *, struct net_device___102 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___102 *, const struct net_device___102 *);
	int (*fill_slave_info)(struct sk_buff___103 *, const struct net_device___102 *, const struct net_device___102 *);
	struct net___107 * (*get_link_net)(const struct net_device___102 *);
	size_t (*get_linkxstats_size)(const struct net_device___102 *, int);
	int (*fill_linkxstats)(struct sk_buff___103 *, const struct net_device___102 *, int *, int);
};

struct netdev_notifier_info___20 {
	struct net_device___102 *dev;
	struct netlink_ext_ack *extack;
};

struct netdev_notifier_change_info___4 {
	struct netdev_notifier_info___20 info;
	unsigned int flags_changed;
};

struct block_device_operations___184;

struct gendisk___187 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___187 *part0;
	const struct block_device_operations___184 *fops;
	struct request_queue___184 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___170 *bdi;
	struct kobject___281 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___281 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___184 {
	struct bio___184 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___210 *bip_vec;
	struct bio_vec___210 bip_inline_vecs[0];
};

struct blkcg___172;

struct blkg_policy_data___172;

struct blkcg_gq___172 {
	struct request_queue___184 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___172 *blkcg;
	struct blkcg_gq___172 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___172 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___184 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___184(struct request___184 *);

typedef void integrity_complete_fn___184(struct request___184 *, unsigned int);

struct blk_integrity_profile___184 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___184 *prepare_fn;
	integrity_complete_fn___184 *complete_fn;
	const char *name;
};

struct block_device_operations___184 {
	blk_qc_t (*submit_bio)(struct bio___184 *);
	int (*open)(struct block_device___187 *, fmode_t);
	void (*release)(struct gendisk___187 *, fmode_t);
	int (*rw_page)(struct block_device___187 *, sector_t, struct page___298 *, unsigned int);
	int (*ioctl)(struct block_device___187 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___187 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___187 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___187 *);
	int (*getgeo)(struct block_device___187 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___187 *, bool);
	void (*swap_slot_free_notify)(struct block_device___187 *, long unsigned int);
	int (*report_zones)(struct gendisk___187 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___187 *, umode_t *);
	struct module___277 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___187 *, sector_t *);
};

typedef void rq_end_io_fn___184(struct request___184 *, blk_status_t);

struct request___184 {
	struct request_queue___184 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___179 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___184 *bio;
	struct bio___184 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___210 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___184 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___184 *saved_end_io;
		} flush;
	};
	struct gendisk___187 *rq_disk;
	struct block_device___187 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___184 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___179 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___184 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___281 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___293 *debugfs_dir;
	struct dentry___293 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___184;

struct elevator_mq_ops___184 {
	int (*init_sched)(struct request_queue___184 *, struct elevator_type___184 *);
	void (*exit_sched)(struct elevator_queue___184 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___179 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___179 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___179 *);
	bool (*allow_merge)(struct request_queue___184 *, struct request___184 *, struct bio___184 *);
	bool (*bio_merge)(struct request_queue___184 *, struct bio___184 *, unsigned int);
	int (*request_merge)(struct request_queue___184 *, struct request___184 **, struct bio___184 *);
	void (*request_merged)(struct request_queue___184 *, struct request___184 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___184 *, struct request___184 *, struct request___184 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___184 *);
	void (*finish_request)(struct request___184 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___179 *, struct list_head *, bool);
	struct request___184 * (*dispatch_request)(struct blk_mq_hw_ctx___179 *);
	bool (*has_work)(struct blk_mq_hw_ctx___179 *);
	void (*completed_request)(struct request___184 *, u64);
	void (*requeue_request)(struct request___184 *);
	struct request___184 * (*former_request)(struct request_queue___184 *, struct request___184 *);
	struct request___184 * (*next_request)(struct request_queue___184 *, struct request___184 *);
	void (*init_icq)(struct io_cq___184 *);
	void (*exit_icq)(struct io_cq___184 *);
};

struct elv_fs_entry___184;

struct elevator_type___184 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___184 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___184 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___277 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___184 {
	struct elevator_type___184 *type;
	void *elevator_data;
	struct kobject___281 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___184 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___184 *, char *);
	ssize_t (*store)(struct elevator_queue___184 *, const char *, size_t);
};

struct blk_mq_queue_data___179;

struct blk_mq_ops___179 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___179 *, const struct blk_mq_queue_data___179 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___179 *);
	int (*get_budget)(struct request_queue___184 *);
	void (*put_budget)(struct request_queue___184 *, int);
	void (*set_rq_budget_token)(struct request___184 *, int);
	int (*get_rq_budget_token)(struct request___184 *);
	enum blk_eh_timer_return (*timeout)(struct request___184 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___179 *);
	void (*complete)(struct request___184 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___179 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___179 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___179 *, struct request___184 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___179 *, struct request___184 *, unsigned int);
	void (*initialize_rq_fn)(struct request___184 *);
	void (*cleanup_rq)(struct request___184 *);
	bool (*busy)(struct request_queue___184 *);
	int (*map_queues)(struct blk_mq_tag_set___179 *);
	void (*show_rq)(struct seq_file___268 *, struct request___184 *);
};

struct blk_mq_tag_set___179 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___179 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___179 {
	struct request___184 *rq;
	bool last;
};

struct blkcg_policy_data___172;

struct blkcg___172 {
	struct cgroup_subsys_state___220 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___172 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___172 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___172 {
	struct blkcg___172 *blkcg;
	int plid;
};

struct blkg_policy_data___172 {
	struct blkcg_gq___172 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___158 {
	struct mem_cgroup___158 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___158 {
	struct lruvec___166 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___158 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___158 *memcg;
};

struct obj_cgroup___158 {
	struct percpu_ref refcnt;
	struct mem_cgroup___158 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct nduseroptmsg {
	unsigned char nduseropt_family;
	unsigned char nduseropt_pad1;
	short unsigned int nduseropt_opts_len;
	int nduseropt_ifindex;
	__u8 nduseropt_icmp_type;
	__u8 nduseropt_icmp_code;
	short unsigned int nduseropt_pad2;
	unsigned int nduseropt_pad3;
};

enum {
	NDUSEROPT_UNSPEC = 0,
	NDUSEROPT_SRCADDR = 1,
	__NDUSEROPT_MAX = 2,
};

struct gnet_dump___96 {
	spinlock_t *lock;
	struct sk_buff___103 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___96;

struct Qdisc_ops___96 {
	struct Qdisc_ops___96 *next;
	const struct Qdisc_class_ops___96 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___103 *, struct Qdisc___96 *, struct sk_buff___103 **);
	struct sk_buff___103 * (*dequeue)(struct Qdisc___96 *);
	struct sk_buff___103 * (*peek)(struct Qdisc___96 *);
	int (*init)(struct Qdisc___96 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___96 *);
	void (*destroy)(struct Qdisc___96 *);
	int (*change)(struct Qdisc___96 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___96 *);
	int (*change_tx_queue_len)(struct Qdisc___96 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___96 *, unsigned int);
	int (*dump)(struct Qdisc___96 *, struct sk_buff___103 *);
	int (*dump_stats)(struct Qdisc___96 *, struct gnet_dump___96 *);
	void (*ingress_block_set)(struct Qdisc___96 *, u32);
	void (*egress_block_set)(struct Qdisc___96 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___96 *);
	u32 (*egress_block_get)(struct Qdisc___96 *);
	struct module___277 *owner;
};

struct Qdisc_class_ops___96 {
	unsigned int flags;
	struct netdev_queue___102 * (*select_queue)(struct Qdisc___96 *, struct tcmsg *);
	int (*graft)(struct Qdisc___96 *, long unsigned int, struct Qdisc___96 *, struct Qdisc___96 **, struct netlink_ext_ack *);
	struct Qdisc___96 * (*leaf)(struct Qdisc___96 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___96 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___96 *, u32);
	int (*change)(struct Qdisc___96 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___96 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___96 *, struct qdisc_walker *);
	struct tcf_block___96 * (*tcf_block)(struct Qdisc___96 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___96 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___96 *, long unsigned int);
	int (*dump)(struct Qdisc___96 *, long unsigned int, struct sk_buff___103 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___96 *, long unsigned int, struct gnet_dump___96 *);
};

struct tcf_chain___96;

struct tcf_block___96 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___107 *net;
	struct Qdisc___96 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___96 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___96;

struct tcf_proto_ops___96;

struct tcf_proto___96 {
	struct tcf_proto___96 *next;
	void *root;
	int (*classify)(struct sk_buff___103 *, const struct tcf_proto___96 *, struct tcf_result___96 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___96 *ops;
	struct tcf_chain___96 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___96 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___96 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___96 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___103 *, const struct tcf_proto___96 *, struct tcf_result___96 *);
	int (*init)(struct tcf_proto___96 *);
	void (*destroy)(struct tcf_proto___96 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___96 *, u32);
	void (*put)(struct tcf_proto___96 *, void *);
	int (*change)(struct net___107 *, struct sk_buff___103 *, struct tcf_proto___96 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___96 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___96 *);
	void (*walk)(struct tcf_proto___96 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___96 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___96 *, void *);
	void (*hw_del)(struct tcf_proto___96 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___107 *, struct tcf_chain___96 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___107 *, struct tcf_proto___96 *, void *, struct sk_buff___103 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___107 *, struct tcf_proto___96 *, void *, struct sk_buff___103 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___103 *, struct net___107 *, void *);
	struct module___277 *owner;
	int flags;
};

struct tcf_chain___96 {
	struct mutex filter_chain_lock;
	struct tcf_proto___96 *filter_chain;
	struct list_head list;
	struct tcf_block___96 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___96 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___89 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___96 *prog;
};

struct pneigh_entry___89;

struct neigh_hash_table___89;

struct neigh_table___89 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___102 *, __u32 *);
	bool (*key_eq)(const struct neighbour___89 *, const void *);
	int (*constructor)(struct neighbour___89 *);
	int (*pconstructor)(struct pneigh_entry___89 *);
	void (*pdestructor)(struct pneigh_entry___89 *);
	void (*proxy_redo)(struct sk_buff___103 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___102 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___89 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___102 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___89 *nht;
	struct pneigh_entry___89 **phash_buckets;
};

struct neigh_ops___89 {
	int family;
	void (*solicit)(struct neighbour___89 *, struct sk_buff___103 *);
	void (*error_report)(struct neighbour___89 *, struct sk_buff___103 *);
	int (*output)(struct neighbour___89 *, struct sk_buff___103 *);
	int (*connected_output)(struct neighbour___89 *, struct sk_buff___103 *);
};

struct pneigh_entry___89 {
	struct pneigh_entry___89 *next;
	possible_net_t___102 net;
	struct net_device___102 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___89 {
	struct neighbour___89 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___65 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___107 *, struct sock___89 *, struct sk_buff___103 *);
	int (*orig_input)(struct sk_buff___103 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___89 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___89 *ctarget;
	struct net___107 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___89 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___89 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___74;

struct timewait_sock_ops___73;

struct proto___89 {
	void (*close)(struct sock___89 *, long int);
	int (*pre_connect)(struct sock___89 *, struct sockaddr *, int);
	int (*connect)(struct sock___89 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___89 *, int);
	struct sock___89 * (*accept)(struct sock___89 *, int, int *, bool);
	int (*ioctl)(struct sock___89 *, int, long unsigned int);
	int (*init)(struct sock___89 *);
	void (*destroy)(struct sock___89 *);
	void (*shutdown)(struct sock___89 *, int);
	int (*setsockopt)(struct sock___89 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___89 *, int, int, char *, int *);
	void (*keepalive)(struct sock___89 *, int);
	int (*compat_ioctl)(struct sock___89 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___89 *, struct msghdr___91 *, size_t);
	int (*recvmsg)(struct sock___89 *, struct msghdr___91 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___89 *, struct page___298 *, int, size_t, int);
	int (*bind)(struct sock___89 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___89 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___89 *, struct sk_buff___103 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___89 *);
	int (*hash)(struct sock___89 *);
	void (*unhash)(struct sock___89 *);
	void (*rehash)(struct sock___89 *);
	int (*get_port)(struct sock___89 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___89 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___89 *, int);
	bool (*sock_is_readable)(struct sock___89 *);
	void (*enter_memory_pressure)(struct sock___89 *);
	void (*leave_memory_pressure)(struct sock___89 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___74 *rsk_prot;
	struct timewait_sock_ops___73 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___277 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___89 *, int);
};

struct sock_reuseport___37 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___96 *prog;
	struct sock___89 *socks[0];
};

struct request_sock___75;

struct request_sock_ops___74 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___89 *, struct request_sock___75 *);
	void (*send_ack)(const struct sock___89 *, struct sk_buff___103 *, struct request_sock___75 *);
	void (*send_reset)(const struct sock___89 *, struct sk_buff___103 *);
	void (*destructor)(struct request_sock___75 *);
	void (*syn_ack_timeout)(const struct request_sock___75 *);
};

struct timewait_sock_ops___73 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___89 *, struct sock___89 *, void *);
	void (*twsk_destructor)(struct sock___89 *);
};

struct request_sock___75 {
	struct sock_common___89 __req_common;
	struct request_sock___75 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___74 *rsk_ops;
	struct sock___89 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___24 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___89 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___24 {
	struct inet_cork___24 base;
	struct flowi fl;
};

struct ipv6_pinfo___23;

struct inet_sock___24 {
	struct sock___89 sk;
	struct ipv6_pinfo___23 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___24 cork;
};

struct ipv6_fl_socklist___23;

struct ipv6_pinfo___23 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___23 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___103 *pktoptions;
	struct sk_buff___103 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___23;

struct ipv6_fl_socklist___23 {
	struct ipv6_fl_socklist___23 *next;
	struct ip6_flowlabel___23 *fl;
	struct callback_head rcu;
};

struct inet6_ifaddr___4 {
	struct in6_addr addr;
	__u32 prefix_len;
	__u32 rt_priority;
	__u32 valid_lft;
	__u32 prefered_lft;
	refcount_t refcnt;
	spinlock_t lock;
	int state;
	__u32 flags;
	__u8 dad_probes;
	__u8 stable_privacy_retry;
	__u16 scope;
	__u64 dad_nonce;
	long unsigned int cstamp;
	long unsigned int tstamp;
	struct delayed_work dad_work;
	struct inet6_dev___71 *idev;
	struct fib6_info___31 *rt;
	struct hlist_node addr_lst;
	struct list_head if_list;
	struct list_head tmp_list;
	struct inet6_ifaddr___4 *ifpub;
	int regen_count;
	bool tokenized;
	struct callback_head rcu;
	struct in6_addr peer_addr;
};

struct ifmcaddr6___71 {
	struct in6_addr mca_addr;
	struct inet6_dev___71 *idev;
	struct ifmcaddr6___71 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___31 {
	struct in6_addr aca_addr;
	struct fib6_info___31 *aca_rt;
	struct ifacaddr6___31 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct nd_msg {
	struct icmp6hdr icmph;
	struct in6_addr target;
	__u8 opt[0];
};

struct rs_msg {
	struct icmp6hdr icmph;
	__u8 opt[0];
};

struct ra_msg {
	struct icmp6hdr icmph;
	__be32 reachable_time;
	__be32 retrans_timer;
};

struct ip6_flowlabel___23 {
	struct ip6_flowlabel___23 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___270 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___107 *fl_net;
};

struct fib_nh_exception___31 {
	struct fib_nh_exception___31 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___33 *fnhe_rth_input;
	struct rtable___33 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___33 {
	struct dst_entry___89 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___31 {
	struct fib_nh_exception___31 *chain;
};

struct fib_info___21;

struct fib_nh___21 {
	struct fib_nh_common___31 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___21 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___21 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___107 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___21 *nh;
	struct callback_head rcu;
	struct fib_nh___21 fib_nh[0];
};

struct nh_info___21;

struct nh_group___21;

struct nexthop___21 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___107 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___21 *nh_info;
		struct nh_group___21 *nh_grp;
	};
};

struct nh_info___21 {
	struct hlist_node dev_hash;
	struct nexthop___21 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___31 fib_nhc;
		struct fib_nh___21 fib_nh;
		struct fib6_nh___31 fib6_nh;
	};
};

struct nh_grp_entry___21;

struct nh_res_bucket___21 {
	struct nh_grp_entry___21 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___21 {
	struct nexthop___21 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___21 *nh_parent;
};

struct nh_res_table___21 {
	struct net___107 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___21 nh_buckets[0];
};

struct nh_group___21 {
	struct nh_group___21 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___21 *res_table;
	struct nh_grp_entry___21 nh_entries[0];
};

struct nf_hook_state___20 {
	u8 hook;
	u8 pf;
	struct net_device___102 *in;
	struct net_device___102 *out;
	struct sock___89 *sk;
	struct net___107 *net;
	int (*okfn)(struct net___107 *, struct sock___89 *, struct sk_buff___103 *);
};

typedef struct bio_vec___209 skb_frag_t___40;

struct inet6_protocol___3 {
	void (*early_demux)(struct sk_buff___102 *);
	void (*early_demux_handler)(struct sk_buff___102 *);
	int (*handler)(struct sk_buff___102 *);
	int (*err_handler)(struct sk_buff___102 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct ip6_tnl_encap_ops___2 {
	size_t (*encap_hlen)(struct ip_tunnel_encap *);
	int (*build_header)(struct sk_buff___102 *, struct ip_tunnel_encap *, u8 *, struct flowi6 *);
	int (*err_handler)(struct sk_buff___102 *, struct inet6_skb_parm *, u8, u8, int, __be32);
};

struct dentry___294;

struct super_block___294;

struct module___278;

struct file_system_type___294 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___294 * (*mount)(struct file_system_type___294 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___294 *);
	struct module___278 *owner;
	struct file_system_type___294 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___294;

struct kiocb___294;

struct iov_iter___214;

struct poll_table_struct___215;

struct vm_area_struct___299;

struct inode___294;

struct file_lock___294;

struct page___299;

struct pipe_inode_info___135;

struct seq_file___269;

struct file_operations___295 {
	struct module___278 *owner;
	loff_t (*llseek)(struct file___294 *, loff_t, int);
	ssize_t (*read)(struct file___294 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___294 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___294 *, struct iov_iter___214 *);
	ssize_t (*write_iter)(struct kiocb___294 *, struct iov_iter___214 *);
	int (*iopoll)(struct kiocb___294 *, bool);
	int (*iterate)(struct file___294 *, struct dir_context *);
	int (*iterate_shared)(struct file___294 *, struct dir_context *);
	__poll_t (*poll)(struct file___294 *, struct poll_table_struct___215 *);
	long int (*unlocked_ioctl)(struct file___294 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___294 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___294 *, struct vm_area_struct___299 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___294 *, struct file___294 *);
	int (*flush)(struct file___294 *, fl_owner_t);
	int (*release)(struct inode___294 *, struct file___294 *);
	int (*fsync)(struct file___294 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___294 *, int);
	int (*lock)(struct file___294 *, int, struct file_lock___294 *);
	ssize_t (*sendpage)(struct file___294 *, struct page___299 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___294 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___294 *, long unsigned int);
	int (*flock)(struct file___294 *, int, struct file_lock___294 *);
	ssize_t (*splice_write)(struct pipe_inode_info___135 *, struct file___294 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___294 *, loff_t *, struct pipe_inode_info___135 *, size_t, unsigned int);
	int (*setlease)(struct file___294 *, long int, struct file_lock___294 **, void **);
	long int (*fallocate)(struct file___294 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___269 *, struct file___294 *);
	ssize_t (*copy_file_range)(struct file___294 *, loff_t, struct file___294 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___294 *, loff_t, struct file___294 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___294 *, loff_t, loff_t, int);
};

struct bio_vec___211 {
	struct page___299 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___294;

struct pipe_buffer___135;

struct pipe_inode_info___135 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___299 *tmp_page;
	struct fasync_struct___294 *fasync_readers;
	struct fasync_struct___294 *fasync_writers;
	struct pipe_buffer___135 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___214 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___211 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___135 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___92 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___214 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___294 *msg_iocb;
};

struct kiocb___294 {
	struct file___294 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___294 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct vmacache___299 {
	u64 seqnum;
	struct vm_area_struct___299 *vmas[4];
};

struct page_frag___299 {
	struct page___299 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___300;

struct pid___271;

struct nsproxy___280;

struct signal_struct___295;

struct bio_list___185;

struct backing_dev_info___171;

struct io_context___185;

struct css_set___221;

struct mem_cgroup___159;

struct request_queue___185;

struct vm_struct___277;

struct task_struct___301 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___301 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___300 *mm;
	struct mm_struct___300 *active_mm;
	struct vmacache___299 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___301 *real_parent;
	struct task_struct___301 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___301 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___271 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___280 *nsproxy;
	struct signal_struct___295 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___301 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___185 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___171 *backing_dev_info;
	struct io_context___185 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___221 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___135 *splice_pipe;
	struct page_frag___299 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___159 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___159 *active_memcg;
	struct request_queue___185 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___301 *oom_reaper_list;
	struct vm_struct___277 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___282;

struct kobj_type___282;

struct kernfs_node___282;

struct kobject___282 {
	const char *name;
	struct list_head entry;
	struct kobject___282 *parent;
	struct kset___282 *kset;
	struct kobj_type___282 *ktype;
	struct kernfs_node___282 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___279 {
	struct kobject___282 kobj;
	struct module___278 *mod;
	struct kobject___282 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___278 {
	struct module___278 *mod;
	struct latch_tree_node node;
};

struct module_layout___278 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___278 mtn;
};

struct module_attribute___278;

struct kernel_param___278;

struct module___278 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___279 mkobj;
	struct module_attribute___278 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___282 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___278 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___278 core_layout;
	struct module_layout___278 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

typedef struct page___299 *pgtable_t___299;

struct address_space___294;

struct page_pool___123;

struct dev_pagemap___289;

struct page___299 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___294 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___123 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___299 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___299 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___300 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___289 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___289;

struct vm_area_struct___299 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___299 *vm_next;
	struct vm_area_struct___299 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___300 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___289 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___294 *vm_file;
	struct file___294 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___299;

struct mm_struct___300 {
	struct {
		struct vm_area_struct___299 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___294 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___299 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___301 *owner;
		struct user_namespace___26 *user_ns;
		struct file___294 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___294;

struct address_space___294 {
	struct inode___294 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___294 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___275;

struct page_pool_params___123 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___275 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___123 {
	u32 count;
	struct page___299 *cache[128];
};

struct page_pool___123 {
	struct page_pool_params___123 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___299 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___123 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___289;

struct dev_pagemap___289 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___289 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___294;

struct path___294 {
	struct vfsmount___294 *mnt;
	struct dentry___294 *dentry;
};

struct fown_struct___271 {
	rwlock_t lock;
	struct pid___271 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___294 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___294 f_path;
	struct inode___294 *f_inode;
	const struct file_operations___295 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___271 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___294 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___289;

struct vm_operations_struct___289 {
	void (*open)(struct vm_area_struct___299 *);
	void (*close)(struct vm_area_struct___299 *);
	int (*may_split)(struct vm_area_struct___299 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___299 *);
	int (*mprotect)(struct vm_area_struct___299 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___289 *);
	vm_fault_t (*huge_fault)(struct vm_fault___289 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___289 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___299 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___289 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___289 *);
	int (*access)(struct vm_area_struct___299 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___299 *);
	int (*set_policy)(struct vm_area_struct___299 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___299 *, long unsigned int);
	struct page___299 * (*find_special_page)(struct vm_area_struct___299 *, long unsigned int);
};

struct core_thread___299 {
	struct task_struct___301 *task;
	struct core_thread___299 *next;
};

struct core_state___299 {
	atomic_t nr_threads;
	struct core_thread___299 dumper;
	struct completion startup;
};

struct vm_fault___289 {
	const struct {
		struct vm_area_struct___299 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___299 *cow_page;
	struct page___299 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___299 prealloc_pte;
};

struct pglist_data___167;

struct lruvec___167 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___167 *pgdat;
};

struct zone___167 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___167 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___167 {
	struct zone___167 *zone;
	int zone_idx;
};

struct zonelist___167 {
	struct zoneref___167 _zonerefs[321];
};

struct pglist_data___167 {
	struct zone___167 node_zones[5];
	struct zonelist___167 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___301 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___301 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___167 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct pid_namespace___271;

struct upid___271 {
	int nr;
	struct pid_namespace___271 *ns;
};

struct pid_namespace___271 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___301 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___271 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___271 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___271 numbers[1];
};

struct signal_struct___295 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___301 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___301 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___271 *pids[4];
	struct pid___271 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___300 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct net___108;

struct cgroup_namespace___221;

struct nsproxy___280 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___271 *pid_ns_for_children;
	struct net___108 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___221 *cgroup_ns;
};

struct bio___185;

struct bio_list___185 {
	struct bio___185 *head;
	struct bio___185 *tail;
};

struct cgroup_subsys_state___221;

struct bdi_writeback___171 {
	struct backing_dev_info___171 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___221 *memcg_css;
	struct cgroup_subsys_state___221 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___171 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___171 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___275 *dev;
	char dev_name[64];
	struct device___275 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___294 *debug_dir;
};

struct io_cq___185;

struct io_context___185 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___185 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___221;

struct css_set___221 {
	struct cgroup_subsys_state___221 *subsys[14];
	refcount_t refcount;
	struct css_set___221 *dom_cset;
	struct cgroup___221 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___221 *mg_src_cgrp;
	struct cgroup___221 *mg_dst_cgrp;
	struct css_set___221 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___221;

struct cgroup_subsys_state___221 {
	struct cgroup___221 *cgroup;
	struct cgroup_subsys___221 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___221 *parent;
};

struct cgroup_file___221 {
	struct kernfs_node___282 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___159;

struct mem_cgroup_per_node___159;

struct mem_cgroup___159 {
	struct cgroup_subsys_state___221 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___221 events_file;
	struct cgroup_file___221 events_local_file;
	struct cgroup_file___221 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___159 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___301 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___159 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___185;

struct blk_integrity___185 {
	const struct blk_integrity_profile___185 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___185 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___185 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___185;

struct elevator_queue___185;

struct blk_mq_ops___180;

struct blk_mq_hw_ctx___180;

struct gendisk___188;

struct blkcg_gq___173;

struct blk_mq_tag_set___180;

struct request_queue___185 {
	struct request___185 *last_merge;
	struct elevator_queue___185 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___180 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___180 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___188 *disk;
	struct kobject___282 kobj;
	struct kobject___282 *mq_kobj;
	struct blk_integrity___185 integrity;
	struct device___275 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___173 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___180 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___185 bio_split;
	struct dentry___294 *debugfs_dir;
	struct dentry___294 *sched_debugfs_dir;
	struct dentry___294 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___277 {
	struct vm_struct___277 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___299 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___294;

struct dentry___294 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___294 *d_parent;
	struct qstr d_name;
	struct inode___294 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___294 *d_op;
	struct super_block___294 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___294;

struct inode___294 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___294 *i_op;
	struct super_block___294 *i_sb;
	struct address_space___294 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___171 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___295 *i_fop;
		void (*free_inode)(struct inode___294 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___294 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___135 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___294 {
	int (*d_revalidate)(struct dentry___294 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___294 *, unsigned int);
	int (*d_hash)(const struct dentry___294 *, struct qstr *);
	int (*d_compare)(const struct dentry___294 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___294 *);
	int (*d_init)(struct dentry___294 *);
	void (*d_release)(struct dentry___294 *);
	void (*d_prune)(struct dentry___294 *);
	void (*d_iput)(struct dentry___294 *, struct inode___294 *);
	char * (*d_dname)(struct dentry___294 *, char *, int);
	struct vfsmount___294 * (*d_automount)(struct path___294 *);
	int (*d_manage)(const struct path___294 *, bool);
	struct dentry___294 * (*d_real)(struct dentry___294 *, const struct inode___294 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___294;

struct mem_dqinfo___294 {
	struct quota_format_type___294 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___294;

struct quota_info___294 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___294 *files[3];
	struct mem_dqinfo___294 info[3];
	const struct quota_format_ops___294 *ops[3];
};

struct rcuwait___295 {
	struct task_struct___301 *task;
};

struct percpu_rw_semaphore___295 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___295 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___294 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___295 rw_sem[3];
};

struct shrink_control___159;

struct shrinker___159 {
	long unsigned int (*count_objects)(struct shrinker___159 *, struct shrink_control___159 *);
	long unsigned int (*scan_objects)(struct shrinker___159 *, struct shrink_control___159 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___294;

struct dquot_operations___294;

struct quotactl_ops___294;

struct block_device___188;

struct super_block___294 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___294 *s_type;
	const struct super_operations___294 *s_op;
	const struct dquot_operations___294 *dq_op;
	const struct quotactl_ops___294 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___294 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___188 *s_bdev;
	struct backing_dev_info___171 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___294 s_dquot;
	struct sb_writers___294 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___294 *s_d_op;
	int cleancache_poolid;
	struct shrinker___159 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___294 {
	struct dentry___294 *mnt_root;
	struct super_block___294 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___159 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___159 *memcg;
};

struct psi_group___221 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___301 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___97;

struct cgroup_bpf___97 {
	struct bpf_prog_array___97 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___97 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___221;

struct cgroup_rstat_cpu___221;

struct cgroup___221 {
	struct cgroup_subsys_state___221 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___282 *kn;
	struct cgroup_file___221 procs_file;
	struct cgroup_file___221 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___221 *subsys[14];
	struct cgroup_root___221 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___221 *dom_cgrp;
	struct cgroup___221 *old_dom_cgrp;
	struct cgroup_rstat_cpu___221 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___221 psi;
	struct cgroup_bpf___97 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___185 {
	struct request_queue___185 *q;
	struct io_context___185 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___294 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___294 *ia_file;
};

struct dquot___294 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___294 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___294 {
	int qf_fmt_id;
	const struct quota_format_ops___294 *qf_ops;
	struct module___278 *qf_owner;
	struct quota_format_type___294 *qf_next;
};

struct quota_format_ops___294 {
	int (*check_quota_file)(struct super_block___294 *, int);
	int (*read_file_info)(struct super_block___294 *, int);
	int (*write_file_info)(struct super_block___294 *, int);
	int (*free_file_info)(struct super_block___294 *, int);
	int (*read_dqblk)(struct dquot___294 *);
	int (*commit_dqblk)(struct dquot___294 *);
	int (*release_dqblk)(struct dquot___294 *);
	int (*get_next_id)(struct super_block___294 *, struct kqid *);
};

struct dquot_operations___294 {
	int (*write_dquot)(struct dquot___294 *);
	struct dquot___294 * (*alloc_dquot)(struct super_block___294 *, int);
	void (*destroy_dquot)(struct dquot___294 *);
	int (*acquire_dquot)(struct dquot___294 *);
	int (*release_dquot)(struct dquot___294 *);
	int (*mark_dirty)(struct dquot___294 *);
	int (*write_info)(struct super_block___294 *, int);
	qsize_t * (*get_reserved_space)(struct inode___294 *);
	int (*get_projid)(struct inode___294 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___294 *, qsize_t *);
	int (*get_next_id)(struct super_block___294 *, struct kqid *);
};

struct quotactl_ops___294 {
	int (*quota_on)(struct super_block___294 *, int, int, const struct path___294 *);
	int (*quota_off)(struct super_block___294 *, int);
	int (*quota_enable)(struct super_block___294 *, unsigned int);
	int (*quota_disable)(struct super_block___294 *, unsigned int);
	int (*quota_sync)(struct super_block___294 *, int);
	int (*set_info)(struct super_block___294 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___294 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___294 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___294 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___294 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___294 *, unsigned int);
};

struct writeback_control___171;

struct address_space_operations___294 {
	int (*writepage)(struct page___299 *, struct writeback_control___171 *);
	int (*readpage)(struct file___294 *, struct page___299 *);
	int (*writepages)(struct address_space___294 *, struct writeback_control___171 *);
	int (*set_page_dirty)(struct page___299 *);
	int (*readpages)(struct file___294 *, struct address_space___294 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___294 *, struct address_space___294 *, loff_t, unsigned int, unsigned int, struct page___299 **, void **);
	int (*write_end)(struct file___294 *, struct address_space___294 *, loff_t, unsigned int, unsigned int, struct page___299 *, void *);
	sector_t (*bmap)(struct address_space___294 *, sector_t);
	void (*invalidatepage)(struct page___299 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___299 *, gfp_t);
	void (*freepage)(struct page___299 *);
	ssize_t (*direct_IO)(struct kiocb___294 *, struct iov_iter___214 *);
	int (*migratepage)(struct address_space___294 *, struct page___299 *, struct page___299 *, enum migrate_mode);
	bool (*isolate_page)(struct page___299 *, isolate_mode_t);
	void (*putback_page)(struct page___299 *);
	int (*launder_page)(struct page___299 *);
	int (*is_partially_uptodate)(struct page___299 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___299 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___294 *, struct page___299 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___294 *, sector_t *);
	void (*swap_deactivate)(struct file___294 *);
};

struct writeback_control___171 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___171 *wb;
	struct inode___294 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___294 {
	struct dentry___294 * (*lookup)(struct inode___294 *, struct dentry___294 *, unsigned int);
	const char * (*get_link)(struct dentry___294 *, struct inode___294 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___294 *, int);
	struct posix_acl * (*get_acl)(struct inode___294 *, int, bool);
	int (*readlink)(struct dentry___294 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___294 *, struct dentry___294 *, umode_t, bool);
	int (*link)(struct dentry___294 *, struct inode___294 *, struct dentry___294 *);
	int (*unlink)(struct inode___294 *, struct dentry___294 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___294 *, struct dentry___294 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___294 *, struct dentry___294 *, umode_t);
	int (*rmdir)(struct inode___294 *, struct dentry___294 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___294 *, struct dentry___294 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___294 *, struct dentry___294 *, struct inode___294 *, struct dentry___294 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___294 *, struct iattr___294 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___294 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___294 *, char *, size_t);
	int (*fiemap)(struct inode___294 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___294 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___294 *, struct dentry___294 *, struct file___294 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___294 *, struct dentry___294 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___294 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___294 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___294 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___294 {
	void (*fl_copy_lock)(struct file_lock___294 *, struct file_lock___294 *);
	void (*fl_release_private)(struct file_lock___294 *);
};

struct lock_manager_operations___294;

struct file_lock___294 {
	struct file_lock___294 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___294 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___294 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___294 *fl_ops;
	const struct lock_manager_operations___294 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___294 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___294 *);
	int (*lm_grant)(struct file_lock___294 *, int);
	bool (*lm_break)(struct file_lock___294 *);
	int (*lm_change)(struct file_lock___294 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___294 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___294 *);
};

struct fasync_struct___294 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___294 *fa_next;
	struct file___294 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___294 {
	struct inode___294 * (*alloc_inode)(struct super_block___294 *);
	void (*destroy_inode)(struct inode___294 *);
	void (*free_inode)(struct inode___294 *);
	void (*dirty_inode)(struct inode___294 *, int);
	int (*write_inode)(struct inode___294 *, struct writeback_control___171 *);
	int (*drop_inode)(struct inode___294 *);
	void (*evict_inode)(struct inode___294 *);
	void (*put_super)(struct super_block___294 *);
	int (*sync_fs)(struct super_block___294 *, int);
	int (*freeze_super)(struct super_block___294 *);
	int (*freeze_fs)(struct super_block___294 *);
	int (*thaw_super)(struct super_block___294 *);
	int (*unfreeze_fs)(struct super_block___294 *);
	int (*statfs)(struct dentry___294 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___294 *, int *, char *);
	void (*umount_begin)(struct super_block___294 *);
	int (*show_options)(struct seq_file___269 *, struct dentry___294 *);
	int (*show_devname)(struct seq_file___269 *, struct dentry___294 *);
	int (*show_path)(struct seq_file___269 *, struct dentry___294 *);
	int (*show_stats)(struct seq_file___269 *, struct dentry___294 *);
	ssize_t (*quota_read)(struct super_block___294 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___294 *, int, const char *, size_t, loff_t);
	struct dquot___294 ** (*get_dquots)(struct inode___294 *);
	long int (*nr_cached_objects)(struct super_block___294 *, struct shrink_control___159 *);
	long int (*free_cached_objects)(struct super_block___294 *, struct shrink_control___159 *);
	struct file___294 * (*real_loop)(struct file___294 *);
};

struct wakeup_source___275;

struct dev_pm_info___275 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___275 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___275 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___275;

struct bus_type___275;

struct device_driver___275;

struct dev_pm_domain___275;

struct fwnode_handle___271;

struct class___275;

struct attribute_group___282;

struct device___275 {
	struct kobject___282 kobj;
	struct device___275 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___275 *type;
	struct bus_type___275 *bus;
	struct device_driver___275 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___275 power;
	struct dev_pm_domain___275 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___271 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___275 *class;
	const struct attribute_group___282 **groups;
	void (*release)(struct device___275 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___188 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___294 *bd_inode;
	struct super_block___294 *bd_super;
	void *bd_claiming;
	struct device___275 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___282 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___188 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___294 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___223)(struct file___294 *, wait_queue_head_t *, struct poll_table_struct___215 *);

struct poll_table_struct___215 {
	poll_queue_proc___223 _qproc;
	__poll_t _key;
};

struct seq_operations___269;

struct seq_file___269 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___269 *op;
	int poll_event;
	const struct file___294 *file;
	void *private;
};

typedef void bio_end_io_t___185(struct bio___185 *);

struct bio_integrity_payload___185;

struct bio___185 {
	struct bio___185 *bi_next;
	struct block_device___188 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___185 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___173 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___185 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___211 *bi_io_vec;
	struct bio_set___185 *bi_pool;
	struct bio_vec___211 bi_inline_vecs[0];
};

struct dev_pagemap_ops___289 {
	void (*page_free)(struct page___299 *);
	void (*kill)(struct dev_pagemap___289 *);
	void (*cleanup)(struct dev_pagemap___289 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___289 *);
};

struct socket_wq___91 {
	wait_queue_head_t wait;
	struct fasync_struct___294 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___90;

struct proto_ops___91;

struct socket___92 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___294 *file;
	struct sock___90 *sk;
	const struct proto_ops___91 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___91 wq;
};

typedef struct {
	struct net___108 *net;
} possible_net_t___103;

struct proto___90;

struct sock_common___90 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___90 *skc_prot;
	possible_net_t___103 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___90 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___104;

struct sk_buff_head___103 {
	struct sk_buff___104 *next;
	struct sk_buff___104 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___90 {
	struct cgroup___221 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___90;

struct xfrm_policy___23;

struct dst_entry___90;

struct net_device___103;

struct sock_reuseport___38;

struct sock___90 {
	struct sock_common___90 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___103 sk_error_queue;
	struct sk_buff___104 *sk_rx_skb_cache;
	struct sk_buff_head___103 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___104 *head;
		struct sk_buff___104 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___90 *sk_filter;
	union {
		struct socket_wq___91 *sk_wq;
		struct socket_wq___91 *sk_wq_raw;
	};
	struct xfrm_policy___23 *sk_policy[2];
	struct dst_entry___90 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___90 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___104 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___104 *sk_tx_skb_cache;
	struct sk_buff_head___103 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___299 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___90 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___271 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___92 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___90 sk_cgrp_data;
	struct mem_cgroup___159 *sk_memcg;
	void (*sk_state_change)(struct sock___90 *);
	void (*sk_data_ready)(struct sock___90 *);
	void (*sk_write_space)(struct sock___90 *);
	void (*sk_error_report)(struct sock___90 *);
	int (*sk_backlog_rcv)(struct sock___90 *, struct sk_buff___104 *);
	struct sk_buff___104 * (*sk_validate_xmit_skb)(struct sock___90 *, struct net_device___103 *, struct sk_buff___104 *);
	void (*sk_destruct)(struct sock___90 *);
	struct sock_reuseport___38 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___90)(read_descriptor_t *, struct sk_buff___104 *, unsigned int, size_t);

struct proto_ops___91 {
	int family;
	struct module___278 *owner;
	int (*release)(struct socket___92 *);
	int (*bind)(struct socket___92 *, struct sockaddr *, int);
	int (*connect)(struct socket___92 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___92 *, struct socket___92 *);
	int (*accept)(struct socket___92 *, struct socket___92 *, int, bool);
	int (*getname)(struct socket___92 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___294 *, struct socket___92 *, struct poll_table_struct___215 *);
	int (*ioctl)(struct socket___92 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___92 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___92 *, void *, bool, bool);
	int (*listen)(struct socket___92 *, int);
	int (*shutdown)(struct socket___92 *, int);
	int (*setsockopt)(struct socket___92 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___92 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___269 *, struct socket___92 *);
	int (*sendmsg)(struct socket___92 *, struct msghdr___92 *, size_t);
	int (*recvmsg)(struct socket___92 *, struct msghdr___92 *, size_t, int);
	int (*mmap)(struct file___294 *, struct socket___92 *, struct vm_area_struct___299 *);
	ssize_t (*sendpage)(struct socket___92 *, struct page___299 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___92 *, loff_t *, struct pipe_inode_info___135 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___90 *, int);
	int (*peek_len)(struct socket___92 *);
	int (*read_sock)(struct sock___90 *, read_descriptor_t *, sk_read_actor_t___90);
	int (*sendpage_locked)(struct sock___90 *, struct page___299 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___90 *, struct msghdr___92 *, size_t);
	int (*set_rcvlowat)(struct sock___90 *, int);
};

struct sk_buff___104 {
	union {
		struct {
			struct sk_buff___104 *next;
			struct sk_buff___104 *prev;
			union {
				struct net_device___103 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___90 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___104 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___63;

struct fib_rules_ops___90;

struct fqdir___108;

struct tcp_congestion_ops___36;

struct fib_notifier_ops___90;

struct netns_ipv4___108 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___63 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___90 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___90 *fibnl;
	struct sock___90 **icmp_sk;
	struct sock___90 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___90 **tcp_sk;
	struct fqdir___108 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___36 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___90 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___90 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___90 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___90;

struct dst_ops___108 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___108 *);
	struct dst_entry___90 * (*check)(struct dst_entry___90 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___90 *);
	unsigned int (*mtu)(const struct dst_entry___90 *);
	u32 * (*cow_metrics)(struct dst_entry___90 *, long unsigned int);
	void (*destroy)(struct dst_entry___90 *);
	void (*ifdown)(struct dst_entry___90 *, struct net_device___103 *, int);
	struct dst_entry___90 * (*negative_advice)(struct dst_entry___90 *);
	void (*link_failure)(struct sk_buff___104 *);
	void (*update_pmtu)(struct dst_entry___90 *, struct sock___90 *, struct sk_buff___104 *, u32, bool);
	void (*redirect)(struct dst_entry___90 *, struct sock___90 *, struct sk_buff___104 *);
	int (*local_out)(struct net___108 *, struct sock___90 *, struct sk_buff___104 *);
	struct neighbour___90 * (*neigh_lookup)(const struct dst_entry___90 *, struct sk_buff___104 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___90 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___32;

struct rt6_info___32;

struct fib6_table___32;

struct netns_ipv6___108 {
	struct dst_ops___108 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___108 *fqdir;
	struct fib6_info___32 *fib6_null_entry;
	struct rt6_info___32 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___32 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___32 *ip6_prohibit_entry;
	struct rt6_info___32 *ip6_blk_hole_entry;
	struct fib6_table___32 *fib6_local_tbl;
	struct fib_rules_ops___90 *fib6_rules_ops;
	struct sock___90 **icmp_sk;
	struct sock___90 *ndisc_sk;
	struct sock___90 *tcp_sk;
	struct sock___90 *igmp_sk;
	struct sock___90 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___90 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___90 *notifier_ops;
	struct fib_notifier_ops___90 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___108 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___108 *fqdir;
};

struct netns_sctp___90 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___90 *ctl_sock;
	struct sock___90 *udp4_sock;
	struct sock___90 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___21;

struct netns_nf___21 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___21 *hooks_ipv4[5];
	struct nf_hook_entries___21 *hooks_ipv6[5];
	struct nf_hook_entries___21 *hooks_arp[3];
	struct nf_hook_entries___21 *hooks_bridge[5];
	struct nf_hook_entries___21 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___97;

struct netns_bpf___97 {
	struct bpf_prog_array___97 *run_array[2];
	struct bpf_prog___97 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___108 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___90 *nlsk;
	struct sock___90 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___108 xfrm4_dst_ops;
	struct dst_ops___108 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___108 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___90 *rtnl;
	struct sock___90 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___103 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___108 ipv4;
	struct netns_ipv6___108 ipv6;
	struct netns_ieee802154_lowpan___108 ieee802154_lowpan;
	struct netns_sctp___90 sctp;
	struct netns_nf___21 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___103 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___97 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___108 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___90 *crypto_nlsk;
	struct sock___90 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___108;

struct fqdir___108 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___108 *f;
	struct net___108 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___108;

struct inet_frags___108 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___108 *, const void *);
	void (*destructor)(struct inet_frag_queue___108 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___108 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___104 *fragments_tail;
	struct sk_buff___104 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___108 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___63 {
	struct ip_ra_chain___63 *next;
	struct sock___90 *sk;
	union {
		void (*destructor)(struct sock___90 *);
		struct sock___90 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___90;

struct fib_lookup_arg___90;

struct fib_rules_ops___90 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___90 *, struct flowi *, int, struct fib_lookup_arg___90 *);
	bool (*suppress)(struct fib_rule___90 *, int, struct fib_lookup_arg___90 *);
	int (*match)(struct fib_rule___90 *, struct flowi *, int);
	int (*configure)(struct fib_rule___90 *, struct sk_buff___104 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___90 *);
	int (*compare)(struct fib_rule___90 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___90 *, struct sk_buff___104 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___90 *);
	void (*flush_cache)(struct fib_rules_ops___90 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___278 *owner;
	struct net___108 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___36 {
	u32 (*ssthresh)(struct sock___90 *);
	void (*cong_avoid)(struct sock___90 *, u32, u32);
	void (*set_state)(struct sock___90 *, u8);
	void (*cwnd_event)(struct sock___90 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___90 *, u32);
	void (*pkts_acked)(struct sock___90 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___90 *);
	void (*cong_control)(struct sock___90 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___90 *);
	u32 (*sndbuf_expand)(struct sock___90 *);
	size_t (*get_info)(struct sock___90 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___278 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___90 *);
	void (*release)(struct sock___90 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___90 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___108 *);
	int (*fib_dump)(struct net___108 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___278 *owner;
	struct callback_head rcu;
};

struct xfrm_state___23;

struct lwtunnel_state___66;

struct dst_entry___90 {
	struct net_device___103 *dev;
	struct dst_ops___108 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___23 *xfrm;
	int (*input)(struct sk_buff___104 *);
	int (*output)(struct net___108 *, struct sock___90 *, struct sk_buff___104 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___66 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___103(struct sk_buff___104 **);

struct bpf_xdp_entity___97 {
	struct bpf_prog___97 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___103;

struct net_device_ops___103;

struct l3mdev_ops___90;

struct ndisc_ops___72;

struct xfrmdev_ops___103;

struct header_ops___103;

struct inet6_dev___72;

struct netdev_rx_queue___103;

struct mini_Qdisc___97;

struct netdev_queue___103;

struct Qdisc___97;

struct rtnl_link_ops___97;

struct dcbnl_rtnl_ops___103;

struct net_device___103 {
	char name[16];
	struct netdev_name_node___103 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___103 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___90 *l3mdev_ops;
	const struct ndisc_ops___72 *ndisc_ops;
	const struct xfrmdev_ops___103 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___103 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___282 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___72 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___103 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___97 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___103 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___97 *miniq_ingress;
	struct netdev_queue___103 *ingress_queue;
	struct nf_hook_entries___21 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___103 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___97 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___97 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___103 = 0,
		NETREG_REGISTERED___103 = 1,
		NETREG_UNREGISTERING___103 = 2,
		NETREG_UNREGISTERED___103 = 3,
		NETREG_RELEASED___103 = 4,
		NETREG_DUMMY___103 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___103 = 0,
		RTNL_LINK_INITIALIZING___103 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___103 *);
	struct netpoll_info *npinfo;
	possible_net_t___103 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___275 dev;
	const struct attribute_group___282 *sysfs_groups[4];
	const struct attribute_group___282 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___97 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___103 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___97 xdp_state[3];
	long: 64;
};

struct neigh_table___90;

struct neigh_parms___90;

struct neigh_ops___90;

struct neighbour___90 {
	struct neighbour___90 *next;
	struct neigh_table___90 *tbl;
	struct neigh_parms___90 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___103 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___90 *, struct sk_buff___104 *);
	const struct neigh_ops___90 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___103 *dev;
	u8 primary_key[0];
};

struct icmp6_filter {
	__u32 data[8];
};

struct rtable___34;

struct fnhe_hash_bucket___32;

struct fib_nh_common___32 {
	struct net_device___103 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___66 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___34 **nhc_pcpu_rth_output;
	struct rtable___34 *nhc_rth_input;
	struct fnhe_hash_bucket___32 *nhc_exceptions;
};

struct fib6_nh___32 {
	struct fib_nh_common___32 nh_common;
	long unsigned int last_probe;
	struct rt6_info___32 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___32;

struct nexthop___22;

struct fib6_info___32 {
	struct fib6_table___32 *fib6_table;
	struct fib6_info___32 *fib6_next;
	struct fib6_node___32 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___22 *nh;
	struct fib6_nh___32 fib6_nh[0];
};

struct rt6_info___32 {
	struct dst_entry___90 dst;
	struct fib6_info___32 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___72 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___32 {
	struct fib6_node___32 *parent;
	struct fib6_node___32 *left;
	struct fib6_node___32 *right;
	struct fib6_node___32 *subtree;
	struct fib6_info___32 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___32 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___32 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___32 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___21;

typedef unsigned int nf_hookfn___26(void *, struct sk_buff___104 *, const struct nf_hook_state___21 *);

struct nf_hook_entry___21 {
	nf_hookfn___26 *hook;
	void *priv;
};

struct nf_hook_entries___21 {
	u16 num_hook_entries;
	struct nf_hook_entry___21 hooks[0];
};

struct bpf_prog_array_item___97 {
	struct bpf_prog___97 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___97 {
	struct callback_head rcu;
	struct bpf_prog_array_item___97 items[0];
};

struct bpf_prog_aux___106;

struct bpf_prog___97 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___106 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___271;

struct fwnode_handle___271 {
	struct fwnode_handle___271 *secondary;
	const struct fwnode_operations___271 *ops;
	struct device___275 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___271;

struct fwnode_endpoint___271;

struct fwnode_operations___271 {
	struct fwnode_handle___271 * (*get)(struct fwnode_handle___271 *);
	void (*put)(struct fwnode_handle___271 *);
	bool (*device_is_available)(const struct fwnode_handle___271 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___271 *, const struct device___275 *);
	bool (*property_present)(const struct fwnode_handle___271 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___271 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___271 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___271 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*get_parent)(const struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*get_next_child_node)(const struct fwnode_handle___271 *, struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*get_named_child_node)(const struct fwnode_handle___271 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___271 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___271 *);
	struct fwnode_handle___271 * (*graph_get_next_endpoint)(const struct fwnode_handle___271 *, struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*graph_get_remote_endpoint)(const struct fwnode_handle___271 *);
	struct fwnode_handle___271 * (*graph_get_port_parent)(struct fwnode_handle___271 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___271 *, struct fwnode_endpoint___271 *);
	int (*add_links)(struct fwnode_handle___271 *);
};

struct fwnode_endpoint___271 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___271 *local_fwnode;
};

struct fwnode_reference_args___271 {
	struct fwnode_handle___271 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___282;

struct kernfs_elem_dir___282 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___282 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___282;

struct kernfs_root___282 {
	struct kernfs_node___282 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___282 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___282 {
	struct kernfs_node___282 *target_kn;
};

struct kernfs_ops___282;

struct kernfs_elem_attr___282 {
	const struct kernfs_ops___282 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___282 *notify_next;
};

struct kernfs_node___282 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___282 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___282 dir;
		struct kernfs_elem_symlink___282 symlink;
		struct kernfs_elem_attr___282 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___282;

struct kernfs_ops___282 {
	int (*open)(struct kernfs_open_file___282 *);
	void (*release)(struct kernfs_open_file___282 *);
	int (*seq_show)(struct seq_file___269 *, void *);
	void * (*seq_start)(struct seq_file___269 *, loff_t *);
	void * (*seq_next)(struct seq_file___269 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___269 *, void *);
	ssize_t (*read)(struct kernfs_open_file___282 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___282 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___282 *, struct poll_table_struct___215 *);
	int (*mmap)(struct kernfs_open_file___282 *, struct vm_area_struct___299 *);
};

struct kernfs_syscall_ops___282 {
	int (*show_options)(struct seq_file___269 *, struct kernfs_root___282 *);
	int (*mkdir)(struct kernfs_node___282 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___282 *);
	int (*rename)(struct kernfs_node___282 *, struct kernfs_node___282 *, const char *);
	int (*show_path)(struct seq_file___269 *, struct kernfs_node___282 *, struct kernfs_root___282 *);
};

struct kernfs_open_file___282 {
	struct kernfs_node___282 *kn;
	struct file___294 *file;
	struct seq_file___269 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___289 *vm_ops;
};

struct kobj_ns_type_operations___90 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___90 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___282;

struct attribute_group___282 {
	const char *name;
	umode_t (*is_visible)(struct kobject___282 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___282 *, struct bin_attribute___282 *, int);
	struct attribute **attrs;
	struct bin_attribute___282 **bin_attrs;
};

struct bin_attribute___282 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___294 * (*f_mapping)();
	ssize_t (*read)(struct file___294 *, struct kobject___282 *, struct bin_attribute___282 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___294 *, struct kobject___282 *, struct bin_attribute___282 *, char *, loff_t, size_t);
	int (*mmap)(struct file___294 *, struct kobject___282 *, struct bin_attribute___282 *, struct vm_area_struct___299 *);
};

struct sysfs_ops___282 {
	ssize_t (*show)(struct kobject___282 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___282 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___282;

struct kset___282 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___282 kobj;
	const struct kset_uevent_ops___282 *uevent_ops;
};

struct kobj_type___282 {
	void (*release)(struct kobject___282 *);
	const struct sysfs_ops___282 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___282 **default_groups;
	const struct kobj_ns_type_operations___90 * (*child_ns_type)(struct kobject___282 *);
	const void * (*namespace)(struct kobject___282 *);
	void (*get_ownership)(struct kobject___282 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___282 {
	int (* const filter)(struct kset___282 *, struct kobject___282 *);
	const char * (* const name)(struct kset___282 *, struct kobject___282 *);
	int (* const uevent)(struct kset___282 *, struct kobject___282 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___278 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___278 *);
	int (*get)(char *, const struct kernel_param___278 *);
	void (*free)(void *);
};

struct kparam_array___278;

struct kernel_param___278 {
	const char *name;
	struct module___278 *mod;
	const struct kernel_param_ops___278 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___278 *arr;
	};
};

struct kparam_array___278 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___278 *ops;
	void *elem;
};

struct module_attribute___278 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___278 *, struct module_kobject___279 *, char *);
	ssize_t (*store)(struct module_attribute___278 *, struct module_kobject___279 *, const char *, size_t);
	void (*setup)(struct module___278 *, const char *);
	int (*test)(struct module___278 *);
	void (*free)(struct module___278 *);
};

struct cgroup_namespace___221 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___221 *root_cset;
};

struct dev_pm_ops___275 {
	int (*prepare)(struct device___275 *);
	void (*complete)(struct device___275 *);
	int (*suspend)(struct device___275 *);
	int (*resume)(struct device___275 *);
	int (*freeze)(struct device___275 *);
	int (*thaw)(struct device___275 *);
	int (*poweroff)(struct device___275 *);
	int (*restore)(struct device___275 *);
	int (*suspend_late)(struct device___275 *);
	int (*resume_early)(struct device___275 *);
	int (*freeze_late)(struct device___275 *);
	int (*thaw_early)(struct device___275 *);
	int (*poweroff_late)(struct device___275 *);
	int (*restore_early)(struct device___275 *);
	int (*suspend_noirq)(struct device___275 *);
	int (*resume_noirq)(struct device___275 *);
	int (*freeze_noirq)(struct device___275 *);
	int (*thaw_noirq)(struct device___275 *);
	int (*poweroff_noirq)(struct device___275 *);
	int (*restore_noirq)(struct device___275 *);
	int (*runtime_suspend)(struct device___275 *);
	int (*runtime_resume)(struct device___275 *);
	int (*runtime_idle)(struct device___275 *);
};

struct wakeup_source___275 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___275 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___275 {
	struct dev_pm_ops___275 ops;
	int (*start)(struct device___275 *);
	void (*detach)(struct device___275 *, bool);
	int (*activate)(struct device___275 *);
	void (*sync)(struct device___275 *);
	void (*dismiss)(struct device___275 *);
};

struct bus_type___275 {
	const char *name;
	const char *dev_name;
	struct device___275 *dev_root;
	const struct attribute_group___282 **bus_groups;
	const struct attribute_group___282 **dev_groups;
	const struct attribute_group___282 **drv_groups;
	int (*match)(struct device___275 *, struct device_driver___275 *);
	int (*uevent)(struct device___275 *, struct kobj_uevent_env *);
	int (*probe)(struct device___275 *);
	void (*sync_state)(struct device___275 *);
	void (*remove)(struct device___275 *);
	void (*shutdown)(struct device___275 *);
	int (*online)(struct device___275 *);
	int (*offline)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	int (*num_vf)(struct device___275 *);
	int (*dma_configure)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___275 {
	const char *name;
	struct bus_type___275 *bus;
	struct module___278 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___275 *);
	void (*sync_state)(struct device___275 *);
	int (*remove)(struct device___275 *);
	void (*shutdown)(struct device___275 *);
	int (*suspend)(struct device___275 *, pm_message_t);
	int (*resume)(struct device___275 *);
	const struct attribute_group___282 **groups;
	const struct attribute_group___282 **dev_groups;
	const struct dev_pm_ops___275 *pm;
	void (*coredump)(struct device___275 *);
	struct driver_private *p;
};

struct device_type___275 {
	const char *name;
	const struct attribute_group___282 **groups;
	int (*uevent)(struct device___275 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___275 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___275 *);
	const struct dev_pm_ops___275 *pm;
};

struct class___275 {
	const char *name;
	struct module___278 *owner;
	const struct attribute_group___282 **class_groups;
	const struct attribute_group___282 **dev_groups;
	struct kobject___282 *dev_kobj;
	int (*dev_uevent)(struct device___275 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___275 *, umode_t *);
	void (*class_release)(struct class___275 *);
	void (*dev_release)(struct device___275 *);
	int (*shutdown_pre)(struct device___275 *);
	const struct kobj_ns_type_operations___90 *ns_type;
	const void * (*namespace)(struct device___275 *);
	void (*get_ownership)(struct device___275 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___275 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___135;

struct pipe_buffer___135 {
	struct page___299 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___135 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___135 {
	int (*confirm)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
	void (*release)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
	bool (*try_steal)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
	bool (*get)(struct pipe_inode_info___135 *, struct pipe_buffer___135 *);
};

typedef struct bio_vec___211 skb_frag_t___41;

struct skb_shared_info___35 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___104 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___41 frags[17];
};

struct seq_operations___269 {
	void * (*start)(struct seq_file___269 *, loff_t *);
	void (*stop)(struct seq_file___269 *, void *);
	void * (*next)(struct seq_file___269 *, void *, loff_t *);
	int (*show)(struct seq_file___269 *, void *);
};

struct seq_net_private___15 {
	struct net___108 *net;
};

struct pernet_operations___37 {
	struct list_head list;
	int (*init)(struct net___108 *);
	void (*pre_exit)(struct net___108 *);
	void (*exit)(struct net___108 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___103 {
	int (*ieee_getets)(struct net_device___103 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___103 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___103 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___103 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___103 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___103 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___103 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___103 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___103 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___103 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___103 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___103 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___103 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___103 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___103 *);
	u8 (*setstate)(struct net_device___103 *, u8);
	void (*getpermhwaddr)(struct net_device___103 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___103 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___103 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___103 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___103 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___103 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___103 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___103 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___103 *, int, u8 *);
	void (*setpfccfg)(struct net_device___103 *, int, u8);
	void (*getpfccfg)(struct net_device___103 *, int, u8 *);
	u8 (*setall)(struct net_device___103 *);
	u8 (*getcap)(struct net_device___103 *, int, u8 *);
	int (*getnumtcs)(struct net_device___103 *, int, u8 *);
	int (*setnumtcs)(struct net_device___103 *, int, u8);
	u8 (*getpfcstate)(struct net_device___103 *);
	void (*setpfcstate)(struct net_device___103 *, u8);
	void (*getbcncfg)(struct net_device___103 *, int, u32 *);
	void (*setbcncfg)(struct net_device___103 *, int, u32);
	void (*getbcnrp)(struct net_device___103 *, int, u8 *);
	void (*setbcnrp)(struct net_device___103 *, int, u8);
	int (*setapp)(struct net_device___103 *, u8, u16, u8);
	int (*getapp)(struct net_device___103 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___103 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___103 *, int, u8);
	u8 (*getdcbx)(struct net_device___103 *);
	u8 (*setdcbx)(struct net_device___103 *, u8);
	int (*peer_getappinfo)(struct net_device___103 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___103 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___103 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___103 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___103 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___103 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___106;

typedef int (*bpf_iter_init_seq_priv_t___105)(void *, struct bpf_iter_aux_info___106 *);

struct bpf_map___106;

struct bpf_iter_aux_info___106 {
	struct bpf_map___106 *map;
};

struct bpf_iter_seq_info___105 {
	const struct seq_operations___269 *seq_ops;
	bpf_iter_init_seq_priv_t___105 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___105 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___106 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___106 *, struct file___294 *);
	void (*map_free)(struct bpf_map___106 *);
	int (*map_get_next_key)(struct bpf_map___106 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___106 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___106 *, void *);
	int (*map_lookup_batch)(struct bpf_map___106 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___106 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___106 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___106 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___106 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___106 *, void *);
	int (*map_update_elem)(struct bpf_map___106 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___106 *, void *);
	int (*map_push_elem)(struct bpf_map___106 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___106 *, void *);
	int (*map_peek_elem)(struct bpf_map___106 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___106 *, struct file___294 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___106 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___106 *, void *, struct seq_file___269 *);
	int (*map_check_btf)(const struct bpf_map___106 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___106 *, struct bpf_prog_aux___106 *);
	void (*map_poke_untrack)(struct bpf_map___106 *, struct bpf_prog_aux___106 *);
	void (*map_poke_run)(struct bpf_map___106 *, u32, struct bpf_prog___97 *, struct bpf_prog___97 *);
	int (*map_direct_value_addr)(const struct bpf_map___106 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___106 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___106 *, struct vm_area_struct___299 *);
	__poll_t (*map_poll)(struct bpf_map___106 *, struct file___294 *, struct poll_table_struct___215 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___106 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___106 *, const struct bpf_map___106 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___106 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___105 *iter_seq_info;
};

struct bpf_map___106 {
	const struct bpf_map_ops___105 *ops;
	struct bpf_map___106 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___159 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___105;

struct bpf_jit_poke_descriptor___105;

struct bpf_prog_ops___97;

struct btf_mod_pair___105;

struct bpf_prog_offload___103;

struct bpf_prog_aux___106 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___97 *dst_prog;
	struct bpf_trampoline___105 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___97 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___105 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___97 *ops;
	struct bpf_map___106 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___105 *used_btfs;
	struct bpf_prog___97 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___106 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___103 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___103;

struct bpf_map_dev_ops___103 {
	int (*map_get_next_key)(struct bpf_offloaded_map___103 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___103 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___103 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___103 *, void *);
};

struct bpf_offloaded_map___103 {
	struct bpf_map___106 map;
	struct net_device___103 *netdev;
	const struct bpf_map_dev_ops___103 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___97 {
	int (*test_run)(struct bpf_prog___97 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___103 {
	struct bpf_prog___97 *prog;
	struct net_device___103 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___105 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___97 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___278 *mod;
};

struct bpf_jit_poke_descriptor___105 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___106 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___105 {
	struct btf *btf;
	struct module___278 *module;
};

struct cftype___221;

struct cgroup_subsys___221 {
	struct cgroup_subsys_state___221 * (*css_alloc)(struct cgroup_subsys_state___221 *);
	int (*css_online)(struct cgroup_subsys_state___221 *);
	void (*css_offline)(struct cgroup_subsys_state___221 *);
	void (*css_released)(struct cgroup_subsys_state___221 *);
	void (*css_free)(struct cgroup_subsys_state___221 *);
	void (*css_reset)(struct cgroup_subsys_state___221 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___221 *, int);
	int (*css_extra_stat_show)(struct seq_file___269 *, struct cgroup_subsys_state___221 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___301 *, struct css_set___221 *);
	void (*cancel_fork)(struct task_struct___301 *, struct css_set___221 *);
	void (*fork)(struct task_struct___301 *);
	void (*exit)(struct task_struct___301 *);
	void (*release)(struct task_struct___301 *);
	void (*bind)(struct cgroup_subsys_state___221 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___221 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___221 *dfl_cftypes;
	struct cftype___221 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___221 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___221 *updated_children;
	struct cgroup___221 *updated_next;
};

struct cgroup_root___221 {
	struct kernfs_root___282 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___221 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___221 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___221 *ss;
	struct list_head node;
	struct kernfs_ops___282 *kf_ops;
	int (*open)(struct kernfs_open_file___282 *);
	void (*release)(struct kernfs_open_file___282 *);
	u64 (*read_u64)(struct cgroup_subsys_state___221 *, struct cftype___221 *);
	s64 (*read_s64)(struct cgroup_subsys_state___221 *, struct cftype___221 *);
	int (*seq_show)(struct seq_file___269 *, void *);
	void * (*seq_start)(struct seq_file___269 *, loff_t *);
	void * (*seq_next)(struct seq_file___269 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___269 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___221 *, struct cftype___221 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___221 *, struct cftype___221 *, s64);
	ssize_t (*write)(struct kernfs_open_file___282 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___282 *, struct poll_table_struct___215 *);
};

struct xdp_rxq_info___103 {
	struct net_device___103 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___103 {
	struct net_device___103 *dev;
};

struct xdp_buff___103 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___103 *rxq;
	struct xdp_txq_info___103 *txq;
	u32 frame_sz;
};

struct xdp_frame___103 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___103 *dev_rx;
};

struct netlink_callback___103 {
	struct sk_buff___104 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___104 *, struct netlink_callback___103 *);
	int (*done)(struct netlink_callback___103 *);
	void *data;
	struct module___278 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___103 {
	int (*create)(struct sk_buff___104 *, struct net_device___103 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___104 *, unsigned char *);
	int (*cache)(const struct neighbour___90 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___103 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___104 *);
};

struct netdev_queue___103 {
	struct net_device___103 *dev;
	struct Qdisc___97 *qdisc;
	struct Qdisc___97 *qdisc_sleeping;
	struct kobject___282 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___103 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___97 {
	struct sk_buff___104 *head;
	struct sk_buff___104 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___97;

struct Qdisc___97 {
	int (*enqueue)(struct sk_buff___104 *, struct Qdisc___97 *, struct sk_buff___104 **);
	struct sk_buff___104 * (*dequeue)(struct Qdisc___97 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___97 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___103 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___103 gso_skb;
	struct qdisc_skb_head___97 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___97 *next_sched;
	struct sk_buff_head___103 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___103 {
	struct xdp_rxq_info___103 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___282 kobj;
	struct net_device___103 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___103 {
	enum net_device_path_type type;
	const struct net_device___103 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___103 = 0,
				DEV_PATH_BR_VLAN_TAG___103 = 1,
				DEV_PATH_BR_VLAN_UNTAG___103 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___103 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___103 {
	const struct net_device___103 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___103 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___97 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___103 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___103 {
	int (*xdo_dev_state_add)(struct xfrm_state___23 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___23 *);
	void (*xdo_dev_state_free)(struct xfrm_state___23 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___104 *, struct xfrm_state___23 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___23 *);
};

struct xfrm_state_offload___23 {
	struct net_device___103 *dev;
	struct net_device___103 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___23;

struct xfrm_type_offload___23;

struct xfrm_state___23 {
	possible_net_t___103 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___90 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___23 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___23 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___299 xfrag;
	const struct xfrm_type___23 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___23 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___103 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___103 *dev;
	const char *name;
};

struct net_device_ops___103 {
	int (*ndo_init)(struct net_device___103 *);
	void (*ndo_uninit)(struct net_device___103 *);
	int (*ndo_open)(struct net_device___103 *);
	int (*ndo_stop)(struct net_device___103 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___104 *, struct net_device___103 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___104 *, struct net_device___103 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___103 *, struct sk_buff___104 *, struct net_device___103 *);
	void (*ndo_change_rx_flags)(struct net_device___103 *, int);
	void (*ndo_set_rx_mode)(struct net_device___103 *);
	int (*ndo_set_mac_address)(struct net_device___103 *, void *);
	int (*ndo_validate_addr)(struct net_device___103 *);
	int (*ndo_do_ioctl)(struct net_device___103 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___103 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___103 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___103 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___103 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___103 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___103 *, int);
	int (*ndo_neigh_setup)(struct net_device___103 *, struct neigh_parms___90 *);
	void (*ndo_tx_timeout)(struct net_device___103 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___103 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___103 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___103 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___103 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___103 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___103 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___103 *);
	int (*ndo_netpoll_setup)(struct net_device___103 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___103 *);
	int (*ndo_set_vf_mac)(struct net_device___103 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___103 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___103 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___103 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___103 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___103 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___103 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___103 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___103 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___103 *, int, struct sk_buff___104 *);
	int (*ndo_get_vf_guid)(struct net_device___103 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___103 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___103 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___103 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___103 *);
	int (*ndo_fcoe_disable)(struct net_device___103 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___103 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___103 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___103 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___103 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___103 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___103 *, const struct sk_buff___104 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___103 *, struct net_device___103 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___103 *, struct net_device___103 *);
	struct net_device___103 * (*ndo_get_xmit_slave)(struct net_device___103 *, struct sk_buff___104 *, bool);
	struct net_device___103 * (*ndo_sk_get_lower_dev)(struct net_device___103 *, struct sock___90 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___103 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___103 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___103 *, struct neighbour___90 *);
	void (*ndo_neigh_destroy)(struct net_device___103 *, struct neighbour___90 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___103 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___103 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___104 *, struct netlink_callback___103 *, struct net_device___103 *, struct net_device___103 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___104 *, struct nlattr **, struct net_device___103 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___103 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___104 *, u32, u32, struct net_device___103 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___103 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___103 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___103 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___103 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___103 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___103 *, struct net_device___103 *);
	void (*ndo_dfwd_del_station)(struct net_device___103 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___103 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___103 *);
	int (*ndo_change_proto_down)(struct net_device___103 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___103 *, struct sk_buff___104 *);
	void (*ndo_set_rx_headroom)(struct net_device___103 *, int);
	int (*ndo_bpf)(struct net_device___103 *, struct netdev_bpf___103 *);
	int (*ndo_xdp_xmit)(struct net_device___103 *, int, struct xdp_frame___103 **, u32);
	struct net_device___103 * (*ndo_xdp_get_xmit_slave)(struct net_device___103 *, struct xdp_buff___103 *);
	int (*ndo_xsk_wakeup)(struct net_device___103 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___103 *);
	int (*ndo_tunnel_ctl)(struct net_device___103 *, struct ip_tunnel_parm *, int);
	struct net_device___103 * (*ndo_get_peer_dev)(struct net_device___103 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___103 *, struct net_device_path___103 *);
};

struct neigh_parms___90 {
	possible_net_t___103 net;
	struct net_device___103 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___90 *);
	struct neigh_table___90 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___90 {
	u32 (*l3mdev_fib_table)(const struct net_device___103 *);
	struct sk_buff___104 * (*l3mdev_l3_rcv)(struct net_device___103 *, struct sk_buff___104 *, u16);
	struct sk_buff___104 * (*l3mdev_l3_out)(struct net_device___103 *, struct sock___90 *, struct sk_buff___104 *, u16);
	struct dst_entry___90 * (*l3mdev_link_scope_lookup)(const struct net_device___103 *, struct flowi6 *);
};

struct ndisc_ops___72 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___103 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___103 *, struct neighbour___90 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___103 *, u8, struct neighbour___90 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___103 *, struct sk_buff___104 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___108 *, struct net_device___103 *, const struct prefix_info *, struct inet6_dev___72 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___72;

struct ifacaddr6___32;

struct inet6_dev___72 {
	struct net_device___103 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___72 *mc_list;
	struct ifmcaddr6___72 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___103 mc_query_queue;
	struct sk_buff_head___103 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___32 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___90 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___97;

struct tcf_block___97;

struct mini_Qdisc___97 {
	struct tcf_proto___97 *filter_list;
	struct tcf_block___97 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___97 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___103 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___103 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___108 *, struct net_device___103 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___103 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___103 *, struct list_head *);
	size_t (*get_size)(const struct net_device___103 *);
	int (*fill_info)(struct sk_buff___104 *, const struct net_device___103 *);
	size_t (*get_xstats_size)(const struct net_device___103 *);
	int (*fill_xstats)(struct sk_buff___104 *, const struct net_device___103 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___103 *, struct net_device___103 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___103 *, const struct net_device___103 *);
	int (*fill_slave_info)(struct sk_buff___104 *, const struct net_device___103 *, const struct net_device___103 *);
	struct net___108 * (*get_link_net)(const struct net_device___103 *);
	size_t (*get_linkxstats_size)(const struct net_device___103 *, int);
	int (*fill_linkxstats)(struct sk_buff___104 *, const struct net_device___103 *, int *, int);
};

struct block_device_operations___185;

struct gendisk___188 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___188 *part0;
	const struct block_device_operations___185 *fops;
	struct request_queue___185 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___171 *bdi;
	struct kobject___282 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___282 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___185 {
	struct bio___185 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___211 *bip_vec;
	struct bio_vec___211 bip_inline_vecs[0];
};

struct blkcg___173;

struct blkg_policy_data___173;

struct blkcg_gq___173 {
	struct request_queue___185 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___173 *blkcg;
	struct blkcg_gq___173 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___173 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___185 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___185(struct request___185 *);

typedef void integrity_complete_fn___185(struct request___185 *, unsigned int);

struct blk_integrity_profile___185 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___185 *prepare_fn;
	integrity_complete_fn___185 *complete_fn;
	const char *name;
};

struct block_device_operations___185 {
	blk_qc_t (*submit_bio)(struct bio___185 *);
	int (*open)(struct block_device___188 *, fmode_t);
	void (*release)(struct gendisk___188 *, fmode_t);
	int (*rw_page)(struct block_device___188 *, sector_t, struct page___299 *, unsigned int);
	int (*ioctl)(struct block_device___188 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___188 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___188 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___188 *);
	int (*getgeo)(struct block_device___188 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___188 *, bool);
	void (*swap_slot_free_notify)(struct block_device___188 *, long unsigned int);
	int (*report_zones)(struct gendisk___188 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___188 *, umode_t *);
	struct module___278 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___188 *, sector_t *);
};

typedef void rq_end_io_fn___185(struct request___185 *, blk_status_t);

struct request___185 {
	struct request_queue___185 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___180 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___185 *bio;
	struct bio___185 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___211 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___185 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___185 *saved_end_io;
		} flush;
	};
	struct gendisk___188 *rq_disk;
	struct block_device___188 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___185 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___180 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___185 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___282 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___294 *debugfs_dir;
	struct dentry___294 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___185;

struct elevator_mq_ops___185 {
	int (*init_sched)(struct request_queue___185 *, struct elevator_type___185 *);
	void (*exit_sched)(struct elevator_queue___185 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___180 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___180 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___180 *);
	bool (*allow_merge)(struct request_queue___185 *, struct request___185 *, struct bio___185 *);
	bool (*bio_merge)(struct request_queue___185 *, struct bio___185 *, unsigned int);
	int (*request_merge)(struct request_queue___185 *, struct request___185 **, struct bio___185 *);
	void (*request_merged)(struct request_queue___185 *, struct request___185 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___185 *, struct request___185 *, struct request___185 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___185 *);
	void (*finish_request)(struct request___185 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___180 *, struct list_head *, bool);
	struct request___185 * (*dispatch_request)(struct blk_mq_hw_ctx___180 *);
	bool (*has_work)(struct blk_mq_hw_ctx___180 *);
	void (*completed_request)(struct request___185 *, u64);
	void (*requeue_request)(struct request___185 *);
	struct request___185 * (*former_request)(struct request_queue___185 *, struct request___185 *);
	struct request___185 * (*next_request)(struct request_queue___185 *, struct request___185 *);
	void (*init_icq)(struct io_cq___185 *);
	void (*exit_icq)(struct io_cq___185 *);
};

struct elv_fs_entry___185;

struct elevator_type___185 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___185 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___185 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___278 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___185 {
	struct elevator_type___185 *type;
	void *elevator_data;
	struct kobject___282 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___185 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___185 *, char *);
	ssize_t (*store)(struct elevator_queue___185 *, const char *, size_t);
};

struct blk_mq_queue_data___180;

struct blk_mq_ops___180 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___180 *, const struct blk_mq_queue_data___180 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___180 *);
	int (*get_budget)(struct request_queue___185 *);
	void (*put_budget)(struct request_queue___185 *, int);
	void (*set_rq_budget_token)(struct request___185 *, int);
	int (*get_rq_budget_token)(struct request___185 *);
	enum blk_eh_timer_return (*timeout)(struct request___185 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___180 *);
	void (*complete)(struct request___185 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___180 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___180 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___180 *, struct request___185 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___180 *, struct request___185 *, unsigned int);
	void (*initialize_rq_fn)(struct request___185 *);
	void (*cleanup_rq)(struct request___185 *);
	bool (*busy)(struct request_queue___185 *);
	int (*map_queues)(struct blk_mq_tag_set___180 *);
	void (*show_rq)(struct seq_file___269 *, struct request___185 *);
};

struct blk_mq_tag_set___180 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___180 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___180 {
	struct request___185 *rq;
	bool last;
};

struct blkcg_policy_data___173;

struct blkcg___173 {
	struct cgroup_subsys_state___221 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___173 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___173 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___173 {
	struct blkcg___173 *blkcg;
	int plid;
};

struct blkg_policy_data___173 {
	struct blkcg_gq___173 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___159 {
	struct mem_cgroup___159 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___159 {
	struct lruvec___167 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___159 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___159 *memcg;
};

struct obj_cgroup___159 {
	struct percpu_ref refcnt;
	struct mem_cgroup___159 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___97 {
	spinlock_t *lock;
	struct sk_buff___104 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___97;

struct Qdisc_ops___97 {
	struct Qdisc_ops___97 *next;
	const struct Qdisc_class_ops___97 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___104 *, struct Qdisc___97 *, struct sk_buff___104 **);
	struct sk_buff___104 * (*dequeue)(struct Qdisc___97 *);
	struct sk_buff___104 * (*peek)(struct Qdisc___97 *);
	int (*init)(struct Qdisc___97 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___97 *);
	void (*destroy)(struct Qdisc___97 *);
	int (*change)(struct Qdisc___97 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___97 *);
	int (*change_tx_queue_len)(struct Qdisc___97 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___97 *, unsigned int);
	int (*dump)(struct Qdisc___97 *, struct sk_buff___104 *);
	int (*dump_stats)(struct Qdisc___97 *, struct gnet_dump___97 *);
	void (*ingress_block_set)(struct Qdisc___97 *, u32);
	void (*egress_block_set)(struct Qdisc___97 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___97 *);
	u32 (*egress_block_get)(struct Qdisc___97 *);
	struct module___278 *owner;
};

struct Qdisc_class_ops___97 {
	unsigned int flags;
	struct netdev_queue___103 * (*select_queue)(struct Qdisc___97 *, struct tcmsg *);
	int (*graft)(struct Qdisc___97 *, long unsigned int, struct Qdisc___97 *, struct Qdisc___97 **, struct netlink_ext_ack *);
	struct Qdisc___97 * (*leaf)(struct Qdisc___97 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___97 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___97 *, u32);
	int (*change)(struct Qdisc___97 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___97 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___97 *, struct qdisc_walker *);
	struct tcf_block___97 * (*tcf_block)(struct Qdisc___97 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___97 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___97 *, long unsigned int);
	int (*dump)(struct Qdisc___97 *, long unsigned int, struct sk_buff___104 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___97 *, long unsigned int, struct gnet_dump___97 *);
};

struct tcf_chain___97;

struct tcf_block___97 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___108 *net;
	struct Qdisc___97 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___97 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___97;

struct tcf_proto_ops___97;

struct tcf_proto___97 {
	struct tcf_proto___97 *next;
	void *root;
	int (*classify)(struct sk_buff___104 *, const struct tcf_proto___97 *, struct tcf_result___97 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___97 *ops;
	struct tcf_chain___97 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___97 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___97 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___97 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___104 *, const struct tcf_proto___97 *, struct tcf_result___97 *);
	int (*init)(struct tcf_proto___97 *);
	void (*destroy)(struct tcf_proto___97 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___97 *, u32);
	void (*put)(struct tcf_proto___97 *, void *);
	int (*change)(struct net___108 *, struct sk_buff___104 *, struct tcf_proto___97 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___97 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___97 *);
	void (*walk)(struct tcf_proto___97 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___97 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___97 *, void *);
	void (*hw_del)(struct tcf_proto___97 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___108 *, struct tcf_chain___97 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___108 *, struct tcf_proto___97 *, void *, struct sk_buff___104 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___108 *, struct tcf_proto___97 *, void *, struct sk_buff___104 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___104 *, struct net___108 *, void *);
	struct module___278 *owner;
	int flags;
};

struct tcf_chain___97 {
	struct mutex filter_chain_lock;
	struct tcf_proto___97 *filter_chain;
	struct list_head list;
	struct tcf_block___97 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___97 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___90 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___97 *prog;
};

struct pneigh_entry___90;

struct neigh_hash_table___90;

struct neigh_table___90 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___103 *, __u32 *);
	bool (*key_eq)(const struct neighbour___90 *, const void *);
	int (*constructor)(struct neighbour___90 *);
	int (*pconstructor)(struct pneigh_entry___90 *);
	void (*pdestructor)(struct pneigh_entry___90 *);
	void (*proxy_redo)(struct sk_buff___104 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___103 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___90 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___103 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___90 *nht;
	struct pneigh_entry___90 **phash_buckets;
};

struct neigh_ops___90 {
	int family;
	void (*solicit)(struct neighbour___90 *, struct sk_buff___104 *);
	void (*error_report)(struct neighbour___90 *, struct sk_buff___104 *);
	int (*output)(struct neighbour___90 *, struct sk_buff___104 *);
	int (*connected_output)(struct neighbour___90 *, struct sk_buff___104 *);
};

struct pneigh_entry___90 {
	struct pneigh_entry___90 *next;
	possible_net_t___103 net;
	struct net_device___103 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___90 {
	struct neighbour___90 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___66 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___108 *, struct sock___90 *, struct sk_buff___104 *);
	int (*orig_input)(struct sk_buff___104 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___90 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___90 *ctarget;
	struct net___108 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___90 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___90 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___75;

struct timewait_sock_ops___74;

struct proto___90 {
	void (*close)(struct sock___90 *, long int);
	int (*pre_connect)(struct sock___90 *, struct sockaddr *, int);
	int (*connect)(struct sock___90 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___90 *, int);
	struct sock___90 * (*accept)(struct sock___90 *, int, int *, bool);
	int (*ioctl)(struct sock___90 *, int, long unsigned int);
	int (*init)(struct sock___90 *);
	void (*destroy)(struct sock___90 *);
	void (*shutdown)(struct sock___90 *, int);
	int (*setsockopt)(struct sock___90 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___90 *, int, int, char *, int *);
	void (*keepalive)(struct sock___90 *, int);
	int (*compat_ioctl)(struct sock___90 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___90 *, struct msghdr___92 *, size_t);
	int (*recvmsg)(struct sock___90 *, struct msghdr___92 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___90 *, struct page___299 *, int, size_t, int);
	int (*bind)(struct sock___90 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___90 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___90 *, struct sk_buff___104 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___90 *);
	int (*hash)(struct sock___90 *);
	void (*unhash)(struct sock___90 *);
	void (*rehash)(struct sock___90 *);
	int (*get_port)(struct sock___90 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___90 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___90 *, int);
	bool (*sock_is_readable)(struct sock___90 *);
	void (*enter_memory_pressure)(struct sock___90 *);
	void (*leave_memory_pressure)(struct sock___90 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___75 *rsk_prot;
	struct timewait_sock_ops___74 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___278 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___90 *, int);
};

struct xfrm_policy_queue___23 {
	struct sk_buff_head___103 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___23 {
	possible_net_t___103 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___23 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___38 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___97 *prog;
	struct sock___90 *socks[0];
};

struct request_sock___76;

struct request_sock_ops___75 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___90 *, struct request_sock___76 *);
	void (*send_ack)(const struct sock___90 *, struct sk_buff___104 *, struct request_sock___76 *);
	void (*send_reset)(const struct sock___90 *, struct sk_buff___104 *);
	void (*destructor)(struct request_sock___76 *);
	void (*syn_ack_timeout)(const struct request_sock___76 *);
};

struct timewait_sock_ops___74 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___90 *, struct sock___90 *, void *);
	void (*twsk_destructor)(struct sock___90 *);
};

struct request_sock___76 {
	struct sock_common___90 __req_common;
	struct request_sock___76 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___75 *rsk_ops;
	struct sock___90 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___25 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___90 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___25 {
	struct inet_cork___25 base;
	struct flowi fl;
};

struct ipv6_pinfo___24;

struct inet_sock___25 {
	struct sock___90 sk;
	struct ipv6_pinfo___24 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___25 cork;
};

struct ipv6_fl_socklist___24;

struct ipv6_pinfo___24 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___24 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___104 *pktoptions;
	struct sk_buff___104 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___24;

struct ipv6_fl_socklist___24 {
	struct ipv6_fl_socklist___24 *next;
	struct ip6_flowlabel___24 *fl;
	struct callback_head rcu;
};

struct raw6_sock {
	struct inet_sock___25 inet;
	__u32 checksum;
	__u32 offset;
	struct icmp6_filter filter;
	__u32 ip6mr_table;
	struct ipv6_pinfo___24 inet6;
};

struct nf_hook_state___21 {
	u8 hook;
	u8 pf;
	struct net_device___103 *in;
	struct net_device___103 *out;
	struct sock___90 *sk;
	struct net___108 *net;
	int (*okfn)(struct net___108 *, struct sock___90 *, struct sk_buff___104 *);
};

struct ifmcaddr6___72 {
	struct in6_addr mca_addr;
	struct inet6_dev___72 *idev;
	struct ifmcaddr6___72 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___32 {
	struct in6_addr aca_addr;
	struct fib6_info___32 *aca_rt;
	struct ifacaddr6___32 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___24 {
	struct ip6_flowlabel___24 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___271 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___108 *fl_net;
};

struct fib_nh_exception___32 {
	struct fib_nh_exception___32 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___34 *fnhe_rth_input;
	struct rtable___34 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___34 {
	struct dst_entry___90 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___32 {
	struct fib_nh_exception___32 *chain;
};

struct fib_info___22;

struct fib_nh___22 {
	struct fib_nh_common___32 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___22 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___22 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___108 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___22 *nh;
	struct callback_head rcu;
	struct fib_nh___22 fib_nh[0];
};

struct nh_info___22;

struct nh_group___22;

struct nexthop___22 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___108 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___22 *nh_info;
		struct nh_group___22 *nh_grp;
	};
};

struct inet_protosw___4 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___90 *prot;
	const struct proto_ops___91 *ops;
	unsigned char flags;
};

struct nh_info___22 {
	struct hlist_node dev_hash;
	struct nexthop___22 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___32 fib_nhc;
		struct fib_nh___22 fib_nh;
		struct fib6_nh___32 fib6_nh;
	};
};

struct nh_grp_entry___22;

struct nh_res_bucket___22 {
	struct nh_grp_entry___22 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___22 {
	struct nexthop___22 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___22 *nh_parent;
};

struct nh_res_table___22 {
	struct net___108 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___22 nh_buckets[0];
};

struct nh_group___22 {
	struct nh_group___22 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___22 *res_table;
	struct nh_grp_entry___22 nh_entries[0];
};

struct raw_iter_state___2 {
	struct seq_net_private___15 p;
	int bucket;
};

struct xfrm_type___23 {
	struct module___278 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___23 *);
	void (*destructor)(struct xfrm_state___23 *);
	int (*input)(struct xfrm_state___23 *, struct sk_buff___104 *);
	int (*output)(struct xfrm_state___23 *, struct sk_buff___104 *);
	int (*reject)(struct xfrm_state___23 *, struct sk_buff___104 *, const struct flowi *);
};

struct xfrm_type_offload___23 {
	struct module___278 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___23 *, struct sk_buff___104 *);
	int (*input_tail)(struct xfrm_state___23 *, struct sk_buff___104 *);
	int (*xmit)(struct xfrm_state___23 *, struct sk_buff___104 *, netdev_features_t);
};

typedef int mh_filter_t(struct sock___90 *, struct sk_buff___104 *);

struct raw6_frag_vec {
	struct msghdr___92 *msg;
	int hlen;
	char c[4];
};

struct ipv6_destopt_hao {
	__u8 type;
	__u8 length;
	struct in6_addr addr;
} __attribute__((packed));

typedef void ip6_icmp_send_t(struct sk_buff___104 *, u8, u8, __u32, const struct in6_addr *, const struct inet6_skb_parm *);

struct inet6_protocol___4 {
	void (*early_demux)(struct sk_buff___104 *);
	void (*early_demux_handler)(struct sk_buff___104 *);
	int (*handler)(struct sk_buff___104 *);
	int (*err_handler)(struct sk_buff___104 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct sec_path___9 {
	int len;
	int olen;
	struct xfrm_state___23 *xvec[6];
	struct xfrm_offload ovec[1];
};

struct icmpv6_msg {
	struct sk_buff___104 *skb;
	int offset;
	uint8_t type;
};

struct icmp6_err {
	int err;
	int fatal;
};

struct netdev_notifier_info___21 {
	struct net_device___85 *dev;
	struct netlink_ext_ack *extack;
};

struct mld_msg {
	struct icmp6hdr mld_hdr;
	struct in6_addr mld_mca;
};

struct mld2_grec {
	__u8 grec_type;
	__u8 grec_auxwords;
	__be16 grec_nsrcs;
	struct in6_addr grec_mca;
	struct in6_addr grec_src[0];
};

struct mld2_report {
	struct icmp6hdr mld2r_hdr;
	struct mld2_grec mld2r_grec[0];
};

struct mld2_query {
	struct icmp6hdr mld2q_hdr;
	struct in6_addr mld2q_mca;
	__u8 mld2q_qrv: 3;
	__u8 mld2q_suppress: 1;
	__u8 mld2q_resv2: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	__u8 mld2q_qqic;
	__be16 mld2q_nsrcs;
	struct in6_addr mld2q_srcs[0];
};

struct igmp6_mc_iter_state {
	struct seq_net_private___11 p;
	struct net_device___85 *dev;
	struct inet6_dev___54 *idev;
};

struct igmp6_mcf_iter_state {
	struct seq_net_private___11 p;
	struct net_device___85 *dev;
	struct inet6_dev___54 *idev;
	struct ifmcaddr6___54 *im;
};

enum ip6_defrag_users {
	IP6_DEFRAG_LOCAL_DELIVER = 0,
	IP6_DEFRAG_CONNTRACK_IN = 1,
	__IP6_DEFRAG_CONNTRACK_IN = 65536,
	IP6_DEFRAG_CONNTRACK_OUT = 65537,
	__IP6_DEFRAG_CONNTRACK_OUT = 131072,
	IP6_DEFRAG_CONNTRACK_BRIDGE_IN = 131073,
	__IP6_DEFRAG_CONNTRACK_BRIDGE_IN = 196608,
};

struct frag_queue {
	struct inet_frag_queue___108 q;
	int iif;
	__u16 nhoffset;
	u8 ecn;
};

struct dentry___295;

struct super_block___295;

struct module___279;

struct file_system_type___295 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___295 * (*mount)(struct file_system_type___295 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___295 *);
	struct module___279 *owner;
	struct file_system_type___295 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___295;

struct kiocb___295;

struct iov_iter___215;

struct poll_table_struct___216;

struct vm_area_struct___300;

struct inode___295;

struct file_lock___295;

struct page___300;

struct pipe_inode_info___136;

struct seq_file___270;

struct file_operations___296 {
	struct module___279 *owner;
	loff_t (*llseek)(struct file___295 *, loff_t, int);
	ssize_t (*read)(struct file___295 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___295 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___295 *, struct iov_iter___215 *);
	ssize_t (*write_iter)(struct kiocb___295 *, struct iov_iter___215 *);
	int (*iopoll)(struct kiocb___295 *, bool);
	int (*iterate)(struct file___295 *, struct dir_context *);
	int (*iterate_shared)(struct file___295 *, struct dir_context *);
	__poll_t (*poll)(struct file___295 *, struct poll_table_struct___216 *);
	long int (*unlocked_ioctl)(struct file___295 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___295 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___295 *, struct vm_area_struct___300 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___295 *, struct file___295 *);
	int (*flush)(struct file___295 *, fl_owner_t);
	int (*release)(struct inode___295 *, struct file___295 *);
	int (*fsync)(struct file___295 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___295 *, int);
	int (*lock)(struct file___295 *, int, struct file_lock___295 *);
	ssize_t (*sendpage)(struct file___295 *, struct page___300 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___295 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___295 *, long unsigned int);
	int (*flock)(struct file___295 *, int, struct file_lock___295 *);
	ssize_t (*splice_write)(struct pipe_inode_info___136 *, struct file___295 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___295 *, loff_t *, struct pipe_inode_info___136 *, size_t, unsigned int);
	int (*setlease)(struct file___295 *, long int, struct file_lock___295 **, void **);
	long int (*fallocate)(struct file___295 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___270 *, struct file___295 *);
	ssize_t (*copy_file_range)(struct file___295 *, loff_t, struct file___295 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___295 *, loff_t, struct file___295 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___295 *, loff_t, loff_t, int);
};

struct vmacache___300 {
	u64 seqnum;
	struct vm_area_struct___300 *vmas[4];
};

struct page_frag___300 {
	struct page___300 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___301;

struct pid___272;

struct nsproxy___281;

struct signal_struct___296;

struct bio_list___186;

struct backing_dev_info___172;

struct io_context___186;

struct css_set___222;

struct mem_cgroup___160;

struct request_queue___186;

struct vm_struct___278;

struct task_struct___302 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___302 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___301 *mm;
	struct mm_struct___301 *active_mm;
	struct vmacache___300 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___302 *real_parent;
	struct task_struct___302 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___302 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___272 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___281 *nsproxy;
	struct signal_struct___296 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___302 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___186 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___172 *backing_dev_info;
	struct io_context___186 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___222 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___136 *splice_pipe;
	struct page_frag___300 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___160 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___160 *active_memcg;
	struct request_queue___186 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___302 *oom_reaper_list;
	struct vm_struct___278 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___283;

struct kobj_type___283;

struct kernfs_node___283;

struct kobject___283 {
	const char *name;
	struct list_head entry;
	struct kobject___283 *parent;
	struct kset___283 *kset;
	struct kobj_type___283 *ktype;
	struct kernfs_node___283 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___280 {
	struct kobject___283 kobj;
	struct module___279 *mod;
	struct kobject___283 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___279 {
	struct module___279 *mod;
	struct latch_tree_node node;
};

struct module_layout___279 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___279 mtn;
};

struct module_attribute___279;

struct kernel_param___279;

struct module___279 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___280 mkobj;
	struct module_attribute___279 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___283 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___279 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___279 core_layout;
	struct module_layout___279 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___272;

struct upid___272 {
	int nr;
	struct pid_namespace___272 *ns;
};

struct pid_namespace___272 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___302 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___272 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___272 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___272 numbers[1];
};

typedef struct page___300 *pgtable_t___300;

struct address_space___295;

struct page_pool___124;

struct dev_pagemap___290;

struct page___300 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___295 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___124 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___300 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___300 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___301 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___290 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___290;

struct vm_area_struct___300 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___300 *vm_next;
	struct vm_area_struct___300 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___301 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___290 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___295 *vm_file;
	struct file___295 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___296 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___302 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___302 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___272 *pids[4];
	struct pid___272 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___301 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___300;

struct mm_struct___301 {
	struct {
		struct vm_area_struct___300 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___295 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___300 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___302 *owner;
		struct user_namespace___26 *user_ns;
		struct file___295 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___109;

struct cgroup_namespace___222;

struct nsproxy___281 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___272 *pid_ns_for_children;
	struct net___109 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___222 *cgroup_ns;
};

struct bio___186;

struct bio_list___186 {
	struct bio___186 *head;
	struct bio___186 *tail;
};

struct cgroup_subsys_state___222;

struct bdi_writeback___172 {
	struct backing_dev_info___172 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___222 *memcg_css;
	struct cgroup_subsys_state___222 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___276;

struct backing_dev_info___172 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___172 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___276 *dev;
	char dev_name[64];
	struct device___276 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___295 *debug_dir;
};

struct io_cq___186;

struct io_context___186 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___186 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___222;

struct css_set___222 {
	struct cgroup_subsys_state___222 *subsys[14];
	refcount_t refcount;
	struct css_set___222 *dom_cset;
	struct cgroup___222 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___222 *mg_src_cgrp;
	struct cgroup___222 *mg_dst_cgrp;
	struct css_set___222 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___295;

struct pipe_buffer___136;

struct pipe_inode_info___136 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___300 *tmp_page;
	struct fasync_struct___295 *fasync_readers;
	struct fasync_struct___295 *fasync_writers;
	struct pipe_buffer___136 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___222;

struct cgroup_subsys_state___222 {
	struct cgroup___222 *cgroup;
	struct cgroup_subsys___222 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___222 *parent;
};

struct cgroup_file___222 {
	struct kernfs_node___283 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___160;

struct mem_cgroup_per_node___160;

struct mem_cgroup___160 {
	struct cgroup_subsys_state___222 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___222 events_file;
	struct cgroup_file___222 events_local_file;
	struct cgroup_file___222 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___160 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___302 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___160 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___186;

struct blk_integrity___186 {
	const struct blk_integrity_profile___186 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___186 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___186 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___186;

struct elevator_queue___186;

struct blk_mq_ops___181;

struct blk_mq_hw_ctx___181;

struct gendisk___189;

struct blkcg_gq___174;

struct blk_mq_tag_set___181;

struct request_queue___186 {
	struct request___186 *last_merge;
	struct elevator_queue___186 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___181 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___181 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___189 *disk;
	struct kobject___283 kobj;
	struct kobject___283 *mq_kobj;
	struct blk_integrity___186 integrity;
	struct device___276 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___174 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___181 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___186 bio_split;
	struct dentry___295 *debugfs_dir;
	struct dentry___295 *sched_debugfs_dir;
	struct dentry___295 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___278 {
	struct vm_struct___278 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___300 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___295;

struct address_space___295 {
	struct inode___295 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___295 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___124 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___276 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___124 {
	u32 count;
	struct page___300 *cache[128];
};

struct page_pool___124 {
	struct page_pool_params___124 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___300 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___124 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___290;

struct dev_pagemap___290 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___290 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___295;

struct path___295 {
	struct vfsmount___295 *mnt;
	struct dentry___295 *dentry;
};

struct fown_struct___272 {
	rwlock_t lock;
	struct pid___272 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___295 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___295 f_path;
	struct inode___295 *f_inode;
	const struct file_operations___296 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___272 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___295 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___290;

struct vm_operations_struct___290 {
	void (*open)(struct vm_area_struct___300 *);
	void (*close)(struct vm_area_struct___300 *);
	int (*may_split)(struct vm_area_struct___300 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___300 *);
	int (*mprotect)(struct vm_area_struct___300 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___290 *);
	vm_fault_t (*huge_fault)(struct vm_fault___290 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___290 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___300 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___290 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___290 *);
	int (*access)(struct vm_area_struct___300 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___300 *);
	int (*set_policy)(struct vm_area_struct___300 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___300 *, long unsigned int);
	struct page___300 * (*find_special_page)(struct vm_area_struct___300 *, long unsigned int);
};

struct core_thread___300 {
	struct task_struct___302 *task;
	struct core_thread___300 *next;
};

struct core_state___300 {
	atomic_t nr_threads;
	struct core_thread___300 dumper;
	struct completion startup;
};

struct vm_fault___290 {
	const struct {
		struct vm_area_struct___300 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___300 *cow_page;
	struct page___300 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___300 prealloc_pte;
};

struct pglist_data___168;

struct lruvec___168 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___168 *pgdat;
};

struct zone___168 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___168 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___168 {
	struct zone___168 *zone;
	int zone_idx;
};

struct zonelist___168 {
	struct zoneref___168 _zonerefs[321];
};

struct pglist_data___168 {
	struct zone___168 node_zones[5];
	struct zonelist___168 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___302 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___302 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___168 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct dentry_operations___295;

struct dentry___295 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___295 *d_parent;
	struct qstr d_name;
	struct inode___295 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___295 *d_op;
	struct super_block___295 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___295;

struct inode___295 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___295 *i_op;
	struct super_block___295 *i_sb;
	struct address_space___295 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___172 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___296 *i_fop;
		void (*free_inode)(struct inode___295 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___295 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___136 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___295 {
	int (*d_revalidate)(struct dentry___295 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___295 *, unsigned int);
	int (*d_hash)(const struct dentry___295 *, struct qstr *);
	int (*d_compare)(const struct dentry___295 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___295 *);
	int (*d_init)(struct dentry___295 *);
	void (*d_release)(struct dentry___295 *);
	void (*d_prune)(struct dentry___295 *);
	void (*d_iput)(struct dentry___295 *, struct inode___295 *);
	char * (*d_dname)(struct dentry___295 *, char *, int);
	struct vfsmount___295 * (*d_automount)(struct path___295 *);
	int (*d_manage)(const struct path___295 *, bool);
	struct dentry___295 * (*d_real)(struct dentry___295 *, const struct inode___295 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___295;

struct mem_dqinfo___295 {
	struct quota_format_type___295 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___295;

struct quota_info___295 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___295 *files[3];
	struct mem_dqinfo___295 info[3];
	const struct quota_format_ops___295 *ops[3];
};

struct rcuwait___296 {
	struct task_struct___302 *task;
};

struct percpu_rw_semaphore___296 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___296 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___295 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___296 rw_sem[3];
};

struct shrink_control___160;

struct shrinker___160 {
	long unsigned int (*count_objects)(struct shrinker___160 *, struct shrink_control___160 *);
	long unsigned int (*scan_objects)(struct shrinker___160 *, struct shrink_control___160 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___295;

struct dquot_operations___295;

struct quotactl_ops___295;

struct block_device___189;

struct super_block___295 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___295 *s_type;
	const struct super_operations___295 *s_op;
	const struct dquot_operations___295 *dq_op;
	const struct quotactl_ops___295 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___295 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___189 *s_bdev;
	struct backing_dev_info___172 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___295 s_dquot;
	struct sb_writers___295 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___295 *s_d_op;
	int cleancache_poolid;
	struct shrinker___160 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___295 {
	struct dentry___295 *mnt_root;
	struct super_block___295 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___160 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___160 *memcg;
};

struct psi_group___222 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___302 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___98;

struct cgroup_bpf___98 {
	struct bpf_prog_array___98 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___98 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___222;

struct cgroup_rstat_cpu___222;

struct cgroup___222 {
	struct cgroup_subsys_state___222 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___283 *kn;
	struct cgroup_file___222 procs_file;
	struct cgroup_file___222 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___222 *subsys[14];
	struct cgroup_root___222 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___222 *dom_cgrp;
	struct cgroup___222 *old_dom_cgrp;
	struct cgroup_rstat_cpu___222 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___222 psi;
	struct cgroup_bpf___98 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___186 {
	struct request_queue___186 *q;
	struct io_context___186 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___295 {
	struct file___295 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___295 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___295 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___295 *ia_file;
};

struct dquot___295 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___295 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___295 {
	int qf_fmt_id;
	const struct quota_format_ops___295 *qf_ops;
	struct module___279 *qf_owner;
	struct quota_format_type___295 *qf_next;
};

struct quota_format_ops___295 {
	int (*check_quota_file)(struct super_block___295 *, int);
	int (*read_file_info)(struct super_block___295 *, int);
	int (*write_file_info)(struct super_block___295 *, int);
	int (*free_file_info)(struct super_block___295 *, int);
	int (*read_dqblk)(struct dquot___295 *);
	int (*commit_dqblk)(struct dquot___295 *);
	int (*release_dqblk)(struct dquot___295 *);
	int (*get_next_id)(struct super_block___295 *, struct kqid *);
};

struct dquot_operations___295 {
	int (*write_dquot)(struct dquot___295 *);
	struct dquot___295 * (*alloc_dquot)(struct super_block___295 *, int);
	void (*destroy_dquot)(struct dquot___295 *);
	int (*acquire_dquot)(struct dquot___295 *);
	int (*release_dquot)(struct dquot___295 *);
	int (*mark_dirty)(struct dquot___295 *);
	int (*write_info)(struct super_block___295 *, int);
	qsize_t * (*get_reserved_space)(struct inode___295 *);
	int (*get_projid)(struct inode___295 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___295 *, qsize_t *);
	int (*get_next_id)(struct super_block___295 *, struct kqid *);
};

struct quotactl_ops___295 {
	int (*quota_on)(struct super_block___295 *, int, int, const struct path___295 *);
	int (*quota_off)(struct super_block___295 *, int);
	int (*quota_enable)(struct super_block___295 *, unsigned int);
	int (*quota_disable)(struct super_block___295 *, unsigned int);
	int (*quota_sync)(struct super_block___295 *, int);
	int (*set_info)(struct super_block___295 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___295 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___295 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___295 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___295 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___295 *, unsigned int);
};

struct writeback_control___172;

struct address_space_operations___295 {
	int (*writepage)(struct page___300 *, struct writeback_control___172 *);
	int (*readpage)(struct file___295 *, struct page___300 *);
	int (*writepages)(struct address_space___295 *, struct writeback_control___172 *);
	int (*set_page_dirty)(struct page___300 *);
	int (*readpages)(struct file___295 *, struct address_space___295 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___295 *, struct address_space___295 *, loff_t, unsigned int, unsigned int, struct page___300 **, void **);
	int (*write_end)(struct file___295 *, struct address_space___295 *, loff_t, unsigned int, unsigned int, struct page___300 *, void *);
	sector_t (*bmap)(struct address_space___295 *, sector_t);
	void (*invalidatepage)(struct page___300 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___300 *, gfp_t);
	void (*freepage)(struct page___300 *);
	ssize_t (*direct_IO)(struct kiocb___295 *, struct iov_iter___215 *);
	int (*migratepage)(struct address_space___295 *, struct page___300 *, struct page___300 *, enum migrate_mode);
	bool (*isolate_page)(struct page___300 *, isolate_mode_t);
	void (*putback_page)(struct page___300 *);
	int (*launder_page)(struct page___300 *);
	int (*is_partially_uptodate)(struct page___300 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___300 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___295 *, struct page___300 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___295 *, sector_t *);
	void (*swap_deactivate)(struct file___295 *);
};

struct writeback_control___172 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___172 *wb;
	struct inode___295 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___212;

struct iov_iter___215 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___212 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___136 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___295 {
	struct dentry___295 * (*lookup)(struct inode___295 *, struct dentry___295 *, unsigned int);
	const char * (*get_link)(struct dentry___295 *, struct inode___295 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___295 *, int);
	struct posix_acl * (*get_acl)(struct inode___295 *, int, bool);
	int (*readlink)(struct dentry___295 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___295 *, struct dentry___295 *, umode_t, bool);
	int (*link)(struct dentry___295 *, struct inode___295 *, struct dentry___295 *);
	int (*unlink)(struct inode___295 *, struct dentry___295 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___295 *, struct dentry___295 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___295 *, struct dentry___295 *, umode_t);
	int (*rmdir)(struct inode___295 *, struct dentry___295 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___295 *, struct dentry___295 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___295 *, struct dentry___295 *, struct inode___295 *, struct dentry___295 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___295 *, struct iattr___295 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___295 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___295 *, char *, size_t);
	int (*fiemap)(struct inode___295 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___295 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___295 *, struct dentry___295 *, struct file___295 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___295 *, struct dentry___295 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___295 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___295 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___295 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___295 {
	void (*fl_copy_lock)(struct file_lock___295 *, struct file_lock___295 *);
	void (*fl_release_private)(struct file_lock___295 *);
};

struct lock_manager_operations___295;

struct file_lock___295 {
	struct file_lock___295 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___295 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___295 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___295 *fl_ops;
	const struct lock_manager_operations___295 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___295 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___295 *);
	int (*lm_grant)(struct file_lock___295 *, int);
	bool (*lm_break)(struct file_lock___295 *);
	int (*lm_change)(struct file_lock___295 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___295 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___295 *);
};

struct fasync_struct___295 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___295 *fa_next;
	struct file___295 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___295 {
	struct inode___295 * (*alloc_inode)(struct super_block___295 *);
	void (*destroy_inode)(struct inode___295 *);
	void (*free_inode)(struct inode___295 *);
	void (*dirty_inode)(struct inode___295 *, int);
	int (*write_inode)(struct inode___295 *, struct writeback_control___172 *);
	int (*drop_inode)(struct inode___295 *);
	void (*evict_inode)(struct inode___295 *);
	void (*put_super)(struct super_block___295 *);
	int (*sync_fs)(struct super_block___295 *, int);
	int (*freeze_super)(struct super_block___295 *);
	int (*freeze_fs)(struct super_block___295 *);
	int (*thaw_super)(struct super_block___295 *);
	int (*unfreeze_fs)(struct super_block___295 *);
	int (*statfs)(struct dentry___295 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___295 *, int *, char *);
	void (*umount_begin)(struct super_block___295 *);
	int (*show_options)(struct seq_file___270 *, struct dentry___295 *);
	int (*show_devname)(struct seq_file___270 *, struct dentry___295 *);
	int (*show_path)(struct seq_file___270 *, struct dentry___295 *);
	int (*show_stats)(struct seq_file___270 *, struct dentry___295 *);
	ssize_t (*quota_read)(struct super_block___295 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___295 *, int, const char *, size_t, loff_t);
	struct dquot___295 ** (*get_dquots)(struct inode___295 *);
	long int (*nr_cached_objects)(struct super_block___295 *, struct shrink_control___160 *);
	long int (*free_cached_objects)(struct super_block___295 *, struct shrink_control___160 *);
	struct file___295 * (*real_loop)(struct file___295 *);
};

struct wakeup_source___276;

struct dev_pm_info___276 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___276 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___276 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___276;

struct bus_type___276;

struct device_driver___276;

struct dev_pm_domain___276;

struct fwnode_handle___272;

struct class___276;

struct attribute_group___283;

struct device___276 {
	struct kobject___283 kobj;
	struct device___276 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___276 *type;
	struct bus_type___276 *bus;
	struct device_driver___276 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___276 power;
	struct dev_pm_domain___276 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___272 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___276 *class;
	const struct attribute_group___283 **groups;
	void (*release)(struct device___276 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___189 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___295 *bd_inode;
	struct super_block___295 *bd_super;
	void *bd_claiming;
	struct device___276 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___283 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___189 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___295 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___224)(struct file___295 *, wait_queue_head_t *, struct poll_table_struct___216 *);

struct poll_table_struct___216 {
	poll_queue_proc___224 _qproc;
	__poll_t _key;
};

struct seq_operations___270;

struct seq_file___270 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___270 *op;
	int poll_event;
	const struct file___295 *file;
	void *private;
};

typedef void bio_end_io_t___186(struct bio___186 *);

struct bio_vec___212 {
	struct page___300 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___186;

struct bio___186 {
	struct bio___186 *bi_next;
	struct block_device___189 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___186 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___174 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___186 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___212 *bi_io_vec;
	struct bio_set___186 *bi_pool;
	struct bio_vec___212 bi_inline_vecs[0];
};

struct kernfs_root___283;

struct kernfs_elem_dir___283 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___283 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___283;

struct kernfs_root___283 {
	struct kernfs_node___283 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___283 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___283 {
	struct kernfs_node___283 *target_kn;
};

struct kernfs_ops___283;

struct kernfs_elem_attr___283 {
	const struct kernfs_ops___283 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___283 *notify_next;
};

struct kernfs_node___283 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___283 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___283 dir;
		struct kernfs_elem_symlink___283 symlink;
		struct kernfs_elem_attr___283 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___283;

struct kernfs_ops___283 {
	int (*open)(struct kernfs_open_file___283 *);
	void (*release)(struct kernfs_open_file___283 *);
	int (*seq_show)(struct seq_file___270 *, void *);
	void * (*seq_start)(struct seq_file___270 *, loff_t *);
	void * (*seq_next)(struct seq_file___270 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___270 *, void *);
	ssize_t (*read)(struct kernfs_open_file___283 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___283 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___283 *, struct poll_table_struct___216 *);
	int (*mmap)(struct kernfs_open_file___283 *, struct vm_area_struct___300 *);
};

struct kernfs_syscall_ops___283 {
	int (*show_options)(struct seq_file___270 *, struct kernfs_root___283 *);
	int (*mkdir)(struct kernfs_node___283 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___283 *);
	int (*rename)(struct kernfs_node___283 *, struct kernfs_node___283 *, const char *);
	int (*show_path)(struct seq_file___270 *, struct kernfs_node___283 *, struct kernfs_root___283 *);
};

struct kernfs_open_file___283 {
	struct kernfs_node___283 *kn;
	struct file___295 *file;
	struct seq_file___270 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___290 *vm_ops;
};

struct sock___91;

struct kobj_ns_type_operations___91 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___91 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___109 *net;
} possible_net_t___104;

struct proto___91;

struct sock_common___91 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___91 *skc_prot;
	possible_net_t___104 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___91 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___105;

struct sk_buff_head___104 {
	struct sk_buff___105 *next;
	struct sk_buff___105 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___91 {
	struct cgroup___222 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___91;

struct socket_wq___92;

struct xfrm_policy___24;

struct dst_entry___91;

struct socket___93;

struct net_device___104;

struct sock_reuseport___39;

struct sock___91 {
	struct sock_common___91 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___104 sk_error_queue;
	struct sk_buff___105 *sk_rx_skb_cache;
	struct sk_buff_head___104 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___105 *head;
		struct sk_buff___105 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___91 *sk_filter;
	union {
		struct socket_wq___92 *sk_wq;
		struct socket_wq___92 *sk_wq_raw;
	};
	struct xfrm_policy___24 *sk_policy[2];
	struct dst_entry___91 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___91 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___105 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___105 *sk_tx_skb_cache;
	struct sk_buff_head___104 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___300 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___91 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___272 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___93 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___91 sk_cgrp_data;
	struct mem_cgroup___160 *sk_memcg;
	void (*sk_state_change)(struct sock___91 *);
	void (*sk_data_ready)(struct sock___91 *);
	void (*sk_write_space)(struct sock___91 *);
	void (*sk_error_report)(struct sock___91 *);
	int (*sk_backlog_rcv)(struct sock___91 *, struct sk_buff___105 *);
	struct sk_buff___105 * (*sk_validate_xmit_skb)(struct sock___91 *, struct net_device___104 *, struct sk_buff___105 *);
	void (*sk_destruct)(struct sock___91 *);
	struct sock_reuseport___39 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___283;

struct attribute_group___283 {
	const char *name;
	umode_t (*is_visible)(struct kobject___283 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___283 *, struct bin_attribute___283 *, int);
	struct attribute **attrs;
	struct bin_attribute___283 **bin_attrs;
};

struct bin_attribute___283 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___295 * (*f_mapping)();
	ssize_t (*read)(struct file___295 *, struct kobject___283 *, struct bin_attribute___283 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___295 *, struct kobject___283 *, struct bin_attribute___283 *, char *, loff_t, size_t);
	int (*mmap)(struct file___295 *, struct kobject___283 *, struct bin_attribute___283 *, struct vm_area_struct___300 *);
};

struct sysfs_ops___283 {
	ssize_t (*show)(struct kobject___283 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___283 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___283;

struct kset___283 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___283 kobj;
	const struct kset_uevent_ops___283 *uevent_ops;
};

struct kobj_type___283 {
	void (*release)(struct kobject___283 *);
	const struct sysfs_ops___283 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___283 **default_groups;
	const struct kobj_ns_type_operations___91 * (*child_ns_type)(struct kobject___283 *);
	const void * (*namespace)(struct kobject___283 *);
	void (*get_ownership)(struct kobject___283 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___283 {
	int (* const filter)(struct kset___283 *, struct kobject___283 *);
	const char * (* const name)(struct kset___283 *, struct kobject___283 *);
	int (* const uevent)(struct kset___283 *, struct kobject___283 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___279 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___279 *);
	int (*get)(char *, const struct kernel_param___279 *);
	void (*free)(void *);
};

struct kparam_array___279;

struct kernel_param___279 {
	const char *name;
	struct module___279 *mod;
	const struct kernel_param_ops___279 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___279 *arr;
	};
};

struct kparam_array___279 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___279 *ops;
	void *elem;
};

struct module_attribute___279 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___279 *, struct module_kobject___280 *, char *);
	ssize_t (*store)(struct module_attribute___279 *, struct module_kobject___280 *, const char *, size_t);
	void (*setup)(struct module___279 *, const char *);
	int (*test)(struct module___279 *);
	void (*free)(struct module___279 *);
};

struct msghdr___93 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___215 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___295 *msg_iocb;
};

struct dev_pagemap_ops___290 {
	void (*page_free)(struct page___300 *);
	void (*kill)(struct dev_pagemap___290 *);
	void (*cleanup)(struct dev_pagemap___290 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___290 *);
};

struct socket_wq___92 {
	wait_queue_head_t wait;
	struct fasync_struct___295 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___92;

struct socket___93 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___295 *file;
	struct sock___91 *sk;
	const struct proto_ops___92 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___92 wq;
};

typedef int (*sk_read_actor_t___91)(read_descriptor_t *, struct sk_buff___105 *, unsigned int, size_t);

struct proto_ops___92 {
	int family;
	struct module___279 *owner;
	int (*release)(struct socket___93 *);
	int (*bind)(struct socket___93 *, struct sockaddr *, int);
	int (*connect)(struct socket___93 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___93 *, struct socket___93 *);
	int (*accept)(struct socket___93 *, struct socket___93 *, int, bool);
	int (*getname)(struct socket___93 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___295 *, struct socket___93 *, struct poll_table_struct___216 *);
	int (*ioctl)(struct socket___93 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___93 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___93 *, void *, bool, bool);
	int (*listen)(struct socket___93 *, int);
	int (*shutdown)(struct socket___93 *, int);
	int (*setsockopt)(struct socket___93 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___93 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___270 *, struct socket___93 *);
	int (*sendmsg)(struct socket___93 *, struct msghdr___93 *, size_t);
	int (*recvmsg)(struct socket___93 *, struct msghdr___93 *, size_t, int);
	int (*mmap)(struct file___295 *, struct socket___93 *, struct vm_area_struct___300 *);
	ssize_t (*sendpage)(struct socket___93 *, struct page___300 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___93 *, loff_t *, struct pipe_inode_info___136 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___91 *, int);
	int (*peek_len)(struct socket___93 *);
	int (*read_sock)(struct sock___91 *, read_descriptor_t *, sk_read_actor_t___91);
	int (*sendpage_locked)(struct sock___91 *, struct page___300 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___91 *, struct msghdr___93 *, size_t);
	int (*set_rcvlowat)(struct sock___91 *, int);
};

struct sk_buff___105 {
	union {
		struct {
			struct sk_buff___105 *next;
			struct sk_buff___105 *prev;
			union {
				struct net_device___104 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___91 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___105 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___64;

struct fib_rules_ops___91;

struct fqdir___109;

struct tcp_congestion_ops___37;

struct fib_notifier_ops___91;

struct netns_ipv4___109 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___64 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___91 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___91 *fibnl;
	struct sock___91 **icmp_sk;
	struct sock___91 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___91 **tcp_sk;
	struct fqdir___109 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___37 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___91 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___91 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___91 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___91;

struct dst_ops___109 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___109 *);
	struct dst_entry___91 * (*check)(struct dst_entry___91 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___91 *);
	unsigned int (*mtu)(const struct dst_entry___91 *);
	u32 * (*cow_metrics)(struct dst_entry___91 *, long unsigned int);
	void (*destroy)(struct dst_entry___91 *);
	void (*ifdown)(struct dst_entry___91 *, struct net_device___104 *, int);
	struct dst_entry___91 * (*negative_advice)(struct dst_entry___91 *);
	void (*link_failure)(struct sk_buff___105 *);
	void (*update_pmtu)(struct dst_entry___91 *, struct sock___91 *, struct sk_buff___105 *, u32, bool);
	void (*redirect)(struct dst_entry___91 *, struct sock___91 *, struct sk_buff___105 *);
	int (*local_out)(struct net___109 *, struct sock___91 *, struct sk_buff___105 *);
	struct neighbour___91 * (*neigh_lookup)(const struct dst_entry___91 *, struct sk_buff___105 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___91 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___33;

struct rt6_info___33;

struct fib6_table___33;

struct netns_ipv6___109 {
	struct dst_ops___109 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___109 *fqdir;
	struct fib6_info___33 *fib6_null_entry;
	struct rt6_info___33 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___33 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___33 *ip6_prohibit_entry;
	struct rt6_info___33 *ip6_blk_hole_entry;
	struct fib6_table___33 *fib6_local_tbl;
	struct fib_rules_ops___91 *fib6_rules_ops;
	struct sock___91 **icmp_sk;
	struct sock___91 *ndisc_sk;
	struct sock___91 *tcp_sk;
	struct sock___91 *igmp_sk;
	struct sock___91 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___91 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___91 *notifier_ops;
	struct fib_notifier_ops___91 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___109 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___109 *fqdir;
};

struct netns_sctp___91 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___91 *ctl_sock;
	struct sock___91 *udp4_sock;
	struct sock___91 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___98;

struct netns_bpf___98 {
	struct bpf_prog_array___98 *run_array[2];
	struct bpf_prog___98 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___109 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___91 *nlsk;
	struct sock___91 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___109 xfrm4_dst_ops;
	struct dst_ops___109 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___109 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___91 *rtnl;
	struct sock___91 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___104 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___109 ipv4;
	struct netns_ipv6___109 ipv6;
	struct netns_ieee802154_lowpan___109 ieee802154_lowpan;
	struct netns_sctp___91 sctp;
	struct netns_nf___21 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___104 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___98 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___109 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___91 *crypto_nlsk;
	struct sock___91 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___109;

struct fqdir___109 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___109 *f;
	struct net___109 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___109;

struct inet_frags___109 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___109 *, const void *);
	void (*destructor)(struct inet_frag_queue___109 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___109 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___105 *fragments_tail;
	struct sk_buff___105 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___109 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___64 {
	struct ip_ra_chain___64 *next;
	struct sock___91 *sk;
	union {
		void (*destructor)(struct sock___91 *);
		struct sock___91 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___91;

struct fib_lookup_arg___91;

struct fib_rules_ops___91 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___91 *, struct flowi *, int, struct fib_lookup_arg___91 *);
	bool (*suppress)(struct fib_rule___91 *, int, struct fib_lookup_arg___91 *);
	int (*match)(struct fib_rule___91 *, struct flowi *, int);
	int (*configure)(struct fib_rule___91 *, struct sk_buff___105 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___91 *);
	int (*compare)(struct fib_rule___91 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___91 *, struct sk_buff___105 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___91 *);
	void (*flush_cache)(struct fib_rules_ops___91 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___279 *owner;
	struct net___109 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___37 {
	u32 (*ssthresh)(struct sock___91 *);
	void (*cong_avoid)(struct sock___91 *, u32, u32);
	void (*set_state)(struct sock___91 *, u8);
	void (*cwnd_event)(struct sock___91 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___91 *, u32);
	void (*pkts_acked)(struct sock___91 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___91 *);
	void (*cong_control)(struct sock___91 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___91 *);
	u32 (*sndbuf_expand)(struct sock___91 *);
	size_t (*get_info)(struct sock___91 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___279 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___91 *);
	void (*release)(struct sock___91 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___91 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___109 *);
	int (*fib_dump)(struct net___109 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___279 *owner;
	struct callback_head rcu;
};

struct xfrm_state___24;

struct lwtunnel_state___67;

struct dst_entry___91 {
	struct net_device___104 *dev;
	struct dst_ops___109 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___24 *xfrm;
	int (*input)(struct sk_buff___105 *);
	int (*output)(struct net___109 *, struct sock___91 *, struct sk_buff___105 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___67 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___104(struct sk_buff___105 **);

struct bpf_xdp_entity___98 {
	struct bpf_prog___98 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___104;

struct net_device_ops___104;

struct l3mdev_ops___91;

struct ndisc_ops___73;

struct xfrmdev_ops___104;

struct header_ops___104;

struct inet6_dev___73;

struct netdev_rx_queue___104;

struct mini_Qdisc___98;

struct netdev_queue___104;

struct Qdisc___98;

struct rtnl_link_ops___98;

struct dcbnl_rtnl_ops___104;

struct net_device___104 {
	char name[16];
	struct netdev_name_node___104 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___104 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___91 *l3mdev_ops;
	const struct ndisc_ops___73 *ndisc_ops;
	const struct xfrmdev_ops___104 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___104 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___283 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___73 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___104 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___98 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___104 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___98 *miniq_ingress;
	struct netdev_queue___104 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___104 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___98 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___98 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___104 = 0,
		NETREG_REGISTERED___104 = 1,
		NETREG_UNREGISTERING___104 = 2,
		NETREG_UNREGISTERED___104 = 3,
		NETREG_RELEASED___104 = 4,
		NETREG_DUMMY___104 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___104 = 0,
		RTNL_LINK_INITIALIZING___104 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___104 *);
	struct netpoll_info *npinfo;
	possible_net_t___104 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___276 dev;
	const struct attribute_group___283 *sysfs_groups[4];
	const struct attribute_group___283 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___98 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___104 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___98 xdp_state[3];
	long: 64;
};

struct neigh_table___91;

struct neigh_parms___91;

struct neigh_ops___91;

struct neighbour___91 {
	struct neighbour___91 *next;
	struct neigh_table___91 *tbl;
	struct neigh_parms___91 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___104 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___91 *, struct sk_buff___105 *);
	const struct neigh_ops___91 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___104 *dev;
	u8 primary_key[0];
};

struct rtable___35;

struct fnhe_hash_bucket___33;

struct fib_nh_common___33 {
	struct net_device___104 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___67 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___35 **nhc_pcpu_rth_output;
	struct rtable___35 *nhc_rth_input;
	struct fnhe_hash_bucket___33 *nhc_exceptions;
};

struct fib6_nh___33 {
	struct fib_nh_common___33 nh_common;
	long unsigned int last_probe;
	struct rt6_info___33 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___33;

struct nexthop___23;

struct fib6_info___33 {
	struct fib6_table___33 *fib6_table;
	struct fib6_info___33 *fib6_next;
	struct fib6_node___33 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___23 *nh;
	struct fib6_nh___33 fib6_nh[0];
};

struct rt6_info___33 {
	struct dst_entry___91 dst;
	struct fib6_info___33 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___73 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___33 {
	struct fib6_node___33 *parent;
	struct fib6_node___33 *left;
	struct fib6_node___33 *right;
	struct fib6_node___33 *subtree;
	struct fib6_info___33 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___33 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___33 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___33 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___98 {
	struct bpf_prog___98 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___98 {
	struct callback_head rcu;
	struct bpf_prog_array_item___98 items[0];
};

struct bpf_prog_aux___107;

struct bpf_prog___98 {
	u16 pages;
	u16 jited;
	u16 jit_requested;
	u16 gpl_compatible;
	u16 cb_access;
	u16 dst_needed;
	u16 blinded;
	u16 is_func;
	u16 kprobe_override;
	u16 has_callchain_buf;
	u16 enforce_expected_attach_type;
	u16 call_get_stack;
	u16 call_get_func_ip;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___107 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___272;

struct fwnode_handle___272 {
	struct fwnode_handle___272 *secondary;
	const struct fwnode_operations___272 *ops;
	struct device___276 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___272;

struct fwnode_endpoint___272;

struct fwnode_operations___272 {
	struct fwnode_handle___272 * (*get)(struct fwnode_handle___272 *);
	void (*put)(struct fwnode_handle___272 *);
	bool (*device_is_available)(const struct fwnode_handle___272 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___272 *, const struct device___276 *);
	bool (*property_present)(const struct fwnode_handle___272 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___272 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___272 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___272 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*get_parent)(const struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*get_next_child_node)(const struct fwnode_handle___272 *, struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*get_named_child_node)(const struct fwnode_handle___272 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___272 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___272 *);
	struct fwnode_handle___272 * (*graph_get_next_endpoint)(const struct fwnode_handle___272 *, struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*graph_get_remote_endpoint)(const struct fwnode_handle___272 *);
	struct fwnode_handle___272 * (*graph_get_port_parent)(struct fwnode_handle___272 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___272 *, struct fwnode_endpoint___272 *);
	int (*add_links)(struct fwnode_handle___272 *);
};

struct fwnode_endpoint___272 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___272 *local_fwnode;
};

struct fwnode_reference_args___272 {
	struct fwnode_handle___272 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct cgroup_namespace___222 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___222 *root_cset;
};

struct dev_pm_ops___276 {
	int (*prepare)(struct device___276 *);
	void (*complete)(struct device___276 *);
	int (*suspend)(struct device___276 *);
	int (*resume)(struct device___276 *);
	int (*freeze)(struct device___276 *);
	int (*thaw)(struct device___276 *);
	int (*poweroff)(struct device___276 *);
	int (*restore)(struct device___276 *);
	int (*suspend_late)(struct device___276 *);
	int (*resume_early)(struct device___276 *);
	int (*freeze_late)(struct device___276 *);
	int (*thaw_early)(struct device___276 *);
	int (*poweroff_late)(struct device___276 *);
	int (*restore_early)(struct device___276 *);
	int (*suspend_noirq)(struct device___276 *);
	int (*resume_noirq)(struct device___276 *);
	int (*freeze_noirq)(struct device___276 *);
	int (*thaw_noirq)(struct device___276 *);
	int (*poweroff_noirq)(struct device___276 *);
	int (*restore_noirq)(struct device___276 *);
	int (*runtime_suspend)(struct device___276 *);
	int (*runtime_resume)(struct device___276 *);
	int (*runtime_idle)(struct device___276 *);
};

struct wakeup_source___276 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___276 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___276 {
	struct dev_pm_ops___276 ops;
	int (*start)(struct device___276 *);
	void (*detach)(struct device___276 *, bool);
	int (*activate)(struct device___276 *);
	void (*sync)(struct device___276 *);
	void (*dismiss)(struct device___276 *);
};

struct bus_type___276 {
	const char *name;
	const char *dev_name;
	struct device___276 *dev_root;
	const struct attribute_group___283 **bus_groups;
	const struct attribute_group___283 **dev_groups;
	const struct attribute_group___283 **drv_groups;
	int (*match)(struct device___276 *, struct device_driver___276 *);
	int (*uevent)(struct device___276 *, struct kobj_uevent_env *);
	int (*probe)(struct device___276 *);
	void (*sync_state)(struct device___276 *);
	void (*remove)(struct device___276 *);
	void (*shutdown)(struct device___276 *);
	int (*online)(struct device___276 *);
	int (*offline)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	int (*num_vf)(struct device___276 *);
	int (*dma_configure)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___276 {
	const char *name;
	struct bus_type___276 *bus;
	struct module___279 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___276 *);
	void (*sync_state)(struct device___276 *);
	int (*remove)(struct device___276 *);
	void (*shutdown)(struct device___276 *);
	int (*suspend)(struct device___276 *, pm_message_t);
	int (*resume)(struct device___276 *);
	const struct attribute_group___283 **groups;
	const struct attribute_group___283 **dev_groups;
	const struct dev_pm_ops___276 *pm;
	void (*coredump)(struct device___276 *);
	struct driver_private *p;
};

struct device_type___276 {
	const char *name;
	const struct attribute_group___283 **groups;
	int (*uevent)(struct device___276 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___276 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___276 *);
	const struct dev_pm_ops___276 *pm;
};

struct class___276 {
	const char *name;
	struct module___279 *owner;
	const struct attribute_group___283 **class_groups;
	const struct attribute_group___283 **dev_groups;
	struct kobject___283 *dev_kobj;
	int (*dev_uevent)(struct device___276 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___276 *, umode_t *);
	void (*class_release)(struct class___276 *);
	void (*dev_release)(struct device___276 *);
	int (*shutdown_pre)(struct device___276 *);
	const struct kobj_ns_type_operations___91 *ns_type;
	const void * (*namespace)(struct device___276 *);
	void (*get_ownership)(struct device___276 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___276 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___136;

struct pipe_buffer___136 {
	struct page___300 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___136 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___136 {
	int (*confirm)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
	void (*release)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
	bool (*try_steal)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
	bool (*get)(struct pipe_inode_info___136 *, struct pipe_buffer___136 *);
};

typedef struct bio_vec___212 skb_frag_t___42;

struct ubuf_info___14 {
	void (*callback)(struct sk_buff___105 *, struct ubuf_info___14 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___36 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___105 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___42 frags[17];
};

struct seq_operations___270 {
	void * (*start)(struct seq_file___270 *, loff_t *);
	void (*stop)(struct seq_file___270 *, void *);
	void * (*next)(struct seq_file___270 *, void *, loff_t *);
	int (*show)(struct seq_file___270 *, void *);
};

struct seq_net_private___16 {
	struct net___109 *net;
};

struct pernet_operations___38 {
	struct list_head list;
	int (*init)(struct net___109 *);
	void (*pre_exit)(struct net___109 *);
	void (*exit)(struct net___109 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___104 {
	int (*ieee_getets)(struct net_device___104 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___104 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___104 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___104 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___104 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___104 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___104 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___104 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___104 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___104 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___104 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___104 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___104 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___104 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___104 *);
	u8 (*setstate)(struct net_device___104 *, u8);
	void (*getpermhwaddr)(struct net_device___104 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___104 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___104 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___104 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___104 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___104 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___104 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___104 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___104 *, int, u8 *);
	void (*setpfccfg)(struct net_device___104 *, int, u8);
	void (*getpfccfg)(struct net_device___104 *, int, u8 *);
	u8 (*setall)(struct net_device___104 *);
	u8 (*getcap)(struct net_device___104 *, int, u8 *);
	int (*getnumtcs)(struct net_device___104 *, int, u8 *);
	int (*setnumtcs)(struct net_device___104 *, int, u8);
	u8 (*getpfcstate)(struct net_device___104 *);
	void (*setpfcstate)(struct net_device___104 *, u8);
	void (*getbcncfg)(struct net_device___104 *, int, u32 *);
	void (*setbcncfg)(struct net_device___104 *, int, u32);
	void (*getbcnrp)(struct net_device___104 *, int, u8 *);
	void (*setbcnrp)(struct net_device___104 *, int, u8);
	int (*setapp)(struct net_device___104 *, u8, u16, u8);
	int (*getapp)(struct net_device___104 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___104 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___104 *, int, u8);
	u8 (*getdcbx)(struct net_device___104 *);
	u8 (*setdcbx)(struct net_device___104 *, u8);
	int (*peer_getappinfo)(struct net_device___104 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___104 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___104 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___104 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___104 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___104 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___107;

typedef int (*bpf_iter_init_seq_priv_t___106)(void *, struct bpf_iter_aux_info___107 *);

struct bpf_map___107;

struct bpf_iter_aux_info___107 {
	struct bpf_map___107 *map;
};

struct bpf_iter_seq_info___106 {
	const struct seq_operations___270 *seq_ops;
	bpf_iter_init_seq_priv_t___106 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___106 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___107 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___107 *, struct file___295 *);
	void (*map_free)(struct bpf_map___107 *);
	int (*map_get_next_key)(struct bpf_map___107 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___107 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___107 *, void *);
	int (*map_lookup_batch)(struct bpf_map___107 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___107 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___107 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___107 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___107 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___107 *, void *);
	int (*map_update_elem)(struct bpf_map___107 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___107 *, void *);
	int (*map_push_elem)(struct bpf_map___107 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___107 *, void *);
	int (*map_peek_elem)(struct bpf_map___107 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___107 *, struct file___295 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___107 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___107 *, void *, struct seq_file___270 *);
	int (*map_check_btf)(const struct bpf_map___107 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___107 *, struct bpf_prog_aux___107 *);
	void (*map_poke_untrack)(struct bpf_map___107 *, struct bpf_prog_aux___107 *);
	void (*map_poke_run)(struct bpf_map___107 *, u32, struct bpf_prog___98 *, struct bpf_prog___98 *);
	int (*map_direct_value_addr)(const struct bpf_map___107 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___107 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___107 *, struct vm_area_struct___300 *);
	__poll_t (*map_poll)(struct bpf_map___107 *, struct file___295 *, struct poll_table_struct___216 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___107 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___107 *, const struct bpf_map___107 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___107 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___106 *iter_seq_info;
};

struct bpf_map___107 {
	const struct bpf_map_ops___106 *ops;
	struct bpf_map___107 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___160 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___106;

struct bpf_jit_poke_descriptor___106;

struct bpf_prog_ops___98;

struct btf_mod_pair___106;

struct bpf_prog_offload___104;

struct bpf_prog_aux___107 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___98 *dst_prog;
	struct bpf_trampoline___106 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___98 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___106 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___98 *ops;
	struct bpf_map___107 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___106 *used_btfs;
	struct bpf_prog___98 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___107 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___104 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___104;

struct bpf_map_dev_ops___104 {
	int (*map_get_next_key)(struct bpf_offloaded_map___104 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___104 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___104 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___104 *, void *);
};

struct bpf_offloaded_map___104 {
	struct bpf_map___107 map;
	struct net_device___104 *netdev;
	const struct bpf_map_dev_ops___104 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___98 {
	int (*test_run)(struct bpf_prog___98 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___104 {
	struct bpf_prog___98 *prog;
	struct net_device___104 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___106 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___98 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___279 *mod;
};

struct bpf_jit_poke_descriptor___106 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___107 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___106 {
	struct btf *btf;
	struct module___279 *module;
};

struct cftype___222;

struct cgroup_subsys___222 {
	struct cgroup_subsys_state___222 * (*css_alloc)(struct cgroup_subsys_state___222 *);
	int (*css_online)(struct cgroup_subsys_state___222 *);
	void (*css_offline)(struct cgroup_subsys_state___222 *);
	void (*css_released)(struct cgroup_subsys_state___222 *);
	void (*css_free)(struct cgroup_subsys_state___222 *);
	void (*css_reset)(struct cgroup_subsys_state___222 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___222 *, int);
	int (*css_extra_stat_show)(struct seq_file___270 *, struct cgroup_subsys_state___222 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___302 *, struct css_set___222 *);
	void (*cancel_fork)(struct task_struct___302 *, struct css_set___222 *);
	void (*fork)(struct task_struct___302 *);
	void (*exit)(struct task_struct___302 *);
	void (*release)(struct task_struct___302 *);
	void (*bind)(struct cgroup_subsys_state___222 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___222 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___222 *dfl_cftypes;
	struct cftype___222 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___222 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___222 *updated_children;
	struct cgroup___222 *updated_next;
};

struct cgroup_root___222 {
	struct kernfs_root___283 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___222 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___222 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___222 *ss;
	struct list_head node;
	struct kernfs_ops___283 *kf_ops;
	int (*open)(struct kernfs_open_file___283 *);
	void (*release)(struct kernfs_open_file___283 *);
	u64 (*read_u64)(struct cgroup_subsys_state___222 *, struct cftype___222 *);
	s64 (*read_s64)(struct cgroup_subsys_state___222 *, struct cftype___222 *);
	int (*seq_show)(struct seq_file___270 *, void *);
	void * (*seq_start)(struct seq_file___270 *, loff_t *);
	void * (*seq_next)(struct seq_file___270 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___270 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___222 *, struct cftype___222 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___222 *, struct cftype___222 *, s64);
	ssize_t (*write)(struct kernfs_open_file___283 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___283 *, struct poll_table_struct___216 *);
};

struct xdp_rxq_info___104 {
	struct net_device___104 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___104 {
	struct net_device___104 *dev;
};

struct xdp_buff___104 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___104 *rxq;
	struct xdp_txq_info___104 *txq;
	u32 frame_sz;
};

struct xdp_frame___104 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___104 *dev_rx;
};

struct netlink_callback___104 {
	struct sk_buff___105 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___105 *, struct netlink_callback___104 *);
	int (*done)(struct netlink_callback___104 *);
	void *data;
	struct module___279 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___104 {
	int (*create)(struct sk_buff___105 *, struct net_device___104 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___105 *, unsigned char *);
	int (*cache)(const struct neighbour___91 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___104 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___105 *);
};

struct netdev_queue___104 {
	struct net_device___104 *dev;
	struct Qdisc___98 *qdisc;
	struct Qdisc___98 *qdisc_sleeping;
	struct kobject___283 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___104 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___98 {
	struct sk_buff___105 *head;
	struct sk_buff___105 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___98;

struct Qdisc___98 {
	int (*enqueue)(struct sk_buff___105 *, struct Qdisc___98 *, struct sk_buff___105 **);
	struct sk_buff___105 * (*dequeue)(struct Qdisc___98 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___98 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___104 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___104 gso_skb;
	struct qdisc_skb_head___98 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___98 *next_sched;
	struct sk_buff_head___104 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___104 {
	struct xdp_rxq_info___104 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___283 kobj;
	struct net_device___104 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___104 {
	enum net_device_path_type type;
	const struct net_device___104 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___104 = 0,
				DEV_PATH_BR_VLAN_TAG___104 = 1,
				DEV_PATH_BR_VLAN_UNTAG___104 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___104 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___104 {
	const struct net_device___104 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___104 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___98 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___104 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___104 {
	int (*xdo_dev_state_add)(struct xfrm_state___24 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___24 *);
	void (*xdo_dev_state_free)(struct xfrm_state___24 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___105 *, struct xfrm_state___24 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___24 *);
};

struct xfrm_state_offload___24 {
	struct net_device___104 *dev;
	struct net_device___104 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___24;

struct xfrm_type_offload___24;

struct xfrm_state___24 {
	possible_net_t___104 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___91 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___24 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___24 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___300 xfrag;
	const struct xfrm_type___24 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___24 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___104 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___104 *dev;
	const char *name;
};

struct net_device_ops___104 {
	int (*ndo_init)(struct net_device___104 *);
	void (*ndo_uninit)(struct net_device___104 *);
	int (*ndo_open)(struct net_device___104 *);
	int (*ndo_stop)(struct net_device___104 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___105 *, struct net_device___104 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___105 *, struct net_device___104 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___104 *, struct sk_buff___105 *, struct net_device___104 *);
	void (*ndo_change_rx_flags)(struct net_device___104 *, int);
	void (*ndo_set_rx_mode)(struct net_device___104 *);
	int (*ndo_set_mac_address)(struct net_device___104 *, void *);
	int (*ndo_validate_addr)(struct net_device___104 *);
	int (*ndo_do_ioctl)(struct net_device___104 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___104 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___104 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___104 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___104 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___104 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___104 *, int);
	int (*ndo_neigh_setup)(struct net_device___104 *, struct neigh_parms___91 *);
	void (*ndo_tx_timeout)(struct net_device___104 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___104 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___104 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___104 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___104 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___104 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___104 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___104 *);
	int (*ndo_netpoll_setup)(struct net_device___104 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___104 *);
	int (*ndo_set_vf_mac)(struct net_device___104 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___104 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___104 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___104 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___104 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___104 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___104 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___104 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___104 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___104 *, int, struct sk_buff___105 *);
	int (*ndo_get_vf_guid)(struct net_device___104 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___104 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___104 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___104 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___104 *);
	int (*ndo_fcoe_disable)(struct net_device___104 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___104 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___104 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___104 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___104 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___104 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___104 *, const struct sk_buff___105 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___104 *, struct net_device___104 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___104 *, struct net_device___104 *);
	struct net_device___104 * (*ndo_get_xmit_slave)(struct net_device___104 *, struct sk_buff___105 *, bool);
	struct net_device___104 * (*ndo_sk_get_lower_dev)(struct net_device___104 *, struct sock___91 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___104 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___104 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___104 *, struct neighbour___91 *);
	void (*ndo_neigh_destroy)(struct net_device___104 *, struct neighbour___91 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___104 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___104 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___105 *, struct netlink_callback___104 *, struct net_device___104 *, struct net_device___104 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___105 *, struct nlattr **, struct net_device___104 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___104 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___105 *, u32, u32, struct net_device___104 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___104 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___104 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___104 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___104 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___104 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___104 *, struct net_device___104 *);
	void (*ndo_dfwd_del_station)(struct net_device___104 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___104 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___104 *);
	int (*ndo_change_proto_down)(struct net_device___104 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___104 *, struct sk_buff___105 *);
	void (*ndo_set_rx_headroom)(struct net_device___104 *, int);
	int (*ndo_bpf)(struct net_device___104 *, struct netdev_bpf___104 *);
	int (*ndo_xdp_xmit)(struct net_device___104 *, int, struct xdp_frame___104 **, u32);
	struct net_device___104 * (*ndo_xdp_get_xmit_slave)(struct net_device___104 *, struct xdp_buff___104 *);
	int (*ndo_xsk_wakeup)(struct net_device___104 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___104 *);
	int (*ndo_tunnel_ctl)(struct net_device___104 *, struct ip_tunnel_parm *, int);
	struct net_device___104 * (*ndo_get_peer_dev)(struct net_device___104 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___104 *, struct net_device_path___104 *);
};

struct neigh_parms___91 {
	possible_net_t___104 net;
	struct net_device___104 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___91 *);
	struct neigh_table___91 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___91 {
	u32 (*l3mdev_fib_table)(const struct net_device___104 *);
	struct sk_buff___105 * (*l3mdev_l3_rcv)(struct net_device___104 *, struct sk_buff___105 *, u16);
	struct sk_buff___105 * (*l3mdev_l3_out)(struct net_device___104 *, struct sock___91 *, struct sk_buff___105 *, u16);
	struct dst_entry___91 * (*l3mdev_link_scope_lookup)(const struct net_device___104 *, struct flowi6 *);
};

struct ndisc_ops___73 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___104 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___104 *, struct neighbour___91 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___104 *, u8, struct neighbour___91 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___104 *, struct sk_buff___105 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___109 *, struct net_device___104 *, const struct prefix_info *, struct inet6_dev___73 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___73;

struct ifacaddr6___33;

struct inet6_dev___73 {
	struct net_device___104 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___73 *mc_list;
	struct ifmcaddr6___73 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___104 mc_query_queue;
	struct sk_buff_head___104 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___33 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___91 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___98;

struct tcf_block___98;

struct mini_Qdisc___98 {
	struct tcf_proto___98 *filter_list;
	struct tcf_block___98 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___98 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___104 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___104 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___109 *, struct net_device___104 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___104 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___104 *, struct list_head *);
	size_t (*get_size)(const struct net_device___104 *);
	int (*fill_info)(struct sk_buff___105 *, const struct net_device___104 *);
	size_t (*get_xstats_size)(const struct net_device___104 *);
	int (*fill_xstats)(struct sk_buff___105 *, const struct net_device___104 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___104 *, struct net_device___104 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___104 *, const struct net_device___104 *);
	int (*fill_slave_info)(struct sk_buff___105 *, const struct net_device___104 *, const struct net_device___104 *);
	struct net___109 * (*get_link_net)(const struct net_device___104 *);
	size_t (*get_linkxstats_size)(const struct net_device___104 *, int);
	int (*fill_linkxstats)(struct sk_buff___105 *, const struct net_device___104 *, int *, int);
};

struct block_device_operations___186;

struct gendisk___189 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___189 *part0;
	const struct block_device_operations___186 *fops;
	struct request_queue___186 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___172 *bdi;
	struct kobject___283 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___283 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___186 {
	struct bio___186 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___212 *bip_vec;
	struct bio_vec___212 bip_inline_vecs[0];
};

struct blkcg___174;

struct blkg_policy_data___174;

struct blkcg_gq___174 {
	struct request_queue___186 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___174 *blkcg;
	struct blkcg_gq___174 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___174 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___186 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___186(struct request___186 *);

typedef void integrity_complete_fn___186(struct request___186 *, unsigned int);

struct blk_integrity_profile___186 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___186 *prepare_fn;
	integrity_complete_fn___186 *complete_fn;
	const char *name;
};

struct block_device_operations___186 {
	blk_qc_t (*submit_bio)(struct bio___186 *);
	int (*open)(struct block_device___189 *, fmode_t);
	void (*release)(struct gendisk___189 *, fmode_t);
	int (*rw_page)(struct block_device___189 *, sector_t, struct page___300 *, unsigned int);
	int (*ioctl)(struct block_device___189 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___189 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___189 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___189 *);
	int (*getgeo)(struct block_device___189 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___189 *, bool);
	void (*swap_slot_free_notify)(struct block_device___189 *, long unsigned int);
	int (*report_zones)(struct gendisk___189 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___189 *, umode_t *);
	struct module___279 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___189 *, sector_t *);
};

typedef void rq_end_io_fn___186(struct request___186 *, blk_status_t);

struct request___186 {
	struct request_queue___186 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___181 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___186 *bio;
	struct bio___186 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___212 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___186 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___186 *saved_end_io;
		} flush;
	};
	struct gendisk___189 *rq_disk;
	struct block_device___189 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___186 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___181 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___186 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___283 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___295 *debugfs_dir;
	struct dentry___295 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___186;

struct elevator_mq_ops___186 {
	int (*init_sched)(struct request_queue___186 *, struct elevator_type___186 *);
	void (*exit_sched)(struct elevator_queue___186 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___181 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___181 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___181 *);
	bool (*allow_merge)(struct request_queue___186 *, struct request___186 *, struct bio___186 *);
	bool (*bio_merge)(struct request_queue___186 *, struct bio___186 *, unsigned int);
	int (*request_merge)(struct request_queue___186 *, struct request___186 **, struct bio___186 *);
	void (*request_merged)(struct request_queue___186 *, struct request___186 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___186 *, struct request___186 *, struct request___186 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___186 *);
	void (*finish_request)(struct request___186 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___181 *, struct list_head *, bool);
	struct request___186 * (*dispatch_request)(struct blk_mq_hw_ctx___181 *);
	bool (*has_work)(struct blk_mq_hw_ctx___181 *);
	void (*completed_request)(struct request___186 *, u64);
	void (*requeue_request)(struct request___186 *);
	struct request___186 * (*former_request)(struct request_queue___186 *, struct request___186 *);
	struct request___186 * (*next_request)(struct request_queue___186 *, struct request___186 *);
	void (*init_icq)(struct io_cq___186 *);
	void (*exit_icq)(struct io_cq___186 *);
};

struct elv_fs_entry___186;

struct elevator_type___186 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___186 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___186 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___279 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___186 {
	struct elevator_type___186 *type;
	void *elevator_data;
	struct kobject___283 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___186 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___186 *, char *);
	ssize_t (*store)(struct elevator_queue___186 *, const char *, size_t);
};

struct blk_mq_queue_data___181;

struct blk_mq_ops___181 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___181 *, const struct blk_mq_queue_data___181 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___181 *);
	int (*get_budget)(struct request_queue___186 *);
	void (*put_budget)(struct request_queue___186 *, int);
	void (*set_rq_budget_token)(struct request___186 *, int);
	int (*get_rq_budget_token)(struct request___186 *);
	enum blk_eh_timer_return (*timeout)(struct request___186 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___181 *);
	void (*complete)(struct request___186 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___181 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___181 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___181 *, struct request___186 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___181 *, struct request___186 *, unsigned int);
	void (*initialize_rq_fn)(struct request___186 *);
	void (*cleanup_rq)(struct request___186 *);
	bool (*busy)(struct request_queue___186 *);
	int (*map_queues)(struct blk_mq_tag_set___181 *);
	void (*show_rq)(struct seq_file___270 *, struct request___186 *);
};

struct blk_mq_tag_set___181 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___181 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___181 {
	struct request___186 *rq;
	bool last;
};

struct blkcg_policy_data___174;

struct blkcg___174 {
	struct cgroup_subsys_state___222 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___174 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___174 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___174 {
	struct blkcg___174 *blkcg;
	int plid;
};

struct blkg_policy_data___174 {
	struct blkcg_gq___174 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___160 {
	struct mem_cgroup___160 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___160 {
	struct lruvec___168 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___160 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___160 *memcg;
};

struct obj_cgroup___160 {
	struct percpu_ref refcnt;
	struct mem_cgroup___160 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___98 {
	spinlock_t *lock;
	struct sk_buff___105 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___98;

struct Qdisc_ops___98 {
	struct Qdisc_ops___98 *next;
	const struct Qdisc_class_ops___98 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___105 *, struct Qdisc___98 *, struct sk_buff___105 **);
	struct sk_buff___105 * (*dequeue)(struct Qdisc___98 *);
	struct sk_buff___105 * (*peek)(struct Qdisc___98 *);
	int (*init)(struct Qdisc___98 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___98 *);
	void (*destroy)(struct Qdisc___98 *);
	int (*change)(struct Qdisc___98 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___98 *);
	int (*change_tx_queue_len)(struct Qdisc___98 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___98 *, unsigned int);
	int (*dump)(struct Qdisc___98 *, struct sk_buff___105 *);
	int (*dump_stats)(struct Qdisc___98 *, struct gnet_dump___98 *);
	void (*ingress_block_set)(struct Qdisc___98 *, u32);
	void (*egress_block_set)(struct Qdisc___98 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___98 *);
	u32 (*egress_block_get)(struct Qdisc___98 *);
	struct module___279 *owner;
};

struct Qdisc_class_ops___98 {
	unsigned int flags;
	struct netdev_queue___104 * (*select_queue)(struct Qdisc___98 *, struct tcmsg *);
	int (*graft)(struct Qdisc___98 *, long unsigned int, struct Qdisc___98 *, struct Qdisc___98 **, struct netlink_ext_ack *);
	struct Qdisc___98 * (*leaf)(struct Qdisc___98 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___98 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___98 *, u32);
	int (*change)(struct Qdisc___98 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___98 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___98 *, struct qdisc_walker *);
	struct tcf_block___98 * (*tcf_block)(struct Qdisc___98 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___98 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___98 *, long unsigned int);
	int (*dump)(struct Qdisc___98 *, long unsigned int, struct sk_buff___105 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___98 *, long unsigned int, struct gnet_dump___98 *);
};

struct tcf_chain___98;

struct tcf_block___98 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___109 *net;
	struct Qdisc___98 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___98 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___98;

struct tcf_proto_ops___98;

struct tcf_proto___98 {
	struct tcf_proto___98 *next;
	void *root;
	int (*classify)(struct sk_buff___105 *, const struct tcf_proto___98 *, struct tcf_result___98 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___98 *ops;
	struct tcf_chain___98 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___98 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___98 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___98 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___105 *, const struct tcf_proto___98 *, struct tcf_result___98 *);
	int (*init)(struct tcf_proto___98 *);
	void (*destroy)(struct tcf_proto___98 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___98 *, u32);
	void (*put)(struct tcf_proto___98 *, void *);
	int (*change)(struct net___109 *, struct sk_buff___105 *, struct tcf_proto___98 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___98 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___98 *);
	void (*walk)(struct tcf_proto___98 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___98 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___98 *, void *);
	void (*hw_del)(struct tcf_proto___98 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___109 *, struct tcf_chain___98 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___109 *, struct tcf_proto___98 *, void *, struct sk_buff___105 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___109 *, struct tcf_proto___98 *, void *, struct sk_buff___105 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___105 *, struct net___109 *, void *);
	struct module___279 *owner;
	int flags;
};

struct tcf_chain___98 {
	struct mutex filter_chain_lock;
	struct tcf_proto___98 *filter_chain;
	struct list_head list;
	struct tcf_block___98 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___98 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___91 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___98 *prog;
};

struct bpf_sock_ops_kern___9 {
	struct sock___91 *sk;
	union {
		u32 args[4];
		u32 reply;
		u32 replylong[4];
	};
	struct sk_buff___105 *syn_skb;
	struct sk_buff___105 *skb;
	void *skb_data_end;
	u8 op;
	u8 is_fullsock;
	u8 remaining_opt_len;
	u64 temp;
};

struct pneigh_entry___91;

struct neigh_hash_table___91;

struct neigh_table___91 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___104 *, __u32 *);
	bool (*key_eq)(const struct neighbour___91 *, const void *);
	int (*constructor)(struct neighbour___91 *);
	int (*pconstructor)(struct pneigh_entry___91 *);
	void (*pdestructor)(struct pneigh_entry___91 *);
	void (*proxy_redo)(struct sk_buff___105 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___104 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___91 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___104 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___91 *nht;
	struct pneigh_entry___91 **phash_buckets;
};

struct neigh_ops___91 {
	int family;
	void (*solicit)(struct neighbour___91 *, struct sk_buff___105 *);
	void (*error_report)(struct neighbour___91 *, struct sk_buff___105 *);
	int (*output)(struct neighbour___91 *, struct sk_buff___105 *);
	int (*connected_output)(struct neighbour___91 *, struct sk_buff___105 *);
};

struct pneigh_entry___91 {
	struct pneigh_entry___91 *next;
	possible_net_t___104 net;
	struct net_device___104 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___91 {
	struct neighbour___91 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___67 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___109 *, struct sock___91 *, struct sk_buff___105 *);
	int (*orig_input)(struct sk_buff___105 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___91 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___91 *ctarget;
	struct net___109 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___91 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___91 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___76;

struct timewait_sock_ops___75;

struct proto___91 {
	void (*close)(struct sock___91 *, long int);
	int (*pre_connect)(struct sock___91 *, struct sockaddr *, int);
	int (*connect)(struct sock___91 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___91 *, int);
	struct sock___91 * (*accept)(struct sock___91 *, int, int *, bool);
	int (*ioctl)(struct sock___91 *, int, long unsigned int);
	int (*init)(struct sock___91 *);
	void (*destroy)(struct sock___91 *);
	void (*shutdown)(struct sock___91 *, int);
	int (*setsockopt)(struct sock___91 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___91 *, int, int, char *, int *);
	void (*keepalive)(struct sock___91 *, int);
	int (*compat_ioctl)(struct sock___91 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___91 *, struct msghdr___93 *, size_t);
	int (*recvmsg)(struct sock___91 *, struct msghdr___93 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___91 *, struct page___300 *, int, size_t, int);
	int (*bind)(struct sock___91 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___91 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___91 *, struct sk_buff___105 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___91 *);
	int (*hash)(struct sock___91 *);
	void (*unhash)(struct sock___91 *);
	void (*rehash)(struct sock___91 *);
	int (*get_port)(struct sock___91 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___91 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___91 *, int);
	bool (*sock_is_readable)(struct sock___91 *);
	void (*enter_memory_pressure)(struct sock___91 *);
	void (*leave_memory_pressure)(struct sock___91 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___76 *rsk_prot;
	struct timewait_sock_ops___75 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___279 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___91 *, int);
};

struct xfrm_policy_queue___24 {
	struct sk_buff_head___104 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___24 {
	possible_net_t___104 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___24 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___39 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___98 *prog;
	struct sock___91 *socks[0];
};

struct request_sock___77;

struct request_sock_ops___76 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___91 *, struct request_sock___77 *);
	void (*send_ack)(const struct sock___91 *, struct sk_buff___105 *, struct request_sock___77 *);
	void (*send_reset)(const struct sock___91 *, struct sk_buff___105 *);
	void (*destructor)(struct request_sock___77 *);
	void (*syn_ack_timeout)(const struct request_sock___77 *);
};

struct timewait_sock_ops___75 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___91 *, struct sock___91 *, void *);
	void (*twsk_destructor)(struct sock___91 *);
};

struct request_sock___77 {
	struct sock_common___91 __req_common;
	struct request_sock___77 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___76 *rsk_ops;
	struct sock___91 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___14 {
	struct request_sock___77 *rskq_rst_head;
	struct request_sock___77 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___14 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___77 *rskq_accept_head;
	struct request_sock___77 *rskq_accept_tail;
	struct fastopen_queue___14 fastopenq;
};

struct inet_request_sock___7 {
	struct request_sock___77 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___105 *pktopts;
		};
	};
};

struct inet_cork___26 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___91 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___26 {
	struct inet_cork___26 base;
	struct flowi fl;
};

struct ipv6_pinfo___25;

struct inet_sock___26 {
	struct sock___91 sk;
	struct ipv6_pinfo___25 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___26 cork;
};

struct ipv6_fl_socklist___25;

struct ipv6_pinfo___25 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___25 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___105 *pktoptions;
	struct sk_buff___105 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___14 {
	int (*queue_xmit)(struct sock___91 *, struct sk_buff___105 *, struct flowi *);
	void (*send_check)(struct sock___91 *, struct sk_buff___105 *);
	int (*rebuild_header)(struct sock___91 *);
	void (*sk_rx_dst_set)(struct sock___91 *, const struct sk_buff___105 *);
	int (*conn_request)(struct sock___91 *, struct sk_buff___105 *);
	struct sock___91 * (*syn_recv_sock)(const struct sock___91 *, struct sk_buff___105 *, struct request_sock___77 *, struct dst_entry___91 *, struct request_sock___77 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___91 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___91 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___91 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___91 *);
};

struct inet_bind_bucket___14;

struct tcp_ulp_ops___14;

struct inet_connection_sock___14 {
	struct inet_sock___26 icsk_inet;
	struct request_sock_queue___14 icsk_accept_queue;
	struct inet_bind_bucket___14 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___37 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___14 *icsk_af_ops;
	const struct tcp_ulp_ops___14 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___91 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___91 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___14 {
	possible_net_t___104 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___14 {
	struct list_head list;
	int (*init)(struct sock___91 *);
	void (*update)(struct sock___91 *, struct proto___91 *, void (*)(struct sock___91 *));
	void (*release)(struct sock___91 *);
	int (*get_info)(const struct sock___91 *, struct sk_buff___105 *);
	size_t (*get_info_size)(const struct sock___91 *);
	void (*clone)(const struct request_sock___77 *, struct sock___91 *, const gfp_t);
	char name[16];
	struct module___279 *owner;
};

struct inet_timewait_sock___3 {
	struct sock_common___91 __tw_common;
	__u32 tw_mark;
	volatile unsigned char tw_substate;
	unsigned char tw_rcv_wscale;
	__be16 tw_sport;
	unsigned int tw_kill: 1;
	unsigned int tw_transparent: 1;
	unsigned int tw_flowlabel: 20;
	unsigned int tw_pad: 2;
	unsigned int tw_tos: 8;
	long: 24;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tw_txhash;
	u32 tw_priority;
	struct timer_list tw_timer;
	struct inet_bind_bucket___14 *tw_tb;
};

struct tcp_request_sock_ops___6;

struct tcp_request_sock___6 {
	struct inet_request_sock___7 req;
	const struct tcp_request_sock_ops___6 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_request_sock_ops___6 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___91 *, const struct sock___91 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___91 *, const struct sk_buff___105 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___105 *, __u16 *);
	struct dst_entry___91 * (*route_req)(const struct sock___91 *, struct sk_buff___105 *, struct flowi *, struct request_sock___77 *);
	u32 (*init_seq)(const struct sk_buff___105 *);
	u32 (*init_ts_off)(const struct net___109 *, const struct sk_buff___105 *);
	int (*send_synack)(const struct sock___91 *, struct dst_entry___91 *, struct flowi *, struct request_sock___77 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___105 *);
};

struct tcp_sock_af_ops___11;

struct tcp_fastopen_request___11;

struct tcp_sock___11 {
	struct inet_connection_sock___14 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___105 *lost_skb_hint;
	struct sk_buff___105 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___105 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___105 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___11 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___11 *fastopen_req;
	struct request_sock___77 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___11 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___91 *, const struct sock___91 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___91 *, const struct sk_buff___105 *);
	int (*md5_parse)(struct sock___91 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___11 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___93 *data;
	size_t size;
	int copied;
	struct ubuf_info___14 *uarg;
};

struct tcp_timewait_sock___3 {
	struct inet_timewait_sock___3 tw_sk;
	u32 tw_rcv_wnd;
	u32 tw_ts_offset;
	u32 tw_ts_recent;
	u32 tw_last_oow_ack_time;
	int tw_ts_recent_stamp;
	u32 tw_tx_delay;
	struct tcp_md5sig_key *tw_md5_key;
};

struct ip6_flowlabel___25;

struct ipv6_fl_socklist___25 {
	struct ipv6_fl_socklist___25 *next;
	struct ip6_flowlabel___25 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___73 {
	struct in6_addr mca_addr;
	struct inet6_dev___73 *idev;
	struct ifmcaddr6___73 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___33 {
	struct in6_addr aca_addr;
	struct fib6_info___33 *aca_rt;
	struct ifacaddr6___33 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___25 {
	struct ip6_flowlabel___25 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___272 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___109 *fl_net;
};

struct fib_nh_exception___33 {
	struct fib_nh_exception___33 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___35 *fnhe_rth_input;
	struct rtable___35 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___35 {
	struct dst_entry___91 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___33 {
	struct fib_nh_exception___33 *chain;
};

struct fib_info___23;

struct fib_nh___23 {
	struct fib_nh_common___33 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___23 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___23 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___109 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___23 *nh;
	struct callback_head rcu;
	struct fib_nh___23 fib_nh[0];
};

struct nh_info___23;

struct nh_group___23;

struct nexthop___23 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___109 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___23 *nh_info;
		struct nh_group___23 *nh_grp;
	};
};

struct tcp6_pseudohdr {
	struct in6_addr saddr;
	struct in6_addr daddr;
	__be32 len;
	__be32 protocol;
};

struct ahash_request___9;

struct tcp_md5sig_pool___3 {
	struct ahash_request___9 *md5_req;
	void *scratch;
};

struct crypto_async_request___13;

typedef void (*crypto_completion_t___13)(struct crypto_async_request___13 *, int);

struct crypto_tfm___29;

struct crypto_async_request___13 {
	struct list_head list;
	crypto_completion_t___13 complete;
	void *data;
	struct crypto_tfm___29 *tfm;
	u32 flags;
};

struct ahash_request___9 {
	struct crypto_async_request___13 base;
	unsigned int nbytes;
	struct scatterlist *src;
	u8 *result;
	void *priv;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__ctx[0];
};

struct tcp_iter_state___2 {
	struct seq_net_private___16 p;
	enum tcp_seq_states state;
	struct sock___91 *syn_wait_sk;
	int bucket;
	int offset;
	int sbucket;
	int num;
	loff_t last_pos;
};

struct nh_info___23 {
	struct hlist_node dev_hash;
	struct nexthop___23 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___33 fib_nhc;
		struct fib_nh___23 fib_nh;
		struct fib6_nh___33 fib6_nh;
	};
};

struct nh_grp_entry___23;

struct nh_res_bucket___23 {
	struct nh_grp_entry___23 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___23 {
	struct nexthop___23 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___23 *nh_parent;
};

struct nh_res_table___23 {
	struct net___109 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___23 nh_buckets[0];
};

struct nh_group___23 {
	struct nh_group___23 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___23 *res_table;
	struct nh_grp_entry___23 nh_entries[0];
};

struct inet6_protocol___5 {
	void (*early_demux)(struct sk_buff___105 *);
	void (*early_demux_handler)(struct sk_buff___105 *);
	int (*handler)(struct sk_buff___105 *);
	int (*err_handler)(struct sk_buff___105 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct inet_protosw___5 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___91 *prot;
	const struct proto_ops___92 *ops;
	unsigned char flags;
};

struct xfrm_type___24 {
	struct module___279 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___24 *);
	void (*destructor)(struct xfrm_state___24 *);
	int (*input)(struct xfrm_state___24 *, struct sk_buff___105 *);
	int (*output)(struct xfrm_state___24 *, struct sk_buff___105 *);
	int (*reject)(struct xfrm_state___24 *, struct sk_buff___105 *, const struct flowi *);
};

struct xfrm_type_offload___24 {
	struct module___279 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___24 *, struct sk_buff___105 *);
	int (*input_tail)(struct xfrm_state___24 *, struct sk_buff___105 *);
	int (*xmit)(struct xfrm_state___24 *, struct sk_buff___105 *, netdev_features_t);
};

struct crypto_alg___29;

struct crypto_tfm___29 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___29 *);
	struct crypto_alg___29 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___29 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___29 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___29 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___29 *, u8 *, const u8 *);
};

struct compress_alg___29 {
	int (*coa_compress)(struct crypto_tfm___29 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___29 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___29 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___29 cipher;
		struct compress_alg___29 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___29 *);
	void (*cra_exit)(struct crypto_tfm___29 *);
	void (*cra_destroy)(struct crypto_alg___29 *);
	struct module___279 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_ahash___8 {
	int (*init)(struct ahash_request___9 *);
	int (*update)(struct ahash_request___9 *);
	int (*final)(struct ahash_request___9 *);
	int (*finup)(struct ahash_request___9 *);
	int (*digest)(struct ahash_request___9 *);
	int (*export)(struct ahash_request___9 *, void *);
	int (*import)(struct ahash_request___9 *, const void *);
	int (*setkey)(struct crypto_ahash___8 *, const u8 *, unsigned int);
	unsigned int reqsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___29 base;
};

struct pingv6_ops___3 {
	int (*ipv6_recv_error)(struct sock___88 *, struct msghdr___90 *, int, int *);
	void (*ip6_datagram_recv_common_ctl)(struct sock___88 *, struct msghdr___90 *, struct sk_buff___102 *);
	void (*ip6_datagram_recv_specific_ctl)(struct sock___88 *, struct msghdr___90 *, struct sk_buff___102 *);
	int (*icmpv6_err_convert)(u8, u8, int *);
	void (*ipv6_icmp_error)(struct sock___88 *, struct sk_buff___102 *, int, __be16, u32, u8 *);
	int (*ipv6_chk_addr)(struct net___106 *, const struct in6_addr *, const struct net_device___101 *, int);
};

struct ping_iter_state___2 {
	struct seq_net_private___11 p;
	int bucket;
	sa_family_t family;
};

struct pingfakehdr___2 {
	struct icmphdr icmph;
	struct msghdr___90 *msg;
	sa_family_t family;
	__wsum wcheck;
};

struct dentry___296;

struct super_block___296;

struct module___280;

struct file_system_type___296 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___296 * (*mount)(struct file_system_type___296 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___296 *);
	struct module___280 *owner;
	struct file_system_type___296 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___296;

struct kiocb___296;

struct iov_iter___216;

struct poll_table_struct___217;

struct vm_area_struct___301;

struct inode___296;

struct file_lock___296;

struct page___301;

struct pipe_inode_info___137;

struct seq_file___271;

struct file_operations___297 {
	struct module___280 *owner;
	loff_t (*llseek)(struct file___296 *, loff_t, int);
	ssize_t (*read)(struct file___296 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___296 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___296 *, struct iov_iter___216 *);
	ssize_t (*write_iter)(struct kiocb___296 *, struct iov_iter___216 *);
	int (*iopoll)(struct kiocb___296 *, bool);
	int (*iterate)(struct file___296 *, struct dir_context *);
	int (*iterate_shared)(struct file___296 *, struct dir_context *);
	__poll_t (*poll)(struct file___296 *, struct poll_table_struct___217 *);
	long int (*unlocked_ioctl)(struct file___296 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___296 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___296 *, struct vm_area_struct___301 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___296 *, struct file___296 *);
	int (*flush)(struct file___296 *, fl_owner_t);
	int (*release)(struct inode___296 *, struct file___296 *);
	int (*fsync)(struct file___296 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___296 *, int);
	int (*lock)(struct file___296 *, int, struct file_lock___296 *);
	ssize_t (*sendpage)(struct file___296 *, struct page___301 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___296 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___296 *, long unsigned int);
	int (*flock)(struct file___296 *, int, struct file_lock___296 *);
	ssize_t (*splice_write)(struct pipe_inode_info___137 *, struct file___296 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___296 *, loff_t *, struct pipe_inode_info___137 *, size_t, unsigned int);
	int (*setlease)(struct file___296 *, long int, struct file_lock___296 **, void **);
	long int (*fallocate)(struct file___296 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___271 *, struct file___296 *);
	ssize_t (*copy_file_range)(struct file___296 *, loff_t, struct file___296 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___296 *, loff_t, struct file___296 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___296 *, loff_t, loff_t, int);
};

struct bio_vec___213 {
	struct page___301 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___296;

struct pipe_buffer___137;

struct pipe_inode_info___137 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___301 *tmp_page;
	struct fasync_struct___296 *fasync_readers;
	struct fasync_struct___296 *fasync_writers;
	struct pipe_buffer___137 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___216 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___213 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___137 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___94 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___216 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___296 *msg_iocb;
};

struct kiocb___296 {
	struct file___296 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___296 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct kset___284;

struct kobj_type___284;

struct kernfs_node___284;

struct kobject___284 {
	const char *name;
	struct list_head entry;
	struct kobject___284 *parent;
	struct kset___284 *kset;
	struct kobj_type___284 *ktype;
	struct kernfs_node___284 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___281 {
	struct kobject___284 kobj;
	struct module___280 *mod;
	struct kobject___284 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___280 {
	struct module___280 *mod;
	struct latch_tree_node node;
};

struct module_layout___280 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___280 mtn;
};

struct module_attribute___280;

struct kernel_param___280;

struct module___280 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___281 mkobj;
	struct module_attribute___280 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___284 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___280 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___280 core_layout;
	struct module_layout___280 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct vmacache___301 {
	u64 seqnum;
	struct vm_area_struct___301 *vmas[4];
};

struct page_frag___301 {
	struct page___301 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___302;

struct pid___273;

struct nsproxy___282;

struct signal_struct___297;

struct bio_list___187;

struct backing_dev_info___173;

struct io_context___187;

struct css_set___223;

struct mem_cgroup___161;

struct request_queue___187;

struct vm_struct___279;

struct task_struct___303 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___303 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___302 *mm;
	struct mm_struct___302 *active_mm;
	struct vmacache___301 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___303 *real_parent;
	struct task_struct___303 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___303 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___273 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___282 *nsproxy;
	struct signal_struct___297 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___303 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___187 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___173 *backing_dev_info;
	struct io_context___187 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___223 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___137 *splice_pipe;
	struct page_frag___301 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___161 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___161 *active_memcg;
	struct request_queue___187 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___303 *oom_reaper_list;
	struct vm_struct___279 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___273;

struct upid___273 {
	int nr;
	struct pid_namespace___273 *ns;
};

struct pid_namespace___273 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___303 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___273 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___273 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___273 numbers[1];
};

typedef struct page___301 *pgtable_t___301;

struct address_space___296;

struct page_pool___125;

struct dev_pagemap___291;

struct page___301 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___296 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___125 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___301 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___301 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___302 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___291 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___291;

struct vm_area_struct___301 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___301 *vm_next;
	struct vm_area_struct___301 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___302 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___291 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___296 *vm_file;
	struct file___296 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___297 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___303 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___303 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___273 *pids[4];
	struct pid___273 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___302 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___301;

struct mm_struct___302 {
	struct {
		struct vm_area_struct___301 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___296 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___301 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___303 *owner;
		struct user_namespace___26 *user_ns;
		struct file___296 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___110;

struct cgroup_namespace___223;

struct nsproxy___282 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___273 *pid_ns_for_children;
	struct net___110 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___223 *cgroup_ns;
};

struct bio___187;

struct bio_list___187 {
	struct bio___187 *head;
	struct bio___187 *tail;
};

struct cgroup_subsys_state___223;

struct bdi_writeback___173 {
	struct backing_dev_info___173 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___223 *memcg_css;
	struct cgroup_subsys_state___223 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___277;

struct backing_dev_info___173 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___173 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___277 *dev;
	char dev_name[64];
	struct device___277 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___296 *debug_dir;
};

struct io_cq___187;

struct io_context___187 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___187 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___223;

struct css_set___223 {
	struct cgroup_subsys_state___223 *subsys[14];
	refcount_t refcount;
	struct css_set___223 *dom_cset;
	struct cgroup___223 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___223 *mg_src_cgrp;
	struct cgroup___223 *mg_dst_cgrp;
	struct css_set___223 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___223;

struct cgroup_subsys_state___223 {
	struct cgroup___223 *cgroup;
	struct cgroup_subsys___223 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___223 *parent;
};

struct cgroup_file___223 {
	struct kernfs_node___284 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___161;

struct mem_cgroup_per_node___161;

struct mem_cgroup___161 {
	struct cgroup_subsys_state___223 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___223 events_file;
	struct cgroup_file___223 events_local_file;
	struct cgroup_file___223 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___161 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___303 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___161 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___187;

struct blk_integrity___187 {
	const struct blk_integrity_profile___187 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___187 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___187 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___187;

struct elevator_queue___187;

struct blk_mq_ops___182;

struct blk_mq_hw_ctx___182;

struct gendisk___190;

struct blkcg_gq___175;

struct blk_mq_tag_set___182;

struct request_queue___187 {
	struct request___187 *last_merge;
	struct elevator_queue___187 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___182 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___182 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___190 *disk;
	struct kobject___284 kobj;
	struct kobject___284 *mq_kobj;
	struct blk_integrity___187 integrity;
	struct device___277 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___175 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___182 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___187 bio_split;
	struct dentry___296 *debugfs_dir;
	struct dentry___296 *sched_debugfs_dir;
	struct dentry___296 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___279 {
	struct vm_struct___279 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___301 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___296;

struct dentry___296 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___296 *d_parent;
	struct qstr d_name;
	struct inode___296 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___296 *d_op;
	struct super_block___296 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___296;

struct address_space___296 {
	struct inode___296 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___296 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___296;

struct inode___296 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___296 *i_op;
	struct super_block___296 *i_sb;
	struct address_space___296 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___173 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___297 *i_fop;
		void (*free_inode)(struct inode___296 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___296 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___137 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___296;

struct path___296;

struct dentry_operations___296 {
	int (*d_revalidate)(struct dentry___296 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___296 *, unsigned int);
	int (*d_hash)(const struct dentry___296 *, struct qstr *);
	int (*d_compare)(const struct dentry___296 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___296 *);
	int (*d_init)(struct dentry___296 *);
	void (*d_release)(struct dentry___296 *);
	void (*d_prune)(struct dentry___296 *);
	void (*d_iput)(struct dentry___296 *, struct inode___296 *);
	char * (*d_dname)(struct dentry___296 *, char *, int);
	struct vfsmount___296 * (*d_automount)(struct path___296 *);
	int (*d_manage)(const struct path___296 *, bool);
	struct dentry___296 * (*d_real)(struct dentry___296 *, const struct inode___296 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___296;

struct mem_dqinfo___296 {
	struct quota_format_type___296 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___296;

struct quota_info___296 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___296 *files[3];
	struct mem_dqinfo___296 info[3];
	const struct quota_format_ops___296 *ops[3];
};

struct rcuwait___297 {
	struct task_struct___303 *task;
};

struct percpu_rw_semaphore___297 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___297 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___296 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___297 rw_sem[3];
};

struct shrink_control___161;

struct shrinker___161 {
	long unsigned int (*count_objects)(struct shrinker___161 *, struct shrink_control___161 *);
	long unsigned int (*scan_objects)(struct shrinker___161 *, struct shrink_control___161 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___296;

struct dquot_operations___296;

struct quotactl_ops___296;

struct block_device___190;

struct super_block___296 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___296 *s_type;
	const struct super_operations___296 *s_op;
	const struct dquot_operations___296 *dq_op;
	const struct quotactl_ops___296 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___296 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___190 *s_bdev;
	struct backing_dev_info___173 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___296 s_dquot;
	struct sb_writers___296 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___296 *s_d_op;
	int cleancache_poolid;
	struct shrinker___161 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___296 {
	struct dentry___296 *mnt_root;
	struct super_block___296 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___296 {
	struct vfsmount___296 *mnt;
	struct dentry___296 *dentry;
};

struct shrink_control___161 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___161 *memcg;
};

struct page_pool_params___125 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___277 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___125 {
	u32 count;
	struct page___301 *cache[128];
};

struct page_pool___125 {
	struct page_pool_params___125 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___301 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___125 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___291;

struct dev_pagemap___291 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___291 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___273 {
	rwlock_t lock;
	struct pid___273 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___296 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___296 f_path;
	struct inode___296 *f_inode;
	const struct file_operations___297 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___273 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___296 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___291;

struct vm_operations_struct___291 {
	void (*open)(struct vm_area_struct___301 *);
	void (*close)(struct vm_area_struct___301 *);
	int (*may_split)(struct vm_area_struct___301 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___301 *);
	int (*mprotect)(struct vm_area_struct___301 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___291 *);
	vm_fault_t (*huge_fault)(struct vm_fault___291 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___291 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___301 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___291 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___291 *);
	int (*access)(struct vm_area_struct___301 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___301 *);
	int (*set_policy)(struct vm_area_struct___301 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___301 *, long unsigned int);
	struct page___301 * (*find_special_page)(struct vm_area_struct___301 *, long unsigned int);
};

struct core_thread___301 {
	struct task_struct___303 *task;
	struct core_thread___301 *next;
};

struct core_state___301 {
	atomic_t nr_threads;
	struct core_thread___301 dumper;
	struct completion startup;
};

struct vm_fault___291 {
	const struct {
		struct vm_area_struct___301 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___301 *cow_page;
	struct page___301 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___301 prealloc_pte;
};

struct pglist_data___169;

struct lruvec___169 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___169 *pgdat;
};

struct zone___169 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___169 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___169 {
	struct zone___169 *zone;
	int zone_idx;
};

struct zonelist___169 {
	struct zoneref___169 _zonerefs[321];
};

struct pglist_data___169 {
	struct zone___169 node_zones[5];
	struct zonelist___169 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___303 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___303 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___169 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___223 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___303 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___99;

struct cgroup_bpf___99 {
	struct bpf_prog_array___99 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___99 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___223;

struct cgroup_rstat_cpu___223;

struct cgroup___223 {
	struct cgroup_subsys_state___223 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___284 *kn;
	struct cgroup_file___223 procs_file;
	struct cgroup_file___223 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___223 *subsys[14];
	struct cgroup_root___223 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___223 *dom_cgrp;
	struct cgroup___223 *old_dom_cgrp;
	struct cgroup_rstat_cpu___223 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___223 psi;
	struct cgroup_bpf___99 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___187 {
	struct request_queue___187 *q;
	struct io_context___187 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___296 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___296 *ia_file;
};

struct dquot___296 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___296 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___296 {
	int qf_fmt_id;
	const struct quota_format_ops___296 *qf_ops;
	struct module___280 *qf_owner;
	struct quota_format_type___296 *qf_next;
};

struct quota_format_ops___296 {
	int (*check_quota_file)(struct super_block___296 *, int);
	int (*read_file_info)(struct super_block___296 *, int);
	int (*write_file_info)(struct super_block___296 *, int);
	int (*free_file_info)(struct super_block___296 *, int);
	int (*read_dqblk)(struct dquot___296 *);
	int (*commit_dqblk)(struct dquot___296 *);
	int (*release_dqblk)(struct dquot___296 *);
	int (*get_next_id)(struct super_block___296 *, struct kqid *);
};

struct dquot_operations___296 {
	int (*write_dquot)(struct dquot___296 *);
	struct dquot___296 * (*alloc_dquot)(struct super_block___296 *, int);
	void (*destroy_dquot)(struct dquot___296 *);
	int (*acquire_dquot)(struct dquot___296 *);
	int (*release_dquot)(struct dquot___296 *);
	int (*mark_dirty)(struct dquot___296 *);
	int (*write_info)(struct super_block___296 *, int);
	qsize_t * (*get_reserved_space)(struct inode___296 *);
	int (*get_projid)(struct inode___296 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___296 *, qsize_t *);
	int (*get_next_id)(struct super_block___296 *, struct kqid *);
};

struct quotactl_ops___296 {
	int (*quota_on)(struct super_block___296 *, int, int, const struct path___296 *);
	int (*quota_off)(struct super_block___296 *, int);
	int (*quota_enable)(struct super_block___296 *, unsigned int);
	int (*quota_disable)(struct super_block___296 *, unsigned int);
	int (*quota_sync)(struct super_block___296 *, int);
	int (*set_info)(struct super_block___296 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___296 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___296 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___296 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___296 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___296 *, unsigned int);
};

struct writeback_control___173;

struct address_space_operations___296 {
	int (*writepage)(struct page___301 *, struct writeback_control___173 *);
	int (*readpage)(struct file___296 *, struct page___301 *);
	int (*writepages)(struct address_space___296 *, struct writeback_control___173 *);
	int (*set_page_dirty)(struct page___301 *);
	int (*readpages)(struct file___296 *, struct address_space___296 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___296 *, struct address_space___296 *, loff_t, unsigned int, unsigned int, struct page___301 **, void **);
	int (*write_end)(struct file___296 *, struct address_space___296 *, loff_t, unsigned int, unsigned int, struct page___301 *, void *);
	sector_t (*bmap)(struct address_space___296 *, sector_t);
	void (*invalidatepage)(struct page___301 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___301 *, gfp_t);
	void (*freepage)(struct page___301 *);
	ssize_t (*direct_IO)(struct kiocb___296 *, struct iov_iter___216 *);
	int (*migratepage)(struct address_space___296 *, struct page___301 *, struct page___301 *, enum migrate_mode);
	bool (*isolate_page)(struct page___301 *, isolate_mode_t);
	void (*putback_page)(struct page___301 *);
	int (*launder_page)(struct page___301 *);
	int (*is_partially_uptodate)(struct page___301 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___301 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___296 *, struct page___301 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___296 *, sector_t *);
	void (*swap_deactivate)(struct file___296 *);
};

struct writeback_control___173 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___173 *wb;
	struct inode___296 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___296 {
	struct dentry___296 * (*lookup)(struct inode___296 *, struct dentry___296 *, unsigned int);
	const char * (*get_link)(struct dentry___296 *, struct inode___296 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___296 *, int);
	struct posix_acl * (*get_acl)(struct inode___296 *, int, bool);
	int (*readlink)(struct dentry___296 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___296 *, struct dentry___296 *, umode_t, bool);
	int (*link)(struct dentry___296 *, struct inode___296 *, struct dentry___296 *);
	int (*unlink)(struct inode___296 *, struct dentry___296 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___296 *, struct dentry___296 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___296 *, struct dentry___296 *, umode_t);
	int (*rmdir)(struct inode___296 *, struct dentry___296 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___296 *, struct dentry___296 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___296 *, struct dentry___296 *, struct inode___296 *, struct dentry___296 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___296 *, struct iattr___296 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___296 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___296 *, char *, size_t);
	int (*fiemap)(struct inode___296 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___296 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___296 *, struct dentry___296 *, struct file___296 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___296 *, struct dentry___296 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___296 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___296 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___296 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___296 {
	void (*fl_copy_lock)(struct file_lock___296 *, struct file_lock___296 *);
	void (*fl_release_private)(struct file_lock___296 *);
};

struct lock_manager_operations___296;

struct file_lock___296 {
	struct file_lock___296 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___296 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___296 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___296 *fl_ops;
	const struct lock_manager_operations___296 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___296 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___296 *);
	int (*lm_grant)(struct file_lock___296 *, int);
	bool (*lm_break)(struct file_lock___296 *);
	int (*lm_change)(struct file_lock___296 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___296 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___296 *);
};

struct fasync_struct___296 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___296 *fa_next;
	struct file___296 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___296 {
	struct inode___296 * (*alloc_inode)(struct super_block___296 *);
	void (*destroy_inode)(struct inode___296 *);
	void (*free_inode)(struct inode___296 *);
	void (*dirty_inode)(struct inode___296 *, int);
	int (*write_inode)(struct inode___296 *, struct writeback_control___173 *);
	int (*drop_inode)(struct inode___296 *);
	void (*evict_inode)(struct inode___296 *);
	void (*put_super)(struct super_block___296 *);
	int (*sync_fs)(struct super_block___296 *, int);
	int (*freeze_super)(struct super_block___296 *);
	int (*freeze_fs)(struct super_block___296 *);
	int (*thaw_super)(struct super_block___296 *);
	int (*unfreeze_fs)(struct super_block___296 *);
	int (*statfs)(struct dentry___296 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___296 *, int *, char *);
	void (*umount_begin)(struct super_block___296 *);
	int (*show_options)(struct seq_file___271 *, struct dentry___296 *);
	int (*show_devname)(struct seq_file___271 *, struct dentry___296 *);
	int (*show_path)(struct seq_file___271 *, struct dentry___296 *);
	int (*show_stats)(struct seq_file___271 *, struct dentry___296 *);
	ssize_t (*quota_read)(struct super_block___296 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___296 *, int, const char *, size_t, loff_t);
	struct dquot___296 ** (*get_dquots)(struct inode___296 *);
	long int (*nr_cached_objects)(struct super_block___296 *, struct shrink_control___161 *);
	long int (*free_cached_objects)(struct super_block___296 *, struct shrink_control___161 *);
	struct file___296 * (*real_loop)(struct file___296 *);
};

struct wakeup_source___277;

struct dev_pm_info___277 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___277 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___277 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___277;

struct bus_type___277;

struct device_driver___277;

struct dev_pm_domain___277;

struct fwnode_handle___273;

struct class___277;

struct attribute_group___284;

struct device___277 {
	struct kobject___284 kobj;
	struct device___277 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___277 *type;
	struct bus_type___277 *bus;
	struct device_driver___277 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___277 power;
	struct dev_pm_domain___277 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___273 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___277 *class;
	const struct attribute_group___284 **groups;
	void (*release)(struct device___277 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___190 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___296 *bd_inode;
	struct super_block___296 *bd_super;
	void *bd_claiming;
	struct device___277 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___284 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___190 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___296 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___225)(struct file___296 *, wait_queue_head_t *, struct poll_table_struct___217 *);

struct poll_table_struct___217 {
	poll_queue_proc___225 _qproc;
	__poll_t _key;
};

struct seq_operations___271;

struct seq_file___271 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___271 *op;
	int poll_event;
	const struct file___296 *file;
	void *private;
};

typedef void bio_end_io_t___187(struct bio___187 *);

struct bio_integrity_payload___187;

struct bio___187 {
	struct bio___187 *bi_next;
	struct block_device___190 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___187 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___175 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___187 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___213 *bi_io_vec;
	struct bio_set___187 *bi_pool;
	struct bio_vec___213 bi_inline_vecs[0];
};

struct dev_pagemap_ops___291 {
	void (*page_free)(struct page___301 *);
	void (*kill)(struct dev_pagemap___291 *);
	void (*cleanup)(struct dev_pagemap___291 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___291 *);
};

struct socket_wq___93 {
	wait_queue_head_t wait;
	struct fasync_struct___296 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___92;

struct proto_ops___93;

struct socket___94 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___296 *file;
	struct sock___92 *sk;
	const struct proto_ops___93 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___93 wq;
};

typedef struct {
	struct net___110 *net;
} possible_net_t___105;

struct proto___92;

struct sock_common___92 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___92 *skc_prot;
	possible_net_t___105 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___92 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___106;

struct sk_buff_head___105 {
	struct sk_buff___106 *next;
	struct sk_buff___106 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___92 {
	struct cgroup___223 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___92;

struct xfrm_policy___25;

struct dst_entry___92;

struct net_device___105;

struct sock___92 {
	struct sock_common___92 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___105 sk_error_queue;
	struct sk_buff___106 *sk_rx_skb_cache;
	struct sk_buff_head___105 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___106 *head;
		struct sk_buff___106 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___92 *sk_filter;
	union {
		struct socket_wq___93 *sk_wq;
		struct socket_wq___93 *sk_wq_raw;
	};
	struct xfrm_policy___25 *sk_policy[2];
	struct dst_entry___92 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___92 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___106 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___106 *sk_tx_skb_cache;
	struct sk_buff_head___105 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___301 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___92 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___273 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___94 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___92 sk_cgrp_data;
	struct mem_cgroup___161 *sk_memcg;
	void (*sk_state_change)(struct sock___92 *);
	void (*sk_data_ready)(struct sock___92 *);
	void (*sk_write_space)(struct sock___92 *);
	void (*sk_error_report)(struct sock___92 *);
	int (*sk_backlog_rcv)(struct sock___92 *, struct sk_buff___106 *);
	struct sk_buff___106 * (*sk_validate_xmit_skb)(struct sock___92 *, struct net_device___105 *, struct sk_buff___106 *);
	void (*sk_destruct)(struct sock___92 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___92)(read_descriptor_t *, struct sk_buff___106 *, unsigned int, size_t);

struct proto_ops___93 {
	int family;
	struct module___280 *owner;
	int (*release)(struct socket___94 *);
	int (*bind)(struct socket___94 *, struct sockaddr *, int);
	int (*connect)(struct socket___94 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___94 *, struct socket___94 *);
	int (*accept)(struct socket___94 *, struct socket___94 *, int, bool);
	int (*getname)(struct socket___94 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___296 *, struct socket___94 *, struct poll_table_struct___217 *);
	int (*ioctl)(struct socket___94 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___94 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___94 *, void *, bool, bool);
	int (*listen)(struct socket___94 *, int);
	int (*shutdown)(struct socket___94 *, int);
	int (*setsockopt)(struct socket___94 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___94 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___271 *, struct socket___94 *);
	int (*sendmsg)(struct socket___94 *, struct msghdr___94 *, size_t);
	int (*recvmsg)(struct socket___94 *, struct msghdr___94 *, size_t, int);
	int (*mmap)(struct file___296 *, struct socket___94 *, struct vm_area_struct___301 *);
	ssize_t (*sendpage)(struct socket___94 *, struct page___301 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___94 *, loff_t *, struct pipe_inode_info___137 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___92 *, int);
	int (*peek_len)(struct socket___94 *);
	int (*read_sock)(struct sock___92 *, read_descriptor_t *, sk_read_actor_t___92);
	int (*sendpage_locked)(struct sock___92 *, struct page___301 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___92 *, struct msghdr___94 *, size_t);
	int (*set_rcvlowat)(struct sock___92 *, int);
};

struct sk_buff___106 {
	union {
		struct {
			struct sk_buff___106 *next;
			struct sk_buff___106 *prev;
			union {
				struct net_device___105 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___92 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___106 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct ip_ra_chain___65;

struct fib_rules_ops___92;

struct fqdir___110;

struct fib_notifier_ops___92;

struct netns_ipv4___110 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___65 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___92 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___92 *fibnl;
	struct sock___92 **icmp_sk;
	struct sock___92 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___92 **tcp_sk;
	struct fqdir___110 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___92 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___92 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___92 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___92;

struct dst_ops___110 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___110 *);
	struct dst_entry___92 * (*check)(struct dst_entry___92 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___92 *);
	unsigned int (*mtu)(const struct dst_entry___92 *);
	u32 * (*cow_metrics)(struct dst_entry___92 *, long unsigned int);
	void (*destroy)(struct dst_entry___92 *);
	void (*ifdown)(struct dst_entry___92 *, struct net_device___105 *, int);
	struct dst_entry___92 * (*negative_advice)(struct dst_entry___92 *);
	void (*link_failure)(struct sk_buff___106 *);
	void (*update_pmtu)(struct dst_entry___92 *, struct sock___92 *, struct sk_buff___106 *, u32, bool);
	void (*redirect)(struct dst_entry___92 *, struct sock___92 *, struct sk_buff___106 *);
	int (*local_out)(struct net___110 *, struct sock___92 *, struct sk_buff___106 *);
	struct neighbour___92 * (*neigh_lookup)(const struct dst_entry___92 *, struct sk_buff___106 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___92 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___34;

struct rt6_info___34;

struct fib6_table___34;

struct netns_ipv6___110 {
	struct dst_ops___110 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___110 *fqdir;
	struct fib6_info___34 *fib6_null_entry;
	struct rt6_info___34 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___34 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___34 *ip6_prohibit_entry;
	struct rt6_info___34 *ip6_blk_hole_entry;
	struct fib6_table___34 *fib6_local_tbl;
	struct fib_rules_ops___92 *fib6_rules_ops;
	struct sock___92 **icmp_sk;
	struct sock___92 *ndisc_sk;
	struct sock___92 *tcp_sk;
	struct sock___92 *igmp_sk;
	struct sock___92 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___92 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___92 *notifier_ops;
	struct fib_notifier_ops___92 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___110 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___110 *fqdir;
};

struct netns_sctp___92 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___92 *ctl_sock;
	struct sock___92 *udp4_sock;
	struct sock___92 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___99;

struct netns_bpf___99 {
	struct bpf_prog_array___99 *run_array[2];
	struct bpf_prog___99 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___110 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___92 *nlsk;
	struct sock___92 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___110 xfrm4_dst_ops;
	struct dst_ops___110 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___110 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___92 *rtnl;
	struct sock___92 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___105 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___110 ipv4;
	struct netns_ipv6___110 ipv6;
	struct netns_ieee802154_lowpan___110 ieee802154_lowpan;
	struct netns_sctp___92 sctp;
	struct netns_nf___21 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___105 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___99 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___110 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___92 *crypto_nlsk;
	struct sock___92 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___110;

struct fqdir___110 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___110 *f;
	struct net___110 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___110;

struct inet_frags___110 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___110 *, const void *);
	void (*destructor)(struct inet_frag_queue___110 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___110 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___106 *fragments_tail;
	struct sk_buff___106 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___110 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___65 {
	struct ip_ra_chain___65 *next;
	struct sock___92 *sk;
	union {
		void (*destructor)(struct sock___92 *);
		struct sock___92 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___92;

struct fib_lookup_arg___92;

struct fib_rules_ops___92 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___92 *, struct flowi *, int, struct fib_lookup_arg___92 *);
	bool (*suppress)(struct fib_rule___92 *, int, struct fib_lookup_arg___92 *);
	int (*match)(struct fib_rule___92 *, struct flowi *, int);
	int (*configure)(struct fib_rule___92 *, struct sk_buff___106 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___92 *);
	int (*compare)(struct fib_rule___92 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___92 *, struct sk_buff___106 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___92 *);
	void (*flush_cache)(struct fib_rules_ops___92 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___280 *owner;
	struct net___110 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___92 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___110 *);
	int (*fib_dump)(struct net___110 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___280 *owner;
	struct callback_head rcu;
};

struct xfrm_state___25;

struct lwtunnel_state___68;

struct dst_entry___92 {
	struct net_device___105 *dev;
	struct dst_ops___110 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___25 *xfrm;
	int (*input)(struct sk_buff___106 *);
	int (*output)(struct net___110 *, struct sock___92 *, struct sk_buff___106 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___68 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___105(struct sk_buff___106 **);

struct bpf_xdp_entity___99 {
	struct bpf_prog___99 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___105;

struct net_device_ops___105;

struct l3mdev_ops___92;

struct ndisc_ops___74;

struct xfrmdev_ops___105;

struct header_ops___105;

struct inet6_dev___74;

struct netdev_rx_queue___105;

struct mini_Qdisc___99;

struct netdev_queue___105;

struct Qdisc___99;

struct rtnl_link_ops___99;

struct dcbnl_rtnl_ops___105;

struct net_device___105 {
	char name[16];
	struct netdev_name_node___105 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___105 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___92 *l3mdev_ops;
	const struct ndisc_ops___74 *ndisc_ops;
	const struct xfrmdev_ops___105 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___105 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___284 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___74 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___105 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___99 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___105 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___99 *miniq_ingress;
	struct netdev_queue___105 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___105 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___99 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___99 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___105 = 0,
		NETREG_REGISTERED___105 = 1,
		NETREG_UNREGISTERING___105 = 2,
		NETREG_UNREGISTERED___105 = 3,
		NETREG_RELEASED___105 = 4,
		NETREG_DUMMY___105 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___105 = 0,
		RTNL_LINK_INITIALIZING___105 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___105 *);
	struct netpoll_info *npinfo;
	possible_net_t___105 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___277 dev;
	const struct attribute_group___284 *sysfs_groups[4];
	const struct attribute_group___284 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___99 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___105 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___99 xdp_state[3];
	long: 64;
};

struct neigh_table___92;

struct neigh_parms___92;

struct neigh_ops___92;

struct neighbour___92 {
	struct neighbour___92 *next;
	struct neigh_table___92 *tbl;
	struct neigh_parms___92 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___105 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___92 *, struct sk_buff___106 *);
	const struct neigh_ops___92 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___105 *dev;
	u8 primary_key[0];
};

struct rtable___36;

struct fnhe_hash_bucket___34;

struct fib_nh_common___34 {
	struct net_device___105 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___68 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___36 **nhc_pcpu_rth_output;
	struct rtable___36 *nhc_rth_input;
	struct fnhe_hash_bucket___34 *nhc_exceptions;
};

struct fib6_nh___34 {
	struct fib_nh_common___34 nh_common;
	long unsigned int last_probe;
	struct rt6_info___34 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___34;

struct nexthop___24;

struct fib6_info___34 {
	struct fib6_table___34 *fib6_table;
	struct fib6_info___34 *fib6_next;
	struct fib6_node___34 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___24 *nh;
	struct fib6_nh___34 fib6_nh[0];
};

struct rt6_info___34 {
	struct dst_entry___92 dst;
	struct fib6_info___34 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___74 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___34 {
	struct fib6_node___34 *parent;
	struct fib6_node___34 *left;
	struct fib6_node___34 *right;
	struct fib6_node___34 *subtree;
	struct fib6_info___34 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___34 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___34 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___34 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct bpf_prog_array_item___99 {
	struct bpf_prog___99 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___99 {
	struct callback_head rcu;
	struct bpf_prog_array_item___99 items[0];
};

struct bpf_prog_aux___108;

struct bpf_prog___99 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___108 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___273;

struct fwnode_handle___273 {
	struct fwnode_handle___273 *secondary;
	const struct fwnode_operations___273 *ops;
	struct device___277 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___273;

struct fwnode_endpoint___273;

struct fwnode_operations___273 {
	struct fwnode_handle___273 * (*get)(struct fwnode_handle___273 *);
	void (*put)(struct fwnode_handle___273 *);
	bool (*device_is_available)(const struct fwnode_handle___273 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___273 *, const struct device___277 *);
	bool (*property_present)(const struct fwnode_handle___273 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___273 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___273 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___273 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*get_parent)(const struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*get_next_child_node)(const struct fwnode_handle___273 *, struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*get_named_child_node)(const struct fwnode_handle___273 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___273 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___273 *);
	struct fwnode_handle___273 * (*graph_get_next_endpoint)(const struct fwnode_handle___273 *, struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*graph_get_remote_endpoint)(const struct fwnode_handle___273 *);
	struct fwnode_handle___273 * (*graph_get_port_parent)(struct fwnode_handle___273 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___273 *, struct fwnode_endpoint___273 *);
	int (*add_links)(struct fwnode_handle___273 *);
};

struct fwnode_endpoint___273 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___273 *local_fwnode;
};

struct fwnode_reference_args___273 {
	struct fwnode_handle___273 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___284;

struct kernfs_elem_dir___284 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___284 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___284;

struct kernfs_root___284 {
	struct kernfs_node___284 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___284 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___284 {
	struct kernfs_node___284 *target_kn;
};

struct kernfs_ops___284;

struct kernfs_elem_attr___284 {
	const struct kernfs_ops___284 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___284 *notify_next;
};

struct kernfs_node___284 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___284 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___284 dir;
		struct kernfs_elem_symlink___284 symlink;
		struct kernfs_elem_attr___284 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___284;

struct kernfs_ops___284 {
	int (*open)(struct kernfs_open_file___284 *);
	void (*release)(struct kernfs_open_file___284 *);
	int (*seq_show)(struct seq_file___271 *, void *);
	void * (*seq_start)(struct seq_file___271 *, loff_t *);
	void * (*seq_next)(struct seq_file___271 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___271 *, void *);
	ssize_t (*read)(struct kernfs_open_file___284 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___284 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___284 *, struct poll_table_struct___217 *);
	int (*mmap)(struct kernfs_open_file___284 *, struct vm_area_struct___301 *);
};

struct kernfs_syscall_ops___284 {
	int (*show_options)(struct seq_file___271 *, struct kernfs_root___284 *);
	int (*mkdir)(struct kernfs_node___284 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___284 *);
	int (*rename)(struct kernfs_node___284 *, struct kernfs_node___284 *, const char *);
	int (*show_path)(struct seq_file___271 *, struct kernfs_node___284 *, struct kernfs_root___284 *);
};

struct kernfs_open_file___284 {
	struct kernfs_node___284 *kn;
	struct file___296 *file;
	struct seq_file___271 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___291 *vm_ops;
};

struct kobj_ns_type_operations___92 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___92 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___284;

struct attribute_group___284 {
	const char *name;
	umode_t (*is_visible)(struct kobject___284 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___284 *, struct bin_attribute___284 *, int);
	struct attribute **attrs;
	struct bin_attribute___284 **bin_attrs;
};

struct bin_attribute___284 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___296 * (*f_mapping)();
	ssize_t (*read)(struct file___296 *, struct kobject___284 *, struct bin_attribute___284 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___296 *, struct kobject___284 *, struct bin_attribute___284 *, char *, loff_t, size_t);
	int (*mmap)(struct file___296 *, struct kobject___284 *, struct bin_attribute___284 *, struct vm_area_struct___301 *);
};

struct sysfs_ops___284 {
	ssize_t (*show)(struct kobject___284 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___284 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___284;

struct kset___284 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___284 kobj;
	const struct kset_uevent_ops___284 *uevent_ops;
};

struct kobj_type___284 {
	void (*release)(struct kobject___284 *);
	const struct sysfs_ops___284 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___284 **default_groups;
	const struct kobj_ns_type_operations___92 * (*child_ns_type)(struct kobject___284 *);
	const void * (*namespace)(struct kobject___284 *);
	void (*get_ownership)(struct kobject___284 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___284 {
	int (* const filter)(struct kset___284 *, struct kobject___284 *);
	const char * (* const name)(struct kset___284 *, struct kobject___284 *);
	int (* const uevent)(struct kset___284 *, struct kobject___284 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___280 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___280 *);
	int (*get)(char *, const struct kernel_param___280 *);
	void (*free)(void *);
};

struct kparam_array___280;

struct kernel_param___280 {
	const char *name;
	struct module___280 *mod;
	const struct kernel_param_ops___280 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___280 *arr;
	};
};

struct kparam_array___280 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___280 *ops;
	void *elem;
};

struct module_attribute___280 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___280 *, struct module_kobject___281 *, char *);
	ssize_t (*store)(struct module_attribute___280 *, struct module_kobject___281 *, const char *, size_t);
	void (*setup)(struct module___280 *, const char *);
	int (*test)(struct module___280 *);
	void (*free)(struct module___280 *);
};

struct cgroup_namespace___223 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___223 *root_cset;
};

struct dev_pm_ops___277 {
	int (*prepare)(struct device___277 *);
	void (*complete)(struct device___277 *);
	int (*suspend)(struct device___277 *);
	int (*resume)(struct device___277 *);
	int (*freeze)(struct device___277 *);
	int (*thaw)(struct device___277 *);
	int (*poweroff)(struct device___277 *);
	int (*restore)(struct device___277 *);
	int (*suspend_late)(struct device___277 *);
	int (*resume_early)(struct device___277 *);
	int (*freeze_late)(struct device___277 *);
	int (*thaw_early)(struct device___277 *);
	int (*poweroff_late)(struct device___277 *);
	int (*restore_early)(struct device___277 *);
	int (*suspend_noirq)(struct device___277 *);
	int (*resume_noirq)(struct device___277 *);
	int (*freeze_noirq)(struct device___277 *);
	int (*thaw_noirq)(struct device___277 *);
	int (*poweroff_noirq)(struct device___277 *);
	int (*restore_noirq)(struct device___277 *);
	int (*runtime_suspend)(struct device___277 *);
	int (*runtime_resume)(struct device___277 *);
	int (*runtime_idle)(struct device___277 *);
};

struct wakeup_source___277 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___277 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___277 {
	struct dev_pm_ops___277 ops;
	int (*start)(struct device___277 *);
	void (*detach)(struct device___277 *, bool);
	int (*activate)(struct device___277 *);
	void (*sync)(struct device___277 *);
	void (*dismiss)(struct device___277 *);
};

struct bus_type___277 {
	const char *name;
	const char *dev_name;
	struct device___277 *dev_root;
	const struct attribute_group___284 **bus_groups;
	const struct attribute_group___284 **dev_groups;
	const struct attribute_group___284 **drv_groups;
	int (*match)(struct device___277 *, struct device_driver___277 *);
	int (*uevent)(struct device___277 *, struct kobj_uevent_env *);
	int (*probe)(struct device___277 *);
	void (*sync_state)(struct device___277 *);
	void (*remove)(struct device___277 *);
	void (*shutdown)(struct device___277 *);
	int (*online)(struct device___277 *);
	int (*offline)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	int (*num_vf)(struct device___277 *);
	int (*dma_configure)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___277 {
	const char *name;
	struct bus_type___277 *bus;
	struct module___280 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___277 *);
	void (*sync_state)(struct device___277 *);
	int (*remove)(struct device___277 *);
	void (*shutdown)(struct device___277 *);
	int (*suspend)(struct device___277 *, pm_message_t);
	int (*resume)(struct device___277 *);
	const struct attribute_group___284 **groups;
	const struct attribute_group___284 **dev_groups;
	const struct dev_pm_ops___277 *pm;
	void (*coredump)(struct device___277 *);
	struct driver_private *p;
};

struct device_type___277 {
	const char *name;
	const struct attribute_group___284 **groups;
	int (*uevent)(struct device___277 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___277 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___277 *);
	const struct dev_pm_ops___277 *pm;
};

struct class___277 {
	const char *name;
	struct module___280 *owner;
	const struct attribute_group___284 **class_groups;
	const struct attribute_group___284 **dev_groups;
	struct kobject___284 *dev_kobj;
	int (*dev_uevent)(struct device___277 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___277 *, umode_t *);
	void (*class_release)(struct class___277 *);
	void (*dev_release)(struct device___277 *);
	int (*shutdown_pre)(struct device___277 *);
	const struct kobj_ns_type_operations___92 *ns_type;
	const void * (*namespace)(struct device___277 *);
	void (*get_ownership)(struct device___277 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___277 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___137;

struct pipe_buffer___137 {
	struct page___301 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___137 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___137 {
	int (*confirm)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
	void (*release)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
	bool (*try_steal)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
	bool (*get)(struct pipe_inode_info___137 *, struct pipe_buffer___137 *);
};

typedef struct bio_vec___213 skb_frag_t___43;

struct skb_shared_info___37 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___106 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___43 frags[17];
};

struct seq_operations___271 {
	void * (*start)(struct seq_file___271 *, loff_t *);
	void (*stop)(struct seq_file___271 *, void *);
	void * (*next)(struct seq_file___271 *, void *, loff_t *);
	int (*show)(struct seq_file___271 *, void *);
};

struct dcbnl_rtnl_ops___105 {
	int (*ieee_getets)(struct net_device___105 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___105 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___105 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___105 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___105 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___105 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___105 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___105 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___105 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___105 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___105 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___105 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___105 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___105 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___105 *);
	u8 (*setstate)(struct net_device___105 *, u8);
	void (*getpermhwaddr)(struct net_device___105 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___105 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___105 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___105 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___105 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___105 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___105 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___105 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___105 *, int, u8 *);
	void (*setpfccfg)(struct net_device___105 *, int, u8);
	void (*getpfccfg)(struct net_device___105 *, int, u8 *);
	u8 (*setall)(struct net_device___105 *);
	u8 (*getcap)(struct net_device___105 *, int, u8 *);
	int (*getnumtcs)(struct net_device___105 *, int, u8 *);
	int (*setnumtcs)(struct net_device___105 *, int, u8);
	u8 (*getpfcstate)(struct net_device___105 *);
	void (*setpfcstate)(struct net_device___105 *, u8);
	void (*getbcncfg)(struct net_device___105 *, int, u32 *);
	void (*setbcncfg)(struct net_device___105 *, int, u32);
	void (*getbcnrp)(struct net_device___105 *, int, u8 *);
	void (*setbcnrp)(struct net_device___105 *, int, u8);
	int (*setapp)(struct net_device___105 *, u8, u16, u8);
	int (*getapp)(struct net_device___105 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___105 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___105 *, int, u8);
	u8 (*getdcbx)(struct net_device___105 *);
	u8 (*setdcbx)(struct net_device___105 *, u8);
	int (*peer_getappinfo)(struct net_device___105 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___105 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___105 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___105 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___105 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___105 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___108;

typedef int (*bpf_iter_init_seq_priv_t___107)(void *, struct bpf_iter_aux_info___108 *);

struct bpf_map___108;

struct bpf_iter_aux_info___108 {
	struct bpf_map___108 *map;
};

struct bpf_iter_seq_info___107 {
	const struct seq_operations___271 *seq_ops;
	bpf_iter_init_seq_priv_t___107 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___107 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___108 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___108 *, struct file___296 *);
	void (*map_free)(struct bpf_map___108 *);
	int (*map_get_next_key)(struct bpf_map___108 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___108 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___108 *, void *);
	int (*map_lookup_batch)(struct bpf_map___108 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___108 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___108 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___108 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___108 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___108 *, void *);
	int (*map_update_elem)(struct bpf_map___108 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___108 *, void *);
	int (*map_push_elem)(struct bpf_map___108 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___108 *, void *);
	int (*map_peek_elem)(struct bpf_map___108 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___108 *, struct file___296 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___108 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___108 *, void *, struct seq_file___271 *);
	int (*map_check_btf)(const struct bpf_map___108 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___108 *, struct bpf_prog_aux___108 *);
	void (*map_poke_untrack)(struct bpf_map___108 *, struct bpf_prog_aux___108 *);
	void (*map_poke_run)(struct bpf_map___108 *, u32, struct bpf_prog___99 *, struct bpf_prog___99 *);
	int (*map_direct_value_addr)(const struct bpf_map___108 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___108 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___108 *, struct vm_area_struct___301 *);
	__poll_t (*map_poll)(struct bpf_map___108 *, struct file___296 *, struct poll_table_struct___217 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___108 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___108 *, const struct bpf_map___108 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___108 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___107 *iter_seq_info;
};

struct bpf_map___108 {
	const struct bpf_map_ops___107 *ops;
	struct bpf_map___108 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___161 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___107;

struct bpf_jit_poke_descriptor___107;

struct bpf_prog_ops___99;

struct btf_mod_pair___107;

struct bpf_prog_offload___105;

struct bpf_prog_aux___108 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___99 *dst_prog;
	struct bpf_trampoline___107 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___99 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___107 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___99 *ops;
	struct bpf_map___108 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___107 *used_btfs;
	struct bpf_prog___99 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___108 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___105 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___105;

struct bpf_map_dev_ops___105 {
	int (*map_get_next_key)(struct bpf_offloaded_map___105 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___105 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___105 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___105 *, void *);
};

struct bpf_offloaded_map___105 {
	struct bpf_map___108 map;
	struct net_device___105 *netdev;
	const struct bpf_map_dev_ops___105 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___99 {
	int (*test_run)(struct bpf_prog___99 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___105 {
	struct bpf_prog___99 *prog;
	struct net_device___105 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___107 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___99 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___280 *mod;
};

struct bpf_jit_poke_descriptor___107 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___108 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___107 {
	struct btf *btf;
	struct module___280 *module;
};

struct cftype___223;

struct cgroup_subsys___223 {
	struct cgroup_subsys_state___223 * (*css_alloc)(struct cgroup_subsys_state___223 *);
	int (*css_online)(struct cgroup_subsys_state___223 *);
	void (*css_offline)(struct cgroup_subsys_state___223 *);
	void (*css_released)(struct cgroup_subsys_state___223 *);
	void (*css_free)(struct cgroup_subsys_state___223 *);
	void (*css_reset)(struct cgroup_subsys_state___223 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___223 *, int);
	int (*css_extra_stat_show)(struct seq_file___271 *, struct cgroup_subsys_state___223 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___303 *, struct css_set___223 *);
	void (*cancel_fork)(struct task_struct___303 *, struct css_set___223 *);
	void (*fork)(struct task_struct___303 *);
	void (*exit)(struct task_struct___303 *);
	void (*release)(struct task_struct___303 *);
	void (*bind)(struct cgroup_subsys_state___223 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___223 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___223 *dfl_cftypes;
	struct cftype___223 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___223 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___223 *updated_children;
	struct cgroup___223 *updated_next;
};

struct cgroup_root___223 {
	struct kernfs_root___284 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___223 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___223 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___223 *ss;
	struct list_head node;
	struct kernfs_ops___284 *kf_ops;
	int (*open)(struct kernfs_open_file___284 *);
	void (*release)(struct kernfs_open_file___284 *);
	u64 (*read_u64)(struct cgroup_subsys_state___223 *, struct cftype___223 *);
	s64 (*read_s64)(struct cgroup_subsys_state___223 *, struct cftype___223 *);
	int (*seq_show)(struct seq_file___271 *, void *);
	void * (*seq_start)(struct seq_file___271 *, loff_t *);
	void * (*seq_next)(struct seq_file___271 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___271 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___223 *, struct cftype___223 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___223 *, struct cftype___223 *, s64);
	ssize_t (*write)(struct kernfs_open_file___284 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___284 *, struct poll_table_struct___217 *);
};

struct xdp_rxq_info___105 {
	struct net_device___105 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___105 {
	struct net_device___105 *dev;
};

struct xdp_buff___105 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___105 *rxq;
	struct xdp_txq_info___105 *txq;
	u32 frame_sz;
};

struct xdp_frame___105 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___105 *dev_rx;
};

struct netlink_callback___105 {
	struct sk_buff___106 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___106 *, struct netlink_callback___105 *);
	int (*done)(struct netlink_callback___105 *);
	void *data;
	struct module___280 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___105 {
	int (*create)(struct sk_buff___106 *, struct net_device___105 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___106 *, unsigned char *);
	int (*cache)(const struct neighbour___92 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___105 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___106 *);
};

struct netdev_queue___105 {
	struct net_device___105 *dev;
	struct Qdisc___99 *qdisc;
	struct Qdisc___99 *qdisc_sleeping;
	struct kobject___284 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___105 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___99 {
	struct sk_buff___106 *head;
	struct sk_buff___106 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___99;

struct Qdisc___99 {
	int (*enqueue)(struct sk_buff___106 *, struct Qdisc___99 *, struct sk_buff___106 **);
	struct sk_buff___106 * (*dequeue)(struct Qdisc___99 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___99 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___105 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___105 gso_skb;
	struct qdisc_skb_head___99 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___99 *next_sched;
	struct sk_buff_head___105 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___105 {
	struct xdp_rxq_info___105 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___284 kobj;
	struct net_device___105 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___105 {
	enum net_device_path_type type;
	const struct net_device___105 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___105 = 0,
				DEV_PATH_BR_VLAN_TAG___105 = 1,
				DEV_PATH_BR_VLAN_UNTAG___105 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___105 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___105 {
	const struct net_device___105 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___105 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___99 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___105 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___105 {
	int (*xdo_dev_state_add)(struct xfrm_state___25 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___25 *);
	void (*xdo_dev_state_free)(struct xfrm_state___25 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___106 *, struct xfrm_state___25 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___25 *);
};

struct xfrm_state_offload___25 {
	struct net_device___105 *dev;
	struct net_device___105 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___25;

struct xfrm_type_offload___25;

struct xfrm_state___25 {
	possible_net_t___105 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___92 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___25 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___25 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___301 xfrag;
	const struct xfrm_type___25 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___25 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___105 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___105 *dev;
	const char *name;
};

struct ip_tunnel_parm___3;

struct net_device_ops___105 {
	int (*ndo_init)(struct net_device___105 *);
	void (*ndo_uninit)(struct net_device___105 *);
	int (*ndo_open)(struct net_device___105 *);
	int (*ndo_stop)(struct net_device___105 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___106 *, struct net_device___105 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___106 *, struct net_device___105 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___105 *, struct sk_buff___106 *, struct net_device___105 *);
	void (*ndo_change_rx_flags)(struct net_device___105 *, int);
	void (*ndo_set_rx_mode)(struct net_device___105 *);
	int (*ndo_set_mac_address)(struct net_device___105 *, void *);
	int (*ndo_validate_addr)(struct net_device___105 *);
	int (*ndo_do_ioctl)(struct net_device___105 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___105 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___105 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___105 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___105 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___105 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___105 *, int);
	int (*ndo_neigh_setup)(struct net_device___105 *, struct neigh_parms___92 *);
	void (*ndo_tx_timeout)(struct net_device___105 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___105 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___105 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___105 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___105 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___105 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___105 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___105 *);
	int (*ndo_netpoll_setup)(struct net_device___105 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___105 *);
	int (*ndo_set_vf_mac)(struct net_device___105 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___105 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___105 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___105 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___105 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___105 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___105 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___105 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___105 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___105 *, int, struct sk_buff___106 *);
	int (*ndo_get_vf_guid)(struct net_device___105 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___105 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___105 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___105 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___105 *);
	int (*ndo_fcoe_disable)(struct net_device___105 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___105 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___105 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___105 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___105 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___105 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___105 *, const struct sk_buff___106 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___105 *, struct net_device___105 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___105 *, struct net_device___105 *);
	struct net_device___105 * (*ndo_get_xmit_slave)(struct net_device___105 *, struct sk_buff___106 *, bool);
	struct net_device___105 * (*ndo_sk_get_lower_dev)(struct net_device___105 *, struct sock___92 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___105 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___105 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___105 *, struct neighbour___92 *);
	void (*ndo_neigh_destroy)(struct net_device___105 *, struct neighbour___92 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___105 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___105 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___106 *, struct netlink_callback___105 *, struct net_device___105 *, struct net_device___105 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___106 *, struct nlattr **, struct net_device___105 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___105 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___106 *, u32, u32, struct net_device___105 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___105 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___105 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___105 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___105 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___105 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___105 *, struct net_device___105 *);
	void (*ndo_dfwd_del_station)(struct net_device___105 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___105 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___105 *);
	int (*ndo_change_proto_down)(struct net_device___105 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___105 *, struct sk_buff___106 *);
	void (*ndo_set_rx_headroom)(struct net_device___105 *, int);
	int (*ndo_bpf)(struct net_device___105 *, struct netdev_bpf___105 *);
	int (*ndo_xdp_xmit)(struct net_device___105 *, int, struct xdp_frame___105 **, u32);
	struct net_device___105 * (*ndo_xdp_get_xmit_slave)(struct net_device___105 *, struct xdp_buff___105 *);
	int (*ndo_xsk_wakeup)(struct net_device___105 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___105 *);
	int (*ndo_tunnel_ctl)(struct net_device___105 *, struct ip_tunnel_parm___3 *, int);
	struct net_device___105 * (*ndo_get_peer_dev)(struct net_device___105 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___105 *, struct net_device_path___105 *);
};

struct neigh_parms___92 {
	possible_net_t___105 net;
	struct net_device___105 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___92 *);
	struct neigh_table___92 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct iphdr___3 {
	__u8 ihl;
	__u8 version: 4;
	__u8 tos;
	__be16 tot_len;
	__be16 id;
	__be16 frag_off;
	__u8 ttl;
	__u8 protocol;
	__sum16 check;
	__be32 saddr;
	__be32 daddr;
};

struct ip_tunnel_parm___3 {
	char name[16];
	int link;
	__be16 i_flags;
	__be16 o_flags;
	__be32 i_key;
	__be32 o_key;
	struct iphdr___3 iph;
};

struct l3mdev_ops___92 {
	u32 (*l3mdev_fib_table)(const struct net_device___105 *);
	struct sk_buff___106 * (*l3mdev_l3_rcv)(struct net_device___105 *, struct sk_buff___106 *, u16);
	struct sk_buff___106 * (*l3mdev_l3_out)(struct net_device___105 *, struct sock___92 *, struct sk_buff___106 *, u16);
	struct dst_entry___92 * (*l3mdev_link_scope_lookup)(const struct net_device___105 *, struct flowi6 *);
};

struct ndisc_ops___74 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___105 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___105 *, struct neighbour___92 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___105 *, u8, struct neighbour___92 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___105 *, struct sk_buff___106 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___110 *, struct net_device___105 *, const struct prefix_info *, struct inet6_dev___74 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___74;

struct ifacaddr6___34;

struct inet6_dev___74 {
	struct net_device___105 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___74 *mc_list;
	struct ifmcaddr6___74 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___105 mc_query_queue;
	struct sk_buff_head___105 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___34 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___92 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___99;

struct tcf_block___99;

struct mini_Qdisc___99 {
	struct tcf_proto___99 *filter_list;
	struct tcf_block___99 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___99 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___105 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___105 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___110 *, struct net_device___105 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___105 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___105 *, struct list_head *);
	size_t (*get_size)(const struct net_device___105 *);
	int (*fill_info)(struct sk_buff___106 *, const struct net_device___105 *);
	size_t (*get_xstats_size)(const struct net_device___105 *);
	int (*fill_xstats)(struct sk_buff___106 *, const struct net_device___105 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___105 *, struct net_device___105 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___105 *, const struct net_device___105 *);
	int (*fill_slave_info)(struct sk_buff___106 *, const struct net_device___105 *, const struct net_device___105 *);
	struct net___110 * (*get_link_net)(const struct net_device___105 *);
	size_t (*get_linkxstats_size)(const struct net_device___105 *, int);
	int (*fill_linkxstats)(struct sk_buff___106 *, const struct net_device___105 *, int *, int);
};

struct rt0_hdr {
	struct ipv6_rt_hdr rt_hdr;
	__u32 reserved;
	struct in6_addr addr[0];
};

struct block_device_operations___187;

struct gendisk___190 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___190 *part0;
	const struct block_device_operations___187 *fops;
	struct request_queue___187 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___173 *bdi;
	struct kobject___284 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___284 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___187 {
	struct bio___187 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___213 *bip_vec;
	struct bio_vec___213 bip_inline_vecs[0];
};

struct blkcg___175;

struct blkg_policy_data___175;

struct blkcg_gq___175 {
	struct request_queue___187 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___175 *blkcg;
	struct blkcg_gq___175 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___175 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___187 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___187(struct request___187 *);

typedef void integrity_complete_fn___187(struct request___187 *, unsigned int);

struct blk_integrity_profile___187 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___187 *prepare_fn;
	integrity_complete_fn___187 *complete_fn;
	const char *name;
};

struct block_device_operations___187 {
	blk_qc_t (*submit_bio)(struct bio___187 *);
	int (*open)(struct block_device___190 *, fmode_t);
	void (*release)(struct gendisk___190 *, fmode_t);
	int (*rw_page)(struct block_device___190 *, sector_t, struct page___301 *, unsigned int);
	int (*ioctl)(struct block_device___190 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___190 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___190 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___190 *);
	int (*getgeo)(struct block_device___190 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___190 *, bool);
	void (*swap_slot_free_notify)(struct block_device___190 *, long unsigned int);
	int (*report_zones)(struct gendisk___190 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___190 *, umode_t *);
	struct module___280 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___190 *, sector_t *);
};

typedef void rq_end_io_fn___187(struct request___187 *, blk_status_t);

struct request___187 {
	struct request_queue___187 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___182 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___187 *bio;
	struct bio___187 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___213 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___187 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___187 *saved_end_io;
		} flush;
	};
	struct gendisk___190 *rq_disk;
	struct block_device___190 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___187 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___182 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___187 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___284 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___296 *debugfs_dir;
	struct dentry___296 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___187;

struct elevator_mq_ops___187 {
	int (*init_sched)(struct request_queue___187 *, struct elevator_type___187 *);
	void (*exit_sched)(struct elevator_queue___187 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___182 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___182 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___182 *);
	bool (*allow_merge)(struct request_queue___187 *, struct request___187 *, struct bio___187 *);
	bool (*bio_merge)(struct request_queue___187 *, struct bio___187 *, unsigned int);
	int (*request_merge)(struct request_queue___187 *, struct request___187 **, struct bio___187 *);
	void (*request_merged)(struct request_queue___187 *, struct request___187 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___187 *, struct request___187 *, struct request___187 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___187 *);
	void (*finish_request)(struct request___187 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___182 *, struct list_head *, bool);
	struct request___187 * (*dispatch_request)(struct blk_mq_hw_ctx___182 *);
	bool (*has_work)(struct blk_mq_hw_ctx___182 *);
	void (*completed_request)(struct request___187 *, u64);
	void (*requeue_request)(struct request___187 *);
	struct request___187 * (*former_request)(struct request_queue___187 *, struct request___187 *);
	struct request___187 * (*next_request)(struct request_queue___187 *, struct request___187 *);
	void (*init_icq)(struct io_cq___187 *);
	void (*exit_icq)(struct io_cq___187 *);
};

struct elv_fs_entry___187;

struct elevator_type___187 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___187 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___187 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___280 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___187 {
	struct elevator_type___187 *type;
	void *elevator_data;
	struct kobject___284 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___187 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___187 *, char *);
	ssize_t (*store)(struct elevator_queue___187 *, const char *, size_t);
};

struct blk_mq_queue_data___182;

struct blk_mq_ops___182 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___182 *, const struct blk_mq_queue_data___182 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___182 *);
	int (*get_budget)(struct request_queue___187 *);
	void (*put_budget)(struct request_queue___187 *, int);
	void (*set_rq_budget_token)(struct request___187 *, int);
	int (*get_rq_budget_token)(struct request___187 *);
	enum blk_eh_timer_return (*timeout)(struct request___187 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___182 *);
	void (*complete)(struct request___187 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___182 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___182 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___182 *, struct request___187 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___182 *, struct request___187 *, unsigned int);
	void (*initialize_rq_fn)(struct request___187 *);
	void (*cleanup_rq)(struct request___187 *);
	bool (*busy)(struct request_queue___187 *);
	int (*map_queues)(struct blk_mq_tag_set___182 *);
	void (*show_rq)(struct seq_file___271 *, struct request___187 *);
};

struct blk_mq_tag_set___182 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___182 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___182 {
	struct request___187 *rq;
	bool last;
};

struct blkcg_policy_data___175;

struct blkcg___175 {
	struct cgroup_subsys_state___223 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___175 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___175 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___175 {
	struct blkcg___175 *blkcg;
	int plid;
};

struct blkg_policy_data___175 {
	struct blkcg_gq___175 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___161 {
	struct mem_cgroup___161 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___161 {
	struct lruvec___169 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___161 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___161 *memcg;
};

struct obj_cgroup___161 {
	struct percpu_ref refcnt;
	struct mem_cgroup___161 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___99 {
	spinlock_t *lock;
	struct sk_buff___106 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___99;

struct Qdisc_ops___99 {
	struct Qdisc_ops___99 *next;
	const struct Qdisc_class_ops___99 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___106 *, struct Qdisc___99 *, struct sk_buff___106 **);
	struct sk_buff___106 * (*dequeue)(struct Qdisc___99 *);
	struct sk_buff___106 * (*peek)(struct Qdisc___99 *);
	int (*init)(struct Qdisc___99 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___99 *);
	void (*destroy)(struct Qdisc___99 *);
	int (*change)(struct Qdisc___99 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___99 *);
	int (*change_tx_queue_len)(struct Qdisc___99 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___99 *, unsigned int);
	int (*dump)(struct Qdisc___99 *, struct sk_buff___106 *);
	int (*dump_stats)(struct Qdisc___99 *, struct gnet_dump___99 *);
	void (*ingress_block_set)(struct Qdisc___99 *, u32);
	void (*egress_block_set)(struct Qdisc___99 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___99 *);
	u32 (*egress_block_get)(struct Qdisc___99 *);
	struct module___280 *owner;
};

struct Qdisc_class_ops___99 {
	unsigned int flags;
	struct netdev_queue___105 * (*select_queue)(struct Qdisc___99 *, struct tcmsg *);
	int (*graft)(struct Qdisc___99 *, long unsigned int, struct Qdisc___99 *, struct Qdisc___99 **, struct netlink_ext_ack *);
	struct Qdisc___99 * (*leaf)(struct Qdisc___99 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___99 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___99 *, u32);
	int (*change)(struct Qdisc___99 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___99 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___99 *, struct qdisc_walker *);
	struct tcf_block___99 * (*tcf_block)(struct Qdisc___99 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___99 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___99 *, long unsigned int);
	int (*dump)(struct Qdisc___99 *, long unsigned int, struct sk_buff___106 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___99 *, long unsigned int, struct gnet_dump___99 *);
};

struct tcf_chain___99;

struct tcf_block___99 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___110 *net;
	struct Qdisc___99 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___99 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___99;

struct tcf_proto_ops___99;

struct tcf_proto___99 {
	struct tcf_proto___99 *next;
	void *root;
	int (*classify)(struct sk_buff___106 *, const struct tcf_proto___99 *, struct tcf_result___99 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___99 *ops;
	struct tcf_chain___99 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___99 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___99 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___99 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___106 *, const struct tcf_proto___99 *, struct tcf_result___99 *);
	int (*init)(struct tcf_proto___99 *);
	void (*destroy)(struct tcf_proto___99 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___99 *, u32);
	void (*put)(struct tcf_proto___99 *, void *);
	int (*change)(struct net___110 *, struct sk_buff___106 *, struct tcf_proto___99 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___99 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___99 *);
	void (*walk)(struct tcf_proto___99 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___99 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___99 *, void *);
	void (*hw_del)(struct tcf_proto___99 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___110 *, struct tcf_chain___99 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___110 *, struct tcf_proto___99 *, void *, struct sk_buff___106 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___110 *, struct tcf_proto___99 *, void *, struct sk_buff___106 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___106 *, struct net___110 *, void *);
	struct module___280 *owner;
	int flags;
};

struct tcf_chain___99 {
	struct mutex filter_chain_lock;
	struct tcf_proto___99 *filter_chain;
	struct list_head list;
	struct tcf_block___99 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___99 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___92 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___99 *prog;
};

struct pneigh_entry___92;

struct neigh_hash_table___92;

struct neigh_table___92 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___105 *, __u32 *);
	bool (*key_eq)(const struct neighbour___92 *, const void *);
	int (*constructor)(struct neighbour___92 *);
	int (*pconstructor)(struct pneigh_entry___92 *);
	void (*pdestructor)(struct pneigh_entry___92 *);
	void (*proxy_redo)(struct sk_buff___106 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___105 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___92 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___105 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___92 *nht;
	struct pneigh_entry___92 **phash_buckets;
};

struct neigh_ops___92 {
	int family;
	void (*solicit)(struct neighbour___92 *, struct sk_buff___106 *);
	void (*error_report)(struct neighbour___92 *, struct sk_buff___106 *);
	int (*output)(struct neighbour___92 *, struct sk_buff___106 *);
	int (*connected_output)(struct neighbour___92 *, struct sk_buff___106 *);
};

struct pneigh_entry___92 {
	struct pneigh_entry___92 *next;
	possible_net_t___105 net;
	struct net_device___105 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___92 {
	struct neighbour___92 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___68 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___110 *, struct sock___92 *, struct sk_buff___106 *);
	int (*orig_input)(struct sk_buff___106 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___92 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___92 *ctarget;
	struct net___110 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___92 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___92 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___77;

struct timewait_sock_ops___76;

struct proto___92 {
	void (*close)(struct sock___92 *, long int);
	int (*pre_connect)(struct sock___92 *, struct sockaddr *, int);
	int (*connect)(struct sock___92 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___92 *, int);
	struct sock___92 * (*accept)(struct sock___92 *, int, int *, bool);
	int (*ioctl)(struct sock___92 *, int, long unsigned int);
	int (*init)(struct sock___92 *);
	void (*destroy)(struct sock___92 *);
	void (*shutdown)(struct sock___92 *, int);
	int (*setsockopt)(struct sock___92 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___92 *, int, int, char *, int *);
	void (*keepalive)(struct sock___92 *, int);
	int (*compat_ioctl)(struct sock___92 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___92 *, struct msghdr___94 *, size_t);
	int (*recvmsg)(struct sock___92 *, struct msghdr___94 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___92 *, struct page___301 *, int, size_t, int);
	int (*bind)(struct sock___92 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___92 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___92 *, struct sk_buff___106 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___92 *);
	int (*hash)(struct sock___92 *);
	void (*unhash)(struct sock___92 *);
	void (*rehash)(struct sock___92 *);
	int (*get_port)(struct sock___92 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___92 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___92 *, int);
	bool (*sock_is_readable)(struct sock___92 *);
	void (*enter_memory_pressure)(struct sock___92 *);
	void (*leave_memory_pressure)(struct sock___92 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___77 *rsk_prot;
	struct timewait_sock_ops___76 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___280 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___92 *, int);
};

struct xfrm_policy_queue___25 {
	struct sk_buff_head___105 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___25 {
	possible_net_t___105 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___25 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct request_sock___78;

struct request_sock_ops___77 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___92 *, struct request_sock___78 *);
	void (*send_ack)(const struct sock___92 *, struct sk_buff___106 *, struct request_sock___78 *);
	void (*send_reset)(const struct sock___92 *, struct sk_buff___106 *);
	void (*destructor)(struct request_sock___78 *);
	void (*syn_ack_timeout)(const struct request_sock___78 *);
};

struct timewait_sock_ops___76 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___92 *, struct sock___92 *, void *);
	void (*twsk_destructor)(struct sock___92 *);
};

struct request_sock___78 {
	struct sock_common___92 __req_common;
	struct request_sock___78 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___77 *rsk_ops;
	struct sock___92 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___74 {
	struct in6_addr mca_addr;
	struct inet6_dev___74 *idev;
	struct ifmcaddr6___74 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___34 {
	struct in6_addr aca_addr;
	struct fib6_info___34 *aca_rt;
	struct ifacaddr6___34 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct inet6_protocol___6 {
	void (*early_demux)(struct sk_buff___106 *);
	void (*early_demux_handler)(struct sk_buff___106 *);
	int (*handler)(struct sk_buff___106 *);
	int (*err_handler)(struct sk_buff___106 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct fib_nh_exception___34 {
	struct fib_nh_exception___34 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___36 *fnhe_rth_input;
	struct rtable___36 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___36 {
	struct dst_entry___92 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___34 {
	struct fib_nh_exception___34 *chain;
};

struct fib_info___24;

struct fib_nh___24 {
	struct fib_nh_common___34 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___24 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___24 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___110 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___24 *nh;
	struct callback_head rcu;
	struct fib_nh___24 fib_nh[0];
};

struct nh_info___24;

struct nh_group___24;

struct nexthop___24 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___110 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___24 *nh_info;
		struct nh_group___24 *nh_grp;
	};
};

struct nh_info___24 {
	struct hlist_node dev_hash;
	struct nexthop___24 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___34 fib_nhc;
		struct fib_nh___24 fib_nh;
		struct fib6_nh___34 fib6_nh;
	};
};

struct nh_grp_entry___24;

struct nh_res_bucket___24 {
	struct nh_grp_entry___24 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___24 {
	struct nexthop___24 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___24 *nh_parent;
};

struct nh_res_table___24 {
	struct net___110 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___24 nh_buckets[0];
};

struct nh_group___24 {
	struct nh_group___24 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___24 *res_table;
	struct nh_grp_entry___24 nh_entries[0];
};

struct xfrm_type___25 {
	struct module___280 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___25 *);
	void (*destructor)(struct xfrm_state___25 *);
	int (*input)(struct xfrm_state___25 *, struct sk_buff___106 *);
	int (*output)(struct xfrm_state___25 *, struct sk_buff___106 *);
	int (*reject)(struct xfrm_state___25 *, struct sk_buff___106 *, const struct flowi *);
};

struct xfrm_type_offload___25 {
	struct module___280 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___25 *, struct sk_buff___106 *);
	int (*input_tail)(struct xfrm_state___25 *, struct sk_buff___106 *);
	int (*xmit)(struct xfrm_state___25 *, struct sk_buff___106 *, netdev_features_t);
};

struct ipv6_rpl_sr_hdr {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
	__u32 cmpre: 4;
	__u32 cmpri: 4;
	__u32 reserved: 4;
	__u32 pad;
	__u32 reserved1: 16;
	long: 48;
	union {
		struct in6_addr addr[0];
		__u8 data[0];
	} segments;
};

struct ioam6_hdr {
	__u8 opt_type;
	__u8 opt_len;
	char: 8;
	__u8 type;
};

struct ioam6_trace_hdr {
	__be16 namespace_id;
	__u8 overflow: 1;
	__u8 nodelen: 5;
	__u8 remlen: 7;
	union {
		__be32 type_be32;
		struct {
			__u32 bit7: 1;
			__u32 bit6: 1;
			__u32 bit5: 1;
			__u32 bit4: 1;
			__u32 bit3: 1;
			__u32 bit2: 1;
			__u32 bit1: 1;
			__u32 bit0: 1;
			__u32 bit15: 1;
			__u32 bit14: 1;
			__u32 bit13: 1;
			__u32 bit12: 1;
			__u32 bit11: 1;
			__u32 bit10: 1;
			__u32 bit9: 1;
			__u32 bit8: 1;
			__u32 bit23: 1;
			__u32 bit22: 1;
			__u32 bit21: 1;
			__u32 bit20: 1;
			__u32 bit19: 1;
			__u32 bit18: 1;
			__u32 bit17: 1;
			__u32 bit16: 1;
		} type;
	};
	__u8 data[0];
};

struct ioam6_schema;

struct ioam6_namespace {
	struct rhash_head head;
	struct callback_head rcu;
	struct ioam6_schema *schema;
	__be16 id;
	__be32 data;
	__be64 data_wide;
};

struct ioam6_schema {
	struct rhash_head head;
	struct callback_head rcu;
	struct ioam6_namespace *ns;
	u32 id;
	int len;
	__be32 hdr;
	u8 data[0];
};

struct ip6fl_iter_state {
	struct seq_net_private___11 p;
	struct pid_namespace___269 *pid_ns;
	int bucket;
};

struct inet_request_sock___8 {
	struct request_sock___74 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___102 *pktopts;
		};
	};
};

typedef struct bio_vec___200 skb_frag_t___44;

struct napi_gro_cb___6 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___93 *last;
};

struct offload_callbacks___5 {
	struct sk_buff___93 * (*gso_segment)(struct sk_buff___93 *, netdev_features_t);
	struct sk_buff___93 * (*gro_receive)(struct list_head *, struct sk_buff___93 *);
	int (*gro_complete)(struct sk_buff___93 *, int);
};

struct net_offload___4 {
	struct offload_callbacks___5 callbacks;
	unsigned int flags;
};

typedef struct sock___79 * (*udp_lookup_t___2)(const struct sk_buff___93 *, __be16, __be16);

struct sr6_tlv {
	__u8 type;
	__u8 len;
	__u8 data[0];
};

enum {
	SEG6_ATTR_UNSPEC = 0,
	SEG6_ATTR_DST = 1,
	SEG6_ATTR_DSTLEN = 2,
	SEG6_ATTR_HMACKEYID = 3,
	SEG6_ATTR_SECRET = 4,
	SEG6_ATTR_SECRETLEN = 5,
	SEG6_ATTR_ALGID = 6,
	SEG6_ATTR_HMACINFO = 7,
	__SEG6_ATTR_MAX = 8,
};

enum {
	SEG6_CMD_UNSPEC = 0,
	SEG6_CMD_SETHMAC = 1,
	SEG6_CMD_DUMPHMAC = 2,
	SEG6_CMD_SET_TUNSRC = 3,
	SEG6_CMD_GET_TUNSRC = 4,
	__SEG6_CMD_MAX = 5,
};

struct seg6_hmac_info {
	struct rhash_head node;
	struct callback_head rcu;
	u32 hmackeyid;
	char secret[64];
	u8 slen;
	u8 alg_id;
};

struct ipv6_rpl_sr_hdr___2 {
	__u8 nexthdr;
	__u8 hdrlen;
	__u8 type;
	__u8 segments_left;
	__u32 cmpre: 4;
	__u32 cmpri: 4;
	__u32 reserved: 4;
	__u32 pad: 4;
	__u32 reserved1: 16;
	long: 48;
	union {
		struct in6_addr addr[0];
		__u8 data[0];
	} segments;
};

enum {
	IOAM6_ATTR_UNSPEC = 0,
	IOAM6_ATTR_NS_ID = 1,
	IOAM6_ATTR_NS_DATA = 2,
	IOAM6_ATTR_NS_DATA_WIDE = 3,
	IOAM6_ATTR_SC_ID = 4,
	IOAM6_ATTR_SC_DATA = 5,
	IOAM6_ATTR_SC_NONE = 6,
	IOAM6_ATTR_PAD = 7,
	__IOAM6_ATTR_MAX = 8,
};

enum {
	IOAM6_CMD_UNSPEC = 0,
	IOAM6_CMD_ADD_NAMESPACE = 1,
	IOAM6_CMD_DEL_NAMESPACE = 2,
	IOAM6_CMD_DUMP_NAMESPACES = 3,
	IOAM6_CMD_ADD_SCHEMA = 4,
	IOAM6_CMD_DEL_SCHEMA = 5,
	IOAM6_CMD_DUMP_SCHEMAS = 6,
	IOAM6_CMD_NS_SET_SCHEMA = 7,
	__IOAM6_CMD_MAX = 8,
};

struct dentry___297;

struct super_block___297;

struct module___281;

struct file_system_type___297 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___297 * (*mount)(struct file_system_type___297 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___297 *);
	struct module___281 *owner;
	struct file_system_type___297 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___297;

struct kiocb___297;

struct iov_iter___217;

struct poll_table_struct___218;

struct vm_area_struct___302;

struct inode___297;

struct file_lock___297;

struct page___302;

struct pipe_inode_info___138;

struct seq_file___272;

struct file_operations___298 {
	struct module___281 *owner;
	loff_t (*llseek)(struct file___297 *, loff_t, int);
	ssize_t (*read)(struct file___297 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___297 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___297 *, struct iov_iter___217 *);
	ssize_t (*write_iter)(struct kiocb___297 *, struct iov_iter___217 *);
	int (*iopoll)(struct kiocb___297 *, bool);
	int (*iterate)(struct file___297 *, struct dir_context *);
	int (*iterate_shared)(struct file___297 *, struct dir_context *);
	__poll_t (*poll)(struct file___297 *, struct poll_table_struct___218 *);
	long int (*unlocked_ioctl)(struct file___297 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___297 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___297 *, struct vm_area_struct___302 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___297 *, struct file___297 *);
	int (*flush)(struct file___297 *, fl_owner_t);
	int (*release)(struct inode___297 *, struct file___297 *);
	int (*fsync)(struct file___297 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___297 *, int);
	int (*lock)(struct file___297 *, int, struct file_lock___297 *);
	ssize_t (*sendpage)(struct file___297 *, struct page___302 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___297 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___297 *, long unsigned int);
	int (*flock)(struct file___297 *, int, struct file_lock___297 *);
	ssize_t (*splice_write)(struct pipe_inode_info___138 *, struct file___297 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___297 *, loff_t *, struct pipe_inode_info___138 *, size_t, unsigned int);
	int (*setlease)(struct file___297 *, long int, struct file_lock___297 **, void **);
	long int (*fallocate)(struct file___297 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___272 *, struct file___297 *);
	ssize_t (*copy_file_range)(struct file___297 *, loff_t, struct file___297 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___297 *, loff_t, struct file___297 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___297 *, loff_t, loff_t, int);
};

struct vmacache___302 {
	u64 seqnum;
	struct vm_area_struct___302 *vmas[4];
};

struct page_frag___302 {
	struct page___302 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___303;

struct pid___274;

struct nsproxy___283;

struct signal_struct___298;

struct bio_list___188;

struct backing_dev_info___174;

struct io_context___188;

struct css_set___224;

struct mem_cgroup___162;

struct request_queue___188;

struct vm_struct___280;

struct task_struct___304 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___304 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___303 *mm;
	struct mm_struct___303 *active_mm;
	struct vmacache___302 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___304 *real_parent;
	struct task_struct___304 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___304 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___274 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___283 *nsproxy;
	struct signal_struct___298 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___304 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___188 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___174 *backing_dev_info;
	struct io_context___188 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___224 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___138 *splice_pipe;
	struct page_frag___302 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___162 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___162 *active_memcg;
	struct request_queue___188 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___304 *oom_reaper_list;
	struct vm_struct___280 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___285;

struct kobj_type___285;

struct kernfs_node___285;

struct kobject___285 {
	const char *name;
	struct list_head entry;
	struct kobject___285 *parent;
	struct kset___285 *kset;
	struct kobj_type___285 *ktype;
	struct kernfs_node___285 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___282 {
	struct kobject___285 kobj;
	struct module___281 *mod;
	struct kobject___285 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___281 {
	struct module___281 *mod;
	struct latch_tree_node node;
};

struct module_layout___281 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___281 mtn;
};

struct module_attribute___281;

struct kernel_param___281;

struct module___281 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___282 mkobj;
	struct module_attribute___281 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___285 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___281 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___281 core_layout;
	struct module_layout___281 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___274;

struct upid___274 {
	int nr;
	struct pid_namespace___274 *ns;
};

struct pid_namespace___274 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___304 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___274 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___274 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___274 numbers[1];
};

typedef struct page___302 *pgtable_t___302;

struct address_space___297;

struct page_pool___126;

struct dev_pagemap___292;

struct page___302 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___297 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___126 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___302 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___302 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___303 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___292 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___292;

struct vm_area_struct___302 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___302 *vm_next;
	struct vm_area_struct___302 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___303 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___292 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___297 *vm_file;
	struct file___297 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___298 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___304 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___304 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___274 *pids[4];
	struct pid___274 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___303 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___302;

struct mm_struct___303 {
	struct {
		struct vm_area_struct___302 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___297 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___302 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___304 *owner;
		struct user_namespace___26 *user_ns;
		struct file___297 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___111;

struct cgroup_namespace___224;

struct nsproxy___283 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___274 *pid_ns_for_children;
	struct net___111 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___224 *cgroup_ns;
};

struct bio___188;

struct bio_list___188 {
	struct bio___188 *head;
	struct bio___188 *tail;
};

struct cgroup_subsys_state___224;

struct bdi_writeback___174 {
	struct backing_dev_info___174 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___224 *memcg_css;
	struct cgroup_subsys_state___224 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___278;

struct backing_dev_info___174 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___174 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___278 *dev;
	char dev_name[64];
	struct device___278 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___297 *debug_dir;
};

struct io_cq___188;

struct io_context___188 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___188 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___224;

struct css_set___224 {
	struct cgroup_subsys_state___224 *subsys[14];
	refcount_t refcount;
	struct css_set___224 *dom_cset;
	struct cgroup___224 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___224 *mg_src_cgrp;
	struct cgroup___224 *mg_dst_cgrp;
	struct css_set___224 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___297;

struct pipe_buffer___138;

struct pipe_inode_info___138 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___302 *tmp_page;
	struct fasync_struct___297 *fasync_readers;
	struct fasync_struct___297 *fasync_writers;
	struct pipe_buffer___138 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___224;

struct cgroup_subsys_state___224 {
	struct cgroup___224 *cgroup;
	struct cgroup_subsys___224 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___224 *parent;
};

struct cgroup_file___224 {
	struct kernfs_node___285 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___162;

struct mem_cgroup_per_node___162;

struct mem_cgroup___162 {
	struct cgroup_subsys_state___224 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___224 events_file;
	struct cgroup_file___224 events_local_file;
	struct cgroup_file___224 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___162 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___304 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___162 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___188;

struct blk_integrity___188 {
	const struct blk_integrity_profile___188 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___188 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___188 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___188;

struct elevator_queue___188;

struct blk_mq_ops___183;

struct blk_mq_hw_ctx___183;

struct gendisk___191;

struct blkcg_gq___176;

struct blk_mq_tag_set___183;

struct request_queue___188 {
	struct request___188 *last_merge;
	struct elevator_queue___188 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___183 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___183 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___191 *disk;
	struct kobject___285 kobj;
	struct kobject___285 *mq_kobj;
	struct blk_integrity___188 integrity;
	struct device___278 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___176 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___183 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___188 bio_split;
	struct dentry___297 *debugfs_dir;
	struct dentry___297 *sched_debugfs_dir;
	struct dentry___297 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___280 {
	struct vm_struct___280 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___302 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___297;

struct address_space___297 {
	struct inode___297 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___297 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___126 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___278 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___126 {
	u32 count;
	struct page___302 *cache[128];
};

struct page_pool___126 {
	struct page_pool_params___126 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___302 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___126 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___292;

struct dev_pagemap___292 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___292 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___297;

struct path___297 {
	struct vfsmount___297 *mnt;
	struct dentry___297 *dentry;
};

struct fown_struct___274 {
	rwlock_t lock;
	struct pid___274 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___297 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___297 f_path;
	struct inode___297 *f_inode;
	const struct file_operations___298 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___274 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___297 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___292;

struct vm_operations_struct___292 {
	void (*open)(struct vm_area_struct___302 *);
	void (*close)(struct vm_area_struct___302 *);
	int (*may_split)(struct vm_area_struct___302 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___302 *);
	int (*mprotect)(struct vm_area_struct___302 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___292 *);
	vm_fault_t (*huge_fault)(struct vm_fault___292 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___292 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___302 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___292 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___292 *);
	int (*access)(struct vm_area_struct___302 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___302 *);
	int (*set_policy)(struct vm_area_struct___302 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___302 *, long unsigned int);
	struct page___302 * (*find_special_page)(struct vm_area_struct___302 *, long unsigned int);
};

struct core_thread___302 {
	struct task_struct___304 *task;
	struct core_thread___302 *next;
};

struct core_state___302 {
	atomic_t nr_threads;
	struct core_thread___302 dumper;
	struct completion startup;
};

struct vm_fault___292 {
	const struct {
		struct vm_area_struct___302 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___302 *cow_page;
	struct page___302 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___302 prealloc_pte;
};

struct pglist_data___170;

struct lruvec___170 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___170 *pgdat;
};

struct zone___170 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___170 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___170 {
	struct zone___170 *zone;
	int zone_idx;
};

struct zonelist___170 {
	struct zoneref___170 _zonerefs[321];
};

struct pglist_data___170 {
	struct zone___170 node_zones[5];
	struct zonelist___170 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___304 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___304 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___170 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct shrink_control___162 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___162 *memcg;
};

struct shrinker___162 {
	long unsigned int (*count_objects)(struct shrinker___162 *, struct shrink_control___162 *);
	long unsigned int (*scan_objects)(struct shrinker___162 *, struct shrink_control___162 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___292 {
	void (*page_free)(struct page___302 *);
	void (*kill)(struct dev_pagemap___292 *);
	void (*cleanup)(struct dev_pagemap___292 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___292 *);
};

struct dentry_operations___297;

struct dentry___297 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___297 *d_parent;
	struct qstr d_name;
	struct inode___297 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___297 *d_op;
	struct super_block___297 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___297;

struct inode___297 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___297 *i_op;
	struct super_block___297 *i_sb;
	struct address_space___297 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___174 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___298 *i_fop;
		void (*free_inode)(struct inode___297 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___297 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___138 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___297 {
	int (*d_revalidate)(struct dentry___297 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___297 *, unsigned int);
	int (*d_hash)(const struct dentry___297 *, struct qstr *);
	int (*d_compare)(const struct dentry___297 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___297 *);
	int (*d_init)(struct dentry___297 *);
	void (*d_release)(struct dentry___297 *);
	void (*d_prune)(struct dentry___297 *);
	void (*d_iput)(struct dentry___297 *, struct inode___297 *);
	char * (*d_dname)(struct dentry___297 *, char *, int);
	struct vfsmount___297 * (*d_automount)(struct path___297 *);
	int (*d_manage)(const struct path___297 *, bool);
	struct dentry___297 * (*d_real)(struct dentry___297 *, const struct inode___297 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___297;

struct mem_dqinfo___297 {
	struct quota_format_type___297 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___297;

struct quota_info___297 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___297 *files[3];
	struct mem_dqinfo___297 info[3];
	const struct quota_format_ops___297 *ops[3];
};

struct rcuwait___298 {
	struct task_struct___304 *task;
};

struct percpu_rw_semaphore___298 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___298 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___297 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___298 rw_sem[3];
};

struct super_operations___297;

struct dquot_operations___297;

struct quotactl_ops___297;

struct block_device___191;

struct super_block___297 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___297 *s_type;
	const struct super_operations___297 *s_op;
	const struct dquot_operations___297 *dq_op;
	const struct quotactl_ops___297 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___297 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___191 *s_bdev;
	struct backing_dev_info___174 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___297 s_dquot;
	struct sb_writers___297 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___297 *s_d_op;
	int cleancache_poolid;
	struct shrinker___162 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___297 {
	struct dentry___297 *mnt_root;
	struct super_block___297 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct psi_group___224 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___304 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___100;

struct cgroup_bpf___100 {
	struct bpf_prog_array___100 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___100 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___224;

struct cgroup_rstat_cpu___224;

struct cgroup___224 {
	struct cgroup_subsys_state___224 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___285 *kn;
	struct cgroup_file___224 procs_file;
	struct cgroup_file___224 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___224 *subsys[14];
	struct cgroup_root___224 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___224 *dom_cgrp;
	struct cgroup___224 *old_dom_cgrp;
	struct cgroup_rstat_cpu___224 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___224 psi;
	struct cgroup_bpf___100 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___188 {
	struct request_queue___188 *q;
	struct io_context___188 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___297 {
	struct file___297 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___297 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___297 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___297 *ia_file;
};

struct dquot___297 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___297 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___297 {
	int qf_fmt_id;
	const struct quota_format_ops___297 *qf_ops;
	struct module___281 *qf_owner;
	struct quota_format_type___297 *qf_next;
};

struct quota_format_ops___297 {
	int (*check_quota_file)(struct super_block___297 *, int);
	int (*read_file_info)(struct super_block___297 *, int);
	int (*write_file_info)(struct super_block___297 *, int);
	int (*free_file_info)(struct super_block___297 *, int);
	int (*read_dqblk)(struct dquot___297 *);
	int (*commit_dqblk)(struct dquot___297 *);
	int (*release_dqblk)(struct dquot___297 *);
	int (*get_next_id)(struct super_block___297 *, struct kqid *);
};

struct dquot_operations___297 {
	int (*write_dquot)(struct dquot___297 *);
	struct dquot___297 * (*alloc_dquot)(struct super_block___297 *, int);
	void (*destroy_dquot)(struct dquot___297 *);
	int (*acquire_dquot)(struct dquot___297 *);
	int (*release_dquot)(struct dquot___297 *);
	int (*mark_dirty)(struct dquot___297 *);
	int (*write_info)(struct super_block___297 *, int);
	qsize_t * (*get_reserved_space)(struct inode___297 *);
	int (*get_projid)(struct inode___297 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___297 *, qsize_t *);
	int (*get_next_id)(struct super_block___297 *, struct kqid *);
};

struct quotactl_ops___297 {
	int (*quota_on)(struct super_block___297 *, int, int, const struct path___297 *);
	int (*quota_off)(struct super_block___297 *, int);
	int (*quota_enable)(struct super_block___297 *, unsigned int);
	int (*quota_disable)(struct super_block___297 *, unsigned int);
	int (*quota_sync)(struct super_block___297 *, int);
	int (*set_info)(struct super_block___297 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___297 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___297 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___297 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___297 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___297 *, unsigned int);
};

struct writeback_control___174;

struct address_space_operations___297 {
	int (*writepage)(struct page___302 *, struct writeback_control___174 *);
	int (*readpage)(struct file___297 *, struct page___302 *);
	int (*writepages)(struct address_space___297 *, struct writeback_control___174 *);
	int (*set_page_dirty)(struct page___302 *);
	int (*readpages)(struct file___297 *, struct address_space___297 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___297 *, struct address_space___297 *, loff_t, unsigned int, unsigned int, struct page___302 **, void **);
	int (*write_end)(struct file___297 *, struct address_space___297 *, loff_t, unsigned int, unsigned int, struct page___302 *, void *);
	sector_t (*bmap)(struct address_space___297 *, sector_t);
	void (*invalidatepage)(struct page___302 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___302 *, gfp_t);
	void (*freepage)(struct page___302 *);
	ssize_t (*direct_IO)(struct kiocb___297 *, struct iov_iter___217 *);
	int (*migratepage)(struct address_space___297 *, struct page___302 *, struct page___302 *, enum migrate_mode);
	bool (*isolate_page)(struct page___302 *, isolate_mode_t);
	void (*putback_page)(struct page___302 *);
	int (*launder_page)(struct page___302 *);
	int (*is_partially_uptodate)(struct page___302 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___302 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___297 *, struct page___302 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___297 *, sector_t *);
	void (*swap_deactivate)(struct file___297 *);
};

struct writeback_control___174 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___174 *wb;
	struct inode___297 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___214;

struct iov_iter___217 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___214 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___138 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___297 {
	struct dentry___297 * (*lookup)(struct inode___297 *, struct dentry___297 *, unsigned int);
	const char * (*get_link)(struct dentry___297 *, struct inode___297 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___297 *, int);
	struct posix_acl * (*get_acl)(struct inode___297 *, int, bool);
	int (*readlink)(struct dentry___297 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___297 *, struct dentry___297 *, umode_t, bool);
	int (*link)(struct dentry___297 *, struct inode___297 *, struct dentry___297 *);
	int (*unlink)(struct inode___297 *, struct dentry___297 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___297 *, struct dentry___297 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___297 *, struct dentry___297 *, umode_t);
	int (*rmdir)(struct inode___297 *, struct dentry___297 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___297 *, struct dentry___297 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___297 *, struct dentry___297 *, struct inode___297 *, struct dentry___297 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___297 *, struct iattr___297 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___297 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___297 *, char *, size_t);
	int (*fiemap)(struct inode___297 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___297 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___297 *, struct dentry___297 *, struct file___297 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___297 *, struct dentry___297 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___297 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___297 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___297 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___297 {
	void (*fl_copy_lock)(struct file_lock___297 *, struct file_lock___297 *);
	void (*fl_release_private)(struct file_lock___297 *);
};

struct lock_manager_operations___297;

struct file_lock___297 {
	struct file_lock___297 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___297 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___297 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___297 *fl_ops;
	const struct lock_manager_operations___297 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___297 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___297 *);
	int (*lm_grant)(struct file_lock___297 *, int);
	bool (*lm_break)(struct file_lock___297 *);
	int (*lm_change)(struct file_lock___297 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___297 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___297 *);
};

struct fasync_struct___297 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___297 *fa_next;
	struct file___297 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___297 {
	struct inode___297 * (*alloc_inode)(struct super_block___297 *);
	void (*destroy_inode)(struct inode___297 *);
	void (*free_inode)(struct inode___297 *);
	void (*dirty_inode)(struct inode___297 *, int);
	int (*write_inode)(struct inode___297 *, struct writeback_control___174 *);
	int (*drop_inode)(struct inode___297 *);
	void (*evict_inode)(struct inode___297 *);
	void (*put_super)(struct super_block___297 *);
	int (*sync_fs)(struct super_block___297 *, int);
	int (*freeze_super)(struct super_block___297 *);
	int (*freeze_fs)(struct super_block___297 *);
	int (*thaw_super)(struct super_block___297 *);
	int (*unfreeze_fs)(struct super_block___297 *);
	int (*statfs)(struct dentry___297 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___297 *, int *, char *);
	void (*umount_begin)(struct super_block___297 *);
	int (*show_options)(struct seq_file___272 *, struct dentry___297 *);
	int (*show_devname)(struct seq_file___272 *, struct dentry___297 *);
	int (*show_path)(struct seq_file___272 *, struct dentry___297 *);
	int (*show_stats)(struct seq_file___272 *, struct dentry___297 *);
	ssize_t (*quota_read)(struct super_block___297 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___297 *, int, const char *, size_t, loff_t);
	struct dquot___297 ** (*get_dquots)(struct inode___297 *);
	long int (*nr_cached_objects)(struct super_block___297 *, struct shrink_control___162 *);
	long int (*free_cached_objects)(struct super_block___297 *, struct shrink_control___162 *);
	struct file___297 * (*real_loop)(struct file___297 *);
};

struct wakeup_source___278;

struct dev_pm_info___278 {
	pm_message_t power_state;
	unsigned int can_wakeup;
	unsigned int async_suspend;
	bool in_dpm_list;
	bool is_prepared;
	bool is_suspended;
	bool is_noirq_suspended;
	bool is_late_suspended;
	bool no_pm;
	bool early_init;
	bool direct_complete;
	long: 56;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___278 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___278 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___278;

struct bus_type___278;

struct device_driver___278;

struct dev_pm_domain___278;

struct fwnode_handle___274;

struct class___278;

struct attribute_group___285;

struct device___278 {
	struct kobject___285 kobj;
	struct device___278 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___278 *type;
	struct bus_type___278 *bus;
	struct device_driver___278 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___278 power;
	struct dev_pm_domain___278 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___274 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___278 *class;
	const struct attribute_group___285 **groups;
	void (*release)(struct device___278 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___191 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___297 *bd_inode;
	struct super_block___297 *bd_super;
	void *bd_claiming;
	struct device___278 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___285 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___191 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___297 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___226)(struct file___297 *, wait_queue_head_t *, struct poll_table_struct___218 *);

struct poll_table_struct___218 {
	poll_queue_proc___226 _qproc;
	__poll_t _key;
};

struct seq_operations___272;

struct seq_file___272 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___272 *op;
	int poll_event;
	const struct file___297 *file;
	void *private;
};

typedef void bio_end_io_t___188(struct bio___188 *);

struct bio_vec___214 {
	struct page___302 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___188;

struct bio___188 {
	struct bio___188 *bi_next;
	struct block_device___191 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___188 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___176 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___188 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___214 *bi_io_vec;
	struct bio_set___188 *bi_pool;
	struct bio_vec___214 bi_inline_vecs[0];
};

struct msghdr___95 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___217 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___297 *msg_iocb;
};

struct net_device___106;

struct sock___93;

struct sk_buff___107 {
	union {
		struct {
			struct sk_buff___107 *next;
			struct sk_buff___107 *prev;
			union {
				struct net_device___106 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___93 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___107 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___111;

struct fqdir___111 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___111 *f;
	struct net___111 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___111;

struct inet_frags___111 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___111 *, const void *);
	void (*destructor)(struct inet_frag_queue___111 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___66;

struct fib_rules_ops___93;

struct tcp_congestion_ops___38;

struct fib_notifier_ops___93;

struct netns_ipv4___111 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___66 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___93 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___93 *fibnl;
	struct sock___93 **icmp_sk;
	struct sock___93 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___93 **tcp_sk;
	struct fqdir___111 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___38 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___93 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___93 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___93 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___93;

struct neighbour___93;

struct dst_ops___111 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___111 *);
	struct dst_entry___93 * (*check)(struct dst_entry___93 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___93 *);
	unsigned int (*mtu)(const struct dst_entry___93 *);
	u32 * (*cow_metrics)(struct dst_entry___93 *, long unsigned int);
	void (*destroy)(struct dst_entry___93 *);
	void (*ifdown)(struct dst_entry___93 *, struct net_device___106 *, int);
	struct dst_entry___93 * (*negative_advice)(struct dst_entry___93 *);
	void (*link_failure)(struct sk_buff___107 *);
	void (*update_pmtu)(struct dst_entry___93 *, struct sock___93 *, struct sk_buff___107 *, u32, bool);
	void (*redirect)(struct dst_entry___93 *, struct sock___93 *, struct sk_buff___107 *);
	int (*local_out)(struct net___111 *, struct sock___93 *, struct sk_buff___107 *);
	struct neighbour___93 * (*neigh_lookup)(const struct dst_entry___93 *, struct sk_buff___107 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___93 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___35;

struct rt6_info___35;

struct fib6_table___35;

struct netns_ipv6___111 {
	struct dst_ops___111 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___111 *fqdir;
	struct fib6_info___35 *fib6_null_entry;
	struct rt6_info___35 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___35 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___35 *ip6_prohibit_entry;
	struct rt6_info___35 *ip6_blk_hole_entry;
	struct fib6_table___35 *fib6_local_tbl;
	struct fib_rules_ops___93 *fib6_rules_ops;
	struct sock___93 **icmp_sk;
	struct sock___93 *ndisc_sk;
	struct sock___93 *tcp_sk;
	struct sock___93 *igmp_sk;
	struct sock___93 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___93 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___93 *notifier_ops;
	struct fib_notifier_ops___93 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___111 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___111 *fqdir;
};

struct netns_sctp___93 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___93 *ctl_sock;
	struct sock___93 *udp4_sock;
	struct sock___93 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___22;

struct netns_nf___22 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___22 *hooks_ipv4[5];
	struct nf_hook_entries___22 *hooks_ipv6[5];
	struct nf_hook_entries___22 *hooks_arp[3];
	struct nf_hook_entries___22 *hooks_bridge[5];
	struct nf_hook_entries___22 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct sk_buff_head___106 {
	struct sk_buff___107 *next;
	struct sk_buff___107 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___100;

struct netns_bpf___100 {
	struct bpf_prog_array___100 *run_array[2];
	struct bpf_prog___100 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___111 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___93 *nlsk;
	struct sock___93 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___111 xfrm4_dst_ops;
	struct dst_ops___111 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___111 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___93 *rtnl;
	struct sock___93 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___106 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___111 ipv4;
	struct netns_ipv6___111 ipv6;
	struct netns_ieee802154_lowpan___111 ieee802154_lowpan;
	struct netns_sctp___93 sctp;
	struct netns_nf___22 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___106 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___100 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___111 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___93 *crypto_nlsk;
	struct sock___93 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___111 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___107 *fragments_tail;
	struct sk_buff___107 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___111 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___66 {
	struct ip_ra_chain___66 *next;
	struct sock___93 *sk;
	union {
		void (*destructor)(struct sock___93 *);
		struct sock___93 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___93;

struct fib_lookup_arg___93;

struct fib_rules_ops___93 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___93 *, struct flowi *, int, struct fib_lookup_arg___93 *);
	bool (*suppress)(struct fib_rule___93 *, int, struct fib_lookup_arg___93 *);
	int (*match)(struct fib_rule___93 *, struct flowi *, int);
	int (*configure)(struct fib_rule___93 *, struct sk_buff___107 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___93 *);
	int (*compare)(struct fib_rule___93 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___93 *, struct sk_buff___107 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___93 *);
	void (*flush_cache)(struct fib_rules_ops___93 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___281 *owner;
	struct net___111 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___111 *net;
} possible_net_t___106;

struct proto___93;

struct sock_common___93 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___93 *skc_prot;
	possible_net_t___106 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___93 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___93 {
	struct cgroup___224 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___93;

struct socket_wq___94;

struct socket___95;

struct sock_reuseport___40;

struct sock___93 {
	struct sock_common___93 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___106 sk_error_queue;
	struct sk_buff___107 *sk_rx_skb_cache;
	struct sk_buff_head___106 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___107 *head;
		struct sk_buff___107 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___93 *sk_filter;
	union {
		struct socket_wq___94 *sk_wq;
		struct socket_wq___94 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___93 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___93 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___107 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___107 *sk_tx_skb_cache;
	struct sk_buff_head___106 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___302 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___93 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___274 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___95 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___93 sk_cgrp_data;
	struct mem_cgroup___162 *sk_memcg;
	void (*sk_state_change)(struct sock___93 *);
	void (*sk_data_ready)(struct sock___93 *);
	void (*sk_write_space)(struct sock___93 *);
	void (*sk_error_report)(struct sock___93 *);
	int (*sk_backlog_rcv)(struct sock___93 *, struct sk_buff___107 *);
	struct sk_buff___107 * (*sk_validate_xmit_skb)(struct sock___93 *, struct net_device___106 *, struct sk_buff___107 *);
	void (*sk_destruct)(struct sock___93 *);
	struct sock_reuseport___40 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct tcp_congestion_ops___38 {
	u32 (*ssthresh)(struct sock___93 *);
	void (*cong_avoid)(struct sock___93 *, u32, u32);
	void (*set_state)(struct sock___93 *, u8);
	void (*cwnd_event)(struct sock___93 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___93 *, u32);
	void (*pkts_acked)(struct sock___93 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___93 *);
	void (*cong_control)(struct sock___93 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___93 *);
	u32 (*sndbuf_expand)(struct sock___93 *);
	size_t (*get_info)(struct sock___93 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___281 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___93 *);
	void (*release)(struct sock___93 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___93 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___111 *);
	int (*fib_dump)(struct net___111 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___281 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___69;

struct dst_entry___93 {
	struct net_device___106 *dev;
	struct dst_ops___111 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___107 *);
	int (*output)(struct net___111 *, struct sock___93 *, struct sk_buff___107 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___69 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___106(struct sk_buff___107 **);

struct bpf_xdp_entity___100 {
	struct bpf_prog___100 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___106;

struct net_device_ops___106;

struct l3mdev_ops___93;

struct ndisc_ops___75;

struct xfrmdev_ops___106;

struct header_ops___106;

struct in_device___22;

struct inet6_dev___75;

struct netdev_rx_queue___106;

struct mini_Qdisc___100;

struct netdev_queue___106;

struct Qdisc___100;

struct rtnl_link_ops___100;

struct dcbnl_rtnl_ops___106;

struct net_device___106 {
	char name[16];
	struct netdev_name_node___106 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___106 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___93 *l3mdev_ops;
	const struct ndisc_ops___75 *ndisc_ops;
	const struct xfrmdev_ops___106 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___106 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___285 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device___22 *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___75 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___106 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___100 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___106 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___100 *miniq_ingress;
	struct netdev_queue___106 *ingress_queue;
	struct nf_hook_entries___22 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___106 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___100 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___100 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___106 = 0,
		NETREG_REGISTERED___106 = 1,
		NETREG_UNREGISTERING___106 = 2,
		NETREG_UNREGISTERED___106 = 3,
		NETREG_RELEASED___106 = 4,
		NETREG_DUMMY___106 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___106 = 0,
		RTNL_LINK_INITIALIZING___106 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___106 *);
	struct netpoll_info *npinfo;
	possible_net_t___106 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___278 dev;
	const struct attribute_group___285 *sysfs_groups[4];
	const struct attribute_group___285 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___100 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___106 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___100 xdp_state[3];
	long: 64;
};

struct neigh_table___93;

struct neigh_parms___93;

struct neigh_ops___93;

struct neighbour___93 {
	struct neighbour___93 *next;
	struct neigh_table___93 *tbl;
	struct neigh_parms___93 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___106 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___93 *, struct sk_buff___107 *);
	const struct neigh_ops___93 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___106 *dev;
	u8 primary_key[0];
};

struct rtable___37;

struct fnhe_hash_bucket___35;

struct fib_nh_common___35 {
	struct net_device___106 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___69 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___37 **nhc_pcpu_rth_output;
	struct rtable___37 *nhc_rth_input;
	struct fnhe_hash_bucket___35 *nhc_exceptions;
};

struct fib6_nh___35 {
	struct fib_nh_common___35 nh_common;
	long unsigned int last_probe;
	struct rt6_info___35 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___35;

struct nexthop___25;

struct fib6_info___35 {
	struct fib6_table___35 *fib6_table;
	struct fib6_info___35 *fib6_next;
	struct fib6_node___35 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___25 *nh;
	struct fib6_nh___35 fib6_nh[0];
};

struct rt6_info___35 {
	struct dst_entry___93 dst;
	struct fib6_info___35 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___75 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___35 {
	struct fib6_node___35 *parent;
	struct fib6_node___35 *left;
	struct fib6_node___35 *right;
	struct fib6_node___35 *subtree;
	struct fib6_info___35 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___35 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___35 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___35 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___22;

typedef unsigned int nf_hookfn___27(void *, struct sk_buff___107 *, const struct nf_hook_state___22 *);

struct nf_hook_entry___22 {
	nf_hookfn___27 *hook;
	void *priv;
};

struct nf_hook_entries___22 {
	u16 num_hook_entries;
	struct nf_hook_entry___22 hooks[0];
};

struct bpf_prog_array_item___100 {
	struct bpf_prog___100 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___100 {
	struct callback_head rcu;
	struct bpf_prog_array_item___100 items[0];
};

struct bpf_prog_aux___109;

struct bpf_prog___100 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___109 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___274;

struct fwnode_handle___274 {
	struct fwnode_handle___274 *secondary;
	const struct fwnode_operations___274 *ops;
	struct device___278 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___274;

struct fwnode_endpoint___274;

struct fwnode_operations___274 {
	struct fwnode_handle___274 * (*get)(struct fwnode_handle___274 *);
	void (*put)(struct fwnode_handle___274 *);
	bool (*device_is_available)(const struct fwnode_handle___274 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___274 *, const struct device___278 *);
	bool (*property_present)(const struct fwnode_handle___274 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___274 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___274 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___274 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*get_parent)(const struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*get_next_child_node)(const struct fwnode_handle___274 *, struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*get_named_child_node)(const struct fwnode_handle___274 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___274 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___274 *);
	struct fwnode_handle___274 * (*graph_get_next_endpoint)(const struct fwnode_handle___274 *, struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*graph_get_remote_endpoint)(const struct fwnode_handle___274 *);
	struct fwnode_handle___274 * (*graph_get_port_parent)(struct fwnode_handle___274 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___274 *, struct fwnode_endpoint___274 *);
	int (*add_links)(struct fwnode_handle___274 *);
};

struct fwnode_endpoint___274 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___274 *local_fwnode;
};

struct fwnode_reference_args___274 {
	struct fwnode_handle___274 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___285;

struct kernfs_elem_dir___285 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___285 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___285;

struct kernfs_root___285 {
	struct kernfs_node___285 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___285 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___285 {
	struct kernfs_node___285 *target_kn;
};

struct kernfs_ops___285;

struct kernfs_elem_attr___285 {
	const struct kernfs_ops___285 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___285 *notify_next;
};

struct kernfs_node___285 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___285 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___285 dir;
		struct kernfs_elem_symlink___285 symlink;
		struct kernfs_elem_attr___285 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___285;

struct kernfs_ops___285 {
	int (*open)(struct kernfs_open_file___285 *);
	void (*release)(struct kernfs_open_file___285 *);
	int (*seq_show)(struct seq_file___272 *, void *);
	void * (*seq_start)(struct seq_file___272 *, loff_t *);
	void * (*seq_next)(struct seq_file___272 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___272 *, void *);
	ssize_t (*read)(struct kernfs_open_file___285 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___285 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___285 *, struct poll_table_struct___218 *);
	int (*mmap)(struct kernfs_open_file___285 *, struct vm_area_struct___302 *);
};

struct kernfs_syscall_ops___285 {
	int (*show_options)(struct seq_file___272 *, struct kernfs_root___285 *);
	int (*mkdir)(struct kernfs_node___285 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___285 *);
	int (*rename)(struct kernfs_node___285 *, struct kernfs_node___285 *, const char *);
	int (*show_path)(struct seq_file___272 *, struct kernfs_node___285 *, struct kernfs_root___285 *);
};

struct kernfs_open_file___285 {
	struct kernfs_node___285 *kn;
	struct file___297 *file;
	struct seq_file___272 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___292 *vm_ops;
};

struct kobj_ns_type_operations___93 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___93 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___285;

struct attribute_group___285 {
	const char *name;
	umode_t (*is_visible)(struct kobject___285 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___285 *, struct bin_attribute___285 *, int);
	struct attribute **attrs;
	struct bin_attribute___285 **bin_attrs;
};

struct bin_attribute___285 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___297 * (*f_mapping)();
	ssize_t (*read)(struct file___297 *, struct kobject___285 *, struct bin_attribute___285 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___297 *, struct kobject___285 *, struct bin_attribute___285 *, char *, loff_t, size_t);
	int (*mmap)(struct file___297 *, struct kobject___285 *, struct bin_attribute___285 *, struct vm_area_struct___302 *);
};

struct sysfs_ops___285 {
	ssize_t (*show)(struct kobject___285 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___285 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___285;

struct kset___285 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___285 kobj;
	const struct kset_uevent_ops___285 *uevent_ops;
};

struct kobj_type___285 {
	void (*release)(struct kobject___285 *);
	const struct sysfs_ops___285 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___285 **default_groups;
	const struct kobj_ns_type_operations___93 * (*child_ns_type)(struct kobject___285 *);
	const void * (*namespace)(struct kobject___285 *);
	void (*get_ownership)(struct kobject___285 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___285 {
	int (* const filter)(struct kset___285 *, struct kobject___285 *);
	const char * (* const name)(struct kset___285 *, struct kobject___285 *);
	int (* const uevent)(struct kset___285 *, struct kobject___285 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___281 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___281 *);
	int (*get)(char *, const struct kernel_param___281 *);
	void (*free)(void *);
};

struct kparam_array___281;

struct kernel_param___281 {
	const char *name;
	struct module___281 *mod;
	const struct kernel_param_ops___281 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___281 *arr;
	};
};

struct kparam_array___281 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___281 *ops;
	void *elem;
};

struct module_attribute___281 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___281 *, struct module_kobject___282 *, char *);
	ssize_t (*store)(struct module_attribute___281 *, struct module_kobject___282 *, const char *, size_t);
	void (*setup)(struct module___281 *, const char *);
	int (*test)(struct module___281 *);
	void (*free)(struct module___281 *);
};

struct cgroup_namespace___224 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___224 *root_cset;
};

struct socket_wq___94 {
	wait_queue_head_t wait;
	struct fasync_struct___297 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___94;

struct socket___95 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___297 *file;
	struct sock___93 *sk;
	const struct proto_ops___94 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___94 wq;
};

typedef int (*sk_read_actor_t___93)(read_descriptor_t *, struct sk_buff___107 *, unsigned int, size_t);

struct proto_ops___94 {
	int family;
	struct module___281 *owner;
	int (*release)(struct socket___95 *);
	int (*bind)(struct socket___95 *, struct sockaddr *, int);
	int (*connect)(struct socket___95 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___95 *, struct socket___95 *);
	int (*accept)(struct socket___95 *, struct socket___95 *, int, bool);
	int (*getname)(struct socket___95 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___297 *, struct socket___95 *, struct poll_table_struct___218 *);
	int (*ioctl)(struct socket___95 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___95 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___95 *, void *, bool, bool);
	int (*listen)(struct socket___95 *, int);
	int (*shutdown)(struct socket___95 *, int);
	int (*setsockopt)(struct socket___95 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___95 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___272 *, struct socket___95 *);
	int (*sendmsg)(struct socket___95 *, struct msghdr___95 *, size_t);
	int (*recvmsg)(struct socket___95 *, struct msghdr___95 *, size_t, int);
	int (*mmap)(struct file___297 *, struct socket___95 *, struct vm_area_struct___302 *);
	ssize_t (*sendpage)(struct socket___95 *, struct page___302 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___95 *, loff_t *, struct pipe_inode_info___138 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___93 *, int);
	int (*peek_len)(struct socket___95 *);
	int (*read_sock)(struct sock___93 *, read_descriptor_t *, sk_read_actor_t___93);
	int (*sendpage_locked)(struct sock___93 *, struct page___302 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___93 *, struct msghdr___95 *, size_t);
	int (*set_rcvlowat)(struct sock___93 *, int);
};

struct dev_pm_ops___278 {
	int (*prepare)(struct device___278 *);
	void (*complete)(struct device___278 *);
	int (*suspend)(struct device___278 *);
	int (*resume)(struct device___278 *);
	int (*freeze)(struct device___278 *);
	int (*thaw)(struct device___278 *);
	int (*poweroff)(struct device___278 *);
	int (*restore)(struct device___278 *);
	int (*suspend_late)(struct device___278 *);
	int (*resume_early)(struct device___278 *);
	int (*freeze_late)(struct device___278 *);
	int (*thaw_early)(struct device___278 *);
	int (*poweroff_late)(struct device___278 *);
	int (*restore_early)(struct device___278 *);
	int (*suspend_noirq)(struct device___278 *);
	int (*resume_noirq)(struct device___278 *);
	int (*freeze_noirq)(struct device___278 *);
	int (*thaw_noirq)(struct device___278 *);
	int (*poweroff_noirq)(struct device___278 *);
	int (*restore_noirq)(struct device___278 *);
	int (*runtime_suspend)(struct device___278 *);
	int (*runtime_resume)(struct device___278 *);
	int (*runtime_idle)(struct device___278 *);
};

struct wakeup_source___278 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___278 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___278 {
	struct dev_pm_ops___278 ops;
	int (*start)(struct device___278 *);
	void (*detach)(struct device___278 *, bool);
	int (*activate)(struct device___278 *);
	void (*sync)(struct device___278 *);
	void (*dismiss)(struct device___278 *);
};

struct bus_type___278 {
	const char *name;
	const char *dev_name;
	struct device___278 *dev_root;
	const struct attribute_group___285 **bus_groups;
	const struct attribute_group___285 **dev_groups;
	const struct attribute_group___285 **drv_groups;
	int (*match)(struct device___278 *, struct device_driver___278 *);
	int (*uevent)(struct device___278 *, struct kobj_uevent_env *);
	int (*probe)(struct device___278 *);
	void (*sync_state)(struct device___278 *);
	void (*remove)(struct device___278 *);
	void (*shutdown)(struct device___278 *);
	int (*online)(struct device___278 *);
	int (*offline)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	int (*num_vf)(struct device___278 *);
	int (*dma_configure)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___278 {
	const char *name;
	struct bus_type___278 *bus;
	struct module___281 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___278 *);
	void (*sync_state)(struct device___278 *);
	int (*remove)(struct device___278 *);
	void (*shutdown)(struct device___278 *);
	int (*suspend)(struct device___278 *, pm_message_t);
	int (*resume)(struct device___278 *);
	const struct attribute_group___285 **groups;
	const struct attribute_group___285 **dev_groups;
	const struct dev_pm_ops___278 *pm;
	void (*coredump)(struct device___278 *);
	struct driver_private *p;
};

struct device_type___278 {
	const char *name;
	const struct attribute_group___285 **groups;
	int (*uevent)(struct device___278 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___278 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___278 *);
	const struct dev_pm_ops___278 *pm;
};

struct class___278 {
	const char *name;
	struct module___281 *owner;
	const struct attribute_group___285 **class_groups;
	const struct attribute_group___285 **dev_groups;
	struct kobject___285 *dev_kobj;
	int (*dev_uevent)(struct device___278 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___278 *, umode_t *);
	void (*class_release)(struct class___278 *);
	void (*dev_release)(struct device___278 *);
	int (*shutdown_pre)(struct device___278 *);
	const struct kobj_ns_type_operations___93 *ns_type;
	const void * (*namespace)(struct device___278 *);
	void (*get_ownership)(struct device___278 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___278 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___138;

struct pipe_buffer___138 {
	struct page___302 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___138 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___138 {
	int (*confirm)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
	void (*release)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
	bool (*try_steal)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
	bool (*get)(struct pipe_inode_info___138 *, struct pipe_buffer___138 *);
};

typedef struct bio_vec___214 skb_frag_t___45;

struct skb_shared_info___38 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___107 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___45 frags[17];
};

struct seq_operations___272 {
	void * (*start)(struct seq_file___272 *, loff_t *);
	void (*stop)(struct seq_file___272 *, void *);
	void * (*next)(struct seq_file___272 *, void *, loff_t *);
	int (*show)(struct seq_file___272 *, void *);
};

struct seq_net_private___17 {
	struct net___111 *net;
};

struct pernet_operations___39 {
	struct list_head list;
	int (*init)(struct net___111 *);
	void (*pre_exit)(struct net___111 *);
	void (*exit)(struct net___111 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___106 {
	int (*ieee_getets)(struct net_device___106 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___106 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___106 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___106 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___106 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___106 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___106 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___106 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___106 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___106 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___106 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___106 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___106 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___106 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___106 *);
	u8 (*setstate)(struct net_device___106 *, u8);
	void (*getpermhwaddr)(struct net_device___106 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___106 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___106 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___106 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___106 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___106 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___106 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___106 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___106 *, int, u8 *);
	void (*setpfccfg)(struct net_device___106 *, int, u8);
	void (*getpfccfg)(struct net_device___106 *, int, u8 *);
	u8 (*setall)(struct net_device___106 *);
	u8 (*getcap)(struct net_device___106 *, int, u8 *);
	int (*getnumtcs)(struct net_device___106 *, int, u8 *);
	int (*setnumtcs)(struct net_device___106 *, int, u8);
	u8 (*getpfcstate)(struct net_device___106 *);
	void (*setpfcstate)(struct net_device___106 *, u8);
	void (*getbcncfg)(struct net_device___106 *, int, u32 *);
	void (*setbcncfg)(struct net_device___106 *, int, u32);
	void (*getbcnrp)(struct net_device___106 *, int, u8 *);
	void (*setbcnrp)(struct net_device___106 *, int, u8);
	int (*setapp)(struct net_device___106 *, u8, u16, u8);
	int (*getapp)(struct net_device___106 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___106 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___106 *, int, u8);
	u8 (*getdcbx)(struct net_device___106 *);
	u8 (*setdcbx)(struct net_device___106 *, u8);
	int (*peer_getappinfo)(struct net_device___106 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___106 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___106 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___106 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___106 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___106 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___109;

typedef int (*bpf_iter_init_seq_priv_t___108)(void *, struct bpf_iter_aux_info___109 *);

struct bpf_map___109;

struct bpf_iter_aux_info___109 {
	struct bpf_map___109 *map;
};

struct bpf_iter_seq_info___108 {
	const struct seq_operations___272 *seq_ops;
	bpf_iter_init_seq_priv_t___108 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___108 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___109 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___109 *, struct file___297 *);
	void (*map_free)(struct bpf_map___109 *);
	int (*map_get_next_key)(struct bpf_map___109 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___109 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___109 *, void *);
	int (*map_lookup_batch)(struct bpf_map___109 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___109 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___109 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___109 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___109 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___109 *, void *);
	int (*map_update_elem)(struct bpf_map___109 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___109 *, void *);
	int (*map_push_elem)(struct bpf_map___109 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___109 *, void *);
	int (*map_peek_elem)(struct bpf_map___109 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___109 *, struct file___297 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___109 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___109 *, void *, struct seq_file___272 *);
	int (*map_check_btf)(const struct bpf_map___109 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___109 *, struct bpf_prog_aux___109 *);
	void (*map_poke_untrack)(struct bpf_map___109 *, struct bpf_prog_aux___109 *);
	void (*map_poke_run)(struct bpf_map___109 *, u32, struct bpf_prog___100 *, struct bpf_prog___100 *);
	int (*map_direct_value_addr)(const struct bpf_map___109 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___109 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___109 *, struct vm_area_struct___302 *);
	__poll_t (*map_poll)(struct bpf_map___109 *, struct file___297 *, struct poll_table_struct___218 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___109 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___109 *, const struct bpf_map___109 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___109 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___108 *iter_seq_info;
};

struct bpf_map___109 {
	const struct bpf_map_ops___108 *ops;
	struct bpf_map___109 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___162 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___108;

struct bpf_jit_poke_descriptor___108;

struct bpf_prog_ops___100;

struct btf_mod_pair___108;

struct bpf_prog_offload___106;

struct bpf_prog_aux___109 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___100 *dst_prog;
	struct bpf_trampoline___108 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___100 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___108 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___100 *ops;
	struct bpf_map___109 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___108 *used_btfs;
	struct bpf_prog___100 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___109 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___106 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___106;

struct bpf_map_dev_ops___106 {
	int (*map_get_next_key)(struct bpf_offloaded_map___106 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___106 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___106 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___106 *, void *);
};

struct bpf_offloaded_map___106 {
	struct bpf_map___109 map;
	struct net_device___106 *netdev;
	const struct bpf_map_dev_ops___106 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___100 {
	int (*test_run)(struct bpf_prog___100 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___106 {
	struct bpf_prog___100 *prog;
	struct net_device___106 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___108 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___100 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___281 *mod;
};

struct bpf_jit_poke_descriptor___108 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___109 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___108 {
	struct btf *btf;
	struct module___281 *module;
};

struct cftype___224;

struct cgroup_subsys___224 {
	struct cgroup_subsys_state___224 * (*css_alloc)(struct cgroup_subsys_state___224 *);
	int (*css_online)(struct cgroup_subsys_state___224 *);
	void (*css_offline)(struct cgroup_subsys_state___224 *);
	void (*css_released)(struct cgroup_subsys_state___224 *);
	void (*css_free)(struct cgroup_subsys_state___224 *);
	void (*css_reset)(struct cgroup_subsys_state___224 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___224 *, int);
	int (*css_extra_stat_show)(struct seq_file___272 *, struct cgroup_subsys_state___224 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___304 *, struct css_set___224 *);
	void (*cancel_fork)(struct task_struct___304 *, struct css_set___224 *);
	void (*fork)(struct task_struct___304 *);
	void (*exit)(struct task_struct___304 *);
	void (*release)(struct task_struct___304 *);
	void (*bind)(struct cgroup_subsys_state___224 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___224 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___224 *dfl_cftypes;
	struct cftype___224 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___224 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___224 *updated_children;
	struct cgroup___224 *updated_next;
};

struct cgroup_root___224 {
	struct kernfs_root___285 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___224 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___224 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___224 *ss;
	struct list_head node;
	struct kernfs_ops___285 *kf_ops;
	int (*open)(struct kernfs_open_file___285 *);
	void (*release)(struct kernfs_open_file___285 *);
	u64 (*read_u64)(struct cgroup_subsys_state___224 *, struct cftype___224 *);
	s64 (*read_s64)(struct cgroup_subsys_state___224 *, struct cftype___224 *);
	int (*seq_show)(struct seq_file___272 *, void *);
	void * (*seq_start)(struct seq_file___272 *, loff_t *);
	void * (*seq_next)(struct seq_file___272 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___272 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___224 *, struct cftype___224 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___224 *, struct cftype___224 *, s64);
	ssize_t (*write)(struct kernfs_open_file___285 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___285 *, struct poll_table_struct___218 *);
};

struct xdp_rxq_info___106 {
	struct net_device___106 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___106 {
	struct net_device___106 *dev;
};

struct xdp_buff___106 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___106 *rxq;
	struct xdp_txq_info___106 *txq;
	u32 frame_sz;
};

struct xdp_frame___106 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___106 *dev_rx;
};

struct netlink_skb_parms___22 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___93 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___106 {
	struct sk_buff___107 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___107 *, struct netlink_callback___106 *);
	int (*done)(struct netlink_callback___106 *);
	void *data;
	struct module___281 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___106 {
	int (*create)(struct sk_buff___107 *, struct net_device___106 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___107 *, unsigned char *);
	int (*cache)(const struct neighbour___93 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___106 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___107 *);
};

struct netdev_queue___106 {
	struct net_device___106 *dev;
	struct Qdisc___100 *qdisc;
	struct Qdisc___100 *qdisc_sleeping;
	struct kobject___285 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___106 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___100 {
	struct sk_buff___107 *head;
	struct sk_buff___107 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___100;

struct Qdisc___100 {
	int (*enqueue)(struct sk_buff___107 *, struct Qdisc___100 *, struct sk_buff___107 **);
	struct sk_buff___107 * (*dequeue)(struct Qdisc___100 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___100 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___106 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___106 gso_skb;
	struct qdisc_skb_head___100 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___100 *next_sched;
	struct sk_buff_head___106 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___106 {
	struct xdp_rxq_info___106 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___285 kobj;
	struct net_device___106 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___106 {
	enum net_device_path_type type;
	const struct net_device___106 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___106 = 0,
				DEV_PATH_BR_VLAN_TAG___106 = 1,
				DEV_PATH_BR_VLAN_UNTAG___106 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___106 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___106 {
	const struct net_device___106 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___106 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___100 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___106 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___106 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___107 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___106 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___106 *dev;
	const char *name;
};

struct net_device_ops___106 {
	int (*ndo_init)(struct net_device___106 *);
	void (*ndo_uninit)(struct net_device___106 *);
	int (*ndo_open)(struct net_device___106 *);
	int (*ndo_stop)(struct net_device___106 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___107 *, struct net_device___106 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___107 *, struct net_device___106 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___106 *, struct sk_buff___107 *, struct net_device___106 *);
	void (*ndo_change_rx_flags)(struct net_device___106 *, int);
	void (*ndo_set_rx_mode)(struct net_device___106 *);
	int (*ndo_set_mac_address)(struct net_device___106 *, void *);
	int (*ndo_validate_addr)(struct net_device___106 *);
	int (*ndo_do_ioctl)(struct net_device___106 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___106 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___106 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___106 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___106 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___106 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___106 *, int);
	int (*ndo_neigh_setup)(struct net_device___106 *, struct neigh_parms___93 *);
	void (*ndo_tx_timeout)(struct net_device___106 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___106 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___106 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___106 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___106 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___106 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___106 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___106 *);
	int (*ndo_netpoll_setup)(struct net_device___106 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___106 *);
	int (*ndo_set_vf_mac)(struct net_device___106 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___106 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___106 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___106 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___106 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___106 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___106 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___106 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___106 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___106 *, int, struct sk_buff___107 *);
	int (*ndo_get_vf_guid)(struct net_device___106 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___106 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___106 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___106 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___106 *);
	int (*ndo_fcoe_disable)(struct net_device___106 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___106 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___106 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___106 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___106 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___106 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___106 *, const struct sk_buff___107 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___106 *, struct net_device___106 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___106 *, struct net_device___106 *);
	struct net_device___106 * (*ndo_get_xmit_slave)(struct net_device___106 *, struct sk_buff___107 *, bool);
	struct net_device___106 * (*ndo_sk_get_lower_dev)(struct net_device___106 *, struct sock___93 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___106 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___106 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___106 *, struct neighbour___93 *);
	void (*ndo_neigh_destroy)(struct net_device___106 *, struct neighbour___93 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___106 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___106 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___107 *, struct netlink_callback___106 *, struct net_device___106 *, struct net_device___106 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___107 *, struct nlattr **, struct net_device___106 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___106 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___107 *, u32, u32, struct net_device___106 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___106 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___106 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___106 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___106 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___106 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___106 *, struct net_device___106 *);
	void (*ndo_dfwd_del_station)(struct net_device___106 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___106 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___106 *);
	int (*ndo_change_proto_down)(struct net_device___106 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___106 *, struct sk_buff___107 *);
	void (*ndo_set_rx_headroom)(struct net_device___106 *, int);
	int (*ndo_bpf)(struct net_device___106 *, struct netdev_bpf___106 *);
	int (*ndo_xdp_xmit)(struct net_device___106 *, int, struct xdp_frame___106 **, u32);
	struct net_device___106 * (*ndo_xdp_get_xmit_slave)(struct net_device___106 *, struct xdp_buff___106 *);
	int (*ndo_xsk_wakeup)(struct net_device___106 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___106 *);
	int (*ndo_tunnel_ctl)(struct net_device___106 *, struct ip_tunnel_parm *, int);
	struct net_device___106 * (*ndo_get_peer_dev)(struct net_device___106 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___106 *, struct net_device_path___106 *);
};

struct neigh_parms___93 {
	possible_net_t___106 net;
	struct net_device___106 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___93 *);
	struct neigh_table___93 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___93 {
	u32 (*l3mdev_fib_table)(const struct net_device___106 *);
	struct sk_buff___107 * (*l3mdev_l3_rcv)(struct net_device___106 *, struct sk_buff___107 *, u16);
	struct sk_buff___107 * (*l3mdev_l3_out)(struct net_device___106 *, struct sock___93 *, struct sk_buff___107 *, u16);
	struct dst_entry___93 * (*l3mdev_link_scope_lookup)(const struct net_device___106 *, struct flowi6 *);
};

struct ndisc_ops___75 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___106 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___106 *, struct neighbour___93 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___106 *, u8, struct neighbour___93 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___106 *, struct sk_buff___107 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___111 *, struct net_device___106 *, const struct prefix_info *, struct inet6_dev___75 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct in_ifaddr___22;

struct in_device___22 {
	struct net_device___106 *dev;
	refcount_t refcnt;
	int dead;
	struct in_ifaddr___22 *ifa_list;
	struct ip_mc_list *mc_list;
	struct ip_mc_list **mc_hash;
	int mc_count;
	spinlock_t mc_tomb_lock;
	struct ip_mc_list *mc_tomb;
	long unsigned int mr_v1_seen;
	long unsigned int mr_v2_seen;
	long unsigned int mr_maxdelay;
	long unsigned int mr_qi;
	long unsigned int mr_qri;
	unsigned char mr_qrv;
	unsigned char mr_gq_running;
	u32 mr_ifc_count;
	struct timer_list mr_gq_timer;
	struct timer_list mr_ifc_timer;
	struct neigh_parms___93 *arp_parms;
	struct ipv4_devconf cnf;
	struct callback_head callback_head;
};

struct ifmcaddr6___75;

struct ifacaddr6___35;

struct inet6_dev___75 {
	struct net_device___106 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___75 *mc_list;
	struct ifmcaddr6___75 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___106 mc_query_queue;
	struct sk_buff_head___106 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___35 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___93 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___100;

struct tcf_block___100;

struct mini_Qdisc___100 {
	struct tcf_proto___100 *filter_list;
	struct tcf_block___100 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___100 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___106 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___106 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___111 *, struct net_device___106 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___106 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___106 *, struct list_head *);
	size_t (*get_size)(const struct net_device___106 *);
	int (*fill_info)(struct sk_buff___107 *, const struct net_device___106 *);
	size_t (*get_xstats_size)(const struct net_device___106 *);
	int (*fill_xstats)(struct sk_buff___107 *, const struct net_device___106 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___106 *, struct net_device___106 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___106 *, const struct net_device___106 *);
	int (*fill_slave_info)(struct sk_buff___107 *, const struct net_device___106 *, const struct net_device___106 *);
	struct net___111 * (*get_link_net)(const struct net_device___106 *);
	size_t (*get_linkxstats_size)(const struct net_device___106 *, int);
	int (*fill_linkxstats)(struct sk_buff___107 *, const struct net_device___106 *, int *, int);
};

struct netdev_notifier_info___22 {
	struct net_device___106 *dev;
	struct netlink_ext_ack *extack;
};

struct in_ifaddr___22 {
	struct hlist_node hash;
	struct in_ifaddr___22 *ifa_next;
	struct in_device___22 *ifa_dev;
	struct callback_head callback_head;
	__be32 ifa_local;
	__be32 ifa_address;
	__be32 ifa_mask;
	__u32 ifa_rt_priority;
	__be32 ifa_broadcast;
	unsigned char ifa_scope;
	unsigned char ifa_prefixlen;
	__u32 ifa_flags;
	char ifa_label[16];
	__u32 ifa_valid_lft;
	__u32 ifa_preferred_lft;
	long unsigned int ifa_cstamp;
	long unsigned int ifa_tstamp;
};

struct block_device_operations___188;

struct gendisk___191 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___191 *part0;
	const struct block_device_operations___188 *fops;
	struct request_queue___188 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___174 *bdi;
	struct kobject___285 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___285 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___188 {
	struct bio___188 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___214 *bip_vec;
	struct bio_vec___214 bip_inline_vecs[0];
};

struct blkcg___176;

struct blkg_policy_data___176;

struct blkcg_gq___176 {
	struct request_queue___188 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___176 *blkcg;
	struct blkcg_gq___176 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___176 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___188 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___188(struct request___188 *);

typedef void integrity_complete_fn___188(struct request___188 *, unsigned int);

struct blk_integrity_profile___188 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___188 *prepare_fn;
	integrity_complete_fn___188 *complete_fn;
	const char *name;
};

struct block_device_operations___188 {
	blk_qc_t (*submit_bio)(struct bio___188 *);
	int (*open)(struct block_device___191 *, fmode_t);
	void (*release)(struct gendisk___191 *, fmode_t);
	int (*rw_page)(struct block_device___191 *, sector_t, struct page___302 *, unsigned int);
	int (*ioctl)(struct block_device___191 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___191 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___191 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___191 *);
	int (*getgeo)(struct block_device___191 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___191 *, bool);
	void (*swap_slot_free_notify)(struct block_device___191 *, long unsigned int);
	int (*report_zones)(struct gendisk___191 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___191 *, umode_t *);
	struct module___281 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___191 *, sector_t *);
};

typedef void rq_end_io_fn___188(struct request___188 *, blk_status_t);

struct request___188 {
	struct request_queue___188 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___183 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___188 *bio;
	struct bio___188 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___214 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___188 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___188 *saved_end_io;
		} flush;
	};
	struct gendisk___191 *rq_disk;
	struct block_device___191 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___188 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___183 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___188 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___285 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___297 *debugfs_dir;
	struct dentry___297 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___188;

struct elevator_mq_ops___188 {
	int (*init_sched)(struct request_queue___188 *, struct elevator_type___188 *);
	void (*exit_sched)(struct elevator_queue___188 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___183 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___183 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___183 *);
	bool (*allow_merge)(struct request_queue___188 *, struct request___188 *, struct bio___188 *);
	bool (*bio_merge)(struct request_queue___188 *, struct bio___188 *, unsigned int);
	int (*request_merge)(struct request_queue___188 *, struct request___188 **, struct bio___188 *);
	void (*request_merged)(struct request_queue___188 *, struct request___188 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___188 *, struct request___188 *, struct request___188 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___188 *);
	void (*finish_request)(struct request___188 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___183 *, struct list_head *, bool);
	struct request___188 * (*dispatch_request)(struct blk_mq_hw_ctx___183 *);
	bool (*has_work)(struct blk_mq_hw_ctx___183 *);
	void (*completed_request)(struct request___188 *, u64);
	void (*requeue_request)(struct request___188 *);
	struct request___188 * (*former_request)(struct request_queue___188 *, struct request___188 *);
	struct request___188 * (*next_request)(struct request_queue___188 *, struct request___188 *);
	void (*init_icq)(struct io_cq___188 *);
	void (*exit_icq)(struct io_cq___188 *);
};

struct elv_fs_entry___188;

struct elevator_type___188 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___188 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___188 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___281 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___188 {
	struct elevator_type___188 *type;
	void *elevator_data;
	struct kobject___285 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___188 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___188 *, char *);
	ssize_t (*store)(struct elevator_queue___188 *, const char *, size_t);
};

struct blk_mq_queue_data___183;

struct blk_mq_ops___183 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___183 *, const struct blk_mq_queue_data___183 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___183 *);
	int (*get_budget)(struct request_queue___188 *);
	void (*put_budget)(struct request_queue___188 *, int);
	void (*set_rq_budget_token)(struct request___188 *, int);
	int (*get_rq_budget_token)(struct request___188 *);
	enum blk_eh_timer_return (*timeout)(struct request___188 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___183 *);
	void (*complete)(struct request___188 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___183 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___183 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___183 *, struct request___188 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___183 *, struct request___188 *, unsigned int);
	void (*initialize_rq_fn)(struct request___188 *);
	void (*cleanup_rq)(struct request___188 *);
	bool (*busy)(struct request_queue___188 *);
	int (*map_queues)(struct blk_mq_tag_set___183 *);
	void (*show_rq)(struct seq_file___272 *, struct request___188 *);
};

struct blk_mq_tag_set___183 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___183 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___183 {
	struct request___188 *rq;
	bool last;
};

struct blkcg_policy_data___176;

struct blkcg___176 {
	struct cgroup_subsys_state___224 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___176 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___176 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___176 {
	struct blkcg___176 *blkcg;
	int plid;
};

struct blkg_policy_data___176 {
	struct blkcg_gq___176 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___162 {
	struct mem_cgroup___162 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___162 {
	struct lruvec___170 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___162 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___162 *memcg;
};

struct obj_cgroup___162 {
	struct percpu_ref refcnt;
	struct mem_cgroup___162 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___100 {
	spinlock_t *lock;
	struct sk_buff___107 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

typedef int (*rtnl_doit_func___15)(struct sk_buff___107 *, struct nlmsghdr *, struct netlink_ext_ack *);

typedef int (*rtnl_dumpit_func___15)(struct sk_buff___107 *, struct netlink_callback___106 *);

struct Qdisc_class_ops___100;

struct Qdisc_ops___100 {
	struct Qdisc_ops___100 *next;
	const struct Qdisc_class_ops___100 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___107 *, struct Qdisc___100 *, struct sk_buff___107 **);
	struct sk_buff___107 * (*dequeue)(struct Qdisc___100 *);
	struct sk_buff___107 * (*peek)(struct Qdisc___100 *);
	int (*init)(struct Qdisc___100 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___100 *);
	void (*destroy)(struct Qdisc___100 *);
	int (*change)(struct Qdisc___100 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___100 *);
	int (*change_tx_queue_len)(struct Qdisc___100 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___100 *, unsigned int);
	int (*dump)(struct Qdisc___100 *, struct sk_buff___107 *);
	int (*dump_stats)(struct Qdisc___100 *, struct gnet_dump___100 *);
	void (*ingress_block_set)(struct Qdisc___100 *, u32);
	void (*egress_block_set)(struct Qdisc___100 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___100 *);
	u32 (*egress_block_get)(struct Qdisc___100 *);
	struct module___281 *owner;
};

struct Qdisc_class_ops___100 {
	unsigned int flags;
	struct netdev_queue___106 * (*select_queue)(struct Qdisc___100 *, struct tcmsg *);
	int (*graft)(struct Qdisc___100 *, long unsigned int, struct Qdisc___100 *, struct Qdisc___100 **, struct netlink_ext_ack *);
	struct Qdisc___100 * (*leaf)(struct Qdisc___100 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___100 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___100 *, u32);
	int (*change)(struct Qdisc___100 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___100 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___100 *, struct qdisc_walker *);
	struct tcf_block___100 * (*tcf_block)(struct Qdisc___100 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___100 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___100 *, long unsigned int);
	int (*dump)(struct Qdisc___100 *, long unsigned int, struct sk_buff___107 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___100 *, long unsigned int, struct gnet_dump___100 *);
};

struct tcf_chain___100;

struct tcf_block___100 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___111 *net;
	struct Qdisc___100 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___100 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___100;

struct tcf_proto_ops___100;

struct tcf_proto___100 {
	struct tcf_proto___100 *next;
	void *root;
	int (*classify)(struct sk_buff___107 *, const struct tcf_proto___100 *, struct tcf_result___100 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___100 *ops;
	struct tcf_chain___100 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___100 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___100 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___100 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___107 *, const struct tcf_proto___100 *, struct tcf_result___100 *);
	int (*init)(struct tcf_proto___100 *);
	void (*destroy)(struct tcf_proto___100 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___100 *, u32);
	void (*put)(struct tcf_proto___100 *, void *);
	int (*change)(struct net___111 *, struct sk_buff___107 *, struct tcf_proto___100 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___100 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___100 *);
	void (*walk)(struct tcf_proto___100 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___100 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___100 *, void *);
	void (*hw_del)(struct tcf_proto___100 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___111 *, struct tcf_chain___100 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___111 *, struct tcf_proto___100 *, void *, struct sk_buff___107 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___111 *, struct tcf_proto___100 *, void *, struct sk_buff___107 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___107 *, struct net___111 *, void *);
	struct module___281 *owner;
	int flags;
};

struct tcf_chain___100 {
	struct mutex filter_chain_lock;
	struct tcf_proto___100 *filter_chain;
	struct list_head list;
	struct tcf_block___100 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___100 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___93 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___100 *prog;
};

struct pneigh_entry___93;

struct neigh_hash_table___93;

struct neigh_table___93 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___106 *, __u32 *);
	bool (*key_eq)(const struct neighbour___93 *, const void *);
	int (*constructor)(struct neighbour___93 *);
	int (*pconstructor)(struct pneigh_entry___93 *);
	void (*pdestructor)(struct pneigh_entry___93 *);
	void (*proxy_redo)(struct sk_buff___107 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___106 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___93 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___106 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___93 *nht;
	struct pneigh_entry___93 **phash_buckets;
};

struct neigh_ops___93 {
	int family;
	void (*solicit)(struct neighbour___93 *, struct sk_buff___107 *);
	void (*error_report)(struct neighbour___93 *, struct sk_buff___107 *);
	int (*output)(struct neighbour___93 *, struct sk_buff___107 *);
	int (*connected_output)(struct neighbour___93 *, struct sk_buff___107 *);
};

struct pneigh_entry___93 {
	struct pneigh_entry___93 *next;
	possible_net_t___106 net;
	struct net_device___106 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___93 {
	struct neighbour___93 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___69 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___111 *, struct sock___93 *, struct sk_buff___107 *);
	int (*orig_input)(struct sk_buff___107 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___93 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___93 *ctarget;
	struct net___111 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___93 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___93 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___78;

struct timewait_sock_ops___77;

struct proto___93 {
	void (*close)(struct sock___93 *, long int);
	int (*pre_connect)(struct sock___93 *, struct sockaddr *, int);
	int (*connect)(struct sock___93 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___93 *, int);
	struct sock___93 * (*accept)(struct sock___93 *, int, int *, bool);
	int (*ioctl)(struct sock___93 *, int, long unsigned int);
	int (*init)(struct sock___93 *);
	void (*destroy)(struct sock___93 *);
	void (*shutdown)(struct sock___93 *, int);
	int (*setsockopt)(struct sock___93 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___93 *, int, int, char *, int *);
	void (*keepalive)(struct sock___93 *, int);
	int (*compat_ioctl)(struct sock___93 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___93 *, struct msghdr___95 *, size_t);
	int (*recvmsg)(struct sock___93 *, struct msghdr___95 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___93 *, struct page___302 *, int, size_t, int);
	int (*bind)(struct sock___93 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___93 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___93 *, struct sk_buff___107 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___93 *);
	int (*hash)(struct sock___93 *);
	void (*unhash)(struct sock___93 *);
	void (*rehash)(struct sock___93 *);
	int (*get_port)(struct sock___93 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___93 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___93 *, int);
	bool (*sock_is_readable)(struct sock___93 *);
	void (*enter_memory_pressure)(struct sock___93 *);
	void (*leave_memory_pressure)(struct sock___93 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___78 *rsk_prot;
	struct timewait_sock_ops___77 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___281 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___93 *, int);
};

struct sock_reuseport___40 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___100 *prog;
	struct sock___93 *socks[0];
};

struct request_sock___79;

struct request_sock_ops___78 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___93 *, struct request_sock___79 *);
	void (*send_ack)(const struct sock___93 *, struct sk_buff___107 *, struct request_sock___79 *);
	void (*send_reset)(const struct sock___93 *, struct sk_buff___107 *);
	void (*destructor)(struct request_sock___79 *);
	void (*syn_ack_timeout)(const struct request_sock___79 *);
};

struct timewait_sock_ops___77 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___93 *, struct sock___93 *, void *);
	void (*twsk_destructor)(struct sock___93 *);
};

struct request_sock___79 {
	struct sock_common___93 __req_common;
	struct request_sock___79 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___78 *rsk_ops;
	struct sock___93 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___27 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___93 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___27 {
	struct inet_cork___27 base;
	struct flowi fl;
};

struct ipv6_pinfo___26;

struct inet_sock___27 {
	struct sock___93 sk;
	struct ipv6_pinfo___26 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___27 cork;
};

struct ipv6_fl_socklist___26;

struct ipv6_pinfo___26 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___26 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___107 *pktoptions;
	struct sk_buff___107 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___26;

struct ipv6_fl_socklist___26 {
	struct ipv6_fl_socklist___26 *next;
	struct ip6_flowlabel___26 *fl;
	struct callback_head rcu;
};

struct raw6_sock___2 {
	struct inet_sock___27 inet;
	__u32 checksum;
	__u32 offset;
	struct icmp6_filter filter;
	__u32 ip6mr_table;
	struct ipv6_pinfo___26 inet6;
};

struct inet6_protocol___7 {
	void (*early_demux)(struct sk_buff___107 *);
	void (*early_demux_handler)(struct sk_buff___107 *);
	int (*handler)(struct sk_buff___107 *);
	int (*err_handler)(struct sk_buff___107 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	unsigned int flags;
};

struct ifmcaddr6___75 {
	struct in6_addr mca_addr;
	struct inet6_dev___75 *idev;
	struct ifmcaddr6___75 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___35 {
	struct in6_addr aca_addr;
	struct fib6_info___35 *aca_rt;
	struct ifacaddr6___35 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___26 {
	struct ip6_flowlabel___26 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___274 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___111 *fl_net;
};

struct fib_nh_exception___35 {
	struct fib_nh_exception___35 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___37 *fnhe_rth_input;
	struct rtable___37 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___37 {
	struct dst_entry___93 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___35 {
	struct fib_nh_exception___35 *chain;
};

struct fib_info___25;

struct fib_nh___25 {
	struct fib_nh_common___35 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___25 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___25 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___111 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___25 *nh;
	struct callback_head rcu;
	struct fib_nh___25 fib_nh[0];
};

struct nh_info___25;

struct nh_group___25;

struct nexthop___25 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___111 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___25 *nh_info;
		struct nh_group___25 *nh_grp;
	};
};

struct fib_dump_filter___6 {
	u32 table_id;
	bool filter_set;
	bool dump_routes;
	bool dump_exceptions;
	unsigned char protocol;
	unsigned char rt_type;
	unsigned int flags;
	struct net_device___106 *dev;
};

struct nh_info___25 {
	struct hlist_node dev_hash;
	struct nexthop___25 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___35 fib_nhc;
		struct fib_nh___25 fib_nh;
		struct fib6_nh___35 fib6_nh;
	};
};

struct nh_grp_entry___25;

struct nh_res_bucket___25 {
	struct nh_grp_entry___25 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___25 {
	struct nexthop___25 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___25 *nh_parent;
};

struct nh_res_table___25 {
	struct net___111 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___25 nh_buckets[0];
};

struct nh_group___25 {
	struct nh_group___25 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___25 *res_table;
	struct nh_grp_entry___25 nh_entries[0];
};

typedef short unsigned int mifi_t;

typedef __u32 if_mask;

struct if_set {
	if_mask ifs_bits[8];
};

struct mif6ctl {
	mifi_t mif6c_mifi;
	unsigned char mif6c_flags;
	unsigned char vifc_threshold;
	__u16 mif6c_pifi;
	unsigned int vifc_rate_limit;
};

struct mf6cctl {
	struct sockaddr_in6 mf6cc_origin;
	struct sockaddr_in6 mf6cc_mcastgrp;
	mifi_t mf6cc_parent;
	struct if_set mf6cc_ifset;
};

struct sioc_sg_req6 {
	struct sockaddr_in6 src;
	struct sockaddr_in6 grp;
	long unsigned int pktcnt;
	long unsigned int bytecnt;
	long unsigned int wrong_if;
};

struct sioc_mif_req6 {
	mifi_t mifi;
	long unsigned int icount;
	long unsigned int ocount;
	long unsigned int ibytes;
	long unsigned int obytes;
};

struct mrt6msg {
	__u8 im6_mbz;
	__u8 im6_msgtype;
	__u16 im6_mif;
	__u32 im6_pad;
	struct in6_addr im6_src;
	struct in6_addr im6_dst;
};

enum {
	IP6MRA_CREPORT_UNSPEC = 0,
	IP6MRA_CREPORT_MSGTYPE = 1,
	IP6MRA_CREPORT_MIF_ID = 2,
	IP6MRA_CREPORT_SRC_ADDR = 3,
	IP6MRA_CREPORT_DST_ADDR = 4,
	IP6MRA_CREPORT_PKT = 5,
	__IP6MRA_CREPORT_MAX = 6,
};

struct vif_device___3 {
	struct net_device___106 *dev;
	long unsigned int bytes_in;
	long unsigned int bytes_out;
	long unsigned int pkt_in;
	long unsigned int pkt_out;
	long unsigned int rate_limit;
	unsigned char threshold;
	short unsigned int flags;
	int link;
	struct netdev_phys_item_id dev_parent_id;
	__be32 local;
	__be32 remote;
};

struct vif_entry_notifier_info___3 {
	struct fib_notifier_info info;
	struct net_device___106 *dev;
	short unsigned int vif_index;
	short unsigned int vif_flags;
	u32 tb_id;
};

struct mr_mfc___3 {
	struct rhlist_head mnode;
	short unsigned int mfc_parent;
	int mfc_flags;
	union {
		struct {
			long unsigned int expires;
			struct sk_buff_head___106 unresolved;
		} unres;
		struct {
			long unsigned int last_assert;
			int minvif;
			int maxvif;
			long unsigned int bytes;
			long unsigned int pkt;
			long unsigned int wrong_if;
			long unsigned int lastuse;
			unsigned char ttls[32];
			refcount_t refcount;
		} res;
	} mfc_un;
	struct list_head list;
	struct callback_head rcu;
	void (*free)(struct callback_head *);
};

struct mfc_entry_notifier_info___3 {
	struct fib_notifier_info info;
	struct mr_mfc___3 *mfc;
	u32 tb_id;
};

struct mr_table___3 {
	struct list_head list;
	possible_net_t___106 net;
	struct mr_table_ops ops;
	u32 id;
	struct sock___93 *mroute_sk;
	struct timer_list ipmr_expire_timer;
	struct list_head mfc_unres_queue;
	struct vif_device___3 vif_table[32];
	struct rhltable mfc_hash;
	struct list_head mfc_cache_list;
	int maxvif;
	atomic_t cache_resolve_queue_len;
	bool mroute_do_assert;
	bool mroute_do_pim;
	bool mroute_do_wrvifwhole;
	int mroute_reg_vif_num;
};

struct mr_vif_iter___3 {
	struct seq_net_private___17 p;
	struct mr_table___3 *mrt;
	int ct;
};

struct mr_mfc_iter___3 {
	struct seq_net_private___17 p;
	struct mr_table___3 *mrt;
	struct list_head *cache;
	spinlock_t *lock;
};

struct mfc6_cache_cmp_arg {
	struct in6_addr mf6c_mcastgrp;
	struct in6_addr mf6c_origin;
};

struct mfc6_cache {
	struct mr_mfc___3 _c;
	union {
		struct {
			struct in6_addr mf6c_mcastgrp;
			struct in6_addr mf6c_origin;
		};
		struct mfc6_cache_cmp_arg cmparg;
	};
};

struct nf_hook_state___22 {
	u8 hook;
	u8 pf;
	struct net_device___106 *in;
	struct net_device___106 *out;
	struct sock___93 *sk;
	struct net___111 *net;
	int (*okfn)(struct net___111 *, struct sock___93 *, struct sk_buff___107 *);
};

struct ip6mr_result {
	struct mr_table___3 *mrt;
};

struct compat_sioc_sg_req6 {
	struct sockaddr_in6 src;
	struct sockaddr_in6 grp;
	compat_ulong_t pktcnt;
	compat_ulong_t bytecnt;
	compat_ulong_t wrong_if;
};

struct compat_sioc_mif_req6 {
	mifi_t mifi;
	compat_ulong_t icount;
	compat_ulong_t ocount;
	compat_ulong_t ibytes;
	compat_ulong_t obytes;
};

struct xfrm6_protocol {
	int (*handler)(struct sk_buff___102 *);
	int (*input_handler)(struct sk_buff___102 *, int, __be32, int);
	int (*cb_handler)(struct sk_buff___102 *, int);
	int (*err_handler)(struct sk_buff___102 *, struct inet6_skb_parm *, u8, u8, int, __be32);
	struct xfrm6_protocol *next;
	int priority;
};

struct dentry___298;

struct super_block___298;

struct module___282;

struct file_system_type___298 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___298 * (*mount)(struct file_system_type___298 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___298 *);
	struct module___282 *owner;
	struct file_system_type___298 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___298;

struct kiocb___298;

struct iov_iter___218;

struct poll_table_struct___219;

struct vm_area_struct___303;

struct inode___298;

struct file_lock___298;

struct page___303;

struct pipe_inode_info___139;

struct seq_file___273;

struct file_operations___299 {
	struct module___282 *owner;
	loff_t (*llseek)(struct file___298 *, loff_t, int);
	ssize_t (*read)(struct file___298 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___298 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___298 *, struct iov_iter___218 *);
	ssize_t (*write_iter)(struct kiocb___298 *, struct iov_iter___218 *);
	int (*iopoll)(struct kiocb___298 *, bool);
	int (*iterate)(struct file___298 *, struct dir_context *);
	int (*iterate_shared)(struct file___298 *, struct dir_context *);
	__poll_t (*poll)(struct file___298 *, struct poll_table_struct___219 *);
	long int (*unlocked_ioctl)(struct file___298 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___298 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___298 *, struct vm_area_struct___303 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___298 *, struct file___298 *);
	int (*flush)(struct file___298 *, fl_owner_t);
	int (*release)(struct inode___298 *, struct file___298 *);
	int (*fsync)(struct file___298 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___298 *, int);
	int (*lock)(struct file___298 *, int, struct file_lock___298 *);
	ssize_t (*sendpage)(struct file___298 *, struct page___303 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___298 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___298 *, long unsigned int);
	int (*flock)(struct file___298 *, int, struct file_lock___298 *);
	ssize_t (*splice_write)(struct pipe_inode_info___139 *, struct file___298 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___298 *, loff_t *, struct pipe_inode_info___139 *, size_t, unsigned int);
	int (*setlease)(struct file___298 *, long int, struct file_lock___298 **, void **);
	long int (*fallocate)(struct file___298 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___273 *, struct file___298 *);
	ssize_t (*copy_file_range)(struct file___298 *, loff_t, struct file___298 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___298 *, loff_t, struct file___298 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___298 *, loff_t, loff_t, int);
};

struct vmacache___303 {
	u64 seqnum;
	struct vm_area_struct___303 *vmas[4];
};

struct page_frag___303 {
	struct page___303 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___304;

struct pid___275;

struct nsproxy___284;

struct signal_struct___299;

struct bio_list___189;

struct backing_dev_info___175;

struct io_context___189;

struct css_set___225;

struct mem_cgroup___163;

struct request_queue___189;

struct vm_struct___281;

struct task_struct___305 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___305 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___304 *mm;
	struct mm_struct___304 *active_mm;
	struct vmacache___303 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___305 *real_parent;
	struct task_struct___305 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___305 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___275 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___284 *nsproxy;
	struct signal_struct___299 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___305 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___189 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___175 *backing_dev_info;
	struct io_context___189 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___225 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___139 *splice_pipe;
	struct page_frag___303 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___163 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___163 *active_memcg;
	struct request_queue___189 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___305 *oom_reaper_list;
	struct vm_struct___281 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___286;

struct kobj_type___286;

struct kernfs_node___286;

struct kobject___286 {
	const char *name;
	struct list_head entry;
	struct kobject___286 *parent;
	struct kset___286 *kset;
	struct kobj_type___286 *ktype;
	struct kernfs_node___286 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___283 {
	struct kobject___286 kobj;
	struct module___282 *mod;
	struct kobject___286 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___282 {
	struct module___282 *mod;
	struct latch_tree_node node;
};

struct module_layout___282 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___282 mtn;
};

struct module_attribute___282;

struct kernel_param___282;

struct module___282 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___283 mkobj;
	struct module_attribute___282 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___286 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___282 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___282 core_layout;
	struct module_layout___282 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___298;

struct dentry___298 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___298 *d_parent;
	struct qstr d_name;
	struct inode___298 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___298 *d_op;
	struct super_block___298 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___298;

struct address_space___298 {
	struct inode___298 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___298 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___298;

struct bdi_writeback___175;

struct inode___298 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___298 *i_op;
	struct super_block___298 *i_sb;
	struct address_space___298 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___175 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___299 *i_fop;
		void (*free_inode)(struct inode___298 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___298 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___139 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___298;

struct path___298;

struct dentry_operations___298 {
	int (*d_revalidate)(struct dentry___298 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___298 *, unsigned int);
	int (*d_hash)(const struct dentry___298 *, struct qstr *);
	int (*d_compare)(const struct dentry___298 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___298 *);
	int (*d_init)(struct dentry___298 *);
	void (*d_release)(struct dentry___298 *);
	void (*d_prune)(struct dentry___298 *);
	void (*d_iput)(struct dentry___298 *, struct inode___298 *);
	char * (*d_dname)(struct dentry___298 *, char *, int);
	struct vfsmount___298 * (*d_automount)(struct path___298 *);
	int (*d_manage)(const struct path___298 *, bool);
	struct dentry___298 * (*d_real)(struct dentry___298 *, const struct inode___298 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___298;

struct mem_dqinfo___298 {
	struct quota_format_type___298 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___298;

struct quota_info___298 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___298 *files[3];
	struct mem_dqinfo___298 info[3];
	const struct quota_format_ops___298 *ops[3];
};

struct rcuwait___299 {
	struct task_struct___305 *task;
};

struct percpu_rw_semaphore___299 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___299 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___298 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___299 rw_sem[3];
};

struct shrink_control___163;

struct shrinker___163 {
	long unsigned int (*count_objects)(struct shrinker___163 *, struct shrink_control___163 *);
	long unsigned int (*scan_objects)(struct shrinker___163 *, struct shrink_control___163 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___298;

struct dquot_operations___298;

struct quotactl_ops___298;

struct block_device___192;

struct super_block___298 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___298 *s_type;
	const struct super_operations___298 *s_op;
	const struct dquot_operations___298 *dq_op;
	const struct quotactl_ops___298 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___298 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___192 *s_bdev;
	struct backing_dev_info___175 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___298 s_dquot;
	struct sb_writers___298 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___298 *s_d_op;
	int cleancache_poolid;
	struct shrinker___163 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___298 {
	struct dentry___298 *mnt_root;
	struct super_block___298 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___298 {
	struct vfsmount___298 *mnt;
	struct dentry___298 *dentry;
};

struct pid_namespace___275;

struct upid___275 {
	int nr;
	struct pid_namespace___275 *ns;
};

struct pid_namespace___275 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___305 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___275 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___275 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___275 numbers[1];
};

typedef struct page___303 *pgtable_t___303;

struct page_pool___127;

struct dev_pagemap___293;

struct page___303 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___298 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___127 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___303 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___303 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___304 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___293 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___293;

struct vm_area_struct___303 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___303 *vm_next;
	struct vm_area_struct___303 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___304 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___293 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___298 *vm_file;
	struct file___298 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___299 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___305 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___305 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___275 *pids[4];
	struct pid___275 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___304 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___303;

struct mm_struct___304 {
	struct {
		struct vm_area_struct___303 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___298 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___303 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___305 *owner;
		struct user_namespace___26 *user_ns;
		struct file___298 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___112;

struct cgroup_namespace___225;

struct nsproxy___284 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___275 *pid_ns_for_children;
	struct net___112 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___225 *cgroup_ns;
};

struct bio___189;

struct bio_list___189 {
	struct bio___189 *head;
	struct bio___189 *tail;
};

struct cgroup_subsys_state___225;

struct bdi_writeback___175 {
	struct backing_dev_info___175 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___225 *memcg_css;
	struct cgroup_subsys_state___225 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___279;

struct backing_dev_info___175 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___175 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___279 *dev;
	char dev_name[64];
	struct device___279 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___298 *debug_dir;
};

struct io_cq___189;

struct io_context___189 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___189 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___225;

struct css_set___225 {
	struct cgroup_subsys_state___225 *subsys[14];
	refcount_t refcount;
	struct css_set___225 *dom_cset;
	struct cgroup___225 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___225 *mg_src_cgrp;
	struct cgroup___225 *mg_dst_cgrp;
	struct css_set___225 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___298;

struct pipe_buffer___139;

struct pipe_inode_info___139 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___303 *tmp_page;
	struct fasync_struct___298 *fasync_readers;
	struct fasync_struct___298 *fasync_writers;
	struct pipe_buffer___139 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___225;

struct cgroup_subsys_state___225 {
	struct cgroup___225 *cgroup;
	struct cgroup_subsys___225 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___225 *parent;
};

struct cgroup_file___225 {
	struct kernfs_node___286 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___163;

struct mem_cgroup_per_node___163;

struct mem_cgroup___163 {
	struct cgroup_subsys_state___225 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___225 events_file;
	struct cgroup_file___225 events_local_file;
	struct cgroup_file___225 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___163 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___305 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___163 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___189;

struct blk_integrity___189 {
	const struct blk_integrity_profile___189 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___189 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___189 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___189;

struct elevator_queue___189;

struct blk_mq_ops___184;

struct blk_mq_hw_ctx___184;

struct gendisk___192;

struct blkcg_gq___177;

struct blk_mq_tag_set___184;

struct request_queue___189 {
	struct request___189 *last_merge;
	struct elevator_queue___189 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___184 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___184 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___192 *disk;
	struct kobject___286 kobj;
	struct kobject___286 *mq_kobj;
	struct blk_integrity___189 integrity;
	struct device___279 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___177 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___184 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___189 bio_split;
	struct dentry___298 *debugfs_dir;
	struct dentry___298 *sched_debugfs_dir;
	struct dentry___298 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___281 {
	struct vm_struct___281 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___303 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___163 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___163 *memcg;
};

struct page_pool_params___127 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___279 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___127 {
	u32 count;
	struct page___303 *cache[128];
};

struct page_pool___127 {
	struct page_pool_params___127 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___303 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___127 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___293;

struct dev_pagemap___293 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___293 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___275 {
	rwlock_t lock;
	struct pid___275 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___298 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___298 f_path;
	struct inode___298 *f_inode;
	const struct file_operations___299 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___275 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___298 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___293;

struct vm_operations_struct___293 {
	void (*open)(struct vm_area_struct___303 *);
	void (*close)(struct vm_area_struct___303 *);
	int (*may_split)(struct vm_area_struct___303 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___303 *);
	int (*mprotect)(struct vm_area_struct___303 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___293 *);
	vm_fault_t (*huge_fault)(struct vm_fault___293 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___293 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___303 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___293 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___293 *);
	int (*access)(struct vm_area_struct___303 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___303 *);
	int (*set_policy)(struct vm_area_struct___303 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___303 *, long unsigned int);
	struct page___303 * (*find_special_page)(struct vm_area_struct___303 *, long unsigned int);
};

struct core_thread___303 {
	struct task_struct___305 *task;
	struct core_thread___303 *next;
};

struct core_state___303 {
	atomic_t nr_threads;
	struct core_thread___303 dumper;
	struct completion startup;
};

struct vm_fault___293 {
	const struct {
		struct vm_area_struct___303 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___303 *cow_page;
	struct page___303 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___303 prealloc_pte;
};

struct pglist_data___171;

struct lruvec___171 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___171 *pgdat;
};

struct zone___171 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___171 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___171 {
	struct zone___171 *zone;
	int zone_idx;
};

struct zonelist___171 {
	struct zoneref___171 _zonerefs[321];
};

struct pglist_data___171 {
	struct zone___171 node_zones[5];
	struct zonelist___171 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___305 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___305 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___171 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___225 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___305 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___101;

struct cgroup_bpf___101 {
	struct bpf_prog_array___101 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___101 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___225;

struct cgroup_rstat_cpu___225;

struct cgroup___225 {
	struct cgroup_subsys_state___225 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___286 *kn;
	struct cgroup_file___225 procs_file;
	struct cgroup_file___225 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___225 *subsys[14];
	struct cgroup_root___225 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___225 *dom_cgrp;
	struct cgroup___225 *old_dom_cgrp;
	struct cgroup_rstat_cpu___225 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___225 psi;
	struct cgroup_bpf___101 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___189 {
	struct request_queue___189 *q;
	struct io_context___189 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct kiocb___298 {
	struct file___298 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___298 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___298 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___298 *ia_file;
};

struct dquot___298 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___298 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___298 {
	int qf_fmt_id;
	const struct quota_format_ops___298 *qf_ops;
	struct module___282 *qf_owner;
	struct quota_format_type___298 *qf_next;
};

struct quota_format_ops___298 {
	int (*check_quota_file)(struct super_block___298 *, int);
	int (*read_file_info)(struct super_block___298 *, int);
	int (*write_file_info)(struct super_block___298 *, int);
	int (*free_file_info)(struct super_block___298 *, int);
	int (*read_dqblk)(struct dquot___298 *);
	int (*commit_dqblk)(struct dquot___298 *);
	int (*release_dqblk)(struct dquot___298 *);
	int (*get_next_id)(struct super_block___298 *, struct kqid *);
};

struct dquot_operations___298 {
	int (*write_dquot)(struct dquot___298 *);
	struct dquot___298 * (*alloc_dquot)(struct super_block___298 *, int);
	void (*destroy_dquot)(struct dquot___298 *);
	int (*acquire_dquot)(struct dquot___298 *);
	int (*release_dquot)(struct dquot___298 *);
	int (*mark_dirty)(struct dquot___298 *);
	int (*write_info)(struct super_block___298 *, int);
	qsize_t * (*get_reserved_space)(struct inode___298 *);
	int (*get_projid)(struct inode___298 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___298 *, qsize_t *);
	int (*get_next_id)(struct super_block___298 *, struct kqid *);
};

struct quotactl_ops___298 {
	int (*quota_on)(struct super_block___298 *, int, int, const struct path___298 *);
	int (*quota_off)(struct super_block___298 *, int);
	int (*quota_enable)(struct super_block___298 *, unsigned int);
	int (*quota_disable)(struct super_block___298 *, unsigned int);
	int (*quota_sync)(struct super_block___298 *, int);
	int (*set_info)(struct super_block___298 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___298 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___298 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___298 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___298 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___298 *, unsigned int);
};

struct writeback_control___175;

struct address_space_operations___298 {
	int (*writepage)(struct page___303 *, struct writeback_control___175 *);
	int (*readpage)(struct file___298 *, struct page___303 *);
	int (*writepages)(struct address_space___298 *, struct writeback_control___175 *);
	int (*set_page_dirty)(struct page___303 *);
	int (*readpages)(struct file___298 *, struct address_space___298 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___298 *, struct address_space___298 *, loff_t, unsigned int, unsigned int, struct page___303 **, void **);
	int (*write_end)(struct file___298 *, struct address_space___298 *, loff_t, unsigned int, unsigned int, struct page___303 *, void *);
	sector_t (*bmap)(struct address_space___298 *, sector_t);
	void (*invalidatepage)(struct page___303 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___303 *, gfp_t);
	void (*freepage)(struct page___303 *);
	ssize_t (*direct_IO)(struct kiocb___298 *, struct iov_iter___218 *);
	int (*migratepage)(struct address_space___298 *, struct page___303 *, struct page___303 *, enum migrate_mode);
	bool (*isolate_page)(struct page___303 *, isolate_mode_t);
	void (*putback_page)(struct page___303 *);
	int (*launder_page)(struct page___303 *);
	int (*is_partially_uptodate)(struct page___303 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___303 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___298 *, struct page___303 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___298 *, sector_t *);
	void (*swap_deactivate)(struct file___298 *);
};

struct writeback_control___175 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___175 *wb;
	struct inode___298 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct bio_vec___215;

struct iov_iter___218 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___215 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___139 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___298 {
	struct dentry___298 * (*lookup)(struct inode___298 *, struct dentry___298 *, unsigned int);
	const char * (*get_link)(struct dentry___298 *, struct inode___298 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___298 *, int);
	struct posix_acl * (*get_acl)(struct inode___298 *, int, bool);
	int (*readlink)(struct dentry___298 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___298 *, struct dentry___298 *, umode_t, bool);
	int (*link)(struct dentry___298 *, struct inode___298 *, struct dentry___298 *);
	int (*unlink)(struct inode___298 *, struct dentry___298 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___298 *, struct dentry___298 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___298 *, struct dentry___298 *, umode_t);
	int (*rmdir)(struct inode___298 *, struct dentry___298 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___298 *, struct dentry___298 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___298 *, struct dentry___298 *, struct inode___298 *, struct dentry___298 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___298 *, struct iattr___298 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___298 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___298 *, char *, size_t);
	int (*fiemap)(struct inode___298 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___298 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___298 *, struct dentry___298 *, struct file___298 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___298 *, struct dentry___298 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___298 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___298 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___298 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___298 {
	void (*fl_copy_lock)(struct file_lock___298 *, struct file_lock___298 *);
	void (*fl_release_private)(struct file_lock___298 *);
};

struct lock_manager_operations___298;

struct file_lock___298 {
	struct file_lock___298 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___298 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___298 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___298 *fl_ops;
	const struct lock_manager_operations___298 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___298 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___298 *);
	int (*lm_grant)(struct file_lock___298 *, int);
	bool (*lm_break)(struct file_lock___298 *);
	int (*lm_change)(struct file_lock___298 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___298 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___298 *);
};

struct fasync_struct___298 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___298 *fa_next;
	struct file___298 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___298 {
	struct inode___298 * (*alloc_inode)(struct super_block___298 *);
	void (*destroy_inode)(struct inode___298 *);
	void (*free_inode)(struct inode___298 *);
	void (*dirty_inode)(struct inode___298 *, int);
	int (*write_inode)(struct inode___298 *, struct writeback_control___175 *);
	int (*drop_inode)(struct inode___298 *);
	void (*evict_inode)(struct inode___298 *);
	void (*put_super)(struct super_block___298 *);
	int (*sync_fs)(struct super_block___298 *, int);
	int (*freeze_super)(struct super_block___298 *);
	int (*freeze_fs)(struct super_block___298 *);
	int (*thaw_super)(struct super_block___298 *);
	int (*unfreeze_fs)(struct super_block___298 *);
	int (*statfs)(struct dentry___298 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___298 *, int *, char *);
	void (*umount_begin)(struct super_block___298 *);
	int (*show_options)(struct seq_file___273 *, struct dentry___298 *);
	int (*show_devname)(struct seq_file___273 *, struct dentry___298 *);
	int (*show_path)(struct seq_file___273 *, struct dentry___298 *);
	int (*show_stats)(struct seq_file___273 *, struct dentry___298 *);
	ssize_t (*quota_read)(struct super_block___298 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___298 *, int, const char *, size_t, loff_t);
	struct dquot___298 ** (*get_dquots)(struct inode___298 *);
	long int (*nr_cached_objects)(struct super_block___298 *, struct shrink_control___163 *);
	long int (*free_cached_objects)(struct super_block___298 *, struct shrink_control___163 *);
	struct file___298 * (*real_loop)(struct file___298 *);
};

struct wakeup_source___279;

struct dev_pm_info___279 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___279 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___279 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___279;

struct bus_type___279;

struct device_driver___279;

struct dev_pm_domain___279;

struct fwnode_handle___275;

struct class___279;

struct attribute_group___286;

struct device___279 {
	struct kobject___286 kobj;
	struct device___279 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___279 *type;
	struct bus_type___279 *bus;
	struct device_driver___279 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___279 power;
	struct dev_pm_domain___279 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___275 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___279 *class;
	const struct attribute_group___286 **groups;
	void (*release)(struct device___279 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___192 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___298 *bd_inode;
	struct super_block___298 *bd_super;
	void *bd_claiming;
	struct device___279 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___286 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___192 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___298 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___227)(struct file___298 *, wait_queue_head_t *, struct poll_table_struct___219 *);

struct poll_table_struct___219 {
	poll_queue_proc___227 _qproc;
	__poll_t _key;
};

struct seq_operations___273;

struct seq_file___273 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___273 *op;
	int poll_event;
	const struct file___298 *file;
	void *private;
};

typedef void bio_end_io_t___189(struct bio___189 *);

struct bio_vec___215 {
	struct page___303 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct bio_integrity_payload___189;

struct bio___189 {
	struct bio___189 *bi_next;
	struct block_device___192 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___189 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___177 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___189 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___215 *bi_io_vec;
	struct bio_set___189 *bi_pool;
	struct bio_vec___215 bi_inline_vecs[0];
};

struct dev_pagemap_ops___293 {
	void (*page_free)(struct page___303 *);
	void (*kill)(struct dev_pagemap___293 *);
	void (*cleanup)(struct dev_pagemap___293 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___293 *);
};

struct fwnode_operations___275;

struct fwnode_handle___275 {
	struct fwnode_handle___275 *secondary;
	const struct fwnode_operations___275 *ops;
	struct device___279 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___275;

struct fwnode_endpoint___275;

struct fwnode_operations___275 {
	struct fwnode_handle___275 * (*get)(struct fwnode_handle___275 *);
	void (*put)(struct fwnode_handle___275 *);
	bool (*device_is_available)(const struct fwnode_handle___275 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___275 *, const struct device___279 *);
	bool (*property_present)(const struct fwnode_handle___275 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___275 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___275 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___275 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*get_parent)(const struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*get_next_child_node)(const struct fwnode_handle___275 *, struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*get_named_child_node)(const struct fwnode_handle___275 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___275 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___275 *);
	struct fwnode_handle___275 * (*graph_get_next_endpoint)(const struct fwnode_handle___275 *, struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*graph_get_remote_endpoint)(const struct fwnode_handle___275 *);
	struct fwnode_handle___275 * (*graph_get_port_parent)(struct fwnode_handle___275 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___275 *, struct fwnode_endpoint___275 *);
	int (*add_links)(struct fwnode_handle___275 *);
};

struct fwnode_endpoint___275 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___275 *local_fwnode;
};

struct fwnode_reference_args___275 {
	struct fwnode_handle___275 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___286;

struct kernfs_elem_dir___286 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___286 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___286;

struct kernfs_root___286 {
	struct kernfs_node___286 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___286 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___286 {
	struct kernfs_node___286 *target_kn;
};

struct kernfs_ops___286;

struct kernfs_elem_attr___286 {
	const struct kernfs_ops___286 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___286 *notify_next;
};

struct kernfs_node___286 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___286 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___286 dir;
		struct kernfs_elem_symlink___286 symlink;
		struct kernfs_elem_attr___286 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___286;

struct kernfs_ops___286 {
	int (*open)(struct kernfs_open_file___286 *);
	void (*release)(struct kernfs_open_file___286 *);
	int (*seq_show)(struct seq_file___273 *, void *);
	void * (*seq_start)(struct seq_file___273 *, loff_t *);
	void * (*seq_next)(struct seq_file___273 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___273 *, void *);
	ssize_t (*read)(struct kernfs_open_file___286 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___286 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___286 *, struct poll_table_struct___219 *);
	int (*mmap)(struct kernfs_open_file___286 *, struct vm_area_struct___303 *);
};

struct kernfs_syscall_ops___286 {
	int (*show_options)(struct seq_file___273 *, struct kernfs_root___286 *);
	int (*mkdir)(struct kernfs_node___286 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___286 *);
	int (*rename)(struct kernfs_node___286 *, struct kernfs_node___286 *, const char *);
	int (*show_path)(struct seq_file___273 *, struct kernfs_node___286 *, struct kernfs_root___286 *);
};

struct kernfs_open_file___286 {
	struct kernfs_node___286 *kn;
	struct file___298 *file;
	struct seq_file___273 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___293 *vm_ops;
};

struct sock___94;

struct kobj_ns_type_operations___94 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___94 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___112 *net;
} possible_net_t___107;

struct proto___94;

struct sock_common___94 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___94 *skc_prot;
	possible_net_t___107 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___94 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___108;

struct sk_buff_head___107 {
	struct sk_buff___108 *next;
	struct sk_buff___108 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___94 {
	struct cgroup___225 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___94;

struct socket_wq___95;

struct xfrm_policy___26;

struct dst_entry___94;

struct socket___96;

struct net_device___107;

struct sock_reuseport___41;

struct sock___94 {
	struct sock_common___94 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___107 sk_error_queue;
	struct sk_buff___108 *sk_rx_skb_cache;
	struct sk_buff_head___107 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___108 *head;
		struct sk_buff___108 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___94 *sk_filter;
	union {
		struct socket_wq___95 *sk_wq;
		struct socket_wq___95 *sk_wq_raw;
	};
	struct xfrm_policy___26 *sk_policy[2];
	struct dst_entry___94 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___94 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___108 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___108 *sk_tx_skb_cache;
	struct sk_buff_head___107 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___303 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___94 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___275 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___96 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___94 sk_cgrp_data;
	struct mem_cgroup___163 *sk_memcg;
	void (*sk_state_change)(struct sock___94 *);
	void (*sk_data_ready)(struct sock___94 *);
	void (*sk_write_space)(struct sock___94 *);
	void (*sk_error_report)(struct sock___94 *);
	int (*sk_backlog_rcv)(struct sock___94 *, struct sk_buff___108 *);
	struct sk_buff___108 * (*sk_validate_xmit_skb)(struct sock___94 *, struct net_device___107 *, struct sk_buff___108 *);
	void (*sk_destruct)(struct sock___94 *);
	struct sock_reuseport___41 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___286;

struct attribute_group___286 {
	const char *name;
	umode_t (*is_visible)(struct kobject___286 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___286 *, struct bin_attribute___286 *, int);
	struct attribute **attrs;
	struct bin_attribute___286 **bin_attrs;
};

struct bin_attribute___286 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___298 * (*f_mapping)();
	ssize_t (*read)(struct file___298 *, struct kobject___286 *, struct bin_attribute___286 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___298 *, struct kobject___286 *, struct bin_attribute___286 *, char *, loff_t, size_t);
	int (*mmap)(struct file___298 *, struct kobject___286 *, struct bin_attribute___286 *, struct vm_area_struct___303 *);
};

struct sysfs_ops___286 {
	ssize_t (*show)(struct kobject___286 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___286 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___286;

struct kset___286 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___286 kobj;
	const struct kset_uevent_ops___286 *uevent_ops;
};

struct kobj_type___286 {
	void (*release)(struct kobject___286 *);
	const struct sysfs_ops___286 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___286 **default_groups;
	const struct kobj_ns_type_operations___94 * (*child_ns_type)(struct kobject___286 *);
	const void * (*namespace)(struct kobject___286 *);
	void (*get_ownership)(struct kobject___286 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___286 {
	int (* const filter)(struct kset___286 *, struct kobject___286 *);
	const char * (* const name)(struct kset___286 *, struct kobject___286 *);
	int (* const uevent)(struct kset___286 *, struct kobject___286 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___282 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___282 *);
	int (*get)(char *, const struct kernel_param___282 *);
	void (*free)(void *);
};

struct kparam_array___282;

struct kernel_param___282 {
	const char *name;
	struct module___282 *mod;
	const struct kernel_param_ops___282 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___282 *arr;
	};
};

struct kparam_array___282 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___282 *ops;
	void *elem;
};

struct module_attribute___282 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___282 *, struct module_kobject___283 *, char *);
	ssize_t (*store)(struct module_attribute___282 *, struct module_kobject___283 *, const char *, size_t);
	void (*setup)(struct module___282 *, const char *);
	int (*test)(struct module___282 *);
	void (*free)(struct module___282 *);
};

struct ip_ra_chain___67;

struct fib_rules_ops___94;

struct fqdir___112;

struct tcp_congestion_ops___39;

struct fib_notifier_ops___94;

struct netns_ipv4___112 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___67 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___94 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___94 *fibnl;
	struct sock___94 **icmp_sk;
	struct sock___94 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___94 **tcp_sk;
	struct fqdir___112 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___39 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___94 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___94 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___94 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___94;

struct dst_ops___112 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___112 *);
	struct dst_entry___94 * (*check)(struct dst_entry___94 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___94 *);
	unsigned int (*mtu)(const struct dst_entry___94 *);
	u32 * (*cow_metrics)(struct dst_entry___94 *, long unsigned int);
	void (*destroy)(struct dst_entry___94 *);
	void (*ifdown)(struct dst_entry___94 *, struct net_device___107 *, int);
	struct dst_entry___94 * (*negative_advice)(struct dst_entry___94 *);
	void (*link_failure)(struct sk_buff___108 *);
	void (*update_pmtu)(struct dst_entry___94 *, struct sock___94 *, struct sk_buff___108 *, u32, bool);
	void (*redirect)(struct dst_entry___94 *, struct sock___94 *, struct sk_buff___108 *);
	int (*local_out)(struct net___112 *, struct sock___94 *, struct sk_buff___108 *);
	struct neighbour___94 * (*neigh_lookup)(const struct dst_entry___94 *, struct sk_buff___108 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___94 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct fib6_info___36;

struct rt6_info___36;

struct fib6_table___36;

struct netns_ipv6___112 {
	struct dst_ops___112 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___112 *fqdir;
	struct fib6_info___36 *fib6_null_entry;
	struct rt6_info___36 *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table___36 *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info___36 *ip6_prohibit_entry;
	struct rt6_info___36 *ip6_blk_hole_entry;
	struct fib6_table___36 *fib6_local_tbl;
	struct fib_rules_ops___94 *fib6_rules_ops;
	struct sock___94 **icmp_sk;
	struct sock___94 *ndisc_sk;
	struct sock___94 *tcp_sk;
	struct sock___94 *igmp_sk;
	struct sock___94 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___94 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___94 *notifier_ops;
	struct fib_notifier_ops___94 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___112 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___112 *fqdir;
};

struct netns_sctp___94 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___94 *ctl_sock;
	struct sock___94 *udp4_sock;
	struct sock___94 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct nf_hook_entries___23;

struct netns_nf___23 {
	struct proc_dir_entry *proc_netfilter;
	const struct nf_logger *nf_loggers[13];
	struct ctl_table_header *nf_log_dir_header;
	struct nf_hook_entries___23 *hooks_ipv4[5];
	struct nf_hook_entries___23 *hooks_ipv6[5];
	struct nf_hook_entries___23 *hooks_arp[3];
	struct nf_hook_entries___23 *hooks_bridge[5];
	struct nf_hook_entries___23 *hooks_decnet[7];
	unsigned int defrag_ipv4_users;
	unsigned int defrag_ipv6_users;
};

struct bpf_prog___101;

struct netns_bpf___101 {
	struct bpf_prog_array___101 *run_array[2];
	struct bpf_prog___101 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___112 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___94 *nlsk;
	struct sock___94 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___112 xfrm4_dst_ops;
	struct dst_ops___112 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___112 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___94 *rtnl;
	struct sock___94 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___107 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___112 ipv4;
	struct netns_ipv6___112 ipv6;
	struct netns_ieee802154_lowpan___112 ieee802154_lowpan;
	struct netns_sctp___94 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___107 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___101 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___112 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___94 *crypto_nlsk;
	struct sock___94 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___225 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___225 *root_cset;
};

struct msghdr___96 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___218 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___298 *msg_iocb;
};

struct socket_wq___95 {
	wait_queue_head_t wait;
	struct fasync_struct___298 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___95;

struct socket___96 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___298 *file;
	struct sock___94 *sk;
	const struct proto_ops___95 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___95 wq;
};

typedef int (*sk_read_actor_t___94)(read_descriptor_t *, struct sk_buff___108 *, unsigned int, size_t);

struct proto_ops___95 {
	int family;
	struct module___282 *owner;
	int (*release)(struct socket___96 *);
	int (*bind)(struct socket___96 *, struct sockaddr *, int);
	int (*connect)(struct socket___96 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___96 *, struct socket___96 *);
	int (*accept)(struct socket___96 *, struct socket___96 *, int, bool);
	int (*getname)(struct socket___96 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___298 *, struct socket___96 *, struct poll_table_struct___219 *);
	int (*ioctl)(struct socket___96 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___96 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___96 *, void *, bool, bool);
	int (*listen)(struct socket___96 *, int);
	int (*shutdown)(struct socket___96 *, int);
	int (*setsockopt)(struct socket___96 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___96 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___273 *, struct socket___96 *);
	int (*sendmsg)(struct socket___96 *, struct msghdr___96 *, size_t);
	int (*recvmsg)(struct socket___96 *, struct msghdr___96 *, size_t, int);
	int (*mmap)(struct file___298 *, struct socket___96 *, struct vm_area_struct___303 *);
	ssize_t (*sendpage)(struct socket___96 *, struct page___303 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___96 *, loff_t *, struct pipe_inode_info___139 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___94 *, int);
	int (*peek_len)(struct socket___96 *);
	int (*read_sock)(struct sock___94 *, read_descriptor_t *, sk_read_actor_t___94);
	int (*sendpage_locked)(struct sock___94 *, struct page___303 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___94 *, struct msghdr___96 *, size_t);
	int (*set_rcvlowat)(struct sock___94 *, int);
};

struct sk_buff___108 {
	union {
		struct {
			struct sk_buff___108 *next;
			struct sk_buff___108 *prev;
			union {
				struct net_device___107 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___94 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___108 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___279 {
	int (*prepare)(struct device___279 *);
	void (*complete)(struct device___279 *);
	int (*suspend)(struct device___279 *);
	int (*resume)(struct device___279 *);
	int (*freeze)(struct device___279 *);
	int (*thaw)(struct device___279 *);
	int (*poweroff)(struct device___279 *);
	int (*restore)(struct device___279 *);
	int (*suspend_late)(struct device___279 *);
	int (*resume_early)(struct device___279 *);
	int (*freeze_late)(struct device___279 *);
	int (*thaw_early)(struct device___279 *);
	int (*poweroff_late)(struct device___279 *);
	int (*restore_early)(struct device___279 *);
	int (*suspend_noirq)(struct device___279 *);
	int (*resume_noirq)(struct device___279 *);
	int (*freeze_noirq)(struct device___279 *);
	int (*thaw_noirq)(struct device___279 *);
	int (*poweroff_noirq)(struct device___279 *);
	int (*restore_noirq)(struct device___279 *);
	int (*runtime_suspend)(struct device___279 *);
	int (*runtime_resume)(struct device___279 *);
	int (*runtime_idle)(struct device___279 *);
};

struct wakeup_source___279 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___279 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___279 {
	struct dev_pm_ops___279 ops;
	int (*start)(struct device___279 *);
	void (*detach)(struct device___279 *, bool);
	int (*activate)(struct device___279 *);
	void (*sync)(struct device___279 *);
	void (*dismiss)(struct device___279 *);
};

struct bus_type___279 {
	const char *name;
	const char *dev_name;
	struct device___279 *dev_root;
	const struct attribute_group___286 **bus_groups;
	const struct attribute_group___286 **dev_groups;
	const struct attribute_group___286 **drv_groups;
	int (*match)(struct device___279 *, struct device_driver___279 *);
	int (*uevent)(struct device___279 *, struct kobj_uevent_env *);
	int (*probe)(struct device___279 *);
	void (*sync_state)(struct device___279 *);
	void (*remove)(struct device___279 *);
	void (*shutdown)(struct device___279 *);
	int (*online)(struct device___279 *);
	int (*offline)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	int (*num_vf)(struct device___279 *);
	int (*dma_configure)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___279 {
	const char *name;
	struct bus_type___279 *bus;
	struct module___282 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___279 *);
	void (*sync_state)(struct device___279 *);
	int (*remove)(struct device___279 *);
	void (*shutdown)(struct device___279 *);
	int (*suspend)(struct device___279 *, pm_message_t);
	int (*resume)(struct device___279 *);
	const struct attribute_group___286 **groups;
	const struct attribute_group___286 **dev_groups;
	const struct dev_pm_ops___279 *pm;
	void (*coredump)(struct device___279 *);
	struct driver_private *p;
};

struct device_type___279 {
	const char *name;
	const struct attribute_group___286 **groups;
	int (*uevent)(struct device___279 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___279 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___279 *);
	const struct dev_pm_ops___279 *pm;
};

struct class___279 {
	const char *name;
	struct module___282 *owner;
	const struct attribute_group___286 **class_groups;
	const struct attribute_group___286 **dev_groups;
	struct kobject___286 *dev_kobj;
	int (*dev_uevent)(struct device___279 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___279 *, umode_t *);
	void (*class_release)(struct class___279 *);
	void (*dev_release)(struct device___279 *);
	int (*shutdown_pre)(struct device___279 *);
	const struct kobj_ns_type_operations___94 *ns_type;
	const void * (*namespace)(struct device___279 *);
	void (*get_ownership)(struct device___279 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___279 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___139;

struct pipe_buffer___139 {
	struct page___303 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___139 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___139 {
	int (*confirm)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
	void (*release)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
	bool (*try_steal)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
	bool (*get)(struct pipe_inode_info___139 *, struct pipe_buffer___139 *);
};

typedef rx_handler_result_t rx_handler_func_t___107(struct sk_buff___108 **);

struct bpf_xdp_entity___101 {
	struct bpf_prog___101 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___107;

struct net_device_ops___107;

struct l3mdev_ops___94;

struct ndisc_ops___76;

struct xfrmdev_ops___107;

struct header_ops___107;

struct inet6_dev___76;

struct netdev_rx_queue___107;

struct mini_Qdisc___101;

struct netdev_queue___107;

struct Qdisc___101;

struct netpoll_info___5;

struct rtnl_link_ops___101;

struct dcbnl_rtnl_ops___107;

struct net_device___107 {
	char name[16];
	struct netdev_name_node___107 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___107 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___94 *l3mdev_ops;
	const struct ndisc_ops___76 *ndisc_ops;
	const struct xfrmdev_ops___107 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___107 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___286 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___76 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___107 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___101 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___107 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___101 *miniq_ingress;
	struct netdev_queue___107 *ingress_queue;
	struct nf_hook_entries___23 *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___107 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___101 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___101 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___107 = 0,
		NETREG_REGISTERED___107 = 1,
		NETREG_UNREGISTERING___107 = 2,
		NETREG_UNREGISTERED___107 = 3,
		NETREG_RELEASED___107 = 4,
		NETREG_DUMMY___107 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___107 = 0,
		RTNL_LINK_INITIALIZING___107 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___107 *);
	struct netpoll_info___5 *npinfo;
	possible_net_t___107 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___279 dev;
	const struct attribute_group___286 *sysfs_groups[4];
	const struct attribute_group___286 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___101 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___107 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___101 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___215 skb_frag_t___46;

struct skb_shared_info___39 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___108 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___46 frags[17];
};

struct inet_frags___112;

struct fqdir___112 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___112 *f;
	struct net___112 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___112;

struct inet_frags___112 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___112 *, const void *);
	void (*destructor)(struct inet_frag_queue___112 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___112 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___108 *fragments_tail;
	struct sk_buff___108 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___112 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___67 {
	struct ip_ra_chain___67 *next;
	struct sock___94 *sk;
	union {
		void (*destructor)(struct sock___94 *);
		struct sock___94 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___94;

struct fib_lookup_arg___94;

struct fib_rules_ops___94 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___94 *, struct flowi *, int, struct fib_lookup_arg___94 *);
	bool (*suppress)(struct fib_rule___94 *, int, struct fib_lookup_arg___94 *);
	int (*match)(struct fib_rule___94 *, struct flowi *, int);
	int (*configure)(struct fib_rule___94 *, struct sk_buff___108 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___94 *);
	int (*compare)(struct fib_rule___94 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___94 *, struct sk_buff___108 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___94 *);
	void (*flush_cache)(struct fib_rules_ops___94 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___282 *owner;
	struct net___112 *fro_net;
	struct callback_head rcu;
};

struct tcp_congestion_ops___39 {
	u32 (*ssthresh)(struct sock___94 *);
	void (*cong_avoid)(struct sock___94 *, u32, u32);
	void (*set_state)(struct sock___94 *, u8);
	void (*cwnd_event)(struct sock___94 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___94 *, u32);
	void (*pkts_acked)(struct sock___94 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___94 *);
	void (*cong_control)(struct sock___94 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___94 *);
	u32 (*sndbuf_expand)(struct sock___94 *);
	size_t (*get_info)(struct sock___94 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___282 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___94 *);
	void (*release)(struct sock___94 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___94 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___112 *);
	int (*fib_dump)(struct net___112 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___282 *owner;
	struct callback_head rcu;
};

struct xfrm_state___26;

struct lwtunnel_state___70;

struct dst_entry___94 {
	struct net_device___107 *dev;
	struct dst_ops___112 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state___26 *xfrm;
	int (*input)(struct sk_buff___108 *);
	int (*output)(struct net___112 *, struct sock___94 *, struct sk_buff___108 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___70 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

struct neigh_table___94;

struct neigh_parms___94;

struct neigh_ops___94;

struct neighbour___94 {
	struct neighbour___94 *next;
	struct neigh_table___94 *tbl;
	struct neigh_parms___94 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___107 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___94 *, struct sk_buff___108 *);
	const struct neigh_ops___94 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___107 *dev;
	u8 primary_key[0];
};

struct rtable___38;

struct fnhe_hash_bucket___36;

struct fib_nh_common___36 {
	struct net_device___107 *nhc_dev;
	int nhc_oif;
	unsigned char nhc_scope;
	u8 nhc_family;
	u8 nhc_gw_family;
	unsigned char nhc_flags;
	struct lwtunnel_state___70 *nhc_lwtstate;
	union {
		__be32 ipv4;
		struct in6_addr ipv6;
	} nhc_gw;
	int nhc_weight;
	atomic_t nhc_upper_bound;
	struct rtable___38 **nhc_pcpu_rth_output;
	struct rtable___38 *nhc_rth_input;
	struct fnhe_hash_bucket___36 *nhc_exceptions;
};

struct fib6_nh___36 {
	struct fib_nh_common___36 nh_common;
	long unsigned int last_probe;
	struct rt6_info___36 **rt6i_pcpu;
	struct rt6_exception_bucket *rt6i_exception_bucket;
};

struct fib6_node___36;

struct nexthop___26;

struct fib6_info___36 {
	struct fib6_table___36 *fib6_table;
	struct fib6_info___36 *fib6_next;
	struct fib6_node___36 *fib6_node;
	union {
		struct list_head fib6_siblings;
		struct list_head nh_list;
	};
	unsigned int fib6_nsiblings;
	refcount_t fib6_ref;
	long unsigned int expires;
	struct dst_metrics *fib6_metrics;
	struct rt6key fib6_dst;
	u32 fib6_flags;
	struct rt6key fib6_src;
	struct rt6key fib6_prefsrc;
	u32 fib6_metric;
	u8 fib6_protocol;
	u8 fib6_type;
	u8 offload;
	u8 trap;
	u8 offload_failed;
	u8 should_flush: 1;
	u8 dst_nocount: 1;
	u8 dst_nopolicy: 1;
	u8 fib6_destroying: 1;
	u8 unused: 4;
	long: 60;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct callback_head rcu;
	struct nexthop___26 *nh;
	struct fib6_nh___36 fib6_nh[0];
};

struct rt6_info___36 {
	struct dst_entry___94 dst;
	struct fib6_info___36 *from;
	int sernum;
	struct rt6key rt6i_dst;
	struct rt6key rt6i_src;
	struct in6_addr rt6i_gateway;
	struct inet6_dev___76 *rt6i_idev;
	u32 rt6i_flags;
	struct list_head rt6i_uncached;
	struct uncached_list *rt6i_uncached_list;
	short unsigned int rt6i_nfheader_len;
};

struct fib6_node___36 {
	struct fib6_node___36 *parent;
	struct fib6_node___36 *left;
	struct fib6_node___36 *right;
	struct fib6_node___36 *subtree;
	struct fib6_info___36 *leaf;
	__u16 fn_bit;
	__u16 fn_flags;
	int fn_sernum;
	struct fib6_info___36 *rr_ptr;
	struct callback_head rcu;
};

struct fib6_table___36 {
	struct hlist_node tb6_hlist;
	u32 tb6_id;
	spinlock_t tb6_lock;
	struct fib6_node___36 tb6_root;
	struct inet_peer_base tb6_peers;
	unsigned int flags;
	unsigned int fib_seq;
};

struct nf_hook_state___23;

typedef unsigned int nf_hookfn___28(void *, struct sk_buff___108 *, const struct nf_hook_state___23 *);

struct nf_hook_entry___23 {
	nf_hookfn___28 *hook;
	void *priv;
};

struct nf_hook_entries___23 {
	u16 num_hook_entries;
	struct nf_hook_entry___23 hooks[0];
};

struct bpf_prog_array_item___101 {
	struct bpf_prog___101 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___101 {
	struct callback_head rcu;
	struct bpf_prog_array_item___101 items[0];
};

struct bpf_prog_aux___110;

struct bpf_prog___101 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___110 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct seq_operations___273 {
	void * (*start)(struct seq_file___273 *, loff_t *);
	void (*stop)(struct seq_file___273 *, void *);
	void * (*next)(struct seq_file___273 *, void *, loff_t *);
	int (*show)(struct seq_file___273 *, void *);
};

struct dcbnl_rtnl_ops___107 {
	int (*ieee_getets)(struct net_device___107 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___107 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___107 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___107 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___107 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___107 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___107 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___107 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___107 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___107 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___107 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___107 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___107 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___107 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___107 *);
	u8 (*setstate)(struct net_device___107 *, u8);
	void (*getpermhwaddr)(struct net_device___107 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___107 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___107 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___107 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___107 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___107 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___107 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___107 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___107 *, int, u8 *);
	void (*setpfccfg)(struct net_device___107 *, int, u8);
	void (*getpfccfg)(struct net_device___107 *, int, u8 *);
	u8 (*setall)(struct net_device___107 *);
	u8 (*getcap)(struct net_device___107 *, int, u8 *);
	int (*getnumtcs)(struct net_device___107 *, int, u8 *);
	int (*setnumtcs)(struct net_device___107 *, int, u8);
	u8 (*getpfcstate)(struct net_device___107 *);
	void (*setpfcstate)(struct net_device___107 *, u8);
	void (*getbcncfg)(struct net_device___107 *, int, u32 *);
	void (*setbcncfg)(struct net_device___107 *, int, u32);
	void (*getbcnrp)(struct net_device___107 *, int, u8 *);
	void (*setbcnrp)(struct net_device___107 *, int, u8);
	int (*setapp)(struct net_device___107 *, u8, u16, u8);
	int (*getapp)(struct net_device___107 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___107 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___107 *, int, u8);
	u8 (*getdcbx)(struct net_device___107 *);
	u8 (*setdcbx)(struct net_device___107 *, u8);
	int (*peer_getappinfo)(struct net_device___107 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___107 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___107 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___107 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___107 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___107 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___110;

typedef int (*bpf_iter_init_seq_priv_t___109)(void *, struct bpf_iter_aux_info___110 *);

struct bpf_map___110;

struct bpf_iter_aux_info___110 {
	struct bpf_map___110 *map;
};

struct bpf_iter_seq_info___109 {
	const struct seq_operations___273 *seq_ops;
	bpf_iter_init_seq_priv_t___109 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___109 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___110 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___110 *, struct file___298 *);
	void (*map_free)(struct bpf_map___110 *);
	int (*map_get_next_key)(struct bpf_map___110 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___110 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___110 *, void *);
	int (*map_lookup_batch)(struct bpf_map___110 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___110 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___110 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___110 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___110 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___110 *, void *);
	int (*map_update_elem)(struct bpf_map___110 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___110 *, void *);
	int (*map_push_elem)(struct bpf_map___110 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___110 *, void *);
	int (*map_peek_elem)(struct bpf_map___110 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___110 *, struct file___298 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___110 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___110 *, void *, struct seq_file___273 *);
	int (*map_check_btf)(const struct bpf_map___110 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___110 *, struct bpf_prog_aux___110 *);
	void (*map_poke_untrack)(struct bpf_map___110 *, struct bpf_prog_aux___110 *);
	void (*map_poke_run)(struct bpf_map___110 *, u32, struct bpf_prog___101 *, struct bpf_prog___101 *);
	int (*map_direct_value_addr)(const struct bpf_map___110 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___110 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___110 *, struct vm_area_struct___303 *);
	__poll_t (*map_poll)(struct bpf_map___110 *, struct file___298 *, struct poll_table_struct___219 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___110 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___110 *, const struct bpf_map___110 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___110 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___109 *iter_seq_info;
};

struct bpf_map___110 {
	const struct bpf_map_ops___109 *ops;
	struct bpf_map___110 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___163 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___109;

struct bpf_jit_poke_descriptor___109;

struct bpf_prog_ops___101;

struct btf_mod_pair___109;

struct bpf_prog_offload___107;

struct bpf_prog_aux___110 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___101 *dst_prog;
	struct bpf_trampoline___109 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___101 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___109 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___101 *ops;
	struct bpf_map___110 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___109 *used_btfs;
	struct bpf_prog___101 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___110 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___107 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___107;

struct bpf_map_dev_ops___107 {
	int (*map_get_next_key)(struct bpf_offloaded_map___107 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___107 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___107 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___107 *, void *);
};

struct bpf_offloaded_map___107 {
	struct bpf_map___110 map;
	struct net_device___107 *netdev;
	const struct bpf_map_dev_ops___107 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___101 {
	int (*test_run)(struct bpf_prog___101 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___107 {
	struct bpf_prog___101 *prog;
	struct net_device___107 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___109 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___101 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___282 *mod;
};

struct bpf_jit_poke_descriptor___109 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___110 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___109 {
	struct btf *btf;
	struct module___282 *module;
};

struct cftype___225;

struct cgroup_subsys___225 {
	struct cgroup_subsys_state___225 * (*css_alloc)(struct cgroup_subsys_state___225 *);
	int (*css_online)(struct cgroup_subsys_state___225 *);
	void (*css_offline)(struct cgroup_subsys_state___225 *);
	void (*css_released)(struct cgroup_subsys_state___225 *);
	void (*css_free)(struct cgroup_subsys_state___225 *);
	void (*css_reset)(struct cgroup_subsys_state___225 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___225 *, int);
	int (*css_extra_stat_show)(struct seq_file___273 *, struct cgroup_subsys_state___225 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___305 *, struct css_set___225 *);
	void (*cancel_fork)(struct task_struct___305 *, struct css_set___225 *);
	void (*fork)(struct task_struct___305 *);
	void (*exit)(struct task_struct___305 *);
	void (*release)(struct task_struct___305 *);
	void (*bind)(struct cgroup_subsys_state___225 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___225 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___225 *dfl_cftypes;
	struct cftype___225 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___225 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___225 *updated_children;
	struct cgroup___225 *updated_next;
};

struct cgroup_root___225 {
	struct kernfs_root___286 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___225 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___225 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___225 *ss;
	struct list_head node;
	struct kernfs_ops___286 *kf_ops;
	int (*open)(struct kernfs_open_file___286 *);
	void (*release)(struct kernfs_open_file___286 *);
	u64 (*read_u64)(struct cgroup_subsys_state___225 *, struct cftype___225 *);
	s64 (*read_s64)(struct cgroup_subsys_state___225 *, struct cftype___225 *);
	int (*seq_show)(struct seq_file___273 *, void *);
	void * (*seq_start)(struct seq_file___273 *, loff_t *);
	void * (*seq_next)(struct seq_file___273 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___273 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___225 *, struct cftype___225 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___225 *, struct cftype___225 *, s64);
	ssize_t (*write)(struct kernfs_open_file___286 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___286 *, struct poll_table_struct___219 *);
};

struct xdp_rxq_info___107 {
	struct net_device___107 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___107 {
	struct net_device___107 *dev;
};

struct xdp_buff___107 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___107 *rxq;
	struct xdp_txq_info___107 *txq;
	u32 frame_sz;
};

struct xdp_frame___107 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___107 *dev_rx;
};

struct netlink_callback___107 {
	struct sk_buff___108 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___108 *, struct netlink_callback___107 *);
	int (*done)(struct netlink_callback___107 *);
	void *data;
	struct module___282 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___107 {
	int (*create)(struct sk_buff___108 *, struct net_device___107 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___108 *, unsigned char *);
	int (*cache)(const struct neighbour___94 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___107 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___108 *);
};

struct netdev_queue___107 {
	struct net_device___107 *dev;
	struct Qdisc___101 *qdisc;
	struct Qdisc___101 *qdisc_sleeping;
	struct kobject___286 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___107 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___101 {
	struct sk_buff___108 *head;
	struct sk_buff___108 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___101;

struct Qdisc___101 {
	int (*enqueue)(struct sk_buff___108 *, struct Qdisc___101 *, struct sk_buff___108 **);
	struct sk_buff___108 * (*dequeue)(struct Qdisc___101 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___101 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___107 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___107 gso_skb;
	struct qdisc_skb_head___101 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___101 *next_sched;
	struct sk_buff_head___107 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___107 {
	struct xdp_rxq_info___107 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___286 kobj;
	struct net_device___107 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___107 {
	enum net_device_path_type type;
	const struct net_device___107 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___107 = 0,
				DEV_PATH_BR_VLAN_TAG___107 = 1,
				DEV_PATH_BR_VLAN_UNTAG___107 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___107 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___107 {
	const struct net_device___107 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___107 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___101 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___107 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___107 {
	int (*xdo_dev_state_add)(struct xfrm_state___26 *);
	void (*xdo_dev_state_delete)(struct xfrm_state___26 *);
	void (*xdo_dev_state_free)(struct xfrm_state___26 *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___108 *, struct xfrm_state___26 *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state___26 *);
};

struct xfrm_state_offload___26 {
	struct net_device___107 *dev;
	struct net_device___107 *real_dev;
	long unsigned int offload_handle;
	unsigned int num_exthdrs;
	u8 flags;
};

struct xfrm_type___26;

struct xfrm_type_offload___26;

struct xfrm_state___26 {
	possible_net_t___107 xs_net;
	union {
		struct hlist_node gclist;
		struct hlist_node bydst;
	};
	struct hlist_node bysrc;
	struct hlist_node byspi;
	struct hlist_node byseq;
	refcount_t refcnt;
	spinlock_t lock;
	struct xfrm_id id;
	struct xfrm_selector sel;
	struct xfrm_mark mark;
	u32 if_id;
	u32 tfcpad;
	u32 genid;
	struct xfrm_state_walk km;
	struct {
		u32 reqid;
		u8 mode;
		u8 replay_window;
		u8 aalgo;
		u8 ealgo;
		u8 calgo;
		u8 flags;
		u16 family;
		xfrm_address_t saddr;
		int header_len;
		int trailer_len;
		u32 extra_flags;
		struct xfrm_mark smark;
	} props;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_algo_auth *aalg;
	struct xfrm_algo *ealg;
	struct xfrm_algo *calg;
	struct xfrm_algo_aead *aead;
	const char *geniv;
	__be16 new_mapping_sport;
	u32 new_mapping;
	u32 mapping_maxage;
	struct xfrm_encap_tmpl *encap;
	struct sock___94 *encap_sk;
	xfrm_address_t *coaddr;
	struct xfrm_state___26 *tunnel;
	atomic_t tunnel_users;
	struct xfrm_replay_state replay;
	struct xfrm_replay_state_esn *replay_esn;
	struct xfrm_replay_state preplay;
	struct xfrm_replay_state_esn *preplay_esn;
	enum xfrm_replay_mode repl_mode;
	u32 xflags;
	u32 replay_maxage;
	u32 replay_maxdiff;
	struct timer_list rtimer;
	struct xfrm_stats stats;
	struct xfrm_lifetime_cur curlft;
	struct hrtimer mtimer;
	struct xfrm_state_offload___26 xso;
	long int saved_tmo;
	time64_t lastused;
	struct page_frag___303 xfrag;
	const struct xfrm_type___26 *type;
	struct xfrm_mode inner_mode;
	struct xfrm_mode inner_mode_iaf;
	struct xfrm_mode outer_mode;
	const struct xfrm_type_offload___26 *type_offload;
	struct xfrm_sec_ctx *security;
	void *data;
};

struct netdev_name_node___107 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___107 *dev;
	const char *name;
};

struct net_device_ops___107 {
	int (*ndo_init)(struct net_device___107 *);
	void (*ndo_uninit)(struct net_device___107 *);
	int (*ndo_open)(struct net_device___107 *);
	int (*ndo_stop)(struct net_device___107 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___108 *, struct net_device___107 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___108 *, struct net_device___107 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___107 *, struct sk_buff___108 *, struct net_device___107 *);
	void (*ndo_change_rx_flags)(struct net_device___107 *, int);
	void (*ndo_set_rx_mode)(struct net_device___107 *);
	int (*ndo_set_mac_address)(struct net_device___107 *, void *);
	int (*ndo_validate_addr)(struct net_device___107 *);
	int (*ndo_do_ioctl)(struct net_device___107 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___107 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___107 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___107 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___107 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___107 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___107 *, int);
	int (*ndo_neigh_setup)(struct net_device___107 *, struct neigh_parms___94 *);
	void (*ndo_tx_timeout)(struct net_device___107 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___107 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___107 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___107 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___107 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___107 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___107 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___107 *);
	int (*ndo_netpoll_setup)(struct net_device___107 *, struct netpoll_info___5 *);
	void (*ndo_netpoll_cleanup)(struct net_device___107 *);
	int (*ndo_set_vf_mac)(struct net_device___107 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___107 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___107 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___107 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___107 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___107 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___107 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___107 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___107 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___107 *, int, struct sk_buff___108 *);
	int (*ndo_get_vf_guid)(struct net_device___107 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___107 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___107 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___107 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___107 *);
	int (*ndo_fcoe_disable)(struct net_device___107 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___107 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___107 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___107 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___107 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___107 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___107 *, const struct sk_buff___108 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___107 *, struct net_device___107 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___107 *, struct net_device___107 *);
	struct net_device___107 * (*ndo_get_xmit_slave)(struct net_device___107 *, struct sk_buff___108 *, bool);
	struct net_device___107 * (*ndo_sk_get_lower_dev)(struct net_device___107 *, struct sock___94 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___107 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___107 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___107 *, struct neighbour___94 *);
	void (*ndo_neigh_destroy)(struct net_device___107 *, struct neighbour___94 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___107 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___107 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___108 *, struct netlink_callback___107 *, struct net_device___107 *, struct net_device___107 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___108 *, struct nlattr **, struct net_device___107 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___107 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___108 *, u32, u32, struct net_device___107 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___107 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___107 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___107 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___107 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___107 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___107 *, struct net_device___107 *);
	void (*ndo_dfwd_del_station)(struct net_device___107 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___107 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___107 *);
	int (*ndo_change_proto_down)(struct net_device___107 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___107 *, struct sk_buff___108 *);
	void (*ndo_set_rx_headroom)(struct net_device___107 *, int);
	int (*ndo_bpf)(struct net_device___107 *, struct netdev_bpf___107 *);
	int (*ndo_xdp_xmit)(struct net_device___107 *, int, struct xdp_frame___107 **, u32);
	struct net_device___107 * (*ndo_xdp_get_xmit_slave)(struct net_device___107 *, struct xdp_buff___107 *);
	int (*ndo_xsk_wakeup)(struct net_device___107 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___107 *);
	int (*ndo_tunnel_ctl)(struct net_device___107 *, struct ip_tunnel_parm *, int);
	struct net_device___107 * (*ndo_get_peer_dev)(struct net_device___107 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___107 *, struct net_device_path___107 *);
};

struct neigh_parms___94 {
	possible_net_t___107 net;
	struct net_device___107 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___94 *);
	struct neigh_table___94 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct netpoll___6;

struct netpoll_info___5 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___107 txq;
	struct delayed_work tx_work;
	struct netpoll___6 *netpoll;
	struct callback_head rcu;
};

struct l3mdev_ops___94 {
	u32 (*l3mdev_fib_table)(const struct net_device___107 *);
	struct sk_buff___108 * (*l3mdev_l3_rcv)(struct net_device___107 *, struct sk_buff___108 *, u16);
	struct sk_buff___108 * (*l3mdev_l3_out)(struct net_device___107 *, struct sock___94 *, struct sk_buff___108 *, u16);
	struct dst_entry___94 * (*l3mdev_link_scope_lookup)(const struct net_device___107 *, struct flowi6 *);
};

struct ndisc_ops___76 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___107 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___107 *, struct neighbour___94 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___107 *, u8, struct neighbour___94 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___107 *, struct sk_buff___108 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___112 *, struct net_device___107 *, const struct prefix_info *, struct inet6_dev___76 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___76;

struct ifacaddr6___36;

struct inet6_dev___76 {
	struct net_device___107 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___76 *mc_list;
	struct ifmcaddr6___76 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___107 mc_query_queue;
	struct sk_buff_head___107 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___36 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___94 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___101;

struct tcf_block___101;

struct mini_Qdisc___101 {
	struct tcf_proto___101 *filter_list;
	struct tcf_block___101 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___101 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___107 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___107 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___112 *, struct net_device___107 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___107 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___107 *, struct list_head *);
	size_t (*get_size)(const struct net_device___107 *);
	int (*fill_info)(struct sk_buff___108 *, const struct net_device___107 *);
	size_t (*get_xstats_size)(const struct net_device___107 *);
	int (*fill_xstats)(struct sk_buff___108 *, const struct net_device___107 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___107 *, struct net_device___107 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___107 *, const struct net_device___107 *);
	int (*fill_slave_info)(struct sk_buff___108 *, const struct net_device___107 *, const struct net_device___107 *);
	struct net___112 * (*get_link_net)(const struct net_device___107 *);
	size_t (*get_linkxstats_size)(const struct net_device___107 *, int);
	int (*fill_linkxstats)(struct sk_buff___108 *, const struct net_device___107 *, int *, int);
};

struct block_device_operations___189;

struct gendisk___192 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___192 *part0;
	const struct block_device_operations___189 *fops;
	struct request_queue___189 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___175 *bdi;
	struct kobject___286 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___286 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___189 {
	struct bio___189 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___215 *bip_vec;
	struct bio_vec___215 bip_inline_vecs[0];
};

struct blkcg___177;

struct blkg_policy_data___177;

struct blkcg_gq___177 {
	struct request_queue___189 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___177 *blkcg;
	struct blkcg_gq___177 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___177 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___189 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___189(struct request___189 *);

typedef void integrity_complete_fn___189(struct request___189 *, unsigned int);

struct blk_integrity_profile___189 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___189 *prepare_fn;
	integrity_complete_fn___189 *complete_fn;
	const char *name;
};

struct block_device_operations___189 {
	blk_qc_t (*submit_bio)(struct bio___189 *);
	int (*open)(struct block_device___192 *, fmode_t);
	void (*release)(struct gendisk___192 *, fmode_t);
	int (*rw_page)(struct block_device___192 *, sector_t, struct page___303 *, unsigned int);
	int (*ioctl)(struct block_device___192 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___192 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___192 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___192 *);
	int (*getgeo)(struct block_device___192 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___192 *, bool);
	void (*swap_slot_free_notify)(struct block_device___192 *, long unsigned int);
	int (*report_zones)(struct gendisk___192 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___192 *, umode_t *);
	struct module___282 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___192 *, sector_t *);
};

typedef void rq_end_io_fn___189(struct request___189 *, blk_status_t);

struct request___189 {
	struct request_queue___189 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___184 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___189 *bio;
	struct bio___189 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___215 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___189 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___189 *saved_end_io;
		} flush;
	};
	struct gendisk___192 *rq_disk;
	struct block_device___192 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___189 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___184 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___189 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___286 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___298 *debugfs_dir;
	struct dentry___298 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___189;

struct elevator_mq_ops___189 {
	int (*init_sched)(struct request_queue___189 *, struct elevator_type___189 *);
	void (*exit_sched)(struct elevator_queue___189 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___184 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___184 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___184 *);
	bool (*allow_merge)(struct request_queue___189 *, struct request___189 *, struct bio___189 *);
	bool (*bio_merge)(struct request_queue___189 *, struct bio___189 *, unsigned int);
	int (*request_merge)(struct request_queue___189 *, struct request___189 **, struct bio___189 *);
	void (*request_merged)(struct request_queue___189 *, struct request___189 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___189 *, struct request___189 *, struct request___189 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___189 *);
	void (*finish_request)(struct request___189 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___184 *, struct list_head *, bool);
	struct request___189 * (*dispatch_request)(struct blk_mq_hw_ctx___184 *);
	bool (*has_work)(struct blk_mq_hw_ctx___184 *);
	void (*completed_request)(struct request___189 *, u64);
	void (*requeue_request)(struct request___189 *);
	struct request___189 * (*former_request)(struct request_queue___189 *, struct request___189 *);
	struct request___189 * (*next_request)(struct request_queue___189 *, struct request___189 *);
	void (*init_icq)(struct io_cq___189 *);
	void (*exit_icq)(struct io_cq___189 *);
};

struct elv_fs_entry___189;

struct elevator_type___189 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___189 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___189 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___282 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___189 {
	struct elevator_type___189 *type;
	void *elevator_data;
	struct kobject___286 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___189 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___189 *, char *);
	ssize_t (*store)(struct elevator_queue___189 *, const char *, size_t);
};

struct blk_mq_queue_data___184;

struct blk_mq_ops___184 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___184 *, const struct blk_mq_queue_data___184 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___184 *);
	int (*get_budget)(struct request_queue___189 *);
	void (*put_budget)(struct request_queue___189 *, int);
	void (*set_rq_budget_token)(struct request___189 *, int);
	int (*get_rq_budget_token)(struct request___189 *);
	enum blk_eh_timer_return (*timeout)(struct request___189 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___184 *);
	void (*complete)(struct request___189 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___184 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___184 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___184 *, struct request___189 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___184 *, struct request___189 *, unsigned int);
	void (*initialize_rq_fn)(struct request___189 *);
	void (*cleanup_rq)(struct request___189 *);
	bool (*busy)(struct request_queue___189 *);
	int (*map_queues)(struct blk_mq_tag_set___184 *);
	void (*show_rq)(struct seq_file___273 *, struct request___189 *);
};

struct blk_mq_tag_set___184 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___184 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___184 {
	struct request___189 *rq;
	bool last;
};

struct blkcg_policy_data___177;

struct blkcg___177 {
	struct cgroup_subsys_state___225 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___177 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___177 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___177 {
	struct blkcg___177 *blkcg;
	int plid;
};

struct blkg_policy_data___177 {
	struct blkcg_gq___177 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___163 {
	struct mem_cgroup___163 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___163 {
	struct lruvec___171 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___163 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___163 *memcg;
};

struct obj_cgroup___163 {
	struct percpu_ref refcnt;
	struct mem_cgroup___163 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct netpoll___6 {
	struct net_device___107 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
};

struct gnet_dump___101 {
	spinlock_t *lock;
	struct sk_buff___108 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___101;

struct Qdisc_ops___101 {
	struct Qdisc_ops___101 *next;
	const struct Qdisc_class_ops___101 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___108 *, struct Qdisc___101 *, struct sk_buff___108 **);
	struct sk_buff___108 * (*dequeue)(struct Qdisc___101 *);
	struct sk_buff___108 * (*peek)(struct Qdisc___101 *);
	int (*init)(struct Qdisc___101 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___101 *);
	void (*destroy)(struct Qdisc___101 *);
	int (*change)(struct Qdisc___101 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___101 *);
	int (*change_tx_queue_len)(struct Qdisc___101 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___101 *, unsigned int);
	int (*dump)(struct Qdisc___101 *, struct sk_buff___108 *);
	int (*dump_stats)(struct Qdisc___101 *, struct gnet_dump___101 *);
	void (*ingress_block_set)(struct Qdisc___101 *, u32);
	void (*egress_block_set)(struct Qdisc___101 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___101 *);
	u32 (*egress_block_get)(struct Qdisc___101 *);
	struct module___282 *owner;
};

struct Qdisc_class_ops___101 {
	unsigned int flags;
	struct netdev_queue___107 * (*select_queue)(struct Qdisc___101 *, struct tcmsg *);
	int (*graft)(struct Qdisc___101 *, long unsigned int, struct Qdisc___101 *, struct Qdisc___101 **, struct netlink_ext_ack *);
	struct Qdisc___101 * (*leaf)(struct Qdisc___101 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___101 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___101 *, u32);
	int (*change)(struct Qdisc___101 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___101 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___101 *, struct qdisc_walker *);
	struct tcf_block___101 * (*tcf_block)(struct Qdisc___101 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___101 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___101 *, long unsigned int);
	int (*dump)(struct Qdisc___101 *, long unsigned int, struct sk_buff___108 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___101 *, long unsigned int, struct gnet_dump___101 *);
};

struct tcf_chain___101;

struct tcf_block___101 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___112 *net;
	struct Qdisc___101 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___101 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___101;

struct tcf_proto_ops___101;

struct tcf_proto___101 {
	struct tcf_proto___101 *next;
	void *root;
	int (*classify)(struct sk_buff___108 *, const struct tcf_proto___101 *, struct tcf_result___101 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___101 *ops;
	struct tcf_chain___101 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___101 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___101 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___101 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___108 *, const struct tcf_proto___101 *, struct tcf_result___101 *);
	int (*init)(struct tcf_proto___101 *);
	void (*destroy)(struct tcf_proto___101 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___101 *, u32);
	void (*put)(struct tcf_proto___101 *, void *);
	int (*change)(struct net___112 *, struct sk_buff___108 *, struct tcf_proto___101 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___101 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___101 *);
	void (*walk)(struct tcf_proto___101 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___101 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___101 *, void *);
	void (*hw_del)(struct tcf_proto___101 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___112 *, struct tcf_chain___101 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___112 *, struct tcf_proto___101 *, void *, struct sk_buff___108 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___112 *, struct tcf_proto___101 *, void *, struct sk_buff___108 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___108 *, struct net___112 *, void *);
	struct module___282 *owner;
	int flags;
};

struct tcf_chain___101 {
	struct mutex filter_chain_lock;
	struct tcf_proto___101 *filter_chain;
	struct list_head list;
	struct tcf_block___101 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___101 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___94 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___101 *prog;
};

struct pneigh_entry___94;

struct neigh_hash_table___94;

struct neigh_table___94 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___107 *, __u32 *);
	bool (*key_eq)(const struct neighbour___94 *, const void *);
	int (*constructor)(struct neighbour___94 *);
	int (*pconstructor)(struct pneigh_entry___94 *);
	void (*pdestructor)(struct pneigh_entry___94 *);
	void (*proxy_redo)(struct sk_buff___108 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___107 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___94 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___107 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___94 *nht;
	struct pneigh_entry___94 **phash_buckets;
};

struct neigh_ops___94 {
	int family;
	void (*solicit)(struct neighbour___94 *, struct sk_buff___108 *);
	void (*error_report)(struct neighbour___94 *, struct sk_buff___108 *);
	int (*output)(struct neighbour___94 *, struct sk_buff___108 *);
	int (*connected_output)(struct neighbour___94 *, struct sk_buff___108 *);
};

struct pneigh_entry___94 {
	struct pneigh_entry___94 *next;
	possible_net_t___107 net;
	struct net_device___107 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___94 {
	struct neighbour___94 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___70 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___112 *, struct sock___94 *, struct sk_buff___108 *);
	int (*orig_input)(struct sk_buff___108 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___94 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___94 *ctarget;
	struct net___112 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___94 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___94 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___79;

struct timewait_sock_ops___78;

struct proto___94 {
	void (*close)(struct sock___94 *, long int);
	int (*pre_connect)(struct sock___94 *, struct sockaddr *, int);
	int (*connect)(struct sock___94 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___94 *, int);
	struct sock___94 * (*accept)(struct sock___94 *, int, int *, bool);
	int (*ioctl)(struct sock___94 *, int, long unsigned int);
	int (*init)(struct sock___94 *);
	void (*destroy)(struct sock___94 *);
	void (*shutdown)(struct sock___94 *, int);
	int (*setsockopt)(struct sock___94 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___94 *, int, int, char *, int *);
	void (*keepalive)(struct sock___94 *, int);
	int (*compat_ioctl)(struct sock___94 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___94 *, struct msghdr___96 *, size_t);
	int (*recvmsg)(struct sock___94 *, struct msghdr___96 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___94 *, struct page___303 *, int, size_t, int);
	int (*bind)(struct sock___94 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___94 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___94 *, struct sk_buff___108 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___94 *);
	int (*hash)(struct sock___94 *);
	void (*unhash)(struct sock___94 *);
	void (*rehash)(struct sock___94 *);
	int (*get_port)(struct sock___94 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___94 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___94 *, int);
	bool (*sock_is_readable)(struct sock___94 *);
	void (*enter_memory_pressure)(struct sock___94 *);
	void (*leave_memory_pressure)(struct sock___94 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___79 *rsk_prot;
	struct timewait_sock_ops___78 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___282 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___94 *, int);
};

struct xfrm_policy_queue___26 {
	struct sk_buff_head___107 hold_queue;
	struct timer_list hold_timer;
	long unsigned int timeout;
};

struct xfrm_policy___26 {
	possible_net_t___107 xp_net;
	struct hlist_node bydst;
	struct hlist_node byidx;
	rwlock_t lock;
	refcount_t refcnt;
	u32 pos;
	struct timer_list timer;
	atomic_t genid;
	u32 priority;
	u32 index;
	u32 if_id;
	struct xfrm_mark mark;
	struct xfrm_selector selector;
	struct xfrm_lifetime_cfg lft;
	struct xfrm_lifetime_cur curlft;
	struct xfrm_policy_walk_entry walk;
	struct xfrm_policy_queue___26 polq;
	bool bydst_reinsert;
	u8 type;
	u8 action;
	u8 flags;
	u8 xfrm_nr;
	u16 family;
	struct xfrm_sec_ctx *security;
	struct xfrm_tmpl xfrm_vec[6];
	struct hlist_node bydst_inexact_list;
	struct callback_head rcu;
};

struct sock_reuseport___41 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___101 *prog;
	struct sock___94 *socks[0];
};

struct request_sock___80;

struct request_sock_ops___79 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___94 *, struct request_sock___80 *);
	void (*send_ack)(const struct sock___94 *, struct sk_buff___108 *, struct request_sock___80 *);
	void (*send_reset)(const struct sock___94 *, struct sk_buff___108 *);
	void (*destructor)(struct request_sock___80 *);
	void (*syn_ack_timeout)(const struct request_sock___80 *);
};

struct timewait_sock_ops___78 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___94 *, struct sock___94 *, void *);
	void (*twsk_destructor)(struct sock___94 *);
};

struct request_sock___80 {
	struct sock_common___94 __req_common;
	struct request_sock___80 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___79 *rsk_ops;
	struct sock___94 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_cork___28 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___94 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___28 {
	struct inet_cork___28 base;
	struct flowi fl;
};

struct ipv6_pinfo___27;

struct inet_sock___28 {
	struct sock___94 sk;
	struct ipv6_pinfo___27 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___28 cork;
};

struct ipv6_fl_socklist___27;

struct ipv6_pinfo___27 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___27 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___108 *pktoptions;
	struct sk_buff___108 *rxpmtu;
	struct inet6_cork cork;
};

struct ip6_flowlabel___27;

struct ipv6_fl_socklist___27 {
	struct ipv6_fl_socklist___27 *next;
	struct ip6_flowlabel___27 *fl;
	struct callback_head rcu;
};

struct nf_hook_state___23 {
	u8 hook;
	u8 pf;
	struct net_device___107 *in;
	struct net_device___107 *out;
	struct sock___94 *sk;
	struct net___112 *net;
	int (*okfn)(struct net___112 *, struct sock___94 *, struct sk_buff___108 *);
};

struct ifmcaddr6___76 {
	struct in6_addr mca_addr;
	struct inet6_dev___76 *idev;
	struct ifmcaddr6___76 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ifacaddr6___36 {
	struct in6_addr aca_addr;
	struct fib6_info___36 *aca_rt;
	struct ifacaddr6___36 *aca_next;
	struct hlist_node aca_addr_lst;
	int aca_users;
	refcount_t aca_refcnt;
	long unsigned int aca_cstamp;
	long unsigned int aca_tstamp;
	struct callback_head rcu;
};

struct ip6_fraglist_iter___2 {
	struct ipv6hdr *tmp_hdr;
	struct sk_buff___108 *frag;
	int offset;
	unsigned int hlen;
	__be32 frag_id;
	u8 nexthdr;
};

struct ip6_flowlabel___27 {
	struct ip6_flowlabel___27 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___275 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___112 *fl_net;
};

struct fib_nh_exception___36 {
	struct fib_nh_exception___36 *fnhe_next;
	int fnhe_genid;
	__be32 fnhe_daddr;
	u32 fnhe_pmtu;
	bool fnhe_mtu_locked;
	__be32 fnhe_gw;
	long unsigned int fnhe_expires;
	struct rtable___38 *fnhe_rth_input;
	struct rtable___38 *fnhe_rth_output;
	long unsigned int fnhe_stamp;
	struct callback_head rcu;
};

struct rtable___38 {
	struct dst_entry___94 dst;
	int rt_genid;
	unsigned int rt_flags;
	__u16 rt_type;
	__u8 rt_is_input;
	__u8 rt_uses_gateway;
	int rt_iif;
	u8 rt_gw_family;
	union {
		__be32 rt_gw4;
		struct in6_addr rt_gw6;
	};
	u32 rt_mtu_locked: 1;
	u32 rt_pmtu: 31;
	long: 33;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head rt_uncached;
	struct uncached_list *rt_uncached_list;
};

struct fnhe_hash_bucket___36 {
	struct fib_nh_exception___36 *chain;
};

struct fib_info___26;

struct fib_nh___26 {
	struct fib_nh_common___36 nh_common;
	struct hlist_node nh_hash;
	struct fib_info___26 *nh_parent;
	__u32 nh_tclassid;
	__be32 nh_saddr;
	int nh_saddr_genid;
};

struct fib_info___26 {
	struct hlist_node fib_hash;
	struct hlist_node fib_lhash;
	struct list_head nh_list;
	struct net___112 *fib_net;
	refcount_t fib_treeref;
	refcount_t fib_clntref;
	unsigned int fib_flags;
	unsigned char fib_dead;
	unsigned char fib_protocol;
	unsigned char fib_scope;
	unsigned char fib_type;
	__be32 fib_prefsrc;
	u32 fib_tb_id;
	u32 fib_priority;
	struct dst_metrics *fib_metrics;
	int fib_nhs;
	bool fib_nh_is_v6;
	bool nh_updated;
	struct nexthop___26 *nh;
	struct callback_head rcu;
	struct fib_nh___26 fib_nh[0];
};

struct nh_info___26;

struct nh_group___26;

struct nexthop___26 {
	struct rb_node rb_node;
	struct list_head fi_list;
	struct list_head f6i_list;
	struct list_head fdb_list;
	struct list_head grp_list;
	struct net___112 *net;
	u32 id;
	u8 protocol;
	u8 nh_flags;
	bool is_group;
	refcount_t refcnt;
	struct callback_head rcu;
	union {
		struct nh_info___26 *nh_info;
		struct nh_group___26 *nh_grp;
	};
};

struct nf_queue_entry___3;

struct nf_ipv6_ops___3 {
	void (*route_input)(struct sk_buff___108 *);
	int (*fragment)(struct net___112 *, struct sock___94 *, struct sk_buff___108 *, int (*)(struct net___112 *, struct sock___94 *, struct sk_buff___108 *));
	int (*reroute)(struct sk_buff___108 *, const struct nf_queue_entry___3 *);
};

struct nf_queue_entry___3 {
	struct list_head list;
	struct sk_buff___108 *skb;
	unsigned int id;
	unsigned int hook_index;
	struct net_device___107 *physin;
	struct net_device___107 *physout;
	struct nf_hook_state___23 state;
	u16 size;
};

struct nh_info___26 {
	struct hlist_node dev_hash;
	struct nexthop___26 *nh_parent;
	u8 family;
	bool reject_nh;
	bool fdb_nh;
	union {
		struct fib_nh_common___36 fib_nhc;
		struct fib_nh___26 fib_nh;
		struct fib6_nh___36 fib6_nh;
	};
};

struct nh_grp_entry___26;

struct nh_res_bucket___26 {
	struct nh_grp_entry___26 *nh_entry;
	atomic_long_t used_time;
	long unsigned int migrated_time;
	bool occupied;
	u8 nh_flags;
};

struct nh_grp_entry___26 {
	struct nexthop___26 *nh;
	u8 weight;
	union {
		struct {
			atomic_t upper_bound;
		} hthr;
		struct {
			struct list_head uw_nh_entry;
			u16 count_buckets;
			u16 wants_buckets;
		} res;
	};
	struct list_head nh_list;
	struct nexthop___26 *nh_parent;
};

struct nh_res_table___26 {
	struct net___112 *net;
	u32 nhg_id;
	struct delayed_work upkeep_dw;
	struct list_head uw_nh_entries;
	long unsigned int unbalanced_since;
	u32 idle_timer;
	u32 unbalanced_timer;
	u16 num_nh_buckets;
	struct nh_res_bucket___26 nh_buckets[0];
};

struct nh_group___26 {
	struct nh_group___26 *spare;
	u16 num_nh;
	bool is_multipath;
	bool hash_threshold;
	bool resilient;
	bool fdb_nh;
	bool has_v4;
	struct nh_res_table___26 *res_table;
	struct nh_grp_entry___26 nh_entries[0];
};

struct xfrm_type___26 {
	struct module___282 *owner;
	u8 proto;
	u8 flags;
	int (*init_state)(struct xfrm_state___26 *);
	void (*destructor)(struct xfrm_state___26 *);
	int (*input)(struct xfrm_state___26 *, struct sk_buff___108 *);
	int (*output)(struct xfrm_state___26 *, struct sk_buff___108 *);
	int (*reject)(struct xfrm_state___26 *, struct sk_buff___108 *, const struct flowi *);
};

struct xfrm_type_offload___26 {
	struct module___282 *owner;
	u8 proto;
	void (*encap)(struct xfrm_state___26 *, struct sk_buff___108 *);
	int (*input_tail)(struct xfrm_state___26 *, struct sk_buff___108 *);
	int (*xmit)(struct xfrm_state___26 *, struct sk_buff___108 *, netdev_features_t);
};

struct br_input_skb_cb {
	struct net_device___107 *brdev;
	u16 frag_max_size;
	u8 igmp;
	u8 mrouters_only;
	u8 proxyarp_replied;
	u8 src_port_isolated;
	u8 vlan_filtered;
	u8 br_netfilter_broute;
	u8 tx_fwd_offload;
	long: 24;
	long: 64;
	int src_hwdom;
	long unsigned int fwd_hwdoms;
};

struct nf_bridge_frag_data;

typedef struct rt6_info___36 * (*pol_lookup_t___2)(struct net___112 *, struct fib6_table___36 *, struct flowi6 *, const struct sk_buff___108 *, int);

struct fib6_rule {
	struct fib_rule___94 common;
	struct rt6key src;
	struct rt6key dst;
	u8 tclass;
};

struct calipso_doi;

struct netlbl_calipso_ops {
	int (*doi_add)(struct calipso_doi *, struct netlbl_audit *);
	void (*doi_free)(struct calipso_doi *);
	int (*doi_remove)(u32, struct netlbl_audit *);
	struct calipso_doi * (*doi_getdef)(u32);
	void (*doi_putdef)(struct calipso_doi *);
	int (*doi_walk)(u32 *, int (*)(struct calipso_doi *, void *), void *);
	int (*sock_getattr)(struct sock___94 *, struct netlbl_lsm_secattr *);
	int (*sock_setattr)(struct sock___94 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*sock_delattr)(struct sock___94 *);
	int (*req_setattr)(struct request_sock___80 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*req_delattr)(struct request_sock___80 *);
	int (*opt_getattr)(const unsigned char *, struct netlbl_lsm_secattr *);
	unsigned char * (*skbuff_optptr)(const struct sk_buff___108 *);
	int (*skbuff_setattr)(struct sk_buff___108 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	int (*skbuff_delattr)(struct sk_buff___108 *);
	void (*cache_invalidate)();
	int (*cache_add)(const unsigned char *, const struct netlbl_lsm_secattr *);
};

struct calipso_doi {
	u32 doi;
	u32 type;
	refcount_t refcount;
	struct list_head list;
	struct callback_head rcu;
};

struct calipso_map_cache_bkt {
	spinlock_t lock;
	u32 size;
	struct list_head list;
};

struct calipso_map_cache_entry {
	u32 hash;
	unsigned char *key;
	size_t key_len;
	struct netlbl_lsm_cache *lsm_data;
	u32 activity;
	struct list_head list;
};

enum {
	SEG6_IPTUNNEL_UNSPEC = 0,
	SEG6_IPTUNNEL_SRH = 1,
	__SEG6_IPTUNNEL_MAX = 2,
};

struct seg6_iptunnel_encap {
	int mode;
	struct ipv6_sr_hdr srh[0];
};

enum {
	SEG6_IPTUN_MODE_INLINE = 0,
	SEG6_IPTUN_MODE_ENCAP = 1,
	SEG6_IPTUN_MODE_L2ENCAP = 2,
};

struct seg6_lwt {
	struct dst_cache cache;
	struct seg6_iptunnel_encap tuninfo[0];
};

struct nl_info___12 {
	struct nlmsghdr *nlh;
	struct net___94 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

enum l3mdev_type {
	L3MDEV_TYPE_UNSPEC = 0,
	L3MDEV_TYPE_VRF = 1,
	__L3MDEV_TYPE_MAX = 2,
};

struct fib6_config___11 {
	u32 fc_table;
	u32 fc_metric;
	int fc_dst_len;
	int fc_src_len;
	int fc_ifindex;
	u32 fc_flags;
	u32 fc_protocol;
	u16 fc_type;
	u16 fc_delete_all_nh: 1;
	u16 fc_ignore_dev_down: 1;
	u16 __unused: 14;
	long: 50;
	long: 64;
	long: 64;
	long: 64;
	u32 fc_nh_id;
	struct in6_addr fc_dst;
	struct in6_addr fc_src;
	struct in6_addr fc_prefsrc;
	struct in6_addr fc_gateway;
	long unsigned int fc_expires;
	struct nlattr *fc_mx;
	int fc_mx_len;
	int fc_mp_len;
	struct nlattr *fc_mp;
	struct nl_info___12 fc_nlinfo;
	struct nlattr *fc_encap;
	u16 fc_encap_type;
	bool fc_is_fdb;
};

enum {
	IP6_FH_F_FRAG = 1,
	IP6_FH_F_AUTH = 2,
	IP6_FH_F_SKIP_RH = 4,
};

enum {
	SEG6_LOCAL_UNSPEC = 0,
	SEG6_LOCAL_ACTION = 1,
	SEG6_LOCAL_SRH = 2,
	SEG6_LOCAL_TABLE = 3,
	SEG6_LOCAL_NH4 = 4,
	SEG6_LOCAL_NH6 = 5,
	SEG6_LOCAL_IIF = 6,
	SEG6_LOCAL_OIF = 7,
	SEG6_LOCAL_BPF = 8,
	SEG6_LOCAL_VRFTABLE = 9,
	SEG6_LOCAL_COUNTERS = 10,
	__SEG6_LOCAL_MAX = 11,
};

enum {
	SEG6_LOCAL_BPF_PROG_UNSPEC = 0,
	SEG6_LOCAL_BPF_PROG = 1,
	SEG6_LOCAL_BPF_PROG_NAME = 2,
	__SEG6_LOCAL_BPF_PROG_MAX = 3,
};

enum {
	SEG6_LOCAL_CNT_UNSPEC = 0,
	SEG6_LOCAL_CNT_PAD = 1,
	SEG6_LOCAL_CNT_PACKETS = 2,
	SEG6_LOCAL_CNT_BYTES = 3,
	SEG6_LOCAL_CNT_ERRORS = 4,
	__SEG6_LOCAL_CNT_MAX = 5,
};

struct seg6_local_lwt;

struct seg6_local_lwtunnel_ops {
	int (*build_state)(struct seg6_local_lwt *, const void *, struct netlink_ext_ack *);
	void (*destroy_state)(struct seg6_local_lwt *);
};

struct bpf_lwt_prog___2 {
	struct bpf_prog___83 *prog;
	char *name;
};

enum seg6_end_dt_mode {
	DT_INVALID_MODE = 4294967274,
	DT_LEGACY_MODE = 0,
	DT_VRF_MODE = 1,
};

struct seg6_end_dt_info {
	enum seg6_end_dt_mode mode;
	struct net___94 *net;
	int vrf_ifindex;
	int vrf_table;
	u16 family;
};

struct pcpu_seg6_local_counters;

struct seg6_action_desc;

struct seg6_local_lwt {
	int action;
	struct ipv6_sr_hdr *srh;
	int table;
	struct in_addr nh4;
	struct in6_addr nh6;
	int iif;
	int oif;
	struct bpf_lwt_prog___2 bpf;
	struct seg6_end_dt_info dt_info;
	struct pcpu_seg6_local_counters *pcpu_counters;
	int headroom;
	struct seg6_action_desc *desc;
	long unsigned int parsed_optattrs;
};

struct seg6_action_desc {
	int action;
	long unsigned int attrs;
	long unsigned int optattrs;
	int (*input)(struct sk_buff___90 *, struct seg6_local_lwt *);
	int static_headroom;
	struct seg6_local_lwtunnel_ops slwt_ops;
};

struct pcpu_seg6_local_counters {
	u64_stats_t packets;
	u64_stats_t bytes;
	u64_stats_t errors;
	struct u64_stats_sync syncp;
};

struct seg6_local_counters {
	__u64 packets;
	__u64 bytes;
	__u64 errors;
};

struct seg6_action_param {
	int (*parse)(struct nlattr **, struct seg6_local_lwt *);
	int (*put)(struct sk_buff___90 *, struct seg6_local_lwt *);
	int (*cmp)(struct seg6_local_lwt *, struct seg6_local_lwt *);
	void (*destroy)(struct seg6_local_lwt *);
};

struct crypto_alg___30;

struct crypto_tfm___30 {
	u32 crt_flags;
	int node;
	void (*exit)(struct crypto_tfm___30 *);
	struct crypto_alg___30 *__crt_alg;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	void *__crt_ctx[0];
};

struct cipher_alg___30 {
	unsigned int cia_min_keysize;
	unsigned int cia_max_keysize;
	int (*cia_setkey)(struct crypto_tfm___30 *, const u8 *, unsigned int);
	void (*cia_encrypt)(struct crypto_tfm___30 *, u8 *, const u8 *);
	void (*cia_decrypt)(struct crypto_tfm___30 *, u8 *, const u8 *);
};

struct compress_alg___30 {
	int (*coa_compress)(struct crypto_tfm___30 *, const u8 *, unsigned int, u8 *, unsigned int *);
	int (*coa_decompress)(struct crypto_tfm___30 *, const u8 *, unsigned int, u8 *, unsigned int *);
};

struct crypto_alg___30 {
	struct list_head cra_list;
	struct list_head cra_users;
	u32 cra_flags;
	unsigned int cra_blocksize;
	unsigned int cra_ctxsize;
	unsigned int cra_alignmask;
	int cra_priority;
	refcount_t cra_refcnt;
	char cra_name[128];
	char cra_driver_name[128];
	const struct crypto_type *cra_type;
	union {
		struct cipher_alg___30 cipher;
		struct compress_alg___30 compress;
	} cra_u;
	int (*cra_init)(struct crypto_tfm___30 *);
	void (*cra_exit)(struct crypto_tfm___30 *);
	void (*cra_destroy)(struct crypto_alg___30 *);
	struct module___282 *cra_module;
	union {
		struct crypto_istat_aead aead;
		struct crypto_istat_akcipher akcipher;
		struct crypto_istat_cipher cipher;
		struct crypto_istat_compress compress;
		struct crypto_istat_hash hash;
		struct crypto_istat_rng rng;
		struct crypto_istat_kpp kpp;
	} stats;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct crypto_shash___17;

struct shash_desc___14 {
	struct crypto_shash___17 *tfm;
	void *__ctx[0];
};

struct crypto_shash___17 {
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_tfm___30 base;
};

struct shash_alg___9 {
	int (*init)(struct shash_desc___14 *);
	int (*update)(struct shash_desc___14 *, const u8 *, unsigned int);
	int (*final)(struct shash_desc___14 *, u8 *);
	int (*finup)(struct shash_desc___14 *, const u8 *, unsigned int, u8 *);
	int (*digest)(struct shash_desc___14 *, const u8 *, unsigned int, u8 *);
	int (*export)(struct shash_desc___14 *, void *);
	int (*import)(struct shash_desc___14 *, const void *);
	int (*setkey)(struct crypto_shash___17 *, const u8 *, unsigned int);
	int (*init_tfm)(struct crypto_shash___17 *);
	void (*exit_tfm)(struct crypto_shash___17 *);
	unsigned int descsize;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int digestsize;
	unsigned int statesize;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct crypto_alg___30 base;
};

struct sr6_tlv_hmac {
	struct sr6_tlv tlvhdr;
	__u16 reserved;
	__be32 hmackeyid;
	__u8 hmac[32];
};

enum {
	SEG6_HMAC_ALGO_SHA1 = 1,
	SEG6_HMAC_ALGO_SHA256 = 2,
};

struct seg6_hmac_algo {
	u8 alg_id;
	char name[64];
	struct crypto_shash___17 **tfms;
	struct shash_desc___14 **shashs;
};

enum {
	IOAM6_IPTUNNEL_UNSPEC = 0,
	IOAM6_IPTUNNEL_TRACE = 1,
	__IOAM6_IPTUNNEL_MAX = 2,
};

struct lwtunnel_encap_ops___4 {
	int (*build_state)(struct net___97 *, struct nlattr *, unsigned int, const void *, struct lwtunnel_state___55 **, struct netlink_ext_ack *);
	void (*destroy_state)(struct lwtunnel_state___55 *);
	int (*output)(struct net___97 *, struct sock___79 *, struct sk_buff___93 *);
	int (*input)(struct sk_buff___93 *);
	int (*fill_encap)(struct sk_buff___93 *, struct lwtunnel_state___55 *);
	int (*get_encap_size)(struct lwtunnel_state___55 *);
	int (*cmp_encap)(struct lwtunnel_state___55 *, struct lwtunnel_state___55 *);
	int (*xmit)(struct sk_buff___93 *);
	struct module___267 *owner;
};

struct ioam6_lwt_encap {
	struct ipv6_opt_hdr eh;
	u8 pad[2];
	struct ioam6_hdr ioamh;
	struct ioam6_trace_hdr traceh;
};

struct ioam6_lwt {
	struct ioam6_lwt_encap tuninfo;
};

struct nl_info___13 {
	struct nlmsghdr *nlh;
	struct net___97 *nl_net;
	u32 portid;
	u8 skip_notify: 1;
	u8 skip_notify_kernel: 1;
	long: 63;
	long: 64;
	long: 64;
};

struct fib6_result___9;

struct fib6_nh___37;

struct fib6_config___12;

struct ipv6_stub___9 {
	int (*ipv6_sock_mc_join)(struct sock___79 *, int, const struct in6_addr *);
	int (*ipv6_sock_mc_drop)(struct sock___79 *, int, const struct in6_addr *);
	struct dst_entry___79 * (*ipv6_dst_lookup_flow)(struct net___97 *, const struct sock___79 *, struct flowi6 *, const struct in6_addr *);
	int (*ipv6_route_input)(struct sk_buff___93 *);
	struct fib6_table * (*fib6_get_table)(struct net___97 *, u32);
	int (*fib6_lookup)(struct net___97 *, int, struct flowi6 *, struct fib6_result___9 *, int);
	int (*fib6_table_lookup)(struct net___97 *, struct fib6_table *, int, struct flowi6 *, struct fib6_result___9 *, int);
	void (*fib6_select_path)(const struct net___97 *, struct fib6_result___9 *, struct flowi6 *, int, bool, const struct sk_buff___93 *, int);
	u32 (*ip6_mtu_from_fib6)(const struct fib6_result___9 *, const struct in6_addr *, const struct in6_addr *);
	int (*fib6_nh_init)(struct net___97 *, struct fib6_nh___37 *, struct fib6_config___12 *, gfp_t, struct netlink_ext_ack *);
	void (*fib6_nh_release)(struct fib6_nh___37 *);
	void (*fib6_nh_release_dsts)(struct fib6_nh___37 *);
	void (*fib6_update_sernum)(struct net___97 *, struct fib6_info *);
	int (*ip6_del_rt)(struct net___97 *, struct fib6_info *, bool);
	void (*fib6_rt_update)(struct net___97 *, struct fib6_info *, struct nl_info___13 *);
	void (*udpv6_encap_enable)();
	void (*ndisc_send_na)(struct net_device___92 *, const struct in6_addr *, const struct in6_addr *, bool, bool, bool, bool);
	void (*xfrm6_local_rxpmtu)(struct sk_buff___93 *, u32);
	int (*xfrm6_udp_encap_rcv)(struct sock___79 *, struct sk_buff___93 *);
	int (*xfrm6_rcv_encap)(struct sk_buff___93 *, int, __be32, int);
	struct neigh_table___79 *nd_tbl;
	int (*ipv6_fragment)(struct net___97 *, struct sock___79 *, struct sk_buff___93 *, int (*)(struct net___97 *, struct sock___79 *, struct sk_buff___93 *));
	struct net_device___92 * (*ipv6_dev_find)(struct net___97 *, const struct in6_addr *, struct net_device___92 *);
};

struct nf_conn___5 {
	struct nf_conntrack ct_general;
	spinlock_t lock;
	u32 timeout;
	struct nf_conntrack_zone zone;
	struct nf_conntrack_tuple_hash tuplehash[2];
	long unsigned int status;
	u16 cpu;
	possible_net_t___89 ct_net;
	struct hlist_node nat_bysource;
	struct {	} __nfct_init_offset;
	struct nf_conn___5 *master;
	u_int32_t mark;
	u_int32_t secmark;
	struct nf_ct_ext___2 *ext;
	union nf_conntrack_proto proto;
};

struct skb_shared_info___40 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___93 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___44 frags[17];
};

struct packet_offload___4 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___5 callbacks;
	struct list_head list;
};

struct net_proto_family___5 {
	int family;
	int (*create)(struct net___74 *, struct socket___58 *, int, int);
	struct module___244 *owner;
};

struct sockaddr_pkt {
	short unsigned int spkt_family;
	unsigned char spkt_device[14];
	__be16 spkt_protocol;
};

struct sockaddr_ll {
	short unsigned int sll_family;
	__be16 sll_protocol;
	int sll_ifindex;
	short unsigned int sll_hatype;
	unsigned char sll_pkttype;
	unsigned char sll_halen;
	unsigned char sll_addr[8];
};

struct tpacket_stats {
	unsigned int tp_packets;
	unsigned int tp_drops;
};

struct tpacket_stats_v3 {
	unsigned int tp_packets;
	unsigned int tp_drops;
	unsigned int tp_freeze_q_cnt;
};

struct tpacket_rollover_stats {
	__u64 tp_all;
	__u64 tp_huge;
	__u64 tp_failed;
};

union tpacket_stats_u {
	struct tpacket_stats stats1;
	struct tpacket_stats_v3 stats3;
};

struct tpacket_auxdata {
	__u32 tp_status;
	__u32 tp_len;
	__u32 tp_snaplen;
	__u16 tp_mac;
	__u16 tp_net;
	__u16 tp_vlan_tci;
	__u16 tp_vlan_tpid;
};

struct tpacket_hdr {
	long unsigned int tp_status;
	unsigned int tp_len;
	unsigned int tp_snaplen;
	short unsigned int tp_mac;
	short unsigned int tp_net;
	unsigned int tp_sec;
	unsigned int tp_usec;
};

struct tpacket2_hdr {
	__u32 tp_status;
	__u32 tp_len;
	__u32 tp_snaplen;
	__u16 tp_mac;
	__u16 tp_net;
	__u32 tp_sec;
	__u32 tp_nsec;
	__u16 tp_vlan_tci;
	__u16 tp_vlan_tpid;
	__u8 tp_padding[4];
};

struct tpacket_hdr_variant1 {
	__u32 tp_rxhash;
	__u32 tp_vlan_tci;
	__u16 tp_vlan_tpid;
	__u16 tp_padding;
};

struct tpacket3_hdr {
	__u32 tp_next_offset;
	__u32 tp_sec;
	__u32 tp_nsec;
	__u32 tp_snaplen;
	__u32 tp_len;
	__u32 tp_status;
	__u16 tp_mac;
	__u16 tp_net;
	union {
		struct tpacket_hdr_variant1 hv1;
	};
	__u8 tp_padding[8];
};

struct tpacket_bd_ts {
	unsigned int ts_sec;
	union {
		unsigned int ts_usec;
		unsigned int ts_nsec;
	};
};

struct tpacket_hdr_v1 {
	__u32 block_status;
	__u32 num_pkts;
	__u32 offset_to_first_pkt;
	__u32 blk_len;
	__u64 seq_num;
	struct tpacket_bd_ts ts_first_pkt;
	struct tpacket_bd_ts ts_last_pkt;
};

union tpacket_bd_header_u {
	struct tpacket_hdr_v1 bh1;
};

struct tpacket_block_desc {
	__u32 version;
	__u32 offset_to_priv;
	union tpacket_bd_header_u hdr;
};

enum tpacket_versions {
	TPACKET_V1 = 0,
	TPACKET_V2 = 1,
	TPACKET_V3 = 2,
};

struct tpacket_req {
	unsigned int tp_block_size;
	unsigned int tp_block_nr;
	unsigned int tp_frame_size;
	unsigned int tp_frame_nr;
};

struct tpacket_req3 {
	unsigned int tp_block_size;
	unsigned int tp_block_nr;
	unsigned int tp_frame_size;
	unsigned int tp_frame_nr;
	unsigned int tp_retire_blk_tov;
	unsigned int tp_sizeof_priv;
	unsigned int tp_feature_req_word;
};

union tpacket_req_u {
	struct tpacket_req req;
	struct tpacket_req3 req3;
};

struct fanout_args {
	__u16 id;
	__u16 type_flags;
	__u32 max_num_members;
};

typedef struct bio_vec___177 skb_frag_t___47;

struct skb_shared_info___41 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___70 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___47 frags[17];
};

struct seq_net_private___18 {
	struct net___74 *net;
};

struct pernet_operations___40 {
	struct list_head list;
	int (*init)(struct net___74 *);
	void (*pre_exit)(struct net___74 *);
	void (*exit)(struct net___74 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct packet_type___9 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___69 *dev;
	int (*func)(struct sk_buff___70 *, struct net_device___69 *, struct packet_type___9 *, struct net_device___69 *);
	void (*list_func)(struct list_head *, struct packet_type___9 *, struct net_device___69 *);
	bool (*id_match)(struct packet_type___9 *, struct sock___56 *);
	struct net___74 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

typedef struct poll_table_struct___181 poll_table___55;

struct packet_mclist {
	struct packet_mclist *next;
	int ifindex;
	int count;
	short unsigned int type;
	short unsigned int alen;
	unsigned char addr[32];
};

struct pgv;

struct tpacket_kbdq_core {
	struct pgv *pkbdq;
	unsigned int feature_req_word;
	unsigned int hdrlen;
	unsigned char reset_pending_on_curr_blk;
	unsigned char delete_blk_timer;
	short unsigned int kactive_blk_num;
	short unsigned int blk_sizeof_priv;
	short unsigned int last_kactive_blk_num;
	char *pkblk_start;
	char *pkblk_end;
	int kblk_size;
	unsigned int max_frame_len;
	unsigned int knum_blocks;
	uint64_t knxt_seq_num;
	char *prev;
	char *nxt_offset;
	struct sk_buff___70 *skb;
	rwlock_t blk_fill_in_prog_lock;
	short unsigned int retire_blk_tov;
	short unsigned int version;
	long unsigned int tov_in_jiffies;
	struct timer_list retire_blk_timer;
};

struct pgv {
	char *buffer;
};

struct packet_ring_buffer {
	struct pgv *pg_vec;
	unsigned int head;
	unsigned int frames_per_block;
	unsigned int frame_size;
	unsigned int frame_max;
	unsigned int pg_vec_order;
	unsigned int pg_vec_pages;
	unsigned int pg_vec_len;
	unsigned int *pending_refcnt;
	union {
		long unsigned int *rx_owner_map;
		struct tpacket_kbdq_core prb_bdqc;
	};
};

struct packet_fanout {
	possible_net_t___69 net;
	unsigned int num_members;
	u32 max_num_members;
	u16 id;
	u8 type;
	u8 flags;
	union {
		atomic_t rr_cur;
		struct bpf_prog___63 *bpf_prog;
	};
	struct list_head list;
	spinlock_t lock;
	refcount_t sk_ref;
	long: 64;
	struct packet_type___9 prot_hook;
	struct sock___56 *arr[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct packet_rollover {
	int sock;
	atomic_long_t num;
	atomic_long_t num_huge;
	atomic_long_t num_failed;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 history[16];
};

struct packet_sock {
	struct sock___56 sk;
	struct packet_fanout *fanout;
	union tpacket_stats_u stats;
	struct packet_ring_buffer rx_ring;
	struct packet_ring_buffer tx_ring;
	int copy_thresh;
	spinlock_t bind_lock;
	struct mutex pg_vec_lock;
	unsigned int running;
	unsigned int auxdata: 1;
	unsigned int origdev: 1;
	unsigned int has_vnet_hdr: 1;
	unsigned int tp_loss: 1;
	unsigned int tp_tx_has_off: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int pressure;
	int ifindex;
	__be16 num;
	struct packet_rollover *rollover;
	struct packet_mclist *mclist;
	atomic_t mapped;
	enum tpacket_versions tp_version;
	unsigned int tp_hdrlen;
	unsigned int tp_reserve;
	unsigned int tp_tstamp;
	struct completion skb_completion;
	struct net_device___69 *cached_dev;
	int (*xmit)(struct sk_buff___70 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct packet_type___9 prot_hook;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_t tp_drops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct packet_mreq_max {
	int mr_ifindex;
	short unsigned int mr_type;
	short unsigned int mr_alen;
	unsigned char mr_address[32];
};

union tpacket_uhdr {
	struct tpacket_hdr *h1;
	struct tpacket2_hdr *h2;
	struct tpacket3_hdr *h3;
	void *raw;
};

struct packet_skb_cb {
	union {
		struct sockaddr_pkt pkt;
		union {
			unsigned int origlen;
			struct sockaddr_ll ll;
		};
	} sa;
};

struct strparser___7;

struct strp_callbacks___7 {
	int (*parse_msg)(struct strparser___7 *, struct sk_buff___93 *);
	void (*rcv_msg)(struct strparser___7 *, struct sk_buff___93 *);
	int (*read_sock_done)(struct strparser___7 *, int);
	void (*abort_parser)(struct strparser___7 *, int);
	void (*lock)(struct strparser___7 *);
	void (*unlock)(struct strparser___7 *);
};

struct strparser___7 {
	struct sock___79 *sk;
	u32 stopped;
	u32 paused;
	u32 aborted;
	u32 interrupted;
	u32 unrecov_intr;
	long: 32;
	long: 64;
	struct sk_buff___93 **skb_nextp;
	struct sk_buff___93 *skb_head;
	unsigned int need_bytes;
	struct delayed_work msg_timer_work;
	struct work_struct work;
	struct strp_stats stats;
	struct strp_callbacks___7 cb;
};

struct dentry___299;

struct super_block___299;

struct module___283;

struct file_system_type___299 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___299 * (*mount)(struct file_system_type___299 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___299 *);
	struct module___283 *owner;
	struct file_system_type___299 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___299;

struct kiocb___299;

struct iov_iter___219;

struct vm_area_struct___304;

struct inode___299;

struct file_lock___299;

struct page___304;

struct pipe_inode_info___140;

struct seq_file___274;

struct file_operations___300 {
	struct module___283 *owner;
	loff_t (*llseek)(struct file___299 *, loff_t, int);
	ssize_t (*read)(struct file___299 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___299 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___299 *, struct iov_iter___219 *);
	ssize_t (*write_iter)(struct kiocb___299 *, struct iov_iter___219 *);
	int (*iopoll)(struct kiocb___299 *, bool);
	int (*iterate)(struct file___299 *, struct dir_context *);
	int (*iterate_shared)(struct file___299 *, struct dir_context *);
	__poll_t (*poll)(struct file___299 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___299 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___299 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___299 *, struct vm_area_struct___304 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___299 *, struct file___299 *);
	int (*flush)(struct file___299 *, fl_owner_t);
	int (*release)(struct inode___299 *, struct file___299 *);
	int (*fsync)(struct file___299 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___299 *, int);
	int (*lock)(struct file___299 *, int, struct file_lock___299 *);
	ssize_t (*sendpage)(struct file___299 *, struct page___304 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___299 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___299 *, long unsigned int);
	int (*flock)(struct file___299 *, int, struct file_lock___299 *);
	ssize_t (*splice_write)(struct pipe_inode_info___140 *, struct file___299 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___299 *, loff_t *, struct pipe_inode_info___140 *, size_t, unsigned int);
	int (*setlease)(struct file___299 *, long int, struct file_lock___299 **, void **);
	long int (*fallocate)(struct file___299 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___274 *, struct file___299 *);
	ssize_t (*copy_file_range)(struct file___299 *, loff_t, struct file___299 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___299 *, loff_t, struct file___299 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___299 *, loff_t, loff_t, int);
};

struct vmacache___304 {
	u64 seqnum;
	struct vm_area_struct___304 *vmas[4];
};

struct page_frag___304 {
	struct page___304 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___305;

struct pid___276;

struct nsproxy___285;

struct signal_struct___300;

struct css_set___226;

struct vm_struct___282;

struct task_struct___306 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___306 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___305 *mm;
	struct mm_struct___305 *active_mm;
	struct vmacache___304 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___306 *real_parent;
	struct task_struct___306 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___306 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___276 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___285 *nsproxy;
	struct signal_struct___300 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___306 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___189 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___226 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___140 *splice_pipe;
	struct page_frag___304 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___306 *oom_reaper_list;
	struct vm_struct___282 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___287;

struct kobj_type___287;

struct kernfs_node___287;

struct kobject___287 {
	const char *name;
	struct list_head entry;
	struct kobject___287 *parent;
	struct kset___287 *kset;
	struct kobj_type___287 *ktype;
	struct kernfs_node___287 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___284 {
	struct kobject___287 kobj;
	struct module___283 *mod;
	struct kobject___287 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___283 {
	struct module___283 *mod;
	struct latch_tree_node node;
};

struct module_layout___283 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___283 mtn;
};

struct module_attribute___283;

struct kernel_param___283;

struct module___283 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___284 mkobj;
	struct module_attribute___283 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___287 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___283 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___283 core_layout;
	struct module_layout___283 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dentry_operations___299;

struct dentry___299 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___299 *d_parent;
	struct qstr d_name;
	struct inode___299 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___299 *d_op;
	struct super_block___299 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___299;

struct address_space___299 {
	struct inode___299 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___299 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___299;

struct inode___299 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___299 *i_op;
	struct super_block___299 *i_sb;
	struct address_space___299 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___300 *i_fop;
		void (*free_inode)(struct inode___299 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___299 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___140 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___299;

struct path___299;

struct dentry_operations___299 {
	int (*d_revalidate)(struct dentry___299 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___299 *, unsigned int);
	int (*d_hash)(const struct dentry___299 *, struct qstr *);
	int (*d_compare)(const struct dentry___299 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___299 *);
	int (*d_init)(struct dentry___299 *);
	void (*d_release)(struct dentry___299 *);
	void (*d_prune)(struct dentry___299 *);
	void (*d_iput)(struct dentry___299 *, struct inode___299 *);
	char * (*d_dname)(struct dentry___299 *, char *, int);
	struct vfsmount___299 * (*d_automount)(struct path___299 *);
	int (*d_manage)(const struct path___299 *, bool);
	struct dentry___299 * (*d_real)(struct dentry___299 *, const struct inode___299 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___299;

struct mem_dqinfo___299 {
	struct quota_format_type___299 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___299;

struct quota_info___299 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___299 *files[3];
	struct mem_dqinfo___299 info[3];
	const struct quota_format_ops___299 *ops[3];
};

struct rcuwait___300 {
	struct task_struct___306 *task;
};

struct percpu_rw_semaphore___300 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___300 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___299 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___300 rw_sem[3];
};

struct super_operations___299;

struct dquot_operations___299;

struct quotactl_ops___299;

struct super_block___299 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___299 *s_type;
	const struct super_operations___299 *s_op;
	const struct dquot_operations___299 *dq_op;
	const struct quotactl_ops___299 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___299 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___299 s_dquot;
	struct sb_writers___299 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___299 *s_d_op;
	int cleancache_poolid;
	struct shrinker___163 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___299 {
	struct dentry___299 *mnt_root;
	struct super_block___299 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___299 {
	struct vfsmount___299 *mnt;
	struct dentry___299 *dentry;
};

struct pid_namespace___276;

struct upid___276 {
	int nr;
	struct pid_namespace___276 *ns;
};

struct pid_namespace___276 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___306 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___276 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___276 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___276 numbers[1];
};

typedef struct page___304 *pgtable_t___304;

struct page_pool___128;

struct dev_pagemap___294;

struct page___304 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___299 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___128 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___304 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___304 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___305 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___294 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___294;

struct vm_area_struct___304 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___304 *vm_next;
	struct vm_area_struct___304 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___305 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___294 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___299 *vm_file;
	struct file___299 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___300 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___306 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___306 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___276 *pids[4];
	struct pid___276 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___305 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___304;

struct mm_struct___305 {
	struct {
		struct vm_area_struct___304 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___299 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___304 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___306 *owner;
		struct user_namespace___26 *user_ns;
		struct file___299 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___113;

struct cgroup_namespace___226;

struct nsproxy___285 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___276 *pid_ns_for_children;
	struct net___113 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___226 *cgroup_ns;
};

struct cgroup_subsys_state___226;

struct cgroup___226;

struct css_set___226 {
	struct cgroup_subsys_state___226 *subsys[14];
	refcount_t refcount;
	struct css_set___226 *dom_cset;
	struct cgroup___226 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___226 *mg_src_cgrp;
	struct cgroup___226 *mg_dst_cgrp;
	struct css_set___226 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___299;

struct pipe_buffer___140;

struct pipe_inode_info___140 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___304 *tmp_page;
	struct fasync_struct___299 *fasync_readers;
	struct fasync_struct___299 *fasync_writers;
	struct pipe_buffer___140 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___282 {
	struct vm_struct___282 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___304 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct device___280;

struct page_pool_params___128 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___280 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___128 {
	u32 count;
	struct page___304 *cache[128];
};

struct page_pool___128 {
	struct page_pool_params___128 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___304 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___128 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___294;

struct dev_pagemap___294 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___294 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___276 {
	rwlock_t lock;
	struct pid___276 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___299 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___299 f_path;
	struct inode___299 *f_inode;
	const struct file_operations___300 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___276 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___299 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___294;

struct vm_operations_struct___294 {
	void (*open)(struct vm_area_struct___304 *);
	void (*close)(struct vm_area_struct___304 *);
	int (*may_split)(struct vm_area_struct___304 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___304 *);
	int (*mprotect)(struct vm_area_struct___304 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___294 *);
	vm_fault_t (*huge_fault)(struct vm_fault___294 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___294 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___304 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___294 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___294 *);
	int (*access)(struct vm_area_struct___304 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___304 *);
	int (*set_policy)(struct vm_area_struct___304 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___304 *, long unsigned int);
	struct page___304 * (*find_special_page)(struct vm_area_struct___304 *, long unsigned int);
};

struct core_thread___304 {
	struct task_struct___306 *task;
	struct core_thread___304 *next;
};

struct core_state___304 {
	atomic_t nr_threads;
	struct core_thread___304 dumper;
	struct completion startup;
};

struct vm_fault___294 {
	const struct {
		struct vm_area_struct___304 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___304 *cow_page;
	struct page___304 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___304 prealloc_pte;
};

struct cgroup_subsys___226;

struct cgroup_subsys_state___226 {
	struct cgroup___226 *cgroup;
	struct cgroup_subsys___226 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___226 *parent;
};

struct cgroup_file___226 {
	struct kernfs_node___287 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___226 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___306 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___226;

struct cgroup_rstat_cpu___226;

struct cgroup___226 {
	struct cgroup_subsys_state___226 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___287 *kn;
	struct cgroup_file___226 procs_file;
	struct cgroup_file___226 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___226 *subsys[14];
	struct cgroup_root___226 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___226 *dom_cgrp;
	struct cgroup___226 *old_dom_cgrp;
	struct cgroup_rstat_cpu___226 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___226 psi;
	struct cgroup_bpf___101 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct kiocb___299 {
	struct file___299 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___299 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iattr___299 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___299 *ia_file;
};

struct dquot___299 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___299 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___299 {
	int qf_fmt_id;
	const struct quota_format_ops___299 *qf_ops;
	struct module___283 *qf_owner;
	struct quota_format_type___299 *qf_next;
};

struct quota_format_ops___299 {
	int (*check_quota_file)(struct super_block___299 *, int);
	int (*read_file_info)(struct super_block___299 *, int);
	int (*write_file_info)(struct super_block___299 *, int);
	int (*free_file_info)(struct super_block___299 *, int);
	int (*read_dqblk)(struct dquot___299 *);
	int (*commit_dqblk)(struct dquot___299 *);
	int (*release_dqblk)(struct dquot___299 *);
	int (*get_next_id)(struct super_block___299 *, struct kqid *);
};

struct dquot_operations___299 {
	int (*write_dquot)(struct dquot___299 *);
	struct dquot___299 * (*alloc_dquot)(struct super_block___299 *, int);
	void (*destroy_dquot)(struct dquot___299 *);
	int (*acquire_dquot)(struct dquot___299 *);
	int (*release_dquot)(struct dquot___299 *);
	int (*mark_dirty)(struct dquot___299 *);
	int (*write_info)(struct super_block___299 *, int);
	qsize_t * (*get_reserved_space)(struct inode___299 *);
	int (*get_projid)(struct inode___299 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___299 *, qsize_t *);
	int (*get_next_id)(struct super_block___299 *, struct kqid *);
};

struct quotactl_ops___299 {
	int (*quota_on)(struct super_block___299 *, int, int, const struct path___299 *);
	int (*quota_off)(struct super_block___299 *, int);
	int (*quota_enable)(struct super_block___299 *, unsigned int);
	int (*quota_disable)(struct super_block___299 *, unsigned int);
	int (*quota_sync)(struct super_block___299 *, int);
	int (*set_info)(struct super_block___299 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___299 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___299 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___299 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___299 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___299 *, unsigned int);
};

struct address_space_operations___299 {
	int (*writepage)(struct page___304 *, struct writeback_control___3 *);
	int (*readpage)(struct file___299 *, struct page___304 *);
	int (*writepages)(struct address_space___299 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___304 *);
	int (*readpages)(struct file___299 *, struct address_space___299 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___299 *, struct address_space___299 *, loff_t, unsigned int, unsigned int, struct page___304 **, void **);
	int (*write_end)(struct file___299 *, struct address_space___299 *, loff_t, unsigned int, unsigned int, struct page___304 *, void *);
	sector_t (*bmap)(struct address_space___299 *, sector_t);
	void (*invalidatepage)(struct page___304 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___304 *, gfp_t);
	void (*freepage)(struct page___304 *);
	ssize_t (*direct_IO)(struct kiocb___299 *, struct iov_iter___219 *);
	int (*migratepage)(struct address_space___299 *, struct page___304 *, struct page___304 *, enum migrate_mode);
	bool (*isolate_page)(struct page___304 *, isolate_mode_t);
	void (*putback_page)(struct page___304 *);
	int (*launder_page)(struct page___304 *);
	int (*is_partially_uptodate)(struct page___304 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___304 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___299 *, struct page___304 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___299 *, sector_t *);
	void (*swap_deactivate)(struct file___299 *);
};

struct bio_vec___216;

struct iov_iter___219 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___216 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___140 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct inode_operations___299 {
	struct dentry___299 * (*lookup)(struct inode___299 *, struct dentry___299 *, unsigned int);
	const char * (*get_link)(struct dentry___299 *, struct inode___299 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___299 *, int);
	struct posix_acl * (*get_acl)(struct inode___299 *, int, bool);
	int (*readlink)(struct dentry___299 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___299 *, struct dentry___299 *, umode_t, bool);
	int (*link)(struct dentry___299 *, struct inode___299 *, struct dentry___299 *);
	int (*unlink)(struct inode___299 *, struct dentry___299 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___299 *, struct dentry___299 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___299 *, struct dentry___299 *, umode_t);
	int (*rmdir)(struct inode___299 *, struct dentry___299 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___299 *, struct dentry___299 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___299 *, struct dentry___299 *, struct inode___299 *, struct dentry___299 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___299 *, struct iattr___299 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___299 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___299 *, char *, size_t);
	int (*fiemap)(struct inode___299 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___299 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___299 *, struct dentry___299 *, struct file___299 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___299 *, struct dentry___299 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___299 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___299 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___299 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___299 {
	void (*fl_copy_lock)(struct file_lock___299 *, struct file_lock___299 *);
	void (*fl_release_private)(struct file_lock___299 *);
};

struct lock_manager_operations___299;

struct file_lock___299 {
	struct file_lock___299 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___299 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___299 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___299 *fl_ops;
	const struct lock_manager_operations___299 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___299 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___299 *);
	int (*lm_grant)(struct file_lock___299 *, int);
	bool (*lm_break)(struct file_lock___299 *);
	int (*lm_change)(struct file_lock___299 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___299 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___299 *);
};

struct fasync_struct___299 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___299 *fa_next;
	struct file___299 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___299 {
	struct inode___299 * (*alloc_inode)(struct super_block___299 *);
	void (*destroy_inode)(struct inode___299 *);
	void (*free_inode)(struct inode___299 *);
	void (*dirty_inode)(struct inode___299 *, int);
	int (*write_inode)(struct inode___299 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___299 *);
	void (*evict_inode)(struct inode___299 *);
	void (*put_super)(struct super_block___299 *);
	int (*sync_fs)(struct super_block___299 *, int);
	int (*freeze_super)(struct super_block___299 *);
	int (*freeze_fs)(struct super_block___299 *);
	int (*thaw_super)(struct super_block___299 *);
	int (*unfreeze_fs)(struct super_block___299 *);
	int (*statfs)(struct dentry___299 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___299 *, int *, char *);
	void (*umount_begin)(struct super_block___299 *);
	int (*show_options)(struct seq_file___274 *, struct dentry___299 *);
	int (*show_devname)(struct seq_file___274 *, struct dentry___299 *);
	int (*show_path)(struct seq_file___274 *, struct dentry___299 *);
	int (*show_stats)(struct seq_file___274 *, struct dentry___299 *);
	ssize_t (*quota_read)(struct super_block___299 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___299 *, int, const char *, size_t, loff_t);
	struct dquot___299 ** (*get_dquots)(struct inode___299 *);
	long int (*nr_cached_objects)(struct super_block___299 *, struct shrink_control___163 *);
	long int (*free_cached_objects)(struct super_block___299 *, struct shrink_control___163 *);
	struct file___299 * (*real_loop)(struct file___299 *);
};

struct seq_operations___274;

struct seq_file___274 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___274 *op;
	int poll_event;
	const struct file___299 *file;
	void *private;
};

struct dev_pagemap_ops___294 {
	void (*page_free)(struct page___304 *);
	void (*kill)(struct dev_pagemap___294 *);
	void (*cleanup)(struct dev_pagemap___294 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___294 *);
};

struct fwnode_operations___276;

struct fwnode_handle___276 {
	struct fwnode_handle___276 *secondary;
	const struct fwnode_operations___276 *ops;
	struct device___280 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___276;

struct fwnode_endpoint___276;

struct fwnode_operations___276 {
	struct fwnode_handle___276 * (*get)(struct fwnode_handle___276 *);
	void (*put)(struct fwnode_handle___276 *);
	bool (*device_is_available)(const struct fwnode_handle___276 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___276 *, const struct device___280 *);
	bool (*property_present)(const struct fwnode_handle___276 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___276 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___276 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___276 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*get_parent)(const struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*get_next_child_node)(const struct fwnode_handle___276 *, struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*get_named_child_node)(const struct fwnode_handle___276 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___276 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___276 *);
	struct fwnode_handle___276 * (*graph_get_next_endpoint)(const struct fwnode_handle___276 *, struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*graph_get_remote_endpoint)(const struct fwnode_handle___276 *);
	struct fwnode_handle___276 * (*graph_get_port_parent)(struct fwnode_handle___276 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___276 *, struct fwnode_endpoint___276 *);
	int (*add_links)(struct fwnode_handle___276 *);
};

struct wakeup_source___280;

struct dev_pm_info___280 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___280 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___280 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___280;

struct bus_type___280;

struct device_driver___280;

struct dev_pm_domain___280;

struct class___280;

struct attribute_group___287;

struct device___280 {
	struct kobject___287 kobj;
	struct device___280 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___280 *type;
	struct bus_type___280 *bus;
	struct device_driver___280 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___280 power;
	struct dev_pm_domain___280 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___276 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___280 *class;
	const struct attribute_group___287 **groups;
	void (*release)(struct device___280 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fwnode_endpoint___276 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___276 *local_fwnode;
};

struct fwnode_reference_args___276 {
	struct fwnode_handle___276 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___287;

struct kernfs_elem_dir___287 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___287 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___287;

struct kernfs_root___287 {
	struct kernfs_node___287 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___287 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___287 {
	struct kernfs_node___287 *target_kn;
};

struct kernfs_ops___287;

struct kernfs_elem_attr___287 {
	const struct kernfs_ops___287 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___287 *notify_next;
};

struct kernfs_node___287 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___287 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___287 dir;
		struct kernfs_elem_symlink___287 symlink;
		struct kernfs_elem_attr___287 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___287;

struct kernfs_ops___287 {
	int (*open)(struct kernfs_open_file___287 *);
	void (*release)(struct kernfs_open_file___287 *);
	int (*seq_show)(struct seq_file___274 *, void *);
	void * (*seq_start)(struct seq_file___274 *, loff_t *);
	void * (*seq_next)(struct seq_file___274 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___274 *, void *);
	ssize_t (*read)(struct kernfs_open_file___287 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___287 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___287 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___287 *, struct vm_area_struct___304 *);
};

struct kernfs_syscall_ops___287 {
	int (*show_options)(struct seq_file___274 *, struct kernfs_root___287 *);
	int (*mkdir)(struct kernfs_node___287 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___287 *);
	int (*rename)(struct kernfs_node___287 *, struct kernfs_node___287 *, const char *);
	int (*show_path)(struct seq_file___274 *, struct kernfs_node___287 *, struct kernfs_root___287 *);
};

struct kernfs_open_file___287 {
	struct kernfs_node___287 *kn;
	struct file___299 *file;
	struct seq_file___274 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___294 *vm_ops;
};

struct bin_attribute___287;

struct attribute_group___287 {
	const char *name;
	umode_t (*is_visible)(struct kobject___287 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___287 *, struct bin_attribute___287 *, int);
	struct attribute **attrs;
	struct bin_attribute___287 **bin_attrs;
};

struct bin_attribute___287 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___299 * (*f_mapping)();
	ssize_t (*read)(struct file___299 *, struct kobject___287 *, struct bin_attribute___287 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___299 *, struct kobject___287 *, struct bin_attribute___287 *, char *, loff_t, size_t);
	int (*mmap)(struct file___299 *, struct kobject___287 *, struct bin_attribute___287 *, struct vm_area_struct___304 *);
};

struct sysfs_ops___287 {
	ssize_t (*show)(struct kobject___287 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___287 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___287;

struct kset___287 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___287 kobj;
	const struct kset_uevent_ops___287 *uevent_ops;
};

struct kobj_type___287 {
	void (*release)(struct kobject___287 *);
	const struct sysfs_ops___287 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___287 **default_groups;
	const struct kobj_ns_type_operations___94 * (*child_ns_type)(struct kobject___287 *);
	const void * (*namespace)(struct kobject___287 *);
	void (*get_ownership)(struct kobject___287 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___287 {
	int (* const filter)(struct kset___287 *, struct kobject___287 *);
	const char * (* const name)(struct kset___287 *, struct kobject___287 *);
	int (* const uevent)(struct kset___287 *, struct kobject___287 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___283 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___283 *);
	int (*get)(char *, const struct kernel_param___283 *);
	void (*free)(void *);
};

struct kparam_array___283;

struct kernel_param___283 {
	const char *name;
	struct module___283 *mod;
	const struct kernel_param_ops___283 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___283 *arr;
	};
};

struct kparam_array___283 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___283 *ops;
	void *elem;
};

struct module_attribute___283 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___283 *, struct module_kobject___284 *, char *);
	ssize_t (*store)(struct module_attribute___283 *, struct module_kobject___284 *, const char *, size_t);
	void (*setup)(struct module___283 *, const char *);
	int (*test)(struct module___283 *);
	void (*free)(struct module___283 *);
};

struct fqdir___113;

struct netns_ipv4___113 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___113 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device___108;

struct sk_buff___109;

struct dst_ops___113 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___113 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___108 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___109 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___109 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___109 *);
	int (*local_out)(struct net___113 *, struct sock *, struct sk_buff___109 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___109 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___113 {
	struct dst_ops___113 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___113 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___113 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___113 *fqdir;
};

struct sk_buff_head___108 {
	struct sk_buff___109 *next;
	struct sk_buff___109 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___113 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___113 xfrm4_dst_ops;
	struct dst_ops___113 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___113 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___108 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___113 ipv4;
	struct netns_ipv6___113 ipv6;
	struct netns_ieee802154_lowpan___113 ieee802154_lowpan;
	struct netns_sctp___94 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___108 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___101 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___113 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___226 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___226 *root_cset;
};

struct bio_vec___216 {
	struct page___304 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct sk_buff___109 {
	union {
		struct {
			struct sk_buff___109 *next;
			struct sk_buff___109 *prev;
			union {
				struct net_device___108 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___94 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___109 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct dev_pm_ops___280 {
	int (*prepare)(struct device___280 *);
	void (*complete)(struct device___280 *);
	int (*suspend)(struct device___280 *);
	int (*resume)(struct device___280 *);
	int (*freeze)(struct device___280 *);
	int (*thaw)(struct device___280 *);
	int (*poweroff)(struct device___280 *);
	int (*restore)(struct device___280 *);
	int (*suspend_late)(struct device___280 *);
	int (*resume_early)(struct device___280 *);
	int (*freeze_late)(struct device___280 *);
	int (*thaw_early)(struct device___280 *);
	int (*poweroff_late)(struct device___280 *);
	int (*restore_early)(struct device___280 *);
	int (*suspend_noirq)(struct device___280 *);
	int (*resume_noirq)(struct device___280 *);
	int (*freeze_noirq)(struct device___280 *);
	int (*thaw_noirq)(struct device___280 *);
	int (*poweroff_noirq)(struct device___280 *);
	int (*restore_noirq)(struct device___280 *);
	int (*runtime_suspend)(struct device___280 *);
	int (*runtime_resume)(struct device___280 *);
	int (*runtime_idle)(struct device___280 *);
};

struct wakeup_source___280 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___280 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___280 {
	struct dev_pm_ops___280 ops;
	int (*start)(struct device___280 *);
	void (*detach)(struct device___280 *, bool);
	int (*activate)(struct device___280 *);
	void (*sync)(struct device___280 *);
	void (*dismiss)(struct device___280 *);
};

struct bus_type___280 {
	const char *name;
	const char *dev_name;
	struct device___280 *dev_root;
	const struct attribute_group___287 **bus_groups;
	const struct attribute_group___287 **dev_groups;
	const struct attribute_group___287 **drv_groups;
	int (*match)(struct device___280 *, struct device_driver___280 *);
	int (*uevent)(struct device___280 *, struct kobj_uevent_env *);
	int (*probe)(struct device___280 *);
	void (*sync_state)(struct device___280 *);
	void (*remove)(struct device___280 *);
	void (*shutdown)(struct device___280 *);
	int (*online)(struct device___280 *);
	int (*offline)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	int (*num_vf)(struct device___280 *);
	int (*dma_configure)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___280 {
	const char *name;
	struct bus_type___280 *bus;
	struct module___283 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___280 *);
	void (*sync_state)(struct device___280 *);
	int (*remove)(struct device___280 *);
	void (*shutdown)(struct device___280 *);
	int (*suspend)(struct device___280 *, pm_message_t);
	int (*resume)(struct device___280 *);
	const struct attribute_group___287 **groups;
	const struct attribute_group___287 **dev_groups;
	const struct dev_pm_ops___280 *pm;
	void (*coredump)(struct device___280 *);
	struct driver_private *p;
};

struct device_type___280 {
	const char *name;
	const struct attribute_group___287 **groups;
	int (*uevent)(struct device___280 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___280 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___280 *);
	const struct dev_pm_ops___280 *pm;
};

struct class___280 {
	const char *name;
	struct module___283 *owner;
	const struct attribute_group___287 **class_groups;
	const struct attribute_group___287 **dev_groups;
	struct kobject___287 *dev_kobj;
	int (*dev_uevent)(struct device___280 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___280 *, umode_t *);
	void (*class_release)(struct class___280 *);
	void (*dev_release)(struct device___280 *);
	int (*shutdown_pre)(struct device___280 *);
	const struct kobj_ns_type_operations___94 *ns_type;
	const void * (*namespace)(struct device___280 *);
	void (*get_ownership)(struct device___280 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___280 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___140;

struct pipe_buffer___140 {
	struct page___304 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___140 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___140 {
	int (*confirm)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
	void (*release)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
	bool (*try_steal)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
	bool (*get)(struct pipe_inode_info___140 *, struct pipe_buffer___140 *);
};

typedef rx_handler_result_t rx_handler_func_t___108(struct sk_buff___109 **);

typedef struct {
	struct net___113 *net;
} possible_net_t___108;

struct netdev_name_node___108;

struct net_device_ops___108;

struct xfrmdev_ops___108;

struct header_ops___108;

struct vlan_info___2;

struct netdev_rx_queue___108;

struct netdev_queue___108;

struct netpoll_info___6;

struct dcbnl_rtnl_ops___108;

struct net_device___108 {
	char name[16];
	struct netdev_name_node___108 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___108 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___108 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___108 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___287 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info___2 *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___108 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___108 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___108 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___108 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___108 = 0,
		NETREG_REGISTERED___108 = 1,
		NETREG_UNREGISTERING___108 = 2,
		NETREG_UNREGISTERED___108 = 3,
		NETREG_RELEASED___108 = 4,
		NETREG_DUMMY___108 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___108 = 0,
		RTNL_LINK_INITIALIZING___108 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___108 *);
	struct netpoll_info___6 *npinfo;
	possible_net_t___108 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___280 dev;
	const struct attribute_group___287 *sysfs_groups[4];
	const struct attribute_group___287 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___108 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___101 xdp_state[3];
	long: 64;
};

typedef struct bio_vec___216 skb_frag_t___48;

struct skb_shared_info___42 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___109 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___48 frags[17];
};

struct inet_frags___113;

struct fqdir___113 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___113 *f;
	struct net___113 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___113;

struct inet_frags___113 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___113 *, const void *);
	void (*destructor)(struct inet_frag_queue___113 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___113 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___109 *fragments_tail;
	struct sk_buff___109 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___113 *fqdir;
	struct callback_head rcu;
};

struct seq_operations___274 {
	void * (*start)(struct seq_file___274 *, loff_t *);
	void (*stop)(struct seq_file___274 *, void *);
	void * (*next)(struct seq_file___274 *, void *, loff_t *);
	int (*show)(struct seq_file___274 *, void *);
};

struct dcbnl_rtnl_ops___108 {
	int (*ieee_getets)(struct net_device___108 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___108 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___108 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___108 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___108 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___108 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___108 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___108 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___108 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___108 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___108 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___108 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___108 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___108 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___108 *);
	u8 (*setstate)(struct net_device___108 *, u8);
	void (*getpermhwaddr)(struct net_device___108 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___108 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___108 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___108 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___108 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___108 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___108 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___108 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___108 *, int, u8 *);
	void (*setpfccfg)(struct net_device___108 *, int, u8);
	void (*getpfccfg)(struct net_device___108 *, int, u8 *);
	u8 (*setall)(struct net_device___108 *);
	u8 (*getcap)(struct net_device___108 *, int, u8 *);
	int (*getnumtcs)(struct net_device___108 *, int, u8 *);
	int (*setnumtcs)(struct net_device___108 *, int, u8);
	u8 (*getpfcstate)(struct net_device___108 *);
	void (*setpfcstate)(struct net_device___108 *, u8);
	void (*getbcncfg)(struct net_device___108 *, int, u32 *);
	void (*setbcncfg)(struct net_device___108 *, int, u32);
	void (*getbcnrp)(struct net_device___108 *, int, u8 *);
	void (*setbcnrp)(struct net_device___108 *, int, u8);
	int (*setapp)(struct net_device___108 *, u8, u16, u8);
	int (*getapp)(struct net_device___108 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___108 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___108 *, int, u8);
	u8 (*getdcbx)(struct net_device___108 *);
	u8 (*setdcbx)(struct net_device___108 *, u8);
	int (*peer_getappinfo)(struct net_device___108 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___108 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___108 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___108 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___108 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___108 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___111;

typedef int (*bpf_iter_init_seq_priv_t___110)(void *, struct bpf_iter_aux_info___111 *);

struct bpf_map___111;

struct bpf_iter_aux_info___111 {
	struct bpf_map___111 *map;
};

struct bpf_iter_seq_info___110 {
	const struct seq_operations___274 *seq_ops;
	bpf_iter_init_seq_priv_t___110 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___111;

struct bpf_map_ops___110 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___111 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___111 *, struct file___299 *);
	void (*map_free)(struct bpf_map___111 *);
	int (*map_get_next_key)(struct bpf_map___111 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___111 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___111 *, void *);
	int (*map_lookup_batch)(struct bpf_map___111 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___111 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___111 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___111 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___111 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___111 *, void *);
	int (*map_update_elem)(struct bpf_map___111 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___111 *, void *);
	int (*map_push_elem)(struct bpf_map___111 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___111 *, void *);
	int (*map_peek_elem)(struct bpf_map___111 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___111 *, struct file___299 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___111 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___111 *, void *, struct seq_file___274 *);
	int (*map_check_btf)(const struct bpf_map___111 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___111 *, struct bpf_prog_aux___111 *);
	void (*map_poke_untrack)(struct bpf_map___111 *, struct bpf_prog_aux___111 *);
	void (*map_poke_run)(struct bpf_map___111 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___111 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___111 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___111 *, struct vm_area_struct___304 *);
	__poll_t (*map_poll)(struct bpf_map___111 *, struct file___299 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___111 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___111 *, const struct bpf_map___111 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___111 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___110 *iter_seq_info;
};

struct bpf_map___111 {
	const struct bpf_map_ops___110 *ops;
	struct bpf_map___111 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___110;

struct bpf_jit_poke_descriptor___110;

struct btf_mod_pair___110;

struct bpf_prog_offload___108;

struct bpf_prog_aux___111 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___110 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___110 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___101 *ops;
	struct bpf_map___111 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___110 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___111 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___108 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___108;

struct bpf_map_dev_ops___108 {
	int (*map_get_next_key)(struct bpf_offloaded_map___108 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___108 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___108 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___108 *, void *);
};

struct bpf_offloaded_map___108 {
	struct bpf_map___111 map;
	struct net_device___108 *netdev;
	const struct bpf_map_dev_ops___108 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___108 {
	struct bpf_prog *prog;
	struct net_device___108 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___110 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___283 *mod;
};

struct bpf_jit_poke_descriptor___110 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___111 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___110 {
	struct btf *btf;
	struct module___283 *module;
};

struct cftype___226;

struct cgroup_subsys___226 {
	struct cgroup_subsys_state___226 * (*css_alloc)(struct cgroup_subsys_state___226 *);
	int (*css_online)(struct cgroup_subsys_state___226 *);
	void (*css_offline)(struct cgroup_subsys_state___226 *);
	void (*css_released)(struct cgroup_subsys_state___226 *);
	void (*css_free)(struct cgroup_subsys_state___226 *);
	void (*css_reset)(struct cgroup_subsys_state___226 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___226 *, int);
	int (*css_extra_stat_show)(struct seq_file___274 *, struct cgroup_subsys_state___226 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___306 *, struct css_set___226 *);
	void (*cancel_fork)(struct task_struct___306 *, struct css_set___226 *);
	void (*fork)(struct task_struct___306 *);
	void (*exit)(struct task_struct___306 *);
	void (*release)(struct task_struct___306 *);
	void (*bind)(struct cgroup_subsys_state___226 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___226 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___226 *dfl_cftypes;
	struct cftype___226 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___226 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___226 *updated_children;
	struct cgroup___226 *updated_next;
};

struct cgroup_root___226 {
	struct kernfs_root___287 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___226 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___226 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___226 *ss;
	struct list_head node;
	struct kernfs_ops___287 *kf_ops;
	int (*open)(struct kernfs_open_file___287 *);
	void (*release)(struct kernfs_open_file___287 *);
	u64 (*read_u64)(struct cgroup_subsys_state___226 *, struct cftype___226 *);
	s64 (*read_s64)(struct cgroup_subsys_state___226 *, struct cftype___226 *);
	int (*seq_show)(struct seq_file___274 *, void *);
	void * (*seq_start)(struct seq_file___274 *, loff_t *);
	void * (*seq_next)(struct seq_file___274 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___274 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___226 *, struct cftype___226 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___226 *, struct cftype___226 *, s64);
	ssize_t (*write)(struct kernfs_open_file___287 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___287 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___108 {
	struct net_device___108 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___108 {
	struct net_device___108 *dev;
};

struct xdp_buff___108 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___108 *rxq;
	struct xdp_txq_info___108 *txq;
	u32 frame_sz;
};

struct xdp_frame___108 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___108 *dev_rx;
};

struct netlink_callback___108 {
	struct sk_buff___109 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___109 *, struct netlink_callback___108 *);
	int (*done)(struct netlink_callback___108 *);
	void *data;
	struct module___283 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___108 {
	int (*create)(struct sk_buff___109 *, struct net_device___108 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___109 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___108 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___109 *);
};

struct netdev_queue___108 {
	struct net_device___108 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___287 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___108 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___108 {
	struct xdp_rxq_info___108 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___287 kobj;
	struct net_device___108 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___108 {
	enum net_device_path_type type;
	const struct net_device___108 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___108 = 0,
				DEV_PATH_BR_VLAN_TAG___108 = 1,
				DEV_PATH_BR_VLAN_UNTAG___108 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___108 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___108 {
	const struct net_device___108 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___108 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___101 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___108 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___108 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___109 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___108 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___108 *dev;
	const char *name;
};

struct net_device_ops___108 {
	int (*ndo_init)(struct net_device___108 *);
	void (*ndo_uninit)(struct net_device___108 *);
	int (*ndo_open)(struct net_device___108 *);
	int (*ndo_stop)(struct net_device___108 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___109 *, struct net_device___108 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___109 *, struct net_device___108 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___108 *, struct sk_buff___109 *, struct net_device___108 *);
	void (*ndo_change_rx_flags)(struct net_device___108 *, int);
	void (*ndo_set_rx_mode)(struct net_device___108 *);
	int (*ndo_set_mac_address)(struct net_device___108 *, void *);
	int (*ndo_validate_addr)(struct net_device___108 *);
	int (*ndo_do_ioctl)(struct net_device___108 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___108 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___108 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___108 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___108 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___108 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___108 *, int);
	int (*ndo_neigh_setup)(struct net_device___108 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___108 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___108 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___108 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___108 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___108 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___108 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___108 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___108 *);
	int (*ndo_netpoll_setup)(struct net_device___108 *, struct netpoll_info___6 *);
	void (*ndo_netpoll_cleanup)(struct net_device___108 *);
	int (*ndo_set_vf_mac)(struct net_device___108 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___108 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___108 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___108 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___108 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___108 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___108 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___108 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___108 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___108 *, int, struct sk_buff___109 *);
	int (*ndo_get_vf_guid)(struct net_device___108 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___108 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___108 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___108 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___108 *);
	int (*ndo_fcoe_disable)(struct net_device___108 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___108 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___108 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___108 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___108 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___108 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___108 *, const struct sk_buff___109 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___108 *, struct net_device___108 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___108 *, struct net_device___108 *);
	struct net_device___108 * (*ndo_get_xmit_slave)(struct net_device___108 *, struct sk_buff___109 *, bool);
	struct net_device___108 * (*ndo_sk_get_lower_dev)(struct net_device___108 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___108 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___108 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___108 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___108 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___108 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___108 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___109 *, struct netlink_callback___108 *, struct net_device___108 *, struct net_device___108 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___109 *, struct nlattr **, struct net_device___108 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___108 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___109 *, u32, u32, struct net_device___108 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___108 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___108 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___108 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___108 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___108 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___108 *, struct net_device___108 *);
	void (*ndo_dfwd_del_station)(struct net_device___108 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___108 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___108 *);
	int (*ndo_change_proto_down)(struct net_device___108 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___108 *, struct sk_buff___109 *);
	void (*ndo_set_rx_headroom)(struct net_device___108 *, int);
	int (*ndo_bpf)(struct net_device___108 *, struct netdev_bpf___108 *);
	int (*ndo_xdp_xmit)(struct net_device___108 *, int, struct xdp_frame___108 **, u32);
	struct net_device___108 * (*ndo_xdp_get_xmit_slave)(struct net_device___108 *, struct xdp_buff___108 *);
	int (*ndo_xsk_wakeup)(struct net_device___108 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___108 *);
	int (*ndo_tunnel_ctl)(struct net_device___108 *, struct ip_tunnel_parm *, int);
	struct net_device___108 * (*ndo_get_peer_dev)(struct net_device___108 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___108 *, struct net_device_path___108 *);
};

struct netpoll___7;

struct netpoll_info___6 {
	refcount_t refcnt;
	struct semaphore dev_lock;
	struct sk_buff_head___108 txq;
	struct delayed_work tx_work;
	struct netpoll___7 *netpoll;
	struct callback_head rcu;
};

struct vlan_group {
	unsigned int nr_vlan_devs;
	struct hlist_node hlist;
	struct net_device___108 **vlan_devices_arrays[16];
};

struct vlan_info___2 {
	struct net_device___108 *real_dev;
	struct vlan_group grp;
	struct list_head vid_list;
	unsigned int nr_vids;
	struct callback_head rcu;
};

struct napi_gro_cb___7 {
	void *frag0;
	unsigned int frag0_len;
	int data_offset;
	u16 flush;
	u16 flush_id;
	u16 count;
	u16 gro_remcsum_start;
	long unsigned int age;
	u16 proto;
	u8 same_flow: 1;
	u8 encap_mark: 1;
	u8 csum_valid: 1;
	u8 csum_cnt: 3;
	u8 free: 2;
	u8 is_ipv6: 1;
	u8 is_fou: 1;
	u8 is_atomic: 1;
	u8 recursion_counter: 4;
	u8 is_flist: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__wsum csum;
	struct sk_buff___109 *last;
};

struct offload_callbacks___6 {
	struct sk_buff___109 * (*gso_segment)(struct sk_buff___109 *, netdev_features_t);
	struct sk_buff___109 * (*gro_receive)(struct list_head *, struct sk_buff___109 *);
	int (*gro_complete)(struct sk_buff___109 *, int);
};

struct packet_offload___5 {
	__be16 type;
	u16 priority;
	struct offload_callbacks___6 callbacks;
	struct list_head list;
};

enum vlan_flags {
	VLAN_FLAG_REORDER_HDR = 1,
	VLAN_FLAG_GVRP = 2,
	VLAN_FLAG_LOOSE_BINDING = 4,
	VLAN_FLAG_MVRP = 8,
	VLAN_FLAG_BRIDGE_BINDING = 16,
};

struct vlan_priority_tci_mapping {
	u32 priority;
	u16 vlan_qos;
	struct vlan_priority_tci_mapping *next;
};

struct vlan_dev_priv {
	unsigned int nr_ingress_mappings;
	u32 ingress_priority_map[8];
	unsigned int nr_egress_mappings;
	struct vlan_priority_tci_mapping *egress_priority_map[16];
	__be16 vlan_proto;
	u16 vlan_id;
	u16 flags;
	struct net_device___108 *real_dev;
	unsigned char real_dev_addr[6];
	struct proc_dir_entry *dent;
	struct vlan_pcpu_stats *vlan_pcpu_stats;
	struct netpoll___7 *netpoll;
};

struct netpoll___7 {
	struct net_device___108 *dev;
	char dev_name[16];
	const char *name;
	union inet_addr local_ip;
	union inet_addr remote_ip;
	bool ipv6;
	u16 local_port;
	u16 remote_port;
	u8 remote_mac[6];
};

enum vlan_protos {
	VLAN_PROTO_8021Q = 0,
	VLAN_PROTO_8021AD = 1,
	VLAN_PROTO_NUM = 2,
};

struct vlan_vid_info {
	struct list_head list;
	__be16 proto;
	u16 vid;
	int refcount;
};

struct dentry___300;

struct super_block___300;

struct module___284;

struct file_system_type___300 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___300 * (*mount)(struct file_system_type___300 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___300 *);
	struct module___284 *owner;
	struct file_system_type___300 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___300;

struct kiocb___300;

struct iov_iter___220;

struct vm_area_struct___305;

struct inode___300;

struct file_lock___300;

struct page___305;

struct pipe_inode_info___141;

struct seq_file___275;

struct file_operations___301 {
	struct module___284 *owner;
	loff_t (*llseek)(struct file___300 *, loff_t, int);
	ssize_t (*read)(struct file___300 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___300 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___300 *, struct iov_iter___220 *);
	ssize_t (*write_iter)(struct kiocb___300 *, struct iov_iter___220 *);
	int (*iopoll)(struct kiocb___300 *, bool);
	int (*iterate)(struct file___300 *, struct dir_context *);
	int (*iterate_shared)(struct file___300 *, struct dir_context *);
	__poll_t (*poll)(struct file___300 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___300 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___300 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___300 *, struct vm_area_struct___305 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___300 *, struct file___300 *);
	int (*flush)(struct file___300 *, fl_owner_t);
	int (*release)(struct inode___300 *, struct file___300 *);
	int (*fsync)(struct file___300 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___300 *, int);
	int (*lock)(struct file___300 *, int, struct file_lock___300 *);
	ssize_t (*sendpage)(struct file___300 *, struct page___305 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___300 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___300 *, long unsigned int);
	int (*flock)(struct file___300 *, int, struct file_lock___300 *);
	ssize_t (*splice_write)(struct pipe_inode_info___141 *, struct file___300 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___300 *, loff_t *, struct pipe_inode_info___141 *, size_t, unsigned int);
	int (*setlease)(struct file___300 *, long int, struct file_lock___300 **, void **);
	long int (*fallocate)(struct file___300 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___275 *, struct file___300 *);
	ssize_t (*copy_file_range)(struct file___300 *, loff_t, struct file___300 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___300 *, loff_t, struct file___300 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___300 *, loff_t, loff_t, int);
};

struct vmacache___305 {
	u64 seqnum;
	struct vm_area_struct___305 *vmas[4];
};

struct page_frag___305 {
	struct page___305 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___306;

struct pid___277;

struct nsproxy___286;

struct signal_struct___301;

struct css_set___227;

struct vm_struct___283;

struct task_struct___307 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___307 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___306 *mm;
	struct mm_struct___306 *active_mm;
	struct vmacache___305 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___307 *real_parent;
	struct task_struct___307 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___307 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___277 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___286 *nsproxy;
	struct signal_struct___301 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___307 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___189 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___227 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___141 *splice_pipe;
	struct page_frag___305 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___307 *oom_reaper_list;
	struct vm_struct___283 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___288;

struct kobj_type___288;

struct kernfs_node___288;

struct kobject___288 {
	const char *name;
	struct list_head entry;
	struct kobject___288 *parent;
	struct kset___288 *kset;
	struct kobj_type___288 *ktype;
	struct kernfs_node___288 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___285 {
	struct kobject___288 kobj;
	struct module___284 *mod;
	struct kobject___288 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___284 {
	struct module___284 *mod;
	struct latch_tree_node node;
};

struct module_layout___284 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___284 mtn;
};

struct module_attribute___284;

struct kernel_param___284;

struct module___284 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___285 mkobj;
	struct module_attribute___284 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___288 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___284 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___284 core_layout;
	struct module_layout___284 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___277;

struct upid___277 {
	int nr;
	struct pid_namespace___277 *ns;
};

struct pid_namespace___277 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___307 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___277 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___277 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___277 numbers[1];
};

typedef struct page___305 *pgtable_t___305;

struct address_space___300;

struct page_pool___129;

struct dev_pagemap___295;

struct page___305 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___300 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___129 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___305 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___305 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___306 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___295 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___295;

struct vm_area_struct___305 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___305 *vm_next;
	struct vm_area_struct___305 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___306 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___295 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___300 *vm_file;
	struct file___300 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___301 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___307 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___307 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___277 *pids[4];
	struct pid___277 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___306 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___305;

struct mm_struct___306 {
	struct {
		struct vm_area_struct___305 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___300 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___305 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___307 *owner;
		struct user_namespace___26 *user_ns;
		struct file___300 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___114;

struct cgroup_namespace___227;

struct nsproxy___286 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___277 *pid_ns_for_children;
	struct net___114 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___227 *cgroup_ns;
};

struct cgroup_subsys_state___227;

struct cgroup___227;

struct css_set___227 {
	struct cgroup_subsys_state___227 *subsys[14];
	refcount_t refcount;
	struct css_set___227 *dom_cset;
	struct cgroup___227 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___227 *mg_src_cgrp;
	struct cgroup___227 *mg_dst_cgrp;
	struct css_set___227 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___300;

struct pipe_buffer___141;

struct pipe_inode_info___141 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___305 *tmp_page;
	struct fasync_struct___300 *fasync_readers;
	struct fasync_struct___300 *fasync_writers;
	struct pipe_buffer___141 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct vm_struct___283 {
	struct vm_struct___283 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___305 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct bio_vec___217 {
	struct page___305 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___220 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___217 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___141 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___97 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___220 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___300 *msg_iocb;
};

struct kiocb___300 {
	struct file___300 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___300 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct net_device___109;

struct sk_buff___110 {
	union {
		struct {
			struct sk_buff___110 *next;
			struct sk_buff___110 *prev;
			union {
				struct net_device___109 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___94 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___110 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___114;

struct fqdir___114 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___114 *f;
	struct net___114 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___114;

struct inet_frags___114 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___114 *, const void *);
	void (*destructor)(struct inet_frag_queue___114 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct netns_ipv4___114 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___114 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_ops___114 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___114 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___109 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___110 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___110 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___110 *);
	int (*local_out)(struct net___114 *, struct sock *, struct sk_buff___110 *);
	struct neighbour * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___110 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___114 {
	struct dst_ops___114 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___114 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___114 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___114 *fqdir;
};

struct sk_buff_head___109 {
	struct sk_buff___110 *next;
	struct sk_buff___110 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___114 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___114 xfrm4_dst_ops;
	struct dst_ops___114 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___114 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___109 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___114 ipv4;
	struct netns_ipv6___114 ipv6;
	struct netns_ieee802154_lowpan___114 ieee802154_lowpan;
	struct netns_sctp___94 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___109 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___101 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___114 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___114 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___110 *fragments_tail;
	struct sk_buff___110 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___114 *fqdir;
	struct callback_head rcu;
};

struct address_space_operations___300;

struct address_space___300 {
	struct inode___300 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___300 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___281;

struct page_pool_params___129 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___281 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___129 {
	u32 count;
	struct page___305 *cache[128];
};

struct page_pool___129 {
	struct page_pool_params___129 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___305 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___129 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___295;

struct dev_pagemap___295 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___295 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___300;

struct path___300 {
	struct vfsmount___300 *mnt;
	struct dentry___300 *dentry;
};

struct fown_struct___277 {
	rwlock_t lock;
	struct pid___277 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___300 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___300 f_path;
	struct inode___300 *f_inode;
	const struct file_operations___301 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___277 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___300 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___295;

struct vm_operations_struct___295 {
	void (*open)(struct vm_area_struct___305 *);
	void (*close)(struct vm_area_struct___305 *);
	int (*may_split)(struct vm_area_struct___305 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___305 *);
	int (*mprotect)(struct vm_area_struct___305 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___295 *);
	vm_fault_t (*huge_fault)(struct vm_fault___295 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___295 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___305 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___295 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___295 *);
	int (*access)(struct vm_area_struct___305 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___305 *);
	int (*set_policy)(struct vm_area_struct___305 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___305 *, long unsigned int);
	struct page___305 * (*find_special_page)(struct vm_area_struct___305 *, long unsigned int);
};

struct core_thread___305 {
	struct task_struct___307 *task;
	struct core_thread___305 *next;
};

struct core_state___305 {
	atomic_t nr_threads;
	struct core_thread___305 dumper;
	struct completion startup;
};

struct vm_fault___295 {
	const struct {
		struct vm_area_struct___305 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___305 *cow_page;
	struct page___305 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___305 prealloc_pte;
};

typedef rx_handler_result_t rx_handler_func_t___109(struct sk_buff___110 **);

typedef struct {
	struct net___114 *net;
} possible_net_t___109;

struct wakeup_source___281;

struct dev_pm_info___281 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___281 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___281 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___281;

struct bus_type___281;

struct device_driver___281;

struct dev_pm_domain___281;

struct fwnode_handle___277;

struct class___281;

struct attribute_group___288;

struct device___281 {
	struct kobject___288 kobj;
	struct device___281 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___281 *type;
	struct bus_type___281 *bus;
	struct device_driver___281 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___281 power;
	struct dev_pm_domain___281 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___277 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___281 *class;
	const struct attribute_group___288 **groups;
	void (*release)(struct device___281 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_name_node___109;

struct net_device_ops___109;

struct iw_handler_def___5;

struct ethtool_ops___32;

struct xfrmdev_ops___109;

struct header_ops___109;

struct netdev_rx_queue___109;

struct netdev_queue___109;

struct dcbnl_rtnl_ops___109;

struct net_device___109 {
	char name[16];
	struct netdev_name_node___109 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___109 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def___5 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops___32 *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___109 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___109 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___288 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___109 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___109 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___109 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___109 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___109 = 0,
		NETREG_REGISTERED___109 = 1,
		NETREG_UNREGISTERING___109 = 2,
		NETREG_UNREGISTERED___109 = 3,
		NETREG_RELEASED___109 = 4,
		NETREG_DUMMY___109 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___109 = 0,
		RTNL_LINK_INITIALIZING___109 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___109 *);
	struct netpoll_info *npinfo;
	possible_net_t___109 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___281 dev;
	const struct attribute_group___288 *sysfs_groups[4];
	const struct attribute_group___288 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___35 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___109 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___101 xdp_state[3];
	long: 64;
};

struct dentry_operations___300;

struct dentry___300 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___300 *d_parent;
	struct qstr d_name;
	struct inode___300 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___300 *d_op;
	struct super_block___300 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___300;

struct inode___300 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___300 *i_op;
	struct super_block___300 *i_sb;
	struct address_space___300 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___301 *i_fop;
		void (*free_inode)(struct inode___300 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___300 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___141 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___300 {
	int (*d_revalidate)(struct dentry___300 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___300 *, unsigned int);
	int (*d_hash)(const struct dentry___300 *, struct qstr *);
	int (*d_compare)(const struct dentry___300 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___300 *);
	int (*d_init)(struct dentry___300 *);
	void (*d_release)(struct dentry___300 *);
	void (*d_prune)(struct dentry___300 *);
	void (*d_iput)(struct dentry___300 *, struct inode___300 *);
	char * (*d_dname)(struct dentry___300 *, char *, int);
	struct vfsmount___300 * (*d_automount)(struct path___300 *);
	int (*d_manage)(const struct path___300 *, bool);
	struct dentry___300 * (*d_real)(struct dentry___300 *, const struct inode___300 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___300;

struct mem_dqinfo___300 {
	struct quota_format_type___300 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___300;

struct quota_info___300 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___300 *files[3];
	struct mem_dqinfo___300 info[3];
	const struct quota_format_ops___300 *ops[3];
};

struct rcuwait___301 {
	struct task_struct___307 *task;
};

struct percpu_rw_semaphore___301 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___301 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___300 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___301 rw_sem[3];
};

struct super_operations___300;

struct dquot_operations___300;

struct quotactl_ops___300;

struct super_block___300 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___300 *s_type;
	const struct super_operations___300 *s_op;
	const struct dquot_operations___300 *dq_op;
	const struct quotactl_ops___300 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___300 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___300 s_dquot;
	struct sb_writers___300 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___300 *s_d_op;
	int cleancache_poolid;
	struct shrinker___163 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___300 {
	struct dentry___300 *mnt_root;
	struct super_block___300 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct cgroup_subsys___227;

struct cgroup_subsys_state___227 {
	struct cgroup___227 *cgroup;
	struct cgroup_subsys___227 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___227 *parent;
};

struct cgroup_file___227 {
	struct kernfs_node___288 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___227 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___307 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___227;

struct cgroup_rstat_cpu___227;

struct cgroup___227 {
	struct cgroup_subsys_state___227 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___288 *kn;
	struct cgroup_file___227 procs_file;
	struct cgroup_file___227 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___227 *subsys[14];
	struct cgroup_root___227 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___227 *dom_cgrp;
	struct cgroup___227 *old_dom_cgrp;
	struct cgroup_rstat_cpu___227 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___227 psi;
	struct cgroup_bpf___101 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___300 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___300 *ia_file;
};

struct dquot___300 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___300 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___300 {
	int qf_fmt_id;
	const struct quota_format_ops___300 *qf_ops;
	struct module___284 *qf_owner;
	struct quota_format_type___300 *qf_next;
};

struct quota_format_ops___300 {
	int (*check_quota_file)(struct super_block___300 *, int);
	int (*read_file_info)(struct super_block___300 *, int);
	int (*write_file_info)(struct super_block___300 *, int);
	int (*free_file_info)(struct super_block___300 *, int);
	int (*read_dqblk)(struct dquot___300 *);
	int (*commit_dqblk)(struct dquot___300 *);
	int (*release_dqblk)(struct dquot___300 *);
	int (*get_next_id)(struct super_block___300 *, struct kqid *);
};

struct dquot_operations___300 {
	int (*write_dquot)(struct dquot___300 *);
	struct dquot___300 * (*alloc_dquot)(struct super_block___300 *, int);
	void (*destroy_dquot)(struct dquot___300 *);
	int (*acquire_dquot)(struct dquot___300 *);
	int (*release_dquot)(struct dquot___300 *);
	int (*mark_dirty)(struct dquot___300 *);
	int (*write_info)(struct super_block___300 *, int);
	qsize_t * (*get_reserved_space)(struct inode___300 *);
	int (*get_projid)(struct inode___300 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___300 *, qsize_t *);
	int (*get_next_id)(struct super_block___300 *, struct kqid *);
};

struct quotactl_ops___300 {
	int (*quota_on)(struct super_block___300 *, int, int, const struct path___300 *);
	int (*quota_off)(struct super_block___300 *, int);
	int (*quota_enable)(struct super_block___300 *, unsigned int);
	int (*quota_disable)(struct super_block___300 *, unsigned int);
	int (*quota_sync)(struct super_block___300 *, int);
	int (*set_info)(struct super_block___300 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___300 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___300 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___300 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___300 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___300 *, unsigned int);
};

struct address_space_operations___300 {
	int (*writepage)(struct page___305 *, struct writeback_control___3 *);
	int (*readpage)(struct file___300 *, struct page___305 *);
	int (*writepages)(struct address_space___300 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___305 *);
	int (*readpages)(struct file___300 *, struct address_space___300 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___300 *, struct address_space___300 *, loff_t, unsigned int, unsigned int, struct page___305 **, void **);
	int (*write_end)(struct file___300 *, struct address_space___300 *, loff_t, unsigned int, unsigned int, struct page___305 *, void *);
	sector_t (*bmap)(struct address_space___300 *, sector_t);
	void (*invalidatepage)(struct page___305 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___305 *, gfp_t);
	void (*freepage)(struct page___305 *);
	ssize_t (*direct_IO)(struct kiocb___300 *, struct iov_iter___220 *);
	int (*migratepage)(struct address_space___300 *, struct page___305 *, struct page___305 *, enum migrate_mode);
	bool (*isolate_page)(struct page___305 *, isolate_mode_t);
	void (*putback_page)(struct page___305 *);
	int (*launder_page)(struct page___305 *);
	int (*is_partially_uptodate)(struct page___305 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___305 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___300 *, struct page___305 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___300 *, sector_t *);
	void (*swap_deactivate)(struct file___300 *);
};

struct inode_operations___300 {
	struct dentry___300 * (*lookup)(struct inode___300 *, struct dentry___300 *, unsigned int);
	const char * (*get_link)(struct dentry___300 *, struct inode___300 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___300 *, int);
	struct posix_acl * (*get_acl)(struct inode___300 *, int, bool);
	int (*readlink)(struct dentry___300 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___300 *, struct dentry___300 *, umode_t, bool);
	int (*link)(struct dentry___300 *, struct inode___300 *, struct dentry___300 *);
	int (*unlink)(struct inode___300 *, struct dentry___300 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___300 *, struct dentry___300 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___300 *, struct dentry___300 *, umode_t);
	int (*rmdir)(struct inode___300 *, struct dentry___300 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___300 *, struct dentry___300 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___300 *, struct dentry___300 *, struct inode___300 *, struct dentry___300 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___300 *, struct iattr___300 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___300 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___300 *, char *, size_t);
	int (*fiemap)(struct inode___300 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___300 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___300 *, struct dentry___300 *, struct file___300 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___300 *, struct dentry___300 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___300 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___300 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___300 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___300 {
	void (*fl_copy_lock)(struct file_lock___300 *, struct file_lock___300 *);
	void (*fl_release_private)(struct file_lock___300 *);
};

struct lock_manager_operations___300;

struct file_lock___300 {
	struct file_lock___300 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___300 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___300 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___300 *fl_ops;
	const struct lock_manager_operations___300 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___300 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___300 *);
	int (*lm_grant)(struct file_lock___300 *, int);
	bool (*lm_break)(struct file_lock___300 *);
	int (*lm_change)(struct file_lock___300 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___300 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___300 *);
};

struct fasync_struct___300 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___300 *fa_next;
	struct file___300 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___300 {
	struct inode___300 * (*alloc_inode)(struct super_block___300 *);
	void (*destroy_inode)(struct inode___300 *);
	void (*free_inode)(struct inode___300 *);
	void (*dirty_inode)(struct inode___300 *, int);
	int (*write_inode)(struct inode___300 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___300 *);
	void (*evict_inode)(struct inode___300 *);
	void (*put_super)(struct super_block___300 *);
	int (*sync_fs)(struct super_block___300 *, int);
	int (*freeze_super)(struct super_block___300 *);
	int (*freeze_fs)(struct super_block___300 *);
	int (*thaw_super)(struct super_block___300 *);
	int (*unfreeze_fs)(struct super_block___300 *);
	int (*statfs)(struct dentry___300 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___300 *, int *, char *);
	void (*umount_begin)(struct super_block___300 *);
	int (*show_options)(struct seq_file___275 *, struct dentry___300 *);
	int (*show_devname)(struct seq_file___275 *, struct dentry___300 *);
	int (*show_path)(struct seq_file___275 *, struct dentry___300 *);
	int (*show_stats)(struct seq_file___275 *, struct dentry___300 *);
	ssize_t (*quota_read)(struct super_block___300 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___300 *, int, const char *, size_t, loff_t);
	struct dquot___300 ** (*get_dquots)(struct inode___300 *);
	long int (*nr_cached_objects)(struct super_block___300 *, struct shrink_control___163 *);
	long int (*free_cached_objects)(struct super_block___300 *, struct shrink_control___163 *);
	struct file___300 * (*real_loop)(struct file___300 *);
};

struct seq_operations___275;

struct seq_file___275 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___275 *op;
	int poll_event;
	const struct file___300 *file;
	void *private;
};

struct dev_pagemap_ops___295 {
	void (*page_free)(struct page___305 *);
	void (*kill)(struct dev_pagemap___295 *);
	void (*cleanup)(struct dev_pagemap___295 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___295 *);
};

struct fwnode_operations___277;

struct fwnode_handle___277 {
	struct fwnode_handle___277 *secondary;
	const struct fwnode_operations___277 *ops;
	struct device___281 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___277;

struct fwnode_endpoint___277;

struct fwnode_operations___277 {
	struct fwnode_handle___277 * (*get)(struct fwnode_handle___277 *);
	void (*put)(struct fwnode_handle___277 *);
	bool (*device_is_available)(const struct fwnode_handle___277 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___277 *, const struct device___281 *);
	bool (*property_present)(const struct fwnode_handle___277 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___277 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___277 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___277 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*get_parent)(const struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*get_next_child_node)(const struct fwnode_handle___277 *, struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*get_named_child_node)(const struct fwnode_handle___277 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___277 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___277 *);
	struct fwnode_handle___277 * (*graph_get_next_endpoint)(const struct fwnode_handle___277 *, struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*graph_get_remote_endpoint)(const struct fwnode_handle___277 *);
	struct fwnode_handle___277 * (*graph_get_port_parent)(struct fwnode_handle___277 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___277 *, struct fwnode_endpoint___277 *);
	int (*add_links)(struct fwnode_handle___277 *);
};

struct fwnode_endpoint___277 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___277 *local_fwnode;
};

struct fwnode_reference_args___277 {
	struct fwnode_handle___277 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___288;

struct kernfs_elem_dir___288 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___288 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___288;

struct kernfs_root___288 {
	struct kernfs_node___288 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___288 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___288 {
	struct kernfs_node___288 *target_kn;
};

struct kernfs_ops___288;

struct kernfs_elem_attr___288 {
	const struct kernfs_ops___288 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___288 *notify_next;
};

struct kernfs_node___288 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___288 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___288 dir;
		struct kernfs_elem_symlink___288 symlink;
		struct kernfs_elem_attr___288 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___288;

struct kernfs_ops___288 {
	int (*open)(struct kernfs_open_file___288 *);
	void (*release)(struct kernfs_open_file___288 *);
	int (*seq_show)(struct seq_file___275 *, void *);
	void * (*seq_start)(struct seq_file___275 *, loff_t *);
	void * (*seq_next)(struct seq_file___275 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___275 *, void *);
	ssize_t (*read)(struct kernfs_open_file___288 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___288 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___288 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___288 *, struct vm_area_struct___305 *);
};

struct kernfs_syscall_ops___288 {
	int (*show_options)(struct seq_file___275 *, struct kernfs_root___288 *);
	int (*mkdir)(struct kernfs_node___288 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___288 *);
	int (*rename)(struct kernfs_node___288 *, struct kernfs_node___288 *, const char *);
	int (*show_path)(struct seq_file___275 *, struct kernfs_node___288 *, struct kernfs_root___288 *);
};

struct kernfs_open_file___288 {
	struct kernfs_node___288 *kn;
	struct file___300 *file;
	struct seq_file___275 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___295 *vm_ops;
};

struct bin_attribute___288;

struct attribute_group___288 {
	const char *name;
	umode_t (*is_visible)(struct kobject___288 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___288 *, struct bin_attribute___288 *, int);
	struct attribute **attrs;
	struct bin_attribute___288 **bin_attrs;
};

struct bin_attribute___288 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___300 * (*f_mapping)();
	ssize_t (*read)(struct file___300 *, struct kobject___288 *, struct bin_attribute___288 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___300 *, struct kobject___288 *, struct bin_attribute___288 *, char *, loff_t, size_t);
	int (*mmap)(struct file___300 *, struct kobject___288 *, struct bin_attribute___288 *, struct vm_area_struct___305 *);
};

struct sysfs_ops___288 {
	ssize_t (*show)(struct kobject___288 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___288 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___288;

struct kset___288 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___288 kobj;
	const struct kset_uevent_ops___288 *uevent_ops;
};

struct kobj_type___288 {
	void (*release)(struct kobject___288 *);
	const struct sysfs_ops___288 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___288 **default_groups;
	const struct kobj_ns_type_operations___94 * (*child_ns_type)(struct kobject___288 *);
	const void * (*namespace)(struct kobject___288 *);
	void (*get_ownership)(struct kobject___288 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___288 {
	int (* const filter)(struct kset___288 *, struct kobject___288 *);
	const char * (* const name)(struct kset___288 *, struct kobject___288 *);
	int (* const uevent)(struct kset___288 *, struct kobject___288 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___284 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___284 *);
	int (*get)(char *, const struct kernel_param___284 *);
	void (*free)(void *);
};

struct kparam_array___284;

struct kernel_param___284 {
	const char *name;
	struct module___284 *mod;
	const struct kernel_param_ops___284 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___284 *arr;
	};
};

struct kparam_array___284 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___284 *ops;
	void *elem;
};

struct module_attribute___284 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___284 *, struct module_kobject___285 *, char *);
	ssize_t (*store)(struct module_attribute___284 *, struct module_kobject___285 *, const char *, size_t);
	void (*setup)(struct module___284 *, const char *);
	int (*test)(struct module___284 *);
	void (*free)(struct module___284 *);
};

struct cgroup_namespace___227 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___227 *root_cset;
};

struct socket_wq___96 {
	wait_queue_head_t wait;
	struct fasync_struct___300 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___96;

struct socket___97 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___300 *file;
	struct sock *sk;
	const struct proto_ops___96 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___96 wq;
};

typedef int (*sk_read_actor_t___95)(read_descriptor_t *, struct sk_buff___110 *, unsigned int, size_t);

struct proto_ops___96 {
	int family;
	struct module___284 *owner;
	int (*release)(struct socket___97 *);
	int (*bind)(struct socket___97 *, struct sockaddr *, int);
	int (*connect)(struct socket___97 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___97 *, struct socket___97 *);
	int (*accept)(struct socket___97 *, struct socket___97 *, int, bool);
	int (*getname)(struct socket___97 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___300 *, struct socket___97 *, struct poll_table_struct___5 *);
	int (*ioctl)(struct socket___97 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___97 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___97 *, void *, bool, bool);
	int (*listen)(struct socket___97 *, int);
	int (*shutdown)(struct socket___97 *, int);
	int (*setsockopt)(struct socket___97 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___97 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___275 *, struct socket___97 *);
	int (*sendmsg)(struct socket___97 *, struct msghdr___97 *, size_t);
	int (*recvmsg)(struct socket___97 *, struct msghdr___97 *, size_t, int);
	int (*mmap)(struct file___300 *, struct socket___97 *, struct vm_area_struct___305 *);
	ssize_t (*sendpage)(struct socket___97 *, struct page___305 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___97 *, loff_t *, struct pipe_inode_info___141 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock *, int);
	int (*peek_len)(struct socket___97 *);
	int (*read_sock)(struct sock *, read_descriptor_t *, sk_read_actor_t___95);
	int (*sendpage_locked)(struct sock *, struct page___305 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock *, struct msghdr___97 *, size_t);
	int (*set_rcvlowat)(struct sock *, int);
};

struct dev_pm_ops___281 {
	int (*prepare)(struct device___281 *);
	void (*complete)(struct device___281 *);
	int (*suspend)(struct device___281 *);
	int (*resume)(struct device___281 *);
	int (*freeze)(struct device___281 *);
	int (*thaw)(struct device___281 *);
	int (*poweroff)(struct device___281 *);
	int (*restore)(struct device___281 *);
	int (*suspend_late)(struct device___281 *);
	int (*resume_early)(struct device___281 *);
	int (*freeze_late)(struct device___281 *);
	int (*thaw_early)(struct device___281 *);
	int (*poweroff_late)(struct device___281 *);
	int (*restore_early)(struct device___281 *);
	int (*suspend_noirq)(struct device___281 *);
	int (*resume_noirq)(struct device___281 *);
	int (*freeze_noirq)(struct device___281 *);
	int (*thaw_noirq)(struct device___281 *);
	int (*poweroff_noirq)(struct device___281 *);
	int (*restore_noirq)(struct device___281 *);
	int (*runtime_suspend)(struct device___281 *);
	int (*runtime_resume)(struct device___281 *);
	int (*runtime_idle)(struct device___281 *);
};

struct wakeup_source___281 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___281 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___281 {
	struct dev_pm_ops___281 ops;
	int (*start)(struct device___281 *);
	void (*detach)(struct device___281 *, bool);
	int (*activate)(struct device___281 *);
	void (*sync)(struct device___281 *);
	void (*dismiss)(struct device___281 *);
};

struct bus_type___281 {
	const char *name;
	const char *dev_name;
	struct device___281 *dev_root;
	const struct attribute_group___288 **bus_groups;
	const struct attribute_group___288 **dev_groups;
	const struct attribute_group___288 **drv_groups;
	int (*match)(struct device___281 *, struct device_driver___281 *);
	int (*uevent)(struct device___281 *, struct kobj_uevent_env *);
	int (*probe)(struct device___281 *);
	void (*sync_state)(struct device___281 *);
	void (*remove)(struct device___281 *);
	void (*shutdown)(struct device___281 *);
	int (*online)(struct device___281 *);
	int (*offline)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	int (*num_vf)(struct device___281 *);
	int (*dma_configure)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___281 {
	const char *name;
	struct bus_type___281 *bus;
	struct module___284 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___281 *);
	void (*sync_state)(struct device___281 *);
	int (*remove)(struct device___281 *);
	void (*shutdown)(struct device___281 *);
	int (*suspend)(struct device___281 *, pm_message_t);
	int (*resume)(struct device___281 *);
	const struct attribute_group___288 **groups;
	const struct attribute_group___288 **dev_groups;
	const struct dev_pm_ops___281 *pm;
	void (*coredump)(struct device___281 *);
	struct driver_private *p;
};

struct device_type___281 {
	const char *name;
	const struct attribute_group___288 **groups;
	int (*uevent)(struct device___281 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___281 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___281 *);
	const struct dev_pm_ops___281 *pm;
};

struct class___281 {
	const char *name;
	struct module___284 *owner;
	const struct attribute_group___288 **class_groups;
	const struct attribute_group___288 **dev_groups;
	struct kobject___288 *dev_kobj;
	int (*dev_uevent)(struct device___281 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___281 *, umode_t *);
	void (*class_release)(struct class___281 *);
	void (*dev_release)(struct device___281 *);
	int (*shutdown_pre)(struct device___281 *);
	const struct kobj_ns_type_operations___94 *ns_type;
	const void * (*namespace)(struct device___281 *);
	void (*get_ownership)(struct device___281 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___281 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___141;

struct pipe_buffer___141 {
	struct page___305 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___141 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___141 {
	int (*confirm)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
	void (*release)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
	bool (*try_steal)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
	bool (*get)(struct pipe_inode_info___141 *, struct pipe_buffer___141 *);
};

typedef struct bio_vec___217 skb_frag_t___49;

struct skb_shared_info___43 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___110 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___49 frags[17];
};

struct seq_operations___275 {
	void * (*start)(struct seq_file___275 *, loff_t *);
	void (*stop)(struct seq_file___275 *, void *);
	void * (*next)(struct seq_file___275 *, void *, loff_t *);
	int (*show)(struct seq_file___275 *, void *);
};

struct pernet_operations___41 {
	struct list_head list;
	int (*init)(struct net___114 *);
	void (*pre_exit)(struct net___114 *);
	void (*exit)(struct net___114 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___109 {
	int (*ieee_getets)(struct net_device___109 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___109 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___109 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___109 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___109 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___109 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___109 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___109 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___109 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___109 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___109 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___109 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___109 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___109 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___109 *);
	u8 (*setstate)(struct net_device___109 *, u8);
	void (*getpermhwaddr)(struct net_device___109 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___109 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___109 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___109 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___109 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___109 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___109 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___109 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___109 *, int, u8 *);
	void (*setpfccfg)(struct net_device___109 *, int, u8);
	void (*getpfccfg)(struct net_device___109 *, int, u8 *);
	u8 (*setall)(struct net_device___109 *);
	u8 (*getcap)(struct net_device___109 *, int, u8 *);
	int (*getnumtcs)(struct net_device___109 *, int, u8 *);
	int (*setnumtcs)(struct net_device___109 *, int, u8);
	u8 (*getpfcstate)(struct net_device___109 *);
	void (*setpfcstate)(struct net_device___109 *, u8);
	void (*getbcncfg)(struct net_device___109 *, int, u32 *);
	void (*setbcncfg)(struct net_device___109 *, int, u32);
	void (*getbcnrp)(struct net_device___109 *, int, u8 *);
	void (*setbcnrp)(struct net_device___109 *, int, u8);
	int (*setapp)(struct net_device___109 *, u8, u16, u8);
	int (*getapp)(struct net_device___109 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___109 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___109 *, int, u8);
	u8 (*getdcbx)(struct net_device___109 *);
	u8 (*setdcbx)(struct net_device___109 *, u8);
	int (*peer_getappinfo)(struct net_device___109 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___109 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___109 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___109 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___109 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___109 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___112;

typedef int (*bpf_iter_init_seq_priv_t___111)(void *, struct bpf_iter_aux_info___112 *);

struct bpf_map___112;

struct bpf_iter_aux_info___112 {
	struct bpf_map___112 *map;
};

struct bpf_iter_seq_info___111 {
	const struct seq_operations___275 *seq_ops;
	bpf_iter_init_seq_priv_t___111 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___112;

struct bpf_map_ops___111 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___112 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___112 *, struct file___300 *);
	void (*map_free)(struct bpf_map___112 *);
	int (*map_get_next_key)(struct bpf_map___112 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___112 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___112 *, void *);
	int (*map_lookup_batch)(struct bpf_map___112 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___112 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___112 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___112 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___112 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___112 *, void *);
	int (*map_update_elem)(struct bpf_map___112 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___112 *, void *);
	int (*map_push_elem)(struct bpf_map___112 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___112 *, void *);
	int (*map_peek_elem)(struct bpf_map___112 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___112 *, struct file___300 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___112 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___112 *, void *, struct seq_file___275 *);
	int (*map_check_btf)(const struct bpf_map___112 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___112 *, struct bpf_prog_aux___112 *);
	void (*map_poke_untrack)(struct bpf_map___112 *, struct bpf_prog_aux___112 *);
	void (*map_poke_run)(struct bpf_map___112 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___112 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___112 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___112 *, struct vm_area_struct___305 *);
	__poll_t (*map_poll)(struct bpf_map___112 *, struct file___300 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___112 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___112 *, const struct bpf_map___112 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___112 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___111 *iter_seq_info;
};

struct bpf_map___112 {
	const struct bpf_map_ops___111 *ops;
	struct bpf_map___112 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___111;

struct bpf_jit_poke_descriptor___111;

struct btf_mod_pair___111;

struct bpf_prog_offload___109;

struct bpf_prog_aux___112 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___111 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___111 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___101 *ops;
	struct bpf_map___112 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___111 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___112 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___109 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___109;

struct bpf_map_dev_ops___109 {
	int (*map_get_next_key)(struct bpf_offloaded_map___109 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___109 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___109 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___109 *, void *);
};

struct bpf_offloaded_map___109 {
	struct bpf_map___112 map;
	struct net_device___109 *netdev;
	const struct bpf_map_dev_ops___109 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___109 {
	struct bpf_prog *prog;
	struct net_device___109 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___111 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___284 *mod;
};

struct bpf_jit_poke_descriptor___111 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___112 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___111 {
	struct btf *btf;
	struct module___284 *module;
};

struct cftype___227;

struct cgroup_subsys___227 {
	struct cgroup_subsys_state___227 * (*css_alloc)(struct cgroup_subsys_state___227 *);
	int (*css_online)(struct cgroup_subsys_state___227 *);
	void (*css_offline)(struct cgroup_subsys_state___227 *);
	void (*css_released)(struct cgroup_subsys_state___227 *);
	void (*css_free)(struct cgroup_subsys_state___227 *);
	void (*css_reset)(struct cgroup_subsys_state___227 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___227 *, int);
	int (*css_extra_stat_show)(struct seq_file___275 *, struct cgroup_subsys_state___227 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___307 *, struct css_set___227 *);
	void (*cancel_fork)(struct task_struct___307 *, struct css_set___227 *);
	void (*fork)(struct task_struct___307 *);
	void (*exit)(struct task_struct___307 *);
	void (*release)(struct task_struct___307 *);
	void (*bind)(struct cgroup_subsys_state___227 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___227 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___227 *dfl_cftypes;
	struct cftype___227 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___227 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___227 *updated_children;
	struct cgroup___227 *updated_next;
};

struct cgroup_root___227 {
	struct kernfs_root___288 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___227 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___227 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___227 *ss;
	struct list_head node;
	struct kernfs_ops___288 *kf_ops;
	int (*open)(struct kernfs_open_file___288 *);
	void (*release)(struct kernfs_open_file___288 *);
	u64 (*read_u64)(struct cgroup_subsys_state___227 *, struct cftype___227 *);
	s64 (*read_s64)(struct cgroup_subsys_state___227 *, struct cftype___227 *);
	int (*seq_show)(struct seq_file___275 *, void *);
	void * (*seq_start)(struct seq_file___275 *, loff_t *);
	void * (*seq_next)(struct seq_file___275 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___275 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___227 *, struct cftype___227 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___227 *, struct cftype___227 *, s64);
	ssize_t (*write)(struct kernfs_open_file___288 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___288 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___109 {
	struct net_device___109 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___109 {
	struct net_device___109 *dev;
};

struct xdp_buff___109 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___109 *rxq;
	struct xdp_txq_info___109 *txq;
	u32 frame_sz;
};

struct xdp_frame___109 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___109 *dev_rx;
};

struct netlink_callback___109 {
	struct sk_buff___110 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___110 *, struct netlink_callback___109 *);
	int (*done)(struct netlink_callback___109 *);
	void *data;
	struct module___284 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___109 {
	int (*create)(struct sk_buff___110 *, struct net_device___109 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___110 *, unsigned char *);
	int (*cache)(const struct neighbour *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___109 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___110 *);
};

struct netdev_queue___109 {
	struct net_device___109 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___288 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___109 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___109 {
	struct xdp_rxq_info___109 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___288 kobj;
	struct net_device___109 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___109 {
	enum net_device_path_type type;
	const struct net_device___109 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___109 = 0,
				DEV_PATH_BR_VLAN_TAG___109 = 1,
				DEV_PATH_BR_VLAN_UNTAG___109 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___109 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___109 {
	const struct net_device___109 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___109 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___101 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___109 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___109 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___110 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___109 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___109 *dev;
	const char *name;
};

struct net_device_ops___109 {
	int (*ndo_init)(struct net_device___109 *);
	void (*ndo_uninit)(struct net_device___109 *);
	int (*ndo_open)(struct net_device___109 *);
	int (*ndo_stop)(struct net_device___109 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___110 *, struct net_device___109 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___110 *, struct net_device___109 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___109 *, struct sk_buff___110 *, struct net_device___109 *);
	void (*ndo_change_rx_flags)(struct net_device___109 *, int);
	void (*ndo_set_rx_mode)(struct net_device___109 *);
	int (*ndo_set_mac_address)(struct net_device___109 *, void *);
	int (*ndo_validate_addr)(struct net_device___109 *);
	int (*ndo_do_ioctl)(struct net_device___109 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___109 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___109 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___109 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___109 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___109 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___109 *, int);
	int (*ndo_neigh_setup)(struct net_device___109 *, struct neigh_parms___2 *);
	void (*ndo_tx_timeout)(struct net_device___109 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___109 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___109 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___109 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___109 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___109 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___109 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___109 *);
	int (*ndo_netpoll_setup)(struct net_device___109 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___109 *);
	int (*ndo_set_vf_mac)(struct net_device___109 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___109 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___109 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___109 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___109 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___109 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___109 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___109 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___109 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___109 *, int, struct sk_buff___110 *);
	int (*ndo_get_vf_guid)(struct net_device___109 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___109 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___109 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___109 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___109 *);
	int (*ndo_fcoe_disable)(struct net_device___109 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___109 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___109 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___109 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___109 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___109 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___109 *, const struct sk_buff___110 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___109 *, struct net_device___109 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___109 *, struct net_device___109 *);
	struct net_device___109 * (*ndo_get_xmit_slave)(struct net_device___109 *, struct sk_buff___110 *, bool);
	struct net_device___109 * (*ndo_sk_get_lower_dev)(struct net_device___109 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___109 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___109 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___109 *, struct neighbour *);
	void (*ndo_neigh_destroy)(struct net_device___109 *, struct neighbour *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___109 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___109 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___110 *, struct netlink_callback___109 *, struct net_device___109 *, struct net_device___109 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___110 *, struct nlattr **, struct net_device___109 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___109 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___110 *, u32, u32, struct net_device___109 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___109 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___109 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___109 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___109 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___109 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___109 *, struct net_device___109 *);
	void (*ndo_dfwd_del_station)(struct net_device___109 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___109 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___109 *);
	int (*ndo_change_proto_down)(struct net_device___109 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___109 *, struct sk_buff___110 *);
	void (*ndo_set_rx_headroom)(struct net_device___109 *, int);
	int (*ndo_bpf)(struct net_device___109 *, struct netdev_bpf___109 *);
	int (*ndo_xdp_xmit)(struct net_device___109 *, int, struct xdp_frame___109 **, u32);
	struct net_device___109 * (*ndo_xdp_get_xmit_slave)(struct net_device___109 *, struct xdp_buff___109 *);
	int (*ndo_xsk_wakeup)(struct net_device___109 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___109 *);
	int (*ndo_tunnel_ctl)(struct net_device___109 *, struct ip_tunnel_parm *, int);
	struct net_device___109 * (*ndo_get_peer_dev)(struct net_device___109 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___109 *, struct net_device_path___109 *);
};

typedef int (*iw_handler___5)(struct net_device___109 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___5 {
	const iw_handler___5 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___5 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___109 *);
};

struct ethtool_ops___32 {
	u32 cap_link_lanes_supported: 1;
	u32 supported_coalesce_params;
	void (*get_drvinfo)(struct net_device___109 *, struct ethtool_drvinfo *);
	int (*get_regs_len)(struct net_device___109 *);
	void (*get_regs)(struct net_device___109 *, struct ethtool_regs *, void *);
	void (*get_wol)(struct net_device___109 *, struct ethtool_wolinfo *);
	int (*set_wol)(struct net_device___109 *, struct ethtool_wolinfo *);
	u32 (*get_msglevel)(struct net_device___109 *);
	void (*set_msglevel)(struct net_device___109 *, u32);
	int (*nway_reset)(struct net_device___109 *);
	u32 (*get_link)(struct net_device___109 *);
	int (*get_link_ext_state)(struct net_device___109 *, struct ethtool_link_ext_state_info *);
	int (*get_eeprom_len)(struct net_device___109 *);
	int (*get_eeprom)(struct net_device___109 *, struct ethtool_eeprom *, u8 *);
	int (*set_eeprom)(struct net_device___109 *, struct ethtool_eeprom *, u8 *);
	int (*get_coalesce)(struct net_device___109 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	int (*set_coalesce)(struct net_device___109 *, struct ethtool_coalesce *, struct kernel_ethtool_coalesce *, struct netlink_ext_ack *);
	void (*get_ringparam)(struct net_device___109 *, struct ethtool_ringparam *);
	int (*set_ringparam)(struct net_device___109 *, struct ethtool_ringparam *);
	void (*get_pause_stats)(struct net_device___109 *, struct ethtool_pause_stats *);
	void (*get_pauseparam)(struct net_device___109 *, struct ethtool_pauseparam *);
	int (*set_pauseparam)(struct net_device___109 *, struct ethtool_pauseparam *);
	void (*self_test)(struct net_device___109 *, struct ethtool_test *, u64 *);
	void (*get_strings)(struct net_device___109 *, u32, u8 *);
	int (*set_phys_id)(struct net_device___109 *, enum ethtool_phys_id_state);
	void (*get_ethtool_stats)(struct net_device___109 *, struct ethtool_stats *, u64 *);
	int (*begin)(struct net_device___109 *);
	void (*complete)(struct net_device___109 *);
	u32 (*get_priv_flags)(struct net_device___109 *);
	int (*set_priv_flags)(struct net_device___109 *, u32);
	int (*get_sset_count)(struct net_device___109 *, int);
	int (*get_rxnfc)(struct net_device___109 *, struct ethtool_rxnfc *, u32 *);
	int (*set_rxnfc)(struct net_device___109 *, struct ethtool_rxnfc *);
	int (*flash_device)(struct net_device___109 *, struct ethtool_flash *);
	int (*reset)(struct net_device___109 *, u32 *);
	u32 (*get_rxfh_key_size)(struct net_device___109 *);
	u32 (*get_rxfh_indir_size)(struct net_device___109 *);
	int (*get_rxfh)(struct net_device___109 *, u32 *, u8 *, u8 *);
	int (*set_rxfh)(struct net_device___109 *, const u32 *, const u8 *, const u8);
	int (*get_rxfh_context)(struct net_device___109 *, u32 *, u8 *, u8 *, u32);
	int (*set_rxfh_context)(struct net_device___109 *, const u32 *, const u8 *, const u8, u32 *, bool);
	void (*get_channels)(struct net_device___109 *, struct ethtool_channels *);
	int (*set_channels)(struct net_device___109 *, struct ethtool_channels *);
	int (*get_dump_flag)(struct net_device___109 *, struct ethtool_dump *);
	int (*get_dump_data)(struct net_device___109 *, struct ethtool_dump *, void *);
	int (*set_dump)(struct net_device___109 *, struct ethtool_dump *);
	int (*get_ts_info)(struct net_device___109 *, struct ethtool_ts_info *);
	int (*get_module_info)(struct net_device___109 *, struct ethtool_modinfo *);
	int (*get_module_eeprom)(struct net_device___109 *, struct ethtool_eeprom *, u8 *);
	int (*get_eee)(struct net_device___109 *, struct ethtool_eee *);
	int (*set_eee)(struct net_device___109 *, struct ethtool_eee *);
	int (*get_tunable)(struct net_device___109 *, const struct ethtool_tunable *, void *);
	int (*set_tunable)(struct net_device___109 *, const struct ethtool_tunable *, const void *);
	int (*get_per_queue_coalesce)(struct net_device___109 *, u32, struct ethtool_coalesce *);
	int (*set_per_queue_coalesce)(struct net_device___109 *, u32, struct ethtool_coalesce *);
	int (*get_link_ksettings)(struct net_device___109 *, struct ethtool_link_ksettings *);
	int (*set_link_ksettings)(struct net_device___109 *, const struct ethtool_link_ksettings *);
	void (*get_fec_stats)(struct net_device___109 *, struct ethtool_fec_stats *);
	int (*get_fecparam)(struct net_device___109 *, struct ethtool_fecparam *);
	int (*set_fecparam)(struct net_device___109 *, struct ethtool_fecparam *);
	void (*get_ethtool_phy_stats)(struct net_device___109 *, struct ethtool_stats *, u64 *);
	int (*get_phy_tunable)(struct net_device___109 *, const struct ethtool_tunable *, void *);
	int (*set_phy_tunable)(struct net_device___109 *, const struct ethtool_tunable *, const void *);
	int (*get_module_eeprom_by_page)(struct net_device___109 *, const struct ethtool_module_eeprom *, struct netlink_ext_ack *);
	void (*get_eth_phy_stats)(struct net_device___109 *, struct ethtool_eth_phy_stats *);
	void (*get_eth_mac_stats)(struct net_device___109 *, struct ethtool_eth_mac_stats *);
	void (*get_eth_ctrl_stats)(struct net_device___109 *, struct ethtool_eth_ctrl_stats *);
	void (*get_rmon_stats)(struct net_device___109 *, struct ethtool_rmon_stats *, const struct ethtool_rmon_hist_range **);
};

enum nl80211_iftype {
	NL80211_IFTYPE_UNSPECIFIED = 0,
	NL80211_IFTYPE_ADHOC = 1,
	NL80211_IFTYPE_STATION = 2,
	NL80211_IFTYPE_AP = 3,
	NL80211_IFTYPE_AP_VLAN = 4,
	NL80211_IFTYPE_WDS = 5,
	NL80211_IFTYPE_MONITOR = 6,
	NL80211_IFTYPE_MESH_POINT = 7,
	NL80211_IFTYPE_P2P_CLIENT = 8,
	NL80211_IFTYPE_P2P_GO = 9,
	NL80211_IFTYPE_P2P_DEVICE = 10,
	NL80211_IFTYPE_OCB = 11,
	NL80211_IFTYPE_NAN = 12,
	NUM_NL80211_IFTYPES = 13,
	NL80211_IFTYPE_MAX = 12,
};

struct cfg80211_conn;

struct cfg80211_cached_keys;

enum ieee80211_bss_type {
	IEEE80211_BSS_TYPE_ESS = 0,
	IEEE80211_BSS_TYPE_PBSS = 1,
	IEEE80211_BSS_TYPE_IBSS = 2,
	IEEE80211_BSS_TYPE_MBSS = 3,
	IEEE80211_BSS_TYPE_ANY = 4,
};

struct cfg80211_internal_bss;

enum nl80211_chan_width {
	NL80211_CHAN_WIDTH_20_NOHT = 0,
	NL80211_CHAN_WIDTH_20 = 1,
	NL80211_CHAN_WIDTH_40 = 2,
	NL80211_CHAN_WIDTH_80 = 3,
	NL80211_CHAN_WIDTH_80P80 = 4,
	NL80211_CHAN_WIDTH_160 = 5,
	NL80211_CHAN_WIDTH_5 = 6,
	NL80211_CHAN_WIDTH_10 = 7,
	NL80211_CHAN_WIDTH_1 = 8,
	NL80211_CHAN_WIDTH_2 = 9,
	NL80211_CHAN_WIDTH_4 = 10,
	NL80211_CHAN_WIDTH_8 = 11,
	NL80211_CHAN_WIDTH_16 = 12,
};

enum ieee80211_edmg_bw_config {
	IEEE80211_EDMG_BW_CONFIG_4 = 4,
	IEEE80211_EDMG_BW_CONFIG_5 = 5,
	IEEE80211_EDMG_BW_CONFIG_6 = 6,
	IEEE80211_EDMG_BW_CONFIG_7 = 7,
	IEEE80211_EDMG_BW_CONFIG_8 = 8,
	IEEE80211_EDMG_BW_CONFIG_9 = 9,
	IEEE80211_EDMG_BW_CONFIG_10 = 10,
	IEEE80211_EDMG_BW_CONFIG_11 = 11,
	IEEE80211_EDMG_BW_CONFIG_12 = 12,
	IEEE80211_EDMG_BW_CONFIG_13 = 13,
	IEEE80211_EDMG_BW_CONFIG_14 = 14,
	IEEE80211_EDMG_BW_CONFIG_15 = 15,
};

struct ieee80211_edmg {
	u8 channels;
	enum ieee80211_edmg_bw_config bw_config;
};

struct ieee80211_channel;

struct cfg80211_chan_def {
	struct ieee80211_channel *chan;
	enum nl80211_chan_width width;
	u32 center_freq1;
	u32 center_freq2;
	struct ieee80211_edmg edmg;
	u16 freq1_offset;
};

struct ieee80211_mcs_info {
	u8 rx_mask[10];
	__le16 rx_highest;
	u8 tx_params;
	u8 reserved[3];
};

struct ieee80211_ht_cap {
	__le16 cap_info;
	u8 ampdu_params_info;
	struct ieee80211_mcs_info mcs;
	__le16 extended_ht_cap_info;
	__le32 tx_BF_cap_info;
	u8 antenna_selection_info;
} __attribute__((packed));

struct key_params;

struct cfg80211_ibss_params {
	const u8 *ssid;
	const u8 *bssid;
	struct cfg80211_chan_def chandef;
	const u8 *ie;
	u8 ssid_len;
	u8 ie_len;
	u16 beacon_interval;
	u32 basic_rates;
	bool channel_fixed;
	bool privacy;
	bool control_port;
	bool control_port_over_nl80211;
	bool userspace_handles_dfs;
	int: 24;
	int mcast_rate[5];
	struct ieee80211_ht_cap ht_capa;
	struct ieee80211_ht_cap ht_capa_mask;
	struct key_params *wep_keys;
	int wep_tx_key;
	int: 32;
} __attribute__((packed));

enum nl80211_auth_type {
	NL80211_AUTHTYPE_OPEN_SYSTEM = 0,
	NL80211_AUTHTYPE_SHARED_KEY = 1,
	NL80211_AUTHTYPE_FT = 2,
	NL80211_AUTHTYPE_NETWORK_EAP = 3,
	NL80211_AUTHTYPE_SAE = 4,
	NL80211_AUTHTYPE_FILS_SK = 5,
	NL80211_AUTHTYPE_FILS_SK_PFS = 6,
	NL80211_AUTHTYPE_FILS_PK = 7,
	__NL80211_AUTHTYPE_NUM = 8,
	NL80211_AUTHTYPE_MAX = 7,
	NL80211_AUTHTYPE_AUTOMATIC = 8,
};

enum nl80211_mfp {
	NL80211_MFP_NO = 0,
	NL80211_MFP_REQUIRED = 1,
	NL80211_MFP_OPTIONAL = 2,
};

enum nl80211_sae_pwe_mechanism {
	NL80211_SAE_PWE_UNSPECIFIED = 0,
	NL80211_SAE_PWE_HUNT_AND_PECK = 1,
	NL80211_SAE_PWE_HASH_TO_ELEMENT = 2,
	NL80211_SAE_PWE_BOTH = 3,
};

struct cfg80211_crypto_settings {
	u32 wpa_versions;
	u32 cipher_group;
	int n_ciphers_pairwise;
	u32 ciphers_pairwise[5];
	int n_akm_suites;
	u32 akm_suites[2];
	bool control_port;
	__be16 control_port_ethertype;
	bool control_port_no_encrypt;
	bool control_port_over_nl80211;
	bool control_port_no_preauth;
	struct key_params *wep_keys;
	int wep_tx_key;
	const u8 *psk;
	const u8 *sae_pwd;
	u8 sae_pwd_len;
	enum nl80211_sae_pwe_mechanism sae_pwe;
};

struct ieee80211_vht_mcs_info {
	__le16 rx_mcs_map;
	__le16 rx_highest;
	__le16 tx_mcs_map;
	__le16 tx_highest;
};

struct ieee80211_vht_cap {
	__le32 vht_cap_info;
	struct ieee80211_vht_mcs_info supp_mcs;
};

enum nl80211_bss_select_attr {
	__NL80211_BSS_SELECT_ATTR_INVALID = 0,
	NL80211_BSS_SELECT_ATTR_RSSI = 1,
	NL80211_BSS_SELECT_ATTR_BAND_PREF = 2,
	NL80211_BSS_SELECT_ATTR_RSSI_ADJUST = 3,
	__NL80211_BSS_SELECT_ATTR_AFTER_LAST = 4,
	NL80211_BSS_SELECT_ATTR_MAX = 3,
};

enum nl80211_band {
	NL80211_BAND_2GHZ = 0,
	NL80211_BAND_5GHZ = 1,
	NL80211_BAND_60GHZ = 2,
	NL80211_BAND_6GHZ = 3,
	NL80211_BAND_S1GHZ = 4,
	NUM_NL80211_BANDS = 5,
};

struct cfg80211_bss_select_adjust {
	enum nl80211_band band;
	s8 delta;
};

struct cfg80211_bss_selection {
	enum nl80211_bss_select_attr behaviour;
	union {
		enum nl80211_band band_pref;
		struct cfg80211_bss_select_adjust adjust;
	} param;
};

struct cfg80211_connect_params {
	struct ieee80211_channel *channel;
	struct ieee80211_channel *channel_hint;
	const u8 *bssid;
	const u8 *bssid_hint;
	const u8 *ssid;
	size_t ssid_len;
	enum nl80211_auth_type auth_type;
	int: 32;
	const u8 *ie;
	size_t ie_len;
	bool privacy;
	int: 24;
	enum nl80211_mfp mfp;
	struct cfg80211_crypto_settings crypto;
	const u8 *key;
	u8 key_len;
	u8 key_idx;
	short: 16;
	u32 flags;
	int bg_scan_period;
	struct ieee80211_ht_cap ht_capa;
	struct ieee80211_ht_cap ht_capa_mask;
	struct ieee80211_vht_cap vht_capa;
	struct ieee80211_vht_cap vht_capa_mask;
	bool pbss;
	int: 24;
	struct cfg80211_bss_selection bss_select;
	const u8 *prev_bssid;
	const u8 *fils_erp_username;
	size_t fils_erp_username_len;
	const u8 *fils_erp_realm;
	size_t fils_erp_realm_len;
	u16 fils_erp_next_seq_num;
	long: 48;
	const u8 *fils_erp_rrk;
	size_t fils_erp_rrk_len;
	bool want_1x;
	int: 24;
	struct ieee80211_edmg edmg;
	int: 32;
} __attribute__((packed));

struct cfg80211_cqm_config;

struct wiphy;

struct wireless_dev {
	struct wiphy *wiphy;
	enum nl80211_iftype iftype;
	struct list_head list;
	struct net_device___109 *netdev;
	u32 identifier;
	struct list_head mgmt_registrations;
	u8 mgmt_registrations_need_update: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mtx;
	bool use_4addr;
	bool is_running;
	bool registered;
	bool registering;
	u8 address[6];
	u8 ssid[32];
	u8 ssid_len;
	u8 mesh_id_len;
	u8 mesh_id_up_len;
	struct cfg80211_conn *conn;
	struct cfg80211_cached_keys *connect_keys;
	enum ieee80211_bss_type conn_bss_type;
	u32 conn_owner_nlportid;
	struct work_struct disconnect_wk;
	u8 disconnect_bssid[6];
	struct list_head event_list;
	spinlock_t event_lock;
	struct cfg80211_internal_bss *current_bss;
	struct cfg80211_chan_def preset_chandef;
	struct cfg80211_chan_def chandef;
	bool ibss_fixed;
	bool ibss_dfs_possible;
	bool ps;
	int ps_timeout;
	int beacon_interval;
	u32 ap_unexpected_nlportid;
	u32 owner_nlportid;
	bool nl_owner_dead;
	bool cac_started;
	long unsigned int cac_start_time;
	unsigned int cac_time_ms;
	struct {
		struct cfg80211_ibss_params ibss;
		struct cfg80211_connect_params connect;
		struct cfg80211_cached_keys *keys;
		const u8 *ie;
		size_t ie_len;
		u8 bssid[6];
		u8 prev_bssid[6];
		u8 ssid[32];
		s8 default_key;
		s8 default_mgmt_key;
		bool prev_bssid_valid;
	} wext;
	struct cfg80211_cqm_config *cqm_config;
	struct list_head pmsr_list;
	spinlock_t pmsr_lock;
	struct work_struct pmsr_free_wk;
	long unsigned int unprot_beacon_reported;
};

struct iw_encode_ext {
	__u32 ext_flags;
	__u8 tx_seq[8];
	__u8 rx_seq[8];
	struct sockaddr addr;
	__u16 alg;
	__u16 key_len;
	__u8 key[0];
};

struct iwreq {
	union {
		char ifrn_name[16];
	} ifr_ifrn;
	union iwreq_data u;
};

struct iw_event {
	__u16 len;
	__u16 cmd;
	union iwreq_data u;
};

struct compat_iw_point {
	compat_caddr_t pointer;
	__u16 length;
	__u16 flags;
};

struct __compat_iw_event {
	__u16 len;
	__u16 cmd;
	compat_caddr_t pointer;
};

enum nl80211_reg_initiator {
	NL80211_REGDOM_SET_BY_CORE = 0,
	NL80211_REGDOM_SET_BY_USER = 1,
	NL80211_REGDOM_SET_BY_DRIVER = 2,
	NL80211_REGDOM_SET_BY_COUNTRY_IE = 3,
};

enum nl80211_dfs_regions {
	NL80211_DFS_UNSET = 0,
	NL80211_DFS_FCC = 1,
	NL80211_DFS_ETSI = 2,
	NL80211_DFS_JP = 3,
};

enum nl80211_user_reg_hint_type {
	NL80211_USER_REG_HINT_USER = 0,
	NL80211_USER_REG_HINT_CELL_BASE = 1,
	NL80211_USER_REG_HINT_INDOOR = 2,
};

enum nl80211_mntr_flags {
	__NL80211_MNTR_FLAG_INVALID = 0,
	NL80211_MNTR_FLAG_FCSFAIL = 1,
	NL80211_MNTR_FLAG_PLCPFAIL = 2,
	NL80211_MNTR_FLAG_CONTROL = 3,
	NL80211_MNTR_FLAG_OTHER_BSS = 4,
	NL80211_MNTR_FLAG_COOK_FRAMES = 5,
	NL80211_MNTR_FLAG_ACTIVE = 6,
	__NL80211_MNTR_FLAG_AFTER_LAST = 7,
	NL80211_MNTR_FLAG_MAX = 6,
};

enum nl80211_key_mode {
	NL80211_KEY_RX_TX = 0,
	NL80211_KEY_NO_TX = 1,
	NL80211_KEY_SET_TX = 2,
};

enum nl80211_bss_scan_width {
	NL80211_BSS_CHAN_WIDTH_20 = 0,
	NL80211_BSS_CHAN_WIDTH_10 = 1,
	NL80211_BSS_CHAN_WIDTH_5 = 2,
	NL80211_BSS_CHAN_WIDTH_1 = 3,
	NL80211_BSS_CHAN_WIDTH_2 = 4,
};

struct nl80211_wowlan_tcp_data_seq {
	__u32 start;
	__u32 offset;
	__u32 len;
};

struct nl80211_wowlan_tcp_data_token {
	__u32 offset;
	__u32 len;
	__u8 token_stream[0];
};

struct nl80211_wowlan_tcp_data_token_feature {
	__u32 min_len;
	__u32 max_len;
	__u32 bufsize;
};

enum nl80211_ext_feature_index {
	NL80211_EXT_FEATURE_VHT_IBSS = 0,
	NL80211_EXT_FEATURE_RRM = 1,
	NL80211_EXT_FEATURE_MU_MIMO_AIR_SNIFFER = 2,
	NL80211_EXT_FEATURE_SCAN_START_TIME = 3,
	NL80211_EXT_FEATURE_BSS_PARENT_TSF = 4,
	NL80211_EXT_FEATURE_SET_SCAN_DWELL = 5,
	NL80211_EXT_FEATURE_BEACON_RATE_LEGACY = 6,
	NL80211_EXT_FEATURE_BEACON_RATE_HT = 7,
	NL80211_EXT_FEATURE_BEACON_RATE_VHT = 8,
	NL80211_EXT_FEATURE_FILS_STA = 9,
	NL80211_EXT_FEATURE_MGMT_TX_RANDOM_TA = 10,
	NL80211_EXT_FEATURE_MGMT_TX_RANDOM_TA_CONNECTED = 11,
	NL80211_EXT_FEATURE_SCHED_SCAN_RELATIVE_RSSI = 12,
	NL80211_EXT_FEATURE_CQM_RSSI_LIST = 13,
	NL80211_EXT_FEATURE_FILS_SK_OFFLOAD = 14,
	NL80211_EXT_FEATURE_4WAY_HANDSHAKE_STA_PSK = 15,
	NL80211_EXT_FEATURE_4WAY_HANDSHAKE_STA_1X = 16,
	NL80211_EXT_FEATURE_FILS_MAX_CHANNEL_TIME = 17,
	NL80211_EXT_FEATURE_ACCEPT_BCAST_PROBE_RESP = 18,
	NL80211_EXT_FEATURE_OCE_PROBE_REQ_HIGH_TX_RATE = 19,
	NL80211_EXT_FEATURE_OCE_PROBE_REQ_DEFERRAL_SUPPRESSION = 20,
	NL80211_EXT_FEATURE_MFP_OPTIONAL = 21,
	NL80211_EXT_FEATURE_LOW_SPAN_SCAN = 22,
	NL80211_EXT_FEATURE_LOW_POWER_SCAN = 23,
	NL80211_EXT_FEATURE_HIGH_ACCURACY_SCAN = 24,
	NL80211_EXT_FEATURE_DFS_OFFLOAD = 25,
	NL80211_EXT_FEATURE_CONTROL_PORT_OVER_NL80211 = 26,
	NL80211_EXT_FEATURE_ACK_SIGNAL_SUPPORT = 27,
	NL80211_EXT_FEATURE_DATA_ACK_SIGNAL_SUPPORT = 27,
	NL80211_EXT_FEATURE_TXQS = 28,
	NL80211_EXT_FEATURE_SCAN_RANDOM_SN = 29,
	NL80211_EXT_FEATURE_SCAN_MIN_PREQ_CONTENT = 30,
	NL80211_EXT_FEATURE_CAN_REPLACE_PTK0 = 31,
	NL80211_EXT_FEATURE_ENABLE_FTM_RESPONDER = 32,
	NL80211_EXT_FEATURE_AIRTIME_FAIRNESS = 33,
	NL80211_EXT_FEATURE_AP_PMKSA_CACHING = 34,
	NL80211_EXT_FEATURE_SCHED_SCAN_BAND_SPECIFIC_RSSI_THOLD = 35,
	NL80211_EXT_FEATURE_EXT_KEY_ID = 36,
	NL80211_EXT_FEATURE_STA_TX_PWR = 37,
	NL80211_EXT_FEATURE_SAE_OFFLOAD = 38,
	NL80211_EXT_FEATURE_VLAN_OFFLOAD = 39,
	NL80211_EXT_FEATURE_AQL = 40,
	NL80211_EXT_FEATURE_BEACON_PROTECTION = 41,
	NL80211_EXT_FEATURE_CONTROL_PORT_NO_PREAUTH = 42,
	NL80211_EXT_FEATURE_PROTECTED_TWT = 43,
	NL80211_EXT_FEATURE_DEL_IBSS_STA = 44,
	NL80211_EXT_FEATURE_MULTICAST_REGISTRATIONS = 45,
	NL80211_EXT_FEATURE_BEACON_PROTECTION_CLIENT = 46,
	NL80211_EXT_FEATURE_SCAN_FREQ_KHZ = 47,
	NL80211_EXT_FEATURE_CONTROL_PORT_OVER_NL80211_TX_STATUS = 48,
	NL80211_EXT_FEATURE_OPERATING_CHANNEL_VALIDATION = 49,
	NL80211_EXT_FEATURE_4WAY_HANDSHAKE_AP_PSK = 50,
	NL80211_EXT_FEATURE_SAE_OFFLOAD_AP = 51,
	NL80211_EXT_FEATURE_FILS_DISCOVERY = 52,
	NL80211_EXT_FEATURE_UNSOL_BCAST_PROBE_RESP = 53,
	NL80211_EXT_FEATURE_BEACON_RATE_HE = 54,
	NL80211_EXT_FEATURE_SECURE_LTF = 55,
	NL80211_EXT_FEATURE_SECURE_RTT = 56,
	NL80211_EXT_FEATURE_PROT_RANGE_NEGO_AND_MEASURE = 57,
	NL80211_EXT_FEATURE_BSS_COLOR = 58,
	NUM_NL80211_EXT_FEATURES = 59,
	MAX_NL80211_EXT_FEATURES = 58,
};

enum nl80211_dfs_state {
	NL80211_DFS_USABLE = 0,
	NL80211_DFS_UNAVAILABLE = 1,
	NL80211_DFS_AVAILABLE = 2,
};

struct nl80211_vendor_cmd_info {
	__u32 vendor_id;
	__u32 subcmd;
};

enum nl80211_sar_type {
	NL80211_SAR_TYPE_POWER = 0,
	NUM_NL80211_SAR_TYPE = 1,
};

struct ieee80211_he_cap_elem {
	u8 mac_cap_info[6];
	u8 phy_cap_info[11];
};

struct ieee80211_he_mcs_nss_supp {
	__le16 rx_mcs_80;
	__le16 tx_mcs_80;
	__le16 rx_mcs_160;
	__le16 tx_mcs_160;
	__le16 rx_mcs_80p80;
	__le16 tx_mcs_80p80;
};

struct ieee80211_he_6ghz_capa {
	__le16 capa;
};

struct rfkill;

enum environment_cap {
	ENVIRON_ANY = 0,
	ENVIRON_INDOOR = 1,
	ENVIRON_OUTDOOR = 2,
};

struct regulatory_request {
	struct callback_head callback_head;
	int wiphy_idx;
	enum nl80211_reg_initiator initiator;
	enum nl80211_user_reg_hint_type user_reg_hint_type;
	char alpha2[3];
	enum nl80211_dfs_regions dfs_region;
	bool intersect;
	bool processed;
	enum environment_cap country_ie_env;
	struct list_head list;
};

struct ieee80211_freq_range {
	u32 start_freq_khz;
	u32 end_freq_khz;
	u32 max_bandwidth_khz;
};

struct ieee80211_power_rule {
	u32 max_antenna_gain;
	u32 max_eirp;
};

struct ieee80211_wmm_ac {
	u16 cw_min;
	u16 cw_max;
	u16 cot;
	u8 aifsn;
};

struct ieee80211_wmm_rule {
	struct ieee80211_wmm_ac client[4];
	struct ieee80211_wmm_ac ap[4];
};

struct ieee80211_reg_rule {
	struct ieee80211_freq_range freq_range;
	struct ieee80211_power_rule power_rule;
	struct ieee80211_wmm_rule wmm_rule;
	u32 flags;
	u32 dfs_cac_ms;
	bool has_wmm;
};

struct ieee80211_regdomain {
	struct callback_head callback_head;
	u32 n_reg_rules;
	char alpha2[3];
	enum nl80211_dfs_regions dfs_region;
	struct ieee80211_reg_rule reg_rules[0];
};

struct ieee80211_channel {
	enum nl80211_band band;
	u32 center_freq;
	u16 freq_offset;
	u16 hw_value;
	u32 flags;
	int max_antenna_gain;
	int max_power;
	int max_reg_power;
	bool beacon_found;
	u32 orig_flags;
	int orig_mag;
	int orig_mpwr;
	enum nl80211_dfs_state dfs_state;
	long unsigned int dfs_state_entered;
	unsigned int dfs_cac_ms;
};

struct ieee80211_rate {
	u32 flags;
	u16 bitrate;
	u16 hw_value;
	u16 hw_value_short;
};

struct ieee80211_sta_ht_cap {
	u16 cap;
	bool ht_supported;
	u8 ampdu_factor;
	u8 ampdu_density;
	struct ieee80211_mcs_info mcs;
	char: 8;
} __attribute__((packed));

struct ieee80211_sta_vht_cap {
	bool vht_supported;
	u32 cap;
	struct ieee80211_vht_mcs_info vht_mcs;
};

struct ieee80211_sta_he_cap {
	bool has_he;
	struct ieee80211_he_cap_elem he_cap_elem;
	struct ieee80211_he_mcs_nss_supp he_mcs_nss_supp;
	u8 ppe_thres[25];
} __attribute__((packed));

struct ieee80211_sband_iftype_data {
	u16 types_mask;
	struct ieee80211_sta_he_cap he_cap;
	struct ieee80211_he_6ghz_capa he_6ghz_capa;
	long: 40;
	struct {
		const u8 *data;
		unsigned int len;
	} vendor_elems;
} __attribute__((packed));

struct ieee80211_sta_s1g_cap {
	bool s1g;
	u8 cap[10];
	u8 nss_mcs[5];
};

struct ieee80211_supported_band {
	struct ieee80211_channel *channels;
	struct ieee80211_rate *bitrates;
	enum nl80211_band band;
	int n_channels;
	int n_bitrates;
	struct ieee80211_sta_ht_cap ht_cap;
	struct ieee80211_sta_vht_cap vht_cap;
	struct ieee80211_sta_s1g_cap s1g_cap;
	struct ieee80211_edmg edmg_cap;
	u16 n_iftype_data;
	const struct ieee80211_sband_iftype_data *iftype_data;
};

struct key_params {
	const u8 *key;
	const u8 *seq;
	int key_len;
	int seq_len;
	u16 vlan_id;
	u32 cipher;
	enum nl80211_key_mode mode;
};

struct mac_address___2 {
	u8 addr[6];
};

struct cfg80211_sar_freq_ranges {
	u32 start_freq;
	u32 end_freq;
};

struct cfg80211_sar_capa {
	enum nl80211_sar_type type;
	u32 num_freq_ranges;
	const struct cfg80211_sar_freq_ranges *freq_ranges;
};

struct cfg80211_ssid {
	u8 ssid[32];
	u8 ssid_len;
};

enum cfg80211_signal_type {
	CFG80211_SIGNAL_TYPE_NONE = 0,
	CFG80211_SIGNAL_TYPE_MBM = 1,
	CFG80211_SIGNAL_TYPE_UNSPEC = 2,
};

struct ieee80211_txrx_stypes;

struct ieee80211_iface_combination;

struct wiphy_iftype_akm_suites;

struct wiphy_wowlan_support;

struct cfg80211_wowlan;

struct wiphy_iftype_ext_capab;

struct wiphy_coalesce_support;

struct wiphy_vendor_command;

struct cfg80211_pmsr_capabilities;

struct wiphy {
	struct mutex mtx;
	u8 perm_addr[6];
	u8 addr_mask[6];
	struct mac_address___2 *addresses;
	const struct ieee80211_txrx_stypes *mgmt_stypes;
	const struct ieee80211_iface_combination *iface_combinations;
	int n_iface_combinations;
	u16 software_iftypes;
	u16 n_addresses;
	u16 interface_modes;
	u16 max_acl_mac_addrs;
	u32 flags;
	u32 regulatory_flags;
	u32 features;
	u8 ext_features[8];
	u32 ap_sme_capa;
	enum cfg80211_signal_type signal_type;
	int bss_priv_size;
	u8 max_scan_ssids;
	u8 max_sched_scan_reqs;
	u8 max_sched_scan_ssids;
	u8 max_match_sets;
	u16 max_scan_ie_len;
	u16 max_sched_scan_ie_len;
	u32 max_sched_scan_plans;
	u32 max_sched_scan_plan_interval;
	u32 max_sched_scan_plan_iterations;
	int n_cipher_suites;
	const u32 *cipher_suites;
	int n_akm_suites;
	const u32 *akm_suites;
	const struct wiphy_iftype_akm_suites *iftype_akm_suites;
	unsigned int num_iftype_akm_suites;
	u8 retry_short;
	u8 retry_long;
	u32 frag_threshold;
	u32 rts_threshold;
	u8 coverage_class;
	char fw_version[32];
	u32 hw_version;
	const struct wiphy_wowlan_support *wowlan;
	struct cfg80211_wowlan *wowlan_config;
	u16 max_remain_on_channel_duration;
	u8 max_num_pmkids;
	u32 available_antennas_tx;
	u32 available_antennas_rx;
	u32 probe_resp_offload;
	const u8 *extended_capabilities;
	const u8 *extended_capabilities_mask;
	u8 extended_capabilities_len;
	const struct wiphy_iftype_ext_capab *iftype_ext_capab;
	unsigned int num_iftype_ext_capab;
	const void *privid;
	struct ieee80211_supported_band *bands[5];
	void (*reg_notifier)(struct wiphy *, struct regulatory_request *);
	const struct ieee80211_regdomain *regd;
	struct device___281 dev;
	bool registered;
	struct dentry___300 *debugfsdir;
	const struct ieee80211_ht_cap *ht_capa_mod_mask;
	const struct ieee80211_vht_cap *vht_capa_mod_mask;
	struct list_head wdev_list;
	possible_net_t___109 _net;
	const struct iw_handler_def___5 *wext;
	const struct wiphy_coalesce_support *coalesce;
	const struct wiphy_vendor_command *vendor_commands;
	const struct nl80211_vendor_cmd_info *vendor_events;
	int n_vendor_commands;
	int n_vendor_events;
	u16 max_ap_assoc_sta;
	u8 max_num_csa_counters;
	u32 bss_select_support;
	u8 nan_supported_bands;
	u32 txq_limit;
	u32 txq_memory_limit;
	u32 txq_quantum;
	long unsigned int tx_queue_len;
	u8 support_mbssid: 1;
	u8 support_only_he_mbssid: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct cfg80211_pmsr_capabilities *pmsr_capa;
	struct {
		u64 peer;
		u64 vif;
		u8 max_retry;
	} tid_config_support;
	u8 max_data_retry_count;
	const struct cfg80211_sar_capa *sar_capa;
	struct rfkill *rfkill;
	long: 64;
	long: 64;
	long: 64;
	char priv[0];
};

struct cfg80211_match_set {
	struct cfg80211_ssid ssid;
	u8 bssid[6];
	s32 rssi_thold;
	s32 per_band_rssi_thold[5];
};

struct cfg80211_sched_scan_plan {
	u32 interval;
	u32 iterations;
};

struct cfg80211_sched_scan_request {
	u64 reqid;
	struct cfg80211_ssid *ssids;
	int n_ssids;
	u32 n_channels;
	enum nl80211_bss_scan_width scan_width;
	const u8 *ie;
	size_t ie_len;
	u32 flags;
	struct cfg80211_match_set *match_sets;
	int n_match_sets;
	s32 min_rssi_thold;
	u32 delay;
	struct cfg80211_sched_scan_plan *scan_plans;
	int n_scan_plans;
	u8 mac_addr[6];
	u8 mac_addr_mask[6];
	bool relative_rssi_set;
	s8 relative_rssi;
	struct cfg80211_bss_select_adjust rssi_adjust;
	struct wiphy *wiphy;
	struct net_device___109 *dev;
	long unsigned int scan_start;
	bool report_results;
	struct callback_head callback_head;
	u32 owner_nlportid;
	bool nl_owner_dead;
	struct list_head list;
	struct ieee80211_channel *channels[0];
};

struct cfg80211_pkt_pattern {
	const u8 *mask;
	const u8 *pattern;
	int pattern_len;
	int pkt_offset;
};

struct cfg80211_wowlan_tcp {
	struct socket___97 *sock;
	__be32 src;
	__be32 dst;
	u16 src_port;
	u16 dst_port;
	u8 dst_mac[6];
	int payload_len;
	const u8 *payload;
	struct nl80211_wowlan_tcp_data_seq payload_seq;
	u32 data_interval;
	u32 wake_len;
	const u8 *wake_data;
	const u8 *wake_mask;
	u32 tokens_size;
	struct nl80211_wowlan_tcp_data_token payload_tok;
};

struct cfg80211_wowlan {
	bool any;
	bool disconnect;
	bool magic_pkt;
	bool gtk_rekey_failure;
	bool eap_identity_req;
	bool four_way_handshake;
	bool rfkill_release;
	struct cfg80211_pkt_pattern *patterns;
	struct cfg80211_wowlan_tcp *tcp;
	int n_patterns;
	struct cfg80211_sched_scan_request *nd_config;
};

struct ieee80211_iface_limit {
	u16 max;
	u16 types;
};

struct ieee80211_iface_combination {
	const struct ieee80211_iface_limit *limits;
	u32 num_different_channels;
	u16 max_interfaces;
	u8 n_limits;
	bool beacon_int_infra_match;
	u8 radar_detect_widths;
	u8 radar_detect_regions;
	u32 beacon_int_min_gcd;
};

struct ieee80211_txrx_stypes {
	u16 tx;
	u16 rx;
};

struct wiphy_wowlan_tcp_support {
	const struct nl80211_wowlan_tcp_data_token_feature *tok;
	u32 data_payload_max;
	u32 data_interval_max;
	u32 wake_payload_max;
	bool seq;
};

struct wiphy_wowlan_support {
	u32 flags;
	int n_patterns;
	int pattern_max_len;
	int pattern_min_len;
	int max_pkt_offset;
	int max_nd_match_sets;
	const struct wiphy_wowlan_tcp_support *tcp;
};

struct wiphy_coalesce_support {
	int n_rules;
	int max_delay;
	int n_patterns;
	int pattern_max_len;
	int pattern_min_len;
	int max_pkt_offset;
};

struct wiphy_vendor_command {
	struct nl80211_vendor_cmd_info info;
	u32 flags;
	int (*doit)(struct wiphy *, struct wireless_dev *, const void *, int);
	int (*dumpit)(struct wiphy *, struct wireless_dev *, struct sk_buff___110 *, const void *, int, long unsigned int *);
	const struct nla_policy *policy;
	unsigned int maxattr;
};

struct wiphy_iftype_ext_capab {
	enum nl80211_iftype iftype;
	const u8 *extended_capabilities;
	const u8 *extended_capabilities_mask;
	u8 extended_capabilities_len;
};

struct cfg80211_pmsr_capabilities {
	unsigned int max_peers;
	u8 report_ap_tsf: 1;
	u8 randomize_mac_addr: 1;
	long: 63;
	struct {
		u32 preambles;
		u32 bandwidths;
		s8 max_bursts_exponent;
		u8 max_ftms_per_burst;
		u8 supported: 1;
		u8 asap: 1;
		u8 non_asap: 1;
		u8 request_lci: 1;
		u8 request_civicloc: 1;
		u8 trigger_based: 1;
		u8 non_trigger_based: 1;
		long: 31;
		long: 64;
	} ftm;
};

struct wiphy_iftype_akm_suites {
	u16 iftypes_mask;
	const u32 *akm_suites;
	int n_akm_suites;
};

struct iw_ioctl_description {
	__u8 header_type;
	__u8 token_type;
	__u16 token_size;
	__u16 min_tokens;
	__u16 max_tokens;
	__u32 flags;
};

typedef int (*wext_ioctl_func)(struct net_device___109 *, struct iwreq *, unsigned int, struct iw_request_info *, iw_handler___5);

struct dentry___301;

struct super_block___301;

struct module___285;

struct file_system_type___301 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___301 * (*mount)(struct file_system_type___301 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___301 *);
	struct module___285 *owner;
	struct file_system_type___301 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___301;

struct kiocb___301;

struct iov_iter___221;

struct vm_area_struct___306;

struct inode___301;

struct file_lock___301;

struct page___306;

struct pipe_inode_info___142;

struct seq_file___276;

struct file_operations___302 {
	struct module___285 *owner;
	loff_t (*llseek)(struct file___301 *, loff_t, int);
	ssize_t (*read)(struct file___301 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___301 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___301 *, struct iov_iter___221 *);
	ssize_t (*write_iter)(struct kiocb___301 *, struct iov_iter___221 *);
	int (*iopoll)(struct kiocb___301 *, bool);
	int (*iterate)(struct file___301 *, struct dir_context *);
	int (*iterate_shared)(struct file___301 *, struct dir_context *);
	__poll_t (*poll)(struct file___301 *, struct poll_table_struct___5 *);
	long int (*unlocked_ioctl)(struct file___301 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___301 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___301 *, struct vm_area_struct___306 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___301 *, struct file___301 *);
	int (*flush)(struct file___301 *, fl_owner_t);
	int (*release)(struct inode___301 *, struct file___301 *);
	int (*fsync)(struct file___301 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___301 *, int);
	int (*lock)(struct file___301 *, int, struct file_lock___301 *);
	ssize_t (*sendpage)(struct file___301 *, struct page___306 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___301 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___301 *, long unsigned int);
	int (*flock)(struct file___301 *, int, struct file_lock___301 *);
	ssize_t (*splice_write)(struct pipe_inode_info___142 *, struct file___301 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___301 *, loff_t *, struct pipe_inode_info___142 *, size_t, unsigned int);
	int (*setlease)(struct file___301 *, long int, struct file_lock___301 **, void **);
	long int (*fallocate)(struct file___301 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___276 *, struct file___301 *);
	ssize_t (*copy_file_range)(struct file___301 *, loff_t, struct file___301 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___301 *, loff_t, struct file___301 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___301 *, loff_t, loff_t, int);
};

struct bio_vec___218 {
	struct page___306 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___301;

struct pipe_buffer___142;

struct pipe_inode_info___142 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___306 *tmp_page;
	struct fasync_struct___301 *fasync_readers;
	struct fasync_struct___301 *fasync_writers;
	struct pipe_buffer___142 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___221 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___218 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___142 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct kiocb___301 {
	struct file___301 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___301 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct iw_thrspy {
	struct sockaddr addr;
	struct iw_quality qual;
	struct iw_quality low;
	struct iw_quality high;
};

struct vmacache___306 {
	u64 seqnum;
	struct vm_area_struct___306 *vmas[4];
};

struct page_frag___306 {
	struct page___306 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___307;

struct pid___278;

struct nsproxy___287;

struct signal_struct___302;

struct css_set___228;

struct vm_struct___284;

struct task_struct___308 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___308 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___307 *mm;
	struct mm_struct___307 *active_mm;
	struct vmacache___306 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___308 *real_parent;
	struct task_struct___308 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___308 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___278 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___287 *nsproxy;
	struct signal_struct___302 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___308 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___2 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___2 *backing_dev_info;
	struct io_context___189 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___228 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___142 *splice_pipe;
	struct page_frag___306 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___2 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___2 *active_memcg;
	struct request_queue___3 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___308 *oom_reaper_list;
	struct vm_struct___284 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___289;

struct kobj_type___289;

struct kernfs_node___289;

struct kobject___289 {
	const char *name;
	struct list_head entry;
	struct kobject___289 *parent;
	struct kset___289 *kset;
	struct kobj_type___289 *ktype;
	struct kernfs_node___289 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___286 {
	struct kobject___289 kobj;
	struct module___285 *mod;
	struct kobject___289 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___285 {
	struct module___285 *mod;
	struct latch_tree_node node;
};

struct module_layout___285 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___285 mtn;
};

struct module_attribute___285;

struct kernel_param___285;

struct module___285 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___286 mkobj;
	struct module_attribute___285 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___289 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___285 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___285 core_layout;
	struct module_layout___285 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___278;

struct upid___278 {
	int nr;
	struct pid_namespace___278 *ns;
};

struct pid_namespace___278 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___308 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___278 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___278 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___278 numbers[1];
};

typedef struct page___306 *pgtable_t___306;

struct address_space___301;

struct page_pool___130;

struct dev_pagemap___296;

struct page___306 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___301 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___130 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___306 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___306 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___307 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___296 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___296;

struct vm_area_struct___306 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___306 *vm_next;
	struct vm_area_struct___306 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___307 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___296 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___301 *vm_file;
	struct file___301 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___302 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___308 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___308 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___278 *pids[4];
	struct pid___278 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___307 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___306;

struct mm_struct___307 {
	struct {
		struct vm_area_struct___306 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___301 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___306 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___308 *owner;
		struct user_namespace___26 *user_ns;
		struct file___301 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___115;

struct cgroup_namespace___228;

struct nsproxy___287 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___278 *pid_ns_for_children;
	struct net___115 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___228 *cgroup_ns;
};

struct cgroup_subsys_state___228;

struct cgroup___228;

struct css_set___228 {
	struct cgroup_subsys_state___228 *subsys[14];
	refcount_t refcount;
	struct css_set___228 *dom_cset;
	struct cgroup___228 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___228 *mg_src_cgrp;
	struct cgroup___228 *mg_dst_cgrp;
	struct css_set___228 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct vm_struct___284 {
	struct vm_struct___284 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___306 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct dentry_operations___301;

struct dentry___301 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___301 *d_parent;
	struct qstr d_name;
	struct inode___301 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___301 *d_op;
	struct super_block___301 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct address_space_operations___301;

struct address_space___301 {
	struct inode___301 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___301 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct inode_operations___301;

struct inode___301 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___301 *i_op;
	struct super_block___301 *i_sb;
	struct address_space___301 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___3 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___302 *i_fop;
		void (*free_inode)(struct inode___301 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___301 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___142 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct vfsmount___301;

struct path___301;

struct dentry_operations___301 {
	int (*d_revalidate)(struct dentry___301 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___301 *, unsigned int);
	int (*d_hash)(const struct dentry___301 *, struct qstr *);
	int (*d_compare)(const struct dentry___301 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___301 *);
	int (*d_init)(struct dentry___301 *);
	void (*d_release)(struct dentry___301 *);
	void (*d_prune)(struct dentry___301 *);
	void (*d_iput)(struct dentry___301 *, struct inode___301 *);
	char * (*d_dname)(struct dentry___301 *, char *, int);
	struct vfsmount___301 * (*d_automount)(struct path___301 *);
	int (*d_manage)(const struct path___301 *, bool);
	struct dentry___301 * (*d_real)(struct dentry___301 *, const struct inode___301 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___301;

struct mem_dqinfo___301 {
	struct quota_format_type___301 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___301;

struct quota_info___301 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___301 *files[3];
	struct mem_dqinfo___301 info[3];
	const struct quota_format_ops___301 *ops[3];
};

struct rcuwait___302 {
	struct task_struct___308 *task;
};

struct percpu_rw_semaphore___302 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___302 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___301 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___302 rw_sem[3];
};

struct super_operations___301;

struct dquot_operations___301;

struct quotactl_ops___301;

struct super_block___301 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___301 *s_type;
	const struct super_operations___301 *s_op;
	const struct dquot_operations___301 *dq_op;
	const struct quotactl_ops___301 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___301 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___5 *s_bdev;
	struct backing_dev_info___2 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___301 s_dquot;
	struct sb_writers___301 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___301 *s_d_op;
	int cleancache_poolid;
	struct shrinker___163 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___301 {
	struct dentry___301 *mnt_root;
	struct super_block___301 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct path___301 {
	struct vfsmount___301 *mnt;
	struct dentry___301 *dentry;
};

struct device___282;

struct page_pool_params___130 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___282 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___130 {
	u32 count;
	struct page___306 *cache[128];
};

struct page_pool___130 {
	struct page_pool_params___130 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___306 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___130 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___296;

struct dev_pagemap___296 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___296 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct fown_struct___278 {
	rwlock_t lock;
	struct pid___278 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___301 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___301 f_path;
	struct inode___301 *f_inode;
	const struct file_operations___302 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___278 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___301 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___296;

struct vm_operations_struct___296 {
	void (*open)(struct vm_area_struct___306 *);
	void (*close)(struct vm_area_struct___306 *);
	int (*may_split)(struct vm_area_struct___306 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___306 *);
	int (*mprotect)(struct vm_area_struct___306 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___296 *);
	vm_fault_t (*huge_fault)(struct vm_fault___296 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___296 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___306 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___296 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___296 *);
	int (*access)(struct vm_area_struct___306 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___306 *);
	int (*set_policy)(struct vm_area_struct___306 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___306 *, long unsigned int);
	struct page___306 * (*find_special_page)(struct vm_area_struct___306 *, long unsigned int);
};

struct core_thread___306 {
	struct task_struct___308 *task;
	struct core_thread___306 *next;
};

struct core_state___306 {
	atomic_t nr_threads;
	struct core_thread___306 dumper;
	struct completion startup;
};

struct vm_fault___296 {
	const struct {
		struct vm_area_struct___306 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___306 *cow_page;
	struct page___306 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___306 prealloc_pte;
};

struct cgroup_subsys___228;

struct cgroup_subsys_state___228 {
	struct cgroup___228 *cgroup;
	struct cgroup_subsys___228 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___228 *parent;
};

struct cgroup_file___228 {
	struct kernfs_node___289 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct psi_group___228 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___308 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_root___228;

struct cgroup_rstat_cpu___228;

struct cgroup___228 {
	struct cgroup_subsys_state___228 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___289 *kn;
	struct cgroup_file___228 procs_file;
	struct cgroup_file___228 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___228 *subsys[14];
	struct cgroup_root___228 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___228 *dom_cgrp;
	struct cgroup___228 *old_dom_cgrp;
	struct cgroup_rstat_cpu___228 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___228 psi;
	struct cgroup_bpf___101 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct iattr___301 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___301 *ia_file;
};

struct dquot___301 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___301 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___301 {
	int qf_fmt_id;
	const struct quota_format_ops___301 *qf_ops;
	struct module___285 *qf_owner;
	struct quota_format_type___301 *qf_next;
};

struct quota_format_ops___301 {
	int (*check_quota_file)(struct super_block___301 *, int);
	int (*read_file_info)(struct super_block___301 *, int);
	int (*write_file_info)(struct super_block___301 *, int);
	int (*free_file_info)(struct super_block___301 *, int);
	int (*read_dqblk)(struct dquot___301 *);
	int (*commit_dqblk)(struct dquot___301 *);
	int (*release_dqblk)(struct dquot___301 *);
	int (*get_next_id)(struct super_block___301 *, struct kqid *);
};

struct dquot_operations___301 {
	int (*write_dquot)(struct dquot___301 *);
	struct dquot___301 * (*alloc_dquot)(struct super_block___301 *, int);
	void (*destroy_dquot)(struct dquot___301 *);
	int (*acquire_dquot)(struct dquot___301 *);
	int (*release_dquot)(struct dquot___301 *);
	int (*mark_dirty)(struct dquot___301 *);
	int (*write_info)(struct super_block___301 *, int);
	qsize_t * (*get_reserved_space)(struct inode___301 *);
	int (*get_projid)(struct inode___301 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___301 *, qsize_t *);
	int (*get_next_id)(struct super_block___301 *, struct kqid *);
};

struct quotactl_ops___301 {
	int (*quota_on)(struct super_block___301 *, int, int, const struct path___301 *);
	int (*quota_off)(struct super_block___301 *, int);
	int (*quota_enable)(struct super_block___301 *, unsigned int);
	int (*quota_disable)(struct super_block___301 *, unsigned int);
	int (*quota_sync)(struct super_block___301 *, int);
	int (*set_info)(struct super_block___301 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___301 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___301 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___301 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___301 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___301 *, unsigned int);
};

struct address_space_operations___301 {
	int (*writepage)(struct page___306 *, struct writeback_control___3 *);
	int (*readpage)(struct file___301 *, struct page___306 *);
	int (*writepages)(struct address_space___301 *, struct writeback_control___3 *);
	int (*set_page_dirty)(struct page___306 *);
	int (*readpages)(struct file___301 *, struct address_space___301 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___301 *, struct address_space___301 *, loff_t, unsigned int, unsigned int, struct page___306 **, void **);
	int (*write_end)(struct file___301 *, struct address_space___301 *, loff_t, unsigned int, unsigned int, struct page___306 *, void *);
	sector_t (*bmap)(struct address_space___301 *, sector_t);
	void (*invalidatepage)(struct page___306 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___306 *, gfp_t);
	void (*freepage)(struct page___306 *);
	ssize_t (*direct_IO)(struct kiocb___301 *, struct iov_iter___221 *);
	int (*migratepage)(struct address_space___301 *, struct page___306 *, struct page___306 *, enum migrate_mode);
	bool (*isolate_page)(struct page___306 *, isolate_mode_t);
	void (*putback_page)(struct page___306 *);
	int (*launder_page)(struct page___306 *);
	int (*is_partially_uptodate)(struct page___306 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___306 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___301 *, struct page___306 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___301 *, sector_t *);
	void (*swap_deactivate)(struct file___301 *);
};

struct inode_operations___301 {
	struct dentry___301 * (*lookup)(struct inode___301 *, struct dentry___301 *, unsigned int);
	const char * (*get_link)(struct dentry___301 *, struct inode___301 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___301 *, int);
	struct posix_acl * (*get_acl)(struct inode___301 *, int, bool);
	int (*readlink)(struct dentry___301 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___301 *, struct dentry___301 *, umode_t, bool);
	int (*link)(struct dentry___301 *, struct inode___301 *, struct dentry___301 *);
	int (*unlink)(struct inode___301 *, struct dentry___301 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___301 *, struct dentry___301 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___301 *, struct dentry___301 *, umode_t);
	int (*rmdir)(struct inode___301 *, struct dentry___301 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___301 *, struct dentry___301 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___301 *, struct dentry___301 *, struct inode___301 *, struct dentry___301 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___301 *, struct iattr___301 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___301 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___301 *, char *, size_t);
	int (*fiemap)(struct inode___301 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___301 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___301 *, struct dentry___301 *, struct file___301 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___301 *, struct dentry___301 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___301 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___301 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___301 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___301 {
	void (*fl_copy_lock)(struct file_lock___301 *, struct file_lock___301 *);
	void (*fl_release_private)(struct file_lock___301 *);
};

struct lock_manager_operations___301;

struct file_lock___301 {
	struct file_lock___301 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___301 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___301 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___301 *fl_ops;
	const struct lock_manager_operations___301 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___301 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___301 *);
	int (*lm_grant)(struct file_lock___301 *, int);
	bool (*lm_break)(struct file_lock___301 *);
	int (*lm_change)(struct file_lock___301 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___301 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___301 *);
};

struct fasync_struct___301 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___301 *fa_next;
	struct file___301 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___301 {
	struct inode___301 * (*alloc_inode)(struct super_block___301 *);
	void (*destroy_inode)(struct inode___301 *);
	void (*free_inode)(struct inode___301 *);
	void (*dirty_inode)(struct inode___301 *, int);
	int (*write_inode)(struct inode___301 *, struct writeback_control___3 *);
	int (*drop_inode)(struct inode___301 *);
	void (*evict_inode)(struct inode___301 *);
	void (*put_super)(struct super_block___301 *);
	int (*sync_fs)(struct super_block___301 *, int);
	int (*freeze_super)(struct super_block___301 *);
	int (*freeze_fs)(struct super_block___301 *);
	int (*thaw_super)(struct super_block___301 *);
	int (*unfreeze_fs)(struct super_block___301 *);
	int (*statfs)(struct dentry___301 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___301 *, int *, char *);
	void (*umount_begin)(struct super_block___301 *);
	int (*show_options)(struct seq_file___276 *, struct dentry___301 *);
	int (*show_devname)(struct seq_file___276 *, struct dentry___301 *);
	int (*show_path)(struct seq_file___276 *, struct dentry___301 *);
	int (*show_stats)(struct seq_file___276 *, struct dentry___301 *);
	ssize_t (*quota_read)(struct super_block___301 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___301 *, int, const char *, size_t, loff_t);
	struct dquot___301 ** (*get_dquots)(struct inode___301 *);
	long int (*nr_cached_objects)(struct super_block___301 *, struct shrink_control___163 *);
	long int (*free_cached_objects)(struct super_block___301 *, struct shrink_control___163 *);
	struct file___301 * (*real_loop)(struct file___301 *);
};

struct seq_operations___276;

struct seq_file___276 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___276 *op;
	int poll_event;
	const struct file___301 *file;
	void *private;
};

struct net_device___110;

struct sk_buff___111 {
	union {
		struct {
			struct sk_buff___111 *next;
			struct sk_buff___111 *prev;
			union {
				struct net_device___110 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___94 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___111 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___115;

struct fqdir___115 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___115 *f;
	struct net___115 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___115;

struct inet_frags___115 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___115 *, const void *);
	void (*destructor)(struct inet_frag_queue___115 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct netns_ipv4___115 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock *fibnl;
	struct sock **icmp_sk;
	struct sock *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock **tcp_sk;
	struct fqdir___115 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___95;

struct dst_ops___115 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___115 *);
	struct dst_entry * (*check)(struct dst_entry *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry *);
	unsigned int (*mtu)(const struct dst_entry *);
	u32 * (*cow_metrics)(struct dst_entry *, long unsigned int);
	void (*destroy)(struct dst_entry *);
	void (*ifdown)(struct dst_entry *, struct net_device___110 *, int);
	struct dst_entry * (*negative_advice)(struct dst_entry *);
	void (*link_failure)(struct sk_buff___111 *);
	void (*update_pmtu)(struct dst_entry *, struct sock *, struct sk_buff___111 *, u32, bool);
	void (*redirect)(struct dst_entry *, struct sock *, struct sk_buff___111 *);
	int (*local_out)(struct net___115 *, struct sock *, struct sk_buff___111 *);
	struct neighbour___95 * (*neigh_lookup)(const struct dst_entry *, struct sk_buff___111 *, const void *);
	void (*confirm_neigh)(const struct dst_entry *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___115 {
	struct dst_ops___115 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___115 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops *fib6_rules_ops;
	struct sock **icmp_sk;
	struct sock *ndisc_sk;
	struct sock *tcp_sk;
	struct sock *igmp_sk;
	struct sock *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops *notifier_ops;
	struct fib_notifier_ops *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___115 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___115 *fqdir;
};

struct sk_buff_head___110 {
	struct sk_buff___111 *next;
	struct sk_buff___111 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct netns_xfrm___115 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock *nlsk;
	struct sock *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___115 xfrm4_dst_ops;
	struct dst_ops___115 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___115 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock *rtnl;
	struct sock *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___110 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___115 ipv4;
	struct netns_ipv6___115 ipv6;
	struct netns_ieee802154_lowpan___115 ieee802154_lowpan;
	struct netns_sctp___94 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___110 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___101 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___115 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock *crypto_nlsk;
	struct sock *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___115 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___111 *fragments_tail;
	struct sk_buff___111 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___115 *fqdir;
	struct callback_head rcu;
};

typedef rx_handler_result_t rx_handler_func_t___110(struct sk_buff___111 **);

typedef struct {
	struct net___115 *net;
} possible_net_t___110;

struct wakeup_source___282;

struct dev_pm_info___282 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___282 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___282 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___282;

struct bus_type___282;

struct device_driver___282;

struct dev_pm_domain___282;

struct fwnode_handle___278;

struct class___282;

struct attribute_group___289;

struct device___282 {
	struct kobject___289 kobj;
	struct device___282 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___282 *type;
	struct bus_type___282 *bus;
	struct device_driver___282 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___282 power;
	struct dev_pm_domain___282 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___278 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___282 *class;
	const struct attribute_group___289 **groups;
	void (*release)(struct device___282 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_name_node___110;

struct net_device_ops___110;

struct iw_handler_def___6;

struct xfrmdev_ops___110;

struct header_ops___110;

struct netdev_rx_queue___110;

struct netdev_queue___110;

struct rtnl_link_ops___102;

struct dcbnl_rtnl_ops___110;

struct net_device___110 {
	char name[16];
	struct netdev_name_node___110 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___110 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def___6 *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___2 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___110 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___110 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___289 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___110 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___110 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___35 *miniq_ingress;
	struct netdev_queue___110 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___110 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___35 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___35 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___110 = 0,
		NETREG_REGISTERED___110 = 1,
		NETREG_UNREGISTERING___110 = 2,
		NETREG_UNREGISTERED___110 = 3,
		NETREG_RELEASED___110 = 4,
		NETREG_DUMMY___110 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___110 = 0,
		RTNL_LINK_INITIALIZING___110 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___110 *);
	struct netpoll_info *npinfo;
	possible_net_t___110 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___282 dev;
	const struct attribute_group___289 *sysfs_groups[4];
	const struct attribute_group___289 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___102 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___110 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___101 xdp_state[3];
	long: 64;
};

struct neigh_table___95;

struct neigh_parms___95;

struct neigh_ops___95;

struct neighbour___95 {
	struct neighbour___95 *next;
	struct neigh_table___95 *tbl;
	struct neigh_parms___95 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___110 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___95 *, struct sk_buff___111 *);
	const struct neigh_ops___95 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___110 *dev;
	u8 primary_key[0];
};

struct dev_pagemap_ops___296 {
	void (*page_free)(struct page___306 *);
	void (*kill)(struct dev_pagemap___296 *);
	void (*cleanup)(struct dev_pagemap___296 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___296 *);
};

struct fwnode_operations___278;

struct fwnode_handle___278 {
	struct fwnode_handle___278 *secondary;
	const struct fwnode_operations___278 *ops;
	struct device___282 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___278;

struct fwnode_endpoint___278;

struct fwnode_operations___278 {
	struct fwnode_handle___278 * (*get)(struct fwnode_handle___278 *);
	void (*put)(struct fwnode_handle___278 *);
	bool (*device_is_available)(const struct fwnode_handle___278 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___278 *, const struct device___282 *);
	bool (*property_present)(const struct fwnode_handle___278 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___278 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___278 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___278 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*get_parent)(const struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*get_next_child_node)(const struct fwnode_handle___278 *, struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*get_named_child_node)(const struct fwnode_handle___278 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___278 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___278 *);
	struct fwnode_handle___278 * (*graph_get_next_endpoint)(const struct fwnode_handle___278 *, struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*graph_get_remote_endpoint)(const struct fwnode_handle___278 *);
	struct fwnode_handle___278 * (*graph_get_port_parent)(struct fwnode_handle___278 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___278 *, struct fwnode_endpoint___278 *);
	int (*add_links)(struct fwnode_handle___278 *);
};

struct fwnode_endpoint___278 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___278 *local_fwnode;
};

struct fwnode_reference_args___278 {
	struct fwnode_handle___278 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___289;

struct kernfs_elem_dir___289 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___289 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___289;

struct kernfs_root___289 {
	struct kernfs_node___289 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___289 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___289 {
	struct kernfs_node___289 *target_kn;
};

struct kernfs_ops___289;

struct kernfs_elem_attr___289 {
	const struct kernfs_ops___289 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___289 *notify_next;
};

struct kernfs_node___289 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___289 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___289 dir;
		struct kernfs_elem_symlink___289 symlink;
		struct kernfs_elem_attr___289 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___289;

struct kernfs_ops___289 {
	int (*open)(struct kernfs_open_file___289 *);
	void (*release)(struct kernfs_open_file___289 *);
	int (*seq_show)(struct seq_file___276 *, void *);
	void * (*seq_start)(struct seq_file___276 *, loff_t *);
	void * (*seq_next)(struct seq_file___276 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___276 *, void *);
	ssize_t (*read)(struct kernfs_open_file___289 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___289 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___289 *, struct poll_table_struct___5 *);
	int (*mmap)(struct kernfs_open_file___289 *, struct vm_area_struct___306 *);
};

struct kernfs_syscall_ops___289 {
	int (*show_options)(struct seq_file___276 *, struct kernfs_root___289 *);
	int (*mkdir)(struct kernfs_node___289 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___289 *);
	int (*rename)(struct kernfs_node___289 *, struct kernfs_node___289 *, const char *);
	int (*show_path)(struct seq_file___276 *, struct kernfs_node___289 *, struct kernfs_root___289 *);
};

struct kernfs_open_file___289 {
	struct kernfs_node___289 *kn;
	struct file___301 *file;
	struct seq_file___276 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___296 *vm_ops;
};

struct bin_attribute___289;

struct attribute_group___289 {
	const char *name;
	umode_t (*is_visible)(struct kobject___289 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___289 *, struct bin_attribute___289 *, int);
	struct attribute **attrs;
	struct bin_attribute___289 **bin_attrs;
};

struct bin_attribute___289 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___301 * (*f_mapping)();
	ssize_t (*read)(struct file___301 *, struct kobject___289 *, struct bin_attribute___289 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___301 *, struct kobject___289 *, struct bin_attribute___289 *, char *, loff_t, size_t);
	int (*mmap)(struct file___301 *, struct kobject___289 *, struct bin_attribute___289 *, struct vm_area_struct___306 *);
};

struct sysfs_ops___289 {
	ssize_t (*show)(struct kobject___289 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___289 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___289;

struct kset___289 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___289 kobj;
	const struct kset_uevent_ops___289 *uevent_ops;
};

struct kobj_type___289 {
	void (*release)(struct kobject___289 *);
	const struct sysfs_ops___289 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___289 **default_groups;
	const struct kobj_ns_type_operations___94 * (*child_ns_type)(struct kobject___289 *);
	const void * (*namespace)(struct kobject___289 *);
	void (*get_ownership)(struct kobject___289 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___289 {
	int (* const filter)(struct kset___289 *, struct kobject___289 *);
	const char * (* const name)(struct kset___289 *, struct kobject___289 *);
	int (* const uevent)(struct kset___289 *, struct kobject___289 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___285 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___285 *);
	int (*get)(char *, const struct kernel_param___285 *);
	void (*free)(void *);
};

struct kparam_array___285;

struct kernel_param___285 {
	const char *name;
	struct module___285 *mod;
	const struct kernel_param_ops___285 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___285 *arr;
	};
};

struct kparam_array___285 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___285 *ops;
	void *elem;
};

struct module_attribute___285 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___285 *, struct module_kobject___286 *, char *);
	ssize_t (*store)(struct module_attribute___285 *, struct module_kobject___286 *, const char *, size_t);
	void (*setup)(struct module___285 *, const char *);
	int (*test)(struct module___285 *);
	void (*free)(struct module___285 *);
};

struct cgroup_namespace___228 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___228 *root_cset;
};

struct dev_pm_ops___282 {
	int (*prepare)(struct device___282 *);
	void (*complete)(struct device___282 *);
	int (*suspend)(struct device___282 *);
	int (*resume)(struct device___282 *);
	int (*freeze)(struct device___282 *);
	int (*thaw)(struct device___282 *);
	int (*poweroff)(struct device___282 *);
	int (*restore)(struct device___282 *);
	int (*suspend_late)(struct device___282 *);
	int (*resume_early)(struct device___282 *);
	int (*freeze_late)(struct device___282 *);
	int (*thaw_early)(struct device___282 *);
	int (*poweroff_late)(struct device___282 *);
	int (*restore_early)(struct device___282 *);
	int (*suspend_noirq)(struct device___282 *);
	int (*resume_noirq)(struct device___282 *);
	int (*freeze_noirq)(struct device___282 *);
	int (*thaw_noirq)(struct device___282 *);
	int (*poweroff_noirq)(struct device___282 *);
	int (*restore_noirq)(struct device___282 *);
	int (*runtime_suspend)(struct device___282 *);
	int (*runtime_resume)(struct device___282 *);
	int (*runtime_idle)(struct device___282 *);
};

struct wakeup_source___282 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___282 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___282 {
	struct dev_pm_ops___282 ops;
	int (*start)(struct device___282 *);
	void (*detach)(struct device___282 *, bool);
	int (*activate)(struct device___282 *);
	void (*sync)(struct device___282 *);
	void (*dismiss)(struct device___282 *);
};

struct bus_type___282 {
	const char *name;
	const char *dev_name;
	struct device___282 *dev_root;
	const struct attribute_group___289 **bus_groups;
	const struct attribute_group___289 **dev_groups;
	const struct attribute_group___289 **drv_groups;
	int (*match)(struct device___282 *, struct device_driver___282 *);
	int (*uevent)(struct device___282 *, struct kobj_uevent_env *);
	int (*probe)(struct device___282 *);
	void (*sync_state)(struct device___282 *);
	void (*remove)(struct device___282 *);
	void (*shutdown)(struct device___282 *);
	int (*online)(struct device___282 *);
	int (*offline)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	int (*num_vf)(struct device___282 *);
	int (*dma_configure)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___282 {
	const char *name;
	struct bus_type___282 *bus;
	struct module___285 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___282 *);
	void (*sync_state)(struct device___282 *);
	int (*remove)(struct device___282 *);
	void (*shutdown)(struct device___282 *);
	int (*suspend)(struct device___282 *, pm_message_t);
	int (*resume)(struct device___282 *);
	const struct attribute_group___289 **groups;
	const struct attribute_group___289 **dev_groups;
	const struct dev_pm_ops___282 *pm;
	void (*coredump)(struct device___282 *);
	struct driver_private *p;
};

struct device_type___282 {
	const char *name;
	const struct attribute_group___289 **groups;
	int (*uevent)(struct device___282 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___282 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___282 *);
	const struct dev_pm_ops___282 *pm;
};

struct class___282 {
	const char *name;
	struct module___285 *owner;
	const struct attribute_group___289 **class_groups;
	const struct attribute_group___289 **dev_groups;
	struct kobject___289 *dev_kobj;
	int (*dev_uevent)(struct device___282 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___282 *, umode_t *);
	void (*class_release)(struct class___282 *);
	void (*dev_release)(struct device___282 *);
	int (*shutdown_pre)(struct device___282 *);
	const struct kobj_ns_type_operations___94 *ns_type;
	const void * (*namespace)(struct device___282 *);
	void (*get_ownership)(struct device___282 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___282 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___142;

struct pipe_buffer___142 {
	struct page___306 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___142 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___142 {
	int (*confirm)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
	void (*release)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
	bool (*try_steal)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
	bool (*get)(struct pipe_inode_info___142 *, struct pipe_buffer___142 *);
};

struct seq_operations___276 {
	void * (*start)(struct seq_file___276 *, loff_t *);
	void (*stop)(struct seq_file___276 *, void *);
	void * (*next)(struct seq_file___276 *, void *, loff_t *);
	int (*show)(struct seq_file___276 *, void *);
};

struct dcbnl_rtnl_ops___110 {
	int (*ieee_getets)(struct net_device___110 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___110 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___110 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___110 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___110 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___110 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___110 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___110 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___110 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___110 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___110 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___110 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___110 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___110 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___110 *);
	u8 (*setstate)(struct net_device___110 *, u8);
	void (*getpermhwaddr)(struct net_device___110 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___110 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___110 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___110 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___110 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___110 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___110 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___110 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___110 *, int, u8 *);
	void (*setpfccfg)(struct net_device___110 *, int, u8);
	void (*getpfccfg)(struct net_device___110 *, int, u8 *);
	u8 (*setall)(struct net_device___110 *);
	u8 (*getcap)(struct net_device___110 *, int, u8 *);
	int (*getnumtcs)(struct net_device___110 *, int, u8 *);
	int (*setnumtcs)(struct net_device___110 *, int, u8);
	u8 (*getpfcstate)(struct net_device___110 *);
	void (*setpfcstate)(struct net_device___110 *, u8);
	void (*getbcncfg)(struct net_device___110 *, int, u32 *);
	void (*setbcncfg)(struct net_device___110 *, int, u32);
	void (*getbcnrp)(struct net_device___110 *, int, u8 *);
	void (*setbcnrp)(struct net_device___110 *, int, u8);
	int (*setapp)(struct net_device___110 *, u8, u16, u8);
	int (*getapp)(struct net_device___110 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___110 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___110 *, int, u8);
	u8 (*getdcbx)(struct net_device___110 *);
	u8 (*setdcbx)(struct net_device___110 *, u8);
	int (*peer_getappinfo)(struct net_device___110 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___110 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___110 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___110 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___110 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___110 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___113;

typedef int (*bpf_iter_init_seq_priv_t___112)(void *, struct bpf_iter_aux_info___113 *);

struct bpf_map___113;

struct bpf_iter_aux_info___113 {
	struct bpf_map___113 *map;
};

struct bpf_iter_seq_info___112 {
	const struct seq_operations___276 *seq_ops;
	bpf_iter_init_seq_priv_t___112 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_prog_aux___113;

struct bpf_map_ops___112 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___113 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___113 *, struct file___301 *);
	void (*map_free)(struct bpf_map___113 *);
	int (*map_get_next_key)(struct bpf_map___113 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___113 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___113 *, void *);
	int (*map_lookup_batch)(struct bpf_map___113 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___113 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___113 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___113 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___113 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___113 *, void *);
	int (*map_update_elem)(struct bpf_map___113 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___113 *, void *);
	int (*map_push_elem)(struct bpf_map___113 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___113 *, void *);
	int (*map_peek_elem)(struct bpf_map___113 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___113 *, struct file___301 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___113 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___113 *, void *, struct seq_file___276 *);
	int (*map_check_btf)(const struct bpf_map___113 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___113 *, struct bpf_prog_aux___113 *);
	void (*map_poke_untrack)(struct bpf_map___113 *, struct bpf_prog_aux___113 *);
	void (*map_poke_run)(struct bpf_map___113 *, u32, struct bpf_prog *, struct bpf_prog *);
	int (*map_direct_value_addr)(const struct bpf_map___113 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___113 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___113 *, struct vm_area_struct___306 *);
	__poll_t (*map_poll)(struct bpf_map___113 *, struct file___301 *, struct poll_table_struct___5 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___113 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___113 *, const struct bpf_map___113 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___113 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___112 *iter_seq_info;
};

struct bpf_map___113 {
	const struct bpf_map_ops___112 *ops;
	struct bpf_map___113 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___2 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___112;

struct bpf_jit_poke_descriptor___112;

struct btf_mod_pair___112;

struct bpf_prog_offload___110;

struct bpf_prog_aux___113 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog *dst_prog;
	struct bpf_trampoline___112 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___112 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___101 *ops;
	struct bpf_map___113 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___112 *used_btfs;
	struct bpf_prog *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___113 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___110 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___110;

struct bpf_map_dev_ops___110 {
	int (*map_get_next_key)(struct bpf_offloaded_map___110 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___110 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___110 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___110 *, void *);
};

struct bpf_offloaded_map___110 {
	struct bpf_map___113 map;
	struct net_device___110 *netdev;
	const struct bpf_map_dev_ops___110 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_offload___110 {
	struct bpf_prog *prog;
	struct net_device___110 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___112 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___285 *mod;
};

struct bpf_jit_poke_descriptor___112 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___113 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___112 {
	struct btf *btf;
	struct module___285 *module;
};

struct cftype___228;

struct cgroup_subsys___228 {
	struct cgroup_subsys_state___228 * (*css_alloc)(struct cgroup_subsys_state___228 *);
	int (*css_online)(struct cgroup_subsys_state___228 *);
	void (*css_offline)(struct cgroup_subsys_state___228 *);
	void (*css_released)(struct cgroup_subsys_state___228 *);
	void (*css_free)(struct cgroup_subsys_state___228 *);
	void (*css_reset)(struct cgroup_subsys_state___228 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___228 *, int);
	int (*css_extra_stat_show)(struct seq_file___276 *, struct cgroup_subsys_state___228 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___308 *, struct css_set___228 *);
	void (*cancel_fork)(struct task_struct___308 *, struct css_set___228 *);
	void (*fork)(struct task_struct___308 *);
	void (*exit)(struct task_struct___308 *);
	void (*release)(struct task_struct___308 *);
	void (*bind)(struct cgroup_subsys_state___228 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___228 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___228 *dfl_cftypes;
	struct cftype___228 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___228 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___228 *updated_children;
	struct cgroup___228 *updated_next;
};

struct cgroup_root___228 {
	struct kernfs_root___289 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___228 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___228 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___228 *ss;
	struct list_head node;
	struct kernfs_ops___289 *kf_ops;
	int (*open)(struct kernfs_open_file___289 *);
	void (*release)(struct kernfs_open_file___289 *);
	u64 (*read_u64)(struct cgroup_subsys_state___228 *, struct cftype___228 *);
	s64 (*read_s64)(struct cgroup_subsys_state___228 *, struct cftype___228 *);
	int (*seq_show)(struct seq_file___276 *, void *);
	void * (*seq_start)(struct seq_file___276 *, loff_t *);
	void * (*seq_next)(struct seq_file___276 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___276 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___228 *, struct cftype___228 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___228 *, struct cftype___228 *, s64);
	ssize_t (*write)(struct kernfs_open_file___289 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___289 *, struct poll_table_struct___5 *);
};

struct xdp_rxq_info___110 {
	struct net_device___110 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___110 {
	struct net_device___110 *dev;
};

struct xdp_buff___110 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___110 *rxq;
	struct xdp_txq_info___110 *txq;
	u32 frame_sz;
};

struct xdp_frame___110 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___110 *dev_rx;
};

struct netlink_callback___110 {
	struct sk_buff___111 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___111 *, struct netlink_callback___110 *);
	int (*done)(struct netlink_callback___110 *);
	void *data;
	struct module___285 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___110 {
	int (*create)(struct sk_buff___111 *, struct net_device___110 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___111 *, unsigned char *);
	int (*cache)(const struct neighbour___95 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___110 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___111 *);
};

struct netdev_queue___110 {
	struct net_device___110 *dev;
	struct Qdisc___35 *qdisc;
	struct Qdisc___35 *qdisc_sleeping;
	struct kobject___289 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___110 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct netdev_rx_queue___110 {
	struct xdp_rxq_info___110 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___289 kobj;
	struct net_device___110 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___110 {
	enum net_device_path_type type;
	const struct net_device___110 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___110 = 0,
				DEV_PATH_BR_VLAN_TAG___110 = 1,
				DEV_PATH_BR_VLAN_UNTAG___110 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___110 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___110 {
	const struct net_device___110 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___110 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___101 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___110 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___110 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___111 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___110 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___110 *dev;
	const char *name;
};

struct net_device_ops___110 {
	int (*ndo_init)(struct net_device___110 *);
	void (*ndo_uninit)(struct net_device___110 *);
	int (*ndo_open)(struct net_device___110 *);
	int (*ndo_stop)(struct net_device___110 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___111 *, struct net_device___110 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___111 *, struct net_device___110 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___110 *, struct sk_buff___111 *, struct net_device___110 *);
	void (*ndo_change_rx_flags)(struct net_device___110 *, int);
	void (*ndo_set_rx_mode)(struct net_device___110 *);
	int (*ndo_set_mac_address)(struct net_device___110 *, void *);
	int (*ndo_validate_addr)(struct net_device___110 *);
	int (*ndo_do_ioctl)(struct net_device___110 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___110 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___110 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___110 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___110 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___110 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___110 *, int);
	int (*ndo_neigh_setup)(struct net_device___110 *, struct neigh_parms___95 *);
	void (*ndo_tx_timeout)(struct net_device___110 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___110 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___110 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___110 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___110 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___110 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___110 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___110 *);
	int (*ndo_netpoll_setup)(struct net_device___110 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___110 *);
	int (*ndo_set_vf_mac)(struct net_device___110 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___110 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___110 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___110 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___110 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___110 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___110 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___110 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___110 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___110 *, int, struct sk_buff___111 *);
	int (*ndo_get_vf_guid)(struct net_device___110 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___110 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___110 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___110 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___110 *);
	int (*ndo_fcoe_disable)(struct net_device___110 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___110 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___110 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___110 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___110 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___110 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___110 *, const struct sk_buff___111 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___110 *, struct net_device___110 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___110 *, struct net_device___110 *);
	struct net_device___110 * (*ndo_get_xmit_slave)(struct net_device___110 *, struct sk_buff___111 *, bool);
	struct net_device___110 * (*ndo_sk_get_lower_dev)(struct net_device___110 *, struct sock *);
	netdev_features_t (*ndo_fix_features)(struct net_device___110 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___110 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___110 *, struct neighbour___95 *);
	void (*ndo_neigh_destroy)(struct net_device___110 *, struct neighbour___95 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___110 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___110 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___111 *, struct netlink_callback___110 *, struct net_device___110 *, struct net_device___110 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___111 *, struct nlattr **, struct net_device___110 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___110 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___111 *, u32, u32, struct net_device___110 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___110 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___110 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___110 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___110 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___110 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___110 *, struct net_device___110 *);
	void (*ndo_dfwd_del_station)(struct net_device___110 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___110 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___110 *);
	int (*ndo_change_proto_down)(struct net_device___110 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___110 *, struct sk_buff___111 *);
	void (*ndo_set_rx_headroom)(struct net_device___110 *, int);
	int (*ndo_bpf)(struct net_device___110 *, struct netdev_bpf___110 *);
	int (*ndo_xdp_xmit)(struct net_device___110 *, int, struct xdp_frame___110 **, u32);
	struct net_device___110 * (*ndo_xdp_get_xmit_slave)(struct net_device___110 *, struct xdp_buff___110 *);
	int (*ndo_xsk_wakeup)(struct net_device___110 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___110 *);
	int (*ndo_tunnel_ctl)(struct net_device___110 *, struct ip_tunnel_parm *, int);
	struct net_device___110 * (*ndo_get_peer_dev)(struct net_device___110 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___110 *, struct net_device_path___110 *);
};

struct neigh_parms___95 {
	possible_net_t___110 net;
	struct net_device___110 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___95 *);
	struct neigh_table___95 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

typedef int (*iw_handler___6)(struct net_device___110 *, struct iw_request_info *, union iwreq_data *, char *);

struct iw_handler_def___6 {
	const iw_handler___6 *standard;
	__u16 num_standard;
	__u16 num_private;
	__u16 num_private_args;
	const iw_handler___6 *private;
	const struct iw_priv_args *private_args;
	struct iw_statistics * (*get_wireless_stats)(struct net_device___110 *);
};

struct rtnl_link_ops___102 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___110 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___110 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___115 *, struct net_device___110 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___110 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___110 *, struct list_head *);
	size_t (*get_size)(const struct net_device___110 *);
	int (*fill_info)(struct sk_buff___111 *, const struct net_device___110 *);
	size_t (*get_xstats_size)(const struct net_device___110 *);
	int (*fill_xstats)(struct sk_buff___111 *, const struct net_device___110 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___110 *, struct net_device___110 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___110 *, const struct net_device___110 *);
	int (*fill_slave_info)(struct sk_buff___111 *, const struct net_device___110 *, const struct net_device___110 *);
	struct net___115 * (*get_link_net)(const struct net_device___110 *);
	size_t (*get_linkxstats_size)(const struct net_device___110 *, int);
	int (*fill_linkxstats)(struct sk_buff___111 *, const struct net_device___110 *, int *, int);
};

struct pneigh_entry___95;

struct neigh_hash_table___95;

struct neigh_table___95 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___110 *, __u32 *);
	bool (*key_eq)(const struct neighbour___95 *, const void *);
	int (*constructor)(struct neighbour___95 *);
	int (*pconstructor)(struct pneigh_entry___95 *);
	void (*pdestructor)(struct pneigh_entry___95 *);
	void (*proxy_redo)(struct sk_buff___111 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___110 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___95 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___110 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___95 *nht;
	struct pneigh_entry___95 **phash_buckets;
};

struct neigh_ops___95 {
	int family;
	void (*solicit)(struct neighbour___95 *, struct sk_buff___111 *);
	void (*error_report)(struct neighbour___95 *, struct sk_buff___111 *);
	int (*output)(struct neighbour___95 *, struct sk_buff___111 *);
	int (*connected_output)(struct neighbour___95 *, struct sk_buff___111 *);
};

struct pneigh_entry___95 {
	struct pneigh_entry___95 *next;
	possible_net_t___110 net;
	struct net_device___110 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___95 {
	struct neighbour___95 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct dentry___302;

struct super_block___302;

struct module___286;

struct file_system_type___302 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___302 * (*mount)(struct file_system_type___302 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___302 *);
	struct module___286 *owner;
	struct file_system_type___302 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___302;

struct kiocb___302;

struct iov_iter___222;

struct poll_table_struct___220;

struct vm_area_struct___307;

struct inode___302;

struct file_lock___302;

struct page___307;

struct pipe_inode_info___143;

struct seq_file___277;

struct file_operations___303 {
	struct module___286 *owner;
	loff_t (*llseek)(struct file___302 *, loff_t, int);
	ssize_t (*read)(struct file___302 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___302 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___302 *, struct iov_iter___222 *);
	ssize_t (*write_iter)(struct kiocb___302 *, struct iov_iter___222 *);
	int (*iopoll)(struct kiocb___302 *, bool);
	int (*iterate)(struct file___302 *, struct dir_context *);
	int (*iterate_shared)(struct file___302 *, struct dir_context *);
	__poll_t (*poll)(struct file___302 *, struct poll_table_struct___220 *);
	long int (*unlocked_ioctl)(struct file___302 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___302 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___302 *, struct vm_area_struct___307 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___302 *, struct file___302 *);
	int (*flush)(struct file___302 *, fl_owner_t);
	int (*release)(struct inode___302 *, struct file___302 *);
	int (*fsync)(struct file___302 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___302 *, int);
	int (*lock)(struct file___302 *, int, struct file_lock___302 *);
	ssize_t (*sendpage)(struct file___302 *, struct page___307 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___302 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___302 *, long unsigned int);
	int (*flock)(struct file___302 *, int, struct file_lock___302 *);
	ssize_t (*splice_write)(struct pipe_inode_info___143 *, struct file___302 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___302 *, loff_t *, struct pipe_inode_info___143 *, size_t, unsigned int);
	int (*setlease)(struct file___302 *, long int, struct file_lock___302 **, void **);
	long int (*fallocate)(struct file___302 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___277 *, struct file___302 *);
	ssize_t (*copy_file_range)(struct file___302 *, loff_t, struct file___302 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___302 *, loff_t, struct file___302 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___302 *, loff_t, loff_t, int);
};

struct bio_vec___219 {
	struct page___307 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___302;

struct pipe_buffer___143;

struct pipe_inode_info___143 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___307 *tmp_page;
	struct fasync_struct___302 *fasync_readers;
	struct fasync_struct___302 *fasync_writers;
	struct pipe_buffer___143 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___222 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___219 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___143 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___98 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___222 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___302 *msg_iocb;
};

struct kiocb___302 {
	struct file___302 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___302 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct vmacache___307 {
	u64 seqnum;
	struct vm_area_struct___307 *vmas[4];
};

struct page_frag___307 {
	struct page___307 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___308;

struct pid___279;

struct nsproxy___288;

struct signal_struct___303;

struct bio_list___190;

struct backing_dev_info___176;

struct io_context___190;

struct css_set___229;

struct mem_cgroup___164;

struct request_queue___190;

struct vm_struct___285;

struct task_struct___309 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___309 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___308 *mm;
	struct mm_struct___308 *active_mm;
	struct vmacache___307 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___309 *real_parent;
	struct task_struct___309 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___309 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___279 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___288 *nsproxy;
	struct signal_struct___303 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___309 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___190 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___176 *backing_dev_info;
	struct io_context___190 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___229 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___143 *splice_pipe;
	struct page_frag___307 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___164 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___164 *active_memcg;
	struct request_queue___190 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___309 *oom_reaper_list;
	struct vm_struct___285 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___290;

struct kobj_type___290;

struct kernfs_node___290;

struct kobject___290 {
	const char *name;
	struct list_head entry;
	struct kobject___290 *parent;
	struct kset___290 *kset;
	struct kobj_type___290 *ktype;
	struct kernfs_node___290 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___287 {
	struct kobject___290 kobj;
	struct module___286 *mod;
	struct kobject___290 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___286 {
	struct module___286 *mod;
	struct latch_tree_node node;
};

struct module_layout___286 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___286 mtn;
};

struct module_attribute___286;

struct kernel_param___286;

struct module___286 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___287 mkobj;
	struct module_attribute___286 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___290 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___286 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___286 core_layout;
	struct module_layout___286 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___279;

struct upid___279 {
	int nr;
	struct pid_namespace___279 *ns;
};

struct pid_namespace___279 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___309 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___279 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___279 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___279 numbers[1];
};

typedef struct page___307 *pgtable_t___307;

struct address_space___302;

struct page_pool___131;

struct dev_pagemap___297;

struct page___307 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___302 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___131 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___307 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___307 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___308 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___297 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___297;

struct vm_area_struct___307 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___307 *vm_next;
	struct vm_area_struct___307 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___308 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___297 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___302 *vm_file;
	struct file___302 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct tty_struct___21;

struct signal_struct___303 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___309 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___309 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___279 *pids[4];
	struct pid___279 *tty_old_pgrp;
	int leader;
	struct tty_struct___21 *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___308 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___307;

struct mm_struct___308 {
	struct {
		struct vm_area_struct___307 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___302 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___307 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___309 *owner;
		struct user_namespace___26 *user_ns;
		struct file___302 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___116;

struct cgroup_namespace___229;

struct nsproxy___288 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___279 *pid_ns_for_children;
	struct net___116 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___229 *cgroup_ns;
};

struct bio___190;

struct bio_list___190 {
	struct bio___190 *head;
	struct bio___190 *tail;
};

struct cgroup_subsys_state___229;

struct bdi_writeback___176 {
	struct backing_dev_info___176 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___229 *memcg_css;
	struct cgroup_subsys_state___229 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___283;

struct backing_dev_info___176 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___176 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___283 *dev;
	char dev_name[64];
	struct device___283 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___302 *debug_dir;
};

struct io_cq___190;

struct io_context___190 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___190 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___229;

struct css_set___229 {
	struct cgroup_subsys_state___229 *subsys[14];
	refcount_t refcount;
	struct css_set___229 *dom_cset;
	struct cgroup___229 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___229 *mg_src_cgrp;
	struct cgroup___229 *mg_dst_cgrp;
	struct css_set___229 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___229;

struct cgroup_subsys_state___229 {
	struct cgroup___229 *cgroup;
	struct cgroup_subsys___229 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___229 *parent;
};

struct cgroup_file___229 {
	struct kernfs_node___290 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___164;

struct mem_cgroup_per_node___164;

struct mem_cgroup___164 {
	struct cgroup_subsys_state___229 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___229 events_file;
	struct cgroup_file___229 events_local_file;
	struct cgroup_file___229 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___164 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___309 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___164 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___190;

struct blk_integrity___190 {
	const struct blk_integrity_profile___190 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___190 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___190 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___190;

struct elevator_queue___190;

struct blk_mq_ops___185;

struct blk_mq_hw_ctx___185;

struct gendisk___193;

struct blkcg_gq___178;

struct blk_mq_tag_set___185;

struct request_queue___190 {
	struct request___190 *last_merge;
	struct elevator_queue___190 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___185 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___185 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___193 *disk;
	struct kobject___290 kobj;
	struct kobject___290 *mq_kobj;
	struct blk_integrity___190 integrity;
	struct device___283 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___178 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___185 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___190 bio_split;
	struct dentry___302 *debugfs_dir;
	struct dentry___302 *sched_debugfs_dir;
	struct dentry___302 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___285 {
	struct vm_struct___285 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___307 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___302;

struct address_space___302 {
	struct inode___302 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___302 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___131 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___283 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___131 {
	u32 count;
	struct page___307 *cache[128];
};

struct page_pool___131 {
	struct page_pool_params___131 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___307 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___131 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___297;

struct dev_pagemap___297 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___297 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___302;

struct path___302 {
	struct vfsmount___302 *mnt;
	struct dentry___302 *dentry;
};

struct fown_struct___279 {
	rwlock_t lock;
	struct pid___279 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___302 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___302 f_path;
	struct inode___302 *f_inode;
	const struct file_operations___303 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___279 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___302 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___297;

struct vm_operations_struct___297 {
	void (*open)(struct vm_area_struct___307 *);
	void (*close)(struct vm_area_struct___307 *);
	int (*may_split)(struct vm_area_struct___307 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___307 *);
	int (*mprotect)(struct vm_area_struct___307 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___297 *);
	vm_fault_t (*huge_fault)(struct vm_fault___297 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___297 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___307 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___297 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___297 *);
	int (*access)(struct vm_area_struct___307 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___307 *);
	int (*set_policy)(struct vm_area_struct___307 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___307 *, long unsigned int);
	struct page___307 * (*find_special_page)(struct vm_area_struct___307 *, long unsigned int);
};

struct core_thread___307 {
	struct task_struct___309 *task;
	struct core_thread___307 *next;
};

struct core_state___307 {
	atomic_t nr_threads;
	struct core_thread___307 dumper;
	struct completion startup;
};

struct vm_fault___297 {
	const struct {
		struct vm_area_struct___307 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___307 *cow_page;
	struct page___307 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___307 prealloc_pte;
};

struct psi_group___229 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___309 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___102;

struct cgroup_bpf___102 {
	struct bpf_prog_array___102 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___102 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___229;

struct cgroup_rstat_cpu___229;

struct cgroup___229 {
	struct cgroup_subsys_state___229 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___290 *kn;
	struct cgroup_file___229 procs_file;
	struct cgroup_file___229 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___229 *subsys[14];
	struct cgroup_root___229 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___229 *dom_cgrp;
	struct cgroup___229 *old_dom_cgrp;
	struct cgroup_rstat_cpu___229 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___229 psi;
	struct cgroup_bpf___102 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct pglist_data___172;

struct lruvec___172 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___172 *pgdat;
};

struct zone___172 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___172 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___172 {
	struct zone___172 *zone;
	int zone_idx;
};

struct zonelist___172 {
	struct zoneref___172 _zonerefs[321];
};

struct pglist_data___172 {
	struct zone___172 node_zones[5];
	struct zonelist___172 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___309 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___309 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___172 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct tty_driver___22;

struct tty_operations___22;

struct tty_ldisc___21;

struct tty_port___22;

struct tty_struct___21 {
	int magic;
	struct kref kref;
	struct device___283 *dev;
	struct tty_driver___22 *driver;
	const struct tty_operations___22 *ops;
	int index;
	struct ld_semaphore ldisc_sem;
	struct tty_ldisc___21 *ldisc;
	struct mutex atomic_write_lock;
	struct mutex legacy_mutex;
	struct mutex throttle_mutex;
	struct rw_semaphore termios_rwsem;
	struct mutex winsize_mutex;
	struct ktermios termios;
	struct ktermios termios_locked;
	char name[64];
	long unsigned int flags;
	int count;
	struct winsize winsize;
	struct {
		spinlock_t lock;
		bool stopped;
		bool tco_stopped;
		long unsigned int unused[0];
	} flow;
	struct {
		spinlock_t lock;
		struct pid___279 *pgrp;
		struct pid___279 *session;
		unsigned char pktstatus;
		bool packet;
		long unsigned int unused[0];
	} ctrl;
	int hw_stopped;
	unsigned int receive_room;
	int flow_change;
	struct tty_struct___21 *link;
	struct fasync_struct___302 *fasync;
	wait_queue_head_t write_wait;
	wait_queue_head_t read_wait;
	struct work_struct hangup_work;
	void *disc_data;
	void *driver_data;
	spinlock_t files_lock;
	struct list_head tty_files;
	int closing;
	unsigned char *write_buf;
	int write_cnt;
	struct work_struct SAK_work;
	struct tty_port___22 *port;
};

struct shrink_control___164 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___164 *memcg;
};

struct shrinker___164 {
	long unsigned int (*count_objects)(struct shrinker___164 *, struct shrink_control___164 *);
	long unsigned int (*scan_objects)(struct shrinker___164 *, struct shrink_control___164 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct dev_pagemap_ops___297 {
	void (*page_free)(struct page___307 *);
	void (*kill)(struct dev_pagemap___297 *);
	void (*cleanup)(struct dev_pagemap___297 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___297 *);
};

struct dentry_operations___302;

struct dentry___302 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___302 *d_parent;
	struct qstr d_name;
	struct inode___302 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___302 *d_op;
	struct super_block___302 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___302;

struct cdev___66;

struct inode___302 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___302 *i_op;
	struct super_block___302 *i_sb;
	struct address_space___302 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___176 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___303 *i_fop;
		void (*free_inode)(struct inode___302 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___302 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___143 *i_pipe;
		struct cdev___66 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___302 {
	int (*d_revalidate)(struct dentry___302 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___302 *, unsigned int);
	int (*d_hash)(const struct dentry___302 *, struct qstr *);
	int (*d_compare)(const struct dentry___302 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___302 *);
	int (*d_init)(struct dentry___302 *);
	void (*d_release)(struct dentry___302 *);
	void (*d_prune)(struct dentry___302 *);
	void (*d_iput)(struct dentry___302 *, struct inode___302 *);
	char * (*d_dname)(struct dentry___302 *, char *, int);
	struct vfsmount___302 * (*d_automount)(struct path___302 *);
	int (*d_manage)(const struct path___302 *, bool);
	struct dentry___302 * (*d_real)(struct dentry___302 *, const struct inode___302 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___302;

struct mem_dqinfo___302 {
	struct quota_format_type___302 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___302;

struct quota_info___302 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___302 *files[3];
	struct mem_dqinfo___302 info[3];
	const struct quota_format_ops___302 *ops[3];
};

struct rcuwait___303 {
	struct task_struct___309 *task;
};

struct percpu_rw_semaphore___303 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___303 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___302 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___303 rw_sem[3];
};

struct super_operations___302;

struct dquot_operations___302;

struct quotactl_ops___302;

struct block_device___193;

struct super_block___302 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___302 *s_type;
	const struct super_operations___302 *s_op;
	const struct dquot_operations___302 *dq_op;
	const struct quotactl_ops___302 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___302 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___193 *s_bdev;
	struct backing_dev_info___176 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___302 s_dquot;
	struct sb_writers___302 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___302 *s_d_op;
	int cleancache_poolid;
	struct shrinker___164 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___302 {
	struct dentry___302 *mnt_root;
	struct super_block___302 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct io_cq___190 {
	struct request_queue___190 *q;
	struct io_context___190 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___302 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___302 *ia_file;
};

struct dquot___302 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___302 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___302 {
	int qf_fmt_id;
	const struct quota_format_ops___302 *qf_ops;
	struct module___286 *qf_owner;
	struct quota_format_type___302 *qf_next;
};

struct quota_format_ops___302 {
	int (*check_quota_file)(struct super_block___302 *, int);
	int (*read_file_info)(struct super_block___302 *, int);
	int (*write_file_info)(struct super_block___302 *, int);
	int (*free_file_info)(struct super_block___302 *, int);
	int (*read_dqblk)(struct dquot___302 *);
	int (*commit_dqblk)(struct dquot___302 *);
	int (*release_dqblk)(struct dquot___302 *);
	int (*get_next_id)(struct super_block___302 *, struct kqid *);
};

struct dquot_operations___302 {
	int (*write_dquot)(struct dquot___302 *);
	struct dquot___302 * (*alloc_dquot)(struct super_block___302 *, int);
	void (*destroy_dquot)(struct dquot___302 *);
	int (*acquire_dquot)(struct dquot___302 *);
	int (*release_dquot)(struct dquot___302 *);
	int (*mark_dirty)(struct dquot___302 *);
	int (*write_info)(struct super_block___302 *, int);
	qsize_t * (*get_reserved_space)(struct inode___302 *);
	int (*get_projid)(struct inode___302 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___302 *, qsize_t *);
	int (*get_next_id)(struct super_block___302 *, struct kqid *);
};

struct quotactl_ops___302 {
	int (*quota_on)(struct super_block___302 *, int, int, const struct path___302 *);
	int (*quota_off)(struct super_block___302 *, int);
	int (*quota_enable)(struct super_block___302 *, unsigned int);
	int (*quota_disable)(struct super_block___302 *, unsigned int);
	int (*quota_sync)(struct super_block___302 *, int);
	int (*set_info)(struct super_block___302 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___302 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___302 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___302 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___302 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___302 *, unsigned int);
};

struct writeback_control___176;

struct address_space_operations___302 {
	int (*writepage)(struct page___307 *, struct writeback_control___176 *);
	int (*readpage)(struct file___302 *, struct page___307 *);
	int (*writepages)(struct address_space___302 *, struct writeback_control___176 *);
	int (*set_page_dirty)(struct page___307 *);
	int (*readpages)(struct file___302 *, struct address_space___302 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___302 *, struct address_space___302 *, loff_t, unsigned int, unsigned int, struct page___307 **, void **);
	int (*write_end)(struct file___302 *, struct address_space___302 *, loff_t, unsigned int, unsigned int, struct page___307 *, void *);
	sector_t (*bmap)(struct address_space___302 *, sector_t);
	void (*invalidatepage)(struct page___307 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___307 *, gfp_t);
	void (*freepage)(struct page___307 *);
	ssize_t (*direct_IO)(struct kiocb___302 *, struct iov_iter___222 *);
	int (*migratepage)(struct address_space___302 *, struct page___307 *, struct page___307 *, enum migrate_mode);
	bool (*isolate_page)(struct page___307 *, isolate_mode_t);
	void (*putback_page)(struct page___307 *);
	int (*launder_page)(struct page___307 *);
	int (*is_partially_uptodate)(struct page___307 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___307 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___302 *, struct page___307 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___302 *, sector_t *);
	void (*swap_deactivate)(struct file___302 *);
};

struct writeback_control___176 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___176 *wb;
	struct inode___302 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct cdev___66 {
	struct kobject___290 kobj;
	struct module___286 *owner;
	const struct file_operations___303 *ops;
	struct list_head list;
	dev_t dev;
	unsigned int count;
};

struct inode_operations___302 {
	struct dentry___302 * (*lookup)(struct inode___302 *, struct dentry___302 *, unsigned int);
	const char * (*get_link)(struct dentry___302 *, struct inode___302 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___302 *, int);
	struct posix_acl * (*get_acl)(struct inode___302 *, int, bool);
	int (*readlink)(struct dentry___302 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___302 *, struct dentry___302 *, umode_t, bool);
	int (*link)(struct dentry___302 *, struct inode___302 *, struct dentry___302 *);
	int (*unlink)(struct inode___302 *, struct dentry___302 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___302 *, struct dentry___302 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___302 *, struct dentry___302 *, umode_t);
	int (*rmdir)(struct inode___302 *, struct dentry___302 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___302 *, struct dentry___302 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___302 *, struct dentry___302 *, struct inode___302 *, struct dentry___302 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___302 *, struct iattr___302 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___302 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___302 *, char *, size_t);
	int (*fiemap)(struct inode___302 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___302 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___302 *, struct dentry___302 *, struct file___302 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___302 *, struct dentry___302 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___302 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___302 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___302 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___302 {
	void (*fl_copy_lock)(struct file_lock___302 *, struct file_lock___302 *);
	void (*fl_release_private)(struct file_lock___302 *);
};

struct lock_manager_operations___302;

struct file_lock___302 {
	struct file_lock___302 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___302 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___302 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___302 *fl_ops;
	const struct lock_manager_operations___302 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___302 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___302 *);
	int (*lm_grant)(struct file_lock___302 *, int);
	bool (*lm_break)(struct file_lock___302 *);
	int (*lm_change)(struct file_lock___302 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___302 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___302 *);
};

struct fasync_struct___302 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___302 *fa_next;
	struct file___302 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___302 {
	struct inode___302 * (*alloc_inode)(struct super_block___302 *);
	void (*destroy_inode)(struct inode___302 *);
	void (*free_inode)(struct inode___302 *);
	void (*dirty_inode)(struct inode___302 *, int);
	int (*write_inode)(struct inode___302 *, struct writeback_control___176 *);
	int (*drop_inode)(struct inode___302 *);
	void (*evict_inode)(struct inode___302 *);
	void (*put_super)(struct super_block___302 *);
	int (*sync_fs)(struct super_block___302 *, int);
	int (*freeze_super)(struct super_block___302 *);
	int (*freeze_fs)(struct super_block___302 *);
	int (*thaw_super)(struct super_block___302 *);
	int (*unfreeze_fs)(struct super_block___302 *);
	int (*statfs)(struct dentry___302 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___302 *, int *, char *);
	void (*umount_begin)(struct super_block___302 *);
	int (*show_options)(struct seq_file___277 *, struct dentry___302 *);
	int (*show_devname)(struct seq_file___277 *, struct dentry___302 *);
	int (*show_path)(struct seq_file___277 *, struct dentry___302 *);
	int (*show_stats)(struct seq_file___277 *, struct dentry___302 *);
	ssize_t (*quota_read)(struct super_block___302 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___302 *, int, const char *, size_t, loff_t);
	struct dquot___302 ** (*get_dquots)(struct inode___302 *);
	long int (*nr_cached_objects)(struct super_block___302 *, struct shrink_control___164 *);
	long int (*free_cached_objects)(struct super_block___302 *, struct shrink_control___164 *);
	struct file___302 * (*real_loop)(struct file___302 *);
};

struct wakeup_source___283;

struct dev_pm_info___283 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___283 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___283 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___283;

struct bus_type___283;

struct device_driver___283;

struct dev_pm_domain___283;

struct fwnode_handle___279;

struct class___283;

struct attribute_group___290;

struct device___283 {
	struct kobject___290 kobj;
	struct device___283 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___283 *type;
	struct bus_type___283 *bus;
	struct device_driver___283 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___283 power;
	struct dev_pm_domain___283 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___279 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___283 *class;
	const struct attribute_group___290 **groups;
	void (*release)(struct device___283 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___193 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___302 *bd_inode;
	struct super_block___302 *bd_super;
	void *bd_claiming;
	struct device___283 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___290 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___193 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___302 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___228)(struct file___302 *, wait_queue_head_t *, struct poll_table_struct___220 *);

struct poll_table_struct___220 {
	poll_queue_proc___228 _qproc;
	__poll_t _key;
};

struct seq_operations___277;

struct seq_file___277 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___277 *op;
	int poll_event;
	const struct file___302 *file;
	void *private;
};

typedef void bio_end_io_t___190(struct bio___190 *);

struct bio_integrity_payload___190;

struct bio___190 {
	struct bio___190 *bi_next;
	struct block_device___193 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___190 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___178 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___190 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___219 *bi_io_vec;
	struct bio_set___190 *bi_pool;
	struct bio_vec___219 bi_inline_vecs[0];
};

struct fib_rules_ops___95;

struct sock___95;

struct fqdir___116;

struct fib_notifier_ops___95;

struct netns_ipv4___116 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___95 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___95 *fibnl;
	struct sock___95 **icmp_sk;
	struct sock___95 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___95 **tcp_sk;
	struct fqdir___116 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___95 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___95 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___95 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___95;

struct net_device___111;

struct sk_buff___112;

struct neighbour___96;

struct dst_ops___116 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___116 *);
	struct dst_entry___95 * (*check)(struct dst_entry___95 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___95 *);
	unsigned int (*mtu)(const struct dst_entry___95 *);
	u32 * (*cow_metrics)(struct dst_entry___95 *, long unsigned int);
	void (*destroy)(struct dst_entry___95 *);
	void (*ifdown)(struct dst_entry___95 *, struct net_device___111 *, int);
	struct dst_entry___95 * (*negative_advice)(struct dst_entry___95 *);
	void (*link_failure)(struct sk_buff___112 *);
	void (*update_pmtu)(struct dst_entry___95 *, struct sock___95 *, struct sk_buff___112 *, u32, bool);
	void (*redirect)(struct dst_entry___95 *, struct sock___95 *, struct sk_buff___112 *);
	int (*local_out)(struct net___116 *, struct sock___95 *, struct sk_buff___112 *);
	struct neighbour___96 * (*neigh_lookup)(const struct dst_entry___95 *, struct sk_buff___112 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___95 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___116 {
	struct dst_ops___116 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___116 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___95 *fib6_rules_ops;
	struct sock___95 **icmp_sk;
	struct sock___95 *ndisc_sk;
	struct sock___95 *tcp_sk;
	struct sock___95 *igmp_sk;
	struct sock___95 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___95 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___95 *notifier_ops;
	struct fib_notifier_ops___95 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___116 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___116 *fqdir;
};

struct netns_sctp___95 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___95 *ctl_sock;
	struct sock___95 *udp4_sock;
	struct sock___95 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___111 {
	struct sk_buff___112 *next;
	struct sk_buff___112 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog___102;

struct netns_bpf___102 {
	struct bpf_prog_array___102 *run_array[2];
	struct bpf_prog___102 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___116 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___95 *nlsk;
	struct sock___95 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___116 xfrm4_dst_ops;
	struct dst_ops___116 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___116 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___95 *rtnl;
	struct sock___95 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___111 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___116 ipv4;
	struct netns_ipv6___116 ipv6;
	struct netns_ieee802154_lowpan___116 ieee802154_lowpan;
	struct netns_sctp___95 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___111 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___102 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___116 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___95 *crypto_nlsk;
	struct sock___95 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct cgroup_namespace___229 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___229 *root_cset;
};

struct kernfs_root___290;

struct kernfs_elem_dir___290 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___290 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___290;

struct kernfs_root___290 {
	struct kernfs_node___290 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___290 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___290 {
	struct kernfs_node___290 *target_kn;
};

struct kernfs_ops___290;

struct kernfs_elem_attr___290 {
	const struct kernfs_ops___290 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___290 *notify_next;
};

struct kernfs_node___290 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___290 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___290 dir;
		struct kernfs_elem_symlink___290 symlink;
		struct kernfs_elem_attr___290 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___290;

struct kernfs_ops___290 {
	int (*open)(struct kernfs_open_file___290 *);
	void (*release)(struct kernfs_open_file___290 *);
	int (*seq_show)(struct seq_file___277 *, void *);
	void * (*seq_start)(struct seq_file___277 *, loff_t *);
	void * (*seq_next)(struct seq_file___277 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___277 *, void *);
	ssize_t (*read)(struct kernfs_open_file___290 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___290 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___290 *, struct poll_table_struct___220 *);
	int (*mmap)(struct kernfs_open_file___290 *, struct vm_area_struct___307 *);
};

struct kernfs_syscall_ops___290 {
	int (*show_options)(struct seq_file___277 *, struct kernfs_root___290 *);
	int (*mkdir)(struct kernfs_node___290 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___290 *);
	int (*rename)(struct kernfs_node___290 *, struct kernfs_node___290 *, const char *);
	int (*show_path)(struct seq_file___277 *, struct kernfs_node___290 *, struct kernfs_root___290 *);
};

struct kernfs_open_file___290 {
	struct kernfs_node___290 *kn;
	struct file___302 *file;
	struct seq_file___277 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___297 *vm_ops;
};

struct kobj_ns_type_operations___95 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___95 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

typedef struct {
	struct net___116 *net;
} possible_net_t___111;

struct proto___95;

struct sock_common___95 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___95 *skc_prot;
	possible_net_t___111 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___95 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sock_cgroup_data___95 {
	struct cgroup___229 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___95;

struct socket_wq___97;

struct socket___98;

struct sock___95 {
	struct sock_common___95 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___111 sk_error_queue;
	struct sk_buff___112 *sk_rx_skb_cache;
	struct sk_buff_head___111 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___112 *head;
		struct sk_buff___112 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___95 *sk_filter;
	union {
		struct socket_wq___97 *sk_wq;
		struct socket_wq___97 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___95 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___95 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___112 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___112 *sk_tx_skb_cache;
	struct sk_buff_head___111 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___307 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___95 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___279 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___98 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___95 sk_cgrp_data;
	struct mem_cgroup___164 *sk_memcg;
	void (*sk_state_change)(struct sock___95 *);
	void (*sk_data_ready)(struct sock___95 *);
	void (*sk_write_space)(struct sock___95 *);
	void (*sk_error_report)(struct sock___95 *);
	int (*sk_backlog_rcv)(struct sock___95 *, struct sk_buff___112 *);
	struct sk_buff___112 * (*sk_validate_xmit_skb)(struct sock___95 *, struct net_device___111 *, struct sk_buff___112 *);
	void (*sk_destruct)(struct sock___95 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct bin_attribute___290;

struct attribute_group___290 {
	const char *name;
	umode_t (*is_visible)(struct kobject___290 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___290 *, struct bin_attribute___290 *, int);
	struct attribute **attrs;
	struct bin_attribute___290 **bin_attrs;
};

struct bin_attribute___290 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___302 * (*f_mapping)();
	ssize_t (*read)(struct file___302 *, struct kobject___290 *, struct bin_attribute___290 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___302 *, struct kobject___290 *, struct bin_attribute___290 *, char *, loff_t, size_t);
	int (*mmap)(struct file___302 *, struct kobject___290 *, struct bin_attribute___290 *, struct vm_area_struct___307 *);
};

struct sysfs_ops___290 {
	ssize_t (*show)(struct kobject___290 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___290 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___290;

struct kset___290 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___290 kobj;
	const struct kset_uevent_ops___290 *uevent_ops;
};

struct kobj_type___290 {
	void (*release)(struct kobject___290 *);
	const struct sysfs_ops___290 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___290 **default_groups;
	const struct kobj_ns_type_operations___95 * (*child_ns_type)(struct kobject___290 *);
	const void * (*namespace)(struct kobject___290 *);
	void (*get_ownership)(struct kobject___290 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___290 {
	int (* const filter)(struct kset___290 *, struct kobject___290 *);
	const char * (* const name)(struct kset___290 *, struct kobject___290 *);
	int (* const uevent)(struct kset___290 *, struct kobject___290 *, struct kobj_uevent_env *);
};

struct dev_pm_ops___283 {
	int (*prepare)(struct device___283 *);
	void (*complete)(struct device___283 *);
	int (*suspend)(struct device___283 *);
	int (*resume)(struct device___283 *);
	int (*freeze)(struct device___283 *);
	int (*thaw)(struct device___283 *);
	int (*poweroff)(struct device___283 *);
	int (*restore)(struct device___283 *);
	int (*suspend_late)(struct device___283 *);
	int (*resume_early)(struct device___283 *);
	int (*freeze_late)(struct device___283 *);
	int (*thaw_early)(struct device___283 *);
	int (*poweroff_late)(struct device___283 *);
	int (*restore_early)(struct device___283 *);
	int (*suspend_noirq)(struct device___283 *);
	int (*resume_noirq)(struct device___283 *);
	int (*freeze_noirq)(struct device___283 *);
	int (*thaw_noirq)(struct device___283 *);
	int (*poweroff_noirq)(struct device___283 *);
	int (*restore_noirq)(struct device___283 *);
	int (*runtime_suspend)(struct device___283 *);
	int (*runtime_resume)(struct device___283 *);
	int (*runtime_idle)(struct device___283 *);
};

struct wakeup_source___283 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___283 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___283 {
	struct dev_pm_ops___283 ops;
	int (*start)(struct device___283 *);
	void (*detach)(struct device___283 *, bool);
	int (*activate)(struct device___283 *);
	void (*sync)(struct device___283 *);
	void (*dismiss)(struct device___283 *);
};

struct bus_type___283 {
	const char *name;
	const char *dev_name;
	struct device___283 *dev_root;
	const struct attribute_group___290 **bus_groups;
	const struct attribute_group___290 **dev_groups;
	const struct attribute_group___290 **drv_groups;
	int (*match)(struct device___283 *, struct device_driver___283 *);
	int (*uevent)(struct device___283 *, struct kobj_uevent_env *);
	int (*probe)(struct device___283 *);
	void (*sync_state)(struct device___283 *);
	void (*remove)(struct device___283 *);
	void (*shutdown)(struct device___283 *);
	int (*online)(struct device___283 *);
	int (*offline)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	int (*num_vf)(struct device___283 *);
	int (*dma_configure)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___283 {
	const char *name;
	struct bus_type___283 *bus;
	struct module___286 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___283 *);
	void (*sync_state)(struct device___283 *);
	int (*remove)(struct device___283 *);
	void (*shutdown)(struct device___283 *);
	int (*suspend)(struct device___283 *, pm_message_t);
	int (*resume)(struct device___283 *);
	const struct attribute_group___290 **groups;
	const struct attribute_group___290 **dev_groups;
	const struct dev_pm_ops___283 *pm;
	void (*coredump)(struct device___283 *);
	struct driver_private *p;
};

struct device_type___283 {
	const char *name;
	const struct attribute_group___290 **groups;
	int (*uevent)(struct device___283 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___283 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___283 *);
	const struct dev_pm_ops___283 *pm;
};

struct class___283 {
	const char *name;
	struct module___286 *owner;
	const struct attribute_group___290 **class_groups;
	const struct attribute_group___290 **dev_groups;
	struct kobject___290 *dev_kobj;
	int (*dev_uevent)(struct device___283 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___283 *, umode_t *);
	void (*class_release)(struct class___283 *);
	void (*dev_release)(struct device___283 *);
	int (*shutdown_pre)(struct device___283 *);
	const struct kobj_ns_type_operations___95 *ns_type;
	const void * (*namespace)(struct device___283 *);
	void (*get_ownership)(struct device___283 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___283 *pm;
	struct subsys_private *p;
};

struct fwnode_operations___279;

struct fwnode_handle___279 {
	struct fwnode_handle___279 *secondary;
	const struct fwnode_operations___279 *ops;
	struct device___283 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct seq_operations___277 {
	void * (*start)(struct seq_file___277 *, loff_t *);
	void (*stop)(struct seq_file___277 *, void *);
	void * (*next)(struct seq_file___277 *, void *, loff_t *);
	int (*show)(struct seq_file___277 *, void *);
};

struct tty_operations___22 {
	struct tty_struct___21 * (*lookup)(struct tty_driver___22 *, struct file___302 *, int);
	int (*install)(struct tty_driver___22 *, struct tty_struct___21 *);
	void (*remove)(struct tty_driver___22 *, struct tty_struct___21 *);
	int (*open)(struct tty_struct___21 *, struct file___302 *);
	void (*close)(struct tty_struct___21 *, struct file___302 *);
	void (*shutdown)(struct tty_struct___21 *);
	void (*cleanup)(struct tty_struct___21 *);
	int (*write)(struct tty_struct___21 *, const unsigned char *, int);
	int (*put_char)(struct tty_struct___21 *, unsigned char);
	void (*flush_chars)(struct tty_struct___21 *);
	unsigned int (*write_room)(struct tty_struct___21 *);
	unsigned int (*chars_in_buffer)(struct tty_struct___21 *);
	int (*ioctl)(struct tty_struct___21 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct tty_struct___21 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___21 *, struct ktermios *);
	void (*throttle)(struct tty_struct___21 *);
	void (*unthrottle)(struct tty_struct___21 *);
	void (*stop)(struct tty_struct___21 *);
	void (*start)(struct tty_struct___21 *);
	void (*hangup)(struct tty_struct___21 *);
	int (*break_ctl)(struct tty_struct___21 *, int);
	void (*flush_buffer)(struct tty_struct___21 *);
	void (*set_ldisc)(struct tty_struct___21 *);
	void (*wait_until_sent)(struct tty_struct___21 *, int);
	void (*send_xchar)(struct tty_struct___21 *, char);
	int (*tiocmget)(struct tty_struct___21 *);
	int (*tiocmset)(struct tty_struct___21 *, unsigned int, unsigned int);
	int (*resize)(struct tty_struct___21 *, struct winsize *);
	int (*get_icount)(struct tty_struct___21 *, struct serial_icounter_struct *);
	int (*get_serial)(struct tty_struct___21 *, struct serial_struct *);
	int (*set_serial)(struct tty_struct___21 *, struct serial_struct *);
	void (*show_fdinfo)(struct tty_struct___21 *, struct seq_file___277 *);
	int (*poll_init)(struct tty_driver___22 *, int, char *);
	int (*poll_get_char)(struct tty_driver___22 *, int);
	void (*poll_put_char)(struct tty_driver___22 *, int, char);
	int (*proc_show)(struct seq_file___277 *, void *);
};

struct tty_driver___22 {
	int magic;
	struct kref kref;
	struct cdev___66 **cdevs;
	struct module___286 *owner;
	const char *driver_name;
	const char *name;
	int name_base;
	int major;
	int minor_start;
	unsigned int num;
	short int type;
	short int subtype;
	struct ktermios init_termios;
	long unsigned int flags;
	struct proc_dir_entry *proc_entry;
	struct tty_driver___22 *other;
	struct tty_struct___21 **ttys;
	struct tty_port___22 **ports;
	struct ktermios **termios;
	void *driver_state;
	const struct tty_operations___22 *ops;
	struct list_head tty_drivers;
};

struct tty_port_operations___21;

struct tty_port_client_operations___21;

struct tty_port___22 {
	struct tty_bufhead buf;
	struct tty_struct___21 *tty;
	struct tty_struct___21 *itty;
	const struct tty_port_operations___21 *ops;
	const struct tty_port_client_operations___21 *client_ops;
	spinlock_t lock;
	int blocked_open;
	int count;
	wait_queue_head_t open_wait;
	wait_queue_head_t delta_msr_wait;
	long unsigned int flags;
	long unsigned int iflags;
	unsigned char console;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct mutex mutex;
	struct mutex buf_mutex;
	unsigned char *xmit_buf;
	unsigned int close_delay;
	unsigned int closing_wait;
	int drain_delay;
	struct kref kref;
	void *client_data;
};

struct tty_ldisc_ops___21 {
	char *name;
	int num;
	int flags;
	int (*open)(struct tty_struct___21 *);
	void (*close)(struct tty_struct___21 *);
	void (*flush_buffer)(struct tty_struct___21 *);
	ssize_t (*read)(struct tty_struct___21 *, struct file___302 *, unsigned char *, size_t, void **, long unsigned int);
	ssize_t (*write)(struct tty_struct___21 *, struct file___302 *, const unsigned char *, size_t);
	int (*ioctl)(struct tty_struct___21 *, struct file___302 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct tty_struct___21 *, struct file___302 *, unsigned int, long unsigned int);
	void (*set_termios)(struct tty_struct___21 *, struct ktermios *);
	__poll_t (*poll)(struct tty_struct___21 *, struct file___302 *, struct poll_table_struct___220 *);
	int (*hangup)(struct tty_struct___21 *);
	void (*receive_buf)(struct tty_struct___21 *, const unsigned char *, const char *, int);
	void (*write_wakeup)(struct tty_struct___21 *);
	void (*dcd_change)(struct tty_struct___21 *, unsigned int);
	int (*receive_buf2)(struct tty_struct___21 *, const unsigned char *, const char *, int);
	struct module___286 *owner;
};

struct tty_ldisc___21 {
	struct tty_ldisc_ops___21 *ops;
	struct tty_struct___21 *tty;
};

struct tty_port_operations___21 {
	int (*carrier_raised)(struct tty_port___22 *);
	void (*dtr_rts)(struct tty_port___22 *, int);
	void (*shutdown)(struct tty_port___22 *);
	int (*activate)(struct tty_port___22 *, struct tty_struct___21 *);
	void (*destruct)(struct tty_port___22 *);
};

struct tty_port_client_operations___21 {
	int (*receive_buf)(struct tty_port___22 *, const unsigned char *, const unsigned char *, size_t);
	void (*write_wakeup)(struct tty_port___22 *);
};

struct fwnode_reference_args___279;

struct fwnode_endpoint___279;

struct fwnode_operations___279 {
	struct fwnode_handle___279 * (*get)(struct fwnode_handle___279 *);
	void (*put)(struct fwnode_handle___279 *);
	bool (*device_is_available)(const struct fwnode_handle___279 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___279 *, const struct device___283 *);
	bool (*property_present)(const struct fwnode_handle___279 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___279 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___279 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___279 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*get_parent)(const struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*get_next_child_node)(const struct fwnode_handle___279 *, struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*get_named_child_node)(const struct fwnode_handle___279 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___279 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___279 *);
	struct fwnode_handle___279 * (*graph_get_next_endpoint)(const struct fwnode_handle___279 *, struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*graph_get_remote_endpoint)(const struct fwnode_handle___279 *);
	struct fwnode_handle___279 * (*graph_get_port_parent)(struct fwnode_handle___279 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___279 *, struct fwnode_endpoint___279 *);
	int (*add_links)(struct fwnode_handle___279 *);
};

struct fwnode_endpoint___279 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___279 *local_fwnode;
};

struct fwnode_reference_args___279 {
	struct fwnode_handle___279 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct sk_buff___112 {
	union {
		struct {
			struct sk_buff___112 *next;
			struct sk_buff___112 *prev;
			union {
				struct net_device___111 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___95 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___112 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___116;

struct fqdir___116 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___116 *f;
	struct net___116 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___116;

struct inet_frags___116 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___116 *, const void *);
	void (*destructor)(struct inet_frag_queue___116 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___116 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___112 *fragments_tail;
	struct sk_buff___112 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___116 *fqdir;
	struct callback_head rcu;
};

struct fib_rule___95;

struct fib_lookup_arg___95;

struct fib_rules_ops___95 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___95 *, struct flowi *, int, struct fib_lookup_arg___95 *);
	bool (*suppress)(struct fib_rule___95 *, int, struct fib_lookup_arg___95 *);
	int (*match)(struct fib_rule___95 *, struct flowi *, int);
	int (*configure)(struct fib_rule___95 *, struct sk_buff___112 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___95 *);
	int (*compare)(struct fib_rule___95 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___95 *, struct sk_buff___112 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___95 *);
	void (*flush_cache)(struct fib_rules_ops___95 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___286 *owner;
	struct net___116 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___95 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___116 *);
	int (*fib_dump)(struct net___116 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___286 *owner;
	struct callback_head rcu;
};

struct dst_entry___95 {
	struct net_device___111 *dev;
	struct dst_ops___116 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___112 *);
	int (*output)(struct net___116 *, struct sock___95 *, struct sk_buff___112 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___111(struct sk_buff___112 **);

struct bpf_xdp_entity___102 {
	struct bpf_prog___102 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___111;

struct net_device_ops___111;

struct l3mdev_ops___95;

struct xfrmdev_ops___111;

struct header_ops___111;

struct netdev_rx_queue___111;

struct mini_Qdisc___102;

struct netdev_queue___111;

struct Qdisc___102;

struct rtnl_link_ops___103;

struct dcbnl_rtnl_ops___111;

struct net_device___111 {
	char name[16];
	struct netdev_name_node___111 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___111 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___95 *l3mdev_ops;
	const struct ndisc_ops *ndisc_ops;
	const struct xfrmdev_ops___111 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___111 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___290 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___111 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___102 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___111 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___102 *miniq_ingress;
	struct netdev_queue___111 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___111 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___102 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___102 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___111 = 0,
		NETREG_REGISTERED___111 = 1,
		NETREG_UNREGISTERING___111 = 2,
		NETREG_UNREGISTERED___111 = 3,
		NETREG_RELEASED___111 = 4,
		NETREG_DUMMY___111 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___111 = 0,
		RTNL_LINK_INITIALIZING___111 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___111 *);
	struct netpoll_info *npinfo;
	possible_net_t___111 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___283 dev;
	const struct attribute_group___290 *sysfs_groups[4];
	const struct attribute_group___290 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___103 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___111 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___102 xdp_state[3];
	long: 64;
};

struct neigh_table___96;

struct neigh_parms___96;

struct neigh_ops___96;

struct neighbour___96 {
	struct neighbour___96 *next;
	struct neigh_table___96 *tbl;
	struct neigh_parms___96 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___111 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___96 *, struct sk_buff___112 *);
	const struct neigh_ops___96 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___111 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___102 {
	struct bpf_prog___102 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___102 {
	struct callback_head rcu;
	struct bpf_prog_array_item___102 items[0];
};

struct bpf_prog_aux___114;

struct bpf_prog___102 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___114 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct kernel_param_ops___286 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___286 *);
	int (*get)(char *, const struct kernel_param___286 *);
	void (*free)(void *);
};

struct kparam_array___286;

struct kernel_param___286 {
	const char *name;
	struct module___286 *mod;
	const struct kernel_param_ops___286 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___286 *arr;
	};
};

struct kparam_array___286 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___286 *ops;
	void *elem;
};

struct module_attribute___286 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___286 *, struct module_kobject___287 *, char *);
	ssize_t (*store)(struct module_attribute___286 *, struct module_kobject___287 *, const char *, size_t);
	void (*setup)(struct module___286 *, const char *);
	int (*test)(struct module___286 *);
	void (*free)(struct module___286 *);
};

struct socket_wq___97 {
	wait_queue_head_t wait;
	struct fasync_struct___302 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___97;

struct socket___98 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___302 *file;
	struct sock___95 *sk;
	const struct proto_ops___97 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___97 wq;
};

typedef int (*sk_read_actor_t___96)(read_descriptor_t *, struct sk_buff___112 *, unsigned int, size_t);

struct proto_ops___97 {
	int family;
	struct module___286 *owner;
	int (*release)(struct socket___98 *);
	int (*bind)(struct socket___98 *, struct sockaddr *, int);
	int (*connect)(struct socket___98 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___98 *, struct socket___98 *);
	int (*accept)(struct socket___98 *, struct socket___98 *, int, bool);
	int (*getname)(struct socket___98 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___302 *, struct socket___98 *, struct poll_table_struct___220 *);
	int (*ioctl)(struct socket___98 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___98 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___98 *, void *, bool, bool);
	int (*listen)(struct socket___98 *, int);
	int (*shutdown)(struct socket___98 *, int);
	int (*setsockopt)(struct socket___98 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___98 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___277 *, struct socket___98 *);
	int (*sendmsg)(struct socket___98 *, struct msghdr___98 *, size_t);
	int (*recvmsg)(struct socket___98 *, struct msghdr___98 *, size_t, int);
	int (*mmap)(struct file___302 *, struct socket___98 *, struct vm_area_struct___307 *);
	ssize_t (*sendpage)(struct socket___98 *, struct page___307 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___98 *, loff_t *, struct pipe_inode_info___143 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___95 *, int);
	int (*peek_len)(struct socket___98 *);
	int (*read_sock)(struct sock___95 *, read_descriptor_t *, sk_read_actor_t___96);
	int (*sendpage_locked)(struct sock___95 *, struct page___307 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___95 *, struct msghdr___98 *, size_t);
	int (*set_rcvlowat)(struct sock___95 *, int);
};

struct pipe_buf_operations___143;

struct pipe_buffer___143 {
	struct page___307 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___143 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___143 {
	int (*confirm)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
	void (*release)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
	bool (*try_steal)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
	bool (*get)(struct pipe_inode_info___143 *, struct pipe_buffer___143 *);
};

struct dcbnl_rtnl_ops___111 {
	int (*ieee_getets)(struct net_device___111 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___111 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___111 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___111 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___111 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___111 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___111 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___111 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___111 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___111 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___111 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___111 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___111 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___111 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___111 *);
	u8 (*setstate)(struct net_device___111 *, u8);
	void (*getpermhwaddr)(struct net_device___111 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___111 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___111 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___111 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___111 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___111 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___111 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___111 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___111 *, int, u8 *);
	void (*setpfccfg)(struct net_device___111 *, int, u8);
	void (*getpfccfg)(struct net_device___111 *, int, u8 *);
	u8 (*setall)(struct net_device___111 *);
	u8 (*getcap)(struct net_device___111 *, int, u8 *);
	int (*getnumtcs)(struct net_device___111 *, int, u8 *);
	int (*setnumtcs)(struct net_device___111 *, int, u8);
	u8 (*getpfcstate)(struct net_device___111 *);
	void (*setpfcstate)(struct net_device___111 *, u8);
	void (*getbcncfg)(struct net_device___111 *, int, u32 *);
	void (*setbcncfg)(struct net_device___111 *, int, u32);
	void (*getbcnrp)(struct net_device___111 *, int, u8 *);
	void (*setbcnrp)(struct net_device___111 *, int, u8);
	int (*setapp)(struct net_device___111 *, u8, u16, u8);
	int (*getapp)(struct net_device___111 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___111 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___111 *, int, u8);
	u8 (*getdcbx)(struct net_device___111 *);
	u8 (*setdcbx)(struct net_device___111 *, u8);
	int (*peer_getappinfo)(struct net_device___111 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___111 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___111 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___111 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___111 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___111 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___114;

typedef int (*bpf_iter_init_seq_priv_t___113)(void *, struct bpf_iter_aux_info___114 *);

struct bpf_map___114;

struct bpf_iter_aux_info___114 {
	struct bpf_map___114 *map;
};

struct bpf_iter_seq_info___113 {
	const struct seq_operations___277 *seq_ops;
	bpf_iter_init_seq_priv_t___113 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___113 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___114 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___114 *, struct file___302 *);
	void (*map_free)(struct bpf_map___114 *);
	int (*map_get_next_key)(struct bpf_map___114 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___114 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___114 *, void *);
	int (*map_lookup_batch)(struct bpf_map___114 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___114 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___114 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___114 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___114 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___114 *, void *);
	int (*map_update_elem)(struct bpf_map___114 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___114 *, void *);
	int (*map_push_elem)(struct bpf_map___114 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___114 *, void *);
	int (*map_peek_elem)(struct bpf_map___114 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___114 *, struct file___302 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___114 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___114 *, void *, struct seq_file___277 *);
	int (*map_check_btf)(const struct bpf_map___114 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___114 *, struct bpf_prog_aux___114 *);
	void (*map_poke_untrack)(struct bpf_map___114 *, struct bpf_prog_aux___114 *);
	void (*map_poke_run)(struct bpf_map___114 *, u32, struct bpf_prog___102 *, struct bpf_prog___102 *);
	int (*map_direct_value_addr)(const struct bpf_map___114 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___114 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___114 *, struct vm_area_struct___307 *);
	__poll_t (*map_poll)(struct bpf_map___114 *, struct file___302 *, struct poll_table_struct___220 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___114 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___114 *, const struct bpf_map___114 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___114 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___113 *iter_seq_info;
};

struct bpf_map___114 {
	const struct bpf_map_ops___113 *ops;
	struct bpf_map___114 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___164 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___113;

struct bpf_jit_poke_descriptor___113;

struct bpf_prog_ops___102;

struct btf_mod_pair___113;

struct bpf_prog_offload___111;

struct bpf_prog_aux___114 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___102 *dst_prog;
	struct bpf_trampoline___113 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___102 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___113 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___102 *ops;
	struct bpf_map___114 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___113 *used_btfs;
	struct bpf_prog___102 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___114 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___111 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___111;

struct bpf_map_dev_ops___111 {
	int (*map_get_next_key)(struct bpf_offloaded_map___111 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___111 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___111 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___111 *, void *);
};

struct bpf_offloaded_map___111 {
	struct bpf_map___114 map;
	struct net_device___111 *netdev;
	const struct bpf_map_dev_ops___111 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___102 {
	int (*test_run)(struct bpf_prog___102 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___111 {
	struct bpf_prog___102 *prog;
	struct net_device___111 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___113 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___102 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___286 *mod;
};

struct bpf_jit_poke_descriptor___113 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___114 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___113 {
	struct btf *btf;
	struct module___286 *module;
};

struct cftype___229;

struct cgroup_subsys___229 {
	struct cgroup_subsys_state___229 * (*css_alloc)(struct cgroup_subsys_state___229 *);
	int (*css_online)(struct cgroup_subsys_state___229 *);
	void (*css_offline)(struct cgroup_subsys_state___229 *);
	void (*css_released)(struct cgroup_subsys_state___229 *);
	void (*css_free)(struct cgroup_subsys_state___229 *);
	void (*css_reset)(struct cgroup_subsys_state___229 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___229 *, int);
	int (*css_extra_stat_show)(struct seq_file___277 *, struct cgroup_subsys_state___229 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___309 *, struct css_set___229 *);
	void (*cancel_fork)(struct task_struct___309 *, struct css_set___229 *);
	void (*fork)(struct task_struct___309 *);
	void (*exit)(struct task_struct___309 *);
	void (*release)(struct task_struct___309 *);
	void (*bind)(struct cgroup_subsys_state___229 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___229 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___229 *dfl_cftypes;
	struct cftype___229 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___229 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___229 *updated_children;
	struct cgroup___229 *updated_next;
};

struct cgroup_root___229 {
	struct kernfs_root___290 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___229 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___229 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___229 *ss;
	struct list_head node;
	struct kernfs_ops___290 *kf_ops;
	int (*open)(struct kernfs_open_file___290 *);
	void (*release)(struct kernfs_open_file___290 *);
	u64 (*read_u64)(struct cgroup_subsys_state___229 *, struct cftype___229 *);
	s64 (*read_s64)(struct cgroup_subsys_state___229 *, struct cftype___229 *);
	int (*seq_show)(struct seq_file___277 *, void *);
	void * (*seq_start)(struct seq_file___277 *, loff_t *);
	void * (*seq_next)(struct seq_file___277 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___277 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___229 *, struct cftype___229 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___229 *, struct cftype___229 *, s64);
	ssize_t (*write)(struct kernfs_open_file___290 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___290 *, struct poll_table_struct___220 *);
};

struct xdp_rxq_info___111 {
	struct net_device___111 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___111 {
	struct net_device___111 *dev;
};

struct xdp_buff___111 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___111 *rxq;
	struct xdp_txq_info___111 *txq;
	u32 frame_sz;
};

struct xdp_frame___111 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___111 *dev_rx;
};

struct netlink_callback___111 {
	struct sk_buff___112 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___112 *, struct netlink_callback___111 *);
	int (*done)(struct netlink_callback___111 *);
	void *data;
	struct module___286 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___111 {
	int (*create)(struct sk_buff___112 *, struct net_device___111 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___112 *, unsigned char *);
	int (*cache)(const struct neighbour___96 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___111 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___112 *);
};

struct netdev_queue___111 {
	struct net_device___111 *dev;
	struct Qdisc___102 *qdisc;
	struct Qdisc___102 *qdisc_sleeping;
	struct kobject___290 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___111 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___102 {
	struct sk_buff___112 *head;
	struct sk_buff___112 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___102;

struct Qdisc___102 {
	int (*enqueue)(struct sk_buff___112 *, struct Qdisc___102 *, struct sk_buff___112 **);
	struct sk_buff___112 * (*dequeue)(struct Qdisc___102 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___102 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___111 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___111 gso_skb;
	struct qdisc_skb_head___102 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___102 *next_sched;
	struct sk_buff_head___111 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___111 {
	struct xdp_rxq_info___111 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___290 kobj;
	struct net_device___111 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___111 {
	enum net_device_path_type type;
	const struct net_device___111 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___111 = 0,
				DEV_PATH_BR_VLAN_TAG___111 = 1,
				DEV_PATH_BR_VLAN_UNTAG___111 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___111 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___111 {
	const struct net_device___111 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___111 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___102 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___111 *offmap;
		};
		struct {
			struct xsk_buff_pool___2 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___111 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___112 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___111 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___111 *dev;
	const char *name;
};

struct net_device_ops___111 {
	int (*ndo_init)(struct net_device___111 *);
	void (*ndo_uninit)(struct net_device___111 *);
	int (*ndo_open)(struct net_device___111 *);
	int (*ndo_stop)(struct net_device___111 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___112 *, struct net_device___111 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___112 *, struct net_device___111 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___111 *, struct sk_buff___112 *, struct net_device___111 *);
	void (*ndo_change_rx_flags)(struct net_device___111 *, int);
	void (*ndo_set_rx_mode)(struct net_device___111 *);
	int (*ndo_set_mac_address)(struct net_device___111 *, void *);
	int (*ndo_validate_addr)(struct net_device___111 *);
	int (*ndo_do_ioctl)(struct net_device___111 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___111 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___111 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___111 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___111 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___111 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___111 *, int);
	int (*ndo_neigh_setup)(struct net_device___111 *, struct neigh_parms___96 *);
	void (*ndo_tx_timeout)(struct net_device___111 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___111 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___111 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___111 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___111 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___111 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___111 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___111 *);
	int (*ndo_netpoll_setup)(struct net_device___111 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___111 *);
	int (*ndo_set_vf_mac)(struct net_device___111 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___111 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___111 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___111 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___111 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___111 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___111 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___111 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___111 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___111 *, int, struct sk_buff___112 *);
	int (*ndo_get_vf_guid)(struct net_device___111 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___111 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___111 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___111 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___111 *);
	int (*ndo_fcoe_disable)(struct net_device___111 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___111 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___111 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___111 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___111 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___111 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___111 *, const struct sk_buff___112 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___111 *, struct net_device___111 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___111 *, struct net_device___111 *);
	struct net_device___111 * (*ndo_get_xmit_slave)(struct net_device___111 *, struct sk_buff___112 *, bool);
	struct net_device___111 * (*ndo_sk_get_lower_dev)(struct net_device___111 *, struct sock___95 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___111 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___111 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___111 *, struct neighbour___96 *);
	void (*ndo_neigh_destroy)(struct net_device___111 *, struct neighbour___96 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___111 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___111 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___112 *, struct netlink_callback___111 *, struct net_device___111 *, struct net_device___111 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___112 *, struct nlattr **, struct net_device___111 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___111 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___112 *, u32, u32, struct net_device___111 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___111 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___111 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___111 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___111 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___111 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___111 *, struct net_device___111 *);
	void (*ndo_dfwd_del_station)(struct net_device___111 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___111 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___111 *);
	int (*ndo_change_proto_down)(struct net_device___111 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___111 *, struct sk_buff___112 *);
	void (*ndo_set_rx_headroom)(struct net_device___111 *, int);
	int (*ndo_bpf)(struct net_device___111 *, struct netdev_bpf___111 *);
	int (*ndo_xdp_xmit)(struct net_device___111 *, int, struct xdp_frame___111 **, u32);
	struct net_device___111 * (*ndo_xdp_get_xmit_slave)(struct net_device___111 *, struct xdp_buff___111 *);
	int (*ndo_xsk_wakeup)(struct net_device___111 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___111 *);
	int (*ndo_tunnel_ctl)(struct net_device___111 *, struct ip_tunnel_parm *, int);
	struct net_device___111 * (*ndo_get_peer_dev)(struct net_device___111 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___111 *, struct net_device_path___111 *);
};

struct neigh_parms___96 {
	possible_net_t___111 net;
	struct net_device___111 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___96 *);
	struct neigh_table___96 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___95 {
	u32 (*l3mdev_fib_table)(const struct net_device___111 *);
	struct sk_buff___112 * (*l3mdev_l3_rcv)(struct net_device___111 *, struct sk_buff___112 *, u16);
	struct sk_buff___112 * (*l3mdev_l3_out)(struct net_device___111 *, struct sock___95 *, struct sk_buff___112 *, u16);
	struct dst_entry___95 * (*l3mdev_link_scope_lookup)(const struct net_device___111 *, struct flowi6 *);
};

struct tcf_proto___102;

struct tcf_block___102;

struct mini_Qdisc___102 {
	struct tcf_proto___102 *filter_list;
	struct tcf_block___102 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___103 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___111 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___111 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___116 *, struct net_device___111 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___111 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___111 *, struct list_head *);
	size_t (*get_size)(const struct net_device___111 *);
	int (*fill_info)(struct sk_buff___112 *, const struct net_device___111 *);
	size_t (*get_xstats_size)(const struct net_device___111 *);
	int (*fill_xstats)(struct sk_buff___112 *, const struct net_device___111 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___111 *, struct net_device___111 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___111 *, const struct net_device___111 *);
	int (*fill_slave_info)(struct sk_buff___112 *, const struct net_device___111 *, const struct net_device___111 *);
	struct net___116 * (*get_link_net)(const struct net_device___111 *);
	size_t (*get_linkxstats_size)(const struct net_device___111 *, int);
	int (*fill_linkxstats)(struct sk_buff___112 *, const struct net_device___111 *, int *, int);
};

struct block_device_operations___190;

struct gendisk___193 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___193 *part0;
	const struct block_device_operations___190 *fops;
	struct request_queue___190 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___176 *bdi;
	struct kobject___290 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___290 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___190 {
	struct bio___190 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___219 *bip_vec;
	struct bio_vec___219 bip_inline_vecs[0];
};

struct blkcg___178;

struct blkg_policy_data___178;

struct blkcg_gq___178 {
	struct request_queue___190 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___178 *blkcg;
	struct blkcg_gq___178 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___178 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___190 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___190(struct request___190 *);

typedef void integrity_complete_fn___190(struct request___190 *, unsigned int);

struct blk_integrity_profile___190 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___190 *prepare_fn;
	integrity_complete_fn___190 *complete_fn;
	const char *name;
};

struct block_device_operations___190 {
	blk_qc_t (*submit_bio)(struct bio___190 *);
	int (*open)(struct block_device___193 *, fmode_t);
	void (*release)(struct gendisk___193 *, fmode_t);
	int (*rw_page)(struct block_device___193 *, sector_t, struct page___307 *, unsigned int);
	int (*ioctl)(struct block_device___193 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___193 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___193 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___193 *);
	int (*getgeo)(struct block_device___193 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___193 *, bool);
	void (*swap_slot_free_notify)(struct block_device___193 *, long unsigned int);
	int (*report_zones)(struct gendisk___193 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___193 *, umode_t *);
	struct module___286 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___193 *, sector_t *);
};

typedef void rq_end_io_fn___190(struct request___190 *, blk_status_t);

struct request___190 {
	struct request_queue___190 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___185 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___190 *bio;
	struct bio___190 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___219 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___190 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___190 *saved_end_io;
		} flush;
	};
	struct gendisk___193 *rq_disk;
	struct block_device___193 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___190 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___185 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___190 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___290 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___302 *debugfs_dir;
	struct dentry___302 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___190;

struct elevator_mq_ops___190 {
	int (*init_sched)(struct request_queue___190 *, struct elevator_type___190 *);
	void (*exit_sched)(struct elevator_queue___190 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___185 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___185 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___185 *);
	bool (*allow_merge)(struct request_queue___190 *, struct request___190 *, struct bio___190 *);
	bool (*bio_merge)(struct request_queue___190 *, struct bio___190 *, unsigned int);
	int (*request_merge)(struct request_queue___190 *, struct request___190 **, struct bio___190 *);
	void (*request_merged)(struct request_queue___190 *, struct request___190 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___190 *, struct request___190 *, struct request___190 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___190 *);
	void (*finish_request)(struct request___190 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___185 *, struct list_head *, bool);
	struct request___190 * (*dispatch_request)(struct blk_mq_hw_ctx___185 *);
	bool (*has_work)(struct blk_mq_hw_ctx___185 *);
	void (*completed_request)(struct request___190 *, u64);
	void (*requeue_request)(struct request___190 *);
	struct request___190 * (*former_request)(struct request_queue___190 *, struct request___190 *);
	struct request___190 * (*next_request)(struct request_queue___190 *, struct request___190 *);
	void (*init_icq)(struct io_cq___190 *);
	void (*exit_icq)(struct io_cq___190 *);
};

struct elv_fs_entry___190;

struct elevator_type___190 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___190 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___190 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___286 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___190 {
	struct elevator_type___190 *type;
	void *elevator_data;
	struct kobject___290 kobj;
	struct mutex sysfs_lock;
	unsigned int registered;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___190 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___190 *, char *);
	ssize_t (*store)(struct elevator_queue___190 *, const char *, size_t);
};

struct blk_mq_queue_data___185;

struct blk_mq_ops___185 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___185 *, const struct blk_mq_queue_data___185 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___185 *);
	int (*get_budget)(struct request_queue___190 *);
	void (*put_budget)(struct request_queue___190 *, int);
	void (*set_rq_budget_token)(struct request___190 *, int);
	int (*get_rq_budget_token)(struct request___190 *);
	enum blk_eh_timer_return (*timeout)(struct request___190 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___185 *);
	void (*complete)(struct request___190 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___185 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___185 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___185 *, struct request___190 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___185 *, struct request___190 *, unsigned int);
	void (*initialize_rq_fn)(struct request___190 *);
	void (*cleanup_rq)(struct request___190 *);
	bool (*busy)(struct request_queue___190 *);
	int (*map_queues)(struct blk_mq_tag_set___185 *);
	void (*show_rq)(struct seq_file___277 *, struct request___190 *);
};

struct blk_mq_tag_set___185 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___185 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___185 {
	struct request___190 *rq;
	bool last;
};

struct blkcg_policy_data___178;

struct blkcg___178 {
	struct cgroup_subsys_state___229 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___178 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___178 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___178 {
	struct blkcg___178 *blkcg;
	int plid;
};

struct blkg_policy_data___178 {
	struct blkcg_gq___178 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___164 {
	struct mem_cgroup___164 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___164 {
	struct lruvec___172 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___164 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___164 *memcg;
};

struct obj_cgroup___164 {
	struct percpu_ref refcnt;
	struct mem_cgroup___164 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___102 {
	spinlock_t *lock;
	struct sk_buff___112 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___102;

struct Qdisc_ops___102 {
	struct Qdisc_ops___102 *next;
	const struct Qdisc_class_ops___102 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___112 *, struct Qdisc___102 *, struct sk_buff___112 **);
	struct sk_buff___112 * (*dequeue)(struct Qdisc___102 *);
	struct sk_buff___112 * (*peek)(struct Qdisc___102 *);
	int (*init)(struct Qdisc___102 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___102 *);
	void (*destroy)(struct Qdisc___102 *);
	int (*change)(struct Qdisc___102 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___102 *);
	int (*change_tx_queue_len)(struct Qdisc___102 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___102 *, unsigned int);
	int (*dump)(struct Qdisc___102 *, struct sk_buff___112 *);
	int (*dump_stats)(struct Qdisc___102 *, struct gnet_dump___102 *);
	void (*ingress_block_set)(struct Qdisc___102 *, u32);
	void (*egress_block_set)(struct Qdisc___102 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___102 *);
	u32 (*egress_block_get)(struct Qdisc___102 *);
	struct module___286 *owner;
};

struct Qdisc_class_ops___102 {
	unsigned int flags;
	struct netdev_queue___111 * (*select_queue)(struct Qdisc___102 *, struct tcmsg *);
	int (*graft)(struct Qdisc___102 *, long unsigned int, struct Qdisc___102 *, struct Qdisc___102 **, struct netlink_ext_ack *);
	struct Qdisc___102 * (*leaf)(struct Qdisc___102 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___102 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___102 *, u32);
	int (*change)(struct Qdisc___102 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___102 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___102 *, struct qdisc_walker *);
	struct tcf_block___102 * (*tcf_block)(struct Qdisc___102 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___102 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___102 *, long unsigned int);
	int (*dump)(struct Qdisc___102 *, long unsigned int, struct sk_buff___112 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___102 *, long unsigned int, struct gnet_dump___102 *);
};

struct tcf_chain___102;

struct tcf_block___102 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___116 *net;
	struct Qdisc___102 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___102 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___102;

struct tcf_proto_ops___102;

struct tcf_proto___102 {
	struct tcf_proto___102 *next;
	void *root;
	int (*classify)(struct sk_buff___112 *, const struct tcf_proto___102 *, struct tcf_result___102 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___102 *ops;
	struct tcf_chain___102 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___102 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___102 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___102 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___112 *, const struct tcf_proto___102 *, struct tcf_result___102 *);
	int (*init)(struct tcf_proto___102 *);
	void (*destroy)(struct tcf_proto___102 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___102 *, u32);
	void (*put)(struct tcf_proto___102 *, void *);
	int (*change)(struct net___116 *, struct sk_buff___112 *, struct tcf_proto___102 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___102 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___102 *);
	void (*walk)(struct tcf_proto___102 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___102 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___102 *, void *);
	void (*hw_del)(struct tcf_proto___102 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___116 *, struct tcf_chain___102 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___116 *, struct tcf_proto___102 *, void *, struct sk_buff___112 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___116 *, struct tcf_proto___102 *, void *, struct sk_buff___112 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___112 *, struct net___116 *, void *);
	struct module___286 *owner;
	int flags;
};

struct tcf_chain___102 {
	struct mutex filter_chain_lock;
	struct tcf_proto___102 *filter_chain;
	struct list_head list;
	struct tcf_block___102 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___102 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___95 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___102 *prog;
};

struct pneigh_entry___96;

struct neigh_hash_table___96;

struct neigh_table___96 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___111 *, __u32 *);
	bool (*key_eq)(const struct neighbour___96 *, const void *);
	int (*constructor)(struct neighbour___96 *);
	int (*pconstructor)(struct pneigh_entry___96 *);
	void (*pdestructor)(struct pneigh_entry___96 *);
	void (*proxy_redo)(struct sk_buff___112 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___111 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___96 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___111 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___96 *nht;
	struct pneigh_entry___96 **phash_buckets;
};

struct neigh_ops___96 {
	int family;
	void (*solicit)(struct neighbour___96 *, struct sk_buff___112 *);
	void (*error_report)(struct neighbour___96 *, struct sk_buff___112 *);
	int (*output)(struct neighbour___96 *, struct sk_buff___112 *);
	int (*connected_output)(struct neighbour___96 *, struct sk_buff___112 *);
};

struct pneigh_entry___96 {
	struct pneigh_entry___96 *next;
	possible_net_t___111 net;
	struct net_device___111 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___96 {
	struct neighbour___96 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct fib_rule___95 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___95 *ctarget;
	struct net___116 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___95 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___95 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___80;

struct proto___95 {
	void (*close)(struct sock___95 *, long int);
	int (*pre_connect)(struct sock___95 *, struct sockaddr *, int);
	int (*connect)(struct sock___95 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___95 *, int);
	struct sock___95 * (*accept)(struct sock___95 *, int, int *, bool);
	int (*ioctl)(struct sock___95 *, int, long unsigned int);
	int (*init)(struct sock___95 *);
	void (*destroy)(struct sock___95 *);
	void (*shutdown)(struct sock___95 *, int);
	int (*setsockopt)(struct sock___95 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___95 *, int, int, char *, int *);
	void (*keepalive)(struct sock___95 *, int);
	int (*compat_ioctl)(struct sock___95 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___95 *, struct msghdr___98 *, size_t);
	int (*recvmsg)(struct sock___95 *, struct msghdr___98 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___95 *, struct page___307 *, int, size_t, int);
	int (*bind)(struct sock___95 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___95 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___95 *, struct sk_buff___112 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___95 *);
	int (*hash)(struct sock___95 *);
	void (*unhash)(struct sock___95 *);
	void (*rehash)(struct sock___95 *);
	int (*get_port)(struct sock___95 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___95 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___95 *, int);
	bool (*sock_is_readable)(struct sock___95 *);
	void (*enter_memory_pressure)(struct sock___95 *);
	void (*leave_memory_pressure)(struct sock___95 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___80 *rsk_prot;
	struct timewait_sock_ops___3 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___286 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___95 *, int);
};

struct request_sock___81;

struct request_sock_ops___80 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___95 *, struct request_sock___81 *);
	void (*send_ack)(const struct sock___95 *, struct sk_buff___112 *, struct request_sock___81 *);
	void (*send_reset)(const struct sock___95 *, struct sk_buff___112 *);
	void (*destructor)(struct request_sock___81 *);
	void (*syn_ack_timeout)(const struct request_sock___81 *);
};

struct request_sock___81 {
	struct sock_common___95 __req_common;
	struct request_sock___81 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___80 *rsk_ops;
	struct sock___95 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct inet_request_sock___9 {
	struct request_sock___65 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___93 *pktopts;
		};
	};
};

struct netlbl_af4list {
	__be32 addr;
	__be32 mask;
	u32 valid;
	struct list_head list;
};

struct netlbl_af6list {
	struct in6_addr addr;
	struct in6_addr mask;
	u32 valid;
	struct list_head list;
};

struct netlbl_domaddr_map {
	struct list_head list4;
	struct list_head list6;
};

struct netlbl_dommap_def {
	u32 type;
	union {
		struct netlbl_domaddr_map *addrsel;
		struct cipso_v4_doi *cipso;
		struct calipso_doi *calipso;
	};
};

struct netlbl_domaddr4_map {
	struct netlbl_dommap_def def;
	struct netlbl_af4list list;
};

struct netlbl_domaddr6_map {
	struct netlbl_dommap_def def;
	struct netlbl_af6list list;
};

struct netlbl_dom_map {
	char *domain;
	u16 family;
	struct netlbl_dommap_def def;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_domhsh_tbl {
	struct list_head *tbl;
	u32 size;
};

struct netlink_skb_parms___23 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___79 *sk;
	bool nsid_is_set;
	int nsid;
};

struct genl_ops___9;

struct genl_info___9;

struct genl_small_ops___9;

struct genl_family___9 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok;
	u8 parallel_ops;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___9 *, struct sk_buff___93 *, struct genl_info___9 *);
	void (*post_doit)(const struct genl_ops___9 *, struct sk_buff___93 *, struct genl_info___9 *);
	const struct genl_ops___9 *ops;
	const struct genl_small_ops___9 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___267 *module;
};

struct genl_ops___9 {
	int (*doit)(struct sk_buff___93 *, struct genl_info___9 *);
	int (*start)(struct netlink_callback___92 *);
	int (*dumpit)(struct sk_buff___93 *, struct netlink_callback___92 *);
	int (*done)(struct netlink_callback___92 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___9 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___92 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___9 {
	int (*doit)(struct sk_buff___93 *, struct genl_info___9 *);
	int (*dumpit)(struct sk_buff___93 *, struct netlink_callback___92 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct cipso_v4_std_map_tbl___2 {
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} lvl;
	long: 64;
	long: 64;
	long: 64;
	struct {
		u32 *cipso;
		u32 *local;
		u32 cipso_size;
		u32 local_size;
	} cat;
	long: 64;
	long: 64;
	long: 64;
};

struct cipso_v4_doi___2 {
	u32 doi;
	u32 type;
	union {
		struct cipso_v4_std_map_tbl___2 *std;
	} map;
	long: 64;
	u8 tags[5];
	refcount_t refcount;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_dommap_def___2 {
	u32 type;
	union {
		struct netlbl_domaddr_map *addrsel;
		struct cipso_v4_doi___2 *cipso;
		struct calipso_doi *calipso;
	};
	long: 64;
};

struct netlbl_domaddr4_map___2 {
	struct netlbl_dommap_def___2 def;
	struct netlbl_af4list list;
};

struct netlbl_domaddr6_map___2 {
	struct netlbl_dommap_def___2 def;
	struct netlbl_af6list list;
};

struct netlbl_dom_map___2 {
	char *domain;
	u16 family;
	struct netlbl_dommap_def___2 def;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

enum {
	NLBL_MGMT_C_UNSPEC = 0,
	NLBL_MGMT_C_ADD = 1,
	NLBL_MGMT_C_REMOVE = 2,
	NLBL_MGMT_C_LISTALL = 3,
	NLBL_MGMT_C_ADDDEF = 4,
	NLBL_MGMT_C_REMOVEDEF = 5,
	NLBL_MGMT_C_LISTDEF = 6,
	NLBL_MGMT_C_PROTOCOLS = 7,
	NLBL_MGMT_C_VERSION = 8,
	__NLBL_MGMT_C_MAX = 9,
};

enum {
	NLBL_MGMT_A_UNSPEC = 0,
	NLBL_MGMT_A_DOMAIN = 1,
	NLBL_MGMT_A_PROTOCOL = 2,
	NLBL_MGMT_A_VERSION = 3,
	NLBL_MGMT_A_CV4DOI = 4,
	NLBL_MGMT_A_IPV6ADDR = 5,
	NLBL_MGMT_A_IPV6MASK = 6,
	NLBL_MGMT_A_IPV4ADDR = 7,
	NLBL_MGMT_A_IPV4MASK = 8,
	NLBL_MGMT_A_ADDRSELECTOR = 9,
	NLBL_MGMT_A_SELECTORLIST = 10,
	NLBL_MGMT_A_FAMILY = 11,
	NLBL_MGMT_A_CLPDOI = 12,
	__NLBL_MGMT_A_MAX = 13,
};

struct netlbl_domhsh_walk_arg {
	struct netlink_callback___92 *nl_cb;
	struct sk_buff___93 *skb;
	u32 seq;
};

enum {
	NLBL_UNLABEL_C_UNSPEC = 0,
	NLBL_UNLABEL_C_ACCEPT = 1,
	NLBL_UNLABEL_C_LIST = 2,
	NLBL_UNLABEL_C_STATICADD = 3,
	NLBL_UNLABEL_C_STATICREMOVE = 4,
	NLBL_UNLABEL_C_STATICLIST = 5,
	NLBL_UNLABEL_C_STATICADDDEF = 6,
	NLBL_UNLABEL_C_STATICREMOVEDEF = 7,
	NLBL_UNLABEL_C_STATICLISTDEF = 8,
	__NLBL_UNLABEL_C_MAX = 9,
};

enum {
	NLBL_UNLABEL_A_UNSPEC = 0,
	NLBL_UNLABEL_A_ACPTFLG = 1,
	NLBL_UNLABEL_A_IPV6ADDR = 2,
	NLBL_UNLABEL_A_IPV6MASK = 3,
	NLBL_UNLABEL_A_IPV4ADDR = 4,
	NLBL_UNLABEL_A_IPV4MASK = 5,
	NLBL_UNLABEL_A_IFACE = 6,
	NLBL_UNLABEL_A_SECCTX = 7,
	__NLBL_UNLABEL_A_MAX = 8,
};

struct netlbl_unlhsh_tbl {
	struct list_head *tbl;
	u32 size;
};

struct netlbl_unlhsh_addr4 {
	struct lsmblob lsmblob;
	struct netlbl_af4list list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_addr6 {
	struct lsmblob lsmblob;
	struct netlbl_af6list list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_iface {
	int ifindex;
	struct list_head addr4_list;
	struct list_head addr6_list;
	u32 valid;
	struct list_head list;
	struct callback_head rcu;
};

struct netlbl_unlhsh_walk_arg {
	struct netlink_callback___98 *nl_cb;
	struct sk_buff___99 *skb;
	u32 seq;
};

enum {
	NLBL_CIPSOV4_C_UNSPEC = 0,
	NLBL_CIPSOV4_C_ADD = 1,
	NLBL_CIPSOV4_C_REMOVE = 2,
	NLBL_CIPSOV4_C_LIST = 3,
	NLBL_CIPSOV4_C_LISTALL = 4,
	__NLBL_CIPSOV4_C_MAX = 5,
};

enum {
	NLBL_CIPSOV4_A_UNSPEC = 0,
	NLBL_CIPSOV4_A_DOI = 1,
	NLBL_CIPSOV4_A_MTYPE = 2,
	NLBL_CIPSOV4_A_TAG = 3,
	NLBL_CIPSOV4_A_TAGLST = 4,
	NLBL_CIPSOV4_A_MLSLVLLOC = 5,
	NLBL_CIPSOV4_A_MLSLVLREM = 6,
	NLBL_CIPSOV4_A_MLSLVL = 7,
	NLBL_CIPSOV4_A_MLSLVLLST = 8,
	NLBL_CIPSOV4_A_MLSCATLOC = 9,
	NLBL_CIPSOV4_A_MLSCATREM = 10,
	NLBL_CIPSOV4_A_MLSCAT = 11,
	NLBL_CIPSOV4_A_MLSCATLST = 12,
	__NLBL_CIPSOV4_A_MAX = 13,
};

struct netlbl_cipsov4_doiwalk_arg {
	struct netlink_callback___111 *nl_cb;
	struct sk_buff___112 *skb;
	u32 seq;
};

struct netlbl_domhsh_walk_arg___2 {
	struct netlbl_audit *audit_info;
	u32 doi;
};

struct netlbl_calipso_ops___2 {
	int (*doi_add)(struct calipso_doi *, struct netlbl_audit *);
	void (*doi_free)(struct calipso_doi *);
	int (*doi_remove)(u32, struct netlbl_audit *);
	struct calipso_doi * (*doi_getdef)(u32);
	void (*doi_putdef)(struct calipso_doi *);
	int (*doi_walk)(u32 *, int (*)(struct calipso_doi *, void *), void *);
	int (*sock_getattr)(struct sock___95 *, struct netlbl_lsm_secattr *);
	int (*sock_setattr)(struct sock___95 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*sock_delattr)(struct sock___95 *);
	int (*req_setattr)(struct request_sock___81 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	void (*req_delattr)(struct request_sock___81 *);
	int (*opt_getattr)(const unsigned char *, struct netlbl_lsm_secattr *);
	unsigned char * (*skbuff_optptr)(const struct sk_buff___112 *);
	int (*skbuff_setattr)(struct sk_buff___112 *, const struct calipso_doi *, const struct netlbl_lsm_secattr *);
	int (*skbuff_delattr)(struct sk_buff___112 *);
	void (*cache_invalidate)();
	int (*cache_add)(const unsigned char *, const struct netlbl_lsm_secattr *);
};

enum {
	NLBL_CALIPSO_C_UNSPEC = 0,
	NLBL_CALIPSO_C_ADD = 1,
	NLBL_CALIPSO_C_REMOVE = 2,
	NLBL_CALIPSO_C_LIST = 3,
	NLBL_CALIPSO_C_LISTALL = 4,
	__NLBL_CALIPSO_C_MAX = 5,
};

enum {
	NLBL_CALIPSO_A_UNSPEC = 0,
	NLBL_CALIPSO_A_DOI = 1,
	NLBL_CALIPSO_A_MTYPE = 2,
	__NLBL_CALIPSO_A_MAX = 3,
};

struct netlbl_calipso_doiwalk_arg {
	struct netlink_callback___111 *nl_cb;
	struct sk_buff___112 *skb;
	u32 seq;
};

enum rfkill_type {
	RFKILL_TYPE_ALL = 0,
	RFKILL_TYPE_WLAN = 1,
	RFKILL_TYPE_BLUETOOTH = 2,
	RFKILL_TYPE_UWB = 3,
	RFKILL_TYPE_WIMAX = 4,
	RFKILL_TYPE_WWAN = 5,
	RFKILL_TYPE_GPS = 6,
	RFKILL_TYPE_FM = 7,
	RFKILL_TYPE_NFC = 8,
	NUM_RFKILL_TYPES = 9,
};

enum rfkill_operation {
	RFKILL_OP_ADD = 0,
	RFKILL_OP_DEL = 1,
	RFKILL_OP_CHANGE = 2,
	RFKILL_OP_CHANGE_ALL = 3,
};

enum rfkill_hard_block_reasons {
	RFKILL_HARD_BLOCK_SIGNAL = 1,
	RFKILL_HARD_BLOCK_NOT_OWNER = 2,
};

struct rfkill_event_ext {
	__u32 idx;
	__u8 type;
	__u8 op;
	__u8 soft;
	__u8 hard;
	__u8 hard_block_reasons;
} __attribute__((packed));

enum rfkill_user_states {
	RFKILL_USER_STATE_SOFT_BLOCKED = 0,
	RFKILL_USER_STATE_UNBLOCKED = 1,
	RFKILL_USER_STATE_HARD_BLOCKED = 2,
};

struct rfkill___2;

struct rfkill_ops {
	void (*poll)(struct rfkill___2 *, void *);
	void (*query)(struct rfkill___2 *, void *);
	int (*set_block)(void *, bool);
};

struct rfkill___2 {
	spinlock_t lock;
	enum rfkill_type type;
	long unsigned int state;
	long unsigned int hard_block_reasons;
	u32 idx;
	bool registered;
	bool persistent;
	bool polling_paused;
	bool suspended;
	const struct rfkill_ops *ops;
	void *data;
	struct led_trigger___9 led_trigger;
	const char *ledtrigname;
	struct device___215 dev;
	struct list_head node;
	struct delayed_work poll_work;
	struct work_struct uevent_work;
	struct work_struct sync_work;
	char name[0];
};

typedef struct poll_table_struct___160 poll_table___56;

struct rfkill_int_event {
	struct list_head list;
	struct rfkill_event_ext ev;
};

struct rfkill_data {
	struct list_head list;
	struct list_head events;
	struct mutex mtx;
	wait_queue_head_t read_wait;
	bool input_handler;
};

enum rfkill_input_master_mode {
	RFKILL_INPUT_MASTER_UNLOCK = 0,
	RFKILL_INPUT_MASTER_RESTORE = 1,
	RFKILL_INPUT_MASTER_UNBLOCKALL = 2,
	NUM_RFKILL_INPUT_MASTER_MODES = 3,
};

enum rfkill_sched_op {
	RFKILL_GLOBAL_OP_EPO = 0,
	RFKILL_GLOBAL_OP_RESTORE = 1,
	RFKILL_GLOBAL_OP_UNLOCK = 2,
	RFKILL_GLOBAL_OP_UNBLOCK = 3,
};

struct dcbmsg {
	__u8 dcb_family;
	__u8 cmd;
	__u16 dcb_pad;
};

enum dcbnl_commands {
	DCB_CMD_UNDEFINED = 0,
	DCB_CMD_GSTATE = 1,
	DCB_CMD_SSTATE = 2,
	DCB_CMD_PGTX_GCFG = 3,
	DCB_CMD_PGTX_SCFG = 4,
	DCB_CMD_PGRX_GCFG = 5,
	DCB_CMD_PGRX_SCFG = 6,
	DCB_CMD_PFC_GCFG = 7,
	DCB_CMD_PFC_SCFG = 8,
	DCB_CMD_SET_ALL = 9,
	DCB_CMD_GPERM_HWADDR = 10,
	DCB_CMD_GCAP = 11,
	DCB_CMD_GNUMTCS = 12,
	DCB_CMD_SNUMTCS = 13,
	DCB_CMD_PFC_GSTATE = 14,
	DCB_CMD_PFC_SSTATE = 15,
	DCB_CMD_BCN_GCFG = 16,
	DCB_CMD_BCN_SCFG = 17,
	DCB_CMD_GAPP = 18,
	DCB_CMD_SAPP = 19,
	DCB_CMD_IEEE_SET = 20,
	DCB_CMD_IEEE_GET = 21,
	DCB_CMD_GDCBX = 22,
	DCB_CMD_SDCBX = 23,
	DCB_CMD_GFEATCFG = 24,
	DCB_CMD_SFEATCFG = 25,
	DCB_CMD_CEE_GET = 26,
	DCB_CMD_IEEE_DEL = 27,
	__DCB_CMD_ENUM_MAX = 28,
	DCB_CMD_MAX = 27,
};

enum dcbnl_attrs {
	DCB_ATTR_UNDEFINED = 0,
	DCB_ATTR_IFNAME = 1,
	DCB_ATTR_STATE = 2,
	DCB_ATTR_PFC_STATE = 3,
	DCB_ATTR_PFC_CFG = 4,
	DCB_ATTR_NUM_TC = 5,
	DCB_ATTR_PG_CFG = 6,
	DCB_ATTR_SET_ALL = 7,
	DCB_ATTR_PERM_HWADDR = 8,
	DCB_ATTR_CAP = 9,
	DCB_ATTR_NUMTCS = 10,
	DCB_ATTR_BCN = 11,
	DCB_ATTR_APP = 12,
	DCB_ATTR_IEEE = 13,
	DCB_ATTR_DCBX = 14,
	DCB_ATTR_FEATCFG = 15,
	DCB_ATTR_CEE = 16,
	__DCB_ATTR_ENUM_MAX = 17,
	DCB_ATTR_MAX = 16,
};

enum ieee_attrs {
	DCB_ATTR_IEEE_UNSPEC = 0,
	DCB_ATTR_IEEE_ETS = 1,
	DCB_ATTR_IEEE_PFC = 2,
	DCB_ATTR_IEEE_APP_TABLE = 3,
	DCB_ATTR_IEEE_PEER_ETS = 4,
	DCB_ATTR_IEEE_PEER_PFC = 5,
	DCB_ATTR_IEEE_PEER_APP = 6,
	DCB_ATTR_IEEE_MAXRATE = 7,
	DCB_ATTR_IEEE_QCN = 8,
	DCB_ATTR_IEEE_QCN_STATS = 9,
	DCB_ATTR_DCB_BUFFER = 10,
	__DCB_ATTR_IEEE_MAX = 11,
};

enum ieee_attrs_app {
	DCB_ATTR_IEEE_APP_UNSPEC = 0,
	DCB_ATTR_IEEE_APP = 1,
	__DCB_ATTR_IEEE_APP_MAX = 2,
};

enum cee_attrs {
	DCB_ATTR_CEE_UNSPEC = 0,
	DCB_ATTR_CEE_PEER_PG = 1,
	DCB_ATTR_CEE_PEER_PFC = 2,
	DCB_ATTR_CEE_PEER_APP_TABLE = 3,
	DCB_ATTR_CEE_TX_PG = 4,
	DCB_ATTR_CEE_RX_PG = 5,
	DCB_ATTR_CEE_PFC = 6,
	DCB_ATTR_CEE_APP_TABLE = 7,
	DCB_ATTR_CEE_FEAT = 8,
	__DCB_ATTR_CEE_MAX = 9,
};

enum peer_app_attr {
	DCB_ATTR_CEE_PEER_APP_UNSPEC = 0,
	DCB_ATTR_CEE_PEER_APP_INFO = 1,
	DCB_ATTR_CEE_PEER_APP = 2,
	__DCB_ATTR_CEE_PEER_APP_MAX = 3,
};

enum dcbnl_pfc_up_attrs {
	DCB_PFC_UP_ATTR_UNDEFINED = 0,
	DCB_PFC_UP_ATTR_0 = 1,
	DCB_PFC_UP_ATTR_1 = 2,
	DCB_PFC_UP_ATTR_2 = 3,
	DCB_PFC_UP_ATTR_3 = 4,
	DCB_PFC_UP_ATTR_4 = 5,
	DCB_PFC_UP_ATTR_5 = 6,
	DCB_PFC_UP_ATTR_6 = 7,
	DCB_PFC_UP_ATTR_7 = 8,
	DCB_PFC_UP_ATTR_ALL = 9,
	__DCB_PFC_UP_ATTR_ENUM_MAX = 10,
	DCB_PFC_UP_ATTR_MAX = 9,
};

enum dcbnl_pg_attrs {
	DCB_PG_ATTR_UNDEFINED = 0,
	DCB_PG_ATTR_TC_0 = 1,
	DCB_PG_ATTR_TC_1 = 2,
	DCB_PG_ATTR_TC_2 = 3,
	DCB_PG_ATTR_TC_3 = 4,
	DCB_PG_ATTR_TC_4 = 5,
	DCB_PG_ATTR_TC_5 = 6,
	DCB_PG_ATTR_TC_6 = 7,
	DCB_PG_ATTR_TC_7 = 8,
	DCB_PG_ATTR_TC_MAX = 9,
	DCB_PG_ATTR_TC_ALL = 10,
	DCB_PG_ATTR_BW_ID_0 = 11,
	DCB_PG_ATTR_BW_ID_1 = 12,
	DCB_PG_ATTR_BW_ID_2 = 13,
	DCB_PG_ATTR_BW_ID_3 = 14,
	DCB_PG_ATTR_BW_ID_4 = 15,
	DCB_PG_ATTR_BW_ID_5 = 16,
	DCB_PG_ATTR_BW_ID_6 = 17,
	DCB_PG_ATTR_BW_ID_7 = 18,
	DCB_PG_ATTR_BW_ID_MAX = 19,
	DCB_PG_ATTR_BW_ID_ALL = 20,
	__DCB_PG_ATTR_ENUM_MAX = 21,
	DCB_PG_ATTR_MAX = 20,
};

enum dcbnl_tc_attrs {
	DCB_TC_ATTR_PARAM_UNDEFINED = 0,
	DCB_TC_ATTR_PARAM_PGID = 1,
	DCB_TC_ATTR_PARAM_UP_MAPPING = 2,
	DCB_TC_ATTR_PARAM_STRICT_PRIO = 3,
	DCB_TC_ATTR_PARAM_BW_PCT = 4,
	DCB_TC_ATTR_PARAM_ALL = 5,
	__DCB_TC_ATTR_PARAM_ENUM_MAX = 6,
	DCB_TC_ATTR_PARAM_MAX = 5,
};

enum dcbnl_cap_attrs {
	DCB_CAP_ATTR_UNDEFINED = 0,
	DCB_CAP_ATTR_ALL = 1,
	DCB_CAP_ATTR_PG = 2,
	DCB_CAP_ATTR_PFC = 3,
	DCB_CAP_ATTR_UP2TC = 4,
	DCB_CAP_ATTR_PG_TCS = 5,
	DCB_CAP_ATTR_PFC_TCS = 6,
	DCB_CAP_ATTR_GSP = 7,
	DCB_CAP_ATTR_BCN = 8,
	DCB_CAP_ATTR_DCBX = 9,
	__DCB_CAP_ATTR_ENUM_MAX = 10,
	DCB_CAP_ATTR_MAX = 9,
};

enum dcbnl_numtcs_attrs {
	DCB_NUMTCS_ATTR_UNDEFINED = 0,
	DCB_NUMTCS_ATTR_ALL = 1,
	DCB_NUMTCS_ATTR_PG = 2,
	DCB_NUMTCS_ATTR_PFC = 3,
	__DCB_NUMTCS_ATTR_ENUM_MAX = 4,
	DCB_NUMTCS_ATTR_MAX = 3,
};

enum dcbnl_bcn_attrs {
	DCB_BCN_ATTR_UNDEFINED = 0,
	DCB_BCN_ATTR_RP_0 = 1,
	DCB_BCN_ATTR_RP_1 = 2,
	DCB_BCN_ATTR_RP_2 = 3,
	DCB_BCN_ATTR_RP_3 = 4,
	DCB_BCN_ATTR_RP_4 = 5,
	DCB_BCN_ATTR_RP_5 = 6,
	DCB_BCN_ATTR_RP_6 = 7,
	DCB_BCN_ATTR_RP_7 = 8,
	DCB_BCN_ATTR_RP_ALL = 9,
	DCB_BCN_ATTR_BCNA_0 = 10,
	DCB_BCN_ATTR_BCNA_1 = 11,
	DCB_BCN_ATTR_ALPHA = 12,
	DCB_BCN_ATTR_BETA = 13,
	DCB_BCN_ATTR_GD = 14,
	DCB_BCN_ATTR_GI = 15,
	DCB_BCN_ATTR_TMAX = 16,
	DCB_BCN_ATTR_TD = 17,
	DCB_BCN_ATTR_RMIN = 18,
	DCB_BCN_ATTR_W = 19,
	DCB_BCN_ATTR_RD = 20,
	DCB_BCN_ATTR_RU = 21,
	DCB_BCN_ATTR_WRTT = 22,
	DCB_BCN_ATTR_RI = 23,
	DCB_BCN_ATTR_C = 24,
	DCB_BCN_ATTR_ALL = 25,
	__DCB_BCN_ATTR_ENUM_MAX = 26,
	DCB_BCN_ATTR_MAX = 25,
};

enum dcb_general_attr_values {
	DCB_ATTR_VALUE_UNDEFINED = 255,
};

enum dcbnl_app_attrs {
	DCB_APP_ATTR_UNDEFINED = 0,
	DCB_APP_ATTR_IDTYPE = 1,
	DCB_APP_ATTR_ID = 2,
	DCB_APP_ATTR_PRIORITY = 3,
	__DCB_APP_ATTR_ENUM_MAX = 4,
	DCB_APP_ATTR_MAX = 3,
};

enum dcbnl_featcfg_attrs {
	DCB_FEATCFG_ATTR_UNDEFINED = 0,
	DCB_FEATCFG_ATTR_ALL = 1,
	DCB_FEATCFG_ATTR_PG = 2,
	DCB_FEATCFG_ATTR_PFC = 3,
	DCB_FEATCFG_ATTR_APP = 4,
	__DCB_FEATCFG_ATTR_ENUM_MAX = 5,
	DCB_FEATCFG_ATTR_MAX = 4,
};

struct dcb_app_type {
	int ifindex;
	struct dcb_app app;
	struct list_head list;
	u8 dcbx;
};

struct dcb_ieee_app_prio_map {
	u64 map[8];
};

struct dcb_ieee_app_dscp_map {
	u8 map[64];
};

enum dcbevent_notif_type {
	DCB_APP_EVENT = 1,
};

struct reply_func {
	int type;
	int (*cb)(struct net_device___98 *, struct nlmsghdr *, u32, struct nlattr **, struct sk_buff___99 *);
};

enum dns_payload_content_type {
	DNS_PAYLOAD_IS_SERVER_LIST = 0,
};

struct dns_payload_header {
	__u8 zero;
	__u8 content;
	__u8 version;
};

enum {
	dns_key_data = 0,
	dns_key_error = 1,
};

enum switchdev_attr_id {
	SWITCHDEV_ATTR_ID_UNDEFINED = 0,
	SWITCHDEV_ATTR_ID_PORT_STP_STATE = 1,
	SWITCHDEV_ATTR_ID_PORT_BRIDGE_FLAGS = 2,
	SWITCHDEV_ATTR_ID_PORT_PRE_BRIDGE_FLAGS = 3,
	SWITCHDEV_ATTR_ID_PORT_MROUTER = 4,
	SWITCHDEV_ATTR_ID_BRIDGE_AGEING_TIME = 5,
	SWITCHDEV_ATTR_ID_BRIDGE_VLAN_FILTERING = 6,
	SWITCHDEV_ATTR_ID_BRIDGE_VLAN_PROTOCOL = 7,
	SWITCHDEV_ATTR_ID_BRIDGE_MC_DISABLED = 8,
	SWITCHDEV_ATTR_ID_BRIDGE_MROUTER = 9,
	SWITCHDEV_ATTR_ID_MRP_PORT_ROLE = 10,
};

struct switchdev_attr {
	struct net_device___98 *orig_dev;
	enum switchdev_attr_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___98 *, int, void *);
	union {
		u8 stp_state;
		struct switchdev_brport_flags brport_flags;
		bool mrouter;
		clock_t ageing_time;
		bool vlan_filtering;
		u16 vlan_protocol;
		bool mc_disabled;
		u8 mrp_port_role;
	} u;
};

struct switchdev_obj___6 {
	struct list_head list;
	struct net_device___98 *orig_dev;
	enum switchdev_obj_id id;
	u32 flags;
	void *complete_priv;
	void (*complete)(struct net_device___98 *, int, void *);
};

struct switchdev_brport {
	struct net_device___98 *dev;
	const void *ctx;
	struct notifier_block *atomic_nb;
	struct notifier_block *blocking_nb;
	bool tx_fwd_offload;
};

enum switchdev_notifier_type {
	SWITCHDEV_FDB_ADD_TO_BRIDGE = 1,
	SWITCHDEV_FDB_DEL_TO_BRIDGE = 2,
	SWITCHDEV_FDB_ADD_TO_DEVICE = 3,
	SWITCHDEV_FDB_DEL_TO_DEVICE = 4,
	SWITCHDEV_FDB_OFFLOADED = 5,
	SWITCHDEV_FDB_FLUSH_TO_BRIDGE = 6,
	SWITCHDEV_PORT_OBJ_ADD = 7,
	SWITCHDEV_PORT_OBJ_DEL = 8,
	SWITCHDEV_PORT_ATTR_SET = 9,
	SWITCHDEV_VXLAN_FDB_ADD_TO_BRIDGE = 10,
	SWITCHDEV_VXLAN_FDB_DEL_TO_BRIDGE = 11,
	SWITCHDEV_VXLAN_FDB_ADD_TO_DEVICE = 12,
	SWITCHDEV_VXLAN_FDB_DEL_TO_DEVICE = 13,
	SWITCHDEV_VXLAN_FDB_OFFLOADED = 14,
	SWITCHDEV_BRPORT_OFFLOADED = 15,
	SWITCHDEV_BRPORT_UNOFFLOADED = 16,
};

struct switchdev_notifier_info {
	struct net_device___98 *dev;
	struct netlink_ext_ack *extack;
	const void *ctx;
};

struct switchdev_notifier_fdb_info {
	struct switchdev_notifier_info info;
	const unsigned char *addr;
	u16 vid;
	u8 added_by_user;
	u8 is_local;
	u8 offloaded;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct switchdev_notifier_port_obj_info {
	struct switchdev_notifier_info info;
	const struct switchdev_obj___6 *obj;
	bool handled;
};

struct switchdev_notifier_port_attr_info {
	struct switchdev_notifier_info info;
	const struct switchdev_attr *attr;
	bool handled;
};

struct switchdev_notifier_brport_info {
	struct switchdev_notifier_info info;
	const struct switchdev_brport brport;
};

typedef void switchdev_deferred_func_t(struct net_device___98 *, const void *);

struct switchdev_deferred_item {
	struct list_head list;
	struct net_device___98 *dev;
	switchdev_deferred_func_t *func;
	long unsigned int data[0];
};

struct switchdev_nested_priv {
	bool (*check_cb)(const struct net_device___98 *);
	bool (*foreign_dev_check_cb)(const struct net_device___98 *, const struct net_device___98 *);
	const struct net_device___98 *dev;
	struct net_device___98 *lower_dev;
};

typedef int (*lookup_by_table_id_t)(struct net___79 *, u32);

struct l3mdev_handler {
	lookup_by_table_id_t dev_lookup;
};

struct packet_type___10 {
	__be16 type;
	bool ignore_outgoing;
	struct net_device___111 *dev;
	int (*func)(struct sk_buff___112 *, struct net_device___111 *, struct packet_type___10 *, struct net_device___111 *);
	void (*list_func)(struct list_head *, struct packet_type___10 *, struct net_device___111 *);
	bool (*id_match)(struct packet_type___10 *, struct sock___95 *);
	struct net___116 *af_packet_net;
	void *af_packet_priv;
	struct list_head list;
};

struct ncsi_dev {
	int state;
	int link_up;
	struct net_device___111 *dev;
	void (*handler)(struct ncsi_dev *);
};

struct ncsi_channel_version {
	u32 version;
	u32 alpha2;
	u8 fw_name[12];
	u32 fw_version;
	u16 pci_ids[4];
	u32 mf_id;
};

struct ncsi_channel_cap {
	u32 index;
	u32 cap;
};

struct ncsi_channel_mode {
	u32 index;
	u32 enable;
	u32 size;
	u32 data[8];
};

struct ncsi_channel_mac_filter {
	u8 n_uc;
	u8 n_mc;
	u8 n_mixed;
	u64 bitmap;
	unsigned char *addrs;
};

struct ncsi_channel_vlan_filter {
	u8 n_vids;
	u64 bitmap;
	u16 *vids;
};

struct ncsi_channel_stats {
	u32 hnc_cnt_hi;
	u32 hnc_cnt_lo;
	u32 hnc_rx_bytes;
	u32 hnc_tx_bytes;
	u32 hnc_rx_uc_pkts;
	u32 hnc_rx_mc_pkts;
	u32 hnc_rx_bc_pkts;
	u32 hnc_tx_uc_pkts;
	u32 hnc_tx_mc_pkts;
	u32 hnc_tx_bc_pkts;
	u32 hnc_fcs_err;
	u32 hnc_align_err;
	u32 hnc_false_carrier;
	u32 hnc_runt_pkts;
	u32 hnc_jabber_pkts;
	u32 hnc_rx_pause_xon;
	u32 hnc_rx_pause_xoff;
	u32 hnc_tx_pause_xon;
	u32 hnc_tx_pause_xoff;
	u32 hnc_tx_s_collision;
	u32 hnc_tx_m_collision;
	u32 hnc_l_collision;
	u32 hnc_e_collision;
	u32 hnc_rx_ctl_frames;
	u32 hnc_rx_64_frames;
	u32 hnc_rx_127_frames;
	u32 hnc_rx_255_frames;
	u32 hnc_rx_511_frames;
	u32 hnc_rx_1023_frames;
	u32 hnc_rx_1522_frames;
	u32 hnc_rx_9022_frames;
	u32 hnc_tx_64_frames;
	u32 hnc_tx_127_frames;
	u32 hnc_tx_255_frames;
	u32 hnc_tx_511_frames;
	u32 hnc_tx_1023_frames;
	u32 hnc_tx_1522_frames;
	u32 hnc_tx_9022_frames;
	u32 hnc_rx_valid_bytes;
	u32 hnc_rx_runt_pkts;
	u32 hnc_rx_jabber_pkts;
	u32 ncsi_rx_cmds;
	u32 ncsi_dropped_cmds;
	u32 ncsi_cmd_type_errs;
	u32 ncsi_cmd_csum_errs;
	u32 ncsi_rx_pkts;
	u32 ncsi_tx_pkts;
	u32 ncsi_tx_aen_pkts;
	u32 pt_tx_pkts;
	u32 pt_tx_dropped;
	u32 pt_tx_channel_err;
	u32 pt_tx_us_err;
	u32 pt_rx_pkts;
	u32 pt_rx_dropped;
	u32 pt_rx_channel_err;
	u32 pt_rx_us_err;
	u32 pt_rx_os_err;
};

struct ncsi_package;

struct ncsi_channel {
	unsigned char id;
	int state;
	bool reconfigure_needed;
	spinlock_t lock;
	struct ncsi_package *package;
	struct ncsi_channel_version version;
	struct ncsi_channel_cap caps[6];
	struct ncsi_channel_mode modes[8];
	struct ncsi_channel_mac_filter mac_filter;
	struct ncsi_channel_vlan_filter vlan_filter;
	struct ncsi_channel_stats stats;
	struct {
		struct timer_list timer;
		bool enabled;
		unsigned int state;
	} monitor;
	struct list_head node;
	struct list_head link;
};

struct ncsi_dev_priv;

struct ncsi_package {
	unsigned char id;
	unsigned char uuid[16];
	struct ncsi_dev_priv *ndp;
	spinlock_t lock;
	unsigned int channel_num;
	struct list_head channels;
	struct list_head node;
	bool multi_channel;
	u32 channel_whitelist;
	struct ncsi_channel *preferred_channel;
};

struct ncsi_request {
	unsigned char id;
	bool used;
	unsigned int flags;
	struct ncsi_dev_priv *ndp;
	struct sk_buff___112 *cmd;
	struct sk_buff___112 *rsp;
	struct timer_list timer;
	bool enabled;
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr nlhdr;
};

struct ncsi_dev_priv {
	struct ncsi_dev ndev;
	unsigned int flags;
	unsigned int gma_flag;
	spinlock_t lock;
	unsigned int package_probe_id;
	unsigned int package_num;
	struct list_head packages;
	struct ncsi_channel *hot_channel;
	struct ncsi_request requests[256];
	unsigned int request_id;
	unsigned int pending_req_num;
	struct ncsi_package *active_package;
	struct ncsi_channel *active_channel;
	struct list_head channel_queue;
	struct work_struct work;
	struct packet_type___10 ptype;
	struct list_head node;
	struct list_head vlan_vids;
	bool multi_package;
	bool mlx_multi_host;
	u32 package_whitelist;
};

struct ncsi_cmd_arg {
	struct ncsi_dev_priv *ndp;
	unsigned char type;
	unsigned char id;
	unsigned char package;
	unsigned char channel;
	short unsigned int payload;
	unsigned int req_flags;
	union {
		unsigned char bytes[16];
		short unsigned int words[8];
		unsigned int dwords[4];
	};
	unsigned char *data;
	struct genl_info___9 *info;
};

struct ncsi_pkt_hdr {
	unsigned char mc_id;
	unsigned char revision;
	unsigned char reserved;
	unsigned char id;
	unsigned char type;
	unsigned char channel;
	__be16 length;
	__be32 reserved1[2];
};

struct ncsi_cmd_pkt_hdr {
	struct ncsi_pkt_hdr common;
};

struct ncsi_cmd_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be32 checksum;
	unsigned char pad[26];
};

struct ncsi_cmd_sp_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	unsigned char reserved[3];
	unsigned char hw_arbitration;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_dc_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	unsigned char reserved[3];
	unsigned char ald;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_rc_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be32 reserved;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_ae_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	unsigned char reserved[3];
	unsigned char mc_id;
	__be32 mode;
	__be32 checksum;
	unsigned char pad[18];
};

struct ncsi_cmd_sl_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be32 mode;
	__be32 oem_mode;
	__be32 checksum;
	unsigned char pad[18];
};

struct ncsi_cmd_svf_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be16 reserved;
	__be16 vlan;
	__be16 reserved1;
	unsigned char index;
	unsigned char enable;
	__be32 checksum;
	unsigned char pad[18];
};

struct ncsi_cmd_ev_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	unsigned char reserved[3];
	unsigned char mode;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_sma_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	unsigned char mac[6];
	unsigned char index;
	unsigned char at_e;
	__be32 checksum;
	unsigned char pad[18];
};

struct ncsi_cmd_ebf_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be32 mode;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_egmf_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be32 mode;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_snfc_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	unsigned char reserved[3];
	unsigned char mode;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_cmd_oem_pkt {
	struct ncsi_cmd_pkt_hdr cmd;
	__be32 mfr_id;
	unsigned char data[0];
};

struct ncsi_cmd_handler {
	unsigned char type;
	int payload;
	int (*handler)(struct sk_buff___112 *, struct ncsi_cmd_arg *);
};

struct ncsi_dev___2 {
	int state;
	int link_up;
	struct net_device___103 *dev;
	void (*handler)(struct ncsi_dev___2 *);
};

enum {
	NCSI_CAP_BASE = 0,
	NCSI_CAP_GENERIC = 0,
	NCSI_CAP_BC = 1,
	NCSI_CAP_MC = 2,
	NCSI_CAP_BUFFER = 3,
	NCSI_CAP_AEN = 4,
	NCSI_CAP_VLAN = 5,
	NCSI_CAP_MAX = 6,
};

enum {
	NCSI_CAP_GENERIC_HWA = 1,
	NCSI_CAP_GENERIC_HDS = 2,
	NCSI_CAP_GENERIC_FC = 4,
	NCSI_CAP_GENERIC_FC1 = 8,
	NCSI_CAP_GENERIC_MC = 16,
	NCSI_CAP_GENERIC_HWA_UNKNOWN = 0,
	NCSI_CAP_GENERIC_HWA_SUPPORT = 32,
	NCSI_CAP_GENERIC_HWA_NOT_SUPPORT = 64,
	NCSI_CAP_GENERIC_HWA_RESERVED = 96,
	NCSI_CAP_GENERIC_HWA_MASK = 96,
	NCSI_CAP_GENERIC_MASK = 127,
	NCSI_CAP_BC_ARP = 1,
	NCSI_CAP_BC_DHCPC = 2,
	NCSI_CAP_BC_DHCPS = 4,
	NCSI_CAP_BC_NETBIOS = 8,
	NCSI_CAP_BC_MASK = 15,
	NCSI_CAP_MC_IPV6_NEIGHBOR = 1,
	NCSI_CAP_MC_IPV6_ROUTER = 2,
	NCSI_CAP_MC_DHCPV6_RELAY = 4,
	NCSI_CAP_MC_DHCPV6_WELL_KNOWN = 8,
	NCSI_CAP_MC_IPV6_MLD = 16,
	NCSI_CAP_MC_IPV6_NEIGHBOR_S = 32,
	NCSI_CAP_MC_MASK = 63,
	NCSI_CAP_AEN_LSC = 1,
	NCSI_CAP_AEN_CR = 2,
	NCSI_CAP_AEN_HDS = 4,
	NCSI_CAP_AEN_MASK = 7,
	NCSI_CAP_VLAN_ONLY = 1,
	NCSI_CAP_VLAN_NO = 2,
	NCSI_CAP_VLAN_ANY = 4,
	NCSI_CAP_VLAN_MASK = 7,
};

enum {
	NCSI_MODE_BASE = 0,
	NCSI_MODE_ENABLE = 0,
	NCSI_MODE_TX_ENABLE = 1,
	NCSI_MODE_LINK = 2,
	NCSI_MODE_VLAN = 3,
	NCSI_MODE_BC = 4,
	NCSI_MODE_MC = 5,
	NCSI_MODE_AEN = 6,
	NCSI_MODE_FC = 7,
	NCSI_MODE_MAX = 8,
};

struct ncsi_package___2;

struct ncsi_channel___2 {
	unsigned char id;
	int state;
	bool reconfigure_needed;
	spinlock_t lock;
	struct ncsi_package___2 *package;
	struct ncsi_channel_version version;
	struct ncsi_channel_cap caps[6];
	struct ncsi_channel_mode modes[8];
	struct ncsi_channel_mac_filter mac_filter;
	struct ncsi_channel_vlan_filter vlan_filter;
	struct ncsi_channel_stats stats;
	struct {
		struct timer_list timer;
		bool enabled;
		unsigned int state;
	} monitor;
	struct list_head node;
	struct list_head link;
};

struct ncsi_dev_priv___2;

struct ncsi_package___2 {
	unsigned char id;
	unsigned char uuid[16];
	struct ncsi_dev_priv___2 *ndp;
	spinlock_t lock;
	unsigned int channel_num;
	struct list_head channels;
	struct list_head node;
	bool multi_channel;
	u32 channel_whitelist;
	struct ncsi_channel___2 *preferred_channel;
};

struct ncsi_request___2 {
	unsigned char id;
	bool used;
	unsigned int flags;
	struct ncsi_dev_priv___2 *ndp;
	struct sk_buff___104 *cmd;
	struct sk_buff___104 *rsp;
	struct timer_list timer;
	bool enabled;
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr nlhdr;
};

struct ncsi_dev_priv___2 {
	struct ncsi_dev___2 ndev;
	unsigned int flags;
	unsigned int gma_flag;
	spinlock_t lock;
	unsigned int package_probe_id;
	unsigned int package_num;
	struct list_head packages;
	struct ncsi_channel___2 *hot_channel;
	struct ncsi_request___2 requests[256];
	unsigned int request_id;
	unsigned int pending_req_num;
	struct ncsi_package___2 *active_package;
	struct ncsi_channel___2 *active_channel;
	struct list_head channel_queue;
	struct work_struct work;
	struct packet_type___5 ptype;
	struct list_head node;
	struct list_head vlan_vids;
	bool multi_package;
	bool mlx_multi_host;
	u32 package_whitelist;
};

struct ncsi_rsp_pkt_hdr {
	struct ncsi_pkt_hdr common;
	__be16 code;
	__be16 reason;
};

struct ncsi_rsp_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 checksum;
	unsigned char pad[22];
};

struct ncsi_rsp_oem_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 mfr_id;
	unsigned char data[0];
};

struct ncsi_rsp_oem_mlx_pkt {
	unsigned char cmd_rev;
	unsigned char cmd;
	unsigned char param;
	unsigned char optional;
	unsigned char data[0];
};

struct ncsi_rsp_oem_bcm_pkt {
	unsigned char ver;
	unsigned char type;
	__be16 len;
	unsigned char data[0];
};

struct ncsi_rsp_oem_intel_pkt {
	unsigned char cmd;
	unsigned char data[0];
};

struct ncsi_rsp_gls_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 status;
	__be32 other;
	__be32 oem_status;
	__be32 checksum;
	unsigned char pad[10];
};

struct ncsi_rsp_gvi_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 ncsi_version;
	unsigned char reserved[3];
	unsigned char alpha2;
	unsigned char fw_name[12];
	__be32 fw_version;
	__be16 pci_ids[4];
	__be32 mf_id;
	__be32 checksum;
};

struct ncsi_rsp_gc_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 cap;
	__be32 bc_cap;
	__be32 mc_cap;
	__be32 buf_cap;
	__be32 aen_cap;
	unsigned char vlan_cnt;
	unsigned char mixed_cnt;
	unsigned char mc_cnt;
	unsigned char uc_cnt;
	unsigned char reserved[2];
	unsigned char vlan_mode;
	unsigned char channel_cnt;
	__be32 checksum;
};

struct ncsi_rsp_gp_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	unsigned char mac_cnt;
	unsigned char reserved[2];
	unsigned char mac_enable;
	unsigned char vlan_cnt;
	unsigned char reserved1;
	__be16 vlan_enable;
	__be32 link_mode;
	__be32 bc_mode;
	__be32 valid_modes;
	unsigned char vlan_mode;
	unsigned char fc_mode;
	unsigned char reserved2[2];
	__be32 aen_mode;
	unsigned char mac[6];
	__be16 vlan;
	__be32 checksum;
};

struct ncsi_rsp_gcps_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 cnt_hi;
	__be32 cnt_lo;
	__be32 rx_bytes;
	__be32 tx_bytes;
	__be32 rx_uc_pkts;
	__be32 rx_mc_pkts;
	__be32 rx_bc_pkts;
	__be32 tx_uc_pkts;
	__be32 tx_mc_pkts;
	__be32 tx_bc_pkts;
	__be32 fcs_err;
	__be32 align_err;
	__be32 false_carrier;
	__be32 runt_pkts;
	__be32 jabber_pkts;
	__be32 rx_pause_xon;
	__be32 rx_pause_xoff;
	__be32 tx_pause_xon;
	__be32 tx_pause_xoff;
	__be32 tx_s_collision;
	__be32 tx_m_collision;
	__be32 l_collision;
	__be32 e_collision;
	__be32 rx_ctl_frames;
	__be32 rx_64_frames;
	__be32 rx_127_frames;
	__be32 rx_255_frames;
	__be32 rx_511_frames;
	__be32 rx_1023_frames;
	__be32 rx_1522_frames;
	__be32 rx_9022_frames;
	__be32 tx_64_frames;
	__be32 tx_127_frames;
	__be32 tx_255_frames;
	__be32 tx_511_frames;
	__be32 tx_1023_frames;
	__be32 tx_1522_frames;
	__be32 tx_9022_frames;
	__be32 rx_valid_bytes;
	__be32 rx_runt_pkts;
	__be32 rx_jabber_pkts;
	__be32 checksum;
};

struct ncsi_rsp_gns_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 rx_cmds;
	__be32 dropped_cmds;
	__be32 cmd_type_errs;
	__be32 cmd_csum_errs;
	__be32 rx_pkts;
	__be32 tx_pkts;
	__be32 tx_aen_pkts;
	__be32 checksum;
};

struct ncsi_rsp_gnpts_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 tx_pkts;
	__be32 tx_dropped;
	__be32 tx_channel_err;
	__be32 tx_us_err;
	__be32 rx_pkts;
	__be32 rx_dropped;
	__be32 rx_channel_err;
	__be32 rx_us_err;
	__be32 rx_os_err;
	__be32 checksum;
};

struct ncsi_rsp_gps_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	__be32 status;
	__be32 checksum;
};

struct ncsi_rsp_gpuuid_pkt {
	struct ncsi_rsp_pkt_hdr rsp;
	unsigned char uuid[16];
	__be32 checksum;
};

struct ncsi_rsp_oem_handler {
	unsigned int mfr_id;
	int (*handler)(struct ncsi_request___2 *);
};

struct ncsi_rsp_handler {
	unsigned char type;
	int payload;
	int (*handler)(struct ncsi_request___2 *);
};

struct ncsi_dev___3 {
	int state;
	int link_up;
	struct net_device___107 *dev;
	void (*handler)(struct ncsi_dev___3 *);
};

struct ncsi_package___3;

struct ncsi_channel___3 {
	unsigned char id;
	int state;
	bool reconfigure_needed;
	spinlock_t lock;
	struct ncsi_package___3 *package;
	struct ncsi_channel_version version;
	struct ncsi_channel_cap caps[6];
	struct ncsi_channel_mode modes[8];
	struct ncsi_channel_mac_filter mac_filter;
	struct ncsi_channel_vlan_filter vlan_filter;
	struct ncsi_channel_stats stats;
	struct {
		struct timer_list timer;
		bool enabled;
		unsigned int state;
	} monitor;
	struct list_head node;
	struct list_head link;
};

struct ncsi_dev_priv___3;

struct ncsi_package___3 {
	unsigned char id;
	unsigned char uuid[16];
	struct ncsi_dev_priv___3 *ndp;
	spinlock_t lock;
	unsigned int channel_num;
	struct list_head channels;
	struct list_head node;
	bool multi_channel;
	u32 channel_whitelist;
	struct ncsi_channel___3 *preferred_channel;
};

struct ncsi_request___3 {
	unsigned char id;
	bool used;
	unsigned int flags;
	struct ncsi_dev_priv___3 *ndp;
	struct sk_buff___108 *cmd;
	struct sk_buff___108 *rsp;
	struct timer_list timer;
	bool enabled;
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr nlhdr;
};

struct ncsi_dev_priv___3 {
	struct ncsi_dev___3 ndev;
	unsigned int flags;
	unsigned int gma_flag;
	spinlock_t lock;
	unsigned int package_probe_id;
	unsigned int package_num;
	struct list_head packages;
	struct ncsi_channel___3 *hot_channel;
	struct ncsi_request___3 requests[256];
	unsigned int request_id;
	unsigned int pending_req_num;
	struct ncsi_package___3 *active_package;
	struct ncsi_channel___3 *active_channel;
	struct list_head channel_queue;
	struct work_struct work;
	struct packet_type___7 ptype;
	struct list_head node;
	struct list_head vlan_vids;
	bool multi_package;
	bool mlx_multi_host;
	u32 package_whitelist;
};

struct ncsi_aen_pkt_hdr {
	struct ncsi_pkt_hdr common;
	unsigned char reserved2[3];
	unsigned char type;
};

struct ncsi_aen_lsc_pkt {
	struct ncsi_aen_pkt_hdr aen;
	__be32 status;
	__be32 oem_status;
	__be32 checksum;
	unsigned char pad[14];
};

struct ncsi_aen_hncdsc_pkt {
	struct ncsi_aen_pkt_hdr aen;
	__be32 status;
	__be32 checksum;
	unsigned char pad[18];
};

struct ncsi_aen_handler {
	unsigned char type;
	int payload;
	int (*handler)(struct ncsi_dev_priv___3 *, struct ncsi_aen_pkt_hdr *);
};

struct platform_device___46 {
	const char *name;
	int id;
	bool id_auto;
	struct device___224 dev;
	u64 platform_dma_mask;
	struct device_dma_parameters dma_parms;
	u32 num_resources;
	struct resource *resource;
	const struct platform_device_id *id_entry;
	char *driver_override;
	struct mfd_cell *mfd_cell;
	struct pdev_archdata archdata;
};

enum {
	ncsi_dev_state_registered = 0,
	ncsi_dev_state_functional = 256,
	ncsi_dev_state_probe = 512,
	ncsi_dev_state_config = 768,
	ncsi_dev_state_suspend = 1024,
};

struct ncsi_dev___4 {
	int state;
	int link_up;
	struct net_device___6 *dev;
	void (*handler)(struct ncsi_dev___4 *);
};

enum {
	MLX_MC_RBT_SUPPORT = 1,
	MLX_MC_RBT_AVL = 8,
};

struct ncsi_package___4;

struct ncsi_channel___4 {
	unsigned char id;
	int state;
	bool reconfigure_needed;
	spinlock_t lock;
	struct ncsi_package___4 *package;
	struct ncsi_channel_version version;
	struct ncsi_channel_cap caps[6];
	struct ncsi_channel_mode modes[8];
	struct ncsi_channel_mac_filter mac_filter;
	struct ncsi_channel_vlan_filter vlan_filter;
	struct ncsi_channel_stats stats;
	struct {
		struct timer_list timer;
		bool enabled;
		unsigned int state;
	} monitor;
	struct list_head node;
	struct list_head link;
};

struct ncsi_dev_priv___4;

struct ncsi_package___4 {
	unsigned char id;
	unsigned char uuid[16];
	struct ncsi_dev_priv___4 *ndp;
	spinlock_t lock;
	unsigned int channel_num;
	struct list_head channels;
	struct list_head node;
	bool multi_channel;
	u32 channel_whitelist;
	struct ncsi_channel___4 *preferred_channel;
};

struct ncsi_request___4 {
	unsigned char id;
	bool used;
	unsigned int flags;
	struct ncsi_dev_priv___4 *ndp;
	struct sk_buff___53 *cmd;
	struct sk_buff___53 *rsp;
	struct timer_list timer;
	bool enabled;
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr nlhdr;
};

struct ncsi_dev_priv___4 {
	struct ncsi_dev___4 ndev;
	unsigned int flags;
	unsigned int gma_flag;
	spinlock_t lock;
	unsigned int package_probe_id;
	unsigned int package_num;
	struct list_head packages;
	struct ncsi_channel___4 *hot_channel;
	struct ncsi_request___4 requests[256];
	unsigned int request_id;
	unsigned int pending_req_num;
	struct ncsi_package___4 *active_package;
	struct ncsi_channel___4 *active_channel;
	struct list_head channel_queue;
	struct work_struct work;
	struct packet_type ptype;
	struct list_head node;
	struct list_head vlan_vids;
	bool multi_package;
	bool mlx_multi_host;
	u32 package_whitelist;
};

enum {
	ncsi_dev_state_major = 65280,
	ncsi_dev_state_minor = 255,
	ncsi_dev_state_probe_deselect = 513,
	ncsi_dev_state_probe_package = 514,
	ncsi_dev_state_probe_channel = 515,
	ncsi_dev_state_probe_mlx_gma = 516,
	ncsi_dev_state_probe_mlx_smaf = 517,
	ncsi_dev_state_probe_cis = 518,
	ncsi_dev_state_probe_keep_phy = 519,
	ncsi_dev_state_probe_gvi = 520,
	ncsi_dev_state_probe_gc = 521,
	ncsi_dev_state_probe_gls = 522,
	ncsi_dev_state_probe_dp = 523,
	ncsi_dev_state_config_sp = 769,
	ncsi_dev_state_config_cis = 770,
	ncsi_dev_state_config_oem_gma = 771,
	ncsi_dev_state_config_clear_vids = 772,
	ncsi_dev_state_config_svf = 773,
	ncsi_dev_state_config_ev = 774,
	ncsi_dev_state_config_sma = 775,
	ncsi_dev_state_config_ebf = 776,
	ncsi_dev_state_config_dgmf = 777,
	ncsi_dev_state_config_ecnt = 778,
	ncsi_dev_state_config_ec = 779,
	ncsi_dev_state_config_ae = 780,
	ncsi_dev_state_config_gls = 781,
	ncsi_dev_state_config_done = 782,
	ncsi_dev_state_suspend_select = 1025,
	ncsi_dev_state_suspend_gls = 1026,
	ncsi_dev_state_suspend_dcnt = 1027,
	ncsi_dev_state_suspend_dc = 1028,
	ncsi_dev_state_suspend_deselect = 1029,
	ncsi_dev_state_suspend_done = 1030,
};

struct vlan_vid {
	struct list_head list;
	__be16 proto;
	u16 vid;
};

struct ncsi_cmd_arg___2 {
	struct ncsi_dev_priv___4 *ndp;
	unsigned char type;
	unsigned char id;
	unsigned char package;
	unsigned char channel;
	short unsigned int payload;
	unsigned int req_flags;
	union {
		unsigned char bytes[16];
		short unsigned int words[8];
		unsigned int dwords[4];
	};
	unsigned char *data;
	struct genl_info___7 *info;
};

struct ncsi_oem_gma_handler {
	unsigned int mfr_id;
	int (*handler)(struct ncsi_cmd_arg___2 *);
};

enum ncsi_nl_commands {
	NCSI_CMD_UNSPEC = 0,
	NCSI_CMD_PKG_INFO = 1,
	NCSI_CMD_SET_INTERFACE = 2,
	NCSI_CMD_CLEAR_INTERFACE = 3,
	NCSI_CMD_SEND_CMD = 4,
	NCSI_CMD_SET_PACKAGE_MASK = 5,
	NCSI_CMD_SET_CHANNEL_MASK = 6,
	__NCSI_CMD_AFTER_LAST = 7,
	NCSI_CMD_MAX = 6,
};

enum ncsi_nl_attrs {
	NCSI_ATTR_UNSPEC = 0,
	NCSI_ATTR_IFINDEX = 1,
	NCSI_ATTR_PACKAGE_LIST = 2,
	NCSI_ATTR_PACKAGE_ID = 3,
	NCSI_ATTR_CHANNEL_ID = 4,
	NCSI_ATTR_DATA = 5,
	NCSI_ATTR_MULTI_FLAG = 6,
	NCSI_ATTR_PACKAGE_MASK = 7,
	NCSI_ATTR_CHANNEL_MASK = 8,
	__NCSI_ATTR_AFTER_LAST = 9,
	NCSI_ATTR_MAX = 8,
};

enum ncsi_nl_pkg_attrs {
	NCSI_PKG_ATTR_UNSPEC = 0,
	NCSI_PKG_ATTR = 1,
	NCSI_PKG_ATTR_ID = 2,
	NCSI_PKG_ATTR_FORCED = 3,
	NCSI_PKG_ATTR_CHANNEL_LIST = 4,
	__NCSI_PKG_ATTR_AFTER_LAST = 5,
	NCSI_PKG_ATTR_MAX = 4,
};

enum ncsi_nl_channel_attrs {
	NCSI_CHANNEL_ATTR_UNSPEC = 0,
	NCSI_CHANNEL_ATTR = 1,
	NCSI_CHANNEL_ATTR_ID = 2,
	NCSI_CHANNEL_ATTR_VERSION_MAJOR = 3,
	NCSI_CHANNEL_ATTR_VERSION_MINOR = 4,
	NCSI_CHANNEL_ATTR_VERSION_STR = 5,
	NCSI_CHANNEL_ATTR_LINK_STATE = 6,
	NCSI_CHANNEL_ATTR_ACTIVE = 7,
	NCSI_CHANNEL_ATTR_FORCED = 8,
	NCSI_CHANNEL_ATTR_VLAN_LIST = 9,
	NCSI_CHANNEL_ATTR_VLAN_ID = 10,
	__NCSI_CHANNEL_ATTR_AFTER_LAST = 11,
	NCSI_CHANNEL_ATTR_MAX = 10,
};

struct sockaddr_xdp {
	__u16 sxdp_family;
	__u16 sxdp_flags;
	__u32 sxdp_ifindex;
	__u32 sxdp_queue_id;
	__u32 sxdp_shared_umem_fd;
};

struct xdp_ring_offset {
	__u64 producer;
	__u64 consumer;
	__u64 desc;
	__u64 flags;
};

struct xdp_mmap_offsets {
	struct xdp_ring_offset rx;
	struct xdp_ring_offset tx;
	struct xdp_ring_offset fr;
	struct xdp_ring_offset cr;
};

struct xdp_umem_reg {
	__u64 addr;
	__u64 len;
	__u32 chunk_size;
	__u32 headroom;
	__u32 flags;
};

struct xdp_statistics {
	__u64 rx_dropped;
	__u64 rx_invalid_descs;
	__u64 tx_invalid_descs;
	__u64 rx_ring_full;
	__u64 rx_fill_ring_empty_descs;
	__u64 tx_ring_empty_descs;
};

struct xdp_options {
	__u32 flags;
};

struct xdp_desc {
	__u64 addr;
	__u32 len;
	__u32 options;
};

struct dentry___303;

struct super_block___303;

struct module___287;

struct file_system_type___303 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___303 * (*mount)(struct file_system_type___303 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___303 *);
	struct module___287 *owner;
	struct file_system_type___303 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___303;

struct kiocb___303;

struct iov_iter___223;

struct poll_table_struct___221;

struct vm_area_struct___308;

struct inode___303;

struct file_lock___303;

struct page___308;

struct pipe_inode_info___144;

struct seq_file___278;

struct file_operations___304 {
	struct module___287 *owner;
	loff_t (*llseek)(struct file___303 *, loff_t, int);
	ssize_t (*read)(struct file___303 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___303 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___303 *, struct iov_iter___223 *);
	ssize_t (*write_iter)(struct kiocb___303 *, struct iov_iter___223 *);
	int (*iopoll)(struct kiocb___303 *, bool);
	int (*iterate)(struct file___303 *, struct dir_context *);
	int (*iterate_shared)(struct file___303 *, struct dir_context *);
	__poll_t (*poll)(struct file___303 *, struct poll_table_struct___221 *);
	long int (*unlocked_ioctl)(struct file___303 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___303 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___303 *, struct vm_area_struct___308 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___303 *, struct file___303 *);
	int (*flush)(struct file___303 *, fl_owner_t);
	int (*release)(struct inode___303 *, struct file___303 *);
	int (*fsync)(struct file___303 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___303 *, int);
	int (*lock)(struct file___303 *, int, struct file_lock___303 *);
	ssize_t (*sendpage)(struct file___303 *, struct page___308 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___303 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___303 *, long unsigned int);
	int (*flock)(struct file___303 *, int, struct file_lock___303 *);
	ssize_t (*splice_write)(struct pipe_inode_info___144 *, struct file___303 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___303 *, loff_t *, struct pipe_inode_info___144 *, size_t, unsigned int);
	int (*setlease)(struct file___303 *, long int, struct file_lock___303 **, void **);
	long int (*fallocate)(struct file___303 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___278 *, struct file___303 *);
	ssize_t (*copy_file_range)(struct file___303 *, loff_t, struct file___303 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___303 *, loff_t, struct file___303 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___303 *, loff_t, loff_t, int);
};

struct vmacache___308 {
	u64 seqnum;
	struct vm_area_struct___308 *vmas[4];
};

struct page_frag___308 {
	struct page___308 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___309;

struct pid___280;

struct nsproxy___289;

struct signal_struct___304;

struct bio_list___191;

struct backing_dev_info___177;

struct io_context___191;

struct css_set___230;

struct mem_cgroup___165;

struct request_queue___191;

struct vm_struct___286;

struct task_struct___310 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___310 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___309 *mm;
	struct mm_struct___309 *active_mm;
	struct vmacache___308 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___310 *real_parent;
	struct task_struct___310 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___310 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___280 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___289 *nsproxy;
	struct signal_struct___304 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___310 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___191 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___177 *backing_dev_info;
	struct io_context___191 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___230 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___144 *splice_pipe;
	struct page_frag___308 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___165 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___165 *active_memcg;
	struct request_queue___191 *throttle_queue;
	struct uprobe_task *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___310 *oom_reaper_list;
	struct vm_struct___286 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___291;

struct kobj_type___291;

struct kernfs_node___291;

struct kobject___291 {
	const char *name;
	struct list_head entry;
	struct kobject___291 *parent;
	struct kset___291 *kset;
	struct kobj_type___291 *ktype;
	struct kernfs_node___291 *sd;
	struct kref kref;
	unsigned int state_initialized;
	unsigned int state_in_sysfs;
	unsigned int state_add_uevent_sent;
	unsigned int state_remove_uevent_sent;
	unsigned int uevent_suppress;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___288 {
	struct kobject___291 kobj;
	struct module___287 *mod;
	struct kobject___291 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___287 {
	struct module___287 *mod;
	struct latch_tree_node node;
};

struct module_layout___287 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___287 mtn;
};

struct module_attribute___287;

struct kernel_param___287;

struct module___287 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___288 mkobj;
	struct module_attribute___287 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___291 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___287 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___287 core_layout;
	struct module_layout___287 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct pid_namespace___280;

struct upid___280 {
	int nr;
	struct pid_namespace___280 *ns;
};

struct pid_namespace___280 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___310 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___280 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___280 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___280 numbers[1];
};

typedef struct page___308 *pgtable_t___308;

struct address_space___303;

struct page_pool___132;

struct dev_pagemap___298;

struct page___308 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___303 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___132 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___308 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___308 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___309 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___298 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___298;

struct vm_area_struct___308 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___308 *vm_next;
	struct vm_area_struct___308 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___309 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___298 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___303 *vm_file;
	struct file___303 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct signal_struct___304 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___310 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___310 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper;
	unsigned int has_child_subreaper;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___280 *pids[4];
	struct pid___280 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___309 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct core_state___308;

struct mm_struct___309 {
	struct {
		struct vm_area_struct___308 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___303 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___308 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___310 *owner;
		struct user_namespace___26 *user_ns;
		struct file___303 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct net___117;

struct cgroup_namespace___230;

struct nsproxy___289 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___280 *pid_ns_for_children;
	struct net___117 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___230 *cgroup_ns;
};

struct bio___191;

struct bio_list___191 {
	struct bio___191 *head;
	struct bio___191 *tail;
};

struct cgroup_subsys_state___230;

struct bdi_writeback___177 {
	struct backing_dev_info___177 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___230 *memcg_css;
	struct cgroup_subsys_state___230 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct device___284;

struct backing_dev_info___177 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___177 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___284 *dev;
	char dev_name[64];
	struct device___284 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___303 *debug_dir;
};

struct io_cq___191;

struct io_context___191 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___191 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct cgroup___230;

struct css_set___230 {
	struct cgroup_subsys_state___230 *subsys[14];
	refcount_t refcount;
	struct css_set___230 *dom_cset;
	struct cgroup___230 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___230 *mg_src_cgrp;
	struct cgroup___230 *mg_dst_cgrp;
	struct css_set___230 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct fasync_struct___303;

struct pipe_buffer___144;

struct pipe_inode_info___144 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___308 *tmp_page;
	struct fasync_struct___303 *fasync_readers;
	struct fasync_struct___303 *fasync_writers;
	struct pipe_buffer___144 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct cgroup_subsys___230;

struct cgroup_subsys_state___230 {
	struct cgroup___230 *cgroup;
	struct cgroup_subsys___230 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___230 *parent;
};

struct cgroup_file___230 {
	struct kernfs_node___291 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___165;

struct mem_cgroup_per_node___165;

struct mem_cgroup___165 {
	struct cgroup_subsys_state___230 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___230 events_file;
	struct cgroup_file___230 events_local_file;
	struct cgroup_file___230 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___165 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___310 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___165 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___191;

struct blk_integrity___191 {
	const struct blk_integrity_profile___191 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___191 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___191 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___191;

struct elevator_queue___191;

struct blk_mq_ops___186;

struct blk_mq_hw_ctx___186;

struct gendisk___194;

struct blkcg_gq___179;

struct blk_mq_tag_set___186;

struct request_queue___191 {
	struct request___191 *last_merge;
	struct elevator_queue___191 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___186 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___186 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___194 *disk;
	struct kobject___291 kobj;
	struct kobject___291 *mq_kobj;
	struct blk_integrity___191 integrity;
	struct device___284 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___179 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___186 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___191 bio_split;
	struct dentry___303 *debugfs_dir;
	struct dentry___303 *sched_debugfs_dir;
	struct dentry___303 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___286 {
	struct vm_struct___286 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___308 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct address_space_operations___303;

struct address_space___303 {
	struct inode___303 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___303 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct page_pool_params___132 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___284 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___132 {
	u32 count;
	struct page___308 *cache[128];
};

struct page_pool___132 {
	struct page_pool_params___132 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___308 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___132 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___298;

struct dev_pagemap___298 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___298 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___303;

struct path___303 {
	struct vfsmount___303 *mnt;
	struct dentry___303 *dentry;
};

struct fown_struct___280 {
	rwlock_t lock;
	struct pid___280 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___303 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___303 f_path;
	struct inode___303 *f_inode;
	const struct file_operations___304 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___280 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___303 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___298;

struct vm_operations_struct___298 {
	void (*open)(struct vm_area_struct___308 *);
	void (*close)(struct vm_area_struct___308 *);
	int (*may_split)(struct vm_area_struct___308 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___308 *);
	int (*mprotect)(struct vm_area_struct___308 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___298 *);
	vm_fault_t (*huge_fault)(struct vm_fault___298 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___298 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___308 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___298 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___298 *);
	int (*access)(struct vm_area_struct___308 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___308 *);
	int (*set_policy)(struct vm_area_struct___308 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___308 *, long unsigned int);
	struct page___308 * (*find_special_page)(struct vm_area_struct___308 *, long unsigned int);
};

struct core_thread___308 {
	struct task_struct___310 *task;
	struct core_thread___308 *next;
};

struct core_state___308 {
	atomic_t nr_threads;
	struct core_thread___308 dumper;
	struct completion startup;
};

struct vm_fault___298 {
	const struct {
		struct vm_area_struct___308 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___308 *cow_page;
	struct page___308 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___308 prealloc_pte;
};

struct pglist_data___173;

struct lruvec___173 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___173 *pgdat;
};

struct zone___173 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___173 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___173 {
	struct zone___173 *zone;
	int zone_idx;
};

struct zonelist___173 {
	struct zoneref___173 _zonerefs[321];
};

struct pglist_data___173 {
	struct zone___173 node_zones[5];
	struct zonelist___173 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___310 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___310 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___173 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct psi_group___230 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___310 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct bpf_prog_array___103;

struct cgroup_bpf___103 {
	struct bpf_prog_array___103 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___103 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___230;

struct cgroup_rstat_cpu___230;

struct cgroup___230 {
	struct cgroup_subsys_state___230 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___291 *kn;
	struct cgroup_file___230 procs_file;
	struct cgroup_file___230 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___230 *subsys[14];
	struct cgroup_root___230 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___230 *dom_cgrp;
	struct cgroup___230 *old_dom_cgrp;
	struct cgroup_rstat_cpu___230 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___230 psi;
	struct cgroup_bpf___103 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct bio_vec___220 {
	struct page___308 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct iov_iter___223 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___220 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___144 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___99 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___223 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___303 *msg_iocb;
};

struct kiocb___303 {
	struct file___303 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___303 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct dentry_operations___303;

struct dentry___303 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___303 *d_parent;
	struct qstr d_name;
	struct inode___303 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___303 *d_op;
	struct super_block___303 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___303;

struct inode___303 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___303 *i_op;
	struct super_block___303 *i_sb;
	struct address_space___303 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___177 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___304 *i_fop;
		void (*free_inode)(struct inode___303 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___303 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___144 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___303 {
	int (*d_revalidate)(struct dentry___303 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___303 *, unsigned int);
	int (*d_hash)(const struct dentry___303 *, struct qstr *);
	int (*d_compare)(const struct dentry___303 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___303 *);
	int (*d_init)(struct dentry___303 *);
	void (*d_release)(struct dentry___303 *);
	void (*d_prune)(struct dentry___303 *);
	void (*d_iput)(struct dentry___303 *, struct inode___303 *);
	char * (*d_dname)(struct dentry___303 *, char *, int);
	struct vfsmount___303 * (*d_automount)(struct path___303 *);
	int (*d_manage)(const struct path___303 *, bool);
	struct dentry___303 * (*d_real)(struct dentry___303 *, const struct inode___303 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___303;

struct mem_dqinfo___303 {
	struct quota_format_type___303 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___303;

struct quota_info___303 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___303 *files[3];
	struct mem_dqinfo___303 info[3];
	const struct quota_format_ops___303 *ops[3];
};

struct rcuwait___304 {
	struct task_struct___310 *task;
};

struct percpu_rw_semaphore___304 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___304 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___303 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___304 rw_sem[3];
};

struct shrink_control___165;

struct shrinker___165 {
	long unsigned int (*count_objects)(struct shrinker___165 *, struct shrink_control___165 *);
	long unsigned int (*scan_objects)(struct shrinker___165 *, struct shrink_control___165 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___303;

struct dquot_operations___303;

struct quotactl_ops___303;

struct block_device___194;

struct super_block___303 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___303 *s_type;
	const struct super_operations___303 *s_op;
	const struct dquot_operations___303 *dq_op;
	const struct quotactl_ops___303 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___303 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___194 *s_bdev;
	struct backing_dev_info___177 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___303 s_dquot;
	struct sb_writers___303 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___303 *s_d_op;
	int cleancache_poolid;
	struct shrinker___165 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___303 {
	struct dentry___303 *mnt_root;
	struct super_block___303 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct shrink_control___165 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___165 *memcg;
};

struct io_cq___191 {
	struct request_queue___191 *q;
	struct io_context___191 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___303 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___303 *ia_file;
};

struct dquot___303 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___303 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___303 {
	int qf_fmt_id;
	const struct quota_format_ops___303 *qf_ops;
	struct module___287 *qf_owner;
	struct quota_format_type___303 *qf_next;
};

struct quota_format_ops___303 {
	int (*check_quota_file)(struct super_block___303 *, int);
	int (*read_file_info)(struct super_block___303 *, int);
	int (*write_file_info)(struct super_block___303 *, int);
	int (*free_file_info)(struct super_block___303 *, int);
	int (*read_dqblk)(struct dquot___303 *);
	int (*commit_dqblk)(struct dquot___303 *);
	int (*release_dqblk)(struct dquot___303 *);
	int (*get_next_id)(struct super_block___303 *, struct kqid *);
};

struct dquot_operations___303 {
	int (*write_dquot)(struct dquot___303 *);
	struct dquot___303 * (*alloc_dquot)(struct super_block___303 *, int);
	void (*destroy_dquot)(struct dquot___303 *);
	int (*acquire_dquot)(struct dquot___303 *);
	int (*release_dquot)(struct dquot___303 *);
	int (*mark_dirty)(struct dquot___303 *);
	int (*write_info)(struct super_block___303 *, int);
	qsize_t * (*get_reserved_space)(struct inode___303 *);
	int (*get_projid)(struct inode___303 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___303 *, qsize_t *);
	int (*get_next_id)(struct super_block___303 *, struct kqid *);
};

struct quotactl_ops___303 {
	int (*quota_on)(struct super_block___303 *, int, int, const struct path___303 *);
	int (*quota_off)(struct super_block___303 *, int);
	int (*quota_enable)(struct super_block___303 *, unsigned int);
	int (*quota_disable)(struct super_block___303 *, unsigned int);
	int (*quota_sync)(struct super_block___303 *, int);
	int (*set_info)(struct super_block___303 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___303 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___303 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___303 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___303 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___303 *, unsigned int);
};

struct writeback_control___177;

struct address_space_operations___303 {
	int (*writepage)(struct page___308 *, struct writeback_control___177 *);
	int (*readpage)(struct file___303 *, struct page___308 *);
	int (*writepages)(struct address_space___303 *, struct writeback_control___177 *);
	int (*set_page_dirty)(struct page___308 *);
	int (*readpages)(struct file___303 *, struct address_space___303 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___303 *, struct address_space___303 *, loff_t, unsigned int, unsigned int, struct page___308 **, void **);
	int (*write_end)(struct file___303 *, struct address_space___303 *, loff_t, unsigned int, unsigned int, struct page___308 *, void *);
	sector_t (*bmap)(struct address_space___303 *, sector_t);
	void (*invalidatepage)(struct page___308 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___308 *, gfp_t);
	void (*freepage)(struct page___308 *);
	ssize_t (*direct_IO)(struct kiocb___303 *, struct iov_iter___223 *);
	int (*migratepage)(struct address_space___303 *, struct page___308 *, struct page___308 *, enum migrate_mode);
	bool (*isolate_page)(struct page___308 *, isolate_mode_t);
	void (*putback_page)(struct page___308 *);
	int (*launder_page)(struct page___308 *);
	int (*is_partially_uptodate)(struct page___308 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___308 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___303 *, struct page___308 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___303 *, sector_t *);
	void (*swap_deactivate)(struct file___303 *);
};

struct writeback_control___177 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate;
	unsigned int for_background;
	unsigned int tagged_writepages;
	unsigned int for_reclaim;
	unsigned int range_cyclic;
	unsigned int for_sync;
	unsigned int no_cgroup_owner;
	unsigned int punt_to_cgroup;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___177 *wb;
	struct inode___303 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___303 {
	struct dentry___303 * (*lookup)(struct inode___303 *, struct dentry___303 *, unsigned int);
	const char * (*get_link)(struct dentry___303 *, struct inode___303 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___303 *, int);
	struct posix_acl * (*get_acl)(struct inode___303 *, int, bool);
	int (*readlink)(struct dentry___303 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___303 *, struct dentry___303 *, umode_t, bool);
	int (*link)(struct dentry___303 *, struct inode___303 *, struct dentry___303 *);
	int (*unlink)(struct inode___303 *, struct dentry___303 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___303 *, struct dentry___303 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___303 *, struct dentry___303 *, umode_t);
	int (*rmdir)(struct inode___303 *, struct dentry___303 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___303 *, struct dentry___303 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___303 *, struct dentry___303 *, struct inode___303 *, struct dentry___303 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___303 *, struct iattr___303 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___303 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___303 *, char *, size_t);
	int (*fiemap)(struct inode___303 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___303 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___303 *, struct dentry___303 *, struct file___303 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___303 *, struct dentry___303 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___303 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___303 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___303 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___303 {
	void (*fl_copy_lock)(struct file_lock___303 *, struct file_lock___303 *);
	void (*fl_release_private)(struct file_lock___303 *);
};

struct lock_manager_operations___303;

struct file_lock___303 {
	struct file_lock___303 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___303 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___303 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___303 *fl_ops;
	const struct lock_manager_operations___303 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___303 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___303 *);
	int (*lm_grant)(struct file_lock___303 *, int);
	bool (*lm_break)(struct file_lock___303 *);
	int (*lm_change)(struct file_lock___303 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___303 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___303 *);
};

struct fasync_struct___303 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___303 *fa_next;
	struct file___303 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___303 {
	struct inode___303 * (*alloc_inode)(struct super_block___303 *);
	void (*destroy_inode)(struct inode___303 *);
	void (*free_inode)(struct inode___303 *);
	void (*dirty_inode)(struct inode___303 *, int);
	int (*write_inode)(struct inode___303 *, struct writeback_control___177 *);
	int (*drop_inode)(struct inode___303 *);
	void (*evict_inode)(struct inode___303 *);
	void (*put_super)(struct super_block___303 *);
	int (*sync_fs)(struct super_block___303 *, int);
	int (*freeze_super)(struct super_block___303 *);
	int (*freeze_fs)(struct super_block___303 *);
	int (*thaw_super)(struct super_block___303 *);
	int (*unfreeze_fs)(struct super_block___303 *);
	int (*statfs)(struct dentry___303 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___303 *, int *, char *);
	void (*umount_begin)(struct super_block___303 *);
	int (*show_options)(struct seq_file___278 *, struct dentry___303 *);
	int (*show_devname)(struct seq_file___278 *, struct dentry___303 *);
	int (*show_path)(struct seq_file___278 *, struct dentry___303 *);
	int (*show_stats)(struct seq_file___278 *, struct dentry___303 *);
	ssize_t (*quota_read)(struct super_block___303 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___303 *, int, const char *, size_t, loff_t);
	struct dquot___303 ** (*get_dquots)(struct inode___303 *);
	long int (*nr_cached_objects)(struct super_block___303 *, struct shrink_control___165 *);
	long int (*free_cached_objects)(struct super_block___303 *, struct shrink_control___165 *);
	struct file___303 * (*real_loop)(struct file___303 *);
};

struct wakeup_source___284;

struct dev_pm_info___284 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___284 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___284 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___284;

struct bus_type___284;

struct device_driver___284;

struct dev_pm_domain___284;

struct fwnode_handle___280;

struct class___284;

struct attribute_group___291;

struct device___284 {
	struct kobject___291 kobj;
	struct device___284 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___284 *type;
	struct bus_type___284 *bus;
	struct device_driver___284 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___284 power;
	struct dev_pm_domain___284 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___280 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___284 *class;
	const struct attribute_group___291 **groups;
	void (*release)(struct device___284 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct block_device___194 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___303 *bd_inode;
	struct super_block___303 *bd_super;
	void *bd_claiming;
	struct device___284 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___291 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___194 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___303 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___229)(struct file___303 *, wait_queue_head_t *, struct poll_table_struct___221 *);

struct poll_table_struct___221 {
	poll_queue_proc___229 _qproc;
	__poll_t _key;
};

struct seq_operations___278;

struct seq_file___278 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___278 *op;
	int poll_event;
	const struct file___303 *file;
	void *private;
};

typedef void bio_end_io_t___191(struct bio___191 *);

struct bio_integrity_payload___191;

struct bio___191 {
	struct bio___191 *bi_next;
	struct block_device___194 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___191 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___179 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___191 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___220 *bi_io_vec;
	struct bio_set___191 *bi_pool;
	struct bio_vec___220 bi_inline_vecs[0];
};

struct dev_pagemap_ops___298 {
	void (*page_free)(struct page___308 *);
	void (*kill)(struct dev_pagemap___298 *);
	void (*cleanup)(struct dev_pagemap___298 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___298 *);
};

struct socket_wq___98 {
	wait_queue_head_t wait;
	struct fasync_struct___303 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct sock___96;

struct proto_ops___98;

struct socket___99 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___303 *file;
	struct sock___96 *sk;
	const struct proto_ops___98 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___98 wq;
};

typedef struct {
	struct net___117 *net;
} possible_net_t___112;

struct proto___96;

struct sock_common___96 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___96 *skc_prot;
	possible_net_t___112 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___96 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct sk_buff___113;

struct sk_buff_head___112 {
	struct sk_buff___113 *next;
	struct sk_buff___113 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct sock_cgroup_data___96 {
	struct cgroup___230 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___96;

struct dst_entry___96;

struct net_device___112;

struct sock___96 {
	struct sock_common___96 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___112 sk_error_queue;
	struct sk_buff___113 *sk_rx_skb_cache;
	struct sk_buff_head___112 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___113 *head;
		struct sk_buff___113 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___96 *sk_filter;
	union {
		struct socket_wq___98 *sk_wq;
		struct socket_wq___98 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___96 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___96 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___113 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___113 *sk_tx_skb_cache;
	struct sk_buff_head___112 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___308 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___96 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___280 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___99 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___96 sk_cgrp_data;
	struct mem_cgroup___165 *sk_memcg;
	void (*sk_state_change)(struct sock___96 *);
	void (*sk_data_ready)(struct sock___96 *);
	void (*sk_write_space)(struct sock___96 *);
	void (*sk_error_report)(struct sock___96 *);
	int (*sk_backlog_rcv)(struct sock___96 *, struct sk_buff___113 *);
	struct sk_buff___113 * (*sk_validate_xmit_skb)(struct sock___96 *, struct net_device___112 *, struct sk_buff___113 *);
	void (*sk_destruct)(struct sock___96 *);
	struct sock_reuseport *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

typedef int (*sk_read_actor_t___97)(read_descriptor_t *, struct sk_buff___113 *, unsigned int, size_t);

struct proto_ops___98 {
	int family;
	struct module___287 *owner;
	int (*release)(struct socket___99 *);
	int (*bind)(struct socket___99 *, struct sockaddr *, int);
	int (*connect)(struct socket___99 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___99 *, struct socket___99 *);
	int (*accept)(struct socket___99 *, struct socket___99 *, int, bool);
	int (*getname)(struct socket___99 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___303 *, struct socket___99 *, struct poll_table_struct___221 *);
	int (*ioctl)(struct socket___99 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___99 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___99 *, void *, bool, bool);
	int (*listen)(struct socket___99 *, int);
	int (*shutdown)(struct socket___99 *, int);
	int (*setsockopt)(struct socket___99 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___99 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___278 *, struct socket___99 *);
	int (*sendmsg)(struct socket___99 *, struct msghdr___99 *, size_t);
	int (*recvmsg)(struct socket___99 *, struct msghdr___99 *, size_t, int);
	int (*mmap)(struct file___303 *, struct socket___99 *, struct vm_area_struct___308 *);
	ssize_t (*sendpage)(struct socket___99 *, struct page___308 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___99 *, loff_t *, struct pipe_inode_info___144 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___96 *, int);
	int (*peek_len)(struct socket___99 *);
	int (*read_sock)(struct sock___96 *, read_descriptor_t *, sk_read_actor_t___97);
	int (*sendpage_locked)(struct sock___96 *, struct page___308 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___96 *, struct msghdr___99 *, size_t);
	int (*set_rcvlowat)(struct sock___96 *, int);
};

struct sk_buff___113 {
	union {
		struct {
			struct sk_buff___113 *next;
			struct sk_buff___113 *prev;
			union {
				struct net_device___112 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___96 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___113 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct net_proto_family___6 {
	int family;
	int (*create)(struct net___117 *, struct socket___99 *, int, int);
	struct module___287 *owner;
};

struct ip_ra_chain___68;

struct fib_rules_ops___96;

struct fqdir___117;

struct fib_notifier_ops___96;

struct netns_ipv4___117 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___68 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___96 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___96 *fibnl;
	struct sock___96 **icmp_sk;
	struct sock___96 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___96 **tcp_sk;
	struct fqdir___117 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___96 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___96 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___96 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct neighbour___97;

struct dst_ops___117 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___117 *);
	struct dst_entry___96 * (*check)(struct dst_entry___96 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___96 *);
	unsigned int (*mtu)(const struct dst_entry___96 *);
	u32 * (*cow_metrics)(struct dst_entry___96 *, long unsigned int);
	void (*destroy)(struct dst_entry___96 *);
	void (*ifdown)(struct dst_entry___96 *, struct net_device___112 *, int);
	struct dst_entry___96 * (*negative_advice)(struct dst_entry___96 *);
	void (*link_failure)(struct sk_buff___113 *);
	void (*update_pmtu)(struct dst_entry___96 *, struct sock___96 *, struct sk_buff___113 *, u32, bool);
	void (*redirect)(struct dst_entry___96 *, struct sock___96 *, struct sk_buff___113 *);
	int (*local_out)(struct net___117 *, struct sock___96 *, struct sk_buff___113 *);
	struct neighbour___97 * (*neigh_lookup)(const struct dst_entry___96 *, struct sk_buff___113 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___96 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___117 {
	struct dst_ops___117 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___117 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___96 *fib6_rules_ops;
	struct sock___96 **icmp_sk;
	struct sock___96 *ndisc_sk;
	struct sock___96 *tcp_sk;
	struct sock___96 *igmp_sk;
	struct sock___96 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___96 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___96 *notifier_ops;
	struct fib_notifier_ops___96 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___117 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___117 *fqdir;
};

struct netns_sctp___96 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___96 *ctl_sock;
	struct sock___96 *udp4_sock;
	struct sock___96 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct bpf_prog___103;

struct netns_bpf___103 {
	struct bpf_prog_array___103 *run_array[2];
	struct bpf_prog___103 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___117 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___96 *nlsk;
	struct sock___96 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___117 xfrm4_dst_ops;
	struct dst_ops___117 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___117 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___96 *rtnl;
	struct sock___96 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___112 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___117 ipv4;
	struct netns_ipv6___117 ipv6;
	struct netns_ieee802154_lowpan___117 ieee802154_lowpan;
	struct netns_sctp___96 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___112 wext_nlevents;
	struct net_generic *gen;
	struct netns_bpf___103 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___117 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___96 *crypto_nlsk;
	struct sock___96 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frags___117;

struct fqdir___117 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___117 *f;
	struct net___117 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___117;

struct inet_frags___117 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___117 *, const void *);
	void (*destructor)(struct inet_frag_queue___117 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct inet_frag_queue___117 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___113 *fragments_tail;
	struct sk_buff___113 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___117 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___68 {
	struct ip_ra_chain___68 *next;
	struct sock___96 *sk;
	union {
		void (*destructor)(struct sock___96 *);
		struct sock___96 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___96;

struct fib_lookup_arg___96;

struct fib_rules_ops___96 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___96 *, struct flowi *, int, struct fib_lookup_arg___96 *);
	bool (*suppress)(struct fib_rule___96 *, int, struct fib_lookup_arg___96 *);
	int (*match)(struct fib_rule___96 *, struct flowi *, int);
	int (*configure)(struct fib_rule___96 *, struct sk_buff___113 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___96 *);
	int (*compare)(struct fib_rule___96 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___96 *, struct sk_buff___113 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___96 *);
	void (*flush_cache)(struct fib_rules_ops___96 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___287 *owner;
	struct net___117 *fro_net;
	struct callback_head rcu;
};

struct fib_notifier_ops___96 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___117 *);
	int (*fib_dump)(struct net___117 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___287 *owner;
	struct callback_head rcu;
};

struct lwtunnel_state___71;

struct dst_entry___96 {
	struct net_device___112 *dev;
	struct dst_ops___117 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___113 *);
	int (*output)(struct net___117 *, struct sock___96 *, struct sk_buff___113 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___71 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___112(struct sk_buff___113 **);

struct bpf_xdp_entity___103 {
	struct bpf_prog___103 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___112;

struct net_device_ops___112;

struct l3mdev_ops___96;

struct ndisc_ops___77;

struct xfrmdev_ops___112;

struct header_ops___112;

struct inet6_dev___77;

struct netdev_rx_queue___112;

struct mini_Qdisc___103;

struct netdev_queue___112;

struct Qdisc___103;

struct rtnl_link_ops___104;

struct dcbnl_rtnl_ops___112;

struct net_device___112 {
	char name[16];
	struct netdev_name_node___112 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___112 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___96 *l3mdev_ops;
	const struct ndisc_ops___77 *ndisc_ops;
	const struct xfrmdev_ops___112 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___112 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___291 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___77 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___112 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___103 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___112 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___103 *miniq_ingress;
	struct netdev_queue___112 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___112 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___103 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___103 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___112 = 0,
		NETREG_REGISTERED___112 = 1,
		NETREG_UNREGISTERING___112 = 2,
		NETREG_UNREGISTERED___112 = 3,
		NETREG_RELEASED___112 = 4,
		NETREG_DUMMY___112 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___112 = 0,
		RTNL_LINK_INITIALIZING___112 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___112 *);
	struct netpoll_info *npinfo;
	possible_net_t___112 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___284 dev;
	const struct attribute_group___291 *sysfs_groups[4];
	const struct attribute_group___291 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___104 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___112 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___103 xdp_state[3];
	long: 64;
};

struct neigh_table___97;

struct neigh_parms___97;

struct neigh_ops___97;

struct neighbour___97 {
	struct neighbour___97 *next;
	struct neigh_table___97 *tbl;
	struct neigh_parms___97 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___112 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___97 *, struct sk_buff___113 *);
	const struct neigh_ops___97 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___112 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___103 {
	struct bpf_prog___103 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___103 {
	struct callback_head rcu;
	struct bpf_prog_array_item___103 items[0];
};

struct bpf_prog_aux___115;

struct bpf_prog___103 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___115 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct fwnode_operations___280;

struct fwnode_handle___280 {
	struct fwnode_handle___280 *secondary;
	const struct fwnode_operations___280 *ops;
	struct device___284 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___280;

struct fwnode_endpoint___280;

struct fwnode_operations___280 {
	struct fwnode_handle___280 * (*get)(struct fwnode_handle___280 *);
	void (*put)(struct fwnode_handle___280 *);
	bool (*device_is_available)(const struct fwnode_handle___280 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___280 *, const struct device___284 *);
	bool (*property_present)(const struct fwnode_handle___280 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___280 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___280 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___280 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*get_parent)(const struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*get_next_child_node)(const struct fwnode_handle___280 *, struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*get_named_child_node)(const struct fwnode_handle___280 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___280 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___280 *);
	struct fwnode_handle___280 * (*graph_get_next_endpoint)(const struct fwnode_handle___280 *, struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*graph_get_remote_endpoint)(const struct fwnode_handle___280 *);
	struct fwnode_handle___280 * (*graph_get_port_parent)(struct fwnode_handle___280 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___280 *, struct fwnode_endpoint___280 *);
	int (*add_links)(struct fwnode_handle___280 *);
};

struct fwnode_endpoint___280 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___280 *local_fwnode;
};

struct fwnode_reference_args___280 {
	struct fwnode_handle___280 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___291;

struct kernfs_elem_dir___291 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___291 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___291;

struct kernfs_root___291 {
	struct kernfs_node___291 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___291 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___291 {
	struct kernfs_node___291 *target_kn;
};

struct kernfs_ops___291;

struct kernfs_elem_attr___291 {
	const struct kernfs_ops___291 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___291 *notify_next;
};

struct kernfs_node___291 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___291 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___291 dir;
		struct kernfs_elem_symlink___291 symlink;
		struct kernfs_elem_attr___291 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___291;

struct kernfs_ops___291 {
	int (*open)(struct kernfs_open_file___291 *);
	void (*release)(struct kernfs_open_file___291 *);
	int (*seq_show)(struct seq_file___278 *, void *);
	void * (*seq_start)(struct seq_file___278 *, loff_t *);
	void * (*seq_next)(struct seq_file___278 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___278 *, void *);
	ssize_t (*read)(struct kernfs_open_file___291 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___291 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___291 *, struct poll_table_struct___221 *);
	int (*mmap)(struct kernfs_open_file___291 *, struct vm_area_struct___308 *);
};

struct kernfs_syscall_ops___291 {
	int (*show_options)(struct seq_file___278 *, struct kernfs_root___291 *);
	int (*mkdir)(struct kernfs_node___291 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___291 *);
	int (*rename)(struct kernfs_node___291 *, struct kernfs_node___291 *, const char *);
	int (*show_path)(struct seq_file___278 *, struct kernfs_node___291 *, struct kernfs_root___291 *);
};

struct kernfs_open_file___291 {
	struct kernfs_node___291 *kn;
	struct file___303 *file;
	struct seq_file___278 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped;
	bool released;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___298 *vm_ops;
};

struct kobj_ns_type_operations___96 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___96 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___291;

struct attribute_group___291 {
	const char *name;
	umode_t (*is_visible)(struct kobject___291 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___291 *, struct bin_attribute___291 *, int);
	struct attribute **attrs;
	struct bin_attribute___291 **bin_attrs;
};

struct bin_attribute___291 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___303 * (*f_mapping)();
	ssize_t (*read)(struct file___303 *, struct kobject___291 *, struct bin_attribute___291 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___303 *, struct kobject___291 *, struct bin_attribute___291 *, char *, loff_t, size_t);
	int (*mmap)(struct file___303 *, struct kobject___291 *, struct bin_attribute___291 *, struct vm_area_struct___308 *);
};

struct sysfs_ops___291 {
	ssize_t (*show)(struct kobject___291 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___291 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___291;

struct kset___291 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___291 kobj;
	const struct kset_uevent_ops___291 *uevent_ops;
};

struct kobj_type___291 {
	void (*release)(struct kobject___291 *);
	const struct sysfs_ops___291 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___291 **default_groups;
	const struct kobj_ns_type_operations___96 * (*child_ns_type)(struct kobject___291 *);
	const void * (*namespace)(struct kobject___291 *);
	void (*get_ownership)(struct kobject___291 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___291 {
	int (* const filter)(struct kset___291 *, struct kobject___291 *);
	const char * (* const name)(struct kset___291 *, struct kobject___291 *);
	int (* const uevent)(struct kset___291 *, struct kobject___291 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___287 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___287 *);
	int (*get)(char *, const struct kernel_param___287 *);
	void (*free)(void *);
};

struct kparam_array___287;

struct kernel_param___287 {
	const char *name;
	struct module___287 *mod;
	const struct kernel_param_ops___287 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___287 *arr;
	};
};

struct kparam_array___287 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___287 *ops;
	void *elem;
};

struct module_attribute___287 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___287 *, struct module_kobject___288 *, char *);
	ssize_t (*store)(struct module_attribute___287 *, struct module_kobject___288 *, const char *, size_t);
	void (*setup)(struct module___287 *, const char *);
	int (*test)(struct module___287 *);
	void (*free)(struct module___287 *);
};

struct cgroup_namespace___230 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___230 *root_cset;
};

struct dev_pm_ops___284 {
	int (*prepare)(struct device___284 *);
	void (*complete)(struct device___284 *);
	int (*suspend)(struct device___284 *);
	int (*resume)(struct device___284 *);
	int (*freeze)(struct device___284 *);
	int (*thaw)(struct device___284 *);
	int (*poweroff)(struct device___284 *);
	int (*restore)(struct device___284 *);
	int (*suspend_late)(struct device___284 *);
	int (*resume_early)(struct device___284 *);
	int (*freeze_late)(struct device___284 *);
	int (*thaw_early)(struct device___284 *);
	int (*poweroff_late)(struct device___284 *);
	int (*restore_early)(struct device___284 *);
	int (*suspend_noirq)(struct device___284 *);
	int (*resume_noirq)(struct device___284 *);
	int (*freeze_noirq)(struct device___284 *);
	int (*thaw_noirq)(struct device___284 *);
	int (*poweroff_noirq)(struct device___284 *);
	int (*restore_noirq)(struct device___284 *);
	int (*runtime_suspend)(struct device___284 *);
	int (*runtime_resume)(struct device___284 *);
	int (*runtime_idle)(struct device___284 *);
};

struct wakeup_source___284 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___284 *dev;
	bool active;
	bool autosleep_enabled;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___284 {
	struct dev_pm_ops___284 ops;
	int (*start)(struct device___284 *);
	void (*detach)(struct device___284 *, bool);
	int (*activate)(struct device___284 *);
	void (*sync)(struct device___284 *);
	void (*dismiss)(struct device___284 *);
};

struct bus_type___284 {
	const char *name;
	const char *dev_name;
	struct device___284 *dev_root;
	const struct attribute_group___291 **bus_groups;
	const struct attribute_group___291 **dev_groups;
	const struct attribute_group___291 **drv_groups;
	int (*match)(struct device___284 *, struct device_driver___284 *);
	int (*uevent)(struct device___284 *, struct kobj_uevent_env *);
	int (*probe)(struct device___284 *);
	void (*sync_state)(struct device___284 *);
	void (*remove)(struct device___284 *);
	void (*shutdown)(struct device___284 *);
	int (*online)(struct device___284 *);
	int (*offline)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	int (*num_vf)(struct device___284 *);
	int (*dma_configure)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___284 {
	const char *name;
	struct bus_type___284 *bus;
	struct module___287 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___284 *);
	void (*sync_state)(struct device___284 *);
	int (*remove)(struct device___284 *);
	void (*shutdown)(struct device___284 *);
	int (*suspend)(struct device___284 *, pm_message_t);
	int (*resume)(struct device___284 *);
	const struct attribute_group___291 **groups;
	const struct attribute_group___291 **dev_groups;
	const struct dev_pm_ops___284 *pm;
	void (*coredump)(struct device___284 *);
	struct driver_private *p;
};

struct device_type___284 {
	const char *name;
	const struct attribute_group___291 **groups;
	int (*uevent)(struct device___284 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___284 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___284 *);
	const struct dev_pm_ops___284 *pm;
};

struct class___284 {
	const char *name;
	struct module___287 *owner;
	const struct attribute_group___291 **class_groups;
	const struct attribute_group___291 **dev_groups;
	struct kobject___291 *dev_kobj;
	int (*dev_uevent)(struct device___284 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___284 *, umode_t *);
	void (*class_release)(struct class___284 *);
	void (*dev_release)(struct device___284 *);
	int (*shutdown_pre)(struct device___284 *);
	const struct kobj_ns_type_operations___96 *ns_type;
	const void * (*namespace)(struct device___284 *);
	void (*get_ownership)(struct device___284 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___284 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___144;

struct pipe_buffer___144 {
	struct page___308 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___144 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___144 {
	int (*confirm)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
	void (*release)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
	bool (*try_steal)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
	bool (*get)(struct pipe_inode_info___144 *, struct pipe_buffer___144 *);
};

typedef struct bio_vec___220 skb_frag_t___50;

struct skb_shared_info___44 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___113 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___50 frags[17];
};

struct seq_operations___278 {
	void * (*start)(struct seq_file___278 *, loff_t *);
	void (*stop)(struct seq_file___278 *, void *);
	void * (*next)(struct seq_file___278 *, void *, loff_t *);
	int (*show)(struct seq_file___278 *, void *);
};

struct pernet_operations___42 {
	struct list_head list;
	int (*init)(struct net___117 *);
	void (*pre_exit)(struct net___117 *);
	void (*exit)(struct net___117 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___112 {
	int (*ieee_getets)(struct net_device___112 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___112 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___112 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___112 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___112 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___112 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___112 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___112 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___112 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___112 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___112 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___112 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___112 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___112 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___112 *);
	u8 (*setstate)(struct net_device___112 *, u8);
	void (*getpermhwaddr)(struct net_device___112 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___112 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___112 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___112 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___112 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___112 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___112 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___112 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___112 *, int, u8 *);
	void (*setpfccfg)(struct net_device___112 *, int, u8);
	void (*getpfccfg)(struct net_device___112 *, int, u8 *);
	u8 (*setall)(struct net_device___112 *);
	u8 (*getcap)(struct net_device___112 *, int, u8 *);
	int (*getnumtcs)(struct net_device___112 *, int, u8 *);
	int (*setnumtcs)(struct net_device___112 *, int, u8);
	u8 (*getpfcstate)(struct net_device___112 *);
	void (*setpfcstate)(struct net_device___112 *, u8);
	void (*getbcncfg)(struct net_device___112 *, int, u32 *);
	void (*setbcncfg)(struct net_device___112 *, int, u32);
	void (*getbcnrp)(struct net_device___112 *, int, u8 *);
	void (*setbcnrp)(struct net_device___112 *, int, u8);
	int (*setapp)(struct net_device___112 *, u8, u16, u8);
	int (*getapp)(struct net_device___112 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___112 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___112 *, int, u8);
	u8 (*getdcbx)(struct net_device___112 *);
	u8 (*setdcbx)(struct net_device___112 *, u8);
	int (*peer_getappinfo)(struct net_device___112 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___112 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___112 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___112 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___112 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___112 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___115;

typedef int (*bpf_iter_init_seq_priv_t___114)(void *, struct bpf_iter_aux_info___115 *);

struct bpf_map___115;

struct bpf_iter_aux_info___115 {
	struct bpf_map___115 *map;
};

struct bpf_iter_seq_info___114 {
	const struct seq_operations___278 *seq_ops;
	bpf_iter_init_seq_priv_t___114 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___114 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___115 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___115 *, struct file___303 *);
	void (*map_free)(struct bpf_map___115 *);
	int (*map_get_next_key)(struct bpf_map___115 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___115 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___115 *, void *);
	int (*map_lookup_batch)(struct bpf_map___115 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___115 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___115 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___115 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___115 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___115 *, void *);
	int (*map_update_elem)(struct bpf_map___115 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___115 *, void *);
	int (*map_push_elem)(struct bpf_map___115 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___115 *, void *);
	int (*map_peek_elem)(struct bpf_map___115 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___115 *, struct file___303 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___115 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___115 *, void *, struct seq_file___278 *);
	int (*map_check_btf)(const struct bpf_map___115 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___115 *, struct bpf_prog_aux___115 *);
	void (*map_poke_untrack)(struct bpf_map___115 *, struct bpf_prog_aux___115 *);
	void (*map_poke_run)(struct bpf_map___115 *, u32, struct bpf_prog___103 *, struct bpf_prog___103 *);
	int (*map_direct_value_addr)(const struct bpf_map___115 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___115 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___115 *, struct vm_area_struct___308 *);
	__poll_t (*map_poll)(struct bpf_map___115 *, struct file___303 *, struct poll_table_struct___221 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___115 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___115 *, const struct bpf_map___115 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___115 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___114 *iter_seq_info;
};

struct bpf_map___115 {
	const struct bpf_map_ops___114 *ops;
	struct bpf_map___115 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___165 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___114;

struct bpf_jit_poke_descriptor___114;

struct bpf_prog_ops___103;

struct btf_mod_pair___114;

struct bpf_prog_offload___112;

struct bpf_prog_aux___115 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___103 *dst_prog;
	struct bpf_trampoline___114 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___103 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___114 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___103 *ops;
	struct bpf_map___115 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___114 *used_btfs;
	struct bpf_prog___103 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___115 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___112 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___112;

struct bpf_map_dev_ops___112 {
	int (*map_get_next_key)(struct bpf_offloaded_map___112 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___112 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___112 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___112 *, void *);
};

struct bpf_offloaded_map___112 {
	struct bpf_map___115 map;
	struct net_device___112 *netdev;
	const struct bpf_map_dev_ops___112 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___103 {
	int (*test_run)(struct bpf_prog___103 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___112 {
	struct bpf_prog___103 *prog;
	struct net_device___112 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___114 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___103 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___287 *mod;
};

struct bpf_jit_poke_descriptor___114 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___115 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___114 {
	struct btf *btf;
	struct module___287 *module;
};

struct cftype___230;

struct cgroup_subsys___230 {
	struct cgroup_subsys_state___230 * (*css_alloc)(struct cgroup_subsys_state___230 *);
	int (*css_online)(struct cgroup_subsys_state___230 *);
	void (*css_offline)(struct cgroup_subsys_state___230 *);
	void (*css_released)(struct cgroup_subsys_state___230 *);
	void (*css_free)(struct cgroup_subsys_state___230 *);
	void (*css_reset)(struct cgroup_subsys_state___230 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___230 *, int);
	int (*css_extra_stat_show)(struct seq_file___278 *, struct cgroup_subsys_state___230 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___310 *, struct css_set___230 *);
	void (*cancel_fork)(struct task_struct___310 *, struct css_set___230 *);
	void (*fork)(struct task_struct___310 *);
	void (*exit)(struct task_struct___310 *);
	void (*release)(struct task_struct___310 *);
	void (*bind)(struct cgroup_subsys_state___230 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___230 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___230 *dfl_cftypes;
	struct cftype___230 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___230 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___230 *updated_children;
	struct cgroup___230 *updated_next;
};

struct cgroup_root___230 {
	struct kernfs_root___291 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___230 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___230 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___230 *ss;
	struct list_head node;
	struct kernfs_ops___291 *kf_ops;
	int (*open)(struct kernfs_open_file___291 *);
	void (*release)(struct kernfs_open_file___291 *);
	u64 (*read_u64)(struct cgroup_subsys_state___230 *, struct cftype___230 *);
	s64 (*read_s64)(struct cgroup_subsys_state___230 *, struct cftype___230 *);
	int (*seq_show)(struct seq_file___278 *, void *);
	void * (*seq_start)(struct seq_file___278 *, loff_t *);
	void * (*seq_next)(struct seq_file___278 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___278 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___230 *, struct cftype___230 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___230 *, struct cftype___230 *, s64);
	ssize_t (*write)(struct kernfs_open_file___291 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___291 *, struct poll_table_struct___221 *);
};

struct xdp_rxq_info___112 {
	struct net_device___112 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___112 {
	struct net_device___112 *dev;
};

struct xdp_buff___112 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___112 *rxq;
	struct xdp_txq_info___112 *txq;
	u32 frame_sz;
};

struct xdp_frame___112 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___112 *dev_rx;
};

struct netlink_callback___112 {
	struct sk_buff___113 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___113 *, struct netlink_callback___112 *);
	int (*done)(struct netlink_callback___112 *);
	void *data;
	struct module___287 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___112 {
	int (*create)(struct sk_buff___113 *, struct net_device___112 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___113 *, unsigned char *);
	int (*cache)(const struct neighbour___97 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___112 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___113 *);
};

struct xsk_buff_pool___3;

struct netdev_queue___112 {
	struct net_device___112 *dev;
	struct Qdisc___103 *qdisc;
	struct Qdisc___103 *qdisc_sleeping;
	struct kobject___291 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___112 *sb_dev;
	struct xsk_buff_pool___3 *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___103 {
	struct sk_buff___113 *head;
	struct sk_buff___113 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___103;

struct Qdisc___103 {
	int (*enqueue)(struct sk_buff___113 *, struct Qdisc___103 *, struct sk_buff___113 **);
	struct sk_buff___113 * (*dequeue)(struct Qdisc___103 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___103 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___112 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___112 gso_skb;
	struct qdisc_skb_head___103 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___103 *next_sched;
	struct sk_buff_head___112 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct xdp_umem___4;

struct xdp_buff_xsk___3;

struct xsk_buff_pool___3 {
	struct device___284 *dev;
	struct net_device___112 *netdev;
	struct list_head xsk_tx_list;
	spinlock_t xsk_tx_list_lock;
	refcount_t users;
	struct xdp_umem___4 *umem;
	struct work_struct work;
	struct list_head free_list;
	u32 heads_cnt;
	u16 queue_id;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *fq;
	struct xsk_queue *cq;
	dma_addr_t *dma_pages;
	struct xdp_buff_xsk___3 *heads;
	u64 chunk_mask;
	u64 addrs_cnt;
	u32 free_list_cnt;
	u32 dma_pages_cnt;
	u32 free_heads_cnt;
	u32 headroom;
	u32 chunk_size;
	u32 frame_len;
	u8 cached_need_wakeup;
	bool uses_need_wakeup;
	bool dma_need_sync;
	bool unaligned;
	void *addrs;
	spinlock_t cq_lock;
	struct xdp_buff_xsk___3 *free_heads[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct netdev_rx_queue___112 {
	struct xdp_rxq_info___112 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___291 kobj;
	struct net_device___112 *dev;
	struct xsk_buff_pool___3 *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___112 {
	enum net_device_path_type type;
	const struct net_device___112 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___112 = 0,
				DEV_PATH_BR_VLAN_TAG___112 = 1,
				DEV_PATH_BR_VLAN_UNTAG___112 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___112 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___112 {
	const struct net_device___112 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___112 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___103 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___112 *offmap;
		};
		struct {
			struct xsk_buff_pool___3 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___112 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___113 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___112 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___112 *dev;
	const char *name;
};

struct net_device_ops___112 {
	int (*ndo_init)(struct net_device___112 *);
	void (*ndo_uninit)(struct net_device___112 *);
	int (*ndo_open)(struct net_device___112 *);
	int (*ndo_stop)(struct net_device___112 *);
	netdev_tx_t___2 (*ndo_start_xmit)(struct sk_buff___113 *, struct net_device___112 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___113 *, struct net_device___112 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___112 *, struct sk_buff___113 *, struct net_device___112 *);
	void (*ndo_change_rx_flags)(struct net_device___112 *, int);
	void (*ndo_set_rx_mode)(struct net_device___112 *);
	int (*ndo_set_mac_address)(struct net_device___112 *, void *);
	int (*ndo_validate_addr)(struct net_device___112 *);
	int (*ndo_do_ioctl)(struct net_device___112 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___112 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___112 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___112 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___112 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___112 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___112 *, int);
	int (*ndo_neigh_setup)(struct net_device___112 *, struct neigh_parms___97 *);
	void (*ndo_tx_timeout)(struct net_device___112 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___112 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___112 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___112 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___112 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___112 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___112 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___112 *);
	int (*ndo_netpoll_setup)(struct net_device___112 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___112 *);
	int (*ndo_set_vf_mac)(struct net_device___112 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___112 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___112 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___112 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___112 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___112 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___112 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___112 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___112 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___112 *, int, struct sk_buff___113 *);
	int (*ndo_get_vf_guid)(struct net_device___112 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___112 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___112 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___112 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___112 *);
	int (*ndo_fcoe_disable)(struct net_device___112 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___112 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___112 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___112 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___112 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___112 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___112 *, const struct sk_buff___113 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___112 *, struct net_device___112 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___112 *, struct net_device___112 *);
	struct net_device___112 * (*ndo_get_xmit_slave)(struct net_device___112 *, struct sk_buff___113 *, bool);
	struct net_device___112 * (*ndo_sk_get_lower_dev)(struct net_device___112 *, struct sock___96 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___112 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___112 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___112 *, struct neighbour___97 *);
	void (*ndo_neigh_destroy)(struct net_device___112 *, struct neighbour___97 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___112 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___112 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___113 *, struct netlink_callback___112 *, struct net_device___112 *, struct net_device___112 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___113 *, struct nlattr **, struct net_device___112 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___112 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___113 *, u32, u32, struct net_device___112 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___112 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___112 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___112 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___112 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___112 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___112 *, struct net_device___112 *);
	void (*ndo_dfwd_del_station)(struct net_device___112 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___112 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___112 *);
	int (*ndo_change_proto_down)(struct net_device___112 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___112 *, struct sk_buff___113 *);
	void (*ndo_set_rx_headroom)(struct net_device___112 *, int);
	int (*ndo_bpf)(struct net_device___112 *, struct netdev_bpf___112 *);
	int (*ndo_xdp_xmit)(struct net_device___112 *, int, struct xdp_frame___112 **, u32);
	struct net_device___112 * (*ndo_xdp_get_xmit_slave)(struct net_device___112 *, struct xdp_buff___112 *);
	int (*ndo_xsk_wakeup)(struct net_device___112 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___112 *);
	int (*ndo_tunnel_ctl)(struct net_device___112 *, struct ip_tunnel_parm *, int);
	struct net_device___112 * (*ndo_get_peer_dev)(struct net_device___112 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___112 *, struct net_device_path___112 *);
};

struct neigh_parms___97 {
	possible_net_t___112 net;
	struct net_device___112 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___97 *);
	struct neigh_table___97 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___96 {
	u32 (*l3mdev_fib_table)(const struct net_device___112 *);
	struct sk_buff___113 * (*l3mdev_l3_rcv)(struct net_device___112 *, struct sk_buff___113 *, u16);
	struct sk_buff___113 * (*l3mdev_l3_out)(struct net_device___112 *, struct sock___96 *, struct sk_buff___113 *, u16);
	struct dst_entry___96 * (*l3mdev_link_scope_lookup)(const struct net_device___112 *, struct flowi6 *);
};

struct ndisc_ops___77 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___112 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___112 *, struct neighbour___97 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___112 *, u8, struct neighbour___97 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___112 *, struct sk_buff___113 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___117 *, struct net_device___112 *, const struct prefix_info *, struct inet6_dev___77 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___77;

struct inet6_dev___77 {
	struct net_device___112 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___77 *mc_list;
	struct ifmcaddr6___77 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___112 mc_query_queue;
	struct sk_buff_head___112 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___36 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___97 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___103;

struct tcf_block___103;

struct mini_Qdisc___103 {
	struct tcf_proto___103 *filter_list;
	struct tcf_block___103 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___104 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___112 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___112 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___117 *, struct net_device___112 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___112 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___112 *, struct list_head *);
	size_t (*get_size)(const struct net_device___112 *);
	int (*fill_info)(struct sk_buff___113 *, const struct net_device___112 *);
	size_t (*get_xstats_size)(const struct net_device___112 *);
	int (*fill_xstats)(struct sk_buff___113 *, const struct net_device___112 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___112 *, struct net_device___112 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___112 *, const struct net_device___112 *);
	int (*fill_slave_info)(struct sk_buff___113 *, const struct net_device___112 *, const struct net_device___112 *);
	struct net___117 * (*get_link_net)(const struct net_device___112 *);
	size_t (*get_linkxstats_size)(const struct net_device___112 *, int);
	int (*fill_linkxstats)(struct sk_buff___113 *, const struct net_device___112 *, int *, int);
};

struct netdev_notifier_info___23 {
	struct net_device___112 *dev;
	struct netlink_ext_ack *extack;
};

struct block_device_operations___191;

struct gendisk___194 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___194 *part0;
	const struct block_device_operations___191 *fops;
	struct request_queue___191 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___177 *bdi;
	struct kobject___291 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___291 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___191 {
	struct bio___191 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___220 *bip_vec;
	struct bio_vec___220 bip_inline_vecs[0];
};

struct blkcg___179;

struct blkg_policy_data___179;

struct blkcg_gq___179 {
	struct request_queue___191 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___179 *blkcg;
	struct blkcg_gq___179 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___179 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___191 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___191(struct request___191 *);

typedef void integrity_complete_fn___191(struct request___191 *, unsigned int);

struct blk_integrity_profile___191 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___191 *prepare_fn;
	integrity_complete_fn___191 *complete_fn;
	const char *name;
};

struct block_device_operations___191 {
	blk_qc_t (*submit_bio)(struct bio___191 *);
	int (*open)(struct block_device___194 *, fmode_t);
	void (*release)(struct gendisk___194 *, fmode_t);
	int (*rw_page)(struct block_device___194 *, sector_t, struct page___308 *, unsigned int);
	int (*ioctl)(struct block_device___194 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___194 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___194 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___194 *);
	int (*getgeo)(struct block_device___194 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___194 *, bool);
	void (*swap_slot_free_notify)(struct block_device___194 *, long unsigned int);
	int (*report_zones)(struct gendisk___194 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___194 *, umode_t *);
	struct module___287 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___194 *, sector_t *);
};

typedef void rq_end_io_fn___191(struct request___191 *, blk_status_t);

struct request___191 {
	struct request_queue___191 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___186 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___191 *bio;
	struct bio___191 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___220 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___191 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___191 *saved_end_io;
		} flush;
	};
	struct gendisk___194 *rq_disk;
	struct block_device___194 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___191 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___186 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___191 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___291 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___303 *debugfs_dir;
	struct dentry___303 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___191;

struct elevator_mq_ops___191 {
	int (*init_sched)(struct request_queue___191 *, struct elevator_type___191 *);
	void (*exit_sched)(struct elevator_queue___191 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___186 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___186 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___186 *);
	bool (*allow_merge)(struct request_queue___191 *, struct request___191 *, struct bio___191 *);
	bool (*bio_merge)(struct request_queue___191 *, struct bio___191 *, unsigned int);
	int (*request_merge)(struct request_queue___191 *, struct request___191 **, struct bio___191 *);
	void (*request_merged)(struct request_queue___191 *, struct request___191 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___191 *, struct request___191 *, struct request___191 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___191 *);
	void (*finish_request)(struct request___191 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___186 *, struct list_head *, bool);
	struct request___191 * (*dispatch_request)(struct blk_mq_hw_ctx___186 *);
	bool (*has_work)(struct blk_mq_hw_ctx___186 *);
	void (*completed_request)(struct request___191 *, u64);
	void (*requeue_request)(struct request___191 *);
	struct request___191 * (*former_request)(struct request_queue___191 *, struct request___191 *);
	struct request___191 * (*next_request)(struct request_queue___191 *, struct request___191 *);
	void (*init_icq)(struct io_cq___191 *);
	void (*exit_icq)(struct io_cq___191 *);
};

struct elv_fs_entry___191;

struct elevator_type___191 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___191 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___191 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___287 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___191 {
	struct elevator_type___191 *type;
	void *elevator_data;
	struct kobject___291 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___191 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___191 *, char *);
	ssize_t (*store)(struct elevator_queue___191 *, const char *, size_t);
};

struct blk_mq_queue_data___186;

struct blk_mq_ops___186 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___186 *, const struct blk_mq_queue_data___186 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___186 *);
	int (*get_budget)(struct request_queue___191 *);
	void (*put_budget)(struct request_queue___191 *, int);
	void (*set_rq_budget_token)(struct request___191 *, int);
	int (*get_rq_budget_token)(struct request___191 *);
	enum blk_eh_timer_return (*timeout)(struct request___191 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___186 *);
	void (*complete)(struct request___191 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___186 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___186 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___186 *, struct request___191 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___186 *, struct request___191 *, unsigned int);
	void (*initialize_rq_fn)(struct request___191 *);
	void (*cleanup_rq)(struct request___191 *);
	bool (*busy)(struct request_queue___191 *);
	int (*map_queues)(struct blk_mq_tag_set___186 *);
	void (*show_rq)(struct seq_file___278 *, struct request___191 *);
};

struct blk_mq_tag_set___186 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___186 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___186 {
	struct request___191 *rq;
	bool last;
};

struct blkcg_policy_data___179;

struct blkcg___179 {
	struct cgroup_subsys_state___230 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___179 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___179 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___179 {
	struct blkcg___179 *blkcg;
	int plid;
};

struct blkg_policy_data___179 {
	struct blkcg_gq___179 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___165 {
	struct mem_cgroup___165 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___165 {
	struct lruvec___173 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___165 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___165 *memcg;
};

struct obj_cgroup___165 {
	struct percpu_ref refcnt;
	struct mem_cgroup___165 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___103 {
	spinlock_t *lock;
	struct sk_buff___113 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___103;

struct Qdisc_ops___103 {
	struct Qdisc_ops___103 *next;
	const struct Qdisc_class_ops___103 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___113 *, struct Qdisc___103 *, struct sk_buff___113 **);
	struct sk_buff___113 * (*dequeue)(struct Qdisc___103 *);
	struct sk_buff___113 * (*peek)(struct Qdisc___103 *);
	int (*init)(struct Qdisc___103 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___103 *);
	void (*destroy)(struct Qdisc___103 *);
	int (*change)(struct Qdisc___103 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___103 *);
	int (*change_tx_queue_len)(struct Qdisc___103 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___103 *, unsigned int);
	int (*dump)(struct Qdisc___103 *, struct sk_buff___113 *);
	int (*dump_stats)(struct Qdisc___103 *, struct gnet_dump___103 *);
	void (*ingress_block_set)(struct Qdisc___103 *, u32);
	void (*egress_block_set)(struct Qdisc___103 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___103 *);
	u32 (*egress_block_get)(struct Qdisc___103 *);
	struct module___287 *owner;
};

struct Qdisc_class_ops___103 {
	unsigned int flags;
	struct netdev_queue___112 * (*select_queue)(struct Qdisc___103 *, struct tcmsg *);
	int (*graft)(struct Qdisc___103 *, long unsigned int, struct Qdisc___103 *, struct Qdisc___103 **, struct netlink_ext_ack *);
	struct Qdisc___103 * (*leaf)(struct Qdisc___103 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___103 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___103 *, u32);
	int (*change)(struct Qdisc___103 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___103 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___103 *, struct qdisc_walker *);
	struct tcf_block___103 * (*tcf_block)(struct Qdisc___103 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___103 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___103 *, long unsigned int);
	int (*dump)(struct Qdisc___103 *, long unsigned int, struct sk_buff___113 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___103 *, long unsigned int, struct gnet_dump___103 *);
};

struct tcf_chain___103;

struct tcf_block___103 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___117 *net;
	struct Qdisc___103 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___103 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___103;

struct tcf_proto_ops___103;

struct tcf_proto___103 {
	struct tcf_proto___103 *next;
	void *root;
	int (*classify)(struct sk_buff___113 *, const struct tcf_proto___103 *, struct tcf_result___103 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___103 *ops;
	struct tcf_chain___103 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___103 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___103 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___103 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___113 *, const struct tcf_proto___103 *, struct tcf_result___103 *);
	int (*init)(struct tcf_proto___103 *);
	void (*destroy)(struct tcf_proto___103 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___103 *, u32);
	void (*put)(struct tcf_proto___103 *, void *);
	int (*change)(struct net___117 *, struct sk_buff___113 *, struct tcf_proto___103 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___103 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___103 *);
	void (*walk)(struct tcf_proto___103 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___103 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___103 *, void *);
	void (*hw_del)(struct tcf_proto___103 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___117 *, struct tcf_chain___103 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___117 *, struct tcf_proto___103 *, void *, struct sk_buff___113 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___117 *, struct tcf_proto___103 *, void *, struct sk_buff___113 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___113 *, struct net___117 *, void *);
	struct module___287 *owner;
	int flags;
};

struct tcf_chain___103 {
	struct mutex filter_chain_lock;
	struct tcf_proto___103 *filter_chain;
	struct list_head list;
	struct tcf_block___103 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___103 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___96 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___103 *prog;
};

typedef struct poll_table_struct___221 poll_table___57;

struct pneigh_entry___97;

struct neigh_hash_table___97;

struct neigh_table___97 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___112 *, __u32 *);
	bool (*key_eq)(const struct neighbour___97 *, const void *);
	int (*constructor)(struct neighbour___97 *);
	int (*pconstructor)(struct pneigh_entry___97 *);
	void (*pdestructor)(struct pneigh_entry___97 *);
	void (*proxy_redo)(struct sk_buff___113 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___112 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___97 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___112 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___97 *nht;
	struct pneigh_entry___97 **phash_buckets;
};

struct neigh_ops___97 {
	int family;
	void (*solicit)(struct neighbour___97 *, struct sk_buff___113 *);
	void (*error_report)(struct neighbour___97 *, struct sk_buff___113 *);
	int (*output)(struct neighbour___97 *, struct sk_buff___113 *);
	int (*connected_output)(struct neighbour___97 *, struct sk_buff___113 *);
};

struct pneigh_entry___97 {
	struct pneigh_entry___97 *next;
	possible_net_t___112 net;
	struct net_device___112 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___97 {
	struct neighbour___97 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___71 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___117 *, struct sock___96 *, struct sk_buff___113 *);
	int (*orig_input)(struct sk_buff___113 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___96 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___96 *ctarget;
	struct net___117 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___96 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___96 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___81;

struct timewait_sock_ops___79;

struct proto___96 {
	void (*close)(struct sock___96 *, long int);
	int (*pre_connect)(struct sock___96 *, struct sockaddr *, int);
	int (*connect)(struct sock___96 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___96 *, int);
	struct sock___96 * (*accept)(struct sock___96 *, int, int *, bool);
	int (*ioctl)(struct sock___96 *, int, long unsigned int);
	int (*init)(struct sock___96 *);
	void (*destroy)(struct sock___96 *);
	void (*shutdown)(struct sock___96 *, int);
	int (*setsockopt)(struct sock___96 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___96 *, int, int, char *, int *);
	void (*keepalive)(struct sock___96 *, int);
	int (*compat_ioctl)(struct sock___96 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___96 *, struct msghdr___99 *, size_t);
	int (*recvmsg)(struct sock___96 *, struct msghdr___99 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___96 *, struct page___308 *, int, size_t, int);
	int (*bind)(struct sock___96 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___96 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___96 *, struct sk_buff___113 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___96 *);
	int (*hash)(struct sock___96 *);
	void (*unhash)(struct sock___96 *);
	void (*rehash)(struct sock___96 *);
	int (*get_port)(struct sock___96 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___96 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___96 *, int);
	bool (*sock_is_readable)(struct sock___96 *);
	void (*enter_memory_pressure)(struct sock___96 *);
	void (*leave_memory_pressure)(struct sock___96 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___81 *rsk_prot;
	struct timewait_sock_ops___79 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___287 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___96 *, int);
};

struct request_sock___82;

struct request_sock_ops___81 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___96 *, struct request_sock___82 *);
	void (*send_ack)(const struct sock___96 *, struct sk_buff___113 *, struct request_sock___82 *);
	void (*send_reset)(const struct sock___96 *, struct sk_buff___113 *);
	void (*destructor)(struct request_sock___82 *);
	void (*syn_ack_timeout)(const struct request_sock___82 *);
};

struct timewait_sock_ops___79 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___96 *, struct sock___96 *, void *);
	void (*twsk_destructor)(struct sock___96 *);
};

struct xdp_umem___4 {
	void *addrs;
	u64 size;
	u32 headroom;
	u32 chunk_size;
	u32 chunks;
	u32 npgs;
	struct user_struct *user;
	refcount_t users;
	u8 flags;
	bool zc;
	struct page___308 **pgs;
	int id;
	struct list_head xsk_dma_list;
	struct work_struct work;
};

struct xdp_sock___2;

struct xsk_map {
	struct bpf_map___115 map;
	spinlock_t lock;
	struct xdp_sock___2 *xsk_map[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_sock___2 {
	struct sock___96 sk;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *rx;
	struct net_device___112 *dev;
	struct xdp_umem___4 *umem;
	struct list_head flush_node;
	struct xsk_buff_pool___3 *pool;
	u16 queue_id;
	bool zc;
	enum {
		XSK_READY___2 = 0,
		XSK_BOUND___2 = 1,
		XSK_UNBOUND___2 = 2,
	} state;
	long: 64;
	struct xsk_queue *tx;
	struct list_head tx_list;
	spinlock_t rx_lock;
	u64 rx_dropped;
	u64 rx_queue_full;
	struct list_head map_list;
	spinlock_t map_list_lock;
	struct mutex mutex;
	struct xsk_queue *fq_tmp;
	struct xsk_queue *cq_tmp;
	long: 64;
};

struct xdp_ring;

struct xsk_queue {
	u32 ring_mask;
	u32 nentries;
	u32 cached_prod;
	u32 cached_cons;
	struct xdp_ring *ring;
	u64 invalid_descs;
	u64 queue_empty_descs;
};

struct xdp_buff_xsk___3 {
	struct xdp_buff___112 xdp;
	dma_addr_t dma;
	dma_addr_t frame_dma;
	struct xsk_buff_pool___3 *pool;
	bool unaligned;
	u64 orig_addr;
	struct list_head free_list_node;
};

struct request_sock___82 {
	struct sock_common___96 __req_common;
	struct request_sock___82 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___81 *rsk_ops;
	struct sock___96 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct ifmcaddr6___77 {
	struct in6_addr mca_addr;
	struct inet6_dev___77 *idev;
	struct ifmcaddr6___77 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct xdp_ring_offset_v1 {
	__u64 producer;
	__u64 consumer;
	__u64 desc;
};

struct xdp_mmap_offsets_v1 {
	struct xdp_ring_offset_v1 rx;
	struct xdp_ring_offset_v1 tx;
	struct xdp_ring_offset_v1 fr;
	struct xdp_ring_offset_v1 cr;
};

struct xsk_map_node {
	struct list_head node;
	struct xsk_map *map;
	struct xdp_sock___2 **map_entry;
};

struct xdp_ring {
	u32 producer;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pad1;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 consumer;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pad2;
	u32 flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pad3;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_rxtx_ring {
	struct xdp_ring ptrs;
	struct xdp_desc desc[0];
};

struct xdp_umem_ring {
	struct xdp_ring ptrs;
	u64 desc[0];
};

struct xdp_ring___2;

struct xsk_queue___2 {
	u32 ring_mask;
	u32 nentries;
	u32 cached_prod;
	u32 cached_cons;
	struct xdp_ring___2 *ring;
	u64 invalid_descs;
	u64 queue_empty_descs;
};

struct xdp_ring___2 {
	u32 producer;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pad1;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 consumer;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pad2;
	u32 flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 pad3;
};

struct xdp_rxtx_ring___2 {
	struct xdp_ring___2 ptrs;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct xdp_desc desc[0];
};

struct xdp_umem_ring___2 {
	struct xdp_ring___2 ptrs;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u64 desc[0];
};

struct xdp_sock___3;

struct xsk_map___2 {
	struct bpf_map___101 map;
	spinlock_t lock;
	struct xdp_sock___3 *xsk_map[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_sock___3 {
	struct sock___85 sk;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct xsk_queue *rx;
	struct net_device___98 *dev;
	struct xdp_umem___2 *umem;
	struct list_head flush_node;
	struct xsk_buff_pool *pool;
	u16 queue_id;
	bool zc;
	enum {
		XSK_READY___3 = 0,
		XSK_BOUND___3 = 1,
		XSK_UNBOUND___3 = 2,
	} state;
	long: 64;
	struct xsk_queue *tx;
	struct list_head tx_list;
	spinlock_t rx_lock;
	u64 rx_dropped;
	u64 rx_queue_full;
	struct list_head map_list;
	spinlock_t map_list_lock;
	struct mutex mutex;
	struct xsk_queue *fq_tmp;
	struct xsk_queue *cq_tmp;
	long: 64;
};

struct xsk_map_node___2 {
	struct list_head node;
	struct xsk_map___2 *map;
	struct xdp_sock___3 **map_entry;
};

struct xsk_dma_map {
	dma_addr_t *dma_pages;
	struct device___270 *dev;
	struct net_device___98 *netdev;
	refcount_t users;
	struct list_head list;
	u32 dma_pages_cnt;
	bool dma_need_sync;
};

struct mptcp_mib {
	long unsigned int mibs[43];
};

struct ubuf_info___15 {
	void (*callback)(struct sk_buff___102 *, struct ubuf_info___15 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct skb_shared_info___45 {
	__u8 flags;
	__u8 meta_len;
	__u8 nr_frags;
	__u8 tx_flags;
	short unsigned int gso_size;
	short unsigned int gso_segs;
	struct sk_buff___102 *frag_list;
	struct skb_shared_hwtstamps hwtstamps;
	unsigned int gso_type;
	u32 tskey;
	atomic_t dataref;
	void *destructor_arg;
	skb_frag_t___40 frags[17];
};

struct napi_struct___16 {
	struct list_head poll_list;
	long unsigned int state;
	int weight;
	int defer_hard_irqs_count;
	long unsigned int gro_bitmask;
	int (*poll)(struct napi_struct___16 *, int);
	int poll_owner;
	struct net_device___101 *dev;
	struct gro_list gro_hash[8];
	struct sk_buff___102 *skb;
	struct list_head rx_list;
	int rx_count;
	struct hrtimer timer;
	struct list_head dev_list;
	struct hlist_node napi_hash_node;
	unsigned int napi_id;
	struct task_struct___299 *thread;
};

typedef struct poll_table_struct___213 poll_table___58;

struct socket_alloc___7 {
	struct socket___90 socket;
	struct inode___292 vfs_inode;
	long: 64;
};

struct fastopen_queue___15 {
	struct request_sock___74 *rskq_rst_head;
	struct request_sock___74 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___15 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___74 *rskq_accept_head;
	struct request_sock___74 *rskq_accept_tail;
	struct fastopen_queue___15 fastopenq;
};

struct inet_connection_sock_af_ops___15 {
	int (*queue_xmit)(struct sock___88 *, struct sk_buff___102 *, struct flowi *);
	void (*send_check)(struct sock___88 *, struct sk_buff___102 *);
	int (*rebuild_header)(struct sock___88 *);
	void (*sk_rx_dst_set)(struct sock___88 *, const struct sk_buff___102 *);
	int (*conn_request)(struct sock___88 *, struct sk_buff___102 *);
	struct sock___88 * (*syn_recv_sock)(const struct sock___88 *, struct sk_buff___102 *, struct request_sock___74 *, struct dst_entry___88 *, struct request_sock___74 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___88 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___88 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___88 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___88 *);
};

struct inet_bind_bucket___15;

struct tcp_ulp_ops___15;

struct inet_connection_sock___15 {
	struct inet_sock___23 icsk_inet;
	struct request_sock_queue___15 icsk_accept_queue;
	struct inet_bind_bucket___15 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___34 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___15 *icsk_af_ops;
	const struct tcp_ulp_ops___15 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___88 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___88 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___15 {
	possible_net_t___101 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___15 {
	struct list_head list;
	int (*init)(struct sock___88 *);
	void (*update)(struct sock___88 *, struct proto___88 *, void (*)(struct sock___88 *));
	void (*release)(struct sock___88 *);
	int (*get_info)(const struct sock___88 *, struct sk_buff___102 *);
	size_t (*get_info_size)(const struct sock___88 *);
	void (*clone)(const struct request_sock___74 *, struct sock___88 *, const gfp_t);
	char name[16];
	struct module___276 *owner;
};

struct tcp_request_sock_ops___7;

struct tcp_request_sock___7 {
	struct inet_request_sock___8 req;
	const struct tcp_request_sock_ops___7 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_request_sock_ops___7 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___88 *, const struct sock___88 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___88 *, const struct sk_buff___102 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___102 *, __u16 *);
	struct dst_entry___88 * (*route_req)(const struct sock___88 *, struct sk_buff___102 *, struct flowi *, struct request_sock___74 *);
	u32 (*init_seq)(const struct sk_buff___102 *);
	u32 (*init_ts_off)(const struct net___106 *, const struct sk_buff___102 *);
	int (*send_synack)(const struct sock___88 *, struct dst_entry___88 *, struct flowi *, struct request_sock___74 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___102 *);
};

struct tcp_sock_af_ops___12;

struct tcp_fastopen_request___12;

struct tcp_sock___12 {
	struct inet_connection_sock___15 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___102 *lost_skb_hint;
	struct sk_buff___102 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___102 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___102 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___12 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___12 *fastopen_req;
	struct request_sock___74 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___12 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___88 *, const struct sock___88 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___88 *, const struct sk_buff___102 *);
	int (*md5_parse)(struct sock___88 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___12 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___90 *data;
	size_t size;
	int copied;
	struct ubuf_info___15 *uarg;
};

struct inet_protosw___6 {
	struct list_head list;
	short unsigned int type;
	short unsigned int protocol;
	struct proto___88 *prot;
	const struct proto_ops___89 *ops;
	unsigned char flags;
};

enum mptcp_event_type {
	MPTCP_EVENT_UNSPEC = 0,
	MPTCP_EVENT_CREATED = 1,
	MPTCP_EVENT_ESTABLISHED = 2,
	MPTCP_EVENT_CLOSED = 3,
	MPTCP_EVENT_ANNOUNCED = 6,
	MPTCP_EVENT_REMOVED = 7,
	MPTCP_EVENT_SUB_ESTABLISHED = 10,
	MPTCP_EVENT_SUB_CLOSED = 11,
	MPTCP_EVENT_SUB_PRIORITY = 13,
};

struct mptcp_options_received {
	u64 sndr_key;
	u64 rcvr_key;
	u64 data_ack;
	u64 data_seq;
	u32 subflow_seq;
	u16 data_len;
	__sum16 csum;
	u16 suboptions;
	u32 token;
	u32 nonce;
	u16 use_map: 1;
	u16 dsn64: 1;
	u16 data_fin: 1;
	u16 use_ack: 1;
	u16 ack64: 1;
	u16 mpc_map: 1;
	u16 reset_reason: 4;
	u16 reset_transient: 1;
	u16 echo: 1;
	u16 backup: 1;
	u16 deny_join_id0: 1;
	u16 __unused: 2;
	long: 46;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 join_id;
	u64 thmac;
	u8 hmac[20];
	struct mptcp_addr_info addr;
	struct mptcp_rm_list rm_list;
	u64 ahmac;
	u64 fail_seq;
};

struct mptcp_pm_data {
	struct mptcp_addr_info local;
	struct mptcp_addr_info remote;
	struct list_head anno_list;
	spinlock_t lock;
	u8 addr_signal;
	bool server_side;
	bool work_pending;
	bool accept_addr;
	bool accept_subflow;
	bool remote_deny_join_id0;
	u8 add_addr_signaled;
	u8 add_addr_accepted;
	u8 local_addr_used;
	u8 subflows;
	u8 status;
	struct mptcp_rm_list rm_list_tx;
	struct mptcp_rm_list rm_list_rx;
};

struct mptcp_data_frag {
	struct list_head list;
	u64 data_seq;
	u16 data_len;
	u16 offset;
	u16 overhead;
	u16 already_sent;
	struct page___297 *page;
};

struct mptcp_sock {
	struct inet_connection_sock___15 sk;
	u64 local_key;
	u64 remote_key;
	u64 write_seq;
	u64 snd_nxt;
	u64 ack_seq;
	u64 rcv_wnd_sent;
	u64 rcv_data_fin_seq;
	int wmem_reserved;
	struct sock___88 *last_snd;
	int snd_burst;
	int old_wspace;
	u64 recovery_snd_nxt;
	u64 snd_una;
	u64 wnd_end;
	long unsigned int timer_ival;
	u32 token;
	int rmem_released;
	long unsigned int flags;
	bool recovery;
	bool can_ack;
	bool fully_established;
	bool rcv_data_fin;
	bool snd_data_fin_enable;
	bool rcv_fastclose;
	bool use_64bit_ack;
	bool csum_enabled;
	spinlock_t join_list_lock;
	struct work_struct work;
	struct sk_buff___102 *ooo_last_skb;
	struct rb_root out_of_order_queue;
	struct sk_buff_head___101 receive_queue;
	int tx_pending_data;
	struct list_head conn_list;
	struct list_head rtx_queue;
	struct mptcp_data_frag *first_pending;
	struct list_head join_list;
	struct socket___90 *subflow;
	struct sock___88 *first;
	struct mptcp_pm_data pm;
	struct {
		u32 space;
		u32 copied;
		u64 time;
		u64 rtt_us;
	} rcvq_space;
	u32 setsockopt_seq;
	char ca_name[16];
};

struct mptcp_subflow_request_sock {
	struct tcp_request_sock___7 sk;
	u16 mp_capable: 1;
	u16 mp_join: 1;
	u16 backup: 1;
	u16 csum_reqd: 1;
	u16 allow_join_id0: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 local_id;
	u8 remote_id;
	u64 local_key;
	u64 idsn;
	u32 token;
	u32 ssn_offset;
	u64 thmac;
	u32 local_nonce;
	u32 remote_nonce;
	struct mptcp_sock *msk;
	struct hlist_nulls_node token_node;
};

enum mptcp_data_avail {
	MPTCP_SUBFLOW_NODATA = 0,
	MPTCP_SUBFLOW_DATA_AVAIL = 1,
};

struct mptcp_delegated_action {
	struct napi_struct___16 napi;
	struct list_head head;
};

struct mptcp_subflow_context {
	struct list_head node;
	u64 local_key;
	u64 remote_key;
	u64 idsn;
	u64 map_seq;
	u32 snd_isn;
	u32 token;
	u32 rel_write_seq;
	u32 map_subflow_seq;
	u32 ssn_offset;
	u32 map_data_len;
	__wsum map_data_csum;
	u32 map_csum_len;
	u32 request_mptcp: 1;
	u32 request_join: 1;
	u32 request_bkup: 1;
	u32 mp_capable: 1;
	u32 mp_join: 1;
	u32 fully_established: 1;
	u32 pm_notified: 1;
	u32 conn_finished: 1;
	u32 map_valid: 1;
	u32 map_csum_reqd: 1;
	u32 map_data_fin: 1;
	u32 mpc_map: 1;
	u32 backup: 1;
	u32 send_mp_prio: 1;
	u32 send_mp_fail: 1;
	u32 rx_eof: 1;
	u32 can_ack: 1;
	u32 disposable: 1;
	u32 stale: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum mptcp_data_avail data_avail;
	u32 remote_nonce;
	u64 thmac;
	u32 local_nonce;
	u32 remote_token;
	u8 hmac[20];
	u8 local_id;
	u8 remote_id;
	u8 reset_seen: 1;
	u8 reset_transient: 1;
	u8 reset_reason: 4;
	long: 52;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 stale_count;
	long int delegated_status;
	struct list_head delegated_node;
	u32 setsockopt_seq;
	u32 stale_rcv_tstamp;
	struct sock___88 *tcp_sock;
	struct sock___88 *conn;
	const struct inet_connection_sock_af_ops___15 *icsk_af_ops;
	void (*tcp_data_ready)(struct sock___88 *);
	void (*tcp_state_change)(struct sock___88 *);
	void (*tcp_write_space)(struct sock___88 *);
	void (*tcp_error_report)(struct sock___88 *);
	struct callback_head rcu;
};

enum linux_mptcp_mib_field {
	MPTCP_MIB_NUM = 0,
	MPTCP_MIB_MPCAPABLEPASSIVE = 1,
	MPTCP_MIB_MPCAPABLEACTIVE = 2,
	MPTCP_MIB_MPCAPABLEACTIVEACK = 3,
	MPTCP_MIB_MPCAPABLEPASSIVEACK = 4,
	MPTCP_MIB_MPCAPABLEPASSIVEFALLBACK = 5,
	MPTCP_MIB_MPCAPABLEACTIVEFALLBACK = 6,
	MPTCP_MIB_TOKENFALLBACKINIT = 7,
	MPTCP_MIB_RETRANSSEGS = 8,
	MPTCP_MIB_JOINNOTOKEN = 9,
	MPTCP_MIB_JOINSYNRX = 10,
	MPTCP_MIB_JOINSYNACKRX = 11,
	MPTCP_MIB_JOINSYNACKMAC = 12,
	MPTCP_MIB_JOINACKRX = 13,
	MPTCP_MIB_JOINACKMAC = 14,
	MPTCP_MIB_DSSNOMATCH = 15,
	MPTCP_MIB_INFINITEMAPRX = 16,
	MPTCP_MIB_DSSTCPMISMATCH = 17,
	MPTCP_MIB_DATACSUMERR = 18,
	MPTCP_MIB_OFOQUEUETAIL = 19,
	MPTCP_MIB_OFOQUEUE = 20,
	MPTCP_MIB_OFOMERGE = 21,
	MPTCP_MIB_NODSSWINDOW = 22,
	MPTCP_MIB_DUPDATA = 23,
	MPTCP_MIB_ADDADDR = 24,
	MPTCP_MIB_ECHOADD = 25,
	MPTCP_MIB_PORTADD = 26,
	MPTCP_MIB_ADDADDRDROP = 27,
	MPTCP_MIB_JOINPORTSYNRX = 28,
	MPTCP_MIB_JOINPORTSYNACKRX = 29,
	MPTCP_MIB_JOINPORTACKRX = 30,
	MPTCP_MIB_MISMATCHPORTSYNRX = 31,
	MPTCP_MIB_MISMATCHPORTACKRX = 32,
	MPTCP_MIB_RMADDR = 33,
	MPTCP_MIB_RMADDRDROP = 34,
	MPTCP_MIB_RMSUBFLOW = 35,
	MPTCP_MIB_MPPRIOTX = 36,
	MPTCP_MIB_MPPRIORX = 37,
	MPTCP_MIB_MPFAILTX = 38,
	MPTCP_MIB_MPFAILRX = 39,
	MPTCP_MIB_RCVPRUNED = 40,
	MPTCP_MIB_SUBFLOWSTALE = 41,
	MPTCP_MIB_SUBFLOWRECOVER = 42,
	__MPTCP_MIB_MAX = 43,
};

struct trace_event_raw_mptcp_subflow_get_send {
	struct trace_entry ent;
	bool active;
	bool free;
	u32 snd_wnd;
	u32 pace;
	u8 backup;
	u64 ratio;
	char __data[0];
};

struct trace_event_raw_mptcp_dump_mpext {
	struct trace_entry ent;
	u64 data_ack;
	u64 data_seq;
	u32 subflow_seq;
	u16 data_len;
	u16 csum;
	u8 use_map;
	u8 dsn64;
	u8 data_fin;
	u8 use_ack;
	u8 ack64;
	u8 mpc_map;
	u8 frozen;
	u8 reset_transient;
	u8 reset_reason;
	u8 csum_reqd;
	char __data[0];
};

struct trace_event_raw_ack_update_msk {
	struct trace_entry ent;
	u64 data_ack;
	u64 old_snd_una;
	u64 new_snd_una;
	u64 new_wnd_end;
	u64 msk_wnd_end;
	char __data[0];
};

struct trace_event_raw_subflow_check_data_avail {
	struct trace_entry ent;
	u8 status;
	const void *skb;
	char __data[0];
};

struct trace_event_data_offsets_mptcp_subflow_get_send {};

struct trace_event_data_offsets_mptcp_dump_mpext {};

struct trace_event_data_offsets_ack_update_msk {};

struct trace_event_data_offsets_subflow_check_data_avail {};

typedef void (*btf_trace_mptcp_subflow_get_send)(void *, struct mptcp_subflow_context *);

typedef void (*btf_trace_get_mapping_status)(void *, struct mptcp_ext *);

typedef void (*btf_trace_ack_update_msk)(void *, u64, u64, u64, u64, u64);

typedef void (*btf_trace_subflow_check_data_avail)(void *, __u8, struct sk_buff___102 *);

struct mptcp_skb_cb {
	u64 map_seq;
	u64 end_seq;
	u32 offset;
	u8 has_rxtstamp: 1;
	long: 63;
	long: 64;
	long: 64;
};

enum {
	MPTCP_CMSG_TS = 1,
};

struct mptcp_sendmsg_info {
	int mss_now;
	int size_goal;
	u16 limit;
	u16 sent;
	unsigned int flags;
	bool data_lock_held;
};

struct subflow_send_info {
	struct sock___88 *ssk;
	u64 ratio;
};

struct socket_alloc___8 {
	struct socket___96 socket;
	struct inode___298 vfs_inode;
	long: 64;
};

struct inet_request_sock___10 {
	struct request_sock___80 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___108 *pktopts;
		};
	};
};

struct tcp_request_sock_ops___8;

struct tcp_request_sock___8 {
	struct inet_request_sock___10 req;
	const struct tcp_request_sock_ops___8 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct tcp_request_sock_ops___8 {
	u16 mss_clamp;
	struct tcp_md5sig_key * (*req_md5_lookup)(const struct sock___94 *, const struct sock___94 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___94 *, const struct sk_buff___108 *);
	__u32 (*cookie_init_seq)(const struct sk_buff___108 *, __u16 *);
	struct dst_entry___94 * (*route_req)(const struct sock___94 *, struct sk_buff___108 *, struct flowi *, struct request_sock___80 *);
	u32 (*init_seq)(const struct sk_buff___108 *);
	u32 (*init_ts_off)(const struct net___112 *, const struct sk_buff___108 *);
	int (*send_synack)(const struct sock___94 *, struct dst_entry___94 *, struct flowi *, struct request_sock___80 *, struct tcp_fastopen_cookie *, enum tcp_synack_type, struct sk_buff___108 *);
};

struct mptcp_data_frag___2 {
	struct list_head list;
	u64 data_seq;
	u16 data_len;
	u16 offset;
	u16 overhead;
	u16 already_sent;
	struct page___303 *page;
};

struct mptcp_sock___2 {
	struct inet_connection_sock___13 sk;
	u64 local_key;
	u64 remote_key;
	u64 write_seq;
	u64 snd_nxt;
	u64 ack_seq;
	u64 rcv_wnd_sent;
	u64 rcv_data_fin_seq;
	int wmem_reserved;
	struct sock___94 *last_snd;
	int snd_burst;
	int old_wspace;
	u64 recovery_snd_nxt;
	u64 snd_una;
	u64 wnd_end;
	long unsigned int timer_ival;
	u32 token;
	int rmem_released;
	long unsigned int flags;
	bool recovery;
	bool can_ack;
	bool fully_established;
	bool rcv_data_fin;
	bool snd_data_fin_enable;
	bool rcv_fastclose;
	bool use_64bit_ack;
	bool csum_enabled;
	spinlock_t join_list_lock;
	struct work_struct work;
	struct sk_buff___108 *ooo_last_skb;
	struct rb_root out_of_order_queue;
	struct sk_buff_head___107 receive_queue;
	int tx_pending_data;
	struct list_head conn_list;
	struct list_head rtx_queue;
	struct mptcp_data_frag___2 *first_pending;
	struct list_head join_list;
	struct socket___96 *subflow;
	struct sock___94 *first;
	struct mptcp_pm_data pm;
	struct {
		u32 space;
		u32 copied;
		u64 time;
		u64 rtt_us;
	} rcvq_space;
	u32 setsockopt_seq;
	char ca_name[16];
};

struct csum_pseudo_header {
	__be64 data_seq;
	__be32 subflow_seq;
	__be16 data_len;
	__sum16 csum;
};

struct mptcp_subflow_request_sock___2 {
	struct tcp_request_sock___8 sk;
	u16 mp_capable: 1;
	u16 mp_join: 1;
	u16 backup: 1;
	u16 csum_reqd: 1;
	u16 allow_join_id0: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 local_id;
	u8 remote_id;
	u64 local_key;
	u64 idsn;
	u32 token;
	u32 ssn_offset;
	u64 thmac;
	u32 local_nonce;
	u32 remote_nonce;
	struct mptcp_sock___2 *msk;
	struct hlist_nulls_node token_node;
};

struct mptcp_subflow_context___2 {
	struct list_head node;
	u64 local_key;
	u64 remote_key;
	u64 idsn;
	u64 map_seq;
	u32 snd_isn;
	u32 token;
	u32 rel_write_seq;
	u32 map_subflow_seq;
	u32 ssn_offset;
	u32 map_data_len;
	__wsum map_data_csum;
	u32 map_csum_len;
	u32 request_mptcp: 1;
	u32 request_join: 1;
	u32 request_bkup: 1;
	u32 mp_capable: 1;
	u32 mp_join: 1;
	u32 fully_established: 1;
	u32 pm_notified: 1;
	u32 conn_finished: 1;
	u32 map_valid: 1;
	u32 map_csum_reqd: 1;
	u32 map_data_fin: 1;
	u32 mpc_map: 1;
	u32 backup: 1;
	u32 send_mp_prio: 1;
	u32 send_mp_fail: 1;
	u32 rx_eof: 1;
	u32 can_ack: 1;
	u32 disposable: 1;
	u32 stale: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum mptcp_data_avail data_avail;
	u32 remote_nonce;
	u64 thmac;
	u32 local_nonce;
	u32 remote_token;
	u8 hmac[20];
	u8 local_id;
	u8 remote_id;
	u8 reset_seen: 1;
	u8 reset_transient: 1;
	u8 reset_reason: 4;
	long: 52;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 stale_count;
	long int delegated_status;
	struct list_head delegated_node;
	u32 setsockopt_seq;
	u32 stale_rcv_tstamp;
	struct sock___94 *tcp_sock;
	struct sock___94 *conn;
	const struct inet_connection_sock_af_ops___13 *icsk_af_ops;
	void (*tcp_data_ready)(struct sock___94 *);
	void (*tcp_state_change)(struct sock___94 *);
	void (*tcp_write_space)(struct sock___94 *);
	void (*tcp_error_report)(struct sock___94 *);
	struct callback_head rcu;
};

enum mapping_status {
	MAPPING_OK = 0,
	MAPPING_INVALID = 1,
	MAPPING_EMPTY = 2,
	MAPPING_DATA_FIN = 3,
	MAPPING_DUMMY = 4,
};

enum mptcp_addr_signal_status {
	MPTCP_ADD_ADDR_SIGNAL = 0,
	MPTCP_ADD_ADDR_ECHO = 1,
	MPTCP_RM_ADDR_SIGNAL = 2,
};

struct mptcp_pm_add_entry;

struct inet_request_sock___11 {
	struct request_sock___80 req;
	u16 snd_wscale: 4;
	u16 rcv_wscale: 4;
	u16 tstamp_ok: 1;
	u16 sack_ok: 1;
	u16 wscale_ok: 1;
	u16 ecn_ok: 1;
	u16 acked: 1;
	u16 no_srccheck: 1;
	u16 smc_ok: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ir_mark;
	union {
		struct ip_options_rcu *ireq_opt;
		struct {
			struct ipv6_txoptions *ipv6_opt;
			struct sk_buff___108 *pktopts;
		};
	};
	long: 64;
	long: 64;
};

struct tcp_request_sock___9 {
	struct inet_request_sock___11 req;
	const struct tcp_request_sock_ops___8 *af_specific;
	u64 snt_synack;
	bool tfo_listener;
	bool is_mptcp;
	bool drop_req;
	u32 txhash;
	u32 rcv_isn;
	u32 snt_isn;
	u32 ts_off;
	u32 last_oow_ack_time;
	u32 rcv_nxt;
	u8 syn_tos;
};

struct mptcp_addr_info___2 {
	u8 id;
	sa_family_t family;
	__be16 port;
	union {
		struct in_addr addr;
		struct in6_addr addr6;
	};
	long: 64;
	long: 64;
};

struct mptcp_pm_data___2 {
	struct mptcp_addr_info___2 local;
	struct mptcp_addr_info___2 remote;
	struct list_head anno_list;
	spinlock_t lock;
	u8 addr_signal;
	bool server_side;
	bool work_pending;
	bool accept_addr;
	bool accept_subflow;
	bool remote_deny_join_id0;
	u8 add_addr_signaled;
	u8 add_addr_accepted;
	u8 local_addr_used;
	u8 subflows;
	u8 status;
	struct mptcp_rm_list rm_list_tx;
	struct mptcp_rm_list rm_list_rx;
};

struct mptcp_sock___3 {
	struct inet_connection_sock___15 sk;
	u64 local_key;
	u64 remote_key;
	u64 write_seq;
	u64 snd_nxt;
	u64 ack_seq;
	u64 rcv_wnd_sent;
	u64 rcv_data_fin_seq;
	int wmem_reserved;
	struct sock___94 *last_snd;
	int snd_burst;
	int old_wspace;
	u64 recovery_snd_nxt;
	u64 snd_una;
	u64 wnd_end;
	long unsigned int timer_ival;
	u32 token;
	int rmem_released;
	long unsigned int flags;
	bool recovery;
	bool can_ack;
	bool fully_established;
	bool rcv_data_fin;
	bool snd_data_fin_enable;
	bool rcv_fastclose;
	bool use_64bit_ack;
	bool csum_enabled;
	spinlock_t join_list_lock;
	struct work_struct work;
	struct sk_buff___108 *ooo_last_skb;
	struct rb_root out_of_order_queue;
	struct sk_buff_head___107 receive_queue;
	int tx_pending_data;
	struct list_head conn_list;
	struct list_head rtx_queue;
	struct mptcp_data_frag___2 *first_pending;
	struct list_head join_list;
	struct socket___96 *subflow;
	struct sock___94 *first;
	struct mptcp_pm_data___2 pm;
	struct {
		u32 space;
		u32 copied;
		u64 time;
		u64 rtt_us;
	} rcvq_space;
	u32 setsockopt_seq;
	char ca_name[16];
};

struct mptcp_subflow_request_sock___3 {
	struct tcp_request_sock___9 sk;
	u16 mp_capable: 1;
	u16 mp_join: 1;
	u16 backup: 1;
	u16 csum_reqd: 1;
	u16 allow_join_id0: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 local_id;
	u8 remote_id;
	u64 local_key;
	u64 idsn;
	u32 token;
	u32 ssn_offset;
	u64 thmac;
	u32 local_nonce;
	u32 remote_nonce;
	struct mptcp_sock___3 *msk;
	struct hlist_nulls_node token_node;
};

struct token_bucket {
	spinlock_t lock;
	int chain_len;
	struct hlist_nulls_head req_chain;
	struct hlist_nulls_head msk_chain;
};

struct pernet_operations___43 {
	struct list_head list;
	int (*init)(struct net___95 *);
	void (*pre_exit)(struct net___95 *);
	void (*exit)(struct net___95 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct mptcp_pernet {
	struct ctl_table_header *ctl_table_hdr;
	unsigned int add_addr_timeout;
	unsigned int stale_loss_cnt;
	u8 mptcp_enabled;
	u8 checksum_enabled;
	u8 allow_join_initial_addr_port;
};

enum mptcp_pm_status {
	MPTCP_PM_ADD_ADDR_RECEIVED = 0,
	MPTCP_PM_ADD_ADDR_SEND_ACK = 1,
	MPTCP_PM_RM_ADDR_RECEIVED = 2,
	MPTCP_PM_ESTABLISHED = 3,
	MPTCP_PM_ALREADY_ESTABLISHED = 4,
	MPTCP_PM_SUBFLOW_ESTABLISHED = 5,
};

enum {
	INET_ULP_INFO_UNSPEC = 0,
	INET_ULP_INFO_NAME = 1,
	INET_ULP_INFO_TLS = 2,
	INET_ULP_INFO_MPTCP = 3,
	__INET_ULP_INFO_MAX = 4,
};

enum {
	MPTCP_SUBFLOW_ATTR_UNSPEC = 0,
	MPTCP_SUBFLOW_ATTR_TOKEN_REM = 1,
	MPTCP_SUBFLOW_ATTR_TOKEN_LOC = 2,
	MPTCP_SUBFLOW_ATTR_RELWRITE_SEQ = 3,
	MPTCP_SUBFLOW_ATTR_MAP_SEQ = 4,
	MPTCP_SUBFLOW_ATTR_MAP_SFSEQ = 5,
	MPTCP_SUBFLOW_ATTR_SSN_OFFSET = 6,
	MPTCP_SUBFLOW_ATTR_MAP_DATALEN = 7,
	MPTCP_SUBFLOW_ATTR_FLAGS = 8,
	MPTCP_SUBFLOW_ATTR_ID_REM = 9,
	MPTCP_SUBFLOW_ATTR_ID_LOC = 10,
	MPTCP_SUBFLOW_ATTR_PAD = 11,
	__MPTCP_SUBFLOW_ATTR_MAX = 12,
};

struct dentry___304;

struct super_block___304;

struct module___288;

struct file_system_type___304 {
	const char *name;
	int fs_flags;
	int (*init_fs_context)(struct fs_context *);
	const struct fs_parameter_spec *parameters;
	struct dentry___304 * (*mount)(struct file_system_type___304 *, int, const char *, void *);
	void (*kill_sb)(struct super_block___304 *);
	struct module___288 *owner;
	struct file_system_type___304 *next;
	struct hlist_head fs_supers;
	struct lock_class_key s_lock_key;
	struct lock_class_key s_umount_key;
	struct lock_class_key s_vfs_rename_key;
	struct lock_class_key s_writers_key[3];
	struct lock_class_key i_lock_key;
	struct lock_class_key i_mutex_key;
	struct lock_class_key invalidate_lock_key;
	struct lock_class_key i_mutex_dir_key;
};

struct file___304;

struct kiocb___304;

struct iov_iter___224;

struct poll_table_struct___222;

struct vm_area_struct___309;

struct inode___304;

struct file_lock___304;

struct page___309;

struct pipe_inode_info___145;

struct seq_file___279;

struct file_operations___305 {
	struct module___288 *owner;
	loff_t (*llseek)(struct file___304 *, loff_t, int);
	ssize_t (*read)(struct file___304 *, char *, size_t, loff_t *);
	ssize_t (*write)(struct file___304 *, const char *, size_t, loff_t *);
	ssize_t (*read_iter)(struct kiocb___304 *, struct iov_iter___224 *);
	ssize_t (*write_iter)(struct kiocb___304 *, struct iov_iter___224 *);
	int (*iopoll)(struct kiocb___304 *, bool);
	int (*iterate)(struct file___304 *, struct dir_context *);
	int (*iterate_shared)(struct file___304 *, struct dir_context *);
	__poll_t (*poll)(struct file___304 *, struct poll_table_struct___222 *);
	long int (*unlocked_ioctl)(struct file___304 *, unsigned int, long unsigned int);
	long int (*compat_ioctl)(struct file___304 *, unsigned int, long unsigned int);
	int (*mmap)(struct file___304 *, struct vm_area_struct___309 *);
	long unsigned int mmap_supported_flags;
	int (*open)(struct inode___304 *, struct file___304 *);
	int (*flush)(struct file___304 *, fl_owner_t);
	int (*release)(struct inode___304 *, struct file___304 *);
	int (*fsync)(struct file___304 *, loff_t, loff_t, int);
	int (*fasync)(int, struct file___304 *, int);
	int (*lock)(struct file___304 *, int, struct file_lock___304 *);
	ssize_t (*sendpage)(struct file___304 *, struct page___309 *, int, size_t, loff_t *, int);
	long unsigned int (*get_unmapped_area)(struct file___304 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
	int (*check_flags)(int);
	int (*setfl)(struct file___304 *, long unsigned int);
	int (*flock)(struct file___304 *, int, struct file_lock___304 *);
	ssize_t (*splice_write)(struct pipe_inode_info___145 *, struct file___304 *, loff_t *, size_t, unsigned int);
	ssize_t (*splice_read)(struct file___304 *, loff_t *, struct pipe_inode_info___145 *, size_t, unsigned int);
	int (*setlease)(struct file___304 *, long int, struct file_lock___304 **, void **);
	long int (*fallocate)(struct file___304 *, int, loff_t, loff_t);
	void (*show_fdinfo)(struct seq_file___279 *, struct file___304 *);
	ssize_t (*copy_file_range)(struct file___304 *, loff_t, struct file___304 *, loff_t, size_t, unsigned int);
	loff_t (*remap_file_range)(struct file___304 *, loff_t, struct file___304 *, loff_t, loff_t, unsigned int);
	int (*fadvise)(struct file___304 *, loff_t, loff_t, int);
};

struct vmacache___309 {
	u64 seqnum;
	struct vm_area_struct___309 *vmas[4];
};

struct page_frag___309 {
	struct page___309 *page;
	__u32 offset;
	__u32 size;
};

struct mm_struct___310;

struct pid___281;

struct nsproxy___290;

struct signal_struct___305;

struct bio_list___192;

struct backing_dev_info___178;

struct io_context___192;

struct css_set___231;

struct mem_cgroup___166;

struct request_queue___192;

struct vm_struct___287;

struct task_struct___311 {
	struct thread_info thread_info;
	unsigned int __state;
	void *stack;
	refcount_t usage;
	unsigned int flags;
	unsigned int ptrace;
	int on_cpu;
	struct __call_single_node wake_entry;
	unsigned int cpu;
	unsigned int wakee_flips;
	long unsigned int wakee_flip_decay_ts;
	struct task_struct___311 *last_wakee;
	int recent_used_cpu;
	int wake_cpu;
	int on_rq;
	int prio;
	int static_prio;
	int normal_prio;
	unsigned int rt_priority;
	const struct sched_class *sched_class;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct sched_entity se;
	struct sched_rt_entity rt;
	struct sched_dl_entity dl;
	struct rb_node core_node;
	long unsigned int core_cookie;
	unsigned int core_occupation;
	struct task_group *sched_task_group;
	struct uclamp_se uclamp_req[2];
	struct uclamp_se uclamp[2];
	struct hlist_head preempt_notifiers;
	unsigned int btrace_seq;
	unsigned int policy;
	int nr_cpus_allowed;
	const cpumask_t *cpus_ptr;
	cpumask_t *user_cpus_ptr;
	cpumask_t cpus_mask;
	void *migration_pending;
	short unsigned int migration_disabled;
	short unsigned int migration_flags;
	int trc_reader_nesting;
	int trc_ipi_to_cpu;
	union rcu_special trc_reader_special;
	bool trc_reader_checked;
	struct list_head trc_holdout_list;
	struct sched_info sched_info;
	struct list_head tasks;
	struct plist_node pushable_tasks;
	struct rb_node pushable_dl_tasks;
	struct mm_struct___310 *mm;
	struct mm_struct___310 *active_mm;
	struct vmacache___309 vmacache;
	struct task_rss_stat rss_stat;
	int exit_state;
	int exit_code;
	int exit_signal;
	int pdeath_signal;
	long unsigned int jobctl;
	unsigned int personality;
	unsigned int sched_reset_on_fork: 1;
	unsigned int sched_contributes_to_load: 1;
	unsigned int sched_migrated: 1;
	unsigned int sched_psi_wake_requeue: 1;
	unsigned int sched_remote_wakeup: 1;
	unsigned int in_execve: 1;
	unsigned int in_iowait: 1;
	unsigned int in_user_fault: 1;
	unsigned int no_cgroup_migration: 1;
	unsigned int frozen: 1;
	unsigned int use_memdelay: 1;
	unsigned int in_memstall: 1;
	unsigned int in_eventfd_signal: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long unsigned int atomic_flags;
	struct restart_block restart_block;
	pid_t pid;
	pid_t tgid;
	long unsigned int stack_canary;
	struct task_struct___311 *real_parent;
	struct task_struct___311 *parent;
	struct list_head children;
	struct list_head sibling;
	struct task_struct___311 *group_leader;
	struct list_head ptraced;
	struct list_head ptrace_entry;
	struct pid___281 *thread_pid;
	struct hlist_node pid_links[4];
	struct list_head thread_group;
	struct list_head thread_node;
	struct completion *vfork_done;
	int *set_child_tid;
	int *clear_child_tid;
	void *pf_io_worker;
	u64 utime;
	u64 stime;
	u64 gtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	u64 start_time;
	u64 start_boottime;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	struct posix_cputimers posix_cputimers;
	const struct cred___31 *ptracer_cred;
	const struct cred___31 *real_cred;
	const struct cred___31 *cred;
	struct key___2 *cached_requested_key;
	char comm[16];
	struct nameidata *nameidata;
	struct sysv_sem sysvsem;
	struct sysv_shm sysvshm;
	long unsigned int last_switch_count;
	long unsigned int last_switch_time;
	struct fs_struct *fs;
	struct files_struct *files;
	struct io_uring_task *io_uring;
	struct nsproxy___290 *nsproxy;
	struct signal_struct___305 *signal;
	struct sighand_struct *sighand;
	sigset_t blocked;
	sigset_t real_blocked;
	sigset_t saved_sigmask;
	struct sigpending pending;
	long unsigned int sas_ss_sp;
	size_t sas_ss_size;
	unsigned int sas_ss_flags;
	struct callback_head *task_works;
	struct audit_context *audit_context;
	kuid_t loginuid;
	unsigned int sessionid;
	struct seccomp seccomp;
	struct syscall_user_dispatch syscall_dispatch;
	u64 parent_exec_id;
	u64 self_exec_id;
	spinlock_t alloc_lock;
	raw_spinlock_t pi_lock;
	struct wake_q_node wake_q;
	struct rb_root_cached pi_waiters;
	struct task_struct___311 *pi_top_task;
	struct rt_mutex_waiter *pi_blocked_on;
	unsigned int in_ubsan;
	void *journal_info;
	struct bio_list___192 *bio_list;
	struct blk_plug *plug;
	struct reclaim_state *reclaim_state;
	struct backing_dev_info___178 *backing_dev_info;
	struct io_context___192 *io_context;
	struct capture_control *capture_control;
	long unsigned int ptrace_message;
	kernel_siginfo_t *last_siginfo;
	struct task_io_accounting ioac;
	unsigned int psi_flags;
	u64 acct_rss_mem1;
	u64 acct_vm_mem1;
	u64 acct_timexpd;
	nodemask_t mems_allowed;
	seqcount_spinlock_t mems_allowed_seq;
	int cpuset_mem_spread_rotor;
	int cpuset_slab_spread_rotor;
	struct css_set___231 *cgroups;
	struct list_head cg_list;
	struct robust_list_head *robust_list;
	struct compat_robust_list_head *compat_robust_list;
	struct list_head pi_state_list;
	struct futex_pi_state *pi_state_cache;
	struct mutex futex_exit_mutex;
	unsigned int futex_state;
	struct perf_event_context___2 *perf_event_ctxp[2];
	struct mutex perf_event_mutex;
	struct list_head perf_event_list;
	struct mempolicy *mempolicy;
	short int il_prev;
	short int pref_node_fork;
	int numa_scan_seq;
	unsigned int numa_scan_period;
	unsigned int numa_scan_period_max;
	int numa_preferred_nid;
	long unsigned int numa_migrate_retry;
	u64 node_stamp;
	u64 last_task_numa_placement;
	u64 last_sum_exec_runtime;
	struct callback_head numa_work;
	struct numa_group *numa_group;
	long unsigned int *numa_faults;
	long unsigned int total_numa_faults;
	long unsigned int numa_faults_locality[3];
	long unsigned int numa_pages_migrated;
	struct rseq *rseq;
	u32 rseq_sig;
	long unsigned int rseq_event_mask;
	struct tlbflush_unmap_batch tlb_ubc;
	union {
		refcount_t rcu_users;
		struct callback_head rcu;
	};
	struct pipe_inode_info___145 *splice_pipe;
	struct page_frag___309 task_frag;
	struct task_delay_info *delays;
	int nr_dirtied;
	int nr_dirtied_pause;
	long unsigned int dirty_paused_when;
	u64 timer_slack_ns;
	u64 default_timer_slack_ns;
	int curr_ret_stack;
	int curr_ret_depth;
	struct ftrace_ret_stack *ret_stack;
	long long unsigned int ftrace_timestamp;
	atomic_t trace_overrun;
	atomic_t tracing_graph_pause;
	long unsigned int trace;
	long unsigned int trace_recursion;
	struct mem_cgroup___166 *memcg_in_oom;
	gfp_t memcg_oom_gfp_mask;
	int memcg_oom_order;
	unsigned int memcg_nr_pages_over_high;
	struct mem_cgroup___166 *active_memcg;
	struct request_queue___192 *throttle_queue;
	struct uprobe_task___4 *utask;
	unsigned int sequential_io;
	unsigned int sequential_io_avg;
	struct kmap_ctrl kmap_ctrl;
	int pagefault_disabled;
	struct task_struct___311 *oom_reaper_list;
	struct vm_struct___287 *stack_vm_area;
	refcount_t stack_refcount;
	void *security;
	struct bpf_local_storage *bpf_storage;
	struct bpf_run_ctx *bpf_ctx;
	struct llist_head kretprobe_instances;
	struct thread_struct___88 thread;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct kset___292;

struct kobj_type___292;

struct kernfs_node___292;

struct kobject___292 {
	const char *name;
	struct list_head entry;
	struct kobject___292 *parent;
	struct kset___292 *kset;
	struct kobj_type___292 *ktype;
	struct kernfs_node___292 *sd;
	struct kref kref;
	unsigned int state_initialized: 1;
	unsigned int state_in_sysfs: 1;
	unsigned int state_add_uevent_sent: 1;
	unsigned int state_remove_uevent_sent: 1;
	unsigned int uevent_suppress: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct module_kobject___289 {
	struct kobject___292 kobj;
	struct module___288 *mod;
	struct kobject___292 *drivers_dir;
	struct module_param_attrs *mp;
	struct completion *kobj_completion;
};

struct mod_tree_node___288 {
	struct module___288 *mod;
	struct latch_tree_node node;
};

struct module_layout___288 {
	void *base;
	unsigned int size;
	unsigned int text_size;
	unsigned int ro_size;
	unsigned int ro_after_init_size;
	struct mod_tree_node___288 mtn;
};

struct module_attribute___288;

struct kernel_param___288;

struct module___288 {
	enum module_state state;
	struct list_head list;
	char name[56];
	struct module_kobject___289 mkobj;
	struct module_attribute___288 *modinfo_attrs;
	const char *version;
	const char *srcversion;
	struct kobject___292 *holders_dir;
	const struct kernel_symbol *syms;
	const s32 *crcs;
	unsigned int num_syms;
	struct mutex param_lock;
	struct kernel_param___288 *kp;
	unsigned int num_kp;
	unsigned int num_gpl_syms;
	const struct kernel_symbol *gpl_syms;
	const s32 *gpl_crcs;
	bool using_gplonly_symbols;
	bool sig_ok;
	bool async_probe_requested;
	unsigned int num_exentries;
	struct exception_table_entry *extable;
	int (*init)();
	struct module_layout___288 core_layout;
	struct module_layout___288 init_layout;
	struct mod_arch_specific arch;
	long unsigned int taints;
	unsigned int num_bugs;
	struct list_head bug_list;
	struct bug_entry *bug_table;
	struct mod_kallsyms *kallsyms;
	struct mod_kallsyms core_kallsyms;
	struct module_sect_attrs *sect_attrs;
	struct module_notes_attrs *notes_attrs;
	char *args;
	void *percpu;
	unsigned int percpu_size;
	void *noinstr_text_start;
	unsigned int noinstr_text_size;
	unsigned int num_tracepoints;
	tracepoint_ptr_t *tracepoints_ptrs;
	unsigned int num_srcu_structs;
	struct srcu_struct **srcu_struct_ptrs;
	unsigned int num_bpf_raw_events;
	struct bpf_raw_event_map *bpf_raw_events;
	unsigned int btf_data_size;
	void *btf_data;
	struct jump_entry *jump_entries;
	unsigned int num_jump_entries;
	unsigned int num_trace_bprintk_fmt;
	const char **trace_bprintk_fmt_start;
	struct trace_event_call___5 **trace_events;
	unsigned int num_trace_events;
	struct trace_eval_map **trace_evals;
	unsigned int num_trace_evals;
	unsigned int num_ftrace_callsites;
	long unsigned int *ftrace_callsites;
	void *kprobes_text_start;
	unsigned int kprobes_text_size;
	long unsigned int *kprobe_blacklist;
	unsigned int num_kprobe_blacklist;
	struct list_head source_list;
	struct list_head target_list;
	void (*exit)();
	atomic_t refcnt;
	struct error_injection_entry *ei_funcs;
	unsigned int num_ei_funcs;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bio_vec___221 {
	struct page___309 *bv_page;
	unsigned int bv_len;
	unsigned int bv_offset;
};

struct fasync_struct___304;

struct pipe_buffer___145;

struct pipe_inode_info___145 {
	struct mutex mutex;
	wait_queue_head_t rd_wait;
	wait_queue_head_t wr_wait;
	unsigned int head;
	unsigned int tail;
	unsigned int max_usage;
	unsigned int ring_size;
	bool note_loss;
	unsigned int nr_accounted;
	unsigned int readers;
	unsigned int writers;
	unsigned int files;
	unsigned int r_counter;
	unsigned int w_counter;
	unsigned int poll_usage;
	struct page___309 *tmp_page;
	struct fasync_struct___304 *fasync_readers;
	struct fasync_struct___304 *fasync_writers;
	struct pipe_buffer___145 *bufs;
	struct user_struct *user;
	struct watch_queue *watch_queue;
};

struct iov_iter___224 {
	u8 iter_type;
	bool data_source;
	size_t iov_offset;
	size_t count;
	union {
		const struct iovec *iov;
		const struct kvec *kvec;
		const struct bio_vec___221 *bvec;
		struct xarray *xarray;
		struct pipe_inode_info___145 *pipe;
	};
	union {
		long unsigned int nr_segs;
		struct {
			unsigned int head;
			unsigned int start_head;
		};
		loff_t xarray_start;
	};
};

struct msghdr___100 {
	void *msg_name;
	int msg_namelen;
	struct iov_iter___224 msg_iter;
	union {
		void *msg_control;
		void *msg_control_user;
	};
	bool msg_control_is_user: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__kernel_size_t msg_controllen;
	unsigned int msg_flags;
	struct kiocb___304 *msg_iocb;
};

struct kiocb___304 {
	struct file___304 *ki_filp;
	loff_t ki_pos;
	void (*ki_complete)(struct kiocb___304 *, long int, long int);
	void *private;
	int ki_flags;
	u16 ki_hint;
	u16 ki_ioprio;
	union {
		unsigned int ki_cookie;
		struct wait_page_queue___117 *ki_waitq;
	};
};

struct net_device___113;

struct sock___97;

struct sk_buff___114 {
	union {
		struct {
			struct sk_buff___114 *next;
			struct sk_buff___114 *prev;
			union {
				struct net_device___113 *dev;
				long unsigned int dev_scratch;
			};
		};
		struct rb_node rbnode;
		struct list_head list;
	};
	union {
		struct sock___97 *sk;
		int ip_defrag_offset;
	};
	union {
		ktime_t tstamp;
		u64 skb_mstamp_ns;
	};
	char cb[48];
	union {
		struct {
			long unsigned int _skb_refdst;
			void (*destructor)(struct sk_buff___114 *);
		};
		struct list_head tcp_tsorted_anchor;
		long unsigned int _sk_redir;
	};
	long unsigned int _nfct;
	unsigned int len;
	unsigned int data_len;
	__u16 mac_len;
	__u16 hdr_len;
	__u16 queue_mapping;
	__u8 __cloned_offset[0];
	__u8 cloned: 1;
	__u8 nohdr: 1;
	__u8 fclone: 2;
	__u8 peeked: 1;
	__u8 head_frag: 1;
	__u8 pfmemalloc: 1;
	__u8 pp_recycle: 1;
	long: 55;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 active_extensions;
	__u32 headers_start[0];
	__u8 __pkt_type_offset[0];
	__u8 pkt_type: 3;
	__u8 ignore_df: 1;
	__u8 nf_trace: 1;
	__u8 ip_summed: 2;
	__u8 ooo_okay: 1;
	__u8 l4_hash: 1;
	__u8 sw_hash: 1;
	__u8 wifi_acked_valid: 1;
	__u8 wifi_acked: 1;
	__u8 no_fcs: 1;
	__u8 encapsulation: 1;
	__u8 encap_hdr_csum: 1;
	__u8 csum_valid: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 __pkt_vlan_present_offset[0];
	__u8 vlan_present: 1;
	__u8 csum_complete_sw: 1;
	__u8 csum_level: 2;
	__u8 csum_not_inet: 1;
	__u8 dst_pending_confirm: 1;
	__u8 ndisc_nodetype: 2;
	__u8 ipvs_property: 1;
	__u8 inner_protocol_type: 1;
	__u8 remcsum_offload: 1;
	__u8 offload_fwd_mark: 1;
	__u8 offload_l3_fwd_mark: 1;
	__u8 tc_skip_classify: 1;
	__u8 tc_at_ingress: 1;
	__u8 redirected: 1;
	__u8 from_ingress: 1;
	__u8 decrypted: 1;
	__u8 slow_gro: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u16 tc_index;
	union {
		__wsum csum;
		struct {
			__u16 csum_start;
			__u16 csum_offset;
		};
	};
	__u32 priority;
	int skb_iif;
	__u32 hash;
	__be16 vlan_proto;
	__u16 vlan_tci;
	union {
		unsigned int napi_id;
		unsigned int sender_cpu;
	};
	__u32 secmark;
	union {
		__u32 mark;
		__u32 reserved_tailroom;
	};
	union {
		__be16 inner_protocol;
		__u8 inner_ipproto;
	};
	__u16 inner_transport_header;
	__u16 inner_network_header;
	__u16 inner_mac_header;
	__be16 protocol;
	__u16 transport_header;
	__u16 network_header;
	__u16 mac_header;
	__u32 headers_end[0];
	sk_buff_data_t tail;
	sk_buff_data_t end;
	unsigned char *head;
	unsigned char *data;
	unsigned int truesize;
	refcount_t users;
	struct skb_ext *extensions;
};

struct inet_frags___118;

struct net___118;

struct fqdir___118 {
	long int high_thresh;
	long int low_thresh;
	int timeout;
	int max_dist;
	struct inet_frags___118 *f;
	struct net___118 *net;
	bool dead;
	long: 56;
	long: 64;
	long: 64;
	struct rhashtable rhashtable;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	atomic_long_t mem;
	struct work_struct destroy_work;
	struct llist_node free_list;
	long: 64;
	long: 64;
};

struct inet_frag_queue___118;

struct inet_frags___118 {
	unsigned int qsize;
	void (*constructor)(struct inet_frag_queue___118 *, const void *);
	void (*destructor)(struct inet_frag_queue___118 *);
	void (*frag_expire)(struct timer_list *);
	struct kmem_cache *frags_cachep;
	const char *frags_cache_name;
	struct rhashtable_params rhash_params;
	refcount_t refcnt;
	struct completion completion;
};

struct ip_ra_chain___69;

struct fib_rules_ops___97;

struct tcp_congestion_ops___40;

struct fib_notifier_ops___97;

struct netns_ipv4___118 {
	struct inet_timewait_death_row tcp_death_row;
	struct ctl_table_header *forw_hdr;
	struct ctl_table_header *frags_hdr;
	struct ctl_table_header *ipv4_hdr;
	struct ctl_table_header *route_hdr;
	struct ctl_table_header *xfrm4_hdr;
	struct ipv4_devconf *devconf_all;
	struct ipv4_devconf *devconf_dflt;
	struct ip_ra_chain___69 *ra_chain;
	struct mutex ra_mutex;
	struct fib_rules_ops___97 *rules_ops;
	struct fib_table *fib_main;
	struct fib_table *fib_default;
	unsigned int fib_rules_require_fldissect;
	bool fib_has_custom_rules;
	bool fib_has_custom_local_routes;
	bool fib_offload_disabled;
	atomic_t fib_num_tclassid_users;
	struct hlist_head *fib_table_hash;
	struct sock___97 *fibnl;
	struct sock___97 **icmp_sk;
	struct sock___97 *mc_autojoin_sk;
	struct inet_peer_base *peers;
	struct sock___97 **tcp_sk;
	struct fqdir___118 *fqdir;
	u8 sysctl_icmp_echo_ignore_all;
	u8 sysctl_icmp_echo_enable_probe;
	u8 sysctl_icmp_echo_ignore_broadcasts;
	u8 sysctl_icmp_ignore_bogus_error_responses;
	u8 sysctl_icmp_errors_use_inbound_ifaddr;
	int sysctl_icmp_ratelimit;
	int sysctl_icmp_ratemask;
	struct local_ports ip_local_ports;
	u8 sysctl_tcp_ecn;
	u8 sysctl_tcp_ecn_fallback;
	u8 sysctl_ip_default_ttl;
	u8 sysctl_ip_no_pmtu_disc;
	u8 sysctl_ip_fwd_use_pmtu;
	u8 sysctl_ip_fwd_update_priority;
	u8 sysctl_ip_nonlocal_bind;
	u8 sysctl_ip_autobind_reuse;
	u8 sysctl_ip_dynaddr;
	u8 sysctl_ip_early_demux;
	u8 sysctl_raw_l3mdev_accept;
	u8 sysctl_tcp_early_demux;
	u8 sysctl_udp_early_demux;
	u8 sysctl_nexthop_compat_mode;
	u8 sysctl_fwmark_reflect;
	u8 sysctl_tcp_fwmark_accept;
	u8 sysctl_tcp_l3mdev_accept;
	u8 sysctl_tcp_mtu_probing;
	int sysctl_tcp_mtu_probe_floor;
	int sysctl_tcp_base_mss;
	int sysctl_tcp_min_snd_mss;
	int sysctl_tcp_probe_threshold;
	u32 sysctl_tcp_probe_interval;
	int sysctl_tcp_keepalive_time;
	int sysctl_tcp_keepalive_intvl;
	u8 sysctl_tcp_keepalive_probes;
	u8 sysctl_tcp_syn_retries;
	u8 sysctl_tcp_synack_retries;
	u8 sysctl_tcp_syncookies;
	u8 sysctl_tcp_migrate_req;
	int sysctl_tcp_reordering;
	u8 sysctl_tcp_retries1;
	u8 sysctl_tcp_retries2;
	u8 sysctl_tcp_orphan_retries;
	u8 sysctl_tcp_tw_reuse;
	int sysctl_tcp_fin_timeout;
	unsigned int sysctl_tcp_notsent_lowat;
	u8 sysctl_tcp_sack;
	u8 sysctl_tcp_window_scaling;
	u8 sysctl_tcp_timestamps;
	u8 sysctl_tcp_early_retrans;
	u8 sysctl_tcp_recovery;
	u8 sysctl_tcp_thin_linear_timeouts;
	u8 sysctl_tcp_slow_start_after_idle;
	u8 sysctl_tcp_retrans_collapse;
	u8 sysctl_tcp_stdurg;
	u8 sysctl_tcp_rfc1337;
	u8 sysctl_tcp_abort_on_overflow;
	u8 sysctl_tcp_fack;
	int sysctl_tcp_max_reordering;
	int sysctl_tcp_adv_win_scale;
	u8 sysctl_tcp_dsack;
	u8 sysctl_tcp_app_win;
	u8 sysctl_tcp_frto;
	u8 sysctl_tcp_nometrics_save;
	u8 sysctl_tcp_no_ssthresh_metrics_save;
	u8 sysctl_tcp_moderate_rcvbuf;
	u8 sysctl_tcp_tso_win_divisor;
	u8 sysctl_tcp_workaround_signed_windows;
	int sysctl_tcp_limit_output_bytes;
	int sysctl_tcp_challenge_ack_limit;
	int sysctl_tcp_min_rtt_wlen;
	u8 sysctl_tcp_min_tso_segs;
	u8 sysctl_tcp_autocorking;
	u8 sysctl_tcp_reflect_tos;
	u8 sysctl_tcp_comp_sack_nr;
	int sysctl_tcp_invalid_ratelimit;
	int sysctl_tcp_pacing_ss_ratio;
	int sysctl_tcp_pacing_ca_ratio;
	int sysctl_tcp_wmem[3];
	int sysctl_tcp_rmem[3];
	long unsigned int sysctl_tcp_comp_sack_delay_ns;
	long unsigned int sysctl_tcp_comp_sack_slack_ns;
	int sysctl_max_syn_backlog;
	int sysctl_tcp_fastopen;
	const struct tcp_congestion_ops___40 *tcp_congestion_control;
	struct tcp_fastopen_context *tcp_fastopen_ctx;
	unsigned int sysctl_tcp_fastopen_blackhole_timeout;
	atomic_t tfo_active_disable_times;
	long unsigned int tfo_active_disable_stamp;
	int sysctl_udp_wmem_min;
	int sysctl_udp_rmem_min;
	u8 sysctl_fib_notify_on_flag_change;
	u8 sysctl_udp_l3mdev_accept;
	u8 sysctl_igmp_llm_reports;
	int sysctl_igmp_max_memberships;
	int sysctl_igmp_max_msf;
	int sysctl_igmp_qrv;
	struct ping_group_range ping_group_range;
	atomic_t dev_addr_genid;
	long unsigned int *sysctl_local_reserved_ports;
	int sysctl_ip_prot_sock;
	struct list_head mr_tables;
	struct fib_rules_ops___97 *mr_rules_ops;
	u32 sysctl_fib_multipath_hash_fields;
	u8 sysctl_fib_multipath_use_neigh;
	u8 sysctl_fib_multipath_hash_policy;
	struct fib_notifier_ops___97 *notifier_ops;
	unsigned int fib_seq;
	struct fib_notifier_ops___97 *ipmr_notifier_ops;
	unsigned int ipmr_seq;
	atomic_t rt_genid;
	siphash_key_t___2 ip_id_key;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dst_entry___97;

struct neighbour___98;

struct dst_ops___118 {
	short unsigned int family;
	unsigned int gc_thresh;
	int (*gc)(struct dst_ops___118 *);
	struct dst_entry___97 * (*check)(struct dst_entry___97 *, __u32);
	unsigned int (*default_advmss)(const struct dst_entry___97 *);
	unsigned int (*mtu)(const struct dst_entry___97 *);
	u32 * (*cow_metrics)(struct dst_entry___97 *, long unsigned int);
	void (*destroy)(struct dst_entry___97 *);
	void (*ifdown)(struct dst_entry___97 *, struct net_device___113 *, int);
	struct dst_entry___97 * (*negative_advice)(struct dst_entry___97 *);
	void (*link_failure)(struct sk_buff___114 *);
	void (*update_pmtu)(struct dst_entry___97 *, struct sock___97 *, struct sk_buff___114 *, u32, bool);
	void (*redirect)(struct dst_entry___97 *, struct sock___97 *, struct sk_buff___114 *);
	int (*local_out)(struct net___118 *, struct sock___97 *, struct sk_buff___114 *);
	struct neighbour___98 * (*neigh_lookup)(const struct dst_entry___97 *, struct sk_buff___114 *, const void *);
	void (*confirm_neigh)(const struct dst_entry___97 *, const void *);
	struct kmem_cache *kmem_cachep;
	struct percpu_counter pcpuc_entries;
	long: 64;
	long: 64;
	long: 64;
};

struct netns_ipv6___118 {
	struct dst_ops___118 ip6_dst_ops;
	struct netns_sysctl_ipv6 sysctl;
	struct ipv6_devconf *devconf_all;
	struct ipv6_devconf *devconf_dflt;
	struct inet_peer_base *peers;
	struct fqdir___118 *fqdir;
	struct fib6_info *fib6_null_entry;
	struct rt6_info *ip6_null_entry;
	struct rt6_statistics *rt6_stats;
	struct timer_list ip6_fib_timer;
	struct hlist_head *fib_table_hash;
	struct fib6_table *fib6_main_tbl;
	struct list_head fib6_walkers;
	rwlock_t fib6_walker_lock;
	spinlock_t fib6_gc_lock;
	unsigned int ip6_rt_gc_expire;
	long unsigned int ip6_rt_last_gc;
	unsigned char flowlabel_has_excl;
	bool fib6_has_custom_rules;
	unsigned int fib6_rules_require_fldissect;
	unsigned int fib6_routes_require_src;
	struct rt6_info *ip6_prohibit_entry;
	struct rt6_info *ip6_blk_hole_entry;
	struct fib6_table *fib6_local_tbl;
	struct fib_rules_ops___97 *fib6_rules_ops;
	struct sock___97 **icmp_sk;
	struct sock___97 *ndisc_sk;
	struct sock___97 *tcp_sk;
	struct sock___97 *igmp_sk;
	struct sock___97 *mc_autojoin_sk;
	struct list_head mr6_tables;
	struct fib_rules_ops___97 *mr6_rules_ops;
	atomic_t dev_addr_genid;
	atomic_t fib6_sernum;
	struct seg6_pernet_data *seg6_data;
	struct fib_notifier_ops___97 *notifier_ops;
	struct fib_notifier_ops___97 *ip6mr_notifier_ops;
	unsigned int ipmr_seq;
	struct {
		struct hlist_head head;
		spinlock_t lock;
		u32 seq;
	} ip6addrlbl_table;
	struct ioam6_pernet_data *ioam6_data;
};

struct netns_ieee802154_lowpan___118 {
	struct netns_sysctl_lowpan sysctl;
	struct fqdir___118 *fqdir;
};

struct netns_sctp___97 {
	struct sctp_mib *sctp_statistics;
	struct proc_dir_entry *proc_net_sctp;
	struct ctl_table_header *sysctl_header;
	struct sock___97 *ctl_sock;
	struct sock___97 *udp4_sock;
	struct sock___97 *udp6_sock;
	int udp_port;
	int encap_port;
	struct list_head local_addr_list;
	struct list_head addr_waitq;
	struct timer_list addr_wq_timer;
	struct list_head auto_asconf_splist;
	spinlock_t addr_wq_lock;
	spinlock_t local_addr_lock;
	unsigned int rto_initial;
	unsigned int rto_min;
	unsigned int rto_max;
	int rto_alpha;
	int rto_beta;
	int max_burst;
	int cookie_preserve_enable;
	char *sctp_hmac_alg;
	unsigned int valid_cookie_life;
	unsigned int sack_timeout;
	unsigned int hb_interval;
	unsigned int probe_interval;
	int max_retrans_association;
	int max_retrans_path;
	int max_retrans_init;
	int pf_retrans;
	int ps_retrans;
	int pf_enable;
	int pf_expose;
	int sndbuf_policy;
	int rcvbuf_policy;
	int default_auto_asconf;
	int addip_enable;
	int addip_noauth;
	int prsctp_enable;
	int reconf_enable;
	int auth_enable;
	int intl_enable;
	int ecn_enable;
	int scope_policy;
	int rwnd_upd_shift;
	long unsigned int max_autoclose;
};

struct sk_buff_head___113 {
	struct sk_buff___114 *next;
	struct sk_buff___114 *prev;
	__u32 qlen;
	spinlock_t lock;
};

struct bpf_prog_array___104;

struct bpf_prog___104;

struct netns_bpf___104 {
	struct bpf_prog_array___104 *run_array[2];
	struct bpf_prog___104 *progs[2];
	struct list_head links[2];
};

struct netns_xfrm___118 {
	struct list_head state_all;
	struct hlist_head *state_bydst;
	struct hlist_head *state_bysrc;
	struct hlist_head *state_byspi;
	struct hlist_head *state_byseq;
	unsigned int state_hmask;
	unsigned int state_num;
	struct work_struct state_hash_work;
	struct list_head policy_all;
	struct hlist_head *policy_byidx;
	unsigned int policy_idx_hmask;
	struct hlist_head policy_inexact[3];
	struct xfrm_policy_hash policy_bydst[3];
	unsigned int policy_count[6];
	struct work_struct policy_hash_work;
	struct xfrm_policy_hthresh policy_hthresh;
	struct list_head inexact_bins;
	struct sock___97 *nlsk;
	struct sock___97 *nlsk_stash;
	u32 sysctl_aevent_etime;
	u32 sysctl_aevent_rseqth;
	int sysctl_larval_drop;
	u32 sysctl_acq_expires;
	u8 policy_default;
	struct ctl_table_header *sysctl_hdr;
	long: 64;
	long: 64;
	long: 64;
	struct dst_ops___118 xfrm4_dst_ops;
	struct dst_ops___118 xfrm6_dst_ops;
	spinlock_t xfrm_state_lock;
	seqcount_spinlock_t xfrm_state_hash_generation;
	seqcount_spinlock_t xfrm_policy_hash_generation;
	spinlock_t xfrm_policy_lock;
	struct mutex xfrm_cfg_mutex;
	long: 64;
	long: 64;
};

struct net___118 {
	refcount_t passive;
	spinlock_t rules_mod_lock;
	unsigned int dev_unreg_count;
	unsigned int dev_base_seq;
	int ifindex;
	spinlock_t nsid_lock;
	atomic_t fnhe_genid;
	struct list_head list;
	struct list_head exit_list;
	struct llist_node cleanup_list;
	struct key_tag *key_domain;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct idr netns_ids;
	struct ns_common___27 ns;
	struct list_head dev_base_head;
	struct proc_dir_entry *proc_net;
	struct proc_dir_entry *proc_net_stat;
	struct ctl_table_set sysctls;
	struct sock___97 *rtnl;
	struct sock___97 *genl_sock;
	struct uevent_sock *uevent_sock;
	struct hlist_head *dev_name_head;
	struct hlist_head *dev_index_head;
	struct raw_notifier_head netdev_chain;
	u32 hash_mix;
	struct net_device___113 *loopback_dev;
	struct list_head rules_ops;
	struct netns_core core;
	struct netns_mib mib;
	struct netns_packet packet;
	struct netns_unix unx;
	struct netns_nexthop nexthop;
	struct netns_ipv4___118 ipv4;
	struct netns_ipv6___118 ipv6;
	struct netns_ieee802154_lowpan___118 ieee802154_lowpan;
	struct netns_sctp___97 sctp;
	struct netns_nf___23 nf;
	struct netns_ct ct;
	struct netns_nftables nft;
	struct sk_buff_head___113 wext_nlevents;
	struct net_generic___2 *gen;
	struct netns_bpf___104 bpf;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netns_xfrm___118 xfrm;
	u64 net_cookie;
	struct netns_ipvs *ipvs;
	struct netns_mpls mpls;
	struct netns_can can;
	struct netns_xdp xdp;
	struct netns_mctp mctp;
	struct sock___97 *crypto_nlsk;
	struct sock___97 *diag_nlsk;
	struct netns_smc smc;
	long: 64;
};

struct inet_frag_queue___118 {
	struct rhash_head node;
	union {
		struct frag_v4_compare_key v4;
		struct frag_v6_compare_key v6;
	} key;
	struct timer_list timer;
	spinlock_t lock;
	refcount_t refcnt;
	struct rb_root rb_fragments;
	struct sk_buff___114 *fragments_tail;
	struct sk_buff___114 *last_run_head;
	ktime_t stamp;
	int len;
	int meat;
	__u8 flags;
	u16 max_size;
	struct fqdir___118 *fqdir;
	struct callback_head rcu;
};

struct ip_ra_chain___69 {
	struct ip_ra_chain___69 *next;
	struct sock___97 *sk;
	union {
		void (*destructor)(struct sock___97 *);
		struct sock___97 *saved_sk;
	};
	struct callback_head rcu;
};

struct fib_rule___97;

struct fib_lookup_arg___97;

struct fib_rules_ops___97 {
	int family;
	struct list_head list;
	int rule_size;
	int addr_size;
	int unresolved_rules;
	int nr_goto_rules;
	unsigned int fib_rules_seq;
	int (*action)(struct fib_rule___97 *, struct flowi *, int, struct fib_lookup_arg___97 *);
	bool (*suppress)(struct fib_rule___97 *, int, struct fib_lookup_arg___97 *);
	int (*match)(struct fib_rule___97 *, struct flowi *, int);
	int (*configure)(struct fib_rule___97 *, struct sk_buff___114 *, struct fib_rule_hdr *, struct nlattr **, struct netlink_ext_ack *);
	int (*delete)(struct fib_rule___97 *);
	int (*compare)(struct fib_rule___97 *, struct fib_rule_hdr *, struct nlattr **);
	int (*fill)(struct fib_rule___97 *, struct sk_buff___114 *, struct fib_rule_hdr *);
	size_t (*nlmsg_payload)(struct fib_rule___97 *);
	void (*flush_cache)(struct fib_rules_ops___97 *);
	int nlgroup;
	const struct nla_policy *policy;
	struct list_head rules_list;
	struct module___288 *owner;
	struct net___118 *fro_net;
	struct callback_head rcu;
};

typedef struct {
	struct net___118 *net;
} possible_net_t___113;

struct proto___97;

struct sock_common___97 {
	union {
		__addrpair skc_addrpair;
		struct {
			__be32 skc_daddr;
			__be32 skc_rcv_saddr;
		};
	};
	union {
		unsigned int skc_hash;
		__u16 skc_u16hashes[2];
	};
	union {
		__portpair skc_portpair;
		struct {
			__be16 skc_dport;
			__u16 skc_num;
		};
	};
	short unsigned int skc_family;
	volatile unsigned char skc_state;
	unsigned char skc_reuse: 4;
	unsigned char skc_reuseport: 1;
	unsigned char skc_ipv6only: 1;
	unsigned char skc_net_refcnt: 1;
	long: 31;
	long: 64;
	long: 64;
	int skc_bound_dev_if;
	union {
		struct hlist_node skc_bind_node;
		struct hlist_node skc_portaddr_node;
	};
	struct proto___97 *skc_prot;
	possible_net_t___113 skc_net;
	struct in6_addr skc_v6_daddr;
	struct in6_addr skc_v6_rcv_saddr;
	atomic64_t skc_cookie;
	union {
		long unsigned int skc_flags;
		struct sock___97 *skc_listener;
		struct inet_timewait_death_row *skc_tw_dr;
	};
	int skc_dontcopy_begin[0];
	union {
		struct hlist_node skc_node;
		struct hlist_nulls_node skc_nulls_node;
	};
	short unsigned int skc_tx_queue_mapping;
	short unsigned int skc_rx_queue_mapping;
	union {
		int skc_incoming_cpu;
		u32 skc_rcv_wnd;
		u32 skc_tw_rcv_nxt;
	};
	refcount_t skc_refcnt;
	int skc_dontcopy_end[0];
	union {
		u32 skc_rxhash;
		u32 skc_window_clamp;
		u32 skc_tw_snd_nxt;
	};
};

struct cgroup___231;

struct sock_cgroup_data___97 {
	struct cgroup___231 *cgroup;
	u32 classid;
	u16 prioidx;
};

struct sk_filter___97;

struct socket_wq___99;

struct socket___100;

struct sock_reuseport___42;

struct sock___97 {
	struct sock_common___97 __sk_common;
	socket_lock_t sk_lock;
	atomic_t sk_drops;
	int sk_rcvlowat;
	struct sk_buff_head___113 sk_error_queue;
	struct sk_buff___114 *sk_rx_skb_cache;
	struct sk_buff_head___113 sk_receive_queue;
	struct {
		atomic_t rmem_alloc;
		int len;
		struct sk_buff___114 *head;
		struct sk_buff___114 *tail;
	} sk_backlog;
	int sk_forward_alloc;
	unsigned int sk_ll_usec;
	unsigned int sk_napi_id;
	int sk_rcvbuf;
	struct sk_filter___97 *sk_filter;
	union {
		struct socket_wq___99 *sk_wq;
		struct socket_wq___99 *sk_wq_raw;
	};
	struct xfrm_policy *sk_policy[2];
	struct dst_entry___97 *sk_rx_dst;
	int sk_rx_dst_ifindex;
	u32 sk_rx_dst_cookie;
	struct dst_entry___97 *sk_dst_cache;
	atomic_t sk_omem_alloc;
	int sk_sndbuf;
	int sk_wmem_queued;
	refcount_t sk_wmem_alloc;
	long unsigned int sk_tsq_flags;
	union {
		struct sk_buff___114 *sk_send_head;
		struct rb_root tcp_rtx_queue;
	};
	struct sk_buff___114 *sk_tx_skb_cache;
	struct sk_buff_head___113 sk_write_queue;
	__s32 sk_peek_off;
	int sk_write_pending;
	__u32 sk_dst_pending_confirm;
	u32 sk_pacing_status;
	long int sk_sndtimeo;
	struct timer_list sk_timer;
	__u32 sk_priority;
	__u32 sk_mark;
	long unsigned int sk_pacing_rate;
	long unsigned int sk_max_pacing_rate;
	struct page_frag___309 sk_frag;
	netdev_features_t sk_route_caps;
	netdev_features_t sk_route_nocaps;
	netdev_features_t sk_route_forced_caps;
	int sk_gso_type;
	unsigned int sk_gso_max_size;
	gfp_t sk_allocation;
	__u32 sk_txhash;
	u8 sk_padding: 1;
	u8 sk_kern_sock: 1;
	u8 sk_no_check_tx: 1;
	u8 sk_no_check_rx: 1;
	u8 sk_userlocks: 4;
	long: 4;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 sk_pacing_shift;
	u16 sk_type;
	u16 sk_protocol;
	u16 sk_gso_max_segs;
	long unsigned int sk_lingertime;
	struct proto___97 *sk_prot_creator;
	rwlock_t sk_callback_lock;
	int sk_err;
	int sk_err_soft;
	u32 sk_ack_backlog;
	u32 sk_max_ack_backlog;
	kuid_t sk_uid;
	u8 sk_prefer_busy_poll;
	u16 sk_busy_poll_budget;
	spinlock_t sk_peer_lock;
	struct pid___281 *sk_peer_pid;
	const struct cred___31 *sk_peer_cred;
	long int sk_rcvtimeo;
	ktime_t sk_stamp;
	u16 sk_tsflags;
	int sk_bind_phc;
	u8 sk_shutdown;
	atomic_t sk_tskey;
	atomic_t sk_zckey;
	u8 sk_clockid;
	u8 sk_txtime_deadline_mode: 1;
	u8 sk_txtime_report_errors: 1;
	u8 sk_txtime_unused: 6;
	long: 58;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct socket___100 *sk_socket;
	void *sk_user_data;
	void *sk_security;
	struct sock_cgroup_data___97 sk_cgrp_data;
	struct mem_cgroup___166 *sk_memcg;
	void (*sk_state_change)(struct sock___97 *);
	void (*sk_data_ready)(struct sock___97 *);
	void (*sk_write_space)(struct sock___97 *);
	void (*sk_error_report)(struct sock___97 *);
	int (*sk_backlog_rcv)(struct sock___97 *, struct sk_buff___114 *);
	struct sk_buff___114 * (*sk_validate_xmit_skb)(struct sock___97 *, struct net_device___113 *, struct sk_buff___114 *);
	void (*sk_destruct)(struct sock___97 *);
	struct sock_reuseport___42 *sk_reuseport_cb;
	struct bpf_local_storage *sk_bpf_storage;
	struct callback_head sk_rcu;
};

struct tcp_congestion_ops___40 {
	u32 (*ssthresh)(struct sock___97 *);
	void (*cong_avoid)(struct sock___97 *, u32, u32);
	void (*set_state)(struct sock___97 *, u8);
	void (*cwnd_event)(struct sock___97 *, enum tcp_ca_event);
	void (*in_ack_event)(struct sock___97 *, u32);
	void (*pkts_acked)(struct sock___97 *, const struct ack_sample *);
	u32 (*min_tso_segs)(struct sock___97 *);
	void (*cong_control)(struct sock___97 *, const struct rate_sample *);
	u32 (*undo_cwnd)(struct sock___97 *);
	u32 (*sndbuf_expand)(struct sock___97 *);
	size_t (*get_info)(struct sock___97 *, u32, int *, union tcp_cc_info *);
	char name[16];
	struct module___288 *owner;
	struct list_head list;
	u32 key;
	u32 flags;
	void (*init)(struct sock___97 *);
	void (*release)(struct sock___97 *);
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct fib_notifier_ops___97 {
	int family;
	struct list_head list;
	unsigned int (*fib_seq_read)(struct net___118 *);
	int (*fib_dump)(struct net___118 *, struct notifier_block *, struct netlink_ext_ack *);
	struct module___288 *owner;
	struct callback_head rcu;
};

typedef struct page___309 *pgtable_t___309;

struct address_space___304;

struct page_pool___133;

struct dev_pagemap___299;

struct page___309 {
	long unsigned int flags;
	union {
		struct {
			struct list_head lru;
			struct address_space___304 *mapping;
			long unsigned int index;
			long unsigned int private;
		};
		struct {
			long unsigned int pp_magic;
			struct page_pool___133 *pp;
			long unsigned int _pp_mapping_pad;
			long unsigned int dma_addr;
			union {
				long unsigned int dma_addr_upper;
				atomic_long_t pp_frag_count;
			};
		};
		struct {
			union {
				struct list_head slab_list;
				struct {
					struct page___309 *next;
					int pages;
					int pobjects;
				};
			};
			struct kmem_cache *slab_cache;
			void *freelist;
			union {
				void *s_mem;
				long unsigned int counters;
				struct {
					unsigned int inuse: 16;
					unsigned int objects: 15;
					unsigned int frozen: 1;
				};
			};
		};
		struct {
			long unsigned int compound_head;
			unsigned char compound_dtor;
			unsigned char compound_order;
			atomic_t compound_mapcount;
			unsigned int compound_nr;
		};
		struct {
			long unsigned int _compound_pad_1;
			atomic_t hpage_pinned_refcount;
			struct list_head deferred_list;
		};
		struct {
			long unsigned int _pt_pad_1;
			pgtable_t___309 pmd_huge_pte;
			long unsigned int _pt_pad_2;
			union {
				struct mm_struct___310 *pt_mm;
				atomic_t pt_frag_refcount;
			};
			spinlock_t ptl;
		};
		struct {
			struct dev_pagemap___299 *pgmap;
			void *zone_device_data;
		};
		struct callback_head callback_head;
	};
	union {
		atomic_t _mapcount;
		unsigned int page_type;
		unsigned int active;
		int units;
	};
	atomic_t _refcount;
	long unsigned int memcg_data;
};

struct vm_operations_struct___299;

struct vm_area_struct___309 {
	long unsigned int vm_start;
	long unsigned int vm_end;
	struct vm_area_struct___309 *vm_next;
	struct vm_area_struct___309 *vm_prev;
	struct rb_node vm_rb;
	long unsigned int rb_subtree_gap;
	struct mm_struct___310 *vm_mm;
	pgprot_t vm_page_prot;
	long unsigned int vm_flags;
	struct {
		struct rb_node rb;
		long unsigned int rb_subtree_last;
	} shared;
	struct list_head anon_vma_chain;
	struct anon_vma *anon_vma;
	const struct vm_operations_struct___299 *vm_ops;
	long unsigned int vm_pgoff;
	struct file___304 *vm_file;
	struct file___304 *vm_prfile;
	void *vm_private_data;
	atomic_long_t swap_readahead_info;
	struct mempolicy *vm_policy;
	struct vm_userfaultfd_ctx vm_userfaultfd_ctx;
};

struct core_state___309;

struct mm_struct___310 {
	struct {
		struct vm_area_struct___309 *mmap;
		struct rb_root mm_rb;
		u64 vmacache_seqnum;
		long unsigned int (*get_unmapped_area)(struct file___304 *, long unsigned int, long unsigned int, long unsigned int, long unsigned int);
		long unsigned int mmap_base;
		long unsigned int mmap_legacy_base;
		long unsigned int task_size;
		long unsigned int highest_vm_end;
		pgd_t *pgd;
		atomic_t membarrier_state;
		atomic_t mm_users;
		atomic_t mm_count;
		atomic_long_t pgtables_bytes;
		int map_count;
		spinlock_t page_table_lock;
		struct rw_semaphore mmap_lock;
		struct list_head mmlist;
		long unsigned int hiwater_rss;
		long unsigned int hiwater_vm;
		long unsigned int total_vm;
		long unsigned int locked_vm;
		atomic64_t pinned_vm;
		long unsigned int data_vm;
		long unsigned int exec_vm;
		long unsigned int stack_vm;
		long unsigned int def_flags;
		seqcount_t write_protect_seq;
		spinlock_t arg_lock;
		long unsigned int start_code;
		long unsigned int end_code;
		long unsigned int start_data;
		long unsigned int end_data;
		long unsigned int start_brk;
		long unsigned int brk;
		long unsigned int start_stack;
		long unsigned int arg_start;
		long unsigned int arg_end;
		long unsigned int env_start;
		long unsigned int env_end;
		long unsigned int saved_auxv[46];
		struct mm_rss_stat rss_stat;
		struct linux_binfmt *binfmt;
		mm_context_t context;
		long unsigned int flags;
		struct core_state___309 *core_state;
		spinlock_t ioctx_lock;
		struct kioctx_table *ioctx_table;
		struct task_struct___311 *owner;
		struct user_namespace___26 *user_ns;
		struct file___304 *exe_file;
		struct mmu_notifier_subscriptions *notifier_subscriptions;
		long unsigned int numa_next_scan;
		long unsigned int numa_scan_offset;
		int numa_scan_seq;
		atomic_t tlb_flush_pending;
		struct uprobes_state uprobes_state;
		atomic_long_t hugetlb_usage;
		struct work_struct async_put_work;
		u32 pasid;
	};
	long unsigned int cpu_bitmap[0];
};

struct address_space_operations___304;

struct address_space___304 {
	struct inode___304 *host;
	struct xarray i_pages;
	struct rw_semaphore invalidate_lock;
	gfp_t gfp_mask;
	atomic_t i_mmap_writable;
	struct rb_root_cached i_mmap;
	struct rw_semaphore i_mmap_rwsem;
	long unsigned int nrpages;
	long unsigned int writeback_index;
	const struct address_space_operations___304 *a_ops;
	long unsigned int flags;
	errseq_t wb_err;
	spinlock_t private_lock;
	struct list_head private_list;
	void *private_data;
};

struct device___285;

struct page_pool_params___133 {
	unsigned int flags;
	unsigned int order;
	unsigned int pool_size;
	int nid;
	struct device___285 *dev;
	enum dma_data_direction dma_dir;
	unsigned int max_len;
	unsigned int offset;
};

struct pp_alloc_cache___133 {
	u32 count;
	struct page___309 *cache[128];
};

struct page_pool___133 {
	struct page_pool_params___133 p;
	struct delayed_work release_dw;
	void (*disconnect)(void *);
	long unsigned int defer_start;
	long unsigned int defer_warn;
	u32 pages_state_hold_cnt;
	unsigned int frag_offset;
	struct page___309 *frag_page;
	long int frag_users;
	long: 64;
	long: 64;
	struct pp_alloc_cache___133 alloc;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct ptr_ring ring;
	atomic_t pages_state_release_cnt;
	refcount_t user_cnt;
	u64 destroy_cnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pagemap_ops___299;

struct dev_pagemap___299 {
	struct vmem_altmap altmap;
	struct percpu_ref *ref;
	struct percpu_ref internal_ref;
	struct completion done;
	enum memory_type type;
	unsigned int flags;
	const struct dev_pagemap_ops___299 *ops;
	void *owner;
	int nr_range;
	union {
		struct range range;
		struct range ranges[0];
	};
};

struct vfsmount___304;

struct path___304 {
	struct vfsmount___304 *mnt;
	struct dentry___304 *dentry;
};

struct fown_struct___281 {
	rwlock_t lock;
	struct pid___281 *pid;
	enum pid_type pid_type;
	kuid_t uid;
	kuid_t euid;
	int signum;
};

struct file___304 {
	union {
		struct llist_node fu_llist;
		struct callback_head fu_rcuhead;
	} f_u;
	struct path___304 f_path;
	struct inode___304 *f_inode;
	const struct file_operations___305 *f_op;
	spinlock_t f_lock;
	enum rw_hint f_write_hint;
	atomic_long_t f_count;
	unsigned int f_flags;
	fmode_t f_mode;
	struct mutex f_pos_lock;
	loff_t f_pos;
	struct fown_struct___281 f_owner;
	const struct cred___31 *f_cred;
	struct file_ra_state f_ra;
	u64 f_version;
	void *f_security;
	void *private_data;
	struct hlist_head *f_ep;
	struct address_space___304 *f_mapping;
	errseq_t f_wb_err;
	errseq_t f_sb_err;
};

struct vm_fault___299;

struct vm_operations_struct___299 {
	void (*open)(struct vm_area_struct___309 *);
	void (*close)(struct vm_area_struct___309 *);
	int (*may_split)(struct vm_area_struct___309 *, long unsigned int);
	int (*mremap)(struct vm_area_struct___309 *);
	int (*mprotect)(struct vm_area_struct___309 *, long unsigned int, long unsigned int, long unsigned int);
	vm_fault_t (*fault)(struct vm_fault___299 *);
	vm_fault_t (*huge_fault)(struct vm_fault___299 *, enum page_entry_size);
	vm_fault_t (*map_pages)(struct vm_fault___299 *, long unsigned int, long unsigned int);
	long unsigned int (*pagesize)(struct vm_area_struct___309 *);
	vm_fault_t (*page_mkwrite)(struct vm_fault___299 *);
	vm_fault_t (*pfn_mkwrite)(struct vm_fault___299 *);
	int (*access)(struct vm_area_struct___309 *, long unsigned int, void *, int, int);
	const char * (*name)(struct vm_area_struct___309 *);
	int (*set_policy)(struct vm_area_struct___309 *, struct mempolicy *);
	struct mempolicy * (*get_policy)(struct vm_area_struct___309 *, long unsigned int);
	struct page___309 * (*find_special_page)(struct vm_area_struct___309 *, long unsigned int);
};

struct core_thread___309 {
	struct task_struct___311 *task;
	struct core_thread___309 *next;
};

struct core_state___309 {
	atomic_t nr_threads;
	struct core_thread___309 dumper;
	struct completion startup;
};

struct vm_fault___299 {
	const struct {
		struct vm_area_struct___309 *vma;
		gfp_t gfp_mask;
		long unsigned int pgoff;
		long unsigned int address;
	};
	enum fault_flag flags;
	pmd_t *pmd;
	pud_t *pud;
	union {
		pte_t orig_pte;
		pmd_t orig_pmd;
	};
	struct page___309 *cow_page;
	struct page___309 *page;
	pte_t *pte;
	spinlock_t *ptl;
	pgtable_t___309 prealloc_pte;
};

struct pglist_data___174;

struct lruvec___174 {
	struct list_head lists[5];
	spinlock_t lru_lock;
	long unsigned int anon_cost;
	long unsigned int file_cost;
	atomic_long_t nonresident_age;
	long unsigned int refaults[2];
	long unsigned int flags;
	struct pglist_data___174 *pgdat;
};

struct zone___174 {
	long unsigned int _watermark[3];
	long unsigned int watermark_boost;
	long unsigned int nr_reserved_highatomic;
	long int lowmem_reserve[5];
	int node;
	struct pglist_data___174 *zone_pgdat;
	struct per_cpu_pages *per_cpu_pageset;
	struct per_cpu_zonestat *per_cpu_zonestats;
	int pageset_high;
	int pageset_batch;
	long unsigned int zone_start_pfn;
	atomic_long_t managed_pages;
	long unsigned int spanned_pages;
	long unsigned int present_pages;
	long unsigned int present_early_pages;
	long unsigned int cma_pages;
	const char *name;
	long unsigned int nr_isolate_pageblock;
	seqlock_t span_seqlock;
	int initialized;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct free_area free_area[13];
	long unsigned int flags;
	spinlock_t lock;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad2_;
	long unsigned int percpu_drift_mark;
	long unsigned int compact_cached_free_pfn;
	long unsigned int compact_cached_migrate_pfn[2];
	long unsigned int compact_init_migrate_pfn;
	long unsigned int compact_init_free_pfn;
	unsigned int compact_considered;
	unsigned int compact_defer_shift;
	int compact_order_failed;
	bool compact_blockskip_flush;
	bool contiguous;
	short: 16;
	struct zone_padding _pad3_;
	atomic_long_t vm_stat[11];
	atomic_long_t vm_numa_event[6];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct zoneref___174 {
	struct zone___174 *zone;
	int zone_idx;
};

struct zonelist___174 {
	struct zoneref___174 _zonerefs[321];
};

struct pglist_data___174 {
	struct zone___174 node_zones[5];
	struct zonelist___174 node_zonelists[2];
	int nr_zones;
	spinlock_t node_size_lock;
	long unsigned int node_start_pfn;
	long unsigned int node_present_pages;
	long unsigned int node_spanned_pages;
	int node_id;
	wait_queue_head_t kswapd_wait;
	wait_queue_head_t pfmemalloc_wait;
	struct task_struct___311 *kswapd;
	int kswapd_order;
	enum zone_type kswapd_highest_zoneidx;
	int kswapd_failures;
	int kcompactd_max_order;
	enum zone_type kcompactd_highest_zoneidx;
	wait_queue_head_t kcompactd_wait;
	struct task_struct___311 *kcompactd;
	bool proactive_compact_trigger;
	long unsigned int totalreserve_pages;
	long unsigned int min_unmapped_pages;
	long unsigned int min_slab_pages;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct zone_padding _pad1_;
	struct deferred_split deferred_split_queue;
	struct lruvec___174 __lruvec;
	long unsigned int flags;
	long: 64;
	struct zone_padding _pad2_;
	struct per_cpu_nodestat *per_cpu_nodestats;
	atomic_long_t vm_stat[39];
};

struct lwtunnel_state___72;

struct dst_entry___97 {
	struct net_device___113 *dev;
	struct dst_ops___118 *ops;
	long unsigned int _metrics;
	long unsigned int expires;
	struct xfrm_state *xfrm;
	int (*input)(struct sk_buff___114 *);
	int (*output)(struct net___118 *, struct sock___97 *, struct sk_buff___114 *);
	short unsigned int flags;
	short int obsolete;
	short unsigned int header_len;
	short unsigned int trailer_len;
	atomic_t __refcnt;
	int __use;
	long unsigned int lastuse;
	struct lwtunnel_state___72 *lwtstate;
	struct callback_head callback_head;
	short int error;
	short int __pad;
	__u32 tclassid;
};

typedef rx_handler_result_t rx_handler_func_t___113(struct sk_buff___114 **);

struct wakeup_source___285;

struct dev_pm_info___285 {
	pm_message_t power_state;
	unsigned int can_wakeup: 1;
	unsigned int async_suspend: 1;
	bool in_dpm_list: 1;
	bool is_prepared: 1;
	bool is_suspended: 1;
	bool is_noirq_suspended: 1;
	bool is_late_suspended: 1;
	bool no_pm: 1;
	bool early_init: 1;
	bool direct_complete: 1;
	long: 63;
	u32 driver_flags;
	spinlock_t lock;
	struct list_head entry;
	struct completion completion;
	struct wakeup_source___285 *wakeup;
	bool wakeup_path: 1;
	bool syscore: 1;
	bool no_pm_callbacks: 1;
	unsigned int must_resume: 1;
	unsigned int may_skip_resume: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hrtimer suspend_timer;
	u64 timer_expires;
	struct work_struct work;
	wait_queue_head_t wait_queue;
	struct wake_irq *wakeirq;
	atomic_t usage_count;
	atomic_t child_count;
	unsigned int disable_depth: 3;
	unsigned int idle_notification: 1;
	unsigned int request_pending: 1;
	unsigned int deferred_resume: 1;
	unsigned int needs_force_resume: 1;
	unsigned int runtime_auto: 1;
	bool ignore_children: 1;
	unsigned int no_callbacks: 1;
	unsigned int irq_safe: 1;
	unsigned int use_autosuspend: 1;
	unsigned int timer_autosuspends: 1;
	unsigned int memalloc_noio: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	unsigned int links_count;
	enum rpm_request request;
	enum rpm_status runtime_status;
	int runtime_error;
	int autosuspend_delay;
	u64 last_busy;
	u64 active_time;
	u64 suspended_time;
	u64 accounting_timestamp;
	struct pm_subsys_data___13 *subsys_data;
	void (*set_latency_tolerance)(struct device___285 *, s32);
	struct dev_pm_qos *qos;
};

struct device_type___285;

struct bus_type___285;

struct device_driver___285;

struct dev_pm_domain___285;

struct fwnode_handle___281;

struct class___285;

struct attribute_group___292;

struct device___285 {
	struct kobject___292 kobj;
	struct device___285 *parent;
	struct device_private *p;
	const char *init_name;
	const struct device_type___285 *type;
	struct bus_type___285 *bus;
	struct device_driver___285 *driver;
	void *platform_data;
	void *driver_data;
	struct mutex mutex;
	struct dev_links_info links;
	struct dev_pm_info___285 power;
	struct dev_pm_domain___285 *pm_domain;
	struct em_perf_domain *em_pd;
	struct irq_domain___2 *msi_domain;
	struct dev_pin_info *pins;
	raw_spinlock_t msi_lock;
	struct list_head msi_list;
	const struct dma_map_ops *dma_ops;
	u64 *dma_mask;
	u64 coherent_dma_mask;
	u64 bus_dma_limit;
	const struct bus_dma_region *dma_range_map;
	struct device_dma_parameters *dma_parms;
	struct list_head dma_pools;
	struct dma_coherent_mem *dma_mem;
	struct cma *cma_area;
	struct io_tlb_mem *dma_io_tlb_mem;
	struct dev_archdata archdata;
	struct device_node___2 *of_node;
	struct fwnode_handle___281 *fwnode;
	int numa_node;
	dev_t devt;
	u32 id;
	spinlock_t devres_lock;
	struct list_head devres_head;
	struct class___285 *class;
	const struct attribute_group___292 **groups;
	void (*release)(struct device___285 *);
	struct iommu_group *iommu_group;
	struct dev_iommu *iommu;
	enum device_removable removable;
	bool offline_disabled: 1;
	bool offline: 1;
	bool of_node_reused: 1;
	bool state_synced: 1;
	bool can_match: 1;
	bool dma_coherent: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_xdp_entity___104 {
	struct bpf_prog___104 *prog;
	struct bpf_xdp_link *link;
};

struct netdev_name_node___113;

struct net_device_ops___113;

struct l3mdev_ops___97;

struct ndisc_ops___78;

struct xfrmdev_ops___113;

struct header_ops___113;

struct inet6_dev___78;

struct netdev_rx_queue___113;

struct mini_Qdisc___104;

struct netdev_queue___113;

struct Qdisc___104;

struct rtnl_link_ops___105;

struct dcbnl_rtnl_ops___113;

struct net_device___113 {
	char name[16];
	struct netdev_name_node___113 *name_node;
	struct dev_ifalias *ifalias;
	long unsigned int mem_end;
	long unsigned int mem_start;
	long unsigned int base_addr;
	long unsigned int state;
	struct list_head dev_list;
	struct list_head napi_list;
	struct list_head unreg_list;
	struct list_head close_list;
	struct list_head ptype_all;
	struct list_head ptype_specific;
	struct {
		struct list_head upper;
		struct list_head lower;
	} adj_list;
	unsigned int flags;
	unsigned int priv_flags;
	const struct net_device_ops___113 *netdev_ops;
	int ifindex;
	short unsigned int gflags;
	short unsigned int hard_header_len;
	unsigned int mtu;
	short unsigned int needed_headroom;
	short unsigned int needed_tailroom;
	netdev_features_t features;
	netdev_features_t hw_features;
	netdev_features_t wanted_features;
	netdev_features_t vlan_features;
	netdev_features_t hw_enc_features;
	netdev_features_t mpls_features;
	netdev_features_t gso_partial_features;
	unsigned int min_mtu;
	unsigned int max_mtu;
	short unsigned int type;
	unsigned char min_header_len;
	unsigned char name_assign_type;
	int group;
	struct net_device_stats stats;
	atomic_long_t rx_dropped;
	atomic_long_t tx_dropped;
	atomic_long_t rx_nohandler;
	atomic_t carrier_up_count;
	atomic_t carrier_down_count;
	const struct iw_handler_def *wireless_handlers;
	struct iw_public_data *wireless_data;
	const struct ethtool_ops *ethtool_ops;
	const struct l3mdev_ops___97 *l3mdev_ops;
	const struct ndisc_ops___78 *ndisc_ops;
	const struct xfrmdev_ops___113 *xfrmdev_ops;
	const struct tlsdev_ops *tlsdev_ops;
	const struct header_ops___113 *header_ops;
	unsigned char operstate;
	unsigned char link_mode;
	unsigned char if_port;
	unsigned char dma;
	unsigned char perm_addr[32];
	unsigned char addr_assign_type;
	unsigned char addr_len;
	unsigned char upper_level;
	unsigned char lower_level;
	short unsigned int neigh_priv_len;
	short unsigned int dev_id;
	short unsigned int dev_port;
	short unsigned int padded;
	spinlock_t addr_list_lock;
	int irq;
	struct netdev_hw_addr_list uc;
	struct netdev_hw_addr_list mc;
	struct netdev_hw_addr_list dev_addrs;
	struct kset___292 *queues_kset;
	unsigned int promiscuity;
	unsigned int allmulti;
	bool uc_promisc;
	struct vlan_info *vlan_info;
	struct dsa_port *dsa_ptr;
	struct tipc_bearer *tipc_ptr;
	void *atalk_ptr;
	struct in_device *ip_ptr;
	struct dn_dev *dn_ptr;
	struct inet6_dev___78 *ip6_ptr;
	void *ax25_ptr;
	struct wireless_dev *ieee80211_ptr;
	struct wpan_dev *ieee802154_ptr;
	struct mpls_dev *mpls_ptr;
	struct mctp_dev *mctp_ptr;
	unsigned char *dev_addr;
	struct netdev_rx_queue___113 *_rx;
	unsigned int num_rx_queues;
	unsigned int real_num_rx_queues;
	struct bpf_prog___104 *xdp_prog;
	long unsigned int gro_flush_timeout;
	int napi_defer_hard_irqs;
	rx_handler_func_t___113 *rx_handler;
	void *rx_handler_data;
	struct mini_Qdisc___104 *miniq_ingress;
	struct netdev_queue___113 *ingress_queue;
	struct nf_hook_entries *nf_hooks_ingress;
	unsigned char broadcast[32];
	struct cpu_rmap *rx_cpu_rmap;
	struct hlist_node index_hlist;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct netdev_queue___113 *_tx;
	unsigned int num_tx_queues;
	unsigned int real_num_tx_queues;
	struct Qdisc___104 *qdisc;
	unsigned int tx_queue_len;
	spinlock_t tx_global_lock;
	struct xdp_dev_bulk_queue *xdp_bulkq;
	struct xps_dev_maps *xps_maps[2];
	struct mini_Qdisc___104 *miniq_egress;
	struct hlist_head qdisc_hash[16];
	struct timer_list watchdog_timer;
	int watchdog_timeo;
	u32 proto_down_reason;
	struct list_head todo_list;
	int *pcpu_refcnt;
	struct list_head link_watch_list;
	enum {
		NETREG_UNINITIALIZED___113 = 0,
		NETREG_REGISTERED___113 = 1,
		NETREG_UNREGISTERING___113 = 2,
		NETREG_UNREGISTERED___113 = 3,
		NETREG_RELEASED___113 = 4,
		NETREG_DUMMY___113 = 5,
	} reg_state: 8;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool dismantle;
	enum {
		RTNL_LINK_INITIALIZED___113 = 0,
		RTNL_LINK_INITIALIZING___113 = 1,
	} rtnl_link_state: 16;
	long: 16;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	bool needs_free_netdev;
	void (*priv_destructor)(struct net_device___113 *);
	struct netpoll_info *npinfo;
	possible_net_t___113 nd_net;
	void *ml_priv;
	enum netdev_ml_priv_type ml_priv_type;
	union {
		struct pcpu_lstats *lstats;
		struct pcpu_sw_netstats *tstats;
		struct pcpu_dstats *dstats;
	};
	struct garp_port *garp_port;
	struct mrp_port *mrp_port;
	struct device___285 dev;
	const struct attribute_group___292 *sysfs_groups[4];
	const struct attribute_group___292 *sysfs_rx_queue_group;
	const struct rtnl_link_ops___105 *rtnl_link_ops;
	unsigned int gso_max_size;
	u16 gso_max_segs;
	const struct dcbnl_rtnl_ops___113 *dcbnl_ops;
	s16 num_tc;
	struct netdev_tc_txq tc_to_txq[16];
	u8 prio_tc_map[16];
	unsigned int fcoe_ddp_xid;
	struct netprio_map *priomap;
	struct phy_device *phydev;
	struct sfp_bus *sfp_bus;
	struct lock_class_key *qdisc_tx_busylock;
	struct lock_class_key *qdisc_running_key;
	bool proto_down;
	unsigned int wol_enabled: 1;
	unsigned int threaded: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct list_head net_notifier_list;
	const struct macsec_ops *macsec_ops;
	const struct udp_tunnel_nic_info *udp_tunnel_nic_info;
	struct udp_tunnel_nic *udp_tunnel_nic;
	struct bpf_xdp_entity___104 xdp_state[3];
	long: 64;
};

struct neigh_table___98;

struct neigh_parms___98;

struct neigh_ops___98;

struct neighbour___98 {
	struct neighbour___98 *next;
	struct neigh_table___98 *tbl;
	struct neigh_parms___98 *parms;
	long unsigned int confirmed;
	long unsigned int updated;
	rwlock_t lock;
	refcount_t refcnt;
	unsigned int arp_queue_len_bytes;
	struct sk_buff_head___113 arp_queue;
	struct timer_list timer;
	long unsigned int used;
	atomic_t probes;
	__u8 flags;
	__u8 nud_state;
	__u8 type;
	__u8 dead;
	u8 protocol;
	seqlock_t ha_lock;
	int: 32;
	unsigned char ha[32];
	struct hh_cache hh;
	int (*output)(struct neighbour___98 *, struct sk_buff___114 *);
	const struct neigh_ops___98 *ops;
	struct list_head gc_list;
	struct callback_head rcu;
	struct net_device___113 *dev;
	u8 primary_key[0];
};

struct bpf_prog_array_item___104 {
	struct bpf_prog___104 *prog;
	union {
		struct bpf_cgroup_storage *cgroup_storage[2];
		u64 bpf_cookie;
	};
};

struct bpf_prog_array___104 {
	struct callback_head rcu;
	struct bpf_prog_array_item___104 items[0];
};

struct bpf_prog_aux___116;

struct bpf_prog___104 {
	u16 pages;
	u16 jited: 1;
	u16 jit_requested: 1;
	u16 gpl_compatible: 1;
	u16 cb_access: 1;
	u16 dst_needed: 1;
	u16 blinded: 1;
	u16 is_func: 1;
	u16 kprobe_override: 1;
	u16 has_callchain_buf: 1;
	u16 enforce_expected_attach_type: 1;
	u16 call_get_stack: 1;
	u16 call_get_func_ip: 1;
	enum bpf_prog_type type;
	enum bpf_attach_type expected_attach_type;
	u32 len;
	u32 jited_len;
	u8 tag[8];
	struct bpf_prog_stats *stats;
	int *active;
	unsigned int (*bpf_func)(const void *, const struct bpf_insn *);
	struct bpf_prog_aux___116 *aux;
	struct sock_fprog_kern *orig_prog;
	struct sock_filter insns[0];
	struct bpf_insn insnsi[0];
};

struct dentry_operations___304;

struct dentry___304 {
	unsigned int d_flags;
	seqcount_spinlock_t d_seq;
	struct hlist_bl_node d_hash;
	struct dentry___304 *d_parent;
	struct qstr d_name;
	struct inode___304 *d_inode;
	unsigned char d_iname[32];
	struct lockref d_lockref;
	const struct dentry_operations___304 *d_op;
	struct super_block___304 *d_sb;
	long unsigned int d_time;
	void *d_fsdata;
	union {
		struct list_head d_lru;
		wait_queue_head_t *d_wait;
	};
	struct list_head d_child;
	struct list_head d_subdirs;
	union {
		struct hlist_node d_alias;
		struct hlist_bl_node d_in_lookup_hash;
		struct callback_head d_rcu;
	} d_u;
};

struct inode_operations___304;

struct bdi_writeback___178;

struct inode___304 {
	umode_t i_mode;
	short unsigned int i_opflags;
	kuid_t i_uid;
	kgid_t i_gid;
	unsigned int i_flags;
	struct posix_acl *i_acl;
	struct posix_acl *i_default_acl;
	const struct inode_operations___304 *i_op;
	struct super_block___304 *i_sb;
	struct address_space___304 *i_mapping;
	void *i_security;
	long unsigned int i_ino;
	union {
		const unsigned int i_nlink;
		unsigned int __i_nlink;
	};
	dev_t i_rdev;
	loff_t i_size;
	struct timespec64 i_atime;
	struct timespec64 i_mtime;
	struct timespec64 i_ctime;
	spinlock_t i_lock;
	short unsigned int i_bytes;
	u8 i_blkbits;
	u8 i_write_hint;
	blkcnt_t i_blocks;
	long unsigned int i_state;
	struct rw_semaphore i_rwsem;
	long unsigned int dirtied_when;
	long unsigned int dirtied_time_when;
	struct hlist_node i_hash;
	struct list_head i_io_list;
	struct bdi_writeback___178 *i_wb;
	int i_wb_frn_winner;
	u16 i_wb_frn_avg_time;
	u16 i_wb_frn_history;
	struct list_head i_lru;
	struct list_head i_sb_list;
	struct list_head i_wb_list;
	union {
		struct hlist_head i_dentry;
		struct callback_head i_rcu;
	};
	atomic64_t i_version;
	atomic64_t i_sequence;
	atomic_t i_count;
	atomic_t i_dio_count;
	atomic_t i_writecount;
	atomic_t i_readcount;
	union {
		const struct file_operations___305 *i_fop;
		void (*free_inode)(struct inode___304 *);
	};
	struct file_lock_context *i_flctx;
	struct address_space___304 i_data;
	struct list_head i_devices;
	union {
		struct pipe_inode_info___145 *i_pipe;
		struct cdev___2 *i_cdev;
		char *i_link;
		unsigned int i_dir_seq;
	};
	__u32 i_generation;
	__u32 i_fsnotify_mask;
	struct fsnotify_mark_connector *i_fsnotify_marks;
	struct fscrypt_info *i_crypt_info;
	struct fsverity_info *i_verity_info;
	void *i_private;
};

struct dentry_operations___304 {
	int (*d_revalidate)(struct dentry___304 *, unsigned int);
	int (*d_weak_revalidate)(struct dentry___304 *, unsigned int);
	int (*d_hash)(const struct dentry___304 *, struct qstr *);
	int (*d_compare)(const struct dentry___304 *, unsigned int, const char *, const struct qstr *);
	int (*d_delete)(const struct dentry___304 *);
	int (*d_init)(struct dentry___304 *);
	void (*d_release)(struct dentry___304 *);
	void (*d_prune)(struct dentry___304 *);
	void (*d_iput)(struct dentry___304 *, struct inode___304 *);
	char * (*d_dname)(struct dentry___304 *, char *, int);
	struct vfsmount___304 * (*d_automount)(struct path___304 *);
	int (*d_manage)(const struct path___304 *, bool);
	struct dentry___304 * (*d_real)(struct dentry___304 *, const struct inode___304 *);
	long: 64;
	long: 64;
	long: 64;
};

struct quota_format_type___304;

struct mem_dqinfo___304 {
	struct quota_format_type___304 *dqi_format;
	int dqi_fmt_id;
	struct list_head dqi_dirty_list;
	long unsigned int dqi_flags;
	unsigned int dqi_bgrace;
	unsigned int dqi_igrace;
	qsize_t dqi_max_spc_limit;
	qsize_t dqi_max_ino_limit;
	void *dqi_priv;
};

struct quota_format_ops___304;

struct quota_info___304 {
	unsigned int flags;
	struct rw_semaphore dqio_sem;
	struct inode___304 *files[3];
	struct mem_dqinfo___304 info[3];
	const struct quota_format_ops___304 *ops[3];
};

struct rcuwait___305 {
	struct task_struct___311 *task;
};

struct percpu_rw_semaphore___305 {
	struct rcu_sync rss;
	unsigned int *read_count;
	struct rcuwait___305 writer;
	wait_queue_head_t waiters;
	atomic_t block;
};

struct sb_writers___304 {
	int frozen;
	wait_queue_head_t wait_unfrozen;
	struct percpu_rw_semaphore___305 rw_sem[3];
};

struct shrink_control___166;

struct shrinker___166 {
	long unsigned int (*count_objects)(struct shrinker___166 *, struct shrink_control___166 *);
	long unsigned int (*scan_objects)(struct shrinker___166 *, struct shrink_control___166 *);
	long int batch;
	int seeks;
	unsigned int flags;
	struct list_head list;
	int id;
	atomic_long_t *nr_deferred;
};

struct super_operations___304;

struct dquot_operations___304;

struct quotactl_ops___304;

struct block_device___195;

struct super_block___304 {
	struct list_head s_list;
	dev_t s_dev;
	unsigned char s_blocksize_bits;
	long unsigned int s_blocksize;
	loff_t s_maxbytes;
	struct file_system_type___304 *s_type;
	const struct super_operations___304 *s_op;
	const struct dquot_operations___304 *dq_op;
	const struct quotactl_ops___304 *s_qcop;
	const struct export_operations *s_export_op;
	long unsigned int s_flags;
	long unsigned int s_iflags;
	long unsigned int s_magic;
	struct dentry___304 *s_root;
	struct rw_semaphore s_umount;
	int s_count;
	atomic_t s_active;
	void *s_security;
	const struct xattr_handler **s_xattr;
	const struct fscrypt_operations *s_cop;
	struct key___2 *s_master_keys;
	const struct fsverity_operations *s_vop;
	struct unicode_map *s_encoding;
	__u16 s_encoding_flags;
	struct hlist_bl_head s_roots;
	struct list_head s_mounts;
	struct block_device___195 *s_bdev;
	struct backing_dev_info___178 *s_bdi;
	struct mtd_info *s_mtd;
	struct hlist_node s_instances;
	unsigned int s_quota_types;
	struct quota_info___304 s_dquot;
	struct sb_writers___304 s_writers;
	void *s_fs_info;
	u32 s_time_gran;
	time64_t s_time_min;
	time64_t s_time_max;
	__u32 s_fsnotify_mask;
	struct fsnotify_mark_connector *s_fsnotify_marks;
	char s_id[32];
	uuid_t s_uuid;
	unsigned int s_max_links;
	fmode_t s_mode;
	struct mutex s_vfs_rename_mutex;
	const char *s_subtype;
	const struct dentry_operations___304 *s_d_op;
	int cleancache_poolid;
	struct shrinker___166 s_shrink;
	atomic_long_t s_remove_count;
	atomic_long_t s_fsnotify_connectors;
	int s_readonly_remount;
	errseq_t s_wb_err;
	struct workqueue_struct *s_dio_done_wq;
	struct hlist_head s_pins;
	struct user_namespace___26 *s_user_ns;
	struct list_lru s_dentry_lru;
	struct list_lru s_inode_lru;
	struct callback_head rcu;
	struct work_struct destroy_work;
	struct mutex s_sync_lock;
	int s_stack_depth;
	int: 32;
	spinlock_t s_inode_list_lock;
	struct list_head s_inodes;
	spinlock_t s_inode_wblist_lock;
	struct list_head s_inodes_wb;
	long: 64;
	long: 64;
};

struct vfsmount___304 {
	struct dentry___304 *mnt_root;
	struct super_block___304 *mnt_sb;
	int mnt_flags;
	struct user_namespace___26 *mnt_userns;
};

struct pid_namespace___281;

struct upid___281 {
	int nr;
	struct pid_namespace___281 *ns;
};

struct pid_namespace___281 {
	struct idr idr;
	struct callback_head rcu;
	unsigned int pid_allocated;
	struct task_struct___311 *child_reaper;
	struct kmem_cache *pid_cachep;
	unsigned int level;
	struct pid_namespace___281 *parent;
	struct fs_pin *bacct;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	int reboot;
	struct ns_common___27 ns;
};

struct pid___281 {
	refcount_t count;
	unsigned int level;
	spinlock_t lock;
	struct hlist_head tasks[4];
	struct hlist_head inodes;
	wait_queue_head_t wait_pidfd;
	struct callback_head rcu;
	struct upid___281 numbers[1];
};

struct signal_struct___305 {
	refcount_t sigcnt;
	atomic_t live;
	int nr_threads;
	struct list_head thread_head;
	wait_queue_head_t wait_chldexit;
	struct task_struct___311 *curr_target;
	struct sigpending shared_pending;
	struct hlist_head multiprocess;
	int group_exit_code;
	int notify_count;
	struct task_struct___311 *group_exit_task;
	int group_stop_count;
	unsigned int flags;
	unsigned int is_child_subreaper: 1;
	unsigned int has_child_subreaper: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int posix_timer_id;
	struct list_head posix_timers;
	struct hrtimer real_timer;
	ktime_t it_real_incr;
	struct cpu_itimer it[2];
	struct thread_group_cputimer cputimer;
	struct posix_cputimers posix_cputimers;
	struct pid___281 *pids[4];
	struct pid___281 *tty_old_pgrp;
	int leader;
	struct tty_struct *tty;
	struct autogroup *autogroup;
	seqlock_t stats_lock;
	u64 utime;
	u64 stime;
	u64 cutime;
	u64 cstime;
	u64 gtime;
	u64 cgtime;
	struct prev_cputime prev_cputime;
	long unsigned int nvcsw;
	long unsigned int nivcsw;
	long unsigned int cnvcsw;
	long unsigned int cnivcsw;
	long unsigned int min_flt;
	long unsigned int maj_flt;
	long unsigned int cmin_flt;
	long unsigned int cmaj_flt;
	long unsigned int inblock;
	long unsigned int oublock;
	long unsigned int cinblock;
	long unsigned int coublock;
	long unsigned int maxrss;
	long unsigned int cmaxrss;
	struct task_io_accounting ioac;
	long long unsigned int sum_sched_runtime;
	struct rlimit rlim[16];
	struct pacct_struct pacct;
	struct taskstats *stats;
	unsigned int audit_tty;
	struct tty_audit_buf *tty_audit_buf;
	bool oom_flag_origin;
	short int oom_score_adj;
	short int oom_score_adj_min;
	struct mm_struct___310 *oom_mm;
	struct mutex cred_guard_mutex;
	struct rw_semaphore exec_update_lock;
};

struct cgroup_namespace___231;

struct nsproxy___290 {
	atomic_t count;
	struct uts_namespace___2 *uts_ns;
	struct ipc_namespace *ipc_ns;
	struct mnt_namespace *mnt_ns;
	struct pid_namespace___281 *pid_ns_for_children;
	struct net___118 *net_ns;
	struct time_namespace *time_ns;
	struct time_namespace *time_ns_for_children;
	struct cgroup_namespace___231 *cgroup_ns;
};

struct bio___192;

struct bio_list___192 {
	struct bio___192 *head;
	struct bio___192 *tail;
};

struct cgroup_subsys_state___231;

struct bdi_writeback___178 {
	struct backing_dev_info___178 *bdi;
	long unsigned int state;
	long unsigned int last_old_flush;
	struct list_head b_dirty;
	struct list_head b_io;
	struct list_head b_more_io;
	struct list_head b_dirty_time;
	spinlock_t list_lock;
	atomic_t writeback_inodes;
	struct percpu_counter stat[4];
	long unsigned int congested;
	long unsigned int bw_time_stamp;
	long unsigned int dirtied_stamp;
	long unsigned int written_stamp;
	long unsigned int write_bandwidth;
	long unsigned int avg_write_bandwidth;
	long unsigned int dirty_ratelimit;
	long unsigned int balanced_dirty_ratelimit;
	struct fprop_local_percpu completions;
	int dirty_exceeded;
	enum wb_reason start_all_reason;
	spinlock_t work_lock;
	struct list_head work_list;
	struct delayed_work dwork;
	struct delayed_work bw_dwork;
	long unsigned int dirty_sleep;
	struct list_head bdi_node;
	struct percpu_ref refcnt;
	struct fprop_local_percpu memcg_completions;
	struct cgroup_subsys_state___231 *memcg_css;
	struct cgroup_subsys_state___231 *blkcg_css;
	struct list_head memcg_node;
	struct list_head blkcg_node;
	struct list_head b_attached;
	struct list_head offline_node;
	union {
		struct work_struct release_work;
		struct callback_head rcu;
	};
};

struct backing_dev_info___178 {
	u64 id;
	struct rb_node rb_node;
	struct list_head bdi_list;
	long unsigned int ra_pages;
	long unsigned int io_pages;
	struct kref refcnt;
	unsigned int capabilities;
	unsigned int min_ratio;
	unsigned int max_ratio;
	unsigned int max_prop_frac;
	atomic_long_t tot_write_bandwidth;
	struct bdi_writeback___178 wb;
	struct list_head wb_list;
	struct xarray cgwb_tree;
	struct mutex cgwb_release_mutex;
	struct rw_semaphore wb_switch_rwsem;
	wait_queue_head_t wb_waitq;
	struct device___285 *dev;
	char dev_name[64];
	struct device___285 *owner;
	struct timer_list laptop_mode_wb_timer;
	struct dentry___304 *debug_dir;
};

struct io_cq___192;

struct io_context___192 {
	atomic_long_t refcount;
	atomic_t active_ref;
	atomic_t nr_tasks;
	spinlock_t lock;
	short unsigned int ioprio;
	struct xarray icq_tree;
	struct io_cq___192 *icq_hint;
	struct hlist_head icq_list;
	struct work_struct release_work;
};

struct css_set___231 {
	struct cgroup_subsys_state___231 *subsys[14];
	refcount_t refcount;
	struct css_set___231 *dom_cset;
	struct cgroup___231 *dfl_cgrp;
	int nr_tasks;
	struct list_head tasks;
	struct list_head mg_tasks;
	struct list_head dying_tasks;
	struct list_head task_iters;
	struct list_head e_cset_node[14];
	struct list_head threaded_csets;
	struct list_head threaded_csets_node;
	struct hlist_node hlist;
	struct list_head cgrp_links;
	struct list_head mg_preload_node;
	struct list_head mg_node;
	struct cgroup___231 *mg_src_cgrp;
	struct cgroup___231 *mg_dst_cgrp;
	struct css_set___231 *mg_dst_cset;
	bool dead;
	struct callback_head callback_head;
};

struct cgroup_subsys___231;

struct cgroup_subsys_state___231 {
	struct cgroup___231 *cgroup;
	struct cgroup_subsys___231 *ss;
	struct percpu_ref refcnt;
	struct list_head sibling;
	struct list_head children;
	struct list_head rstat_css_node;
	int id;
	unsigned int flags;
	u64 serial_nr;
	atomic_t online_cnt;
	struct work_struct destroy_work;
	struct rcu_work destroy_rwork;
	struct cgroup_subsys_state___231 *parent;
};

struct cgroup_file___231 {
	struct kernfs_node___292 *kn;
	long unsigned int notified_at;
	struct timer_list notify_timer;
};

struct obj_cgroup___166;

struct mem_cgroup_per_node___166;

struct mem_cgroup___166 {
	struct cgroup_subsys_state___231 css;
	struct mem_cgroup_id id;
	struct page_counter memory;
	union {
		struct page_counter swap;
		struct page_counter memsw;
	};
	struct page_counter kmem;
	struct page_counter tcpmem;
	struct work_struct high_work;
	long unsigned int soft_limit;
	struct vmpressure vmpressure;
	bool oom_group;
	bool oom_lock;
	int under_oom;
	int swappiness;
	int oom_kill_disable;
	struct cgroup_file___231 events_file;
	struct cgroup_file___231 events_local_file;
	struct cgroup_file___231 swap_events_file;
	struct mutex thresholds_lock;
	struct mem_cgroup_thresholds thresholds;
	struct mem_cgroup_thresholds memsw_thresholds;
	struct list_head oom_notify;
	long unsigned int move_charge_at_immigrate;
	spinlock_t move_lock;
	long unsigned int move_lock_flags;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct memcg_padding _pad1_;
	struct memcg_vmstats vmstats;
	atomic_long_t memory_events[8];
	atomic_long_t memory_events_local[8];
	long unsigned int socket_pressure;
	bool tcpmem_active;
	int tcpmem_pressure;
	int kmemcg_id;
	enum memcg_kmem_state kmem_state;
	struct obj_cgroup___166 *objcg;
	struct list_head objcg_list;
	struct memcg_padding _pad2_;
	atomic_t moving_account;
	struct task_struct___311 *move_lock_task;
	struct memcg_vmstats_percpu *vmstats_percpu;
	struct list_head cgwb_list;
	struct wb_domain cgwb_domain;
	struct memcg_cgwb_frn cgwb_frn[4];
	struct list_head event_list;
	spinlock_t event_list_lock;
	struct deferred_split deferred_split_queue;
	struct mem_cgroup_per_node___166 *nodeinfo[0];
	long: 64;
};

struct blk_integrity_profile___192;

struct blk_integrity___192 {
	const struct blk_integrity_profile___192 *profile;
	unsigned char flags;
	unsigned char tuple_size;
	unsigned char interval_exp;
	unsigned char tag_size;
};

struct bio_set___192 {
	struct kmem_cache *bio_slab;
	unsigned int front_pad;
	struct bio_alloc_cache *cache;
	mempool_t bio_pool;
	mempool_t bvec_pool;
	mempool_t bio_integrity_pool;
	mempool_t bvec_integrity_pool;
	unsigned int back_pad;
	spinlock_t rescue_lock;
	struct bio_list___192 rescue_list;
	struct work_struct rescue_work;
	struct workqueue_struct *rescue_workqueue;
	struct hlist_node cpuhp_dead;
};

struct request___192;

struct elevator_queue___192;

struct blk_mq_ops___187;

struct blk_mq_hw_ctx___187;

struct gendisk___195;

struct blkcg_gq___180;

struct blk_mq_tag_set___187;

struct request_queue___192 {
	struct request___192 *last_merge;
	struct elevator_queue___192 *elevator;
	struct percpu_ref q_usage_counter;
	struct blk_queue_stats *stats;
	struct rq_qos *rq_qos;
	const struct blk_mq_ops___187 *mq_ops;
	struct blk_mq_ctx *queue_ctx;
	unsigned int queue_depth;
	struct blk_mq_hw_ctx___187 **queue_hw_ctx;
	unsigned int nr_hw_queues;
	void *queuedata;
	long unsigned int queue_flags;
	atomic_t pm_only;
	int id;
	spinlock_t queue_lock;
	struct gendisk___195 *disk;
	struct kobject___292 kobj;
	struct kobject___292 *mq_kobj;
	struct blk_integrity___192 integrity;
	struct device___285 *dev;
	enum rpm_status rpm_status;
	long unsigned int nr_requests;
	unsigned int dma_pad_mask;
	unsigned int dma_alignment;
	struct blk_keyslot_manager *ksm;
	unsigned int rq_timeout;
	int poll_nsec;
	struct blk_stat_callback *poll_cb;
	struct blk_rq_stat poll_stat[16];
	struct timer_list timeout;
	struct work_struct timeout_work;
	atomic_t nr_active_requests_shared_sbitmap;
	struct sbitmap_queue sched_bitmap_tags;
	struct sbitmap_queue sched_breserved_tags;
	struct list_head icq_list;
	long unsigned int blkcg_pols[1];
	struct blkcg_gq___180 *root_blkg;
	struct list_head blkg_list;
	struct queue_limits limits;
	unsigned int required_elevator_features;
	unsigned int nr_zones;
	long unsigned int *conv_zones_bitmap;
	long unsigned int *seq_zones_wlock;
	unsigned int max_open_zones;
	unsigned int max_active_zones;
	int node;
	struct mutex debugfs_mutex;
	struct blk_trace *blk_trace;
	struct blk_flush_queue *fq;
	struct list_head requeue_list;
	spinlock_t requeue_lock;
	struct delayed_work requeue_work;
	struct mutex sysfs_lock;
	struct mutex sysfs_dir_lock;
	struct list_head unused_hctx_list;
	spinlock_t unused_hctx_lock;
	int mq_freeze_depth;
	struct throtl_data *td;
	struct callback_head callback_head;
	wait_queue_head_t mq_freeze_wq;
	struct mutex mq_freeze_lock;
	struct blk_mq_tag_set___187 *tag_set;
	struct list_head tag_set_list;
	struct bio_set___192 bio_split;
	struct dentry___304 *debugfs_dir;
	struct dentry___304 *sched_debugfs_dir;
	struct dentry___304 *rqos_debugfs_dir;
	bool mq_sysfs_init_done;
	size_t cmd_size;
	u64 write_hints[5];
};

struct vm_struct___287 {
	struct vm_struct___287 *next;
	void *addr;
	long unsigned int size;
	long unsigned int flags;
	struct page___309 **pages;
	unsigned int nr_pages;
	phys_addr_t phys_addr;
	const void *caller;
};

struct shrink_control___166 {
	gfp_t gfp_mask;
	int nid;
	long unsigned int nr_to_scan;
	long unsigned int nr_scanned;
	struct mem_cgroup___166 *memcg;
};

struct psi_group___231 {
	struct mutex avgs_lock;
	struct psi_group_cpu *pcpu;
	u64 avg_total[6];
	u64 avg_last_update;
	u64 avg_next_update;
	struct delayed_work avgs_work;
	u64 total[12];
	long unsigned int avg[18];
	struct task_struct___311 *poll_task;
	struct timer_list poll_timer;
	wait_queue_head_t poll_wait;
	atomic_t poll_wakeup;
	struct mutex trigger_lock;
	struct list_head triggers;
	u32 nr_triggers[6];
	u32 poll_states;
	u64 poll_min_period;
	u64 polling_total[6];
	u64 polling_next_update;
	u64 polling_until;
};

struct cgroup_bpf___104 {
	struct bpf_prog_array___104 *effective[23];
	struct list_head progs[23];
	u32 flags[23];
	struct list_head storages;
	struct bpf_prog_array___104 *inactive;
	struct percpu_ref refcnt;
	struct work_struct release_work;
};

struct cgroup_root___231;

struct cgroup_rstat_cpu___231;

struct cgroup___231 {
	struct cgroup_subsys_state___231 self;
	long unsigned int flags;
	int level;
	int max_depth;
	int nr_descendants;
	int nr_dying_descendants;
	int max_descendants;
	int nr_populated_csets;
	int nr_populated_domain_children;
	int nr_populated_threaded_children;
	int nr_threaded_children;
	struct kernfs_node___292 *kn;
	struct cgroup_file___231 procs_file;
	struct cgroup_file___231 events_file;
	u16 subtree_control;
	u16 subtree_ss_mask;
	u16 old_subtree_control;
	u16 old_subtree_ss_mask;
	struct cgroup_subsys_state___231 *subsys[14];
	struct cgroup_root___231 *root;
	struct list_head cset_links;
	struct list_head e_csets[14];
	struct cgroup___231 *dom_cgrp;
	struct cgroup___231 *old_dom_cgrp;
	struct cgroup_rstat_cpu___231 *rstat_cpu;
	struct list_head rstat_css_list;
	struct cgroup_base_stat last_bstat;
	struct cgroup_base_stat bstat;
	struct prev_cputime prev_cputime;
	struct list_head pidlists;
	struct mutex pidlist_mutex;
	wait_queue_head_t offline_waitq;
	struct work_struct release_agent_work;
	struct psi_group___231 psi;
	struct cgroup_bpf___104 bpf;
	atomic_t congestion_count;
	struct cgroup_freezer_state freezer;
	u64 ancestor_ids[0];
};

struct io_cq___192 {
	struct request_queue___192 *q;
	struct io_context___192 *ioc;
	union {
		struct list_head q_node;
		struct kmem_cache___4 *__rcu_icq_cache;
	};
	union {
		struct hlist_node ioc_node;
		struct callback_head __rcu_head;
	};
	unsigned int flags;
};

struct iattr___304 {
	unsigned int ia_valid;
	umode_t ia_mode;
	kuid_t ia_uid;
	kgid_t ia_gid;
	loff_t ia_size;
	struct timespec64 ia_atime;
	struct timespec64 ia_mtime;
	struct timespec64 ia_ctime;
	struct file___304 *ia_file;
};

struct dquot___304 {
	struct hlist_node dq_hash;
	struct list_head dq_inuse;
	struct list_head dq_free;
	struct list_head dq_dirty;
	struct mutex dq_lock;
	spinlock_t dq_dqb_lock;
	atomic_t dq_count;
	struct super_block___304 *dq_sb;
	struct kqid dq_id;
	loff_t dq_off;
	long unsigned int dq_flags;
	struct mem_dqblk dq_dqb;
};

struct quota_format_type___304 {
	int qf_fmt_id;
	const struct quota_format_ops___304 *qf_ops;
	struct module___288 *qf_owner;
	struct quota_format_type___304 *qf_next;
};

struct quota_format_ops___304 {
	int (*check_quota_file)(struct super_block___304 *, int);
	int (*read_file_info)(struct super_block___304 *, int);
	int (*write_file_info)(struct super_block___304 *, int);
	int (*free_file_info)(struct super_block___304 *, int);
	int (*read_dqblk)(struct dquot___304 *);
	int (*commit_dqblk)(struct dquot___304 *);
	int (*release_dqblk)(struct dquot___304 *);
	int (*get_next_id)(struct super_block___304 *, struct kqid *);
};

struct dquot_operations___304 {
	int (*write_dquot)(struct dquot___304 *);
	struct dquot___304 * (*alloc_dquot)(struct super_block___304 *, int);
	void (*destroy_dquot)(struct dquot___304 *);
	int (*acquire_dquot)(struct dquot___304 *);
	int (*release_dquot)(struct dquot___304 *);
	int (*mark_dirty)(struct dquot___304 *);
	int (*write_info)(struct super_block___304 *, int);
	qsize_t * (*get_reserved_space)(struct inode___304 *);
	int (*get_projid)(struct inode___304 *, kprojid_t *);
	int (*get_inode_usage)(struct inode___304 *, qsize_t *);
	int (*get_next_id)(struct super_block___304 *, struct kqid *);
};

struct quotactl_ops___304 {
	int (*quota_on)(struct super_block___304 *, int, int, const struct path___304 *);
	int (*quota_off)(struct super_block___304 *, int);
	int (*quota_enable)(struct super_block___304 *, unsigned int);
	int (*quota_disable)(struct super_block___304 *, unsigned int);
	int (*quota_sync)(struct super_block___304 *, int);
	int (*set_info)(struct super_block___304 *, int, struct qc_info *);
	int (*get_dqblk)(struct super_block___304 *, struct kqid, struct qc_dqblk *);
	int (*get_nextdqblk)(struct super_block___304 *, struct kqid *, struct qc_dqblk *);
	int (*set_dqblk)(struct super_block___304 *, struct kqid, struct qc_dqblk *);
	int (*get_state)(struct super_block___304 *, struct qc_state *);
	int (*rm_xquota)(struct super_block___304 *, unsigned int);
};

struct writeback_control___178;

struct address_space_operations___304 {
	int (*writepage)(struct page___309 *, struct writeback_control___178 *);
	int (*readpage)(struct file___304 *, struct page___309 *);
	int (*writepages)(struct address_space___304 *, struct writeback_control___178 *);
	int (*set_page_dirty)(struct page___309 *);
	int (*readpages)(struct file___304 *, struct address_space___304 *, struct list_head *, unsigned int);
	void (*readahead)(struct readahead_control___3 *);
	int (*write_begin)(struct file___304 *, struct address_space___304 *, loff_t, unsigned int, unsigned int, struct page___309 **, void **);
	int (*write_end)(struct file___304 *, struct address_space___304 *, loff_t, unsigned int, unsigned int, struct page___309 *, void *);
	sector_t (*bmap)(struct address_space___304 *, sector_t);
	void (*invalidatepage)(struct page___309 *, unsigned int, unsigned int);
	int (*releasepage)(struct page___309 *, gfp_t);
	void (*freepage)(struct page___309 *);
	ssize_t (*direct_IO)(struct kiocb___304 *, struct iov_iter___224 *);
	int (*migratepage)(struct address_space___304 *, struct page___309 *, struct page___309 *, enum migrate_mode);
	bool (*isolate_page)(struct page___309 *, isolate_mode_t);
	void (*putback_page)(struct page___309 *);
	int (*launder_page)(struct page___309 *);
	int (*is_partially_uptodate)(struct page___309 *, long unsigned int, long unsigned int);
	void (*is_dirty_writeback)(struct page___309 *, bool *, bool *);
	int (*error_remove_page)(struct address_space___304 *, struct page___309 *);
	int (*swap_activate)(struct swap_info_struct___3 *, struct file___304 *, sector_t *);
	void (*swap_deactivate)(struct file___304 *);
};

struct writeback_control___178 {
	long int nr_to_write;
	long int pages_skipped;
	loff_t range_start;
	loff_t range_end;
	enum writeback_sync_modes sync_mode;
	unsigned int for_kupdate: 1;
	unsigned int for_background: 1;
	unsigned int tagged_writepages: 1;
	unsigned int for_reclaim: 1;
	unsigned int range_cyclic: 1;
	unsigned int for_sync: 1;
	unsigned int no_cgroup_owner: 1;
	unsigned int punt_to_cgroup: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bdi_writeback___178 *wb;
	struct inode___304 *inode;
	int wb_id;
	int wb_lcand_id;
	int wb_tcand_id;
	size_t wb_bytes;
	size_t wb_lcand_bytes;
	size_t wb_tcand_bytes;
};

struct inode_operations___304 {
	struct dentry___304 * (*lookup)(struct inode___304 *, struct dentry___304 *, unsigned int);
	const char * (*get_link)(struct dentry___304 *, struct inode___304 *, struct delayed_call *);
	int (*permission)(struct user_namespace___26 *, struct inode___304 *, int);
	struct posix_acl * (*get_acl)(struct inode___304 *, int, bool);
	int (*readlink)(struct dentry___304 *, char *, int);
	int (*create)(struct user_namespace___26 *, struct inode___304 *, struct dentry___304 *, umode_t, bool);
	int (*link)(struct dentry___304 *, struct inode___304 *, struct dentry___304 *);
	int (*unlink)(struct inode___304 *, struct dentry___304 *);
	int (*symlink)(struct user_namespace___26 *, struct inode___304 *, struct dentry___304 *, const char *);
	int (*mkdir)(struct user_namespace___26 *, struct inode___304 *, struct dentry___304 *, umode_t);
	int (*rmdir)(struct inode___304 *, struct dentry___304 *);
	int (*mknod)(struct user_namespace___26 *, struct inode___304 *, struct dentry___304 *, umode_t, dev_t);
	int (*rename)(struct user_namespace___26 *, struct inode___304 *, struct dentry___304 *, struct inode___304 *, struct dentry___304 *, unsigned int);
	int (*setattr)(struct user_namespace___26 *, struct dentry___304 *, struct iattr___304 *);
	int (*getattr)(struct user_namespace___26 *, const struct path___304 *, struct kstat *, u32, unsigned int);
	ssize_t (*listxattr)(struct dentry___304 *, char *, size_t);
	int (*fiemap)(struct inode___304 *, struct fiemap_extent_info *, u64, u64);
	int (*update_time)(struct inode___304 *, struct timespec64 *, int);
	int (*atomic_open)(struct inode___304 *, struct dentry___304 *, struct file___304 *, unsigned int, umode_t);
	int (*tmpfile)(struct user_namespace___26 *, struct inode___304 *, struct dentry___304 *, umode_t);
	int (*set_acl)(struct user_namespace___26 *, struct inode___304 *, struct posix_acl *, int);
	int (*fileattr_set)(struct user_namespace___26 *, struct dentry___304 *, struct fileattr *);
	int (*fileattr_get)(struct dentry___304 *, struct fileattr *);
	long: 64;
};

struct file_lock_operations___304 {
	void (*fl_copy_lock)(struct file_lock___304 *, struct file_lock___304 *);
	void (*fl_release_private)(struct file_lock___304 *);
};

struct lock_manager_operations___304;

struct file_lock___304 {
	struct file_lock___304 *fl_blocker;
	struct list_head fl_list;
	struct hlist_node fl_link;
	struct list_head fl_blocked_requests;
	struct list_head fl_blocked_member;
	fl_owner_t fl_owner;
	unsigned int fl_flags;
	unsigned char fl_type;
	unsigned int fl_pid;
	int fl_link_cpu;
	wait_queue_head_t fl_wait;
	struct file___304 *fl_file;
	loff_t fl_start;
	loff_t fl_end;
	struct fasync_struct___304 *fl_fasync;
	long unsigned int fl_break_time;
	long unsigned int fl_downgrade_time;
	const struct file_lock_operations___304 *fl_ops;
	const struct lock_manager_operations___304 *fl_lmops;
	union {
		struct nfs_lock_info nfs_fl;
		struct nfs4_lock_info nfs4_fl;
		struct {
			struct list_head link;
			int state;
			unsigned int debug_id;
		} afs;
	} fl_u;
};

struct lock_manager_operations___304 {
	fl_owner_t (*lm_get_owner)(fl_owner_t);
	void (*lm_put_owner)(fl_owner_t);
	void (*lm_notify)(struct file_lock___304 *);
	int (*lm_grant)(struct file_lock___304 *, int);
	bool (*lm_break)(struct file_lock___304 *);
	int (*lm_change)(struct file_lock___304 *, int, struct list_head *);
	void (*lm_setup)(struct file_lock___304 *, void **);
	bool (*lm_breaker_owns_lease)(struct file_lock___304 *);
};

struct fasync_struct___304 {
	rwlock_t fa_lock;
	int magic;
	int fa_fd;
	struct fasync_struct___304 *fa_next;
	struct file___304 *fa_file;
	struct callback_head fa_rcu;
};

struct super_operations___304 {
	struct inode___304 * (*alloc_inode)(struct super_block___304 *);
	void (*destroy_inode)(struct inode___304 *);
	void (*free_inode)(struct inode___304 *);
	void (*dirty_inode)(struct inode___304 *, int);
	int (*write_inode)(struct inode___304 *, struct writeback_control___178 *);
	int (*drop_inode)(struct inode___304 *);
	void (*evict_inode)(struct inode___304 *);
	void (*put_super)(struct super_block___304 *);
	int (*sync_fs)(struct super_block___304 *, int);
	int (*freeze_super)(struct super_block___304 *);
	int (*freeze_fs)(struct super_block___304 *);
	int (*thaw_super)(struct super_block___304 *);
	int (*unfreeze_fs)(struct super_block___304 *);
	int (*statfs)(struct dentry___304 *, struct kstatfs *);
	int (*remount_fs)(struct super_block___304 *, int *, char *);
	void (*umount_begin)(struct super_block___304 *);
	int (*show_options)(struct seq_file___279 *, struct dentry___304 *);
	int (*show_devname)(struct seq_file___279 *, struct dentry___304 *);
	int (*show_path)(struct seq_file___279 *, struct dentry___304 *);
	int (*show_stats)(struct seq_file___279 *, struct dentry___304 *);
	ssize_t (*quota_read)(struct super_block___304 *, int, char *, size_t, loff_t);
	ssize_t (*quota_write)(struct super_block___304 *, int, const char *, size_t, loff_t);
	struct dquot___304 ** (*get_dquots)(struct inode___304 *);
	long int (*nr_cached_objects)(struct super_block___304 *, struct shrink_control___166 *);
	long int (*free_cached_objects)(struct super_block___304 *, struct shrink_control___166 *);
	struct file___304 * (*real_loop)(struct file___304 *);
};

struct block_device___195 {
	sector_t bd_start_sect;
	struct disk_stats *bd_stats;
	long unsigned int bd_stamp;
	bool bd_read_only;
	dev_t bd_dev;
	int bd_openers;
	struct inode___304 *bd_inode;
	struct super_block___304 *bd_super;
	void *bd_claiming;
	struct device___285 bd_device;
	void *bd_holder;
	int bd_holders;
	bool bd_write_holder;
	struct kobject___292 *bd_holder_dir;
	u8 bd_partno;
	spinlock_t bd_size_lock;
	struct gendisk___195 *bd_disk;
	int bd_fsfreeze_count;
	struct mutex bd_fsfreeze_mutex;
	struct super_block___304 *bd_fsfreeze_sb;
	struct partition_meta_info *bd_meta_info;
};

typedef void (*poll_queue_proc___230)(struct file___304 *, wait_queue_head_t *, struct poll_table_struct___222 *);

struct poll_table_struct___222 {
	poll_queue_proc___230 _qproc;
	__poll_t _key;
};

struct seq_operations___279;

struct seq_file___279 {
	char *buf;
	size_t size;
	size_t from;
	size_t count;
	size_t pad_until;
	loff_t index;
	loff_t read_pos;
	struct mutex lock;
	const struct seq_operations___279 *op;
	int poll_event;
	const struct file___304 *file;
	void *private;
};

typedef void bio_end_io_t___192(struct bio___192 *);

struct bio_integrity_payload___192;

struct bio___192 {
	struct bio___192 *bi_next;
	struct block_device___195 *bi_bdev;
	unsigned int bi_opf;
	short unsigned int bi_flags;
	short unsigned int bi_ioprio;
	short unsigned int bi_write_hint;
	blk_status_t bi_status;
	atomic_t __bi_remaining;
	struct bvec_iter bi_iter;
	bio_end_io_t___192 *bi_end_io;
	void *bi_private;
	struct blkcg_gq___180 *bi_blkg;
	struct bio_issue bi_issue;
	u64 bi_iocost_cost;
	struct bio_crypt_ctx *bi_crypt_context;
	union {
		struct bio_integrity_payload___192 *bi_integrity;
	};
	short unsigned int bi_vcnt;
	short unsigned int bi_max_vecs;
	atomic_t __bi_cnt;
	struct bio_vec___221 *bi_io_vec;
	struct bio_set___192 *bi_pool;
	struct bio_vec___221 bi_inline_vecs[0];
};

struct dev_pagemap_ops___299 {
	void (*page_free)(struct page___309 *);
	void (*kill)(struct dev_pagemap___299 *);
	void (*cleanup)(struct dev_pagemap___299 *);
	vm_fault_t (*migrate_to_ram)(struct vm_fault___299 *);
};

struct fwnode_operations___281;

struct fwnode_handle___281 {
	struct fwnode_handle___281 *secondary;
	const struct fwnode_operations___281 *ops;
	struct device___285 *dev;
	struct list_head suppliers;
	struct list_head consumers;
	u8 flags;
};

struct fwnode_reference_args___281;

struct fwnode_endpoint___281;

struct fwnode_operations___281 {
	struct fwnode_handle___281 * (*get)(struct fwnode_handle___281 *);
	void (*put)(struct fwnode_handle___281 *);
	bool (*device_is_available)(const struct fwnode_handle___281 *);
	const void * (*device_get_match_data)(const struct fwnode_handle___281 *, const struct device___285 *);
	bool (*property_present)(const struct fwnode_handle___281 *, const char *);
	int (*property_read_int_array)(const struct fwnode_handle___281 *, const char *, unsigned int, void *, size_t);
	int (*property_read_string_array)(const struct fwnode_handle___281 *, const char *, const char **, size_t);
	const char * (*get_name)(const struct fwnode_handle___281 *);
	const char * (*get_name_prefix)(const struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*get_parent)(const struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*get_next_child_node)(const struct fwnode_handle___281 *, struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*get_named_child_node)(const struct fwnode_handle___281 *, const char *);
	int (*get_reference_args)(const struct fwnode_handle___281 *, const char *, const char *, unsigned int, unsigned int, struct fwnode_reference_args___281 *);
	struct fwnode_handle___281 * (*graph_get_next_endpoint)(const struct fwnode_handle___281 *, struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*graph_get_remote_endpoint)(const struct fwnode_handle___281 *);
	struct fwnode_handle___281 * (*graph_get_port_parent)(struct fwnode_handle___281 *);
	int (*graph_parse_endpoint)(const struct fwnode_handle___281 *, struct fwnode_endpoint___281 *);
	int (*add_links)(struct fwnode_handle___281 *);
};

struct fwnode_endpoint___281 {
	unsigned int port;
	unsigned int id;
	const struct fwnode_handle___281 *local_fwnode;
};

struct fwnode_reference_args___281 {
	struct fwnode_handle___281 *fwnode;
	unsigned int nargs;
	u64 args[8];
};

struct kernfs_root___292;

struct kernfs_elem_dir___292 {
	long unsigned int subdirs;
	struct rb_root children;
	struct kernfs_root___292 *root;
	long unsigned int rev;
};

struct kernfs_syscall_ops___292;

struct kernfs_root___292 {
	struct kernfs_node___292 *kn;
	unsigned int flags;
	struct idr ino_idr;
	u32 last_id_lowbits;
	u32 id_highbits;
	struct kernfs_syscall_ops___292 *syscall_ops;
	struct list_head supers;
	wait_queue_head_t deactivate_waitq;
};

struct kernfs_elem_symlink___292 {
	struct kernfs_node___292 *target_kn;
};

struct kernfs_ops___292;

struct kernfs_elem_attr___292 {
	const struct kernfs_ops___292 *ops;
	struct kernfs_open_node *open;
	loff_t size;
	struct kernfs_node___292 *notify_next;
};

struct kernfs_node___292 {
	atomic_t count;
	atomic_t active;
	struct kernfs_node___292 *parent;
	const char *name;
	struct rb_node rb;
	const void *ns;
	unsigned int hash;
	union {
		struct kernfs_elem_dir___292 dir;
		struct kernfs_elem_symlink___292 symlink;
		struct kernfs_elem_attr___292 attr;
	};
	void *priv;
	u64 id;
	short unsigned int flags;
	umode_t mode;
	struct kernfs_iattrs *iattr;
};

struct kernfs_open_file___292;

struct kernfs_ops___292 {
	int (*open)(struct kernfs_open_file___292 *);
	void (*release)(struct kernfs_open_file___292 *);
	int (*seq_show)(struct seq_file___279 *, void *);
	void * (*seq_start)(struct seq_file___279 *, loff_t *);
	void * (*seq_next)(struct seq_file___279 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___279 *, void *);
	ssize_t (*read)(struct kernfs_open_file___292 *, char *, size_t, loff_t);
	size_t atomic_write_len;
	bool prealloc;
	ssize_t (*write)(struct kernfs_open_file___292 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___292 *, struct poll_table_struct___222 *);
	int (*mmap)(struct kernfs_open_file___292 *, struct vm_area_struct___309 *);
};

struct kernfs_syscall_ops___292 {
	int (*show_options)(struct seq_file___279 *, struct kernfs_root___292 *);
	int (*mkdir)(struct kernfs_node___292 *, const char *, umode_t);
	int (*rmdir)(struct kernfs_node___292 *);
	int (*rename)(struct kernfs_node___292 *, struct kernfs_node___292 *, const char *);
	int (*show_path)(struct seq_file___279 *, struct kernfs_node___292 *, struct kernfs_root___292 *);
};

struct kernfs_open_file___292 {
	struct kernfs_node___292 *kn;
	struct file___304 *file;
	struct seq_file___279 *seq_file;
	void *priv;
	struct mutex mutex;
	struct mutex prealloc_mutex;
	int event;
	struct list_head list;
	char *prealloc_buf;
	size_t atomic_write_len;
	bool mmapped: 1;
	bool released: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	const struct vm_operations_struct___299 *vm_ops;
};

struct kobj_ns_type_operations___97 {
	enum kobj_ns_type type;
	bool (*current_may_mount)();
	void * (*grab_current_ns)();
	const void * (*netlink_ns)(struct sock___97 *);
	const void * (*initial_ns)();
	void (*drop_ns)(void *);
};

struct bin_attribute___292;

struct attribute_group___292 {
	const char *name;
	umode_t (*is_visible)(struct kobject___292 *, struct attribute *, int);
	umode_t (*is_bin_visible)(struct kobject___292 *, struct bin_attribute___292 *, int);
	struct attribute **attrs;
	struct bin_attribute___292 **bin_attrs;
};

struct bin_attribute___292 {
	struct attribute attr;
	size_t size;
	void *private;
	struct address_space___304 * (*f_mapping)();
	ssize_t (*read)(struct file___304 *, struct kobject___292 *, struct bin_attribute___292 *, char *, loff_t, size_t);
	ssize_t (*write)(struct file___304 *, struct kobject___292 *, struct bin_attribute___292 *, char *, loff_t, size_t);
	int (*mmap)(struct file___304 *, struct kobject___292 *, struct bin_attribute___292 *, struct vm_area_struct___309 *);
};

struct sysfs_ops___292 {
	ssize_t (*show)(struct kobject___292 *, struct attribute *, char *);
	ssize_t (*store)(struct kobject___292 *, struct attribute *, const char *, size_t);
};

struct kset_uevent_ops___292;

struct kset___292 {
	struct list_head list;
	spinlock_t list_lock;
	struct kobject___292 kobj;
	const struct kset_uevent_ops___292 *uevent_ops;
};

struct kobj_type___292 {
	void (*release)(struct kobject___292 *);
	const struct sysfs_ops___292 *sysfs_ops;
	struct attribute **default_attrs;
	const struct attribute_group___292 **default_groups;
	const struct kobj_ns_type_operations___97 * (*child_ns_type)(struct kobject___292 *);
	const void * (*namespace)(struct kobject___292 *);
	void (*get_ownership)(struct kobject___292 *, kuid_t *, kgid_t *);
};

struct kset_uevent_ops___292 {
	int (* const filter)(struct kset___292 *, struct kobject___292 *);
	const char * (* const name)(struct kset___292 *, struct kobject___292 *);
	int (* const uevent)(struct kset___292 *, struct kobject___292 *, struct kobj_uevent_env *);
};

struct kernel_param_ops___288 {
	unsigned int flags;
	int (*set)(const char *, const struct kernel_param___288 *);
	int (*get)(char *, const struct kernel_param___288 *);
	void (*free)(void *);
};

struct kparam_array___288;

struct kernel_param___288 {
	const char *name;
	struct module___288 *mod;
	const struct kernel_param_ops___288 *ops;
	const u16 perm;
	s8 level;
	u8 flags;
	union {
		void *arg;
		const struct kparam_string *str;
		const struct kparam_array___288 *arr;
	};
};

struct kparam_array___288 {
	unsigned int max;
	unsigned int elemsize;
	unsigned int *num;
	const struct kernel_param_ops___288 *ops;
	void *elem;
};

struct module_attribute___288 {
	struct attribute attr;
	ssize_t (*show)(struct module_attribute___288 *, struct module_kobject___289 *, char *);
	ssize_t (*store)(struct module_attribute___288 *, struct module_kobject___289 *, const char *, size_t);
	void (*setup)(struct module___288 *, const char *);
	int (*test)(struct module___288 *);
	void (*free)(struct module___288 *);
};

struct cgroup_namespace___231 {
	struct ns_common___27 ns;
	struct user_namespace___26 *user_ns;
	struct ucounts___26 *ucounts;
	struct css_set___231 *root_cset;
};

struct socket_wq___99 {
	wait_queue_head_t wait;
	struct fasync_struct___304 *fasync_list;
	long unsigned int flags;
	struct callback_head rcu;
	long: 64;
};

struct proto_ops___99;

struct socket___100 {
	socket_state state;
	short int type;
	long unsigned int flags;
	struct file___304 *file;
	struct sock___97 *sk;
	const struct proto_ops___99 *ops;
	long: 64;
	long: 64;
	long: 64;
	struct socket_wq___99 wq;
};

typedef int (*sk_read_actor_t___98)(read_descriptor_t *, struct sk_buff___114 *, unsigned int, size_t);

struct proto_ops___99 {
	int family;
	struct module___288 *owner;
	int (*release)(struct socket___100 *);
	int (*bind)(struct socket___100 *, struct sockaddr *, int);
	int (*connect)(struct socket___100 *, struct sockaddr *, int, int);
	int (*socketpair)(struct socket___100 *, struct socket___100 *);
	int (*accept)(struct socket___100 *, struct socket___100 *, int, bool);
	int (*getname)(struct socket___100 *, struct sockaddr *, int);
	__poll_t (*poll)(struct file___304 *, struct socket___100 *, struct poll_table_struct___222 *);
	int (*ioctl)(struct socket___100 *, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct socket___100 *, unsigned int, long unsigned int);
	int (*gettstamp)(struct socket___100 *, void *, bool, bool);
	int (*listen)(struct socket___100 *, int);
	int (*shutdown)(struct socket___100 *, int);
	int (*setsockopt)(struct socket___100 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct socket___100 *, int, int, char *, int *);
	void (*show_fdinfo)(struct seq_file___279 *, struct socket___100 *);
	int (*sendmsg)(struct socket___100 *, struct msghdr___100 *, size_t);
	int (*recvmsg)(struct socket___100 *, struct msghdr___100 *, size_t, int);
	int (*mmap)(struct file___304 *, struct socket___100 *, struct vm_area_struct___309 *);
	ssize_t (*sendpage)(struct socket___100 *, struct page___309 *, int, size_t, int);
	ssize_t (*splice_read)(struct socket___100 *, loff_t *, struct pipe_inode_info___145 *, size_t, unsigned int);
	int (*set_peek_off)(struct sock___97 *, int);
	int (*peek_len)(struct socket___100 *);
	int (*read_sock)(struct sock___97 *, read_descriptor_t *, sk_read_actor_t___98);
	int (*sendpage_locked)(struct sock___97 *, struct page___309 *, int, size_t, int);
	int (*sendmsg_locked)(struct sock___97 *, struct msghdr___100 *, size_t);
	int (*set_rcvlowat)(struct sock___97 *, int);
};

struct dev_pm_ops___285 {
	int (*prepare)(struct device___285 *);
	void (*complete)(struct device___285 *);
	int (*suspend)(struct device___285 *);
	int (*resume)(struct device___285 *);
	int (*freeze)(struct device___285 *);
	int (*thaw)(struct device___285 *);
	int (*poweroff)(struct device___285 *);
	int (*restore)(struct device___285 *);
	int (*suspend_late)(struct device___285 *);
	int (*resume_early)(struct device___285 *);
	int (*freeze_late)(struct device___285 *);
	int (*thaw_early)(struct device___285 *);
	int (*poweroff_late)(struct device___285 *);
	int (*restore_early)(struct device___285 *);
	int (*suspend_noirq)(struct device___285 *);
	int (*resume_noirq)(struct device___285 *);
	int (*freeze_noirq)(struct device___285 *);
	int (*thaw_noirq)(struct device___285 *);
	int (*poweroff_noirq)(struct device___285 *);
	int (*restore_noirq)(struct device___285 *);
	int (*runtime_suspend)(struct device___285 *);
	int (*runtime_resume)(struct device___285 *);
	int (*runtime_idle)(struct device___285 *);
};

struct wakeup_source___285 {
	const char *name;
	int id;
	struct list_head entry;
	spinlock_t lock;
	struct wake_irq *wakeirq;
	struct timer_list timer;
	long unsigned int timer_expires;
	ktime_t total_time;
	ktime_t max_time;
	ktime_t last_time;
	ktime_t start_prevent_time;
	ktime_t prevent_sleep_time;
	long unsigned int event_count;
	long unsigned int active_count;
	long unsigned int relax_count;
	long unsigned int expire_count;
	long unsigned int wakeup_count;
	struct device___285 *dev;
	bool active: 1;
	bool autosleep_enabled: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct dev_pm_domain___285 {
	struct dev_pm_ops___285 ops;
	int (*start)(struct device___285 *);
	void (*detach)(struct device___285 *, bool);
	int (*activate)(struct device___285 *);
	void (*sync)(struct device___285 *);
	void (*dismiss)(struct device___285 *);
};

struct bus_type___285 {
	const char *name;
	const char *dev_name;
	struct device___285 *dev_root;
	const struct attribute_group___292 **bus_groups;
	const struct attribute_group___292 **dev_groups;
	const struct attribute_group___292 **drv_groups;
	int (*match)(struct device___285 *, struct device_driver___285 *);
	int (*uevent)(struct device___285 *, struct kobj_uevent_env *);
	int (*probe)(struct device___285 *);
	void (*sync_state)(struct device___285 *);
	void (*remove)(struct device___285 *);
	void (*shutdown)(struct device___285 *);
	int (*online)(struct device___285 *);
	int (*offline)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	int (*num_vf)(struct device___285 *);
	int (*dma_configure)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
	const struct iommu_ops *iommu_ops;
	struct subsys_private *p;
	struct lock_class_key lock_key;
	bool need_parent_lock;
};

struct device_driver___285 {
	const char *name;
	struct bus_type___285 *bus;
	struct module___288 *owner;
	const char *mod_name;
	bool suppress_bind_attrs;
	enum probe_type probe_type;
	const struct of_device_id *of_match_table;
	const struct acpi_device_id *acpi_match_table;
	int (*probe)(struct device___285 *);
	void (*sync_state)(struct device___285 *);
	int (*remove)(struct device___285 *);
	void (*shutdown)(struct device___285 *);
	int (*suspend)(struct device___285 *, pm_message_t);
	int (*resume)(struct device___285 *);
	const struct attribute_group___292 **groups;
	const struct attribute_group___292 **dev_groups;
	const struct dev_pm_ops___285 *pm;
	void (*coredump)(struct device___285 *);
	struct driver_private *p;
};

struct device_type___285 {
	const char *name;
	const struct attribute_group___292 **groups;
	int (*uevent)(struct device___285 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___285 *, umode_t *, kuid_t *, kgid_t *);
	void (*release)(struct device___285 *);
	const struct dev_pm_ops___285 *pm;
};

struct class___285 {
	const char *name;
	struct module___288 *owner;
	const struct attribute_group___292 **class_groups;
	const struct attribute_group___292 **dev_groups;
	struct kobject___292 *dev_kobj;
	int (*dev_uevent)(struct device___285 *, struct kobj_uevent_env *);
	char * (*devnode)(struct device___285 *, umode_t *);
	void (*class_release)(struct class___285 *);
	void (*dev_release)(struct device___285 *);
	int (*shutdown_pre)(struct device___285 *);
	const struct kobj_ns_type_operations___97 *ns_type;
	const void * (*namespace)(struct device___285 *);
	void (*get_ownership)(struct device___285 *, kuid_t *, kgid_t *);
	const struct dev_pm_ops___285 *pm;
	struct subsys_private *p;
};

struct pipe_buf_operations___145;

struct pipe_buffer___145 {
	struct page___309 *page;
	unsigned int offset;
	unsigned int len;
	const struct pipe_buf_operations___145 *ops;
	unsigned int flags;
	long unsigned int private;
};

struct pipe_buf_operations___145 {
	int (*confirm)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
	void (*release)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
	bool (*try_steal)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
	bool (*get)(struct pipe_inode_info___145 *, struct pipe_buffer___145 *);
};

struct ubuf_info___16 {
	void (*callback)(struct sk_buff___114 *, struct ubuf_info___16 *, bool);
	union {
		struct {
			long unsigned int desc;
			void *ctx;
		};
		struct {
			u32 id;
			u16 len;
			u16 zerocopy: 1;
			long: 63;
			u32 bytelen;
		};
	};
	refcount_t refcnt;
	u8 flags;
	struct mmpin mmp;
};

struct seq_operations___279 {
	void * (*start)(struct seq_file___279 *, loff_t *);
	void (*stop)(struct seq_file___279 *, void *);
	void * (*next)(struct seq_file___279 *, void *, loff_t *);
	int (*show)(struct seq_file___279 *, void *);
};

struct pernet_operations___44 {
	struct list_head list;
	int (*init)(struct net___118 *);
	void (*pre_exit)(struct net___118 *);
	void (*exit)(struct net___118 *);
	void (*exit_batch)(struct list_head *);
	unsigned int *id;
	size_t size;
};

struct dcbnl_rtnl_ops___113 {
	int (*ieee_getets)(struct net_device___113 *, struct ieee_ets *);
	int (*ieee_setets)(struct net_device___113 *, struct ieee_ets *);
	int (*ieee_getmaxrate)(struct net_device___113 *, struct ieee_maxrate *);
	int (*ieee_setmaxrate)(struct net_device___113 *, struct ieee_maxrate *);
	int (*ieee_getqcn)(struct net_device___113 *, struct ieee_qcn *);
	int (*ieee_setqcn)(struct net_device___113 *, struct ieee_qcn *);
	int (*ieee_getqcnstats)(struct net_device___113 *, struct ieee_qcn_stats *);
	int (*ieee_getpfc)(struct net_device___113 *, struct ieee_pfc *);
	int (*ieee_setpfc)(struct net_device___113 *, struct ieee_pfc *);
	int (*ieee_getapp)(struct net_device___113 *, struct dcb_app *);
	int (*ieee_setapp)(struct net_device___113 *, struct dcb_app *);
	int (*ieee_delapp)(struct net_device___113 *, struct dcb_app *);
	int (*ieee_peer_getets)(struct net_device___113 *, struct ieee_ets *);
	int (*ieee_peer_getpfc)(struct net_device___113 *, struct ieee_pfc *);
	u8 (*getstate)(struct net_device___113 *);
	u8 (*setstate)(struct net_device___113 *, u8);
	void (*getpermhwaddr)(struct net_device___113 *, u8 *);
	void (*setpgtccfgtx)(struct net_device___113 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgtx)(struct net_device___113 *, int, u8);
	void (*setpgtccfgrx)(struct net_device___113 *, int, u8, u8, u8, u8);
	void (*setpgbwgcfgrx)(struct net_device___113 *, int, u8);
	void (*getpgtccfgtx)(struct net_device___113 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgtx)(struct net_device___113 *, int, u8 *);
	void (*getpgtccfgrx)(struct net_device___113 *, int, u8 *, u8 *, u8 *, u8 *);
	void (*getpgbwgcfgrx)(struct net_device___113 *, int, u8 *);
	void (*setpfccfg)(struct net_device___113 *, int, u8);
	void (*getpfccfg)(struct net_device___113 *, int, u8 *);
	u8 (*setall)(struct net_device___113 *);
	u8 (*getcap)(struct net_device___113 *, int, u8 *);
	int (*getnumtcs)(struct net_device___113 *, int, u8 *);
	int (*setnumtcs)(struct net_device___113 *, int, u8);
	u8 (*getpfcstate)(struct net_device___113 *);
	void (*setpfcstate)(struct net_device___113 *, u8);
	void (*getbcncfg)(struct net_device___113 *, int, u32 *);
	void (*setbcncfg)(struct net_device___113 *, int, u32);
	void (*getbcnrp)(struct net_device___113 *, int, u8 *);
	void (*setbcnrp)(struct net_device___113 *, int, u8);
	int (*setapp)(struct net_device___113 *, u8, u16, u8);
	int (*getapp)(struct net_device___113 *, u8, u16);
	u8 (*getfeatcfg)(struct net_device___113 *, int, u8 *);
	u8 (*setfeatcfg)(struct net_device___113 *, int, u8);
	u8 (*getdcbx)(struct net_device___113 *);
	u8 (*setdcbx)(struct net_device___113 *, u8);
	int (*peer_getappinfo)(struct net_device___113 *, struct dcb_peer_app_info *, u16 *);
	int (*peer_getapptable)(struct net_device___113 *, struct dcb_app *);
	int (*cee_peer_getpg)(struct net_device___113 *, struct cee_pg *);
	int (*cee_peer_getpfc)(struct net_device___113 *, struct cee_pfc *);
	int (*dcbnl_getbuffer)(struct net_device___113 *, struct dcbnl_buffer *);
	int (*dcbnl_setbuffer)(struct net_device___113 *, struct dcbnl_buffer *);
};

struct bpf_iter_aux_info___116;

typedef int (*bpf_iter_init_seq_priv_t___115)(void *, struct bpf_iter_aux_info___116 *);

struct bpf_map___116;

struct bpf_iter_aux_info___116 {
	struct bpf_map___116 *map;
};

struct bpf_iter_seq_info___115 {
	const struct seq_operations___279 *seq_ops;
	bpf_iter_init_seq_priv_t___115 init_seq_private;
	bpf_iter_fini_seq_priv_t fini_seq_private;
	u32 seq_priv_size;
};

struct bpf_map_ops___115 {
	int (*map_alloc_check)(union bpf_attr *);
	struct bpf_map___116 * (*map_alloc)(union bpf_attr *);
	void (*map_release)(struct bpf_map___116 *, struct file___304 *);
	void (*map_free)(struct bpf_map___116 *);
	int (*map_get_next_key)(struct bpf_map___116 *, void *, void *);
	void (*map_release_uref)(struct bpf_map___116 *);
	void * (*map_lookup_elem_sys_only)(struct bpf_map___116 *, void *);
	int (*map_lookup_batch)(struct bpf_map___116 *, const union bpf_attr *, union bpf_attr *);
	int (*map_lookup_and_delete_elem)(struct bpf_map___116 *, void *, void *, u64);
	int (*map_lookup_and_delete_batch)(struct bpf_map___116 *, const union bpf_attr *, union bpf_attr *);
	int (*map_update_batch)(struct bpf_map___116 *, const union bpf_attr *, union bpf_attr *);
	int (*map_delete_batch)(struct bpf_map___116 *, const union bpf_attr *, union bpf_attr *);
	void * (*map_lookup_elem)(struct bpf_map___116 *, void *);
	int (*map_update_elem)(struct bpf_map___116 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_map___116 *, void *);
	int (*map_push_elem)(struct bpf_map___116 *, void *, u64);
	int (*map_pop_elem)(struct bpf_map___116 *, void *);
	int (*map_peek_elem)(struct bpf_map___116 *, void *);
	void * (*map_fd_get_ptr)(struct bpf_map___116 *, struct file___304 *, int);
	void (*map_fd_put_ptr)(void *);
	int (*map_gen_lookup)(struct bpf_map___116 *, struct bpf_insn *);
	u32 (*map_fd_sys_lookup_elem)(void *);
	void (*map_seq_show_elem)(struct bpf_map___116 *, void *, struct seq_file___279 *);
	int (*map_check_btf)(const struct bpf_map___116 *, const struct btf *, const struct btf_type *, const struct btf_type *);
	int (*map_poke_track)(struct bpf_map___116 *, struct bpf_prog_aux___116 *);
	void (*map_poke_untrack)(struct bpf_map___116 *, struct bpf_prog_aux___116 *);
	void (*map_poke_run)(struct bpf_map___116 *, u32, struct bpf_prog___104 *, struct bpf_prog___104 *);
	int (*map_direct_value_addr)(const struct bpf_map___116 *, u64 *, u32);
	int (*map_direct_value_meta)(const struct bpf_map___116 *, u64, u32 *);
	int (*map_mmap)(struct bpf_map___116 *, struct vm_area_struct___309 *);
	__poll_t (*map_poll)(struct bpf_map___116 *, struct file___304 *, struct poll_table_struct___222 *);
	int (*map_local_storage_charge)(struct bpf_local_storage_map *, void *, u32);
	void (*map_local_storage_uncharge)(struct bpf_local_storage_map *, void *, u32);
	struct bpf_local_storage ** (*map_owner_storage_ptr)(void *);
	int (*map_redirect)(struct bpf_map___116 *, u32, u64);
	bool (*map_meta_equal)(const struct bpf_map___116 *, const struct bpf_map___116 *);
	int (*map_set_for_each_callback_args)(struct bpf_verifier_env *, struct bpf_func_state *, struct bpf_func_state *);
	int (*map_for_each_callback)(struct bpf_map___116 *, void *, void *, u64);
	const char * const map_btf_name;
	int *map_btf_id;
	const struct bpf_iter_seq_info___115 *iter_seq_info;
};

struct bpf_map___116 {
	const struct bpf_map_ops___115 *ops;
	struct bpf_map___116 *inner_map_meta;
	void *security;
	enum bpf_map_type map_type;
	u32 key_size;
	u32 value_size;
	u32 max_entries;
	u32 map_flags;
	int spin_lock_off;
	int timer_off;
	u32 id;
	int numa_node;
	u32 btf_key_type_id;
	u32 btf_value_type_id;
	struct btf *btf;
	struct mem_cgroup___166 *memcg;
	char name[16];
	u32 btf_vmlinux_value_type_id;
	bool bypass_spec_v1;
	bool frozen;
	long: 16;
	long: 64;
	long: 64;
	atomic64_t refcnt;
	atomic64_t usercnt;
	struct work_struct work;
	struct mutex freeze_mutex;
	atomic64_t writecnt;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_trampoline___115;

struct bpf_jit_poke_descriptor___115;

struct bpf_prog_ops___104;

struct btf_mod_pair___115;

struct bpf_prog_offload___113;

struct bpf_prog_aux___116 {
	atomic64_t refcnt;
	u32 used_map_cnt;
	u32 used_btf_cnt;
	u32 max_ctx_offset;
	u32 max_pkt_offset;
	u32 max_tp_access;
	u32 stack_depth;
	u32 id;
	u32 func_cnt;
	u32 func_idx;
	u32 attach_btf_id;
	u32 ctx_arg_info_size;
	u32 max_rdonly_access;
	u32 max_rdwr_access;
	struct btf *attach_btf;
	const struct bpf_ctx_arg_aux *ctx_arg_info;
	struct mutex dst_mutex;
	struct bpf_prog___104 *dst_prog;
	struct bpf_trampoline___115 *dst_trampoline;
	enum bpf_prog_type saved_dst_prog_type;
	enum bpf_attach_type saved_dst_attach_type;
	bool verifier_zext;
	bool offload_requested;
	bool attach_btf_trace;
	bool func_proto_unreliable;
	bool sleepable;
	bool tail_call_reachable;
	struct hlist_node tramp_hlist;
	const struct btf_type *attach_func_proto;
	const char *attach_func_name;
	struct bpf_prog___104 **func;
	void *jit_data;
	struct bpf_jit_poke_descriptor___115 *poke_tab;
	struct bpf_kfunc_desc_tab *kfunc_tab;
	u32 size_poke_tab;
	struct bpf_ksym ksym;
	const struct bpf_prog_ops___104 *ops;
	struct bpf_map___116 **used_maps;
	struct mutex used_maps_mutex;
	struct btf_mod_pair___115 *used_btfs;
	struct bpf_prog___104 *prog;
	struct user_struct *user;
	u64 load_time;
	struct bpf_map___116 *cgroup_storage[2];
	char name[16];
	void *security;
	struct bpf_prog_offload___113 *offload;
	struct btf *btf;
	struct bpf_func_info *func_info;
	struct bpf_func_info_aux *func_info_aux;
	struct bpf_line_info *linfo;
	void **jited_linfo;
	u32 func_info_cnt;
	u32 nr_linfo;
	u32 linfo_idx;
	u32 num_exentries;
	struct exception_table_entry *extable;
	union {
		struct work_struct work;
		struct callback_head rcu;
	};
};

struct bpf_offloaded_map___113;

struct bpf_map_dev_ops___113 {
	int (*map_get_next_key)(struct bpf_offloaded_map___113 *, void *, void *);
	int (*map_lookup_elem)(struct bpf_offloaded_map___113 *, void *, void *);
	int (*map_update_elem)(struct bpf_offloaded_map___113 *, void *, void *, u64);
	int (*map_delete_elem)(struct bpf_offloaded_map___113 *, void *);
};

struct bpf_offloaded_map___113 {
	struct bpf_map___116 map;
	struct net_device___113 *netdev;
	const struct bpf_map_dev_ops___113 *dev_ops;
	void *dev_priv;
	struct list_head offloads;
	long: 64;
	long: 64;
	long: 64;
};

struct bpf_prog_ops___104 {
	int (*test_run)(struct bpf_prog___104 *, const union bpf_attr *, union bpf_attr *);
};

struct bpf_prog_offload___113 {
	struct bpf_prog___104 *prog;
	struct net_device___113 *netdev;
	struct bpf_offload_dev *offdev;
	void *dev_priv;
	struct list_head offloads;
	bool dev_state;
	bool opt_failed;
	void *jited_image;
	u32 jited_len;
};

struct bpf_trampoline___115 {
	struct hlist_node hlist;
	struct mutex mutex;
	refcount_t refcnt;
	u64 key;
	struct {
		struct btf_func_model model;
		void *addr;
		bool ftrace_managed;
	} func;
	struct bpf_prog___104 *extension_prog;
	struct hlist_head progs_hlist[3];
	int progs_cnt[3];
	struct bpf_tramp_image *cur_image;
	u64 selector;
	struct module___288 *mod;
};

struct bpf_jit_poke_descriptor___115 {
	void *tailcall_target;
	void *tailcall_bypass;
	void *bypass_addr;
	void *aux;
	union {
		struct {
			struct bpf_map___116 *map;
			u32 key;
		} tail_call;
	};
	bool tailcall_target_stable;
	u8 adj_off;
	u16 reason;
	u32 insn_idx;
};

struct btf_mod_pair___115 {
	struct btf *btf;
	struct module___288 *module;
};

struct cftype___231;

struct cgroup_subsys___231 {
	struct cgroup_subsys_state___231 * (*css_alloc)(struct cgroup_subsys_state___231 *);
	int (*css_online)(struct cgroup_subsys_state___231 *);
	void (*css_offline)(struct cgroup_subsys_state___231 *);
	void (*css_released)(struct cgroup_subsys_state___231 *);
	void (*css_free)(struct cgroup_subsys_state___231 *);
	void (*css_reset)(struct cgroup_subsys_state___231 *);
	void (*css_rstat_flush)(struct cgroup_subsys_state___231 *, int);
	int (*css_extra_stat_show)(struct seq_file___279 *, struct cgroup_subsys_state___231 *);
	int (*can_attach)(struct cgroup_taskset *);
	void (*cancel_attach)(struct cgroup_taskset *);
	void (*attach)(struct cgroup_taskset *);
	void (*post_attach)();
	int (*can_fork)(struct task_struct___311 *, struct css_set___231 *);
	void (*cancel_fork)(struct task_struct___311 *, struct css_set___231 *);
	void (*fork)(struct task_struct___311 *);
	void (*exit)(struct task_struct___311 *);
	void (*release)(struct task_struct___311 *);
	void (*bind)(struct cgroup_subsys_state___231 *);
	bool early_init: 1;
	bool implicit_on_dfl: 1;
	bool threaded: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int id;
	const char *name;
	const char *legacy_name;
	struct cgroup_root___231 *root;
	struct idr css_idr;
	struct list_head cfts;
	struct cftype___231 *dfl_cftypes;
	struct cftype___231 *legacy_cftypes;
	unsigned int depends_on;
};

struct cgroup_rstat_cpu___231 {
	struct u64_stats_sync bsync;
	struct cgroup_base_stat bstat;
	struct cgroup_base_stat last_bstat;
	struct cgroup___231 *updated_children;
	struct cgroup___231 *updated_next;
};

struct cgroup_root___231 {
	struct kernfs_root___292 *kf_root;
	unsigned int subsys_mask;
	int hierarchy_id;
	struct cgroup___231 cgrp;
	u64 cgrp_ancestor_id_storage;
	atomic_t nr_cgrps;
	struct list_head root_list;
	unsigned int flags;
	char release_agent_path[4096];
	char name[64];
};

struct cftype___231 {
	char name[64];
	long unsigned int private;
	size_t max_write_len;
	unsigned int flags;
	unsigned int file_offset;
	struct cgroup_subsys___231 *ss;
	struct list_head node;
	struct kernfs_ops___292 *kf_ops;
	int (*open)(struct kernfs_open_file___292 *);
	void (*release)(struct kernfs_open_file___292 *);
	u64 (*read_u64)(struct cgroup_subsys_state___231 *, struct cftype___231 *);
	s64 (*read_s64)(struct cgroup_subsys_state___231 *, struct cftype___231 *);
	int (*seq_show)(struct seq_file___279 *, void *);
	void * (*seq_start)(struct seq_file___279 *, loff_t *);
	void * (*seq_next)(struct seq_file___279 *, void *, loff_t *);
	void (*seq_stop)(struct seq_file___279 *, void *);
	int (*write_u64)(struct cgroup_subsys_state___231 *, struct cftype___231 *, u64);
	int (*write_s64)(struct cgroup_subsys_state___231 *, struct cftype___231 *, s64);
	ssize_t (*write)(struct kernfs_open_file___292 *, char *, size_t, loff_t);
	__poll_t (*poll)(struct kernfs_open_file___292 *, struct poll_table_struct___222 *);
};

struct xdp_rxq_info___113 {
	struct net_device___113 *dev;
	u32 queue_index;
	u32 reg_state;
	struct xdp_mem_info mem;
	unsigned int napi_id;
	long: 32;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct xdp_txq_info___113 {
	struct net_device___113 *dev;
};

struct xdp_buff___113 {
	void *data;
	void *data_end;
	void *data_meta;
	void *data_hard_start;
	struct xdp_rxq_info___113 *rxq;
	struct xdp_txq_info___113 *txq;
	u32 frame_sz;
};

struct xdp_frame___113 {
	void *data;
	u16 len;
	u16 headroom;
	u32 metasize: 8;
	u32 frame_sz: 24;
	long: 40;
	long: 64;
	struct xdp_mem_info mem;
	struct net_device___113 *dev_rx;
};

struct netlink_skb_parms___24 {
	struct scm_creds creds;
	__u32 portid;
	__u32 dst_group;
	__u32 flags;
	struct sock___97 *sk;
	bool nsid_is_set;
	int nsid;
};

struct netlink_callback___113 {
	struct sk_buff___114 *skb;
	const struct nlmsghdr *nlh;
	int (*dump)(struct sk_buff___114 *, struct netlink_callback___113 *);
	int (*done)(struct netlink_callback___113 *);
	void *data;
	struct module___288 *module;
	struct netlink_ext_ack *extack;
	u16 family;
	u16 answer_flags;
	u32 min_dump_alloc;
	unsigned int prev_seq;
	unsigned int seq;
	bool strict_check;
	union {
		u8 ctx[48];
		long int args[6];
	};
};

struct header_ops___113 {
	int (*create)(struct sk_buff___114 *, struct net_device___113 *, short unsigned int, const void *, const void *, unsigned int);
	int (*parse)(const struct sk_buff___114 *, unsigned char *);
	int (*cache)(const struct neighbour___98 *, struct hh_cache *, __be16);
	void (*cache_update)(struct hh_cache *, const struct net_device___113 *, const unsigned char *);
	bool (*validate)(const char *, unsigned int);
	__be16 (*parse_protocol)(const struct sk_buff___114 *);
};

struct netdev_queue___113 {
	struct net_device___113 *dev;
	struct Qdisc___104 *qdisc;
	struct Qdisc___104 *qdisc_sleeping;
	struct kobject___292 kobj;
	int numa_node;
	long unsigned int tx_maxrate;
	long unsigned int trans_timeout;
	struct net_device___113 *sb_dev;
	struct xsk_buff_pool *pool;
	spinlock_t _xmit_lock;
	int xmit_lock_owner;
	long unsigned int trans_start;
	long unsigned int state;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct dql dql;
};

struct qdisc_skb_head___104 {
	struct sk_buff___114 *head;
	struct sk_buff___114 *tail;
	__u32 qlen;
	spinlock_t lock;
};

struct Qdisc_ops___104;

struct Qdisc___104 {
	int (*enqueue)(struct sk_buff___114 *, struct Qdisc___104 *, struct sk_buff___114 **);
	struct sk_buff___114 * (*dequeue)(struct Qdisc___104 *);
	unsigned int flags;
	u32 limit;
	const struct Qdisc_ops___104 *ops;
	struct qdisc_size_table *stab;
	struct hlist_node hash;
	u32 handle;
	u32 parent;
	struct netdev_queue___113 *dev_queue;
	struct net_rate_estimator *rate_est;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	int pad;
	refcount_t refcnt;
	long: 64;
	long: 64;
	long: 64;
	struct sk_buff_head___113 gso_skb;
	struct qdisc_skb_head___104 q;
	struct gnet_stats_basic_packed bstats;
	seqcount_t running;
	struct gnet_stats_queue qstats;
	long unsigned int state;
	struct Qdisc___104 *next_sched;
	struct sk_buff_head___113 skb_bad_txq;
	spinlock_t busylock;
	spinlock_t seqlock;
	struct callback_head rcu;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long int privdata[0];
};

struct netdev_rx_queue___113 {
	struct xdp_rxq_info___113 xdp_rxq;
	struct rps_map *rps_map;
	struct rps_dev_flow_table *rps_flow_table;
	struct kobject___292 kobj;
	struct net_device___113 *dev;
	struct xsk_buff_pool *pool;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct net_device_path___113 {
	enum net_device_path_type type;
	const struct net_device___113 *dev;
	union {
		struct {
			u16 id;
			__be16 proto;
			u8 h_dest[6];
		} encap;
		struct {
			enum {
				DEV_PATH_BR_VLAN_KEEP___113 = 0,
				DEV_PATH_BR_VLAN_TAG___113 = 1,
				DEV_PATH_BR_VLAN_UNTAG___113 = 2,
				DEV_PATH_BR_VLAN_UNTAG_HW___113 = 3,
			} vlan_mode;
			u16 vlan_id;
			__be16 vlan_proto;
		} bridge;
		struct {
			int port;
			u16 proto;
		} dsa;
	};
};

struct net_device_path_ctx___113 {
	const struct net_device___113 *dev;
	const u8 *daddr;
	int num_vlans;
	struct {
		u16 id;
		__be16 proto;
	} vlan[2];
};

struct netdev_bpf___113 {
	enum bpf_netdev_command command;
	union {
		struct {
			u32 flags;
			struct bpf_prog___104 *prog;
			struct netlink_ext_ack *extack;
		};
		struct {
			struct bpf_offloaded_map___113 *offmap;
		};
		struct {
			struct xsk_buff_pool___3 *pool;
			u16 queue_id;
		} xsk;
	};
};

struct xfrmdev_ops___113 {
	int (*xdo_dev_state_add)(struct xfrm_state *);
	void (*xdo_dev_state_delete)(struct xfrm_state *);
	void (*xdo_dev_state_free)(struct xfrm_state *);
	bool (*xdo_dev_offload_ok)(struct sk_buff___114 *, struct xfrm_state *);
	void (*xdo_dev_state_advance_esn)(struct xfrm_state *);
};

struct netdev_name_node___113 {
	struct hlist_node hlist;
	struct list_head list;
	struct net_device___113 *dev;
	const char *name;
};

struct net_device_ops___113 {
	int (*ndo_init)(struct net_device___113 *);
	void (*ndo_uninit)(struct net_device___113 *);
	int (*ndo_open)(struct net_device___113 *);
	int (*ndo_stop)(struct net_device___113 *);
	netdev_tx_t (*ndo_start_xmit)(struct sk_buff___114 *, struct net_device___113 *);
	netdev_features_t (*ndo_features_check)(struct sk_buff___114 *, struct net_device___113 *, netdev_features_t);
	u16 (*ndo_select_queue)(struct net_device___113 *, struct sk_buff___114 *, struct net_device___113 *);
	void (*ndo_change_rx_flags)(struct net_device___113 *, int);
	void (*ndo_set_rx_mode)(struct net_device___113 *);
	int (*ndo_set_mac_address)(struct net_device___113 *, void *);
	int (*ndo_validate_addr)(struct net_device___113 *);
	int (*ndo_do_ioctl)(struct net_device___113 *, struct ifreq *, int);
	int (*ndo_eth_ioctl)(struct net_device___113 *, struct ifreq *, int);
	int (*ndo_siocbond)(struct net_device___113 *, struct ifreq *, int);
	int (*ndo_siocwandev)(struct net_device___113 *, struct if_settings *);
	int (*ndo_siocdevprivate)(struct net_device___113 *, struct ifreq *, void *, int);
	int (*ndo_set_config)(struct net_device___113 *, struct ifmap *);
	int (*ndo_change_mtu)(struct net_device___113 *, int);
	int (*ndo_neigh_setup)(struct net_device___113 *, struct neigh_parms___98 *);
	void (*ndo_tx_timeout)(struct net_device___113 *, unsigned int);
	void (*ndo_get_stats64)(struct net_device___113 *, struct rtnl_link_stats64 *);
	bool (*ndo_has_offload_stats)(const struct net_device___113 *, int);
	int (*ndo_get_offload_stats)(int, const struct net_device___113 *, void *);
	struct net_device_stats * (*ndo_get_stats)(struct net_device___113 *);
	int (*ndo_vlan_rx_add_vid)(struct net_device___113 *, __be16, u16);
	int (*ndo_vlan_rx_kill_vid)(struct net_device___113 *, __be16, u16);
	void (*ndo_poll_controller)(struct net_device___113 *);
	int (*ndo_netpoll_setup)(struct net_device___113 *, struct netpoll_info *);
	void (*ndo_netpoll_cleanup)(struct net_device___113 *);
	int (*ndo_set_vf_mac)(struct net_device___113 *, int, u8 *);
	int (*ndo_set_vf_vlan)(struct net_device___113 *, int, u16, u8, __be16);
	int (*ndo_set_vf_rate)(struct net_device___113 *, int, int, int);
	int (*ndo_set_vf_spoofchk)(struct net_device___113 *, int, bool);
	int (*ndo_set_vf_trust)(struct net_device___113 *, int, bool);
	int (*ndo_get_vf_config)(struct net_device___113 *, int, struct ifla_vf_info *);
	int (*ndo_set_vf_link_state)(struct net_device___113 *, int, int);
	int (*ndo_get_vf_stats)(struct net_device___113 *, int, struct ifla_vf_stats *);
	int (*ndo_set_vf_port)(struct net_device___113 *, int, struct nlattr **);
	int (*ndo_get_vf_port)(struct net_device___113 *, int, struct sk_buff___114 *);
	int (*ndo_get_vf_guid)(struct net_device___113 *, int, struct ifla_vf_guid *, struct ifla_vf_guid *);
	int (*ndo_set_vf_guid)(struct net_device___113 *, int, u64, int);
	int (*ndo_set_vf_rss_query_en)(struct net_device___113 *, int, bool);
	int (*ndo_setup_tc)(struct net_device___113 *, enum tc_setup_type, void *);
	int (*ndo_fcoe_enable)(struct net_device___113 *);
	int (*ndo_fcoe_disable)(struct net_device___113 *);
	int (*ndo_fcoe_ddp_setup)(struct net_device___113 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_ddp_done)(struct net_device___113 *, u16);
	int (*ndo_fcoe_ddp_target)(struct net_device___113 *, u16, struct scatterlist *, unsigned int);
	int (*ndo_fcoe_get_hbainfo)(struct net_device___113 *, struct netdev_fcoe_hbainfo *);
	int (*ndo_fcoe_get_wwn)(struct net_device___113 *, u64 *, int);
	int (*ndo_rx_flow_steer)(struct net_device___113 *, const struct sk_buff___114 *, u16, u32);
	int (*ndo_add_slave)(struct net_device___113 *, struct net_device___113 *, struct netlink_ext_ack *);
	int (*ndo_del_slave)(struct net_device___113 *, struct net_device___113 *);
	struct net_device___113 * (*ndo_get_xmit_slave)(struct net_device___113 *, struct sk_buff___114 *, bool);
	struct net_device___113 * (*ndo_sk_get_lower_dev)(struct net_device___113 *, struct sock___97 *);
	netdev_features_t (*ndo_fix_features)(struct net_device___113 *, netdev_features_t);
	int (*ndo_set_features)(struct net_device___113 *, netdev_features_t);
	int (*ndo_neigh_construct)(struct net_device___113 *, struct neighbour___98 *);
	void (*ndo_neigh_destroy)(struct net_device___113 *, struct neighbour___98 *);
	int (*ndo_fdb_add)(struct ndmsg *, struct nlattr **, struct net_device___113 *, const unsigned char *, u16, u16, struct netlink_ext_ack *);
	int (*ndo_fdb_del)(struct ndmsg *, struct nlattr **, struct net_device___113 *, const unsigned char *, u16);
	int (*ndo_fdb_dump)(struct sk_buff___114 *, struct netlink_callback___113 *, struct net_device___113 *, struct net_device___113 *, int *);
	int (*ndo_fdb_get)(struct sk_buff___114 *, struct nlattr **, struct net_device___113 *, const unsigned char *, u16, u32, u32, struct netlink_ext_ack *);
	int (*ndo_bridge_setlink)(struct net_device___113 *, struct nlmsghdr *, u16, struct netlink_ext_ack *);
	int (*ndo_bridge_getlink)(struct sk_buff___114 *, u32, u32, struct net_device___113 *, u32, int);
	int (*ndo_bridge_dellink)(struct net_device___113 *, struct nlmsghdr *, u16);
	int (*ndo_change_carrier)(struct net_device___113 *, bool);
	int (*ndo_get_phys_port_id)(struct net_device___113 *, struct netdev_phys_item_id *);
	int (*ndo_get_port_parent_id)(struct net_device___113 *, struct netdev_phys_item_id *);
	int (*ndo_get_phys_port_name)(struct net_device___113 *, char *, size_t);
	void * (*ndo_dfwd_add_station)(struct net_device___113 *, struct net_device___113 *);
	void (*ndo_dfwd_del_station)(struct net_device___113 *, void *);
	int (*ndo_set_tx_maxrate)(struct net_device___113 *, int, u32);
	int (*ndo_get_iflink)(const struct net_device___113 *);
	int (*ndo_change_proto_down)(struct net_device___113 *, bool);
	int (*ndo_fill_metadata_dst)(struct net_device___113 *, struct sk_buff___114 *);
	void (*ndo_set_rx_headroom)(struct net_device___113 *, int);
	int (*ndo_bpf)(struct net_device___113 *, struct netdev_bpf___113 *);
	int (*ndo_xdp_xmit)(struct net_device___113 *, int, struct xdp_frame___113 **, u32);
	struct net_device___113 * (*ndo_xdp_get_xmit_slave)(struct net_device___113 *, struct xdp_buff___113 *);
	int (*ndo_xsk_wakeup)(struct net_device___113 *, u32, u32);
	struct devlink_port * (*ndo_get_devlink_port)(struct net_device___113 *);
	int (*ndo_tunnel_ctl)(struct net_device___113 *, struct ip_tunnel_parm *, int);
	struct net_device___113 * (*ndo_get_peer_dev)(struct net_device___113 *);
	int (*ndo_fill_forward_path)(struct net_device_path_ctx___113 *, struct net_device_path___113 *);
};

struct neigh_parms___98 {
	possible_net_t___113 net;
	struct net_device___113 *dev;
	struct list_head list;
	int (*neigh_setup)(struct neighbour___98 *);
	struct neigh_table___98 *tbl;
	void *sysctl_table;
	int dead;
	refcount_t refcnt;
	struct callback_head callback_head;
	int reachable_time;
	int data[13];
	long unsigned int data_state[1];
};

struct l3mdev_ops___97 {
	u32 (*l3mdev_fib_table)(const struct net_device___113 *);
	struct sk_buff___114 * (*l3mdev_l3_rcv)(struct net_device___113 *, struct sk_buff___114 *, u16);
	struct sk_buff___114 * (*l3mdev_l3_out)(struct net_device___113 *, struct sock___97 *, struct sk_buff___114 *, u16);
	struct dst_entry___97 * (*l3mdev_link_scope_lookup)(const struct net_device___113 *, struct flowi6 *);
};

struct ndisc_ops___78 {
	int (*is_useropt)(u8);
	int (*parse_options)(const struct net_device___113 *, struct nd_opt_hdr *, struct ndisc_options *);
	void (*update)(const struct net_device___113 *, struct neighbour___98 *, u32, u8, const struct ndisc_options *);
	int (*opt_addr_space)(const struct net_device___113 *, u8, struct neighbour___98 *, u8 *, u8 **);
	void (*fill_addr_option)(const struct net_device___113 *, struct sk_buff___114 *, u8, const u8 *);
	void (*prefix_rcv_add_addr)(struct net___118 *, struct net_device___113 *, const struct prefix_info *, struct inet6_dev___78 *, struct in6_addr *, int, u32, bool, bool, __u32, u32, bool);
};

struct ifmcaddr6___78;

struct inet6_dev___78 {
	struct net_device___113 *dev;
	struct list_head addr_list;
	struct ifmcaddr6___78 *mc_list;
	struct ifmcaddr6___78 *mc_tomb;
	unsigned char mc_qrv;
	unsigned char mc_gq_running;
	unsigned char mc_ifc_count;
	unsigned char mc_dad_count;
	long unsigned int mc_v1_seen;
	long unsigned int mc_qi;
	long unsigned int mc_qri;
	long unsigned int mc_maxdelay;
	struct delayed_work mc_gq_work;
	struct delayed_work mc_ifc_work;
	struct delayed_work mc_dad_work;
	struct delayed_work mc_query_work;
	struct delayed_work mc_report_work;
	struct sk_buff_head___113 mc_query_queue;
	struct sk_buff_head___113 mc_report_queue;
	spinlock_t mc_query_lock;
	spinlock_t mc_report_lock;
	struct mutex mc_lock;
	struct ifacaddr6___36 *ac_list;
	rwlock_t lock;
	refcount_t refcnt;
	__u32 if_flags;
	int dead;
	u32 desync_factor;
	struct list_head tempaddr_list;
	struct in6_addr token;
	struct neigh_parms___98 *nd_parms;
	struct ipv6_devconf cnf;
	struct ipv6_devstat stats;
	struct timer_list rs_timer;
	__s32 rs_interval;
	__u8 rs_probes;
	long unsigned int tstamp;
	struct callback_head rcu;
	unsigned int ra_mtu;
};

struct tcf_proto___104;

struct tcf_block___104;

struct mini_Qdisc___104 {
	struct tcf_proto___104 *filter_list;
	struct tcf_block___104 *block;
	struct gnet_stats_basic_cpu *cpu_bstats;
	struct gnet_stats_queue *cpu_qstats;
	struct callback_head rcu;
};

struct rtnl_link_ops___105 {
	struct list_head list;
	const char *kind;
	size_t priv_size;
	struct net_device___113 * (*alloc)(struct nlattr **, const char *, unsigned char, unsigned int, unsigned int);
	void (*setup)(struct net_device___113 *);
	bool netns_refund;
	unsigned int maxtype;
	const struct nla_policy *policy;
	int (*validate)(struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*newlink)(struct net___118 *, struct net_device___113 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	int (*changelink)(struct net_device___113 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	void (*dellink)(struct net_device___113 *, struct list_head *);
	size_t (*get_size)(const struct net_device___113 *);
	int (*fill_info)(struct sk_buff___114 *, const struct net_device___113 *);
	size_t (*get_xstats_size)(const struct net_device___113 *);
	int (*fill_xstats)(struct sk_buff___114 *, const struct net_device___113 *);
	unsigned int (*get_num_tx_queues)();
	unsigned int (*get_num_rx_queues)();
	unsigned int slave_maxtype;
	const struct nla_policy *slave_policy;
	int (*slave_changelink)(struct net_device___113 *, struct net_device___113 *, struct nlattr **, struct nlattr **, struct netlink_ext_ack *);
	size_t (*get_slave_size)(const struct net_device___113 *, const struct net_device___113 *);
	int (*fill_slave_info)(struct sk_buff___114 *, const struct net_device___113 *, const struct net_device___113 *);
	struct net___118 * (*get_link_net)(const struct net_device___113 *);
	size_t (*get_linkxstats_size)(const struct net_device___113 *, int);
	int (*fill_linkxstats)(struct sk_buff___114 *, const struct net_device___113 *, int *, int);
};

struct block_device_operations___192;

struct gendisk___195 {
	int major;
	int first_minor;
	int minors;
	char disk_name[32];
	short unsigned int events;
	short unsigned int event_flags;
	struct xarray part_tbl;
	struct block_device___195 *part0;
	const struct block_device_operations___192 *fops;
	struct request_queue___192 *queue;
	void *private_data;
	int flags;
	long unsigned int state;
	struct mutex open_mutex;
	unsigned int open_partitions;
	struct backing_dev_info___178 *bdi;
	struct kobject___292 *slave_dir;
	struct list_head slave_bdevs;
	struct timer_rand_state *random;
	atomic_t sync_io;
	struct disk_events *ev;
	struct kobject___292 integrity_kobj;
	struct cdrom_device_info *cdi;
	int node_id;
	struct badblocks *bb;
	struct lockdep_map lockdep_map;
	u64 diskseq;
};

struct bio_integrity_payload___192 {
	struct bio___192 *bip_bio;
	struct bvec_iter bip_iter;
	short unsigned int bip_vcnt;
	short unsigned int bip_max_vcnt;
	short unsigned int bip_flags;
	struct bvec_iter bio_iter;
	struct work_struct bip_work;
	struct bio_vec___221 *bip_vec;
	struct bio_vec___221 bip_inline_vecs[0];
};

struct blkcg___180;

struct blkg_policy_data___180;

struct blkcg_gq___180 {
	struct request_queue___192 *q;
	struct list_head q_node;
	struct hlist_node blkcg_node;
	struct blkcg___180 *blkcg;
	struct blkcg_gq___180 *parent;
	struct percpu_ref refcnt;
	bool online;
	struct blkg_iostat_set *iostat_cpu;
	struct blkg_iostat_set iostat;
	struct blkg_policy_data___180 *pd[6];
	spinlock_t async_bio_lock;
	struct bio_list___192 async_bios;
	struct work_struct async_bio_work;
	atomic_t use_delay;
	atomic64_t delay_nsec;
	atomic64_t delay_start;
	u64 last_delay;
	int last_use;
	struct callback_head callback_head;
};

typedef void integrity_prepare_fn___192(struct request___192 *);

typedef void integrity_complete_fn___192(struct request___192 *, unsigned int);

struct blk_integrity_profile___192 {
	integrity_processing_fn *generate_fn;
	integrity_processing_fn *verify_fn;
	integrity_prepare_fn___192 *prepare_fn;
	integrity_complete_fn___192 *complete_fn;
	const char *name;
};

struct block_device_operations___192 {
	blk_qc_t (*submit_bio)(struct bio___192 *);
	int (*open)(struct block_device___195 *, fmode_t);
	void (*release)(struct gendisk___195 *, fmode_t);
	int (*rw_page)(struct block_device___195 *, sector_t, struct page___309 *, unsigned int);
	int (*ioctl)(struct block_device___195 *, fmode_t, unsigned int, long unsigned int);
	int (*compat_ioctl)(struct block_device___195 *, fmode_t, unsigned int, long unsigned int);
	unsigned int (*check_events)(struct gendisk___195 *, unsigned int);
	void (*unlock_native_capacity)(struct gendisk___195 *);
	int (*getgeo)(struct block_device___195 *, struct hd_geometry *);
	int (*set_read_only)(struct block_device___195 *, bool);
	void (*swap_slot_free_notify)(struct block_device___195 *, long unsigned int);
	int (*report_zones)(struct gendisk___195 *, sector_t, unsigned int, report_zones_cb, void *);
	char * (*devnode)(struct gendisk___195 *, umode_t *);
	struct module___288 *owner;
	const struct pr_ops *pr_ops;
	int (*alternative_gpt_sector)(struct gendisk___195 *, sector_t *);
};

typedef void rq_end_io_fn___192(struct request___192 *, blk_status_t);

struct request___192 {
	struct request_queue___192 *q;
	struct blk_mq_ctx *mq_ctx;
	struct blk_mq_hw_ctx___187 *mq_hctx;
	unsigned int cmd_flags;
	req_flags_t rq_flags;
	int tag;
	int internal_tag;
	unsigned int __data_len;
	sector_t __sector;
	struct bio___192 *bio;
	struct bio___192 *biotail;
	struct list_head queuelist;
	union {
		struct hlist_node hash;
		struct llist_node ipi_list;
	};
	union {
		struct rb_node rb_node;
		struct bio_vec___221 special_vec;
		void *completion_data;
		int error_count;
	};
	union {
		struct {
			struct io_cq___192 *icq;
			void *priv[2];
		} elv;
		struct {
			unsigned int seq;
			struct list_head list;
			rq_end_io_fn___192 *saved_end_io;
		} flush;
	};
	struct gendisk___195 *rq_disk;
	struct block_device___195 *part;
	u64 alloc_time_ns;
	u64 start_time_ns;
	u64 io_start_time_ns;
	short unsigned int wbt_flags;
	short unsigned int stats_sectors;
	short unsigned int nr_phys_segments;
	short unsigned int nr_integrity_segments;
	struct bio_crypt_ctx *crypt_ctx;
	struct blk_ksm_keyslot *crypt_keyslot;
	short unsigned int write_hint;
	short unsigned int ioprio;
	enum mq_rq_state state;
	refcount_t ref;
	unsigned int timeout;
	long unsigned int deadline;
	union {
		struct __call_single_data csd;
		u64 fifo_time;
	};
	rq_end_io_fn___192 *end_io;
	void *end_io_data;
};

struct blk_mq_hw_ctx___187 {
	struct {
		spinlock_t lock;
		struct list_head dispatch;
		long unsigned int state;
		long: 64;
		long: 64;
		long: 64;
		long: 64;
	};
	struct delayed_work run_work;
	cpumask_var_t cpumask;
	int next_cpu;
	int next_cpu_batch;
	long unsigned int flags;
	void *sched_data;
	struct request_queue___192 *queue;
	struct blk_flush_queue *fq;
	void *driver_data;
	struct sbitmap ctx_map;
	struct blk_mq_ctx *dispatch_from;
	unsigned int dispatch_busy;
	short unsigned int type;
	short unsigned int nr_ctx;
	struct blk_mq_ctx **ctxs;
	spinlock_t dispatch_wait_lock;
	wait_queue_entry_t dispatch_wait;
	atomic_t wait_index;
	struct blk_mq_tags *tags;
	struct blk_mq_tags *sched_tags;
	long unsigned int queued;
	long unsigned int run;
	long unsigned int dispatched[7];
	unsigned int numa_node;
	unsigned int queue_num;
	atomic_t nr_active;
	struct hlist_node cpuhp_online;
	struct hlist_node cpuhp_dead;
	struct kobject___292 kobj;
	long unsigned int poll_considered;
	long unsigned int poll_invoked;
	long unsigned int poll_success;
	struct dentry___304 *debugfs_dir;
	struct dentry___304 *sched_debugfs_dir;
	struct list_head hctx_list;
	struct srcu_struct srcu[0];
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
};

struct elevator_type___192;

struct elevator_mq_ops___192 {
	int (*init_sched)(struct request_queue___192 *, struct elevator_type___192 *);
	void (*exit_sched)(struct elevator_queue___192 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___187 *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___187 *, unsigned int);
	void (*depth_updated)(struct blk_mq_hw_ctx___187 *);
	bool (*allow_merge)(struct request_queue___192 *, struct request___192 *, struct bio___192 *);
	bool (*bio_merge)(struct request_queue___192 *, struct bio___192 *, unsigned int);
	int (*request_merge)(struct request_queue___192 *, struct request___192 **, struct bio___192 *);
	void (*request_merged)(struct request_queue___192 *, struct request___192 *, enum elv_merge);
	void (*requests_merged)(struct request_queue___192 *, struct request___192 *, struct request___192 *);
	void (*limit_depth)(unsigned int, struct blk_mq_alloc_data *);
	void (*prepare_request)(struct request___192 *);
	void (*finish_request)(struct request___192 *);
	void (*insert_requests)(struct blk_mq_hw_ctx___187 *, struct list_head *, bool);
	struct request___192 * (*dispatch_request)(struct blk_mq_hw_ctx___187 *);
	bool (*has_work)(struct blk_mq_hw_ctx___187 *);
	void (*completed_request)(struct request___192 *, u64);
	void (*requeue_request)(struct request___192 *);
	struct request___192 * (*former_request)(struct request_queue___192 *, struct request___192 *);
	struct request___192 * (*next_request)(struct request_queue___192 *, struct request___192 *);
	void (*init_icq)(struct io_cq___192 *);
	void (*exit_icq)(struct io_cq___192 *);
};

struct elv_fs_entry___192;

struct elevator_type___192 {
	struct kmem_cache *icq_cache;
	struct elevator_mq_ops___192 ops;
	size_t icq_size;
	size_t icq_align;
	struct elv_fs_entry___192 *elevator_attrs;
	const char *elevator_name;
	const char *elevator_alias;
	const unsigned int elevator_features;
	struct module___288 *elevator_owner;
	const struct blk_mq_debugfs_attr *queue_debugfs_attrs;
	const struct blk_mq_debugfs_attr *hctx_debugfs_attrs;
	char icq_cache_name[22];
	struct list_head list;
};

struct elevator_queue___192 {
	struct elevator_type___192 *type;
	void *elevator_data;
	struct kobject___292 kobj;
	struct mutex sysfs_lock;
	unsigned int registered: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct hlist_head hash[64];
};

struct elv_fs_entry___192 {
	struct attribute attr;
	ssize_t (*show)(struct elevator_queue___192 *, char *);
	ssize_t (*store)(struct elevator_queue___192 *, const char *, size_t);
};

struct blk_mq_queue_data___187;

struct blk_mq_ops___187 {
	blk_status_t (*queue_rq)(struct blk_mq_hw_ctx___187 *, const struct blk_mq_queue_data___187 *);
	void (*commit_rqs)(struct blk_mq_hw_ctx___187 *);
	int (*get_budget)(struct request_queue___192 *);
	void (*put_budget)(struct request_queue___192 *, int);
	void (*set_rq_budget_token)(struct request___192 *, int);
	int (*get_rq_budget_token)(struct request___192 *);
	enum blk_eh_timer_return (*timeout)(struct request___192 *, bool);
	int (*poll)(struct blk_mq_hw_ctx___187 *);
	void (*complete)(struct request___192 *);
	int (*init_hctx)(struct blk_mq_hw_ctx___187 *, void *, unsigned int);
	void (*exit_hctx)(struct blk_mq_hw_ctx___187 *, unsigned int);
	int (*init_request)(struct blk_mq_tag_set___187 *, struct request___192 *, unsigned int, unsigned int);
	void (*exit_request)(struct blk_mq_tag_set___187 *, struct request___192 *, unsigned int);
	void (*initialize_rq_fn)(struct request___192 *);
	void (*cleanup_rq)(struct request___192 *);
	bool (*busy)(struct request_queue___192 *);
	int (*map_queues)(struct blk_mq_tag_set___187 *);
	void (*show_rq)(struct seq_file___279 *, struct request___192 *);
};

struct blk_mq_tag_set___187 {
	struct blk_mq_queue_map map[3];
	unsigned int nr_maps;
	const struct blk_mq_ops___187 *ops;
	unsigned int nr_hw_queues;
	unsigned int queue_depth;
	unsigned int reserved_tags;
	unsigned int cmd_size;
	int numa_node;
	unsigned int timeout;
	unsigned int flags;
	void *driver_data;
	atomic_t active_queues_shared_sbitmap;
	struct sbitmap_queue __bitmap_tags;
	struct sbitmap_queue __breserved_tags;
	struct blk_mq_tags **tags;
	struct mutex tag_list_lock;
	struct list_head tag_list;
};

struct blk_mq_queue_data___187 {
	struct request___192 *rq;
	bool last;
};

struct blkcg_policy_data___180;

struct blkcg___180 {
	struct cgroup_subsys_state___231 css;
	spinlock_t lock;
	refcount_t online_pin;
	struct xarray blkg_tree;
	struct blkcg_gq___180 *blkg_hint;
	struct hlist_head blkg_list;
	struct blkcg_policy_data___180 *cpd[6];
	struct list_head all_blkcgs_node;
	char fc_app_id[129];
	struct list_head cgwb_list;
};

struct blkcg_policy_data___180 {
	struct blkcg___180 *blkcg;
	int plid;
};

struct blkg_policy_data___180 {
	struct blkcg_gq___180 *blkg;
	int plid;
};

struct mem_cgroup_reclaim_iter___166 {
	struct mem_cgroup___166 *position;
	unsigned int generation;
};

struct mem_cgroup_per_node___166 {
	struct lruvec___174 lruvec;
	struct lruvec_stats_percpu *lruvec_stats_percpu;
	struct lruvec_stats lruvec_stats;
	long unsigned int lru_zone_size[25];
	struct mem_cgroup_reclaim_iter___166 iter;
	struct shrinker_info *shrinker_info;
	struct rb_node tree_node;
	long unsigned int usage_in_excess;
	bool on_tree;
	struct mem_cgroup___166 *memcg;
};

struct obj_cgroup___166 {
	struct percpu_ref refcnt;
	struct mem_cgroup___166 *memcg;
	atomic_t nr_charged_bytes;
	union {
		struct list_head list;
		struct callback_head rcu;
	};
};

struct gnet_dump___104 {
	spinlock_t *lock;
	struct sk_buff___114 *skb;
	struct nlattr *tail;
	int compat_tc_stats;
	int compat_xstats;
	int padattr;
	void *xstats;
	int xstats_len;
	struct tc_stats tc_stats;
};

struct Qdisc_class_ops___104;

struct Qdisc_ops___104 {
	struct Qdisc_ops___104 *next;
	const struct Qdisc_class_ops___104 *cl_ops;
	char id[16];
	int priv_size;
	unsigned int static_flags;
	int (*enqueue)(struct sk_buff___114 *, struct Qdisc___104 *, struct sk_buff___114 **);
	struct sk_buff___114 * (*dequeue)(struct Qdisc___104 *);
	struct sk_buff___114 * (*peek)(struct Qdisc___104 *);
	int (*init)(struct Qdisc___104 *, struct nlattr *, struct netlink_ext_ack *);
	void (*reset)(struct Qdisc___104 *);
	void (*destroy)(struct Qdisc___104 *);
	int (*change)(struct Qdisc___104 *, struct nlattr *, struct netlink_ext_ack *);
	void (*attach)(struct Qdisc___104 *);
	int (*change_tx_queue_len)(struct Qdisc___104 *, unsigned int);
	void (*change_real_num_tx)(struct Qdisc___104 *, unsigned int);
	int (*dump)(struct Qdisc___104 *, struct sk_buff___114 *);
	int (*dump_stats)(struct Qdisc___104 *, struct gnet_dump___104 *);
	void (*ingress_block_set)(struct Qdisc___104 *, u32);
	void (*egress_block_set)(struct Qdisc___104 *, u32);
	u32 (*ingress_block_get)(struct Qdisc___104 *);
	u32 (*egress_block_get)(struct Qdisc___104 *);
	struct module___288 *owner;
};

struct Qdisc_class_ops___104 {
	unsigned int flags;
	struct netdev_queue___113 * (*select_queue)(struct Qdisc___104 *, struct tcmsg *);
	int (*graft)(struct Qdisc___104 *, long unsigned int, struct Qdisc___104 *, struct Qdisc___104 **, struct netlink_ext_ack *);
	struct Qdisc___104 * (*leaf)(struct Qdisc___104 *, long unsigned int);
	void (*qlen_notify)(struct Qdisc___104 *, long unsigned int);
	long unsigned int (*find)(struct Qdisc___104 *, u32);
	int (*change)(struct Qdisc___104 *, u32, u32, struct nlattr **, long unsigned int *, struct netlink_ext_ack *);
	int (*delete)(struct Qdisc___104 *, long unsigned int, struct netlink_ext_ack *);
	void (*walk)(struct Qdisc___104 *, struct qdisc_walker *);
	struct tcf_block___104 * (*tcf_block)(struct Qdisc___104 *, long unsigned int, struct netlink_ext_ack *);
	long unsigned int (*bind_tcf)(struct Qdisc___104 *, long unsigned int, u32);
	void (*unbind_tcf)(struct Qdisc___104 *, long unsigned int);
	int (*dump)(struct Qdisc___104 *, long unsigned int, struct sk_buff___114 *, struct tcmsg *);
	int (*dump_stats)(struct Qdisc___104 *, long unsigned int, struct gnet_dump___104 *);
};

struct tcf_chain___104;

struct tcf_block___104 {
	struct mutex lock;
	struct list_head chain_list;
	u32 index;
	u32 classid;
	refcount_t refcnt;
	struct net___118 *net;
	struct Qdisc___104 *q;
	struct rw_semaphore cb_lock;
	struct flow_block flow_block;
	struct list_head owner_list;
	bool keep_dst;
	atomic_t offloadcnt;
	unsigned int nooffloaddevcnt;
	unsigned int lockeddevcnt;
	struct {
		struct tcf_chain___104 *chain;
		struct list_head filter_chain_list;
	} chain0;
	struct callback_head rcu;
	struct hlist_head proto_destroy_ht[128];
	struct mutex proto_destroy_lock;
};

struct tcf_result___104;

struct tcf_proto_ops___104;

struct tcf_proto___104 {
	struct tcf_proto___104 *next;
	void *root;
	int (*classify)(struct sk_buff___114 *, const struct tcf_proto___104 *, struct tcf_result___104 *);
	__be16 protocol;
	u32 prio;
	void *data;
	const struct tcf_proto_ops___104 *ops;
	struct tcf_chain___104 *chain;
	spinlock_t lock;
	bool deleting;
	refcount_t refcnt;
	struct callback_head rcu;
	struct hlist_node destroy_ht_node;
};

struct tcf_result___104 {
	union {
		struct {
			long unsigned int class;
			u32 classid;
		};
		const struct tcf_proto___104 *goto_tp;
		struct {
			bool ingress;
			struct gnet_stats_queue *qstats;
		};
	};
};

struct tcf_proto_ops___104 {
	struct list_head head;
	char kind[16];
	int (*classify)(struct sk_buff___114 *, const struct tcf_proto___104 *, struct tcf_result___104 *);
	int (*init)(struct tcf_proto___104 *);
	void (*destroy)(struct tcf_proto___104 *, bool, struct netlink_ext_ack *);
	void * (*get)(struct tcf_proto___104 *, u32);
	void (*put)(struct tcf_proto___104 *, void *);
	int (*change)(struct net___118 *, struct sk_buff___114 *, struct tcf_proto___104 *, long unsigned int, u32, struct nlattr **, void **, u32, struct netlink_ext_ack *);
	int (*delete)(struct tcf_proto___104 *, void *, bool *, bool, struct netlink_ext_ack *);
	bool (*delete_empty)(struct tcf_proto___104 *);
	void (*walk)(struct tcf_proto___104 *, struct tcf_walker *, bool);
	int (*reoffload)(struct tcf_proto___104 *, bool, flow_setup_cb_t *, void *, struct netlink_ext_ack *);
	void (*hw_add)(struct tcf_proto___104 *, void *);
	void (*hw_del)(struct tcf_proto___104 *, void *);
	void (*bind_class)(void *, u32, long unsigned int, void *, long unsigned int);
	void * (*tmplt_create)(struct net___118 *, struct tcf_chain___104 *, struct nlattr **, struct netlink_ext_ack *);
	void (*tmplt_destroy)(void *);
	int (*dump)(struct net___118 *, struct tcf_proto___104 *, void *, struct sk_buff___114 *, struct tcmsg *, bool);
	int (*terse_dump)(struct net___118 *, struct tcf_proto___104 *, void *, struct sk_buff___114 *, struct tcmsg *, bool);
	int (*tmplt_dump)(struct sk_buff___114 *, struct net___118 *, void *);
	struct module___288 *owner;
	int flags;
};

struct tcf_chain___104 {
	struct mutex filter_chain_lock;
	struct tcf_proto___104 *filter_chain;
	struct list_head list;
	struct tcf_block___104 *block;
	u32 index;
	unsigned int refcnt;
	unsigned int action_refcnt;
	bool explicitly_created;
	bool flushing;
	const struct tcf_proto_ops___104 *tmplt_ops;
	void *tmplt_priv;
	struct callback_head rcu;
};

struct sk_filter___97 {
	refcount_t refcnt;
	struct callback_head rcu;
	struct bpf_prog___104 *prog;
};

struct pneigh_entry___98;

struct neigh_hash_table___98;

struct neigh_table___98 {
	int family;
	unsigned int entry_size;
	unsigned int key_len;
	__be16 protocol;
	__u32 (*hash)(const void *, const struct net_device___113 *, __u32 *);
	bool (*key_eq)(const struct neighbour___98 *, const void *);
	int (*constructor)(struct neighbour___98 *);
	int (*pconstructor)(struct pneigh_entry___98 *);
	void (*pdestructor)(struct pneigh_entry___98 *);
	void (*proxy_redo)(struct sk_buff___114 *);
	int (*is_multicast)(const void *);
	bool (*allow_add)(const struct net_device___113 *, struct netlink_ext_ack *);
	char *id;
	struct neigh_parms___98 parms;
	struct list_head parms_list;
	int gc_interval;
	int gc_thresh1;
	int gc_thresh2;
	int gc_thresh3;
	long unsigned int last_flush;
	struct delayed_work gc_work;
	struct timer_list proxy_timer;
	struct sk_buff_head___113 proxy_queue;
	atomic_t entries;
	atomic_t gc_entries;
	struct list_head gc_list;
	rwlock_t lock;
	long unsigned int last_rand;
	struct neigh_statistics *stats;
	struct neigh_hash_table___98 *nht;
	struct pneigh_entry___98 **phash_buckets;
};

struct neigh_ops___98 {
	int family;
	void (*solicit)(struct neighbour___98 *, struct sk_buff___114 *);
	void (*error_report)(struct neighbour___98 *, struct sk_buff___114 *);
	int (*output)(struct neighbour___98 *, struct sk_buff___114 *);
	int (*connected_output)(struct neighbour___98 *, struct sk_buff___114 *);
};

struct pneigh_entry___98 {
	struct pneigh_entry___98 *next;
	possible_net_t___113 net;
	struct net_device___113 *dev;
	u8 flags;
	u8 protocol;
	u8 key[0];
};

struct neigh_hash_table___98 {
	struct neighbour___98 **hash_buckets;
	unsigned int hash_shift;
	__u32 hash_rnd[4];
	struct callback_head rcu;
};

struct lwtunnel_state___72 {
	__u16 type;
	__u16 flags;
	__u16 headroom;
	atomic_t refcnt;
	int (*orig_output)(struct net___118 *, struct sock___97 *, struct sk_buff___114 *);
	int (*orig_input)(struct sk_buff___114 *);
	struct callback_head rcu;
	__u8 data[0];
};

struct fib_rule___97 {
	struct list_head list;
	int iifindex;
	int oifindex;
	u32 mark;
	u32 mark_mask;
	u32 flags;
	u32 table;
	u8 action;
	u8 l3mdev;
	u8 proto;
	u8 ip_proto;
	u32 target;
	__be64 tun_id;
	struct fib_rule___97 *ctarget;
	struct net___118 *fr_net;
	refcount_t refcnt;
	u32 pref;
	int suppress_ifgroup;
	int suppress_prefixlen;
	char iifname[16];
	char oifname[16];
	struct fib_kuid_range uid_range;
	struct fib_rule_port_range sport_range;
	struct fib_rule_port_range dport_range;
	struct callback_head rcu;
};

struct fib_lookup_arg___97 {
	void *lookup_ptr;
	const void *lookup_data;
	void *result;
	struct fib_rule___97 *rule;
	u32 table;
	int flags;
};

struct request_sock_ops___82;

struct timewait_sock_ops___80;

struct proto___97 {
	void (*close)(struct sock___97 *, long int);
	int (*pre_connect)(struct sock___97 *, struct sockaddr *, int);
	int (*connect)(struct sock___97 *, struct sockaddr *, int);
	int (*disconnect)(struct sock___97 *, int);
	struct sock___97 * (*accept)(struct sock___97 *, int, int *, bool);
	int (*ioctl)(struct sock___97 *, int, long unsigned int);
	int (*init)(struct sock___97 *);
	void (*destroy)(struct sock___97 *);
	void (*shutdown)(struct sock___97 *, int);
	int (*setsockopt)(struct sock___97 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___97 *, int, int, char *, int *);
	void (*keepalive)(struct sock___97 *, int);
	int (*compat_ioctl)(struct sock___97 *, unsigned int, long unsigned int);
	int (*sendmsg)(struct sock___97 *, struct msghdr___100 *, size_t);
	int (*recvmsg)(struct sock___97 *, struct msghdr___100 *, size_t, int, int, int *);
	int (*sendpage)(struct sock___97 *, struct page___309 *, int, size_t, int);
	int (*bind)(struct sock___97 *, struct sockaddr *, int);
	int (*bind_add)(struct sock___97 *, struct sockaddr *, int);
	int (*backlog_rcv)(struct sock___97 *, struct sk_buff___114 *);
	bool (*bpf_bypass_getsockopt)(int, int);
	void (*release_cb)(struct sock___97 *);
	int (*hash)(struct sock___97 *);
	void (*unhash)(struct sock___97 *);
	void (*rehash)(struct sock___97 *);
	int (*get_port)(struct sock___97 *, short unsigned int);
	int (*psock_update_sk_prot)(struct sock___97 *, struct sk_psock *, bool);
	unsigned int inuse_idx;
	bool (*stream_memory_free)(const struct sock___97 *, int);
	bool (*sock_is_readable)(struct sock___97 *);
	void (*enter_memory_pressure)(struct sock___97 *);
	void (*leave_memory_pressure)(struct sock___97 *);
	atomic_long_t *memory_allocated;
	struct percpu_counter *sockets_allocated;
	long unsigned int *memory_pressure;
	long int *sysctl_mem;
	int *sysctl_wmem;
	int *sysctl_rmem;
	u32 sysctl_wmem_offset;
	u32 sysctl_rmem_offset;
	int max_header;
	bool no_autobind;
	struct kmem_cache *slab;
	unsigned int obj_size;
	slab_flags_t slab_flags;
	unsigned int useroffset;
	unsigned int usersize;
	unsigned int *orphan_count;
	struct request_sock_ops___82 *rsk_prot;
	struct timewait_sock_ops___80 *twsk_prot;
	union {
		struct inet_hashinfo *hashinfo;
		struct udp_table *udp_table;
		struct raw_hashinfo *raw_hash;
		struct smc_hashinfo *smc_hash;
	} h;
	struct module___288 *owner;
	char name[32];
	struct list_head node;
	int (*diag_destroy)(struct sock___97 *, int);
};

struct sock_reuseport___42 {
	struct callback_head rcu;
	u16 max_socks;
	u16 num_socks;
	u16 num_closed_socks;
	unsigned int synq_overflow_ts;
	unsigned int reuseport_id;
	unsigned int bind_inany: 1;
	unsigned int has_conns: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	struct bpf_prog___104 *prog;
	struct sock___97 *socks[0];
};

struct request_sock___83;

struct request_sock_ops___82 {
	int family;
	unsigned int obj_size;
	struct kmem_cache *slab;
	char *slab_name;
	int (*rtx_syn_ack)(const struct sock___97 *, struct request_sock___83 *);
	void (*send_ack)(const struct sock___97 *, struct sk_buff___114 *, struct request_sock___83 *);
	void (*send_reset)(const struct sock___97 *, struct sk_buff___114 *);
	void (*destructor)(struct request_sock___83 *);
	void (*syn_ack_timeout)(const struct request_sock___83 *);
};

struct timewait_sock_ops___80 {
	struct kmem_cache *twsk_slab;
	char *twsk_slab_name;
	unsigned int twsk_obj_size;
	int (*twsk_unique)(struct sock___97 *, struct sock___97 *, void *);
	void (*twsk_destructor)(struct sock___97 *);
};

struct request_sock___83 {
	struct sock_common___97 __req_common;
	struct request_sock___83 *dl_next;
	u16 mss;
	u8 num_retrans;
	u8 syncookie: 1;
	u8 num_timeout: 7;
	long: 25;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 ts_recent;
	struct timer_list rsk_timer;
	const struct request_sock_ops___82 *rsk_ops;
	struct sock___97 *sk;
	struct saved_syn *saved_syn;
	u32 secid;
	u32 peer_secid;
};

struct fastopen_queue___16 {
	struct request_sock___83 *rskq_rst_head;
	struct request_sock___83 *rskq_rst_tail;
	spinlock_t lock;
	int qlen;
	int max_qlen;
	struct tcp_fastopen_context *ctx;
};

struct request_sock_queue___16 {
	spinlock_t rskq_lock;
	u8 rskq_defer_accept;
	u32 synflood_warned;
	atomic_t qlen;
	atomic_t young;
	struct request_sock___83 *rskq_accept_head;
	struct request_sock___83 *rskq_accept_tail;
	struct fastopen_queue___16 fastopenq;
};

struct inet_cork___29 {
	unsigned int flags;
	__be32 addr;
	struct ip_options *opt;
	unsigned int fragsize;
	int length;
	struct dst_entry___97 *dst;
	u8 tx_flags;
	__u8 ttl;
	__s16 tos;
	char priority;
	__u16 gso_size;
	u64 transmit_time;
	u32 mark;
};

struct inet_cork_full___29 {
	struct inet_cork___29 base;
	struct flowi fl;
};

struct ipv6_pinfo___28;

struct inet_sock___29 {
	struct sock___97 sk;
	struct ipv6_pinfo___28 *pinet6;
	__be32 inet_saddr;
	__s16 uc_ttl;
	__u16 cmsg_flags;
	struct ip_options_rcu *inet_opt;
	__be16 inet_sport;
	__u16 inet_id;
	__u8 tos;
	__u8 min_ttl;
	__u8 mc_ttl;
	__u8 pmtudisc;
	__u8 recverr: 1;
	__u8 is_icsk: 1;
	__u8 freebind: 1;
	__u8 hdrincl: 1;
	__u8 mc_loop: 1;
	__u8 transparent: 1;
	__u8 mc_all: 1;
	__u8 nodefrag: 1;
	__u8 bind_address_no_port: 1;
	__u8 recverr_rfc4884: 1;
	__u8 defer_connect: 1;
	long: 15;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 rcv_tos;
	__u8 convert_csum;
	int uc_index;
	int mc_index;
	__be32 mc_addr;
	struct ip_mc_socklist *mc_list;
	struct inet_cork_full___29 cork;
};

struct ipv6_fl_socklist___28;

struct ipv6_pinfo___28 {
	struct in6_addr saddr;
	struct in6_pktinfo sticky_pktinfo;
	const struct in6_addr *daddr_cache;
	const struct in6_addr *saddr_cache;
	__be32 flow_label;
	__u32 frag_size;
	__u16 __unused_1: 7;
	__s16 hop_limit: 9;
	__u16 mc_loop: 1;
	__u16 __unused_2: 6;
	__s16 mcast_hops: 9;
	long: 23;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	int ucast_oif;
	int mcast_oif;
	union {
		struct {
			__u16 srcrt: 1;
			__u16 osrcrt: 1;
			__u16 rxinfo: 1;
			__u16 rxoinfo: 1;
			__u16 rxhlim: 1;
			__u16 rxohlim: 1;
			__u16 hopopts: 1;
			__u16 ohopopts: 1;
			__u16 dstopts: 1;
			__u16 odstopts: 1;
			__u16 rxflow: 1;
			__u16 rxtclass: 1;
			__u16 rxpmtu: 1;
			__u16 rxorigdstaddr: 1;
			__u16 recvfragsize: 1;
		} bits;
		__u16 all;
	} rxopt;
	__u16 recverr: 1;
	__u16 sndflow: 1;
	__u16 repflow: 1;
	__u16 pmtudisc: 3;
	__u16 padding: 1;
	__u16 srcprefs: 3;
	__u16 dontfrag: 1;
	__u16 autoflowlabel: 1;
	__u16 autoflowlabel_set: 1;
	__u16 mc_all: 1;
	__u16 recverr_rfc4884: 1;
	__u16 rtalert_isolate: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 min_hopcount;
	__u8 tclass;
	__be32 rcv_flowinfo;
	__u32 dst_cookie;
	struct ipv6_mc_socklist *ipv6_mc_list;
	struct ipv6_ac_socklist *ipv6_ac_list;
	struct ipv6_fl_socklist___28 *ipv6_fl_list;
	struct ipv6_txoptions *opt;
	struct sk_buff___114 *pktoptions;
	struct sk_buff___114 *rxpmtu;
	struct inet6_cork cork;
};

struct inet_connection_sock_af_ops___16 {
	int (*queue_xmit)(struct sock___97 *, struct sk_buff___114 *, struct flowi *);
	void (*send_check)(struct sock___97 *, struct sk_buff___114 *);
	int (*rebuild_header)(struct sock___97 *);
	void (*sk_rx_dst_set)(struct sock___97 *, const struct sk_buff___114 *);
	int (*conn_request)(struct sock___97 *, struct sk_buff___114 *);
	struct sock___97 * (*syn_recv_sock)(const struct sock___97 *, struct sk_buff___114 *, struct request_sock___83 *, struct dst_entry___97 *, struct request_sock___83 *, bool *);
	u16 net_header_len;
	u16 net_frag_header_len;
	u16 sockaddr_len;
	int (*setsockopt)(struct sock___97 *, int, int, sockptr_t, unsigned int);
	int (*getsockopt)(struct sock___97 *, int, int, char *, int *);
	void (*addr2sockaddr)(struct sock___97 *, struct sockaddr *);
	void (*mtu_reduced)(struct sock___97 *);
};

struct inet_bind_bucket___16;

struct tcp_ulp_ops___16;

struct inet_connection_sock___16 {
	struct inet_sock___29 icsk_inet;
	struct request_sock_queue___16 icsk_accept_queue;
	struct inet_bind_bucket___16 *icsk_bind_hash;
	long unsigned int icsk_timeout;
	struct timer_list icsk_retransmit_timer;
	struct timer_list icsk_delack_timer;
	__u32 icsk_rto;
	__u32 icsk_rto_min;
	__u32 icsk_delack_max;
	__u32 icsk_pmtu_cookie;
	const struct tcp_congestion_ops___40 *icsk_ca_ops;
	const struct inet_connection_sock_af_ops___16 *icsk_af_ops;
	const struct tcp_ulp_ops___16 *icsk_ulp_ops;
	void *icsk_ulp_data;
	void (*icsk_clean_acked)(struct sock___97 *, u32);
	struct hlist_node icsk_listen_portaddr_node;
	unsigned int (*icsk_sync_mss)(struct sock___97 *, u32);
	__u8 icsk_ca_state: 5;
	__u8 icsk_ca_initialized: 1;
	__u8 icsk_ca_setsockopt: 1;
	__u8 icsk_ca_dst_locked: 1;
	long: 7;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	__u8 icsk_retransmits;
	__u8 icsk_pending;
	__u8 icsk_backoff;
	__u8 icsk_syn_retries;
	__u8 icsk_probes_out;
	__u16 icsk_ext_hdr_len;
	struct {
		__u8 pending;
		__u8 quick;
		__u8 pingpong;
		__u8 retry;
		__u32 ato;
		long unsigned int timeout;
		__u32 lrcvtime;
		__u16 last_seg_size;
		__u16 rcv_mss;
	} icsk_ack;
	struct {
		int search_high;
		int search_low;
		u32 probe_size: 31;
		u32 enabled: 1;
		long: 31;
		long: 64;
		u32 probe_timestamp;
	} icsk_mtup;
	u32 icsk_probes_tstamp;
	u32 icsk_user_timeout;
	u64 icsk_ca_priv[13];
};

struct inet_bind_bucket___16 {
	possible_net_t___113 ib_net;
	int l3mdev;
	short unsigned int port;
	signed char fastreuse;
	signed char fastreuseport;
	kuid_t fastuid;
	struct in6_addr fast_v6_rcv_saddr;
	__be32 fast_rcv_saddr;
	short unsigned int fast_sk_family;
	bool fast_ipv6_only;
	struct hlist_node node;
	struct hlist_head owners;
};

struct tcp_ulp_ops___16 {
	struct list_head list;
	int (*init)(struct sock___97 *);
	void (*update)(struct sock___97 *, struct proto___97 *, void (*)(struct sock___97 *));
	void (*release)(struct sock___97 *);
	int (*get_info)(const struct sock___97 *, struct sk_buff___114 *);
	size_t (*get_info_size)(const struct sock___97 *);
	void (*clone)(const struct request_sock___83 *, struct sock___97 *, const gfp_t);
	char name[16];
	struct module___288 *owner;
};

struct tcp_sock_af_ops___13;

struct tcp_fastopen_request___13;

struct tcp_sock___13 {
	struct inet_connection_sock___16 inet_conn;
	u16 tcp_header_len;
	u16 gso_segs;
	__be32 pred_flags;
	u64 bytes_received;
	u32 segs_in;
	u32 data_segs_in;
	u32 rcv_nxt;
	u32 copied_seq;
	u32 rcv_wup;
	u32 snd_nxt;
	u32 segs_out;
	u32 data_segs_out;
	u64 bytes_sent;
	u64 bytes_acked;
	u32 dsack_dups;
	u32 snd_una;
	u32 snd_sml;
	u32 rcv_tstamp;
	u32 lsndtime;
	u32 last_oow_ack_time;
	u32 compressed_ack_rcv_nxt;
	u32 tsoffset;
	struct list_head tsq_node;
	struct list_head tsorted_sent_queue;
	u32 snd_wl1;
	u32 snd_wnd;
	u32 max_window;
	u32 mss_cache;
	u32 window_clamp;
	u32 rcv_ssthresh;
	struct tcp_rack rack;
	u16 advmss;
	u8 compressed_ack;
	u8 dup_ack_counter: 2;
	u8 tlp_retrans: 1;
	u8 unused: 5;
	long: 27;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 chrono_start;
	u32 chrono_stat[3];
	u8 chrono_type: 2;
	u8 rate_app_limited: 1;
	u8 fastopen_connect: 1;
	u8 fastopen_no_cookie: 1;
	u8 is_sack_reneg: 1;
	u8 fastopen_client_fail: 2;
	u8 nonagle: 4;
	u8 thin_lto: 1;
	u8 recvmsg_inq: 1;
	u8 repair: 1;
	u8 frto: 1;
	long: 47;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 repair_queue;
	u8 save_syn: 2;
	u8 syn_data: 1;
	u8 syn_fastopen: 1;
	u8 syn_fastopen_exp: 1;
	u8 syn_fastopen_ch: 1;
	u8 syn_data_acked: 1;
	u8 is_cwnd_limited: 1;
	long: 63;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u32 tlp_high_seq;
	u32 tcp_tx_delay;
	u64 tcp_wstamp_ns;
	u64 tcp_clock_cache;
	u64 tcp_mstamp;
	u32 srtt_us;
	u32 mdev_us;
	u32 mdev_max_us;
	u32 rttvar_us;
	u32 rtt_seq;
	struct minmax rtt_min;
	u32 packets_out;
	u32 retrans_out;
	u32 max_packets_out;
	u32 max_packets_seq;
	u16 urg_data;
	u8 ecn_flags;
	u8 keepalive_probes;
	u32 reordering;
	u32 reord_seen;
	u32 snd_up;
	struct tcp_options_received rx_opt;
	u32 snd_ssthresh;
	u32 snd_cwnd;
	u32 snd_cwnd_cnt;
	u32 snd_cwnd_clamp;
	u32 snd_cwnd_used;
	u32 snd_cwnd_stamp;
	u32 prior_cwnd;
	u32 prr_delivered;
	u32 prr_out;
	u32 delivered;
	u32 delivered_ce;
	u32 lost;
	u32 app_limited;
	u64 first_tx_mstamp;
	u64 delivered_mstamp;
	u32 rate_delivered;
	u32 rate_interval_us;
	u32 rcv_wnd;
	u32 write_seq;
	u32 notsent_lowat;
	u32 pushed_seq;
	u32 lost_out;
	u32 sacked_out;
	struct hrtimer pacing_timer;
	struct hrtimer compressed_ack_timer;
	struct sk_buff___114 *lost_skb_hint;
	struct sk_buff___114 *retransmit_skb_hint;
	struct rb_root out_of_order_queue;
	struct sk_buff___114 *ooo_last_skb;
	struct tcp_sack_block duplicate_sack[1];
	struct tcp_sack_block selective_acks[4];
	struct tcp_sack_block recv_sack_cache[4];
	struct sk_buff___114 *highest_sack;
	int lost_cnt_hint;
	u32 prior_ssthresh;
	u32 high_seq;
	u32 retrans_stamp;
	u32 undo_marker;
	int undo_retrans;
	u64 bytes_retrans;
	u32 total_retrans;
	u32 urg_seq;
	unsigned int keepalive_time;
	unsigned int keepalive_intvl;
	int linger2;
	u8 bpf_sock_ops_cb_flags;
	u16 timeout_rehash;
	u32 rcv_ooopack;
	u32 rcv_rtt_last_tsecr;
	struct {
		u32 rtt_us;
		u32 seq;
		u64 time;
	} rcv_rtt_est;
	struct {
		u32 space;
		u32 seq;
		u64 time;
	} rcvq_space;
	struct {
		u32 probe_seq_start;
		u32 probe_seq_end;
	} mtu_probe;
	u32 mtu_info;
	bool is_mptcp;
	bool syn_smc;
	const struct tcp_sock_af_ops___13 *af_specific;
	struct tcp_md5sig_info *md5sig_info;
	struct tcp_fastopen_request___13 *fastopen_req;
	struct request_sock___83 *fastopen_rsk;
	struct saved_syn *saved_syn;
};

struct tcp_sock_af_ops___13 {
	struct tcp_md5sig_key * (*md5_lookup)(const struct sock___97 *, const struct sock___97 *);
	int (*calc_md5_hash)(char *, const struct tcp_md5sig_key *, const struct sock___97 *, const struct sk_buff___114 *);
	int (*md5_parse)(struct sock___97 *, int, sockptr_t, int);
};

struct tcp_fastopen_request___13 {
	struct tcp_fastopen_cookie cookie;
	struct msghdr___100 *data;
	size_t size;
	int copied;
	struct ubuf_info___16 *uarg;
};

struct ip6_flowlabel___28;

struct ipv6_fl_socklist___28 {
	struct ipv6_fl_socklist___28 *next;
	struct ip6_flowlabel___28 *fl;
	struct callback_head rcu;
};

struct ifmcaddr6___78 {
	struct in6_addr mca_addr;
	struct inet6_dev___78 *idev;
	struct ifmcaddr6___78 *next;
	struct ip6_sf_list *mca_sources;
	struct ip6_sf_list *mca_tomb;
	unsigned int mca_sfmode;
	unsigned char mca_crcount;
	long unsigned int mca_sfcount[2];
	struct delayed_work mca_work;
	unsigned int mca_flags;
	int mca_users;
	refcount_t mca_refcnt;
	long unsigned int mca_cstamp;
	long unsigned int mca_tstamp;
	struct callback_head rcu;
};

struct ip6_flowlabel___28 {
	struct ip6_flowlabel___28 *next;
	__be32 label;
	atomic_t users;
	struct in6_addr dst;
	struct ipv6_txoptions *opt;
	long unsigned int linger;
	struct callback_head rcu;
	u8 share;
	union {
		struct pid___281 *pid;
		kuid_t uid;
	} owner;
	long unsigned int lastuse;
	long unsigned int expires;
	struct net___118 *fl_net;
};

struct genl_ops___10;

struct genl_info___10;

struct genl_small_ops___10;

struct genl_family___10 {
	int id;
	unsigned int hdrsize;
	char name[16];
	unsigned int version;
	unsigned int maxattr;
	unsigned int mcgrp_offset;
	u8 netnsok: 1;
	u8 parallel_ops: 1;
	long: 39;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 n_ops;
	u8 n_small_ops;
	u8 n_mcgrps;
	const struct nla_policy *policy;
	int (*pre_doit)(const struct genl_ops___10 *, struct sk_buff___114 *, struct genl_info___10 *);
	void (*post_doit)(const struct genl_ops___10 *, struct sk_buff___114 *, struct genl_info___10 *);
	const struct genl_ops___10 *ops;
	const struct genl_small_ops___10 *small_ops;
	const struct genl_multicast_group *mcgrps;
	struct module___288 *module;
};

struct genl_ops___10 {
	int (*doit)(struct sk_buff___114 *, struct genl_info___10 *);
	int (*start)(struct netlink_callback___113 *);
	int (*dumpit)(struct sk_buff___114 *, struct netlink_callback___113 *);
	int (*done)(struct netlink_callback___113 *);
	const struct nla_policy *policy;
	unsigned int maxattr;
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

struct genl_info___10 {
	u32 snd_seq;
	u32 snd_portid;
	struct nlmsghdr *nlhdr;
	struct genlmsghdr *genlhdr;
	void *userhdr;
	struct nlattr **attrs;
	possible_net_t___113 _net;
	void *user_ptr[2];
	struct netlink_ext_ack *extack;
};

struct genl_small_ops___10 {
	int (*doit)(struct sk_buff___114 *, struct genl_info___10 *);
	int (*dumpit)(struct sk_buff___114 *, struct netlink_callback___113 *);
	u8 cmd;
	u8 internal_flags;
	u8 flags;
	u8 validate;
};

enum {
	MPTCP_PM_ATTR_UNSPEC = 0,
	MPTCP_PM_ATTR_ADDR = 1,
	MPTCP_PM_ATTR_RCV_ADD_ADDRS = 2,
	MPTCP_PM_ATTR_SUBFLOWS = 3,
	__MPTCP_PM_ATTR_MAX = 4,
};

enum {
	MPTCP_PM_ADDR_ATTR_UNSPEC = 0,
	MPTCP_PM_ADDR_ATTR_FAMILY = 1,
	MPTCP_PM_ADDR_ATTR_ID = 2,
	MPTCP_PM_ADDR_ATTR_ADDR4 = 3,
	MPTCP_PM_ADDR_ATTR_ADDR6 = 4,
	MPTCP_PM_ADDR_ATTR_PORT = 5,
	MPTCP_PM_ADDR_ATTR_FLAGS = 6,
	MPTCP_PM_ADDR_ATTR_IF_IDX = 7,
	__MPTCP_PM_ADDR_ATTR_MAX = 8,
};

enum {
	MPTCP_PM_CMD_UNSPEC = 0,
	MPTCP_PM_CMD_ADD_ADDR = 1,
	MPTCP_PM_CMD_DEL_ADDR = 2,
	MPTCP_PM_CMD_GET_ADDR = 3,
	MPTCP_PM_CMD_FLUSH_ADDRS = 4,
	MPTCP_PM_CMD_SET_LIMITS = 5,
	MPTCP_PM_CMD_GET_LIMITS = 6,
	MPTCP_PM_CMD_SET_FLAGS = 7,
	__MPTCP_PM_CMD_AFTER_LAST = 8,
};

enum mptcp_event_attr {
	MPTCP_ATTR_UNSPEC = 0,
	MPTCP_ATTR_TOKEN = 1,
	MPTCP_ATTR_FAMILY = 2,
	MPTCP_ATTR_LOC_ID = 3,
	MPTCP_ATTR_REM_ID = 4,
	MPTCP_ATTR_SADDR4 = 5,
	MPTCP_ATTR_SADDR6 = 6,
	MPTCP_ATTR_DADDR4 = 7,
	MPTCP_ATTR_DADDR6 = 8,
	MPTCP_ATTR_SPORT = 9,
	MPTCP_ATTR_DPORT = 10,
	MPTCP_ATTR_BACKUP = 11,
	MPTCP_ATTR_ERROR = 12,
	MPTCP_ATTR_FLAGS = 13,
	MPTCP_ATTR_TIMEOUT = 14,
	MPTCP_ATTR_IF_IDX = 15,
	MPTCP_ATTR_RESET_REASON = 16,
	MPTCP_ATTR_RESET_FLAGS = 17,
	__MPTCP_ATTR_AFTER_LAST = 18,
};

struct mptcp_data_frag___3 {
	struct list_head list;
	u64 data_seq;
	u16 data_len;
	u16 offset;
	u16 overhead;
	u16 already_sent;
	struct page___309 *page;
};

struct mptcp_sock___4 {
	struct inet_connection_sock___16 sk;
	u64 local_key;
	u64 remote_key;
	u64 write_seq;
	u64 snd_nxt;
	u64 ack_seq;
	u64 rcv_wnd_sent;
	u64 rcv_data_fin_seq;
	int wmem_reserved;
	struct sock___97 *last_snd;
	int snd_burst;
	int old_wspace;
	u64 recovery_snd_nxt;
	u64 snd_una;
	u64 wnd_end;
	long unsigned int timer_ival;
	u32 token;
	int rmem_released;
	long unsigned int flags;
	bool recovery;
	bool can_ack;
	bool fully_established;
	bool rcv_data_fin;
	bool snd_data_fin_enable;
	bool rcv_fastclose;
	bool use_64bit_ack;
	bool csum_enabled;
	spinlock_t join_list_lock;
	struct work_struct work;
	struct sk_buff___114 *ooo_last_skb;
	struct rb_root out_of_order_queue;
	struct sk_buff_head___113 receive_queue;
	int tx_pending_data;
	struct list_head conn_list;
	struct list_head rtx_queue;
	struct mptcp_data_frag___3 *first_pending;
	struct list_head join_list;
	struct socket___100 *subflow;
	struct sock___97 *first;
	struct mptcp_pm_data pm;
	struct {
		u32 space;
		u32 copied;
		u64 time;
		u64 rtt_us;
	} rcvq_space;
	u32 setsockopt_seq;
	char ca_name[16];
};

struct mptcp_subflow_context___3 {
	struct list_head node;
	u64 local_key;
	u64 remote_key;
	u64 idsn;
	u64 map_seq;
	u32 snd_isn;
	u32 token;
	u32 rel_write_seq;
	u32 map_subflow_seq;
	u32 ssn_offset;
	u32 map_data_len;
	__wsum map_data_csum;
	u32 map_csum_len;
	u32 request_mptcp: 1;
	u32 request_join: 1;
	u32 request_bkup: 1;
	u32 mp_capable: 1;
	u32 mp_join: 1;
	u32 fully_established: 1;
	u32 pm_notified: 1;
	u32 conn_finished: 1;
	u32 map_valid: 1;
	u32 map_csum_reqd: 1;
	u32 map_data_fin: 1;
	u32 mpc_map: 1;
	u32 backup: 1;
	u32 send_mp_prio: 1;
	u32 send_mp_fail: 1;
	u32 rx_eof: 1;
	u32 can_ack: 1;
	u32 disposable: 1;
	u32 stale: 1;
	long: 31;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	enum mptcp_data_avail data_avail;
	u32 remote_nonce;
	u64 thmac;
	u32 local_nonce;
	u32 remote_token;
	u8 hmac[20];
	u8 local_id;
	u8 remote_id;
	u8 reset_seen: 1;
	u8 reset_transient: 1;
	u8 reset_reason: 4;
	long: 52;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 stale_count;
	long int delegated_status;
	struct list_head delegated_node;
	u32 setsockopt_seq;
	u32 stale_rcv_tstamp;
	struct sock___97 *tcp_sock;
	struct sock___97 *conn;
	const struct inet_connection_sock_af_ops___16 *icsk_af_ops;
	void (*tcp_data_ready)(struct sock___97 *);
	void (*tcp_state_change)(struct sock___97 *);
	void (*tcp_write_space)(struct sock___97 *);
	void (*tcp_error_report)(struct sock___97 *);
	struct callback_head rcu;
};

struct mptcp_pm_addr_entry {
	struct list_head list;
	struct mptcp_addr_info addr;
	u8 flags;
	int ifindex;
	struct socket___100 *lsk;
};

struct mptcp_pm_add_entry___2 {
	struct list_head list;
	struct mptcp_addr_info addr;
	struct timer_list add_timer;
	struct mptcp_sock___4 *sock;
	u8 retrans_times;
};

struct pm_nl_pernet {
	spinlock_t lock;
	struct list_head local_addr_list;
	unsigned int addrs;
	unsigned int stale_loss_cnt;
	unsigned int add_addr_signal_max;
	unsigned int add_addr_accept_max;
	unsigned int local_addr_max;
	unsigned int subflows_max;
	unsigned int next_id;
	long unsigned int id_bitmap[4];
};

struct mptcp_subflow_request_sock___4 {
	struct tcp_request_sock___9 sk;
	u16 mp_capable;
	u16 mp_join;
	u16 backup;
	u16 csum_reqd;
	u16 allow_join_id0;
	long: 56;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	long: 64;
	u8 local_id;
	u8 remote_id;
	u64 local_key;
	u64 idsn;
	u32 token;
	u32 ssn_offset;
	u64 thmac;
	u32 local_nonce;
	u32 remote_nonce;
	struct mptcp_sock___3 *msk;
	struct hlist_nulls_node token_node;
};

struct join_entry {
	u32 token;
	u32 remote_nonce;
	u32 local_nonce;
	u8 join_id;
	u8 local_id;
	u8 backup;
	u8 valid;
};

typedef struct {
	u32 version;
	u32 length;
	u64 memory_protection_attribute;
} efi_properties_table_t;

typedef union {
	struct {
		u32 revision;
		efi_handle_t parent_handle;
		efi_system_table_t *system_table;
		efi_handle_t device_handle;
		void *file_path;
		void *reserved;
		u32 load_options_size;
		void *load_options;
		void *image_base;
		__u64 image_size;
		unsigned int image_code_type;
		unsigned int image_data_type;
		efi_status_t (*unload)(efi_handle_t);
	};
	struct {
		u32 revision;
		u32 parent_handle;
		u32 system_table;
		u32 device_handle;
		u32 file_path;
		u32 reserved;
		u32 load_options_size;
		u32 load_options;
		u32 image_base;
		__u64 image_size;
		u32 image_code_type;
		u32 image_data_type;
		u32 unload;
	} mixed_mode;
} efi_loaded_image_t;

struct efi_boot_memmap {
	efi_memory_desc_t **map;
	long unsigned int *map_size;
	long unsigned int *desc_size;
	u32 *desc_ver;
	long unsigned int *key_ptr;
	long unsigned int *buff_size;
};

typedef efi_status_t (*efi_exit_boot_map_processing)(struct efi_boot_memmap *, void *);

struct exit_boot_struct {
	efi_memory_desc_t *runtime_map;
	int *runtime_entry_count;
	void *new_fdt_addr;
};

union efi_simple_text_input_protocol___2;

typedef union efi_simple_text_input_protocol___2 efi_simple_text_input_protocol_t___2;

union efi_simple_text_input_protocol___2 {
	struct {
		void *reset;
		efi_status_t (*read_keystroke)(efi_simple_text_input_protocol_t___2 *, efi_input_key_t *);
		efi_event_t wait_for_key;
	};
	struct {
		u32 reset;
		u32 read_keystroke;
		u32 wait_for_key;
	} mixed_mode;
};

union efi_simple_text_output_protocol___2;

typedef union efi_simple_text_output_protocol___2 efi_simple_text_output_protocol_t___2;

union efi_simple_text_output_protocol___2 {
	struct {
		void *reset;
		efi_status_t (*output_string)(efi_simple_text_output_protocol_t___2 *, efi_char16_t *);
		void *test_string;
	};
	struct {
		u32 reset;
		u32 output_string;
		u32 test_string;
	} mixed_mode;
};

typedef union {
	struct {
		efi_table_hdr_t hdr;
		long unsigned int fw_vendor;
		u32 fw_revision;
		long unsigned int con_in_handle;
		efi_simple_text_input_protocol_t___2 *con_in;
		long unsigned int con_out_handle;
		efi_simple_text_output_protocol_t___2 *con_out;
		long unsigned int stderr_handle;
		long unsigned int stderr;
		efi_runtime_services_t *runtime;
		efi_boot_services_t *boottime;
		long unsigned int nr_tables;
		long unsigned int tables;
	};
	efi_system_table_32_t mixed_mode;
} efi_system_table_t___2;

typedef struct {
	u32 red_mask;
	u32 green_mask;
	u32 blue_mask;
	u32 reserved_mask;
} efi_pixel_bitmask_t;

typedef struct {
	u32 version;
	u32 horizontal_resolution;
	u32 vertical_resolution;
	int pixel_format;
	efi_pixel_bitmask_t pixel_information;
	u32 pixels_per_scan_line;
} efi_graphics_output_mode_info_t;

union efi_graphics_output_protocol_mode {
	struct {
		u32 max_mode;
		u32 mode;
		efi_graphics_output_mode_info_t *info;
		long unsigned int size_of_info;
		efi_physical_addr_t frame_buffer_base;
		long unsigned int frame_buffer_size;
	};
	struct {
		u32 max_mode;
		u32 mode;
		u32 info;
		u32 size_of_info;
		u64 frame_buffer_base;
		u32 frame_buffer_size;
	} mixed_mode;
};

typedef union efi_graphics_output_protocol_mode efi_graphics_output_protocol_mode_t;

union efi_graphics_output_protocol;

typedef union efi_graphics_output_protocol efi_graphics_output_protocol_t;

union efi_graphics_output_protocol {
	struct {
		efi_status_t (*query_mode)(efi_graphics_output_protocol_t *, u32, long unsigned int *, efi_graphics_output_mode_info_t **);
		efi_status_t (*set_mode)(efi_graphics_output_protocol_t *, u32);
		void *blt;
		efi_graphics_output_protocol_mode_t *mode;
	};
	struct {
		u32 query_mode;
		u32 set_mode;
		u32 blt;
		u32 mode;
	} mixed_mode;
};

enum efi_cmdline_option {
	EFI_CMDLINE_NONE = 0,
	EFI_CMDLINE_MODE_NUM = 1,
	EFI_CMDLINE_RES = 2,
	EFI_CMDLINE_AUTO = 3,
	EFI_CMDLINE_LIST = 4,
};

struct efi_generic_dev_path___2;

typedef struct efi_generic_dev_path___2 efi_device_path_protocol_t___2;

union efi_boot_services___2 {
	struct {
		efi_table_hdr_t hdr;
		void *raise_tpl;
		void *restore_tpl;
		efi_status_t (*allocate_pages)(int, int, long unsigned int, efi_physical_addr_t *);
		efi_status_t (*free_pages)(efi_physical_addr_t, long unsigned int);
		efi_status_t (*get_memory_map)(long unsigned int *, void *, long unsigned int *, long unsigned int *, u32 *);
		efi_status_t (*allocate_pool)(int, long unsigned int, void **);
		efi_status_t (*free_pool)(void *);
		efi_status_t (*create_event)(u32, long unsigned int, efi_event_notify_t, void *, efi_event_t *);
		efi_status_t (*set_timer)(efi_event_t, EFI_TIMER_DELAY, u64);
		efi_status_t (*wait_for_event)(long unsigned int, efi_event_t *, long unsigned int *);
		void *signal_event;
		efi_status_t (*close_event)(efi_event_t);
		void *check_event;
		void *install_protocol_interface;
		void *reinstall_protocol_interface;
		void *uninstall_protocol_interface;
		efi_status_t (*handle_protocol)(efi_handle_t, efi_guid_t *, void **);
		void *__reserved;
		void *register_protocol_notify;
		efi_status_t (*locate_handle)(int, efi_guid_t *, void *, long unsigned int *, efi_handle_t *);
		efi_status_t (*locate_device_path)(efi_guid_t *, efi_device_path_protocol_t___2 **, efi_handle_t *);
		efi_status_t (*install_configuration_table)(efi_guid_t *, void *);
		void *load_image;
		void *start_image;
		efi_status_t (*exit)(efi_handle_t, efi_status_t, long unsigned int, efi_char16_t *);
		void *unload_image;
		efi_status_t (*exit_boot_services)(efi_handle_t, long unsigned int);
		void *get_next_monotonic_count;
		efi_status_t (*stall)(long unsigned int);
		void *set_watchdog_timer;
		void *connect_controller;
		efi_status_t (*disconnect_controller)(efi_handle_t, efi_handle_t, efi_handle_t);
		void *open_protocol;
		void *close_protocol;
		void *open_protocol_information;
		void *protocols_per_handle;
		void *locate_handle_buffer;
		efi_status_t (*locate_protocol)(efi_guid_t *, void *, void **);
		void *install_multiple_protocol_interfaces;
		void *uninstall_multiple_protocol_interfaces;
		void *calculate_crc32;
		void *copy_mem;
		void *set_mem;
		void *create_event_ex;
	};
	struct {
		efi_table_hdr_t hdr;
		u32 raise_tpl;
		u32 restore_tpl;
		u32 allocate_pages;
		u32 free_pages;
		u32 get_memory_map;
		u32 allocate_pool;
		u32 free_pool;
		u32 create_event;
		u32 set_timer;
		u32 wait_for_event;
		u32 signal_event;
		u32 close_event;
		u32 check_event;
		u32 install_protocol_interface;
		u32 reinstall_protocol_interface;
		u32 uninstall_protocol_interface;
		u32 handle_protocol;
		u32 __reserved;
		u32 register_protocol_notify;
		u32 locate_handle;
		u32 locate_device_path;
		u32 install_configuration_table;
		u32 load_image;
		u32 start_image;
		u32 exit;
		u32 unload_image;
		u32 exit_boot_services;
		u32 get_next_monotonic_count;
		u32 stall;
		u32 set_watchdog_timer;
		u32 connect_controller;
		u32 disconnect_controller;
		u32 open_protocol;
		u32 close_protocol;
		u32 open_protocol_information;
		u32 protocols_per_handle;
		u32 locate_handle_buffer;
		u32 locate_protocol;
		u32 install_multiple_protocol_interfaces;
		u32 uninstall_multiple_protocol_interfaces;
		u32 calculate_crc32;
		u32 copy_mem;
		u32 set_mem;
		u32 create_event_ex;
	} mixed_mode;
};

typedef union efi_boot_services___2 efi_boot_services_t___2;

typedef union {
	struct {
		efi_table_hdr_t hdr;
		long unsigned int fw_vendor;
		u32 fw_revision;
		long unsigned int con_in_handle;
		efi_simple_text_input_protocol_t *con_in;
		long unsigned int con_out_handle;
		efi_simple_text_output_protocol_t *con_out;
		long unsigned int stderr_handle;
		long unsigned int stderr;
		efi_runtime_services_t *runtime;
		efi_boot_services_t___2 *boottime;
		long unsigned int nr_tables;
		long unsigned int tables;
	};
	efi_system_table_32_t mixed_mode;
} efi_system_table_t___3;

struct efi_generic_dev_path___2 {
	u8 type;
	u8 sub_type;
	u16 length;
};

struct linux_efi_random_seed___2 {
	u32 size;
	u8 bits[0];
};

union efi_rng_protocol;

typedef union efi_rng_protocol efi_rng_protocol_t;

union efi_rng_protocol {
	struct {
		efi_status_t (*get_info)(efi_rng_protocol_t *, long unsigned int *, efi_guid_t *);
		efi_status_t (*get_rng)(efi_rng_protocol_t *, efi_guid_t *, long unsigned int, u8 *);
	};
	struct {
		u32 get_info;
		u32 get_rng;
	} mixed_mode;
};

typedef u32 efi_tcg2_event_log_format;

union efi_tcg2_protocol;

typedef union efi_tcg2_protocol efi_tcg2_protocol_t;

union efi_tcg2_protocol {
	struct {
		void *get_capability;
		efi_status_t (*get_event_log)(efi_tcg2_protocol_t *, efi_tcg2_event_log_format, efi_physical_addr_t *, efi_physical_addr_t *, efi_bool_t *);
		void *hash_log_extend_event;
		void *submit_command;
		void *get_active_pcr_banks;
		void *set_active_pcr_banks;
		void *get_result_of_set_active_pcr_banks;
	};
	struct {
		u32 get_capability;
		u32 get_event_log;
		u32 hash_log_extend_event;
		u32 submit_command;
		u32 get_active_pcr_banks;
		u32 set_active_pcr_banks;
		u32 get_result_of_set_active_pcr_banks;
	} mixed_mode;
};

struct efi_vendor_dev_path {
	struct efi_generic_dev_path header;
	efi_guid_t vendorguid;
	u8 vendordata[0];
};

typedef union {
	struct {
		u32 revision;
		efi_handle_t parent_handle;
		efi_system_table_t___2 *system_table;
		efi_handle_t device_handle;
		void *file_path;
		void *reserved;
		u32 load_options_size;
		void *load_options;
		void *image_base;
		__u64 image_size;
		unsigned int image_code_type;
		unsigned int image_data_type;
		efi_status_t (*unload)(efi_handle_t);
	};
	struct {
		u32 revision;
		u32 parent_handle;
		u32 system_table;
		u32 device_handle;
		u32 file_path;
		u32 reserved;
		u32 load_options_size;
		u32 load_options;
		u32 image_base;
		__u64 image_size;
		u32 image_code_type;
		u32 image_data_type;
		u32 unload;
	} mixed_mode;
} efi_loaded_image_t___2;

union efi_load_file_protocol;

typedef union efi_load_file_protocol efi_load_file_protocol_t;

union efi_load_file_protocol {
	struct {
		efi_status_t (*load_file)(efi_load_file_protocol_t *, efi_device_path_protocol_t *, bool, long unsigned int *, void *);
	};
	struct {
		u32 load_file;
	} mixed_mode;
};

typedef union efi_load_file_protocol efi_load_file2_protocol_t;

typedef struct {
	u32 attributes;
	u16 file_path_list_length;
	u8 variable_data[0];
} __attribute__((packed)) efi_load_option_t;

typedef struct {
	u32 attributes;
	u16 file_path_list_length;
	const efi_char16_t *description;
	const efi_device_path_protocol_t *file_path_list;
	size_t optional_data_size;
	const void *optional_data;
} efi_load_option_unpacked_t;

typedef struct {
	u64 size;
	u64 file_size;
	u64 phys_size;
	efi_time_t create_time;
	efi_time_t last_access_time;
	efi_time_t modification_time;
	__u64 attribute;
	efi_char16_t filename[0];
} efi_file_info_t;

struct efi_file_protocol;

typedef struct efi_file_protocol efi_file_protocol_t;

struct efi_file_protocol {
	u64 revision;
	efi_status_t (*open)(efi_file_protocol_t *, efi_file_protocol_t **, efi_char16_t *, u64, u64);
	efi_status_t (*close)(efi_file_protocol_t *);
	efi_status_t (*delete)(efi_file_protocol_t *);
	efi_status_t (*read)(efi_file_protocol_t *, long unsigned int *, void *);
	efi_status_t (*write)(efi_file_protocol_t *, long unsigned int, void *);
	efi_status_t (*get_position)(efi_file_protocol_t *, u64 *);
	efi_status_t (*set_position)(efi_file_protocol_t *, u64);
	efi_status_t (*get_info)(efi_file_protocol_t *, efi_guid_t *, long unsigned int *, void *);
	efi_status_t (*set_info)(efi_file_protocol_t *, efi_guid_t *, long unsigned int, void *);
	efi_status_t (*flush)(efi_file_protocol_t *);
};

struct efi_simple_file_system_protocol;

typedef struct efi_simple_file_system_protocol efi_simple_file_system_protocol_t;

struct efi_simple_file_system_protocol {
	u64 revision;
	int (*open_volume)(efi_simple_file_system_protocol_t *, efi_file_protocol_t **);
};

struct finfo {
	efi_file_info_t info;
	efi_char16_t filename[256];
};

typedef enum {
	EfiPciIoWidthUint8 = 0,
	EfiPciIoWidthUint16 = 1,
	EfiPciIoWidthUint32 = 2,
	EfiPciIoWidthUint64 = 3,
	EfiPciIoWidthFifoUint8 = 4,
	EfiPciIoWidthFifoUint16 = 5,
	EfiPciIoWidthFifoUint32 = 6,
	EfiPciIoWidthFifoUint64 = 7,
	EfiPciIoWidthFillUint8 = 8,
	EfiPciIoWidthFillUint16 = 9,
	EfiPciIoWidthFillUint32 = 10,
	EfiPciIoWidthFillUint64 = 11,
	EfiPciIoWidthMaximum = 12,
} EFI_PCI_IO_PROTOCOL_WIDTH;

typedef struct {
	u32 read;
	u32 write;
} efi_pci_io_protocol_access_32_t;

typedef struct {
	void *read;
	void *write;
} efi_pci_io_protocol_access_t;

union efi_pci_io_protocol;

typedef union efi_pci_io_protocol efi_pci_io_protocol_t;

typedef efi_status_t (*efi_pci_io_protocol_cfg_t)(efi_pci_io_protocol_t *, EFI_PCI_IO_PROTOCOL_WIDTH, u32, long unsigned int, void *);

typedef struct {
	efi_pci_io_protocol_cfg_t read;
	efi_pci_io_protocol_cfg_t write;
} efi_pci_io_protocol_config_access_t;

union efi_pci_io_protocol {
	struct {
		void *poll_mem;
		void *poll_io;
		efi_pci_io_protocol_access_t mem;
		efi_pci_io_protocol_access_t io;
		efi_pci_io_protocol_config_access_t pci;
		void *copy_mem;
		void *map;
		void *unmap;
		void *allocate_buffer;
		void *free_buffer;
		void *flush;
		efi_status_t (*get_location)(efi_pci_io_protocol_t *, long unsigned int *, long unsigned int *, long unsigned int *, long unsigned int *);
		void *attributes;
		void *get_bar_attributes;
		void *set_bar_attributes;
		uint64_t romsize;
		void *romimage;
	};
	struct {
		u32 poll_mem;
		u32 poll_io;
		efi_pci_io_protocol_access_32_t mem;
		efi_pci_io_protocol_access_32_t io;
		efi_pci_io_protocol_access_32_t pci;
		u32 copy_mem;
		u32 map;
		u32 unmap;
		u32 allocate_buffer;
		u32 free_buffer;
		u32 flush;
		u32 get_location;
		u32 attributes;
		u32 get_bar_attributes;
		u32 set_bar_attributes;
		u64 romsize;
		u32 romimage;
	} mixed_mode;
};

#ifndef BPF_NO_PRESERVE_ACCESS_INDEX
#pragma clang attribute pop
#endif

#endif /* __VMLINUX_H__ */
